(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   3057650,     128389]*)
(*NotebookOutlinePosition[   3081501,     128935]*)
(*  CellTagsIndexPosition[   3080506,     128909]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Using RayTraceFunction", "Section",
  CellTags->"Using RayTraceFunction"],

Cell[CellGroupData[{

Cell["?RayTraceFunction", "Input",
  CellTags->"Using RayTraceFunction"],

Cell[BoxData[
    \("RayTraceFunction[inputparameters] is an encapsulated function, created \
by TurboTrace, that contains compiled source code for a specific optical \
system and performs high-speed, geometric ray-trace calculations. \n\nThe \
RayTraceFunction object is returned by TurboTrace when the option OutputType \
-> RayTraceFunction is given. Otherwise, for OutputType -> TurboSystem, \
RayTraceFunction is left embedded within the TurboSystem object and used \
internally by TurboTrace and TurboPlot. In general, user-specified symbolic \
parameters defined for the optical system are automatically included in the \
RayTraceFunction inputparameters. \n\nSee also: TurboTrace, SymbolicValues, \
EmbedRays, EmbedThresholdIntensity, EmbedGenerationLimit, ReportedParameters, \
and ReportedFunction."\)], "Print",
  CellTags->{"Info3252053846-2417689", "Using RayTraceFunction"}]
}, Open  ]],

Cell[BoxData[
    \(\(sys = {LineOfRays[45, 
            NumberOfRays \[Rule] 6], \[IndentingNewLine]Move[
            SphericalLens[{r1, 100}, {r2, \(-100\)}, 50, 10], 
            100], \[IndentingNewLine]Move[Baffle[50], 200]};\)\)], "Input",
  CellTags->"Using RayTraceFunction"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnalyzeSystem[sys, PlotType \[Rule] TopView];\)\)], "Input",
  CellTags->"Using RayTraceFunction"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.52381 .00655 -3 -4.5 ]
[.52381 .00655 3 4.5 ]
[.97619 .00655 -3 -4.5 ]
[.97619 .00655 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.51512 .03036 m
.5325 .03036 L
.54096 .07004 L
.50666 .07004 L
.51512 .03036 L
F
.50666 .07004 m
.54096 .07004 L
.54596 .10972 L
.50166 .10972 L
.50666 .07004 L
F
.50166 .10972 m
.54596 .10972 L
.54762 .1494 L
.5 .1494 L
.50166 .10972 L
F
.5 .1494 m
.54762 .1494 L
.54596 .18909 L
.50166 .18909 L
.5 .1494 L
F
.50166 .18909 m
.54596 .18909 L
.54096 .22877 L
.50666 .22877 L
.50166 .18909 L
F
.50666 .22877 m
.54096 .22877 L
.5325 .26845 L
.51512 .26845 L
.50666 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.51512 .03036 m
.50666 .07004 L
.50166 .10972 L
.5 .1494 L
.50166 .18909 L
.50666 .22877 L
.51512 .26845 L
.5325 .26845 L
.54096 .22877 L
.54596 .18909 L
.54762 .1494 L
.54596 .10972 L
.54096 .07004 L
.5325 .03036 L
.51512 .03036 L
s
.5 g
.51512 .1494 m
.5325 .1494 L
.54096 .1494 L
.50666 .1494 L
.51512 .1494 L
F
.50666 .1494 m
.54096 .1494 L
.54596 .1494 L
.50166 .1494 L
.50666 .1494 L
F
.50166 .1494 m
.54596 .1494 L
.54762 .1494 L
.5 .1494 L
.50166 .1494 L
F
.5 .1494 m
.54762 .1494 L
.54596 .1494 L
.50166 .1494 L
.5 .1494 L
F
.50166 .1494 m
.54596 .1494 L
.54096 .1494 L
.50666 .1494 L
.50166 .1494 L
F
.50666 .1494 m
.54096 .1494 L
.5325 .1494 L
.51512 .1494 L
.50666 .1494 L
F
0 g
.51512 .1494 m
.50666 .1494 L
.50166 .1494 L
.5 .1494 L
.50166 .1494 L
.50666 .1494 L
.51512 .1494 L
.5325 .1494 L
.54096 .1494 L
.54596 .1494 L
.54762 .1494 L
.54596 .1494 L
.54096 .1494 L
.5325 .1494 L
.51512 .1494 L
s
.51512 .26845 m
.5325 .26845 L
.5325 .2644 L
.51512 .2644 L
.51512 .26845 L
s
.51512 .2644 m
.5325 .2644 L
.5325 .2525 L
.51512 .2525 L
.51512 .2644 L
s
.51512 .2525 m
.5325 .2525 L
.5325 .23358 L
.51512 .23358 L
.51512 .2525 L
s
.51512 .23358 m
.5325 .23358 L
.5325 .20893 L
.51512 .20893 L
.51512 .23358 L
s
.51512 .20893 m
.5325 .20893 L
.5325 .18022 L
.51512 .18022 L
.51512 .20893 L
s
.51512 .18022 m
.5325 .18022 L
.5325 .1494 L
.51512 .1494 L
.51512 .18022 L
s
.51512 .1494 m
.5325 .1494 L
.5325 .11859 L
.51512 .11859 L
.51512 .1494 L
s
.51512 .11859 m
.5325 .11859 L
.5325 .08988 L
.51512 .08988 L
.51512 .11859 L
s
.51512 .08988 m
.5325 .08988 L
.5325 .06523 L
.51512 .06523 L
.51512 .08988 L
s
.51512 .06523 m
.5325 .06523 L
.5325 .04631 L
.51512 .04631 L
.51512 .06523 L
s
.51512 .04631 m
.5325 .04631 L
.5325 .03441 L
.51512 .03441 L
.51512 .04631 L
s
.51512 .03441 m
.5325 .03441 L
.5325 .03036 L
.51512 .03036 L
.51512 .03441 L
s
.51512 .03036 m
.5325 .03036 L
.5325 .03441 L
.51512 .03441 L
.51512 .03036 L
s
.51512 .03441 m
.5325 .03441 L
.5325 .04631 L
.51512 .04631 L
.51512 .03441 L
s
.51512 .04631 m
.5325 .04631 L
.5325 .06523 L
.51512 .06523 L
.51512 .04631 L
s
.51512 .06523 m
.5325 .06523 L
.5325 .08988 L
.51512 .08988 L
.51512 .06523 L
s
.51512 .08988 m
.5325 .08988 L
.5325 .11859 L
.51512 .11859 L
.51512 .08988 L
s
.51512 .11859 m
.5325 .11859 L
.5325 .1494 L
.51512 .1494 L
.51512 .11859 L
s
.51512 .1494 m
.5325 .1494 L
.5325 .18022 L
.51512 .18022 L
.51512 .1494 L
s
.51512 .18022 m
.5325 .18022 L
.5325 .20893 L
.51512 .20893 L
.51512 .18022 L
s
.51512 .20893 m
.5325 .20893 L
.5325 .23358 L
.51512 .23358 L
.51512 .20893 L
s
.51512 .23358 m
.5325 .23358 L
.5325 .2525 L
.51512 .2525 L
.51512 .23358 L
s
.51512 .2525 m
.5325 .2525 L
.5325 .2644 L
.51512 .2644 L
.51512 .2525 L
s
.51512 .2644 m
.5325 .2644 L
.5325 .26845 L
.51512 .26845 L
.51512 .2644 L
s
.5 g
.97619 .1494 m
.97619 .18909 L
.97619 .18774 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .18909 m
.97619 .22877 L
.97619 .22607 L
.97619 .18774 L
.97619 .18909 L
F
.97619 .22877 m
.97619 .26845 L
.97619 .2644 L
.97619 .22607 L
.97619 .22877 L
F
.97619 .1494 m
.97619 .18774 L
.97619 .18377 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .18774 m
.97619 .22607 L
.97619 .21814 L
.97619 .18377 L
.97619 .18774 L
F
.97619 .22607 m
.97619 .2644 L
.97619 .2525 L
.97619 .21814 L
.97619 .22607 L
F
.97619 .1494 m
.97619 .18377 L
.97619 .17746 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .18377 m
.97619 .21814 L
.97619 .20552 L
.97619 .17746 L
.97619 .18377 L
F
.97619 .21814 m
.97619 .2525 L
.97619 .23358 L
.97619 .20552 L
.97619 .21814 L
F
.97619 .1494 m
.97619 .17746 L
.97619 .16925 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .17746 m
.97619 .20552 L
.97619 .18909 L
.97619 .16925 L
.97619 .17746 L
F
.97619 .20552 m
.97619 .23358 L
.97619 .20893 L
.97619 .18909 L
.97619 .20552 L
F
.97619 .1494 m
.97619 .16925 L
.97619 .15968 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .16925 m
.97619 .18909 L
.97619 .16995 L
.97619 .15968 L
.97619 .16925 L
F
.97619 .18909 m
.97619 .20893 L
.97619 .18022 L
.97619 .16995 L
.97619 .18909 L
F
.97619 .1494 m
.97619 .15968 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .15968 m
.97619 .16995 L
.97619 .1494 L
.97619 .1494 L
.97619 .15968 L
F
.97619 .16995 m
.97619 .18022 L
.97619 .1494 L
.97619 .1494 L
.97619 .16995 L
F
.97619 .1494 m
.97619 .1494 L
.97619 .13913 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .1494 m
.97619 .1494 L
.97619 .12886 L
.97619 .13913 L
.97619 .1494 L
F
.97619 .1494 m
.97619 .1494 L
.97619 .11859 L
.97619 .12886 L
.97619 .1494 L
F
.97619 .1494 m
.97619 .13913 L
.97619 .12956 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .13913 m
.97619 .12886 L
.97619 .10972 L
.97619 .12956 L
.97619 .13913 L
F
.97619 .12886 m
.97619 .11859 L
.97619 .08988 L
.97619 .10972 L
.97619 .12886 L
F
.97619 .1494 m
.97619 .12956 L
.97619 .12134 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .12956 m
.97619 .10972 L
.97619 .09329 L
.97619 .12134 L
.97619 .12956 L
F
.97619 .10972 m
.97619 .08988 L
.97619 .06523 L
.97619 .09329 L
.97619 .10972 L
F
.97619 .1494 m
.97619 .12134 L
.97619 .11504 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .12134 m
.97619 .09329 L
.97619 .08067 L
.97619 .11504 L
.97619 .12134 L
F
.97619 .09329 m
.97619 .06523 L
.97619 .04631 L
.97619 .08067 L
.97619 .09329 L
F
.97619 .1494 m
.97619 .11504 L
.97619 .11107 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .11504 m
.97619 .08067 L
.97619 .07274 L
.97619 .11107 L
.97619 .11504 L
F
.97619 .08067 m
.97619 .04631 L
.97619 .03441 L
.97619 .07274 L
.97619 .08067 L
F
.97619 .1494 m
.97619 .11107 L
.97619 .10972 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .11107 m
.97619 .07274 L
.97619 .07004 L
.97619 .10972 L
.97619 .11107 L
F
.97619 .07274 m
.97619 .03441 L
.97619 .03036 L
.97619 .07004 L
.97619 .07274 L
F
.97619 .1494 m
.97619 .10972 L
.97619 .11107 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .10972 m
.97619 .07004 L
.97619 .07274 L
.97619 .11107 L
.97619 .10972 L
F
.97619 .07004 m
.97619 .03036 L
.97619 .03441 L
.97619 .07274 L
.97619 .07004 L
F
.97619 .1494 m
.97619 .11107 L
.97619 .11504 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .11107 m
.97619 .07274 L
.97619 .08067 L
.97619 .11504 L
.97619 .11107 L
F
.97619 .07274 m
.97619 .03441 L
.97619 .04631 L
.97619 .08067 L
.97619 .07274 L
F
.97619 .1494 m
.97619 .11504 L
.97619 .12134 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .11504 m
.97619 .08067 L
.97619 .09329 L
.97619 .12134 L
.97619 .11504 L
F
.97619 .08067 m
.97619 .04631 L
.97619 .06523 L
.97619 .09329 L
.97619 .08067 L
F
.97619 .1494 m
.97619 .12134 L
.97619 .12956 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .12134 m
.97619 .09329 L
.97619 .10972 L
.97619 .12956 L
.97619 .12134 L
F
.97619 .09329 m
.97619 .06523 L
.97619 .08988 L
.97619 .10972 L
.97619 .09329 L
F
.97619 .1494 m
.97619 .12956 L
.97619 .13913 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .12956 m
.97619 .10972 L
.97619 .12886 L
.97619 .13913 L
.97619 .12956 L
F
.97619 .10972 m
.97619 .08988 L
.97619 .11859 L
.97619 .12886 L
.97619 .10972 L
F
.97619 .1494 m
.97619 .13913 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .13913 m
.97619 .12886 L
.97619 .1494 L
.97619 .1494 L
.97619 .13913 L
F
.97619 .12886 m
.97619 .11859 L
.97619 .1494 L
.97619 .1494 L
.97619 .12886 L
F
.97619 .1494 m
.97619 .1494 L
.97619 .15968 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .1494 m
.97619 .1494 L
.97619 .16995 L
.97619 .15968 L
.97619 .1494 L
F
.97619 .1494 m
.97619 .1494 L
.97619 .18022 L
.97619 .16995 L
.97619 .1494 L
F
.97619 .1494 m
.97619 .15968 L
.97619 .16925 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .15968 m
.97619 .16995 L
.97619 .18909 L
.97619 .16925 L
.97619 .15968 L
F
.97619 .16995 m
.97619 .18022 L
.97619 .20893 L
.97619 .18909 L
.97619 .16995 L
F
.97619 .1494 m
.97619 .16925 L
.97619 .17746 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .16925 m
.97619 .18909 L
.97619 .20552 L
.97619 .17746 L
.97619 .16925 L
F
.97619 .18909 m
.97619 .20893 L
.97619 .23358 L
.97619 .20552 L
.97619 .18909 L
F
.97619 .1494 m
.97619 .17746 L
.97619 .18377 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .17746 m
.97619 .20552 L
.97619 .21814 L
.97619 .18377 L
.97619 .17746 L
F
.97619 .20552 m
.97619 .23358 L
.97619 .2525 L
.97619 .21814 L
.97619 .20552 L
F
.97619 .1494 m
.97619 .18377 L
.97619 .18774 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .18377 m
.97619 .21814 L
.97619 .22607 L
.97619 .18774 L
.97619 .18377 L
F
.97619 .21814 m
.97619 .2525 L
.97619 .2644 L
.97619 .22607 L
.97619 .21814 L
F
.97619 .1494 m
.97619 .18774 L
.97619 .18909 L
.97619 .1494 L
.97619 .1494 L
F
.97619 .18774 m
.97619 .22607 L
.97619 .22877 L
.97619 .18909 L
.97619 .18774 L
F
.97619 .22607 m
.97619 .2644 L
.97619 .26845 L
.97619 .22877 L
.97619 .22607 L
F
0 g
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .04226 m
.51221 .04226 L
s
% Start of user PostScript
0 -22.5 102.564 -22.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.51221 .04226 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .08512 m
.50436 .08512 L
s
% Start of user PostScript
0 -13.5 100.915 -13.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50436 .08512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .12798 m
.50048 .12798 L
s
% Start of user PostScript
0 -4.5 100.101 -4.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50048 .12798 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17083 m
.50048 .17083 L
s
% Start of user PostScript
0 4.5 100.101 4.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50048 .17083 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21369 m
.50436 .21369 L
s
% Start of user PostScript
0 13.5 100.915 13.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50436 .21369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25655 m
.51221 .25655 L
s
% Start of user PostScript
0 22.5 102.564 22.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.51221 .25655 Mdot
.039 .916 .04 r
.5 Mabswid
.51221 .04226 m
.53583 .04412 L
s
0 0 0 r
2 Mabswid
.53583 .04412 Mdot
.039 .916 .04 r
.5 Mabswid
.50436 .08512 m
.5435 .08694 L
s
0 0 0 r
2 Mabswid
.5435 .08694 Mdot
.039 .916 .04 r
.5 Mabswid
.50048 .12798 m
.54717 .12869 L
s
0 0 0 r
2 Mabswid
.54717 .12869 Mdot
.039 .916 .04 r
.5 Mabswid
.50048 .17083 m
.54717 .17011 L
s
0 0 0 r
2 Mabswid
.54717 .17011 Mdot
.039 .916 .04 r
.5 Mabswid
.50436 .21369 m
.5435 .21187 L
s
0 0 0 r
2 Mabswid
.5435 .21187 Mdot
.039 .916 .04 r
.5 Mabswid
.51221 .25655 m
.53583 .25469 L
s
0 0 0 r
2 Mabswid
.53583 .25469 Mdot
.039 .916 .04 r
.5 Mabswid
.53583 .04412 m
.97619 .15412 L
s
% Start of user PostScript
107.525 -22.1107 200. 0.990158 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .15412 Mdot
.039 .916 .04 r
.5 Mabswid
.5435 .08694 m
.97619 .14829 L
s
% Start of user PostScript
109.136 -13.1179 200. -0.234368 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .14829 Mdot
.039 .916 .04 r
.5 Mabswid
.54717 .12869 m
.97619 .14847 L
s
% Start of user PostScript
109.905 -4.34905 200. -0.196357 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .14847 Mdot
.039 .916 .04 r
.5 Mabswid
.54717 .17011 m
.97619 .15034 L
s
% Start of user PostScript
109.905 4.34905 200. 0.196357 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .15034 Mdot
.039 .916 .04 r
.5 Mabswid
.5435 .21187 m
.97619 .15052 L
s
% Start of user PostScript
109.136 13.1179 200. 0.234368 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .15052 Mdot
.039 .916 .04 r
.5 Mabswid
.53583 .25469 m
.97619 .14469 L
s
% Start of user PostScript
107.525 22.1107 200. -0.990158 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .14469 Mdot
[(L)] .52381 .00655 0 0 Mshowa
[(B)] .97619 .00655 0 0 Mshowa
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->True,
  ImageSize->{818.625, 224.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<b0000h2000`400?l00000o`00003oo`3ooooo
0?ooool0oooo=@3oool00?l0ooooo`3ooooo0?ooocD0oooo003o0?ooojX0oooo1@00003o0?ooof`0
oooo1000000E0?ooo`00o`3ooon[0?ooo`040000003oool0oooo00000?l0ooooK@3oool010000000
oooo0?ooo`00000D0?ooo`00o`3ooon[0?ooo`030000003oool0oooo0?l0ooooKP3oool010000000
oooo0?ooo`00000D0?ooo`00o`3ooon[0?ooo`030000003oool0oooo0?l0ooooKP3oool3000001D0
oooo003o0?oooj/0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`040000003oool0oooo000001@0
oooo003o0?oooj/0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`040000003oool0oooo000001@0
oooo003o0?ooojX0oooo0`00003o0?ooofh0oooo1000000E0?ooo`00o`3ooooo0?ooool0oooo=@3o
ool00?l0ooooo`3ooooo0?ooocD0oooo003o0?ooool0ooooo`3ooole0?ooo`00o`3ooooo0?ooool0
oooo=@3oool00?l0ooooo`3ooooo0?ooocD0oooo003o0?ooool0ooooo`3ooole0?ooo`00o`3ooooo
0?ooool0oooo=@3oool00?l0ooooo`3ooooo0?ooocD0oooo003o0?ooool0ooooo`3ooole0?ooo`00
o`3ooooo0?ooool0oooo=@3oool00?l0ooooo`3ooooo0?ooocD0oooo003o0?ooool0ooooo`3ooole
0?ooo`00o`3ooooo0?ooool0oooo=@3oool00?l0ooooo`3ooooo0?ooocD0oooo003o0?ooool0oooo
o`3ooole0?ooo`00o`3ooonV0?ooo`l00000o`3ooomY0?ooo`030000003oool0oooo01<0oooo003o
0?ooojH0oooo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`3o0?ooofL0oooo00<00000
0?ooo`3oool04`3oool00?l0ooooYP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo
0?l0ooooI`3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonU0?ooo`8000003@1oOgl200000?l0
ooooJ03oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonU0?oooa400000o`3ooomX0?ooo`030000
003oool0oooo01<0oooo003o0?ooojD0oooo0P00000=07moO`800000o`3ooomX0?ooo`030000003o
ool0oooo01<0oooo003o0?ooojD0oooo0P00000=07moO`800000o`3ooomX0?ooo`030000003oool0
oooo01<0oooo003o0?ooojD0oooo0P00000=07moO`800000o`3ooomX0?ooo`030000003oool0oooo
01<0oooo003o0?oooi/0oooo0`09jPX60?ooo`030000001oOgl0000000d0Ogmo00<0000007moO`00
0000o`3ooomW0?ooo`030000003oool0oooo01<0oooo003o0?oooi`0oooo1P09jPX01@3oool00000
0000001oOgl0000000d0Ogmo00<0000007moO`000000o`3ooomW0?ooo`030000003oool0oooo01<0
oooo000E0?ooool02NX:V@09jPX607moO`030000001oOgl000000?l0ooooI`3oool00`000000oooo
0?ooo`0C0?ooo`00o`3ooonL0?ooo`D02NX:0`3oool00`000000Ogmo0000000707moO`/02NX:o`3o
oomU0?ooo`030000003oool0oooo01<0oooo003o0?oooi/0oooo0P09jPX70?ooo`030000001oOgl0
000000d0Ogmo00D0000007moO`00000000000?ooo`0400WZ2_l0ooooH@3oool00`000000oooo0?oo
o`0C0?ooo`00o`3ooonS0?ooo`030000001oOgl0Ogmo00l000000P1oOgl00`000000oooo0?ooo`03
0?ooo`@02NX:o`3ooomM0?ooo`030000003oool0oooo01<0oooo003o0?oooj<0oooo00@0000007mo
O`1oOgl000003@1oOgl010000000Ogmo07moO`0000090?ooo`@02NX:o`3ooomI0?ooo`030000003o
ool0oooo01<0oooo003o0?oooj<0oooo00@0000007moO`1oOgl000003@1oOgl010000000Ogmo07mo
O`00000=0?ooo`@02NX:o`3ooomE0?ooo`030000003oool0oooo01<0oooo003o0?oooj<0oooo00@0
000007moO`1oOgl000003@1oOgl010000000Ogmo07moO`00000A0?ooo`@02NX:o`3ooomA0?ooo`03
0000003oool0oooo01<0oooo003o0?oooj80oooo00D0000007moO`1oOgl0Ogmo0000000=07moO`05
0000001oOgl0Ogmo07moO`000000503oool400WZ2_l0ooooC@3oool00`000000oooo0?ooo`0C0?oo
o`00o`3ooonR0?ooo`050000001oOgl0Ogmo07moO`0000003@1oOgl01@000000Ogmo07moO`1oOgl0
000001P0oooo1009jP[o0?ooodT0oooo00<000000?ooo`3oool04`3oool00?l0ooooXP3oool01@00
0000Ogmo07moO`1oOgl0000000d0Ogmo00D0000007moO`1oOgl0Ogmo0000000L0?ooo`@02NX:o`3o
oom50?ooo`030000003oool0oooo01<0oooo003o0?oooj80oooo00D0000007moO`1oOgl0Ogmo0000
000=07moO`050000001oOgl0Ogmo07moO`000000803oool400WZ2_l0oooo@@3oool00`000000oooo
0?ooo`0C0?ooo`00o`3ooonR0?ooo`050000001oOgl0Ogmo07moO`0000003@1oOgl01@000000Ogmo
07moO`1oOgl0000002@0oooo1009jP[o0?ooocd0oooo00<000000?ooo`3oool04`3oool00?l0oooo
X@3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0
0P1oOgl00`000000oooo0?ooo`0U0?ooo`@02NX:o`3oooli0?ooo`030000003oool0oooo01<0oooo
003o0?oooj40oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo0080Ogmo00<000000?ooo`3oool0:@3oool400WZ2_l0oooo=@3oool00`000000oooo0?oo
o`0C0?ooo`00o`3ooonQ0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl02`1oOgl0
0`000000Ogmo07moO`0207moO`030000003oool0oooo02d0oooo1009jP[o0?oooc40oooo00<00000
0?ooo`3oool04`3oool00?l0ooooX@3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo
00/0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0a0?ooo`@02NX:o`3oool]0?oo
o`030000003oool0oooo01<0oooo003o0?oooj40oooo00<0000007moO`1oOgl00P1oOgl00`000000
Ogmo07moO`0;07moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0=@3oool400WZ2_l0
oooo:@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonP0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03P0oooo
1009jP[o0?ooobD0oooo00<000000?ooo`3oool04`3oool00?l0ooooX03oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0l0?ooo`@02NX:o`3ooolQ0?ooo`030000003oool0oooo01<0oooo003o0?oooj00oooo00<00000
07moO`1oOgl00`1oOgl?000000D0Ogmo00<000000?ooo`3oool0@03oool400WZ2_l0oooo7@3oool0
0`000000oooo0?ooo`0C0?ooo`00o`3ooonP0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl02`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo04@0oooo1009jP[o0?oo
oaT0oooo00<000000?ooo`3oool04`3oool00?l0ooooX03oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`180?ooo`@0
2NX:o`3ooolE0?ooo`030000003oool0oooo01<0oooo003o0?oooil0oooo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
B`3oool400WZ2_l0oooo4@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonO0?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0407moO`030000003o
ool0oooo04l0oooo1009jP[o0?ooo`d0oooo00<000000?ooo`3oool04`3oool00?l0ooooW`3oool0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000oooo0?ooo`1C0?ooo`@02NX:o`3oool90?ooo`030000003oool0oooo01<0oooo003o0?oo
oil0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo
00@0Ogmo00<000000?ooo`3oool0E`3oool400WZ2_l0oooo1@3oool00`000000oooo0?ooo`0C0?oo
o`00o`3ooonO0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000
Ogmo07moO`0407moO`030000003oool0oooo05/0oooo1009jP[o0?ooo`40oooo00<000000?ooo`3o
ool04`3oool00?l0ooooW`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00/0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1O0?ooo`@02NX:o03oool00`000000oooo
0?ooo`0C0?ooo`00o`3ooonN0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl02`1o
Ogl00`000000Ogmo07moO`0507moO`030000003oool0oooo0680oooo1009jP[h0?ooo`030000003o
ool0oooo01<0oooo003o0?oooih0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0;
07moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0IP3oool400WZ2_@0oooo00<00000
0?ooo`3oool04`3oool00?l0ooooWP3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo
00/0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`1Z0?ooo`@02NX:l03oool00`00
0000oooo0?ooo`0C0?ooo`00o`3ooonN0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl02`1oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo06h0oooo1009jP[/0?ooo`03
0000003oool0oooo01<0oooo003o0?oooih0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo
07moO`0;07moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0LP3oool400WZ2^P0oooo
00<000000?ooo`3oool04`3oool00?l0ooooU@3oool300WZ2PH0oooo00<0000007moO`1oOgl01@1o
Ogl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0MP3o
ool400WZ2^@0oooo00<000000?ooo`3oool04`3oool00?l0ooooUP3oool600WZ2P<000001`1oOgl0
0`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0NP3oool4
00WZ2^00oooo00<000000?ooo`3oool04`3oool001D0ooooo`09jPZ700WZ2P0300000009jPX02NX:
00l02NX:1P1oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo07h0oooo1009jP[L0?oo
o`030000003oool0oooo01<0oooo003o0?oooiH0oooo1@09jPX20?ooo`030000001oOgl0Ogmo00H0
Ogmo00<0000007moO`1oOgl01@1oOgl>00WZ2P0300000009jPX02NX:00<02NX:O`3oool400WZ2]P0
oooo00<000000?ooo`3oool04`3oool00?l0ooooU@3oool200WZ2PH0oooo00<0000007moO`1oOgl0
1P1oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00D0Ogmo0P0000040?ooo`L02NX:
O03oool400WZ2]@0oooo00<000000?ooo`3oool04`3oool00?l0ooooW@3oool00`000000Ogmo07mo
O`0607moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl01P1oOgl00`000000oooo0?oo
o`090?ooo`L02NX:N@3oool400WZ2]00oooo00<000000?ooo`3oool04`3oool00?l0ooooW@3oool0
0`000000Ogmo07moO`0607moO`l00000201oOgl00`000000oooo0?ooo`0@0?ooo`L02NX:MP3oool4
00WZ2/`0oooo00<000000?ooo`3oool04`3oool00?l0ooooW@3oool00`000000Ogmo07moO`0607mo
O`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl01P1oOgl00`000000oooo0?ooo`0G0?oo
o`L02NX:L`3oool400WZ2/P0oooo00<000000?ooo`3oool04`3oool00?l0ooooW@3oool00`000000
Ogmo07moO`0607moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl01P1oOgl00`000000
oooo0?ooo`0N0?ooo`L02NX:L03oool400WZ2/@0oooo00<000000?ooo`3oool04`3oool00?l0oooo
W@3oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0
1P1oOgl00`000000oooo0?ooo`0U0?ooo`L02NX:K@3oool400WZ2/00oooo00<000000?ooo`3oool0
4`3oool00?l0ooooW@3oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo00/0Ogmo00<0
000007moO`1oOgl01P1oOgl00`000000oooo0?ooo`0/0?ooo`L02NX:JP3oool400WZ2[`0oooo00<0
00000?ooo`3oool04`3oool00?l0ooooW03oool00`000000Ogmo07moO`0707moO`030000001oOgl0
Ogmo00/0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`0b0?ooo`L02NX:I`3oool4
00WZ2[P0oooo00<000000?ooo`3oool04`3oool00?l0ooooW03oool00`000000Ogmo07moO`0707mo
O`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`0i0?oo
o`L02NX:I03oool400WZ2[@0oooo00<000000?ooo`3oool04`3oool00?l0ooooW03oool00`000000
Ogmo07moO`0707moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000
oooo0?ooo`100?ooo`L02NX:H@3oool300WZ2[40oooo00<000000?ooo`3oool04`3oool00?l0oooo
W03oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0
1`1oOgl00`000000oooo0?ooo`170?ooo`L02NX:G@3oool400WZ2Zd0oooo00<000000?ooo`3oool0
4`3oool00?l0ooooW03oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00/0Ogmo00<0
000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`1>0?ooo`L02NX:FP3oool400WZ2ZT0oooo00<0
00000?ooo`3oool04`3oool00?l0ooooW03oool00`000000Ogmo07moO`0707moO`030000001oOgl0
Ogmo00/0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`1E0?ooo`L02NX:E`3oool4
00WZ2ZD0oooo00<000000?ooo`3oool04`3oool00?l0ooooW03oool00`000000Ogmo07moO`0707mo
O`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`1L0?oo
o`L02NX:E03oool400WZ2Z40oooo00<000000?ooo`3oool04`3oool00?l0ooooW03oool00`000000
Ogmo07moO`0707moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000
oooo0?ooo`1S0?ooo`L02NX:D@3oool400WZ2Yd0oooo00<000000?ooo`3oool04`3oool00?l0oooo
V`3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0
201oOgl00`000000oooo0?ooo`1Y0?ooo`L02NX:CP3oool400WZ2YT0oooo00<000000?ooo`3oool0
4`3oool00?l0ooooV`3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo00/0Ogmo00<0
000007moO`1oOgl0201oOgl00`000000oooo0?ooo`1`0?ooo`L02NX:B`3oool400WZ2YD0oooo00<0
00000?ooo`3oool04`3oool00?l0ooooV`3oool00`000000Ogmo07moO`0807moO`030000001oOgl0
Ogmo00/0Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`1g0?ooo`L02NX:B03oool4
00WZ2Y40oooo00<000000?ooo`3oool04`3oool00?l0ooooV`3oool00`000000Ogmo07moO`0807mo
O`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`1n0?oo
o`L02NX:A@3oool400WZ2Xd0oooo00<000000?ooo`3oool04`3oool00?l0ooooV`3oool00`000000
Ogmo07moO`0807moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0201oOgl00`000000
oooo0?ooo`250?ooo`L02NX:@P3oool400WZ2XT0oooo00<000000?ooo`3oool04`3oool00?l0oooo
V`3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0
201oOgl00`000000oooo0?ooo`2<0?ooo`L02NX:?`3oool400WZ2XD0oooo00<000000?ooo`3oool0
4`3oool00?l0ooooV`3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo00/0Ogmo00<0
000007moO`1oOgl0201oOgl00`000000oooo0?ooo`2C0?ooo`L02NX:?03oool400WZ2X40oooo00<0
00000?ooo`3oool04`3oool00?l0ooooV`3oool00`000000Ogmo07moO`0807moO`030000001oOgl0
Ogmo00/0Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`2J0?ooo`L02NX:>@3oool4
00WZ2Wd0oooo00<000000?ooo`3oool04`3oool00?l0ooooV`3oool00`000000Ogmo07moO`0807mo
O`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`2Q0?oo
o`L02NX:=P3oool400WZ2WT0oooo00<000000?ooo`3oool04`3oool00?l0ooooV`3oool00`000000
Ogmo07moO`0807moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0201oOgl00`000000
oooo0?ooo`2X0?ooo`P02NX:<P3oool400WZ2WD0oooo00<000000?ooo`3oool04`3oool00?l0oooo
V`3oool00`000000Ogmo07moO`0807moO`l000002P1oOgl00`000000oooo0?ooo`2`0?ooo`L02NX:
;`3oool400WZ2W40oooo00<000000?ooo`3oool04`3oool00?l0ooooV`3oool00`000000Ogmo07mo
O`0807moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?oo
o`2g0?ooo`L02NX:;03oool400WZ2Vd0oooo00<000000?ooo`3oool04`3oool00?l0ooooVP3oool0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0201oOgl0
0`000000oooo0?ooo`2n0?ooo`L02NX::@3oool400WZ2VT0oooo00<000000?ooo`3oool04`3oool0
0?l0ooooVP3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00/0Ogmo00<0000007mo
O`1oOgl0201oOgl00`000000oooo0?ooo`350?ooo`L02NX:9P3oool400WZ2VD0oooo00<000000?oo
o`3oool04`3oool00?l0ooooVP3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00/0
Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`3<0?ooo`L02NX:8`3oool400WZ2V40
oooo00<000000?ooo`3oool04`3oool00?l0ooooVP3oool00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`3C0?ooo`L02NX:
803oool400WZ2Ud0oooo00<000000?ooo`3oool04`3oool00?l0ooooTP3oool300WZ2PD0oooo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00P0Ogmo00<0
00000?ooo`3oool0fP3oool700WZ2Qd0oooo1009jPYI0?ooo`030000003oool0oooo01<0oooo003o
0?oooi<0oooo1P09jPX2000000/0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`08
07moO`030000003oool0oooo0>40oooo1`09jPXJ0?ooo`@02NX:E@3oool00`000000oooo0?ooo`0C
0?ooo`005@3ooooo00WZ2X@02NX:00<0000000WZ2P09jPX08`09jPX00`0000002NX:00WZ2P0:00WZ
2]h0oooo1`09jPXG0?ooo`@02NX:D@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonC0?ooo`D0
2NX:0P3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1o
Ogl0201oOgl2000000/0oooo5P09jP[?0?ooo`L02NX:503oool400WZ2Td0oooo00<000000?ooo`3o
ool04`3oool00?l0ooooTP3oool200WZ2PH0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0;07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool07`3ooolF00WZ2/00oooo
1`09jPXA0?ooo`@02NX:B@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonJ0?ooo`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0907moO`030000003o
ool0oooo03D0oooo5@09jPZb0?ooo`L02NX:3P3oool400WZ2TD0oooo00<000000?ooo`3oool04`3o
ool00?l0ooooVP3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00/0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000oooo0?ooo`1:0?oooaH02NX:X`3oool700WZ2P/0oooo1009jPY1
0?ooo`030000003oool0oooo01<0oooo003o0?oooiX0oooo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0H03ooolF00WZ
2Y@0oooo1`09jPX80?ooo`@02NX:?@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonJ0?ooo`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0907moO`03
0000003oool0oooo07H0oooo5P09jPZ50?ooo`L02NX:1@3oool400WZ2ST0oooo00<000000?ooo`3o
ool04`3oool00?l0ooooVP3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00/0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`2<0?oooaH02NX:MP3oool700WZ2P80oooo
1009jPXe0?ooo`030000003oool0oooo01<0oooo003o0?oooiX0oooo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0XP3o
oolE00WZ2VP0oooo2P09jPXa0?ooo`030000003oool0oooo01<0oooo003o0?oooiX0oooo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
0?ooo`3oool0]`3ooolF00WZ2UT0oooo1`09jPX]0?ooo`030000003oool0oooo01<0oooo003o0?oo
oiT0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo
00T0Ogmo00<000000?ooo`3oool0c@3ooolF00WZ2TX0oooo1`09jPXV0?ooo`030000003oool0oooo
01<0oooo003o0?oooiT0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0;07moO`03
0000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0h`3ooolF00WZ2SP0oooo2P09jPXO0?ooo`03
0000003oool0oooo01<0oooo003o0?oooiT0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0;07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0n@3ooolF00WZ2RH0oooo
1009jPX20?ooo`L02NX:603oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonI0?ooo`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0907moO`030000003o
ool0oooo0?l0oooo403ooolE00WZ2QD0oooo1009jPX50?ooo`L02NX:2@3oool800WZ2P800000503o
ool00?l0ooooV@3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00/0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000oooo0?ooo`3o0?ooobD0oooo5P09jPX30?ooo`@02NX:203oool7
00WZ2P80oooo1`09jPX00`3oool000000000000D0?ooo`00o`3ooonI0?ooo`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo
0?l0oooo>`3ooolP00WZ2P030000003oool0oooo01<0oooo003o0?oooiT0oooo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3o
ool0o`3ooom60?ooo`@02NX:0`3oool>00WZ2P800000503oool00?l0ooooV@3ooolX00000?l0oooo
B`3oool500WZ2PD0oooo1`09jPX00`3oool000000000000D0?ooo`00o`3ooonI0?ooo`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0907moO`030000003o
ool0oooo0?l0ooooA@3oool400WZ2PD0oooo3@09jPX2000001@0oooo003o0?oooiT0oooo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
0?ooo`3oool0o`3ooolj0?ooob002NX:00<0oooo000000000000503oool00?l0ooooV@3oool00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000oooo0?ooo`3o0?ooob@0oooo5P09jPX30?ooo`@02NX:203oool700WZ2P<0oooo2009jPX00`00
0000oooo0?ooo`0C0?ooo`00o`3ooonI0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02`1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo0?l0oooo3`3ooolE00WZ2QD0
oooo1009jPX50?ooo`L02NX:2P3oool800WZ2P800000503oool00?l0ooooV@3oool00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo
0?ooo`3h0?oooaH02NX:9P3oool400WZ2P80oooo1`09jPXI0?ooo`800000503oool00?l0ooooV@3o
ool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000oooo0?ooo`3R0?oooaH02NX:>03oool:00WZ2R00oooo00<000000?ooo`3oool04`3o
ool00?l0ooooV@3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00/0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000oooo0?ooo`3<0?oooaH02NX:BP3oool700WZ2RL0oooo00<00000
0?ooo`3oool04`3oool00?l0ooooV@3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00/0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`2f0?oooaH02NX:F@3oool700WZ
2Rh0oooo00<000000?ooo`3oool04`3oool00?l0ooooVP3oool00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`2Q0?oooaD0
2NX:J03oool:00WZ2S80oooo00<000000?ooo`3oool04`3oool00?l0ooooVP3oool00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo
0?ooo`2;0?oooaH02NX:MP3oool700WZ2P80oooo1009jPXf0?ooo`030000003oool0oooo01<0oooo
003o0?oooiX0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo00T0Ogmo00<000000?ooo`3oool0M@3ooolF00WZ2XD0oooo1`09jPX50?ooo`@02NX:>P3o
ool00`000000oooo0?ooo`0C0?ooo`00o`3ooonJ0?ooo`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02`1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo05l0oooo5P09jPZD
0?ooo`L02NX:203oool400WZ2Sh0oooo00<000000?ooo`3oool04`3oool00?l0ooooVP3oool00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000oooo0?ooo`190?oooaH02NX:X`3oool700WZ2P/0oooo1009jPY20?ooo`030000003oool0oooo
01<0oooo003o0?oooiX0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0;07moO`03
0000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0=03ooolE00WZ2[80oooo1`09jPX>0?ooo`@0
2NX:AP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonJ0?ooo`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo01h0oooo
5P09jP[00?ooo`L02NX:4@3oool400WZ2TX0oooo00<000000?ooo`3oool04`3oool00?l0ooooTP3o
ool300WZ2PD0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo00T0Ogmo00<000000?ooo`3oool0203ooolF00WZ2/l0oooo1`09jPXD0?ooo`@02NX:CP3o
ool00`000000oooo0?ooo`0C0?ooo`00o`3ooonC0?ooo`H02NX:0P00000;07moO`030000001oOgl0
Ogmo00@0Ogmo4P09jPX00`0000002NX:00WZ2P0900WZ2]h0oooo1`09jPXG0?ooo`@02NX:DP3oool0
0`000000oooo0?ooo`0C0?ooo`005@3ooooo00WZ2X@02NX:00<0000000WZ2P09jPX04@09jPX707mo
O`030000001oOgl0Ogmo00P0Ogmo0P00003Q0?ooo`L02NX:6P3oool400WZ2UH0oooo00<000000?oo
o`3oool04`3oool00?l0ooooT`3oool500WZ2P80oooo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0;07moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool0f@3oool700WZ2Qd0
oooo1009jPYJ0?ooo`030000003oool0oooo01<0oooo003o0?oooi80oooo0P09jPX60?ooo`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0807moO`030000
003oool0oooo0=80oooo1`09jPXP0?ooo`@02NX:GP3oool00`000000oooo0?ooo`0C0?ooo`00o`3o
oonJ0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07mo
O`0807moO`030000003oool0oooo0</0oooo1`09jPXS0?ooo`@02NX:HP3oool00`000000oooo0?oo
o`0C0?ooo`00o`3ooonJ0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02`1oOgl0
0`000000Ogmo07moO`0807moO`030000003oool0oooo0<@0oooo1`09jPXV0?ooo`@02NX:IP3oool0
0`000000oooo0?ooo`0C0?ooo`00o`3ooonJ0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02`1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo0;d0oooo1`09jPXY0?oo
o`@02NX:JP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonJ0?ooo`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo0;H0
oooo1`09jPX/0?ooo`@02NX:KP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonJ0?ooo`030000
001oOgl0Ogmo00T0Ogmo3`00000:07moO`030000003oool0oooo0:l0oooo1`09jPX_0?ooo`@02NX:
LP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonK0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo0:L0oooo2009
jPXb0?ooo`@02NX:MP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonK0?ooo`030000001oOgl0
Ogmo00P0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0807moO`030000003oool0
oooo0:00oooo1`09jPXf0?ooo`@02NX:NP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonK0?oo
o`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0807mo
O`030000003oool0oooo09T0oooo1`09jPXi0?ooo`@02NX:OP3oool00`000000oooo0?ooo`0C0?oo
o`00o`3ooonK0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000
Ogmo07moO`0807moO`030000003oool0oooo0980oooo1`09jPXl0?ooo`@02NX:PP3oool00`000000
oooo0?ooo`0C0?ooo`00o`3ooonK0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo08/0oooo1`09jPXo0?ooo`@02NX:
QP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonK0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo08@0oooo1`09
jPY20?ooo`@02NX:RP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonK0?ooo`030000001oOgl0
Ogmo00P0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0807moO`030000003oool0
oooo07d0oooo1`09jPY50?ooo`@02NX:SP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonK0?oo
o`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0807mo
O`030000003oool0oooo07H0oooo1`09jPY80?ooo`@02NX:TP3oool00`000000oooo0?ooo`0C0?oo
o`00o`3ooonK0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000
Ogmo07moO`0807moO`030000003oool0oooo06l0oooo1`09jPY;0?ooo`@02NX:UP3oool00`000000
oooo0?ooo`0C0?ooo`00o`3ooonK0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo06P0oooo1`09jPY>0?ooo`@02NX:
VP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonK0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo0640oooo1`09
jPYA0?ooo`@02NX:WP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonK0?ooo`030000001oOgl0
Ogmo00P0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0807moO`030000003oool0
oooo05X0oooo1`09jPYD0?ooo`@02NX:XP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonL0?oo
o`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0707mo
O`030000003oool0oooo05@0oooo1`09jPYG0?ooo`@02NX:YP3oool00`000000oooo0?ooo`0C0?oo
o`00o`3ooonL0?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000
Ogmo07moO`0707moO`030000003oool0oooo04d0oooo1`09jPYJ0?ooo`@02NX:ZP3oool00`000000
oooo0?ooo`0C0?ooo`00o`3ooonL0?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000Ogmo07moO`0707moO`030000003oool0oooo04H0oooo1`09jPYM0?ooo`@02NX:
[P3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonL0?ooo`030000001oOgl0Ogmo00L0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0707moO`030000003oool0oooo03l0oooo1`09
jPYQ0?ooo`<02NX:/P3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonL0?ooo`030000001oOgl0
Ogmo00L0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0707moO`030000003oool0
oooo03P0oooo1`09jPYT0?ooo`@02NX:]@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonL0?oo
o`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0707mo
O`030000003oool0oooo0340oooo1`09jPYW0?ooo`@02NX:^@3oool00`000000oooo0?ooo`0C0?oo
o`00o`3ooonL0?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000
Ogmo07moO`0707moO`030000003oool0oooo02X0oooo1`09jPYZ0?ooo`@02NX:_@3oool00`000000
oooo0?ooo`0C0?ooo`00o`3ooonL0?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000Ogmo07moO`0707moO`030000003oool0oooo02<0oooo1`09jPY]0?ooo`@02NX:
`@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonM0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0607moO`030000003oool0oooo01d0oooo1`09
jPY`0?ooo`@02NX:a@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonM0?ooo`030000001oOgl0
Ogmo00H0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0607moO`030000003oool0
oooo01H0oooo1`09jPYc0?ooo`@02NX:b@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonM0?oo
o`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0607mo
O`030000003oool0oooo00l0oooo1`09jPYf0?ooo`@02NX:c@3oool00`000000oooo0?ooo`0C0?oo
o`00o`3ooonM0?ooo`030000001oOgl0Ogmo00H0Ogmo3`00000807moO`030000003oool0oooo00P0
oooo1`09jPYi0?ooo`@02NX:d@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonM0?ooo`030000
001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0607moO`040000
003oool0oooo0?ooo`L02NX:O03oool400WZ2]D0oooo00<000000?ooo`3oool04`3oool00?l0oooo
U@3oool300WZ2PD0oooo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo07moO`0;07moO`030000
0009jPX02NX:00D02NX:00<0000000WZ2P09jPX00P09jPYo0?ooo`@02NX:f@3oool00`000000oooo
0?ooo`0C0?ooo`00o`3ooonF0?ooo`H02NX:0P00000707moOa002NX:1`1oOgl2000007h0oooo1009
jP[M0?ooo`030000003oool0oooo01<0oooo000E0?ooool02NX:Q`09jPX00`0000002NX:00WZ2P06
00WZ2P0307moO`000000Ogmo00`0Ogmo00<0000007moO`1oOgl01P1oOgl00`000000oooo0?ooo`1h
0?ooo`@02NX:h@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonF0?ooo`D02NX:0`3oool00`00
0000Ogmo07moO`0507moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl01@1oOgl00`00
0000oooo0?ooo`1e0?ooo`@02NX:i@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonE0?ooo`80
2NX:1`3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1o
Ogl01@1oOgl00`000000oooo0?ooo`1a0?ooo`@02NX:j@3oool00`000000oooo0?ooo`0C0?ooo`00
o`3ooonN0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo
07moO`0507moO`030000003oool0oooo06d0oooo1009jP[]0?ooo`030000003oool0oooo01<0oooo
003o0?oooih0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo00D0Ogmo00<000000?ooo`3oool0J@3oool400WZ2_40oooo00<000000?ooo`3oool04`3o
ool00?l0ooooWP3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00/0Ogmo00<00000
07moO`1oOgl01@1oOgl00`000000oooo0?ooo`1U0?ooo`@02NX:m@3oool00`000000oooo0?ooo`0C
0?ooo`00o`3ooonN0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl02`1oOgl00`00
0000Ogmo07moO`0507moO`030000003oool0oooo0640oooo1009jP[i0?ooo`030000003oool0oooo
01<0oooo003o0?oooih0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0;07moO`03
0000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0G@3oool400WZ2_d0oooo00<000000?ooo`3o
ool04`3oool00?l0ooooWP3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00/0Ogmo
00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`1I0?ooo`@02NX:o`3oool20?ooo`030000
003oool0oooo01<0oooo003o0?oooil0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0;07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0EP3oool400WZ2_l0oooo1P3o
ool00`000000oooo0?ooo`0C0?ooo`00o`3ooonO0?ooo`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl02`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo0580oooo1009jP[o
0?ooo`X0oooo00<000000?ooo`3oool04`3oool00?l0ooooW`3oool00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1>0?oo
o`@02NX:o`3oool>0?ooo`030000003oool0oooo01<0oooo003o0?oooil0oooo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3o
ool0BP3oool400WZ2_l0oooo4P3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonO0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0407moO`030000
003oool0oooo04H0oooo1009jP[o0?oooaH0oooo00<000000?ooo`3oool04`3oool00?l0ooooW`3o
ool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000oooo0?ooo`120?ooo`@02NX:o`3ooolJ0?ooo`030000003oool0oooo01<0oooo003o
0?oooj00oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0?`3oool400WZ2_l0oooo7P3oool00`000000oooo0?ooo`0C
0?ooo`00o`3ooonP0?ooo`030000001oOgl0Ogmo00<0Ogmo3`00000507moO`030000003oool0oooo
03/0oooo1009jP[o0?ooob80oooo00<000000?ooo`3oool04`3oool00?l0ooooX03oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0g0?ooo`@02NX:o`3ooolV0?ooo`030000003oool0oooo01<0oooo003o0?oooj00oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0<`3oool400WZ2_l0oooo:P3oool00`000000oooo0?ooo`0C0?ooo`00o`3o
oonP0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo02l0oooo1009jP[o0?ooobh0oooo00<000000?ooo`3oool04`3o
ool00?l0ooooX@3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00/0Ogmo00<00000
07moO`1oOgl00P1oOgl00`000000oooo0?ooo`0/0?ooo`@02NX:o`3ooolb0?ooo`030000003oool0
oooo01<0oooo003o0?oooj40oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0;07mo
O`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0:03oool400WZ2_l0oooo=P3oool00`00
0000oooo0?ooo`0C0?ooo`00o`3ooonQ0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1o
Ogl02`1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo02@0oooo1009jP[o0?ooocX0
oooo00<000000?ooo`3oool04`3oool00?l0ooooX@3oool00`000000Ogmo07moO`0207moO`030000
001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0P0?ooo`@02NX:
o`3oooln0?ooo`030000003oool0oooo01<0oooo003o0?oooj80oooo00D0000007moO`1oOgl0Ogmo
0000000=07moO`050000001oOgl0Ogmo07moO`0000007`3oool400WZ2_l0oooo@P3oool00`000000
oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`050000001oOgl0Ogmo07moO`0000003@1oOgl01@000000
Ogmo07moO`1oOgl0000001/0oooo1009jP[o0?ooodH0oooo00<000000?ooo`3oool04`3oool00?l0
ooooXP3oool01@000000Ogmo07moO`1oOgl0000000d0Ogmo00D0000007moO`1oOgl0Ogmo0000000G
0?ooo`@02NX:o`3ooom:0?ooo`030000003oool0oooo01<0oooo003o0?oooj80oooo00D0000007mo
O`1oOgl0Ogmo0000000=07moO`050000001oOgl0Ogmo07moO`0000004`3oool400WZ2_l0ooooCP3o
ool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`050000001oOgl0Ogmo07moO`0000003@1o
Ogl01@000000Ogmo07moO`1oOgl0000000l0oooo1009jP[o0?oooe80oooo00<000000?ooo`3oool0
4`3oool00?l0ooooX`3oool010000000Ogmo07moO`00000=07moO`040000001oOgl0Ogmo000000`0
oooo1009jP[o0?oooeH0oooo00<000000?ooo`3oool04`3oool00?l0ooooX`3oool010000000Ogmo
07moO`00000=07moO`040000001oOgl0Ogmo000000P0oooo1009jP[o0?oooeX0oooo00<000000?oo
o`3oool04`3oool00?l0ooooX`3oool00`000000Ogmo07moO`0?00000080Ogmo00<000000?ooo`3o
ool00P3oool400WZ2_l0ooooGP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonK0?ooo`<02NX:
1@3oool010000000Ogmo07moO`00000=07moO`040000001oOgl00000000000@02NX:o`3ooomR0?oo
o`030000003oool0oooo01<0oooo003o0?oooi`0oooo1P09jPX01@3oool0000007moO`1oOgl00000
00H0Ogmo2`09jP[o0?ooofH0oooo00<000000?ooo`3oool04`3oool001D0ooooo`09jPZH00WZ2PL0
Ogmo00<0000007moO`000000o`3ooomW0?ooo`030000003oool0oooo01<0oooo003o0?oooi`0oooo
1@09jPX20?ooo`80000000<0Ogmo0000001oOgl0301oOgl00`000000Ogmo0000003o0?ooofL0oooo
00<000000?ooo`3oool04`3oool00?l0ooooV`3oool200WZ2PL0oooo00<0000007moO`0000003@1o
Ogl00`000000Ogmo0000003o0?ooofL0oooo00<000000?ooo`3oool04`3oool00?l0ooooY03oool0
0`000000Ogmo0000000=07moO`030000001oOgl000000?l0ooooI`3oool00`000000oooo0?ooo`0C
0?ooo`00o`3ooonU0?ooo`8000003@1oOgl200000?l0ooooJ03oool00`000000oooo0?ooo`0C0?oo
o`00o`3ooonU0?ooo`8000003@1oOgl200000?l0ooooJ03oool00`000000oooo0?ooo`0C0?ooo`00
o`3ooonU0?ooo`8000003@1oOgl200000?l0ooooJ03oool00`000000oooo0?ooo`0C0?ooo`00o`3o
oonU0?oooa400000o`3ooomX0?ooo`030000003oool0oooo01<0oooo003o0?ooojD0oooo0P00000=
07moO`800000o`3ooomX0?ooo`030000003oool0oooo01<0oooo003o0?ooojH0oooo00<0000007mo
O`1oOgl02`1oOgl00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool04`3oool00?l0
ooooYP3oool?00000?l0ooooJ@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?ooool0oooo
=@3oool00?l0ooooo`3ooooo0?ooocD0oooo003o0?ooool0ooooo`3ooole0?ooo`00o`3ooooo0?oo
ool0oooo=@3oool00?l0ooooo`3ooooo0?ooocD0oooo0000\
\>"],
  ImageRangeCache->{{{0, 817.625}, {223.938, 0}} -> {-5.42744, -31.3754, \
0.257887, 0.257887}},
  CellTags->"Using RayTraceFunction"]
}, Open  ]],

Cell[CellGroupData[{

Cell["res1 = TurboTrace[sys]", "Input",
  CellTags->"Using RayTraceFunction"],

Cell[BoxData[
    \({RayTraceFunction \[Rule] 
        "RayTraceFunction[{r1, r2}, -raytrace code: 514504 Bytes- ]", 
      SymbolicValues \[Rule] {r1 \[Rule] 100.`, r2 \[Rule] \(-100.`\)}, 
      EmbedRays \[Rule] True, EmbedThresholdIntensity \[Rule] True, 
      EmbedGenerationLimit \[Rule] True}\)], "Output",
  CellTags->"Using RayTraceFunction"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(RayTraceFunction/.res1)[100,-100]", "Input",
  CellTags->"Using RayTraceFunction"],

Cell[BoxData[
    \("-ray intercepts of 1 surfaces-"\)], "Output",
  CellTags->"Using RayTraceFunction"]
}, Open  ]],

Cell[CellGroupData[{

Cell["res2 = TurboTrace[sys,OpticalLength]", "Input",
  CellTags->"Using RayTraceFunction"],

Cell[BoxData[
    \({RayTraceFunction \[Rule] 
        "RayTraceFunction[{r1, r2}, -raytrace code: 515292 Bytes- ]", 
      SymbolicValues \[Rule] {r1 \[Rule] 100.`, r2 \[Rule] \(-100.`\)}, 
      EmbedRays \[Rule] True, EmbedThresholdIntensity \[Rule] True, 
      EmbedGenerationLimit \[Rule] True}\)], "Output",
  CellTags->"Using RayTraceFunction"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(RayTraceFunction/.res2)[100,-100]", "Input",
  CellTags->"Using RayTraceFunction"],

Cell[BoxData[
    \({205.4418987661499`, 205.1925990763471`, 205.19036969980868`, 
      205.19036969980868`, 205.1925990763471`, 
      205.4418987661499`}\)], "Output",
  CellTags->"Using RayTraceFunction"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["TurboPlot Examples", "Section",
  CellTags->"TurboPlot Examples"],

Cell[CellGroupData[{

Cell["\<\
trace = TurboPlot[
\t{LineOfRays[30,NumberOfRays->31], 
\tMove[PlanoConvexLens[{f,100},50,10],50],
\tBoundary[200]}, PlotType->TopView];\
\>", "Input",
  CellTags->"TurboPlot Examples"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.5 0.0047619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.29249 .38095 m
.30952 .38095 L
.30952 .42063 L
.275 .42063 L
.29249 .38095 L
F
.275 .42063 m
.30952 .42063 L
.30952 .46032 L
.26511 .46032 L
.275 .42063 L
F
.26511 .46032 m
.30952 .46032 L
.30952 .5 L
.2619 .5 L
.26511 .46032 L
F
.2619 .5 m
.30952 .5 L
.30952 .53968 L
.26511 .53968 L
.2619 .5 L
F
.26511 .53968 m
.30952 .53968 L
.30952 .57937 L
.275 .57937 L
.26511 .53968 L
F
.275 .57937 m
.30952 .57937 L
.30952 .61905 L
.29249 .61905 L
.275 .57937 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.29249 .38095 m
.275 .42063 L
.26511 .46032 L
.2619 .5 L
.26511 .53968 L
.275 .57937 L
.29249 .61905 L
.30952 .61905 L
.30952 .57937 L
.30952 .53968 L
.30952 .5 L
.30952 .46032 L
.30952 .42063 L
.30952 .38095 L
.29249 .38095 L
s
.5 g
.29249 .5 m
.30952 .5 L
.30952 .5 L
.275 .5 L
.29249 .5 L
F
.275 .5 m
.30952 .5 L
.30952 .5 L
.26511 .5 L
.275 .5 L
F
.26511 .5 m
.30952 .5 L
.30952 .5 L
.2619 .5 L
.26511 .5 L
F
.2619 .5 m
.30952 .5 L
.30952 .5 L
.26511 .5 L
.2619 .5 L
F
.26511 .5 m
.30952 .5 L
.30952 .5 L
.275 .5 L
.26511 .5 L
F
.275 .5 m
.30952 .5 L
.30952 .5 L
.29249 .5 L
.275 .5 L
F
0 g
.29249 .5 m
.275 .5 L
.26511 .5 L
.2619 .5 L
.26511 .5 L
.275 .5 L
.29249 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.29249 .5 L
s
.29249 .61905 m
.30952 .61905 L
.30952 .61499 L
.29249 .61499 L
.29249 .61905 L
s
.29249 .61499 m
.30952 .61499 L
.30952 .6031 L
.29249 .6031 L
.29249 .61499 L
s
.29249 .6031 m
.30952 .6031 L
.30952 .58418 L
.29249 .58418 L
.29249 .6031 L
s
.29249 .58418 m
.30952 .58418 L
.30952 .55952 L
.29249 .55952 L
.29249 .58418 L
s
.29249 .55952 m
.30952 .55952 L
.30952 .53081 L
.29249 .53081 L
.29249 .55952 L
s
.29249 .53081 m
.30952 .53081 L
.30952 .5 L
.29249 .5 L
.29249 .53081 L
s
.29249 .5 m
.30952 .5 L
.30952 .46919 L
.29249 .46919 L
.29249 .5 L
s
.29249 .46919 m
.30952 .46919 L
.30952 .44048 L
.29249 .44048 L
.29249 .46919 L
s
.29249 .44048 m
.30952 .44048 L
.30952 .41582 L
.29249 .41582 L
.29249 .44048 L
s
.29249 .41582 m
.30952 .41582 L
.30952 .3969 L
.29249 .3969 L
.29249 .41582 L
s
.29249 .3969 m
.30952 .3969 L
.30952 .38501 L
.29249 .38501 L
.29249 .3969 L
s
.29249 .38501 m
.30952 .38501 L
.30952 .38095 L
.29249 .38095 L
.29249 .38501 L
s
.29249 .38095 m
.30952 .38095 L
.30952 .38501 L
.29249 .38501 L
.29249 .38095 L
s
.29249 .38501 m
.30952 .38501 L
.30952 .3969 L
.29249 .3969 L
.29249 .38501 L
s
.29249 .3969 m
.30952 .3969 L
.30952 .41582 L
.29249 .41582 L
.29249 .3969 L
s
.29249 .41582 m
.30952 .41582 L
.30952 .44048 L
.29249 .44048 L
.29249 .41582 L
s
.29249 .44048 m
.30952 .44048 L
.30952 .46919 L
.29249 .46919 L
.29249 .44048 L
s
.29249 .46919 m
.30952 .46919 L
.30952 .5 L
.29249 .5 L
.29249 .46919 L
s
.29249 .5 m
.30952 .5 L
.30952 .53081 L
.29249 .53081 L
.29249 .5 L
s
.29249 .53081 m
.30952 .53081 L
.30952 .55952 L
.29249 .55952 L
.29249 .53081 L
s
.29249 .55952 m
.30952 .55952 L
.30952 .58418 L
.29249 .58418 L
.29249 .55952 L
s
.29249 .58418 m
.30952 .58418 L
.30952 .6031 L
.29249 .6031 L
.29249 .58418 L
s
.29249 .6031 m
.30952 .6031 L
.30952 .61499 L
.29249 .61499 L
.29249 .6031 L
s
.29249 .61499 m
.30952 .61499 L
.30952 .61905 L
.29249 .61905 L
.29249 .61499 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .42857 m
.27246 .42857 L
s
0 0 0 r
2.5 Mabswid
.27246 .42857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .43333 m
.27107 .43333 L
s
0 0 0 r
2.5 Mabswid
.27107 .43333 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .4381 m
.26979 .4381 L
s
0 0 0 r
2.5 Mabswid
.26979 .4381 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .44286 m
.26861 .44286 L
s
0 0 0 r
2.5 Mabswid
.26861 .44286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .44762 m
.26752 .44762 L
s
0 0 0 r
2.5 Mabswid
.26752 .44762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .45238 m
.26654 .45238 L
s
0 0 0 r
2.5 Mabswid
.26654 .45238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .45714 m
.26565 .45714 L
s
0 0 0 r
2.5 Mabswid
.26565 .45714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .4619 m
.26486 .4619 L
s
0 0 0 r
2.5 Mabswid
.26486 .4619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .46667 m
.26416 .46667 L
s
0 0 0 r
2.5 Mabswid
.26416 .46667 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .47143 m
.26356 .47143 L
s
0 0 0 r
2.5 Mabswid
.26356 .47143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .47619 m
.26305 .47619 L
s
0 0 0 r
2.5 Mabswid
.26305 .47619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .48095 m
.26264 .48095 L
s
0 0 0 r
2.5 Mabswid
.26264 .48095 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .48571 m
.26232 .48571 L
s
0 0 0 r
2.5 Mabswid
.26232 .48571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .49048 m
.26209 .49048 L
s
0 0 0 r
2.5 Mabswid
.26209 .49048 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .49524 m
.26195 .49524 L
s
0 0 0 r
2.5 Mabswid
.26195 .49524 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.2619 .5 L
s
0 0 0 r
2.5 Mabswid
.2619 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .50476 m
.26195 .50476 L
s
0 0 0 r
2.5 Mabswid
.26195 .50476 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .50952 m
.26209 .50952 L
s
0 0 0 r
2.5 Mabswid
.26209 .50952 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .51429 m
.26232 .51429 L
s
0 0 0 r
2.5 Mabswid
.26232 .51429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .51905 m
.26264 .51905 L
s
0 0 0 r
2.5 Mabswid
.26264 .51905 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .52381 m
.26305 .52381 L
s
0 0 0 r
2.5 Mabswid
.26305 .52381 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .52857 m
.26356 .52857 L
s
0 0 0 r
2.5 Mabswid
.26356 .52857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .53333 m
.26416 .53333 L
s
0 0 0 r
2.5 Mabswid
.26416 .53333 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5381 m
.26486 .5381 L
s
0 0 0 r
2.5 Mabswid
.26486 .5381 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .54286 m
.26565 .54286 L
s
0 0 0 r
2.5 Mabswid
.26565 .54286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .54762 m
.26654 .54762 L
s
0 0 0 r
2.5 Mabswid
.26654 .54762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .55238 m
.26752 .55238 L
s
0 0 0 r
2.5 Mabswid
.26752 .55238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .55714 m
.26861 .55714 L
s
0 0 0 r
2.5 Mabswid
.26861 .55714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5619 m
.26979 .5619 L
s
0 0 0 r
2.5 Mabswid
.26979 .5619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .56667 m
.27107 .56667 L
s
0 0 0 r
2.5 Mabswid
.27107 .56667 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .57143 m
.27246 .57143 L
s
0 0 0 r
2.5 Mabswid
.27246 .57143 Mdot
.039 .916 .04 r
.5 Mabswid
.27246 .42857 m
.30952 .43236 L
s
0 0 0 r
2.5 Mabswid
.30952 .43236 Mdot
.039 .916 .04 r
.5 Mabswid
.27107 .43333 m
.30952 .43699 L
s
0 0 0 r
2.5 Mabswid
.30952 .43699 Mdot
.039 .916 .04 r
.5 Mabswid
.26979 .4381 m
.30952 .44159 L
s
0 0 0 r
2.5 Mabswid
.30952 .44159 Mdot
.039 .916 .04 r
.5 Mabswid
.26861 .44286 m
.30952 .44616 L
s
0 0 0 r
2.5 Mabswid
.30952 .44616 Mdot
.039 .916 .04 r
.5 Mabswid
.26752 .44762 m
.30952 .45072 L
s
0 0 0 r
2.5 Mabswid
.30952 .45072 Mdot
.039 .916 .04 r
.5 Mabswid
.26654 .45238 m
.30952 .45526 L
s
0 0 0 r
2.5 Mabswid
.30952 .45526 Mdot
.039 .916 .04 r
.5 Mabswid
.26565 .45714 m
.30952 .45978 L
s
0 0 0 r
2.5 Mabswid
.30952 .45978 Mdot
.039 .916 .04 r
.5 Mabswid
.26486 .4619 m
.30952 .46428 L
s
0 0 0 r
2.5 Mabswid
.30952 .46428 Mdot
.039 .916 .04 r
.5 Mabswid
.26416 .46667 m
.30952 .46877 L
s
0 0 0 r
2.5 Mabswid
.30952 .46877 Mdot
.039 .916 .04 r
.5 Mabswid
.26356 .47143 m
.30952 .47326 L
s
0 0 0 r
2.5 Mabswid
.30952 .47326 Mdot
.039 .916 .04 r
.5 Mabswid
.26305 .47619 m
.30952 .47773 L
s
0 0 0 r
2.5 Mabswid
.30952 .47773 Mdot
.039 .916 .04 r
.5 Mabswid
.26264 .48095 m
.30952 .48219 L
s
0 0 0 r
2.5 Mabswid
.30952 .48219 Mdot
.039 .916 .04 r
.5 Mabswid
.26232 .48571 m
.30952 .48665 L
s
0 0 0 r
2.5 Mabswid
.30952 .48665 Mdot
.039 .916 .04 r
.5 Mabswid
.26209 .49048 m
.30952 .4911 L
s
0 0 0 r
2.5 Mabswid
.30952 .4911 Mdot
.039 .916 .04 r
.5 Mabswid
.26195 .49524 m
.30952 .49555 L
s
0 0 0 r
2.5 Mabswid
.30952 .49555 Mdot
.039 .916 .04 r
.5 Mabswid
.2619 .5 m
.30952 .5 L
s
0 0 0 r
2.5 Mabswid
.30952 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.26195 .50476 m
.30952 .50445 L
s
0 0 0 r
2.5 Mabswid
.30952 .50445 Mdot
.039 .916 .04 r
.5 Mabswid
.26209 .50952 m
.30952 .5089 L
s
0 0 0 r
2.5 Mabswid
.30952 .5089 Mdot
.039 .916 .04 r
.5 Mabswid
.26232 .51429 m
.30952 .51335 L
s
0 0 0 r
2.5 Mabswid
.30952 .51335 Mdot
.039 .916 .04 r
.5 Mabswid
.26264 .51905 m
.30952 .51781 L
s
0 0 0 r
2.5 Mabswid
.30952 .51781 Mdot
.039 .916 .04 r
.5 Mabswid
.26305 .52381 m
.30952 .52227 L
s
0 0 0 r
2.5 Mabswid
.30952 .52227 Mdot
.039 .916 .04 r
.5 Mabswid
.26356 .52857 m
.30952 .52674 L
s
0 0 0 r
2.5 Mabswid
.30952 .52674 Mdot
.039 .916 .04 r
.5 Mabswid
.26416 .53333 m
.30952 .53123 L
s
0 0 0 r
2.5 Mabswid
.30952 .53123 Mdot
.039 .916 .04 r
.5 Mabswid
.26486 .5381 m
.30952 .53572 L
s
0 0 0 r
2.5 Mabswid
.30952 .53572 Mdot
.039 .916 .04 r
.5 Mabswid
.26565 .54286 m
.30952 .54022 L
s
0 0 0 r
2.5 Mabswid
.30952 .54022 Mdot
.039 .916 .04 r
.5 Mabswid
.26654 .54762 m
.30952 .54474 L
s
0 0 0 r
2.5 Mabswid
.30952 .54474 Mdot
.039 .916 .04 r
.5 Mabswid
.26752 .55238 m
.30952 .54928 L
s
0 0 0 r
2.5 Mabswid
.30952 .54928 Mdot
.039 .916 .04 r
.5 Mabswid
.26861 .55714 m
.30952 .55384 L
s
0 0 0 r
2.5 Mabswid
.30952 .55384 Mdot
.039 .916 .04 r
.5 Mabswid
.26979 .5619 m
.30952 .55841 L
s
0 0 0 r
2.5 Mabswid
.30952 .55841 Mdot
.039 .916 .04 r
.5 Mabswid
.27107 .56667 m
.30952 .56301 L
s
0 0 0 r
2.5 Mabswid
.30952 .56301 Mdot
.039 .916 .04 r
.5 Mabswid
.27246 .57143 m
.30952 .56764 L
s
0 0 0 r
2.5 Mabswid
.30952 .56764 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .43236 m
.97619 .53664 L
s
0 0 0 r
2.5 Mabswid
.97619 .53664 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .43699 m
.97619 .53379 L
s
0 0 0 r
2.5 Mabswid
.97619 .53379 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .44159 m
.97619 .53103 L
s
0 0 0 r
2.5 Mabswid
.97619 .53103 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .44616 m
.97619 .52835 L
s
0 0 0 r
2.5 Mabswid
.97619 .52835 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .45072 m
.97619 .52574 L
s
0 0 0 r
2.5 Mabswid
.97619 .52574 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .45526 m
.97619 .5232 L
s
0 0 0 r
2.5 Mabswid
.97619 .5232 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .45978 m
.97619 .52072 L
s
0 0 0 r
2.5 Mabswid
.97619 .52072 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .46428 m
.97619 .51829 L
s
0 0 0 r
2.5 Mabswid
.97619 .51829 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .46877 m
.97619 .51591 L
s
0 0 0 r
2.5 Mabswid
.97619 .51591 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .47326 m
.97619 .51356 L
s
0 0 0 r
2.5 Mabswid
.97619 .51356 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .47773 m
.97619 .51125 L
s
0 0 0 r
2.5 Mabswid
.97619 .51125 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .48219 m
.97619 .50897 L
s
0 0 0 r
2.5 Mabswid
.97619 .50897 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .48665 m
.97619 .50671 L
s
0 0 0 r
2.5 Mabswid
.97619 .50671 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .4911 m
.97619 .50446 L
s
0 0 0 r
2.5 Mabswid
.97619 .50446 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .49555 m
.97619 .50223 L
s
0 0 0 r
2.5 Mabswid
.97619 .50223 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .5 m
.97619 .5 L
s
0 0 0 r
2.5 Mabswid
.97619 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .50445 m
.97619 .49777 L
s
0 0 0 r
2.5 Mabswid
.97619 .49777 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .5089 m
.97619 .49554 L
s
0 0 0 r
2.5 Mabswid
.97619 .49554 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .51335 m
.97619 .49329 L
s
0 0 0 r
2.5 Mabswid
.97619 .49329 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .51781 m
.97619 .49103 L
s
0 0 0 r
2.5 Mabswid
.97619 .49103 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .52227 m
.97619 .48875 L
s
0 0 0 r
2.5 Mabswid
.97619 .48875 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .52674 m
.97619 .48644 L
s
0 0 0 r
2.5 Mabswid
.97619 .48644 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .53123 m
.97619 .48409 L
s
0 0 0 r
2.5 Mabswid
.97619 .48409 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .53572 m
.97619 .48171 L
s
0 0 0 r
2.5 Mabswid
.97619 .48171 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .54022 m
.97619 .47928 L
s
0 0 0 r
2.5 Mabswid
.97619 .47928 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .54474 m
.97619 .4768 L
s
0 0 0 r
2.5 Mabswid
.97619 .4768 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .54928 m
.97619 .47426 L
s
0 0 0 r
2.5 Mabswid
.97619 .47426 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .55384 m
.97619 .47165 L
s
0 0 0 r
2.5 Mabswid
.97619 .47165 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .55841 m
.97619 .46897 L
s
0 0 0 r
2.5 Mabswid
.97619 .46897 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .56301 m
.97619 .46621 L
s
0 0 0 r
2.5 Mabswid
.97619 .46621 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .56764 m
.97619 .46336 L
s
0 0 0 r
2.5 Mabswid
.97619 .46336 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0BP3oool600000;l0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0BP3oool600000;l0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0B@3oool2000000@0Ogmo00<000000?ooo`3oool0_@3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`190?ooo`800000101oOgl00`000000oooo
0?ooo`2m0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04P0oooo00<0
000007moO`0000001@00002o0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo04P0oooo00<0000007moO`000000101oOgl00`000000oooo0?ooo`2m0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo04L0oooo00@0000007moO`1oOgl00000101oOgl0
0`000000oooo0?ooo`2m0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
04L0oooo00@0000007moO`1oOgl00000101oOgl00`000000oooo0?ooo`2m0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo04L0oooo00@0000007moO`1oOgl00000101oOgl0
0`000000oooo0?ooo`2m0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
04H0oooo00D0000007moO`1oOgl0Ogmo0000000407moO`030000003oool0oooo0;d0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0AP3oool010000000Ogmo07moO`1oOgl6
00000;l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0A@3oool00`00
0000Ogmo07moO`0207moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0_@3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`150?ooo`030000001oOgl0Ogmo0080
Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo00D0
oooo00060?ooodL02NX:00<0000000WZ2P09jPX00P09jPX00`1oOgl0000007moO`0307moO`030000
003oool0oooo0;d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0A03o
ool2000000<0Ogmo1@09jPX00`1oOgl000000000002n0?ooo`030000003oool0oooo00D0oooo0006
0?ooodh02NX:0`1oOgl500WZ2[`0oooo00<000000?ooo`3oool01@3oool000H0ooooAP09jPX00`00
00002NX:00WZ2P0D00WZ2[D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0@`3oool2000000D0Ogmo00<0000000WZ2P09jPX04`09jPZ_0?ooo`030000003oool0oooo00D0
oooo00060?ooodH02NX:00<0000000WZ2P09jPX01@09jPX407moO`8000000`3ooolB00WZ2ZT0oooo
00<000000?ooo`3oool01@3oool000H0ooooC@09jPX00`0000002NX:00WZ2P0700WZ2PL0oooo4P09
jPZR0?ooo`030000003oool0oooo00D0oooo00060?ooodD02NX:00<0000000WZ2P09jPX06009jPX5
0?oooa402NX:W03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`120?oo
o`8000001P1oOglK00WZ2PD0oooo4009jPZE0?ooo`030000003oool0oooo00D0oooo00060?ooodD0
2NX:00<0000000WZ2P09jPX0:009jPX40?ooo`l02NX:S`3oool00`000000oooo0?ooo`050?ooo`00
1P3ooom500WZ2P0300000009jPX02NX:00D02NX:00<0000007moO`1oOgl00P1oOgl2000000@0oooo
8@09jPX30?ooo`d02NX:QP3oool200WZ2P8000001`3oool000H0ooooF@09jPX:0?oooah02NX:0P3o
ool=00WZ2WP0oooo2@09jPX2000000L0oooo00060?ooo`030000003oool0oooo0480oooo0P000006
07moOaT02NX:203ooolK00WZ2P030?ooo`09jPX02NX:00X02NX:K03oool?00WZ2P8000001`3oool0
00H0ooooA009jPX00`0000002NX:00WZ2P0/00WZ2PD0oooo9@09jPYO0?oooaD02NX:0P0000070?oo
o`001P3ooom400WZ2P0300000009jPX02NX:00H02NX:00<0000007moO`1oOgl00P1oOgl2000000L0
oooo9@09jPX30?ooob002NX:DP3ooolL00WZ2P8000001`3oool000H0oooo00<000000?ooo`3oool0
@@3oool3000000H0Ogmo4@09jPX=0?ooob802NX:00<0oooo00WZ2P09jPX06@09jPY60?ooob802NX:
0P0000070?ooo`001P3ooom400WZ2P0300000009jPX02NX:02`02NX:203ooole00WZ2SP0oooo:@09
jPX2000000L0oooo00060?oood@02NX:00<0000000WZ2P09jPX0@@09jPX30?ooob`02NX::`3oool_
00WZ2P8000001`3oool000H0ooooA009jPX00`0000002NX:00WZ2P1g00WZ2Qh0oooo=@09jPX20000
00L0oooo00060?ooo`030000003oool0oooo0440oooo0P00000707moO`030000001oOgl0Ogmo0080
Ogmo0P00000G0?oooeX02NX:403oooll00WZ2P8000001`3oool000H0ooooA009jPX00`0000002NX:
00WZ2P0l00WZ2QP0oooo<`09jPX00`3oool02NX:00WZ2P1000WZ2P8000001`3oool000H0ooooA009
jPX00`0000002NX:00WZ2P3:00WZ2P8000001`3oool000H0ooooA009jPX00`0000002NX:00WZ2P0k
00WZ2QP0oooo<`09jPX30?oood402NX:0P0000070?ooo`001P3oool00`000000oooo0?ooo`110?oo
o`8000001`1oOgl00`000000Ogmo07moO`0207moO`8000005P3ooomJ00WZ2Q80oooo>`09jPX20000
00L0oooo00060?oood@02NX:00<0000000WZ2P09jPX0MP09jPXP0?oooc@02NX:0P0000070?ooo`00
1P3ooom400WZ2P0300000009jPX02NX:04002NX:0`3oool/00WZ2Rd0oooo;P09jPX2000000L0oooo
00060?oood@02NX:00<0000000WZ2P09jPX0:`09jPX80?ooocD02NX:>P3ooolX00WZ2P8000001`3o
ool000H0oooo00<000000?ooo`3oool0@@3oool3000000D0Ogmo4@09jPX=0?ooob802NX:00<0oooo
00WZ2P09jPX06@09jPY80?ooob402NX:0P0000070?ooo`001P3ooom400WZ2P0300000009jPX02NX:
00D02NX:00<0Ogmo0000001oOgl00`1oOgl2000000H0oooo9@09jPX30?ooob002NX:E03ooolK00WZ
2P8000001`3oool000H0ooooA009jPX00`0000002NX:00WZ2P0[00WZ2PD0oooo9@09jPYQ0?oooa@0
2NX:0P0000070?ooo`001P3oool00`000000oooo0?ooo`110?ooo`<000001@1oOglI00WZ2PP0oooo
6`09jPX00`3oool02NX:00WZ2P0:00WZ2Vh0oooo3P09jPX2000000L0oooo00060?oooeP02NX:2P3o
oolN00WZ2P80oooo3@09jPYj0?ooo`P02NX:0P0000070?ooo`001P3ooom500WZ2P0300000009jPX0
2NX:00@02NX:00<0Ogmo0000001oOgl00`1oOgl2000000<0oooo8@09jPX30?ooo`d02NX:R03oool0
0`09jPX00000000000070?ooo`001P3ooom500WZ2P0300000009jPX02NX:02L02NX:103oool?00WZ
2Y00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0@P3oool2000000D0
Ogmo6`09jPX50?oooa002NX:UP3oool00`000000oooo0?ooo`050?ooo`001P3ooom500WZ2P030000
0009jPX02NX:01L02NX:1@3ooolA00WZ2Yd0oooo00<000000?ooo`3oool01@3oool000H0ooooC009
jPX00`1oOgl02NX:00WZ2P0700WZ2PL0oooo4P09jPZS0?ooo`030000003oool0oooo00D0oooo0006
0?ooodH02NX:00<0000000WZ2P09jPX01009jPX00`000000Ogmo07moO`0207moO`8000000P3ooolB
00WZ2ZX0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0@`3oool20000
00D0Ogmo5@09jPZ`0?ooo`030000003oool0oooo00D0oooo00060?ooodH02NX:00<0000000WZ2P09
jPX04`09jPZf0?ooo`030000003oool0oooo00D0oooo00060?oooeD02NX:_@3oool00`000000oooo
0?ooo`050?ooo`001P3ooom700WZ2P0300000009jPX02NX:00<02NX:00<0000007moO`1oOgl00P1o
Ogl200000;h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0A03oool2
000000@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`2m0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo04D0oooo00<0000007moO`1oOgl00P1oOgl00`00
0000Ogmo07moO`0207moO`030000003oool0oooo0;d0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0A@3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0080
Ogmo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`150?ooo`030000001oOgl0Ogmo0080Ogmo1P00002o0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo04H0oooo00D0000007moO`1oOgl0Ogmo0000000407moO`030000
003oool0oooo0;d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0AP3o
ool01@000000Ogmo07moO`1oOgl0000000@0Ogmo00<000000?ooo`3oool0_@3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`170?ooo`040000001oOgl0Ogmo000000@0Ogmo
00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`170?ooo`040000001oOgl0Ogmo000000@0Ogmo00<000000?ooo`3oool0_@3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`180?ooo`030000001oOgl0000000@0Ogmo00<0
00000?ooo`3oool0_@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`18
0?ooo`030000001oOgl0000000D00000_`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`180?ooo`030000001oOgl0000000@0Ogmo00<000000?ooo`3oool0_@3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`190?ooo`800000101oOgl00`000000
oooo0?ooo`2m0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04T0oooo
1`00002o0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04X0oooo1P00
002o0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo0P00003o0?oooa40oooo00<000000?ooo`3oool01@3oool000H0ooooo`00000D000000L0
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00105, -105.001, 0.731715, \
0.731715}},
  CellTags->"TurboPlot Examples"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboPlot[trace,PlotType->TopView,SymbolicValues->{f->50}];", "Input",
  CellTags->"TurboPlot Examples"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.5 0.0047619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.29249 .38095 m
.30952 .38095 L
.30952 .42063 L
.275 .42063 L
.29249 .38095 L
F
.275 .42063 m
.30952 .42063 L
.30952 .46032 L
.26511 .46032 L
.275 .42063 L
F
.26511 .46032 m
.30952 .46032 L
.30952 .5 L
.2619 .5 L
.26511 .46032 L
F
.2619 .5 m
.30952 .5 L
.30952 .53968 L
.26511 .53968 L
.2619 .5 L
F
.26511 .53968 m
.30952 .53968 L
.30952 .57937 L
.275 .57937 L
.26511 .53968 L
F
.275 .57937 m
.30952 .57937 L
.30952 .61905 L
.29249 .61905 L
.275 .57937 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.29249 .38095 m
.275 .42063 L
.26511 .46032 L
.2619 .5 L
.26511 .53968 L
.275 .57937 L
.29249 .61905 L
.30952 .61905 L
.30952 .57937 L
.30952 .53968 L
.30952 .5 L
.30952 .46032 L
.30952 .42063 L
.30952 .38095 L
.29249 .38095 L
s
.5 g
.29249 .5 m
.30952 .5 L
.30952 .5 L
.275 .5 L
.29249 .5 L
F
.275 .5 m
.30952 .5 L
.30952 .5 L
.26511 .5 L
.275 .5 L
F
.26511 .5 m
.30952 .5 L
.30952 .5 L
.2619 .5 L
.26511 .5 L
F
.2619 .5 m
.30952 .5 L
.30952 .5 L
.26511 .5 L
.2619 .5 L
F
.26511 .5 m
.30952 .5 L
.30952 .5 L
.275 .5 L
.26511 .5 L
F
.275 .5 m
.30952 .5 L
.30952 .5 L
.29249 .5 L
.275 .5 L
F
0 g
.29249 .5 m
.275 .5 L
.26511 .5 L
.2619 .5 L
.26511 .5 L
.275 .5 L
.29249 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.29249 .5 L
s
.29249 .61905 m
.30952 .61905 L
.30952 .61499 L
.29249 .61499 L
.29249 .61905 L
s
.29249 .61499 m
.30952 .61499 L
.30952 .6031 L
.29249 .6031 L
.29249 .61499 L
s
.29249 .6031 m
.30952 .6031 L
.30952 .58418 L
.29249 .58418 L
.29249 .6031 L
s
.29249 .58418 m
.30952 .58418 L
.30952 .55952 L
.29249 .55952 L
.29249 .58418 L
s
.29249 .55952 m
.30952 .55952 L
.30952 .53081 L
.29249 .53081 L
.29249 .55952 L
s
.29249 .53081 m
.30952 .53081 L
.30952 .5 L
.29249 .5 L
.29249 .53081 L
s
.29249 .5 m
.30952 .5 L
.30952 .46919 L
.29249 .46919 L
.29249 .5 L
s
.29249 .46919 m
.30952 .46919 L
.30952 .44048 L
.29249 .44048 L
.29249 .46919 L
s
.29249 .44048 m
.30952 .44048 L
.30952 .41582 L
.29249 .41582 L
.29249 .44048 L
s
.29249 .41582 m
.30952 .41582 L
.30952 .3969 L
.29249 .3969 L
.29249 .41582 L
s
.29249 .3969 m
.30952 .3969 L
.30952 .38501 L
.29249 .38501 L
.29249 .3969 L
s
.29249 .38501 m
.30952 .38501 L
.30952 .38095 L
.29249 .38095 L
.29249 .38501 L
s
.29249 .38095 m
.30952 .38095 L
.30952 .38501 L
.29249 .38501 L
.29249 .38095 L
s
.29249 .38501 m
.30952 .38501 L
.30952 .3969 L
.29249 .3969 L
.29249 .38501 L
s
.29249 .3969 m
.30952 .3969 L
.30952 .41582 L
.29249 .41582 L
.29249 .3969 L
s
.29249 .41582 m
.30952 .41582 L
.30952 .44048 L
.29249 .44048 L
.29249 .41582 L
s
.29249 .44048 m
.30952 .44048 L
.30952 .46919 L
.29249 .46919 L
.29249 .44048 L
s
.29249 .46919 m
.30952 .46919 L
.30952 .5 L
.29249 .5 L
.29249 .46919 L
s
.29249 .5 m
.30952 .5 L
.30952 .53081 L
.29249 .53081 L
.29249 .5 L
s
.29249 .53081 m
.30952 .53081 L
.30952 .55952 L
.29249 .55952 L
.29249 .53081 L
s
.29249 .55952 m
.30952 .55952 L
.30952 .58418 L
.29249 .58418 L
.29249 .55952 L
s
.29249 .58418 m
.30952 .58418 L
.30952 .6031 L
.29249 .6031 L
.29249 .58418 L
s
.29249 .6031 m
.30952 .6031 L
.30952 .61499 L
.29249 .61499 L
.29249 .6031 L
s
.29249 .61499 m
.30952 .61499 L
.30952 .61905 L
.29249 .61905 L
.29249 .61499 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .42857 m
.28466 .42857 L
s
0 0 0 r
2.5 Mabswid
.28466 .42857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .43333 m
.28144 .43333 L
s
0 0 0 r
2.5 Mabswid
.28144 .43333 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .4381 m
.27854 .4381 L
s
0 0 0 r
2.5 Mabswid
.27854 .4381 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .44286 m
.27592 .44286 L
s
0 0 0 r
2.5 Mabswid
.27592 .44286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .44762 m
.27356 .44762 L
s
0 0 0 r
2.5 Mabswid
.27356 .44762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .45238 m
.27145 .45238 L
s
0 0 0 r
2.5 Mabswid
.27145 .45238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .45714 m
.26958 .45714 L
s
0 0 0 r
2.5 Mabswid
.26958 .45714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .4619 m
.26793 .4619 L
s
0 0 0 r
2.5 Mabswid
.26793 .4619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .46667 m
.26649 .46667 L
s
0 0 0 r
2.5 Mabswid
.26649 .46667 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .47143 m
.26526 .47143 L
s
0 0 0 r
2.5 Mabswid
.26526 .47143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .47619 m
.26422 .47619 L
s
0 0 0 r
2.5 Mabswid
.26422 .47619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .48095 m
.26338 .48095 L
s
0 0 0 r
2.5 Mabswid
.26338 .48095 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .48571 m
.26273 .48571 L
s
0 0 0 r
2.5 Mabswid
.26273 .48571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .49048 m
.26227 .49048 L
s
0 0 0 r
2.5 Mabswid
.26227 .49048 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .49524 m
.262 .49524 L
s
0 0 0 r
2.5 Mabswid
.262 .49524 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.2619 .5 L
s
0 0 0 r
2.5 Mabswid
.2619 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .50476 m
.262 .50476 L
s
0 0 0 r
2.5 Mabswid
.262 .50476 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .50952 m
.26227 .50952 L
s
0 0 0 r
2.5 Mabswid
.26227 .50952 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .51429 m
.26273 .51429 L
s
0 0 0 r
2.5 Mabswid
.26273 .51429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .51905 m
.26338 .51905 L
s
0 0 0 r
2.5 Mabswid
.26338 .51905 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .52381 m
.26422 .52381 L
s
0 0 0 r
2.5 Mabswid
.26422 .52381 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .52857 m
.26526 .52857 L
s
0 0 0 r
2.5 Mabswid
.26526 .52857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .53333 m
.26649 .53333 L
s
0 0 0 r
2.5 Mabswid
.26649 .53333 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5381 m
.26793 .5381 L
s
0 0 0 r
2.5 Mabswid
.26793 .5381 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .54286 m
.26958 .54286 L
s
0 0 0 r
2.5 Mabswid
.26958 .54286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .54762 m
.27145 .54762 L
s
0 0 0 r
2.5 Mabswid
.27145 .54762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .55238 m
.27356 .55238 L
s
0 0 0 r
2.5 Mabswid
.27356 .55238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .55714 m
.27592 .55714 L
s
0 0 0 r
2.5 Mabswid
.27592 .55714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5619 m
.27854 .5619 L
s
0 0 0 r
2.5 Mabswid
.27854 .5619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .56667 m
.28144 .56667 L
s
0 0 0 r
2.5 Mabswid
.28144 .56667 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .57143 m
.28466 .57143 L
s
0 0 0 r
2.5 Mabswid
.28466 .57143 Mdot
.039 .916 .04 r
.5 Mabswid
.28466 .42857 m
.30952 .4343 L
s
0 0 0 r
2.5 Mabswid
.30952 .4343 Mdot
.039 .916 .04 r
.5 Mabswid
.28144 .43333 m
.30952 .43923 L
s
0 0 0 r
2.5 Mabswid
.30952 .43923 Mdot
.039 .916 .04 r
.5 Mabswid
.27854 .4381 m
.30952 .44402 L
s
0 0 0 r
2.5 Mabswid
.30952 .44402 Mdot
.039 .916 .04 r
.5 Mabswid
.27592 .44286 m
.30952 .44868 L
s
0 0 0 r
2.5 Mabswid
.30952 .44868 Mdot
.039 .916 .04 r
.5 Mabswid
.27356 .44762 m
.30952 .45324 L
s
0 0 0 r
2.5 Mabswid
.30952 .45324 Mdot
.039 .916 .04 r
.5 Mabswid
.27145 .45238 m
.30952 .45772 L
s
0 0 0 r
2.5 Mabswid
.30952 .45772 Mdot
.039 .916 .04 r
.5 Mabswid
.26958 .45714 m
.30952 .46212 L
s
0 0 0 r
2.5 Mabswid
.30952 .46212 Mdot
.039 .916 .04 r
.5 Mabswid
.26793 .4619 m
.30952 .46646 L
s
0 0 0 r
2.5 Mabswid
.30952 .46646 Mdot
.039 .916 .04 r
.5 Mabswid
.26649 .46667 m
.30952 .47075 L
s
0 0 0 r
2.5 Mabswid
.30952 .47075 Mdot
.039 .916 .04 r
.5 Mabswid
.26526 .47143 m
.30952 .475 L
s
0 0 0 r
2.5 Mabswid
.30952 .475 Mdot
.039 .916 .04 r
.5 Mabswid
.26422 .47619 m
.30952 .47922 L
s
0 0 0 r
2.5 Mabswid
.30952 .47922 Mdot
.039 .916 .04 r
.5 Mabswid
.26338 .48095 m
.30952 .48341 L
s
0 0 0 r
2.5 Mabswid
.30952 .48341 Mdot
.039 .916 .04 r
.5 Mabswid
.26273 .48571 m
.30952 .48757 L
s
0 0 0 r
2.5 Mabswid
.30952 .48757 Mdot
.039 .916 .04 r
.5 Mabswid
.26227 .49048 m
.30952 .49172 L
s
0 0 0 r
2.5 Mabswid
.30952 .49172 Mdot
.039 .916 .04 r
.5 Mabswid
.262 .49524 m
.30952 .49586 L
s
0 0 0 r
2.5 Mabswid
.30952 .49586 Mdot
.039 .916 .04 r
.5 Mabswid
.2619 .5 m
.30952 .5 L
s
0 0 0 r
2.5 Mabswid
.30952 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.262 .50476 m
.30952 .50414 L
s
0 0 0 r
2.5 Mabswid
.30952 .50414 Mdot
.039 .916 .04 r
.5 Mabswid
.26227 .50952 m
.30952 .50828 L
s
0 0 0 r
2.5 Mabswid
.30952 .50828 Mdot
.039 .916 .04 r
.5 Mabswid
.26273 .51429 m
.30952 .51243 L
s
0 0 0 r
2.5 Mabswid
.30952 .51243 Mdot
.039 .916 .04 r
.5 Mabswid
.26338 .51905 m
.30952 .51659 L
s
0 0 0 r
2.5 Mabswid
.30952 .51659 Mdot
.039 .916 .04 r
.5 Mabswid
.26422 .52381 m
.30952 .52078 L
s
0 0 0 r
2.5 Mabswid
.30952 .52078 Mdot
.039 .916 .04 r
.5 Mabswid
.26526 .52857 m
.30952 .525 L
s
0 0 0 r
2.5 Mabswid
.30952 .525 Mdot
.039 .916 .04 r
.5 Mabswid
.26649 .53333 m
.30952 .52925 L
s
0 0 0 r
2.5 Mabswid
.30952 .52925 Mdot
.039 .916 .04 r
.5 Mabswid
.26793 .5381 m
.30952 .53354 L
s
0 0 0 r
2.5 Mabswid
.30952 .53354 Mdot
.039 .916 .04 r
.5 Mabswid
.26958 .54286 m
.30952 .53788 L
s
0 0 0 r
2.5 Mabswid
.30952 .53788 Mdot
.039 .916 .04 r
.5 Mabswid
.27145 .54762 m
.30952 .54228 L
s
0 0 0 r
2.5 Mabswid
.30952 .54228 Mdot
.039 .916 .04 r
.5 Mabswid
.27356 .55238 m
.30952 .54676 L
s
0 0 0 r
2.5 Mabswid
.30952 .54676 Mdot
.039 .916 .04 r
.5 Mabswid
.27592 .55714 m
.30952 .55132 L
s
0 0 0 r
2.5 Mabswid
.30952 .55132 Mdot
.039 .916 .04 r
.5 Mabswid
.27854 .5619 m
.30952 .55598 L
s
0 0 0 r
2.5 Mabswid
.30952 .55598 Mdot
.039 .916 .04 r
.5 Mabswid
.28144 .56667 m
.30952 .56077 L
s
0 0 0 r
2.5 Mabswid
.30952 .56077 Mdot
.039 .916 .04 r
.5 Mabswid
.28466 .57143 m
.30952 .5657 L
s
0 0 0 r
2.5 Mabswid
.30952 .5657 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .4343 m
.97619 .67598 L
s
0 0 0 r
2.5 Mabswid
.97619 .67598 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .43923 m
.97619 .65839 L
s
0 0 0 r
2.5 Mabswid
.97619 .65839 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .44402 m
.97619 .64243 L
s
0 0 0 r
2.5 Mabswid
.97619 .64243 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .44868 m
.97619 .62779 L
s
0 0 0 r
2.5 Mabswid
.97619 .62779 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .45324 m
.97619 .61423 L
s
0 0 0 r
2.5 Mabswid
.97619 .61423 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .45772 m
.97619 .60157 L
s
0 0 0 r
2.5 Mabswid
.97619 .60157 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .46212 m
.97619 .58965 L
s
0 0 0 r
2.5 Mabswid
.97619 .58965 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .46646 m
.97619 .57835 L
s
0 0 0 r
2.5 Mabswid
.97619 .57835 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .47075 m
.97619 .56756 L
s
0 0 0 r
2.5 Mabswid
.97619 .56756 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .475 m
.97619 .55719 L
s
0 0 0 r
2.5 Mabswid
.97619 .55719 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .47922 m
.97619 .54717 L
s
0 0 0 r
2.5 Mabswid
.97619 .54717 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .48341 m
.97619 .53742 L
s
0 0 0 r
2.5 Mabswid
.97619 .53742 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .48757 m
.97619 .52788 L
s
0 0 0 r
2.5 Mabswid
.97619 .52788 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .49172 m
.97619 .5185 L
s
0 0 0 r
2.5 Mabswid
.97619 .5185 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .49586 m
.97619 .50923 L
s
0 0 0 r
2.5 Mabswid
.97619 .50923 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .5 m
.97619 .5 L
s
0 0 0 r
2.5 Mabswid
.97619 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .50414 m
.97619 .49077 L
s
0 0 0 r
2.5 Mabswid
.97619 .49077 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .50828 m
.97619 .4815 L
s
0 0 0 r
2.5 Mabswid
.97619 .4815 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .51243 m
.97619 .47212 L
s
0 0 0 r
2.5 Mabswid
.97619 .47212 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .51659 m
.97619 .46258 L
s
0 0 0 r
2.5 Mabswid
.97619 .46258 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .52078 m
.97619 .45283 L
s
0 0 0 r
2.5 Mabswid
.97619 .45283 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .525 m
.97619 .44281 L
s
0 0 0 r
2.5 Mabswid
.97619 .44281 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .52925 m
.97619 .43244 L
s
0 0 0 r
2.5 Mabswid
.97619 .43244 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .53354 m
.97619 .42165 L
s
0 0 0 r
2.5 Mabswid
.97619 .42165 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .53788 m
.97619 .41035 L
s
0 0 0 r
2.5 Mabswid
.97619 .41035 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .54228 m
.97619 .39843 L
s
0 0 0 r
2.5 Mabswid
.97619 .39843 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .54676 m
.97619 .38577 L
s
0 0 0 r
2.5 Mabswid
.97619 .38577 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .55132 m
.97619 .37221 L
s
0 0 0 r
2.5 Mabswid
.97619 .37221 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .55598 m
.97619 .35757 L
s
0 0 0 r
2.5 Mabswid
.97619 .35757 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .56077 m
.97619 .34161 L
s
0 0 0 r
2.5 Mabswid
.97619 .34161 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .5657 m
.97619 .32402 L
s
0 0 0 r
2.5 Mabswid
.97619 .32402 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo3`3oool2000000L0oooo
00060?ooo`030000003oool0oooo0?l0oooo303oool300WZ2P8000001`3oool000H0oooo00<00000
0?ooo`3oool0o`3oool90?ooo`<02NX:103oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?ooo`H0oooo0`09jPX70?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo103oool200WZ2PX0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool10?ooo`<02NX:2`3oool2000000L0oooo00060?ooo`030000003o
ool0oooo0?d0oooo0`09jPX=0?ooo`0300WZ2P000000000000L0oooo00060?ooo`030000003oool0
oooo0?X0oooo0`09jPX=0?ooo`<02NX:0P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3h0?ooo`802NX:3@3oool300WZ2PD0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0m@3oool300WZ2P`0oooo0`09jPX80?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?80oooo0`09jPX<0?ooo`<02NX:2@3oool00`09jPX00000
000000070?ooo`001P3oool00`000000oooo0?ooo`3_0?ooo`<02NX:303oool300WZ2PT0oooo0`09
jPX00`3oool00000000000070?ooo`001P3oool00`000000oooo0?ooo`3]0?ooo`802NX:303oool3
00WZ2PT0oooo0`09jPX50?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0>X0oooo0`09jPX;0?ooo`<02NX:203oool400WZ2PP0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0i`3oool300WZ2P/0oooo0`09jPX80?ooo`<02NX:2P3oool00`09jPX0
0000000000070?ooo`001P3oool00`000000oooo0?ooo`3T0?ooo`<02NX:2`3oool300WZ2PL0oooo
1009jPX90?ooo`@02NX:00<0oooo0000000000001`3oool000H0oooo00<000000?ooo`3oool0hP3o
ool200WZ2PX0oooo1009jPX70?ooo`<02NX:2P3oool300WZ2PH0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0BP3oool6000008l0oooo0`09jPX90?ooo`<02NX:203oool3
00WZ2PT0oooo1009jPX90?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
04X0oooo1P00002<0?ooo`<02NX:2@3oool300WZ2PL0oooo1009jPX80?ooo`@02NX:2`3oool00`09
jPX00000000000070?ooo`001P3oool00`000000oooo0?ooo`190?ooo`800000101oOgl00`000000
oooo0?ooo`280?ooo`802NX:2@3oool300WZ2PL0oooo0`09jPX90?ooo`<02NX:2`3oool400WZ2P03
0?ooo`000000000000L0oooo00060?ooo`030000003oool0oooo04T0oooo0P00000407moO`030000
003oool0oooo08D0oooo0`09jPX80?ooo`<02NX:1`3oool300WZ2PP0oooo1009jPX:0?ooo`@02NX:
1P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`180?ooo`030000001o
Ogl0000000D00000Q03oool300WZ2PP0oooo0`09jPX60?ooo`@02NX:1`3oool400WZ2PT0oooo1@09
jPX:0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04P0oooo00<00000
07moO`000000101oOgl00`000000oooo0?ooo`1o0?ooo`<02NX:203oool300WZ2PH0oooo0`09jPX8
0?ooo`<02NX:2@3oool400WZ2Pd0oooo00<02NX:0000000000001`3oool000H0oooo00<000000?oo
o`3oool0A`3oool010000000Ogmo07moO`00000407moO`030000003oool0oooo07d0oooo0P09jPX8
0?ooo`<02NX:1P3oool300WZ2PL0oooo1009jPX80?ooo`@02NX:303oool500WZ2P030?ooo`000000
000000L0oooo00060?ooo`030000003oool0oooo04L0oooo00@0000007moO`1oOgl00000101oOgl0
0`000000oooo0?ooo`1j0?ooo`<02NX:1`3oool300WZ2PD0oooo1009jPX60?ooo`@02NX:203oool4
00WZ2P/0oooo1@09jPX70?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
04L0oooo00@0000007moO`1oOgl00000101oOgl00`000000oooo0?ooo`1g0?ooo`<02NX:1`3oool3
00WZ2PD0oooo0`09jPX70?ooo`<02NX:203oool400WZ2P/0oooo1009jPX90?ooo`802NX:0P000007
0?ooo`001P3oool00`000000oooo0?ooo`160?ooo`050000001oOgl0Ogmo07moO`000000101oOgl0
0`000000oooo0?ooo`1d0?ooo`<02NX:1`3oool300WZ2P@0oooo1009jPX60?ooo`@02NX:1`3oool4
00WZ2PX0oooo1@09jPX80?ooo`D02NX:0P3oool2000000L0oooo00060?ooo`030000003oool0oooo
04H0oooo00@0000007moO`1oOgl0Ogmo1P00001d0?ooo`802NX:1P3oool400WZ2P@0oooo0`09jPX6
0?ooo`@02NX:1P3oool500WZ2PT0oooo1@09jPX80?ooo`D02NX:203oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`150?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007mo
O`1oOgl00P1oOgl00`000000oooo0?ooo`1_0?ooo`<02NX:1@3oool300WZ2PD0oooo0`09jPX50?oo
o`@02NX:1P3oool400WZ2PX0oooo1009jPX80?ooo`D02NX:303oool2000000L0oooo00060?ooo`03
0000003oool0oooo04D0oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0207moO`03
0000003oool0oooo06`0oooo0`09jPX50?ooo`<02NX:103oool400WZ2PD0oooo0`09jPX60?ooo`@0
2NX:2@3oool500WZ2PL0oooo1@09jPX?0?ooo`802NX:0P0000070?ooo`001P3ooom:00WZ2P040000
0009jPX02NX:00WZ2P@0Ogmo00<000000?ooo`3oool0J@3oool300WZ2PD0oooo0`09jPX40?ooo`<0
2NX:1@3oool400WZ2PD0oooo1009jPX80?ooo`D02NX:1P3oool600WZ2Ph0oooo1P09jPX30?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04D0oooo00H0000007moO`000000
000007moO`00000300WZ2P0307moO`000000oooo06P0oooo0P09jPX50?ooo`<02NX:103oool300WZ
2P@0oooo1009jPX50?ooo`@02NX:203oool400WZ2PH0oooo1@09jPX>0?ooo`H02NX:203oool20000
00L0oooo00060?ooodd02NX:00@0000007moO`1oOgl0Ogmo0`09jPYU0?ooo`<02NX:103oool300WZ
2P<0oooo1009jPX40?ooo`<02NX:103oool500WZ2PL0oooo1@09jPX50?ooo`D02NX:3@3oool600WZ
2P/0oooo0`09jPX2000000L0oooo00060?oood`02NX:00<0Ogmo00WZ2P09jPX00P09jPX00`1oOgl0
00000000000300WZ2Ul0oooo0`09jPX40?ooo`<02NX:0`3oool300WZ2P@0oooo1009jPX30?ooo`@0
2NX:1`3oool500WZ2PD0oooo1@09jPX<0?ooo`H02NX:2P3oool700WZ2P@0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0A03oool40000000307moO`09jPX02NX:00L02NX:
0P3oool300WZ2UT0oooo0`09jPX40?ooo`<02NX:0P3oool400WZ2P<0oooo1009jPX30?ooo`@02NX:
1P3oool500WZ2PD0oooo1@09jPX;0?ooo`H02NX:2@3oool700WZ2PX0oooo0P0000070?ooo`001P3o
oom800WZ2P0300000009jPX02NX:00@02NX:0P1oOgl700WZ2P80oooo0`09jPYD0?ooo`802NX:103o
ool300WZ2P80oooo0`09jPX40?ooo`<02NX:0`3oool400WZ2PH0oooo1009jPX50?ooo`D02NX:2P3o
ool600WZ2PP0oooo1`09jPX>0?ooo`<02NX:0P0000070?ooo`001P3ooom700WZ2P0300000009jPX0
2NX:00802NX:00<0Ogmo0000001oOgl03009jPX20?ooo`802NX:C`3oool300WZ2P<0oooo0`09jPX2
0?ooo`<02NX:0`3oool400WZ2P80oooo1009jPX50?ooo`D02NX:0`3oool600WZ2PT0oooo1P09jPX7
0?ooo`L02NX:303oool900WZ2P@0oooo00<000000?ooo`3oool01@3oool000H0ooooB`09jPX00`1o
Ogl02NX:00WZ2P0300WZ2P0407moO`00000000000?ooo`T02NX:00@0oooo00WZ2P09jPX02NX:B@3o
ool300WZ2P80oooo1009jPX00`3oool02NX:00WZ2P0200WZ2P80oooo1009jPX20?ooo`@02NX:103o
ool500WZ2P<0oooo1@09jPX90?ooo`H02NX:1P3oool700WZ2P/0oooo2009jPX80?ooo`@02NX:0P00
00070?ooo`001P3oool00`000000oooo0?ooo`130?ooo`<000000P1oOgl500WZ2P0307moO`09jPX0
2NX:00802NX:103oool800WZ2P040?ooo`09jPX02NX:00WZ2T<0oooo0`09jPX20?ooo`<02NX:0P3o
ool300WZ2P<0oooo0`09jPX00`3oool02NX:00WZ2P0300WZ2P@0oooo1009jPX30?ooo`D02NX:203o
ool600WZ2PD0oooo1`09jPX:0?ooo`P02NX:1`3oool900WZ2P@0oooo0P0000070?ooo`001P3ooom6
00WZ2P0300000009jPX02NX:00D02NX:0P1oOgl900WZ2P<0oooo2009jPX0103oool02NX:00WZ2P09
jPXn0?ooo`802NX:0P3oool300WZ2P80oooo0`09jPX20?ooo`P02NX:103oool500WZ2P80oooo1@09
jPX70?ooo`H02NX:103oool700WZ2PP0oooo2@09jPX50?ooo`X02NX:3P3oool00`000000oooo0?oo
o`050?ooo`001P3ooom=00WZ2P0300000009jPX02NX:00d02NX:0`3oool700WZ2P030?ooo`09jPX0
2NX:03T0oooo0`09jPX01@3oool02NX:00WZ2P09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX01P09
jPX30?ooo`D02NX:0P3oool500WZ2PH0oooo1P09jPX30?ooo`L02NX:1`3oool800WZ2P@0oooo2P09
jPXB0?ooo`D02NX:0P0000070?ooo`001P3ooom500WZ2P0300000009jPX02NX:00802NX:0`1oOglE
00WZ2P80oooo2@09jPXc0?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09
jPX02NX:00H02NX:0`3oool400WZ2P030?ooo`09jPX02NX:00@02NX:1@3oool600WZ2P030?ooo`09
jPX02NX:00H02NX:1P3oool800WZ2P<0oooo2@09jPX@0?ooo``02NX:1@3oool2000000L0oooo0006
0?ooo`030000003oool0oooo0480oooo0P00000307moO`H02NX:100000020?oooa002NX:00<0oooo
00WZ2P09jPX01`09jPX]0?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09
jPX02NX:00D02NX:0P3oool:00WZ2PD0oooo3@09jPX50?ooo`T02NX:00<0oooo00WZ2P09jPX02009
jPX=0?ooo``02NX:4P3oool00`000000oooo0?ooo`050?ooo`001P3ooom500WZ2P0300000009jPX0
2NX:00D02NX:00<0000007moO`1oOgl01`09jPX50?ooo`h02NX:00<0oooo00WZ2P09jPX01P09jPXX
0?ooo`802NX:00<0oooo00WZ2P09jPX03009jPX00`3oool02NX:00WZ2P0800WZ2P@0oooo3009jPX4
0?ooo`P02NX:00<0oooo00WZ2P09jPX01`09jPX;0?ooo``02NX:5P3oool700WZ2P8000001`3oool0
00H0ooooGP09jPX40?ooo``02NX:00<0oooo00WZ2P09jPX01009jPXS0?oooa002NX:00<0oooo00WZ
2P09jPX01`09jPX30?ooo`/02NX:0`3ooolA00WZ2PP0oooo3009jPXB0?oooa002NX:1`3oool20000
00L0oooo00060?ooo`030000003oool0oooo0440oooo0`00000607moOaP02NX:0`3oool@00WZ2Qd0
oooo3P09jPX00`3oool02NX:00WZ2P0700WZ2P80oooo2P09jPX00`3oool02NX:00WZ2P0>00WZ2PH0
oooo3009jPX>0?oooa002NX:5`3oool2000000L0oooo00060?oood@02NX:00<0000000WZ2P09jPX0
9@09jPX20?ooo`d02NX:5`3ooolF00WZ2P030?ooo`09jPX02NX:01D02NX:103oool<00WZ2PX0oooo
4009jPXJ0?ooo`d02NX:0P0000070?ooo`001P3ooom400WZ2P0300000009jPX02NX:02`02NX:00<0
oooo00WZ2P09jPX02009jPXB0?oooa802NX:00<0oooo00WZ2P09jPX04P09jPX00`3oool02NX:00WZ
2P0:00WZ2PH0oooo4009jPX?0?oooa/02NX:3P3oool00`000000oooo0?ooo`050?ooo`001P3ooom4
00WZ2P0300000009jPX02NX:00H02NX:00<0000007moO`1oOgl00P1oOgl2000000L0oooo9P09jPX<
0?ooob/02NX:0P3oool@00WZ2P<0oooo7009jPXA0?oooaL02NX:0P0000070?ooo`001P3oool00`00
0000oooo0?ooo`110?ooo`8000001`1oOglD00WZ2PX0oooo6`09jPX40?ooog002NX:5`3oool20000
00L0oooo00060?oood@02NX:00<0000000WZ2P09jPX0P`09jPY80?ooo`030000003oool0oooo00D0
oooo00060?oood@02NX:00<0000000WZ2P09jPX0bP09jPX2000000L0oooo00060?oood@02NX:00<0
000000WZ2P09jPX0Q009jPY60?ooo`8000001`3oool000H0oooo00<000000?ooo`3oool0@@3oool2
000000H0Ogmo5009jPX:0?oooa/02NX:1P3ooom`00WZ2QH0oooo0P0000070?ooo`001P3ooom400WZ
2P0300000009jPX02NX:00D02NX:00<0Ogmo0000001oOgl00`1oOgl2000000H0oooo9P09jPX>0?oo
ob/02NX:0P3oool@00WZ2P<0oooo7009jPXA0?oooaH02NX:0P0000070?ooo`001P3ooom400WZ2P03
00000009jPX02NX:02/02NX:00<0oooo00WZ2P09jPX02009jPXD0?oooa802NX:00<0oooo00WZ2P09
jPX04P09jPX00`3oool02NX:00WZ2P0:00WZ2PH0oooo4009jPX?0?oooa/02NX:3@3oool00`000000
oooo0?ooo`050?ooo`001P3ooom400WZ2P0300000009jPX02NX:02@02NX:0P3oool=00WZ2QT0oooo
5P09jPX00`3oool02NX:00WZ2P0E00WZ2P@0oooo3009jPX:0?oooa002NX:6P3oool<00WZ2P800000
1`3oool000H0oooo00<000000?ooo`3oool0@@3oool3000000D0Ogmo6009jPX30?oooa002NX:7`3o
ool>00WZ2P030?ooo`09jPX02NX:00L02NX:0P3oool:00WZ2P030?ooo`09jPX02NX:00h02NX:1P3o
ool<00WZ2Ph0oooo4009jPXF0?ooo`8000001`3oool000H0ooooG@09jPX40?ooo``02NX:00<0oooo
00WZ2P09jPX01009jPXU0?oooa002NX:00<0oooo00WZ2P09jPX01`09jPX30?ooo`/02NX:0`3ooolA
00WZ2PP0oooo3009jPXB0?oooa002NX:1`3oool00`000000oooo0?ooo`050?ooo`001P3ooom500WZ
2P0300000009jPX02NX:00@02NX:00<0Ogmo0000001oOgl01`09jPX50?ooo`h02NX:00<0oooo00WZ
2P09jPX01P09jPXZ0?ooo`802NX:00<0oooo00WZ2P09jPX03009jPX00`3oool02NX:00WZ2P0800WZ
2P@0oooo3009jPX40?ooo`P02NX:00<0oooo00WZ2P09jPX01`09jPX;0?ooo``02NX:5P3oool600WZ
2P8000001`3oool000H0oooo00<000000?ooo`3oool0@P3oool200000080Ogmo1P09jPX500000003
0?ooo`09jPX02NX:00h02NX:00<0oooo00WZ2P09jPX01`09jPX_0?ooo`<02NX:00D0oooo00WZ2P09
jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00D02NX:0P3oool:00WZ2PD0oooo3@09jPX50?oo
o`T02NX:00<0oooo00WZ2P09jPX02009jPX=0?ooo``02NX:403oool2000000L0oooo00060?ooodD0
2NX:00@0000000WZ2P09jPX02NX:0`1oOglE00WZ2P80oooo2@09jPXe0?ooo`<02NX:00D0oooo00WZ
2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00H02NX:0`3oool400WZ2P030?ooo`09jPX0
2NX:00@02NX:1@3oool600WZ2P030?ooo`09jPX02NX:00H02NX:1P3oool800WZ2P<0oooo2@09jPX@
0?ooo``02NX:103oool2000000L0oooo00060?oood`02NX:00<0Ogmo00WZ2P09jPX03@09jPX30?oo
o`L02NX:00<0oooo00WZ2P09jPX0>`3oool300WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX0
0`3oool02NX:00WZ2P0600WZ2P<0oooo1@09jPX20?ooo`D02NX:1P3oool600WZ2P<0oooo1`09jPX7
0?ooo`P02NX:103oool:00WZ2Q80oooo1009jPX2000000L0oooo00060?ooodH02NX:00<0000000WZ
2P09jPX01009jPX00`000000Ogmo00WZ2P0800WZ2P<0oooo2009jPX0103oool02NX:00WZ2P09jPY0
0?ooo`802NX:0P3oool300WZ2P80oooo0`09jPX20?ooo`P02NX:103oool500WZ2P80oooo1@09jPX7
0?ooo`H02NX:103oool700WZ2PP0oooo2@09jPX50?ooo`X02NX:3@3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`130?ooo`<0000000<0Ogmo00WZ2P09jPX00`09jPX00`1o
Ogl02NX:00WZ2P0200WZ2P@0oooo2009jPX0103oool02NX:00WZ2P09jPY50?ooo`<02NX:0P3oool3
00WZ2P80oooo0`09jPX30?ooo`<02NX:00<0oooo00WZ2P09jPX00`09jPX40?ooo`@02NX:0`3oool5
00WZ2PP0oooo1P09jPX50?ooo`L02NX:2P3oool800WZ2PL0oooo2@09jPX30?ooo`8000001`3oool0
00H0ooooBP09jPX00`1oOgl02NX:00WZ2P0300WZ2P80Ogmo0P00000900WZ2P040?ooo`09jPX02NX:
00WZ2T/0oooo0`09jPX20?ooo`@02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`@02NX:0P3oool4
00WZ2P@0oooo1@09jPX30?ooo`D02NX:2@3oool600WZ2PH0oooo1`09jPX;0?ooo`P02NX:203oool3
00WZ2P8000001`3oool000H0ooooA`09jPX0100000002NX:00WZ2P09jPX207moO`0300000009jPX0
2NX:00X02NX:0P3oool200WZ2U40oooo0`09jPX30?ooo`<02NX:0P3oool300WZ2P<0oooo1009jPX2
0?ooo`@02NX:1@3oool500WZ2P<0oooo1P09jPX90?ooo`H02NX:1`3oool700WZ2P`0oooo2@09jPX3
0?ooo`030000003oool0oooo00D0oooo00060?ooodP02NX:00<0000000WZ2P09jPX00`09jPX207mo
O`L02NX:0P3oool300WZ2UH0oooo0P09jPX40?ooo`<02NX:0P3oool300WZ2P@0oooo0`09jPX30?oo
o`@02NX:1P3oool400WZ2PD0oooo1@09jPX:0?ooo`H02NX:203oool700WZ2Ph0oooo0P09jPX20000
00L0oooo00060?ooo`030000003oool0oooo04@0oooo0`0000000`1oOgl02NX:00WZ2P0700WZ2P80
oooo0`09jPYK0?ooo`<02NX:103oool300WZ2P80oooo1009jPX30?ooo`@02NX:0`3oool400WZ2PH0
oooo1@09jPX50?ooo`D02NX:2`3oool600WZ2PT0oooo1`09jPX90?ooo`8000001`3oool000H0oooo
B`09jPX00`1oOgl02NX:00WZ2P0200WZ2P80Ogmo00@0000000WZ2P09jPX02NX:H@3oool300WZ2P@0
oooo0`09jPX30?ooo`<02NX:103oool400WZ2P<0oooo1009jPX70?ooo`D02NX:1@3oool500WZ2P`0
oooo1P09jPX:0?ooo`L02NX:0`3oool00`000000oooo0?ooo`050?ooo`001P3ooom<00WZ2P0307mo
O`000000Ogmo00@02NX:00<000000?ooo`3oool0I03oool300WZ2P@0oooo0`09jPX30?ooo`@02NX:
103oool300WZ2P@0oooo1@09jPX70?ooo`D02NX:1@3oool500WZ2Pd0oooo1P09jPX;0?ooo`802NX:
0P0000070?ooo`001P3ooom:00WZ2P0300000009jPX02NX:00802NX:0`1oOgl2000006T0oooo0P09
jPX50?ooo`<02NX:103oool300WZ2P@0oooo1009jPX50?ooo`@02NX:203oool400WZ2PH0oooo1@09
jPX>0?ooo`H02NX:1`3oool2000000L0oooo00060?ooo`030000003oool0oooo04D0oooo00H00000
07moO`000000000007moO`00000407moO`030000003oool0oooo06X0oooo0`09jPX50?ooo`<02NX:
103oool300WZ2PD0oooo1009jPX50?ooo`@02NX:203oool500WZ2PH0oooo1P09jPX>0?ooo`H02NX:
0P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`150?ooo`030000001o
Ogl0Ogmo0080Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`1]0?ooo`<02NX:1@3o
ool300WZ2P@0oooo1009jPX50?ooo`<02NX:1P3oool400WZ2PT0oooo1@09jPX70?ooo`D02NX:3`3o
ool00`09jPX00000000000070?ooo`001P3oool00`000000oooo0?ooo`150?ooo`030000001oOgl0
Ogmo0080Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`1`0?ooo`<02NX:1@3oool3
00WZ2PD0oooo0`09jPX50?ooo`@02NX:1P3oool400WZ2PX0oooo1009jPX80?ooo`D02NX:2`3oool2
000000L0oooo00060?ooo`030000003oool0oooo04D0oooo00<0000007moO`1oOgl00P1oOgl60000
07D0oooo0P09jPX60?ooo`@02NX:103oool300WZ2PH0oooo1009jPX60?ooo`D02NX:2@3oool500WZ
2PP0oooo1@09jPX70?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04H0
oooo00D0000007moO`1oOgl0Ogmo0000000407moO`030000003oool0oooo07D0oooo0`09jPX70?oo
o`<02NX:103oool400WZ2PH0oooo1009jPX70?ooo`@02NX:2P3oool500WZ2PP0oooo1@09jPX00`3o
ool00000000000070?ooo`001P3oool00`000000oooo0?ooo`160?ooo`050000001oOgl0Ogmo07mo
O`000000101oOgl00`000000oooo0?ooo`1h0?ooo`<02NX:1`3oool300WZ2PD0oooo0`09jPX70?oo
o`<02NX:203oool400WZ2P/0oooo1009jPX90?ooo`0300WZ2P000000000000L0oooo00060?ooo`03
0000003oool0oooo04L0oooo00@0000007moO`1oOgl00000101oOgl00`000000oooo0?ooo`1k0?oo
o`<02NX:1`3oool300WZ2PD0oooo1009jPX60?ooo`@02NX:203oool400WZ2P/0oooo1@09jPX60?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04L0oooo00@0000007moO`1o
Ogl00000101oOgl00`000000oooo0?ooo`1n0?ooo`802NX:203oool300WZ2PH0oooo0`09jPX70?oo
o`@02NX:203oool400WZ2P`0oooo1@09jPX00`3oool000000?ooo`060?ooo`001P3oool00`000000
oooo0?ooo`180?ooo`030000001oOgl0000000@0Ogmo00<000000?ooo`3oool0P03oool300WZ2PP0
oooo0`09jPX60?ooo`<02NX:203oool300WZ2PT0oooo1009jPX=0?ooo`8000001`3oool000H0oooo
00<000000?ooo`3oool0B03oool00`000000Ogmo00000005000008D0oooo0`09jPX80?ooo`<02NX:
1P3oool400WZ2PL0oooo1009jPX90?ooo`D02NX:203oool2000000L0oooo00060?ooo`030000003o
ool0oooo04P0oooo00<0000007moO`000000101oOgl00`000000oooo0?ooo`260?ooo`<02NX:203o
ool300WZ2PL0oooo0`09jPX80?ooo`@02NX:2P3oool400WZ2PD0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0B@3oool2000000@0Ogmo00<000000?ooo`3oool0R@3oool2
00WZ2PT0oooo0`09jPX70?ooo`<02NX:2@3oool300WZ2P/0oooo1009jPX00`3oool000000?ooo`06
0?ooo`001P3oool00`000000oooo0?ooo`190?ooo`L00000S@3oool300WZ2PT0oooo0`09jPX70?oo
o`@02NX:203oool400WZ2P/0oooo0P0000070?ooo`001P3oool00`000000oooo0?ooo`1:0?ooo`H0
0000T03oool300WZ2PT0oooo0`09jPX80?ooo`<02NX:2@3oool400WZ2PL0oooo0P0000070?ooo`00
1P3oool00`000000oooo0?ooo`3S0?ooo`802NX:2P3oool400WZ2PL0oooo0`09jPX:0?ooo`<02NX:
1@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3U0?ooo`<02NX:2`3o
ool300WZ2PL0oooo1009jPX90?ooo`@02NX:0P0000070?ooo`001P3oool00`000000oooo0?ooo`3X
0?ooo`<02NX:2`3oool300WZ2PP0oooo0`09jPX:0?ooo`8000001`3oool000H0oooo00<000000?oo
o`3oool0j`3oool300WZ2P/0oooo0`09jPX80?ooo`@02NX:1`3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3^0?ooo`802NX:303oool300WZ2PT0oooo0`09jPX40?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?00oooo0`09jPX<0?ooo`<02NX:
2@3oool300WZ2P030?ooo`000000oooo00H0oooo00060?ooo`030000003oool0oooo0?<0oooo0`09
jPX<0?ooo`<02NX:2@3oool2000000L0oooo00060?ooo`030000003oool0oooo0?H0oooo0`09jPX<
0?ooo`<02NX:1P3oool2000000L0oooo00060?ooo`030000003oool0oooo0?T0oooo0P09jPX=0?oo
o`<02NX:103oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3k0?ooo`<0
2NX:3@3oool300WZ2P030?ooo`000000oooo00H0oooo00060?ooo`030000003oool0oooo0?h0oooo
0`09jPX=0?ooo`8000001`3oool000H0oooo00<000000?ooo`3oool0o`3oool20?ooo`<02NX:2P3o
ool2000000L0oooo00060?ooo`030000003oool0oooo0?l0oooo1@3oool200WZ2PT0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool70?ooo`<02NX:1P3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?ooo`X0oooo0`09jPX30?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo3@3oool200WZ2P800000
1`3oool000H0oooo00<000000?ooo`3oool0o`3oool?0?ooo`8000001`3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo0P00003o0?oooa40oooo00<0
00000?ooo`3oool01@3oool000H0ooooo`00000D000000L0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00105, -105.001, 0.731715, \
0.731715}},
  CellTags->"TurboPlot Examples"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboPlot[WedgeOfRays[10],trace,PlotType->TopView];", "Input",
  CellTags->"TurboPlot Examples"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.5 0.0047619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.29249 .38095 m
.30952 .38095 L
.30952 .42063 L
.275 .42063 L
.29249 .38095 L
F
.275 .42063 m
.30952 .42063 L
.30952 .46032 L
.26511 .46032 L
.275 .42063 L
F
.26511 .46032 m
.30952 .46032 L
.30952 .5 L
.2619 .5 L
.26511 .46032 L
F
.2619 .5 m
.30952 .5 L
.30952 .53968 L
.26511 .53968 L
.2619 .5 L
F
.26511 .53968 m
.30952 .53968 L
.30952 .57937 L
.275 .57937 L
.26511 .53968 L
F
.275 .57937 m
.30952 .57937 L
.30952 .61905 L
.29249 .61905 L
.275 .57937 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.29249 .38095 m
.275 .42063 L
.26511 .46032 L
.2619 .5 L
.26511 .53968 L
.275 .57937 L
.29249 .61905 L
.30952 .61905 L
.30952 .57937 L
.30952 .53968 L
.30952 .5 L
.30952 .46032 L
.30952 .42063 L
.30952 .38095 L
.29249 .38095 L
s
.5 g
.29249 .5 m
.30952 .5 L
.30952 .5 L
.275 .5 L
.29249 .5 L
F
.275 .5 m
.30952 .5 L
.30952 .5 L
.26511 .5 L
.275 .5 L
F
.26511 .5 m
.30952 .5 L
.30952 .5 L
.2619 .5 L
.26511 .5 L
F
.2619 .5 m
.30952 .5 L
.30952 .5 L
.26511 .5 L
.2619 .5 L
F
.26511 .5 m
.30952 .5 L
.30952 .5 L
.275 .5 L
.26511 .5 L
F
.275 .5 m
.30952 .5 L
.30952 .5 L
.29249 .5 L
.275 .5 L
F
0 g
.29249 .5 m
.275 .5 L
.26511 .5 L
.2619 .5 L
.26511 .5 L
.275 .5 L
.29249 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.30952 .5 L
.29249 .5 L
s
.29249 .61905 m
.30952 .61905 L
.30952 .61499 L
.29249 .61499 L
.29249 .61905 L
s
.29249 .61499 m
.30952 .61499 L
.30952 .6031 L
.29249 .6031 L
.29249 .61499 L
s
.29249 .6031 m
.30952 .6031 L
.30952 .58418 L
.29249 .58418 L
.29249 .6031 L
s
.29249 .58418 m
.30952 .58418 L
.30952 .55952 L
.29249 .55952 L
.29249 .58418 L
s
.29249 .55952 m
.30952 .55952 L
.30952 .53081 L
.29249 .53081 L
.29249 .55952 L
s
.29249 .53081 m
.30952 .53081 L
.30952 .5 L
.29249 .5 L
.29249 .53081 L
s
.29249 .5 m
.30952 .5 L
.30952 .46919 L
.29249 .46919 L
.29249 .5 L
s
.29249 .46919 m
.30952 .46919 L
.30952 .44048 L
.29249 .44048 L
.29249 .46919 L
s
.29249 .44048 m
.30952 .44048 L
.30952 .41582 L
.29249 .41582 L
.29249 .44048 L
s
.29249 .41582 m
.30952 .41582 L
.30952 .3969 L
.29249 .3969 L
.29249 .41582 L
s
.29249 .3969 m
.30952 .3969 L
.30952 .38501 L
.29249 .38501 L
.29249 .3969 L
s
.29249 .38501 m
.30952 .38501 L
.30952 .38095 L
.29249 .38095 L
.29249 .38501 L
s
.29249 .38095 m
.30952 .38095 L
.30952 .38501 L
.29249 .38501 L
.29249 .38095 L
s
.29249 .38501 m
.30952 .38501 L
.30952 .3969 L
.29249 .3969 L
.29249 .38501 L
s
.29249 .3969 m
.30952 .3969 L
.30952 .41582 L
.29249 .41582 L
.29249 .3969 L
s
.29249 .41582 m
.30952 .41582 L
.30952 .44048 L
.29249 .44048 L
.29249 .41582 L
s
.29249 .44048 m
.30952 .44048 L
.30952 .46919 L
.29249 .46919 L
.29249 .44048 L
s
.29249 .46919 m
.30952 .46919 L
.30952 .5 L
.29249 .5 L
.29249 .46919 L
s
.29249 .5 m
.30952 .5 L
.30952 .53081 L
.29249 .53081 L
.29249 .5 L
s
.29249 .53081 m
.30952 .53081 L
.30952 .55952 L
.29249 .55952 L
.29249 .53081 L
s
.29249 .55952 m
.30952 .55952 L
.30952 .58418 L
.29249 .58418 L
.29249 .55952 L
s
.29249 .58418 m
.30952 .58418 L
.30952 .6031 L
.29249 .6031 L
.29249 .58418 L
s
.29249 .6031 m
.30952 .6031 L
.30952 .61499 L
.29249 .61499 L
.29249 .6031 L
s
.29249 .61499 m
.30952 .61499 L
.30952 .61905 L
.29249 .61905 L
.29249 .61499 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .5 m
.26279 .52091 L
s
0 0 0 r
2.5 Mabswid
.26279 .52091 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.2619 .5 L
s
0 0 0 r
2.5 Mabswid
.2619 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.26279 .47909 L
s
0 0 0 r
2.5 Mabswid
.26279 .47909 Mdot
.039 .916 .04 r
.5 Mabswid
.26279 .52091 m
.30952 .52222 L
s
0 0 0 r
2.5 Mabswid
.30952 .52222 Mdot
.039 .916 .04 r
.5 Mabswid
.2619 .5 m
.30952 .5 L
s
0 0 0 r
2.5 Mabswid
.30952 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.26279 .47909 m
.30952 .47778 L
s
0 0 0 r
2.5 Mabswid
.30952 .47778 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .52222 m
.97619 .55075 L
s
0 0 0 r
2.5 Mabswid
.97619 .55075 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .5 m
.97619 .5 L
s
0 0 0 r
2.5 Mabswid
.97619 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .47778 m
.97619 .44925 L
s
0 0 0 r
2.5 Mabswid
.97619 .44925 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00105, -105.001, 0.731715, \
0.731715}},
  CellTags->"TurboPlot Examples"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Lens Optimizations", "Section",
  CellTags->"Lens Optimizations"],

Cell[CellGroupData[{

Cell["?OptimizeSystem", "Input",
  CellTags->"Lens Optimizations"],

Cell[BoxData[
    \("OptimizeSystem[system, options] optimizes the performance of an \
optical system for a specified set of input parameters. \n\nOptimizeSystem \
first calls ConstructMeritFunction to create a RayTraceFunction according to \
the MeritType option setting and then calls a minimization algorithm \
according to the MinimizationType option. MeritType is internally converted \
into particular settings for the ReportedParameter and ReportedFunction \
options. As an alternative to using the MeritType option, the user can \
instead work directly with the ReportedParameters and ReportedFunction \
options. In addition to accepting an optical system of light sources and \
components, one or more previously calculated results from \
ConstructMeritFunction may be directly passed to OptimizeSystem. If more than \
one ConstructMeritFunction result is passed, OptimizeSystem uses the combined \
merit results to perform the minimization. \n\nSee also: \
ConstructMeritFunction, MeritType, MinimizationType, TurboTrace, and \
RayTraceFunction."\)], "Print",
  CellTags->{"Info3252053709-8785867", "Lens Optimizations"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["?ConstructMeritFunction", "Input",
  CellTags->"Lens Optimizations"],

Cell[BoxData[
    \("ConstructMeritFunction[opticalsystem, options] constructs a \
RayTraceFunction that calculates the performance of an optical system for a \
specified set of input parameters. \n\nConstructMeritFunction calls \
TurboTrace to create the RayTraceFunction according to the MeritType option \
setting. MeritType is internally converted by ConstructMeritFunction into \
particular settings for the ReportedParameter and ReportedFunction options. \
As an alternative to using the MeritType option, the user can instead work \
directly with the ReportedParameters and ReportedFunction options. \
ConstructMeritFunction is used by OptimizeSystem. See also: OptimizeSystem, \
MeritType, TurboTrace, and RayTraceFunction."\)], "Print",
  CellTags->{"Info3252053717-8293308", "Lens Optimizations"}]
}, Open  ]],

Cell[BoxData[
    \(\(sys = {LineOfRays[45, 
            NumberOfRays \[Rule] 6], \[IndentingNewLine]Move[
            SphericalLens[{r1, 100}, {r2, \(-100\)}, 50, 10], 
            100], \[IndentingNewLine]Move[Baffle[50], 200]};\)\)], "Input",
  CellTags->"Lens Optimizations"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(turbosys\  = \ TurboPlot[sys, PlotType \[Rule] TopView];\)\)], "Input",\

  CellTags->"Lens Optimizations"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.125 0.0047619 [
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.51512 .00595 m
.5325 .00595 L
.54096 .04563 L
.50666 .04563 L
.51512 .00595 L
F
.50666 .04563 m
.54096 .04563 L
.54596 .08532 L
.50166 .08532 L
.50666 .04563 L
F
.50166 .08532 m
.54596 .08532 L
.54762 .125 L
.5 .125 L
.50166 .08532 L
F
.5 .125 m
.54762 .125 L
.54596 .16468 L
.50166 .16468 L
.5 .125 L
F
.50166 .16468 m
.54596 .16468 L
.54096 .20437 L
.50666 .20437 L
.50166 .16468 L
F
.50666 .20437 m
.54096 .20437 L
.5325 .24405 L
.51512 .24405 L
.50666 .20437 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.51512 .00595 m
.50666 .04563 L
.50166 .08532 L
.5 .125 L
.50166 .16468 L
.50666 .20437 L
.51512 .24405 L
.5325 .24405 L
.54096 .20437 L
.54596 .16468 L
.54762 .125 L
.54596 .08532 L
.54096 .04563 L
.5325 .00595 L
.51512 .00595 L
s
.5 g
.51512 .125 m
.5325 .125 L
.54096 .125 L
.50666 .125 L
.51512 .125 L
F
.50666 .125 m
.54096 .125 L
.54596 .125 L
.50166 .125 L
.50666 .125 L
F
.50166 .125 m
.54596 .125 L
.54762 .125 L
.5 .125 L
.50166 .125 L
F
.5 .125 m
.54762 .125 L
.54596 .125 L
.50166 .125 L
.5 .125 L
F
.50166 .125 m
.54596 .125 L
.54096 .125 L
.50666 .125 L
.50166 .125 L
F
.50666 .125 m
.54096 .125 L
.5325 .125 L
.51512 .125 L
.50666 .125 L
F
0 g
.51512 .125 m
.50666 .125 L
.50166 .125 L
.5 .125 L
.50166 .125 L
.50666 .125 L
.51512 .125 L
.5325 .125 L
.54096 .125 L
.54596 .125 L
.54762 .125 L
.54596 .125 L
.54096 .125 L
.5325 .125 L
.51512 .125 L
s
.51512 .24405 m
.5325 .24405 L
.5325 .23999 L
.51512 .23999 L
.51512 .24405 L
s
.51512 .23999 m
.5325 .23999 L
.5325 .2281 L
.51512 .2281 L
.51512 .23999 L
s
.51512 .2281 m
.5325 .2281 L
.5325 .20918 L
.51512 .20918 L
.51512 .2281 L
s
.51512 .20918 m
.5325 .20918 L
.5325 .18452 L
.51512 .18452 L
.51512 .20918 L
s
.51512 .18452 m
.5325 .18452 L
.5325 .15581 L
.51512 .15581 L
.51512 .18452 L
s
.51512 .15581 m
.5325 .15581 L
.5325 .125 L
.51512 .125 L
.51512 .15581 L
s
.51512 .125 m
.5325 .125 L
.5325 .09419 L
.51512 .09419 L
.51512 .125 L
s
.51512 .09419 m
.5325 .09419 L
.5325 .06548 L
.51512 .06548 L
.51512 .09419 L
s
.51512 .06548 m
.5325 .06548 L
.5325 .04082 L
.51512 .04082 L
.51512 .06548 L
s
.51512 .04082 m
.5325 .04082 L
.5325 .0219 L
.51512 .0219 L
.51512 .04082 L
s
.51512 .0219 m
.5325 .0219 L
.5325 .01001 L
.51512 .01001 L
.51512 .0219 L
s
.51512 .01001 m
.5325 .01001 L
.5325 .00595 L
.51512 .00595 L
.51512 .01001 L
s
.51512 .00595 m
.5325 .00595 L
.5325 .01001 L
.51512 .01001 L
.51512 .00595 L
s
.51512 .01001 m
.5325 .01001 L
.5325 .0219 L
.51512 .0219 L
.51512 .01001 L
s
.51512 .0219 m
.5325 .0219 L
.5325 .04082 L
.51512 .04082 L
.51512 .0219 L
s
.51512 .04082 m
.5325 .04082 L
.5325 .06548 L
.51512 .06548 L
.51512 .04082 L
s
.51512 .06548 m
.5325 .06548 L
.5325 .09419 L
.51512 .09419 L
.51512 .06548 L
s
.51512 .09419 m
.5325 .09419 L
.5325 .125 L
.51512 .125 L
.51512 .09419 L
s
.51512 .125 m
.5325 .125 L
.5325 .15581 L
.51512 .15581 L
.51512 .125 L
s
.51512 .15581 m
.5325 .15581 L
.5325 .18452 L
.51512 .18452 L
.51512 .15581 L
s
.51512 .18452 m
.5325 .18452 L
.5325 .20918 L
.51512 .20918 L
.51512 .18452 L
s
.51512 .20918 m
.5325 .20918 L
.5325 .2281 L
.51512 .2281 L
.51512 .20918 L
s
.51512 .2281 m
.5325 .2281 L
.5325 .23999 L
.51512 .23999 L
.51512 .2281 L
s
.51512 .23999 m
.5325 .23999 L
.5325 .24405 L
.51512 .24405 L
.51512 .23999 L
s
.5 g
.97619 .125 m
.97619 .16468 L
.97619 .16333 L
.97619 .125 L
.97619 .125 L
F
.97619 .16468 m
.97619 .20437 L
.97619 .20166 L
.97619 .16333 L
.97619 .16468 L
F
.97619 .20437 m
.97619 .24405 L
.97619 .23999 L
.97619 .20166 L
.97619 .20437 L
F
.97619 .125 m
.97619 .16333 L
.97619 .15937 L
.97619 .125 L
.97619 .125 L
F
.97619 .16333 m
.97619 .20166 L
.97619 .19373 L
.97619 .15937 L
.97619 .16333 L
F
.97619 .20166 m
.97619 .23999 L
.97619 .2281 L
.97619 .19373 L
.97619 .20166 L
F
.97619 .125 m
.97619 .15937 L
.97619 .15306 L
.97619 .125 L
.97619 .125 L
F
.97619 .15937 m
.97619 .19373 L
.97619 .18112 L
.97619 .15306 L
.97619 .15937 L
F
.97619 .19373 m
.97619 .2281 L
.97619 .20918 L
.97619 .18112 L
.97619 .19373 L
F
.97619 .125 m
.97619 .15306 L
.97619 .14484 L
.97619 .125 L
.97619 .125 L
F
.97619 .15306 m
.97619 .18112 L
.97619 .16468 L
.97619 .14484 L
.97619 .15306 L
F
.97619 .18112 m
.97619 .20918 L
.97619 .18452 L
.97619 .16468 L
.97619 .18112 L
F
.97619 .125 m
.97619 .14484 L
.97619 .13527 L
.97619 .125 L
.97619 .125 L
F
.97619 .14484 m
.97619 .16468 L
.97619 .14554 L
.97619 .13527 L
.97619 .14484 L
F
.97619 .16468 m
.97619 .18452 L
.97619 .15581 L
.97619 .14554 L
.97619 .16468 L
F
.97619 .125 m
.97619 .13527 L
.97619 .125 L
.97619 .125 L
.97619 .125 L
F
.97619 .13527 m
.97619 .14554 L
.97619 .125 L
.97619 .125 L
.97619 .13527 L
F
.97619 .14554 m
.97619 .15581 L
.97619 .125 L
.97619 .125 L
.97619 .14554 L
F
.97619 .125 m
.97619 .125 L
.97619 .11473 L
.97619 .125 L
.97619 .125 L
F
.97619 .125 m
.97619 .125 L
.97619 .10446 L
.97619 .11473 L
.97619 .125 L
F
.97619 .125 m
.97619 .125 L
.97619 .09419 L
.97619 .10446 L
.97619 .125 L
F
.97619 .125 m
.97619 .11473 L
.97619 .10516 L
.97619 .125 L
.97619 .125 L
F
.97619 .11473 m
.97619 .10446 L
.97619 .08532 L
.97619 .10516 L
.97619 .11473 L
F
.97619 .10446 m
.97619 .09419 L
.97619 .06548 L
.97619 .08532 L
.97619 .10446 L
F
.97619 .125 m
.97619 .10516 L
.97619 .09694 L
.97619 .125 L
.97619 .125 L
F
.97619 .10516 m
.97619 .08532 L
.97619 .06888 L
.97619 .09694 L
.97619 .10516 L
F
.97619 .08532 m
.97619 .06548 L
.97619 .04082 L
.97619 .06888 L
.97619 .08532 L
F
.97619 .125 m
.97619 .09694 L
.97619 .09063 L
.97619 .125 L
.97619 .125 L
F
.97619 .09694 m
.97619 .06888 L
.97619 .05627 L
.97619 .09063 L
.97619 .09694 L
F
.97619 .06888 m
.97619 .04082 L
.97619 .0219 L
.97619 .05627 L
.97619 .06888 L
F
.97619 .125 m
.97619 .09063 L
.97619 .08667 L
.97619 .125 L
.97619 .125 L
F
.97619 .09063 m
.97619 .05627 L
.97619 .04834 L
.97619 .08667 L
.97619 .09063 L
F
.97619 .05627 m
.97619 .0219 L
.97619 .01001 L
.97619 .04834 L
.97619 .05627 L
F
.97619 .125 m
.97619 .08667 L
.97619 .08532 L
.97619 .125 L
.97619 .125 L
F
.97619 .08667 m
.97619 .04834 L
.97619 .04563 L
.97619 .08532 L
.97619 .08667 L
F
.97619 .04834 m
.97619 .01001 L
.97619 .00595 L
.97619 .04563 L
.97619 .04834 L
F
.97619 .125 m
.97619 .08532 L
.97619 .08667 L
.97619 .125 L
.97619 .125 L
F
.97619 .08532 m
.97619 .04563 L
.97619 .04834 L
.97619 .08667 L
.97619 .08532 L
F
.97619 .04563 m
.97619 .00595 L
.97619 .01001 L
.97619 .04834 L
.97619 .04563 L
F
.97619 .125 m
.97619 .08667 L
.97619 .09063 L
.97619 .125 L
.97619 .125 L
F
.97619 .08667 m
.97619 .04834 L
.97619 .05627 L
.97619 .09063 L
.97619 .08667 L
F
.97619 .04834 m
.97619 .01001 L
.97619 .0219 L
.97619 .05627 L
.97619 .04834 L
F
.97619 .125 m
.97619 .09063 L
.97619 .09694 L
.97619 .125 L
.97619 .125 L
F
.97619 .09063 m
.97619 .05627 L
.97619 .06888 L
.97619 .09694 L
.97619 .09063 L
F
.97619 .05627 m
.97619 .0219 L
.97619 .04082 L
.97619 .06888 L
.97619 .05627 L
F
.97619 .125 m
.97619 .09694 L
.97619 .10516 L
.97619 .125 L
.97619 .125 L
F
.97619 .09694 m
.97619 .06888 L
.97619 .08532 L
.97619 .10516 L
.97619 .09694 L
F
.97619 .06888 m
.97619 .04082 L
.97619 .06548 L
.97619 .08532 L
.97619 .06888 L
F
.97619 .125 m
.97619 .10516 L
.97619 .11473 L
.97619 .125 L
.97619 .125 L
F
.97619 .10516 m
.97619 .08532 L
.97619 .10446 L
.97619 .11473 L
.97619 .10516 L
F
.97619 .08532 m
.97619 .06548 L
.97619 .09419 L
.97619 .10446 L
.97619 .08532 L
F
.97619 .125 m
.97619 .11473 L
.97619 .125 L
.97619 .125 L
.97619 .125 L
F
.97619 .11473 m
.97619 .10446 L
.97619 .125 L
.97619 .125 L
.97619 .11473 L
F
.97619 .10446 m
.97619 .09419 L
.97619 .125 L
.97619 .125 L
.97619 .10446 L
F
.97619 .125 m
.97619 .125 L
.97619 .13527 L
.97619 .125 L
.97619 .125 L
F
.97619 .125 m
.97619 .125 L
.97619 .14554 L
.97619 .13527 L
.97619 .125 L
F
.97619 .125 m
.97619 .125 L
.97619 .15581 L
.97619 .14554 L
.97619 .125 L
F
.97619 .125 m
.97619 .13527 L
.97619 .14484 L
.97619 .125 L
.97619 .125 L
F
.97619 .13527 m
.97619 .14554 L
.97619 .16468 L
.97619 .14484 L
.97619 .13527 L
F
.97619 .14554 m
.97619 .15581 L
.97619 .18452 L
.97619 .16468 L
.97619 .14554 L
F
.97619 .125 m
.97619 .14484 L
.97619 .15306 L
.97619 .125 L
.97619 .125 L
F
.97619 .14484 m
.97619 .16468 L
.97619 .18112 L
.97619 .15306 L
.97619 .14484 L
F
.97619 .16468 m
.97619 .18452 L
.97619 .20918 L
.97619 .18112 L
.97619 .16468 L
F
.97619 .125 m
.97619 .15306 L
.97619 .15937 L
.97619 .125 L
.97619 .125 L
F
.97619 .15306 m
.97619 .18112 L
.97619 .19373 L
.97619 .15937 L
.97619 .15306 L
F
.97619 .18112 m
.97619 .20918 L
.97619 .2281 L
.97619 .19373 L
.97619 .18112 L
F
.97619 .125 m
.97619 .15937 L
.97619 .16333 L
.97619 .125 L
.97619 .125 L
F
.97619 .15937 m
.97619 .19373 L
.97619 .20166 L
.97619 .16333 L
.97619 .15937 L
F
.97619 .19373 m
.97619 .2281 L
.97619 .23999 L
.97619 .20166 L
.97619 .19373 L
F
.97619 .125 m
.97619 .16333 L
.97619 .16468 L
.97619 .125 L
.97619 .125 L
F
.97619 .16333 m
.97619 .20166 L
.97619 .20437 L
.97619 .16468 L
.97619 .16333 L
F
.97619 .20166 m
.97619 .23999 L
.97619 .24405 L
.97619 .20437 L
.97619 .20166 L
F
0 g
.97619 .24405 m
.97619 .23999 L
.97619 .2281 L
.97619 .20918 L
.97619 .18452 L
.97619 .15581 L
.97619 .125 L
.97619 .09419 L
.97619 .06548 L
.97619 .04082 L
.97619 .0219 L
.97619 .01001 L
.97619 .00595 L
.97619 .01001 L
.97619 .0219 L
.97619 .04082 L
.97619 .06548 L
.97619 .09419 L
.97619 .125 L
.97619 .15581 L
.97619 .18452 L
.97619 .20918 L
.97619 .2281 L
.97619 .23999 L
.97619 .24405 L
s
.039 .916 .04 r
.02381 .01786 m
.51221 .01786 L
s
0 0 0 r
2.5 Mabswid
.51221 .01786 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .06071 m
.50436 .06071 L
s
0 0 0 r
2.5 Mabswid
.50436 .06071 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .10357 m
.50048 .10357 L
s
0 0 0 r
2.5 Mabswid
.50048 .10357 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14643 m
.50048 .14643 L
s
0 0 0 r
2.5 Mabswid
.50048 .14643 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18929 m
.50436 .18929 L
s
0 0 0 r
2.5 Mabswid
.50436 .18929 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23214 m
.51221 .23214 L
s
0 0 0 r
2.5 Mabswid
.51221 .23214 Mdot
.039 .916 .04 r
.5 Mabswid
.51221 .01786 m
.53583 .01971 L
s
0 0 0 r
2.5 Mabswid
.53583 .01971 Mdot
.039 .916 .04 r
.5 Mabswid
.50436 .06071 m
.5435 .06253 L
s
0 0 0 r
2.5 Mabswid
.5435 .06253 Mdot
.039 .916 .04 r
.5 Mabswid
.50048 .10357 m
.54717 .10429 L
s
0 0 0 r
2.5 Mabswid
.54717 .10429 Mdot
.039 .916 .04 r
.5 Mabswid
.50048 .14643 m
.54717 .14571 L
s
0 0 0 r
2.5 Mabswid
.54717 .14571 Mdot
.039 .916 .04 r
.5 Mabswid
.50436 .18929 m
.5435 .18747 L
s
0 0 0 r
2.5 Mabswid
.5435 .18747 Mdot
.039 .916 .04 r
.5 Mabswid
.51221 .23214 m
.53583 .23029 L
s
0 0 0 r
2.5 Mabswid
.53583 .23029 Mdot
.039 .916 .04 r
.5 Mabswid
.53583 .01971 m
.97619 .12962 L
s
0 0 0 r
2.5 Mabswid
.97619 .12962 Mdot
.039 .916 .04 r
.5 Mabswid
.5435 .06253 m
.97619 .12383 L
s
0 0 0 r
2.5 Mabswid
.97619 .12383 Mdot
.039 .916 .04 r
.5 Mabswid
.54717 .10429 m
.97619 .12405 L
s
0 0 0 r
2.5 Mabswid
.97619 .12405 Mdot
.039 .916 .04 r
.5 Mabswid
.54717 .14571 m
.97619 .12595 L
s
0 0 0 r
2.5 Mabswid
.97619 .12595 Mdot
.039 .916 .04 r
.5 Mabswid
.5435 .18747 m
.97619 .12617 L
s
0 0 0 r
2.5 Mabswid
.97619 .12617 Mdot
.039 .916 .04 r
.5 Mabswid
.53583 .23029 m
.97619 .12038 L
s
0 0 0 r
2.5 Mabswid
.97619 .12038 Mdot
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->True,
  ImageSize->{500.625, 125.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000OB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3ooooe0?ooo`00o`3ooooe0?ooo`00o`3oool20?ooo`T00000g03oool00`000000oooo
0?ooo`0;0?ooo`00o`3oool20?ooo`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0fP3o
ool00`000000oooo0?ooo`0;0?ooo`00o`3oool20?ooo`T00000g03oool00`000000oooo0?ooo`0;
0?ooo`00o`3oool10?ooo`8000001`1oOgl200000=/0oooo00<000000?ooo`3oool02`3oool00?l0
oooo0@3oool2000000L0Ogmo0P00003K0?ooo`030000003oool0oooo00/0oooo003o0?ooo`40oooo
0P00000707moO`800000f`3oool00`000000oooo0?ooo`0;0?ooo`003@3ooooi00WZ2P<0Ogmo0P00
003K0?ooo`030000003oool0oooo00/0oooo003o0?ooo`<00000101oOgl400WZ2P0400000009jPX0
2NX:00WZ2]P0oooo00<000000?ooo`3oool02`3oool00?l0oooo00<0000007moO`0000002P000002
0?ooo`@02NX:e03oool00`000000oooo0?ooo`0;0?ooo`00o`3oool00`000000Ogmo0000000707mo
O`030000001oOgl0000000H0oooo1009jP[@0?ooo`030000003oool0oooo00/0oooo003o0?ooo`03
0000001oOgl0000000L0Ogmo00<0000007moO`0000002P3oool400WZ2/`0oooo00<000000?ooo`3o
ool02`3oool00?l0oooo00<0000007moO`0000001`1oOgl010000000Ogmo07moO`00000=0?ooo`@0
2NX:b03oool00`000000oooo0?ooo`0;0?ooo`00o`3oool00`000000Ogmo0000000707moO`040000
001oOgl0Ogmo00000140oooo1009jP[40?ooo`030000003oool0oooo00/0oooo003n0?ooo`040000
001oOgl0Ogmo000000L0Ogmo00@0000007moO`1oOgl000005@3oool400WZ2/00oooo00<000000?oo
o`3oool02`3oool00?h0oooo00@0000007moO`1oOgl000001`1oOgl010000000Ogmo07moO`00000I
0?ooo`@02NX:_03oool00`000000oooo0?ooo`0;0?ooo`00oP3oool010000000Ogmo07moO`000007
07moO`050000001oOgl0Ogmo07moO`000000703oool400WZ2[P0oooo00<000000?ooo`3oool02`3o
ool00?h0oooo00@0000007moO`1oOgl000001`1oOgl01@000000Ogmo07moO`1oOgl000000200oooo
1009jPZd0?ooo`030000003oool0oooo00/0oooo003n0?ooo`040000001oOgl0Ogmo000000L0Ogmo
00D0000007moO`1oOgl0Ogmo0000000T0?ooo`@02NX:/03oool00`000000oooo0?ooo`0;0?ooo`00
o@3oool010000000Ogmo07moO`1oOgl9000000<0Ogmo00<000000?ooo`3oool09P3oool400WZ2Z`0
oooo00<000000?ooo`3oool02`3oool00?d0oooo00D0000007moO`1oOgl0Ogmo0000000707moO`03
0000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0:@3oool400WZ2ZP0oooo00<000000?ooo`3o
ool02`3oool00?d0oooo00D0000007moO`1oOgl0Ogmo0000000707moO`030000001oOgl0Ogmo0080
Ogmo00<000000?ooo`3oool0;@3oool400WZ2Z@0oooo00<000000?ooo`3oool02`3oool00?d0oooo
00D0000007moO`1oOgl0Ogmo0000000707moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3o
ool0<@3oool400WZ2Z00oooo00<000000?ooo`3oool02`3oool00?d0oooo00D0000007moO`1oOgl0
Ogmo0000000707moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0=@3oool400WZ2Y`0
oooo00<000000?ooo`3oool02`3oool00?d0oooo00D0000007moO`1oOgl0Ogmo0000000707moO`03
0000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0>@3oool400WZ2YP0oooo00<000000?ooo`3o
ool02`3oool00?`0oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0507moO`030000
001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0?@3oool400WZ2Y@0oooo00<000000?ooo`3oool0
2`3oool00?`0oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0507moO`030000001o
Ogl0Ogmo0080Ogmo00<000000?ooo`3oool0@@3oool400WZ2Y00oooo00<000000?ooo`3oool02`3o
ool00?`0oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0A03oool400WZ2X`0oooo00<000000?ooo`3oool02`3oool0
0?/0oooo0P00000407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`180?ooo`@02NX:R03oool00`000000oooo0?ooo`0;0?ooo`003@3ooooo00WZ2P80
2NX:00<0000000WZ2P09jPX00P09jPY;0?ooo`@02NX:Q03oool00`000000oooo0?ooo`0;0?ooo`00
o03oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0
0P1oOgl2000000<0oooo1`09jPY80?ooo`@02NX:P03oool00`000000oooo0?ooo`0;0?ooo`00o03o
ool00`000000Ogmo07moO`0207moO`T000001@1oOgl00`000000oooo0?ooo`080?ooo`L02NX:A@3o
ool400WZ2W`0oooo00<000000?ooo`3oool02`3oool00?/0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool03`3oool7
00WZ2T80oooo1009jPYh0?ooo`030000003oool0oooo00/0oooo003k0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
01H0oooo1`09jPXo0?ooo`@02NX:M03oool00`000000oooo0?ooo`0;0?ooo`00n`3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0M0?ooo`L02NX:?03oool400WZ2W00oooo00<000000?ooo`3oool02`3oool00?/0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0903oool700WZ2ST0oooo1009jPY/0?ooo`030000003oool0oooo00/0oooo
003k0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo02/0oooo1`09jPXf0?ooo`<02NX:J@3oool00`000000oooo0?oo
o`0;0?ooo`00n`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00D0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`0a0?ooo`L02NX:<P3oool400WZ2VD0oooo00<00000
0?ooo`3oool02`3oool00?/0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0507mo
O`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0>03oool700WZ2Rl0oooo1009jPYQ0?oo
o`030000003oool0oooo00/0oooo003j0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl01@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03l0oooo1`09jPX/0?ooo`@0
2NX:G@3oool00`000000oooo0?ooo`0;0?ooo`00nP3oool00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`160?ooo`L02NX:
:@3oool400WZ2UT0oooo00<000000?ooo`3oool02`3oool00?X0oooo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0C@3o
ool700WZ2RH0oooo1009jPYE0?ooo`030000003oool0oooo00/0oooo003j0?ooo`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0
oooo05@0oooo1`09jPXS0?ooo`@02NX:D@3oool00`000000oooo0?ooo`0;0?ooo`00nP3oool00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000oooo0?ooo`1K0?ooo`L02NX:803oool400WZ2Td0oooo00<000000?ooo`3oool02`3oool00?X0
oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0
Ogmo00<000000?ooo`3oool0HP3oool700WZ2Qd0oooo1009jPY90?ooo`030000003oool0oooo00/0
oooo003j0?ooo`030000001oOgl0Ogmo00@0Ogmo2@00000607moO`030000003oool0oooo06T0oooo
1P09jPXK0?ooo`@02NX:A@3oool00`000000oooo0?ooo`0;0?ooo`00nP3oool00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?oo
o`1_0?ooo`L02NX:603oool400WZ2T40oooo00<000000?ooo`3oool02`3oool00?X0oooo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<00000
0?ooo`3oool0MP3oool700WZ2QD0oooo1009jPXm0?ooo`030000003oool0oooo00/0oooo003j0?oo
o`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407mo
O`030000003oool0oooo07d0oooo1`09jPXB0?ooo`@02NX:>@3oool00`000000oooo0?ooo`0;0?oo
o`00nP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000oooo0?ooo`240?ooo`L02NX:3`3oool400WZ2SD0oooo00<000000?ooo`3o
ool02`3oool000d0ooook009jPX00`0000002NX:00WZ2P0D00WZ2P0300000009jPX02NX:00X02NX:
P@3oool700WZ2P`0oooo1009jPXa0?ooo`030000003oool0oooo00/0oooo003i0?ooo`8000001P1o
Ogl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo0P00000;0?oooaD02NX:L`3o
ool700WZ2PT0oooo1009jPX]0?ooo`030000003oool0oooo00/0oooo003i0?ooo`030000001oOgl0
Ogmo00D0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0507moO`030000003oool0
oooo01h0oooo5@09jPYU0?ooo`L02NX:1P3oool400WZ2RT0oooo00<000000?ooo`3oool02`3oool0
0?T0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo
00D0Ogmo00<000000?ooo`3oool0<`3ooolF00WZ2UH0oooo1`09jPX30?ooo`@02NX:9@3oool00`00
0000oooo0?ooo`0;0?ooo`00n@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00D0
Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`190?oooaD02NX:B03oool;00WZ2R40
oooo00<000000?ooo`3oool02`3oool00?T0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo
07moO`0507moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0GP3ooolE00WZ2SX0oooo
2009jPXM0?ooo`030000003oool0oooo00/0oooo003i0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0
000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo07<0oooo5@09
jPX/0?ooo`L02NX:5`3oool00`000000oooo0?ooo`0;0?ooo`00n@3oool00`000000Ogmo07moO`05
07moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`28
0?oooaH02NX:6`3oool900WZ2Q00oooo00<000000?ooo`3oool02`3oool00?T0oooo00<0000007mo
O`1oOgl01@1oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00D0Ogmo00<000000?oo
o`3oool0WP3ooolE00WZ2PX0oooo1009jPX00`3oool02NX:00WZ2P0500WZ2PL0oooo00<02NX:0000
000000003@3oool00?T0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0507moO`03
0000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0/`3ooolE00WZ2P030?ooo`09jPX02NX:00D0
2NX:00<0oooo0000000000003@3oool00?T0oooo6@0000370?ooo``02NX:0P00000=0?ooo`00n@3o
ool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl01@1o
Ogl00`000000oooo0?ooo`340?ooo`d02NX:0P00000=0?ooo`00n@3oool00`000000Ogmo07moO`05
07moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`2b
0?oooal02NX:0P00000=0?ooo`00n@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo
00D0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`2M0?oooaD02NX:2P3oool;00WZ
2PX0oooo0P00000=0?ooo`00n@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00D0
Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`270?oooaH02NX:6`3oool800WZ2Q80
oooo00<000000?ooo`3oool02`3oool00?T0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo
07moO`0507moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0LP3ooolE00WZ2R/0oooo
1`09jPXI0?ooo`030000003oool0oooo00/0oooo003i0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0
000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo05d0oooo5@09
jPXi0?ooo`T02NX:7P3oool00`000000oooo0?ooo`0;0?ooo`00n@3oool00`000000Ogmo07moO`05
07moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`18
0?oooaD02NX:AP3oool800WZ2P030?ooo`09jPX02NX:00802NX:8P3oool00`000000oooo0?ooo`0;
0?ooo`00n@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00D0Ogmo00<0000007mo
O`1oOgl01@1oOgl00`000000oooo0?ooo`0b0?oooaH02NX:E03oool700WZ2PD0oooo1009jPXV0?oo
o`030000003oool0oooo00/0oooo003i0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl01@1oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo01d0oooo5@09jPYS0?ooo`L0
2NX:203oool400WZ2RX0oooo00<000000?ooo`3oool02`3oool00?T0oooo00<0000007moO`1oOgl0
1@1oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo0P00000:0?oooaD02NX:
L@3oool700WZ2P/0oooo1009jPX^0?ooo`030000003oool0oooo00/0oooo000=0?ooon`02NX:00<0
000000WZ2P09jPX05009jPX00`0000002NX:00WZ2P0900WZ2Wl0oooo1`09jPX>0?ooo`@02NX:<P3o
ool00`000000oooo0?ooo`0;0?ooo`00n@3oool2000000H0Ogmo00<0000007moO`1oOgl01@1oOgl0
0`000000Ogmo07moO`0407moO`030000003oool0oooo0840oooo1`09jPXA0?ooo`@02NX:=P3oool0
0`000000oooo0?ooo`0;0?ooo`00nP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1i0?ooo`P02NX:503oool400WZ
2SX0oooo00<000000?ooo`3oool02`3oool00?X0oooo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0LP3oool700WZ2QP0
oooo1009jPXn0?ooo`030000003oool0oooo00/0oooo003j0?ooo`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo06/0oooo
1`09jPXK0?ooo`@02NX:@P3oool00`000000oooo0?ooo`0;0?ooo`00nP3oool00`000000Ogmo07mo
O`0407moO`T000001P1oOgl00`000000oooo0?ooo`1T0?ooo`L02NX:7P3oool400WZ2TH0oooo00<0
00000?ooo`3oool02`3oool00?X0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`05
07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0G@3oool700WZ2R40oooo1009jPY:
0?ooo`030000003oool0oooo00/0oooo003j0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo05H0oooo1`09jPXT0?oo
o`@02NX:CP3oool00`000000oooo0?ooo`0;0?ooo`00nP3oool00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1>0?ooo`P0
2NX:9`3oool400WZ2U80oooo00<000000?ooo`3oool02`3oool00?X0oooo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
A`3oool700WZ2R/0oooo1009jPYF0?ooo`030000003oool0oooo00/0oooo003j0?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000003o
ool0oooo0400oooo1`09jPX^0?ooo`@02NX:FP3oool00`000000oooo0?ooo`0;0?ooo`00nP3oool0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000oooo0?ooo`0i0?ooo`L02NX:<@3oool400WZ2Uh0oooo00<000000?ooo`3oool02`3oool0
0?X0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo
00@0Ogmo00<000000?ooo`3oool0<P3oool700WZ2S@0oooo1009jPYR0?ooo`030000003oool0oooo
00/0oooo003k0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000
Ogmo07moO`0407moO`030000003oool0oooo02/0oooo1`09jPXg0?ooo`@02NX:IP3oool00`000000
oooo0?ooo`0;0?ooo`00n`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00D0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0S0?ooo`P02NX:>P3oool400WZ2VX0oooo
00<000000?ooo`3oool02`3oool00?/0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0507moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool07@3oool700WZ2Sl0oooo0`09
jPY^0?ooo`030000003oool0oooo00/0oooo003k0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl01@1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo01H0oooo1`09jPY2
0?ooo`@02NX:L@3oool00`000000oooo0?ooo`0;0?ooo`00n`3oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0?0?oo
o`L02NX:A@3oool400WZ2WD0oooo00<000000?ooo`3oool02`3oool00?/0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0203oool700WZ2TP0oooo1009jPYi0?ooo`030000003oool0oooo00/0oooo003k0?ooo`030000
001oOgl0Ogmo00<0Ogmo2@00000507moO`040000003oool0oooo0?ooo`L02NX:B`3oool400WZ2Wd0
oooo00<000000?ooo`3oool02`3oool00?`0oooo00<0000007moO`1oOgl00P1oOgl010000000Ogmo
07moO`1oOgl900WZ2P0300000009jPX02NX:00802NX:CP3oool400WZ2X40oooo00<000000?ooo`3o
ool02`3oool000d0oooon009jPX407moO`030000001oOgl0Ogmo0080Ogmo0P00001=0?ooo`@02NX:
Q@3oool00`000000oooo0?ooo`0;0?ooo`00n`3oool2000000@0Ogmo00<0000007moO`1oOgl01@1o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo04L0oooo1009jPZ90?ooo`030000003o
ool0oooo00/0oooo003l0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl01@1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo04<0oooo1009jPZ=0?ooo`030000003oool0
oooo00/0oooo003l0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl01@1oOgl00`00
0000Ogmo07moO`0307moO`030000003oool0oooo03l0oooo1009jPZA0?ooo`030000003oool0oooo
00/0oooo003l0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl01@1oOgl00`000000
Ogmo07moO`0207moO`030000003oool0oooo03`0oooo1009jPZE0?ooo`030000003oool0oooo00/0
oooo003l0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo
07moO`0207moO`030000003oool0oooo03P0oooo1009jPZI0?ooo`030000003oool0oooo00/0oooo
003m0?ooo`050000001oOgl0Ogmo07moO`0000001`1oOgl00`000000Ogmo07moO`0207moO`030000
003oool0oooo03@0oooo1009jPZM0?ooo`030000003oool0oooo00/0oooo003m0?ooo`050000001o
Ogl0Ogmo07moO`0000001`1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo0300oooo
1009jPZQ0?ooo`030000003oool0oooo00/0oooo003m0?ooo`050000001oOgl0Ogmo07moO`000000
1`1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo02`0oooo1009jPZU0?ooo`030000
003oool0oooo00/0oooo003m0?ooo`050000001oOgl0Ogmo07moO`0000001`1oOgl00`000000Ogmo
07moO`0207moO`030000003oool0oooo02P0oooo1009jPZY0?ooo`030000003oool0oooo00/0oooo
003m0?ooo`040000001oOgl0Ogmo07moO`T00000101oOgl00`000000oooo0?ooo`0T0?ooo`@02NX:
[@3oool00`000000oooo0?ooo`0;0?ooo`00oP3oool010000000Ogmo07moO`00000707moO`050000
001oOgl0Ogmo07moO`0000008`3oool400WZ2[40oooo00<000000?ooo`3oool02`3oool00?h0oooo
00@0000007moO`1oOgl000001`1oOgl01@000000Ogmo07moO`1oOgl0000001l0oooo1009jPZe0?oo
o`030000003oool0oooo00/0oooo003n0?ooo`040000001oOgl0Ogmo000000L0Ogmo00D0000007mo
O`1oOgl0Ogmo0000000K0?ooo`@02NX:^@3oool00`000000oooo0?ooo`0;0?ooo`00oP3oool01000
0000Ogmo07moO`00000707moO`050000001oOgl0Ogmo07moO`0000005`3oool400WZ2[d0oooo00<0
00000?ooo`3oool02`3oool00?h0oooo00@0000007moO`1oOgl000001`1oOgl010000000Ogmo07mo
O`00000D0?ooo`@02NX:`@3oool00`000000oooo0?ooo`0;0?ooo`00o`3oool00`000000Ogmo0000
000707moO`040000001oOgl0Ogmo00000100oooo1009jP[50?ooo`030000003oool0oooo00/0oooo
003o0?ooo`030000001oOgl0000000L0Ogmo00@0000007moO`1oOgl00000303oool400WZ2/T0oooo
00<000000?ooo`3oool02`3oool00?l0oooo00<0000007moO`0000001`1oOgl010000000Ogmo07mo
O`0000080?ooo`@02NX:c@3oool00`000000oooo0?ooo`0;0?ooo`00o`3oool00`000000Ogmo0000
000707moO`030000001oOgl0000000D0oooo1009jP[A0?ooo`030000003oool0oooo00/0oooo003o
0?ooo`030000001oOgl0000000X0000000<0oooo00WZ2P09jPX00P09jP[E0?ooo`030000003oool0
oooo00/0oooo003o0?ooo`<000000`1oOgl500WZ2P0300000009jPX02NX:0=T0oooo00<000000?oo
o`3oool02`3oool000d0oooon009jPX407moO`030000001oOgl000000=X0oooo00<000000?ooo`3o
ool02`3oool00?l0oooo0@3oool2000000L0Ogmo0P00003K0?ooo`030000003oool0oooo00/0oooo
003o0?ooo`40oooo0P00000707moO`800000f`3oool00`000000oooo0?ooo`0;0?ooo`00o`3oool1
0?ooo`8000001`1oOgl200000=/0oooo00<000000?ooo`3oool02`3oool00?l0oooo0P3oool:0000
0=/0oooo00<000000?ooo`3oool02`3oool00?l0oooo0P3oool00`000000Ogmo07moO`0507moO`03
0000003oool0oooo0=X0oooo00<000000?ooo`3oool02`3oool00?l0oooo0P3oool900000=`0oooo
00<000000?ooo`3oool02`3oool00?l0oooom@3oool00?l0oooom@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499.625}, {124.125, 0}} -> {-5.66193, -26.2503, \
0.422965, 0.422965}},
  CellTags->"Lens Optimizations"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Timing[soln = OptimizeSystem[sys]]", "Input",
  CellTags->"Lens Optimizations"],

Cell[BoxData[
    \({29.183333333333394`\ Second, {SymbolicValues \[Rule] {r1 \[Rule] 
              59.39960503300152`, r2 \[Rule] \(-392.864214516093`\)}, 
        NumberOfCycles \[Rule] 828, 
        FinalMerit \[Rule] 0.4199628268520226`}}\)], "Output",
  CellTags->"Lens Optimizations"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboPlot[turbosys, PlotType->TopView, soln];", "Input",
  CellTags->"Lens Optimizations"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.125 0.0047619 [
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.52627 .00595 m
.54383 .00595 L
.54593 .04563 L
.51136 .04563 L
.52627 .00595 L
F
.51136 .04563 m
.54593 .04563 L
.5472 .08532 L
.5028 .08532 L
.51136 .04563 L
F
.5028 .08532 m
.5472 .08532 L
.54762 .125 L
.5 .125 L
.5028 .08532 L
F
.5 .125 m
.54762 .125 L
.5472 .16468 L
.5028 .16468 L
.5 .125 L
F
.5028 .16468 m
.5472 .16468 L
.54593 .20437 L
.51136 .20437 L
.5028 .16468 L
F
.51136 .20437 m
.54593 .20437 L
.54383 .24405 L
.52627 .24405 L
.51136 .20437 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.52627 .00595 m
.51136 .04563 L
.5028 .08532 L
.5 .125 L
.5028 .16468 L
.51136 .20437 L
.52627 .24405 L
.54383 .24405 L
.54593 .20437 L
.5472 .16468 L
.54762 .125 L
.5472 .08532 L
.54593 .04563 L
.54383 .00595 L
.52627 .00595 L
s
.5 g
.52627 .125 m
.54383 .125 L
.54593 .125 L
.51136 .125 L
.52627 .125 L
F
.51136 .125 m
.54593 .125 L
.5472 .125 L
.5028 .125 L
.51136 .125 L
F
.5028 .125 m
.5472 .125 L
.54762 .125 L
.5 .125 L
.5028 .125 L
F
.5 .125 m
.54762 .125 L
.5472 .125 L
.5028 .125 L
.5 .125 L
F
.5028 .125 m
.5472 .125 L
.54593 .125 L
.51136 .125 L
.5028 .125 L
F
.51136 .125 m
.54593 .125 L
.54383 .125 L
.52627 .125 L
.51136 .125 L
F
0 g
.52627 .125 m
.51136 .125 L
.5028 .125 L
.5 .125 L
.5028 .125 L
.51136 .125 L
.52627 .125 L
.54383 .125 L
.54593 .125 L
.5472 .125 L
.54762 .125 L
.5472 .125 L
.54593 .125 L
.54383 .125 L
.52627 .125 L
s
.52627 .24405 m
.54383 .24405 L
.54383 .23999 L
.52627 .23999 L
.52627 .24405 L
s
.52627 .23999 m
.54383 .23999 L
.54383 .2281 L
.52627 .2281 L
.52627 .23999 L
s
.52627 .2281 m
.54383 .2281 L
.54383 .20918 L
.52627 .20918 L
.52627 .2281 L
s
.52627 .20918 m
.54383 .20918 L
.54383 .18452 L
.52627 .18452 L
.52627 .20918 L
s
.52627 .18452 m
.54383 .18452 L
.54383 .15581 L
.52627 .15581 L
.52627 .18452 L
s
.52627 .15581 m
.54383 .15581 L
.54383 .125 L
.52627 .125 L
.52627 .15581 L
s
.52627 .125 m
.54383 .125 L
.54383 .09419 L
.52627 .09419 L
.52627 .125 L
s
.52627 .09419 m
.54383 .09419 L
.54383 .06548 L
.52627 .06548 L
.52627 .09419 L
s
.52627 .06548 m
.54383 .06548 L
.54383 .04082 L
.52627 .04082 L
.52627 .06548 L
s
.52627 .04082 m
.54383 .04082 L
.54383 .0219 L
.52627 .0219 L
.52627 .04082 L
s
.52627 .0219 m
.54383 .0219 L
.54383 .01001 L
.52627 .01001 L
.52627 .0219 L
s
.52627 .01001 m
.54383 .01001 L
.54383 .00595 L
.52627 .00595 L
.52627 .01001 L
s
.52627 .00595 m
.54383 .00595 L
.54383 .01001 L
.52627 .01001 L
.52627 .00595 L
s
.52627 .01001 m
.54383 .01001 L
.54383 .0219 L
.52627 .0219 L
.52627 .01001 L
s
.52627 .0219 m
.54383 .0219 L
.54383 .04082 L
.52627 .04082 L
.52627 .0219 L
s
.52627 .04082 m
.54383 .04082 L
.54383 .06548 L
.52627 .06548 L
.52627 .04082 L
s
.52627 .06548 m
.54383 .06548 L
.54383 .09419 L
.52627 .09419 L
.52627 .06548 L
s
.52627 .09419 m
.54383 .09419 L
.54383 .125 L
.52627 .125 L
.52627 .09419 L
s
.52627 .125 m
.54383 .125 L
.54383 .15581 L
.52627 .15581 L
.52627 .125 L
s
.52627 .15581 m
.54383 .15581 L
.54383 .18452 L
.52627 .18452 L
.52627 .15581 L
s
.52627 .18452 m
.54383 .18452 L
.54383 .20918 L
.52627 .20918 L
.52627 .18452 L
s
.52627 .20918 m
.54383 .20918 L
.54383 .2281 L
.52627 .2281 L
.52627 .20918 L
s
.52627 .2281 m
.54383 .2281 L
.54383 .23999 L
.52627 .23999 L
.52627 .2281 L
s
.52627 .23999 m
.54383 .23999 L
.54383 .24405 L
.52627 .24405 L
.52627 .23999 L
s
.5 g
.97619 .125 m
.97619 .16468 L
.97619 .16333 L
.97619 .125 L
.97619 .125 L
F
.97619 .16468 m
.97619 .20437 L
.97619 .20166 L
.97619 .16333 L
.97619 .16468 L
F
.97619 .20437 m
.97619 .24405 L
.97619 .23999 L
.97619 .20166 L
.97619 .20437 L
F
.97619 .125 m
.97619 .16333 L
.97619 .15937 L
.97619 .125 L
.97619 .125 L
F
.97619 .16333 m
.97619 .20166 L
.97619 .19373 L
.97619 .15937 L
.97619 .16333 L
F
.97619 .20166 m
.97619 .23999 L
.97619 .2281 L
.97619 .19373 L
.97619 .20166 L
F
.97619 .125 m
.97619 .15937 L
.97619 .15306 L
.97619 .125 L
.97619 .125 L
F
.97619 .15937 m
.97619 .19373 L
.97619 .18112 L
.97619 .15306 L
.97619 .15937 L
F
.97619 .19373 m
.97619 .2281 L
.97619 .20918 L
.97619 .18112 L
.97619 .19373 L
F
.97619 .125 m
.97619 .15306 L
.97619 .14484 L
.97619 .125 L
.97619 .125 L
F
.97619 .15306 m
.97619 .18112 L
.97619 .16468 L
.97619 .14484 L
.97619 .15306 L
F
.97619 .18112 m
.97619 .20918 L
.97619 .18452 L
.97619 .16468 L
.97619 .18112 L
F
.97619 .125 m
.97619 .14484 L
.97619 .13527 L
.97619 .125 L
.97619 .125 L
F
.97619 .14484 m
.97619 .16468 L
.97619 .14554 L
.97619 .13527 L
.97619 .14484 L
F
.97619 .16468 m
.97619 .18452 L
.97619 .15581 L
.97619 .14554 L
.97619 .16468 L
F
.97619 .125 m
.97619 .13527 L
.97619 .125 L
.97619 .125 L
.97619 .125 L
F
.97619 .13527 m
.97619 .14554 L
.97619 .125 L
.97619 .125 L
.97619 .13527 L
F
.97619 .14554 m
.97619 .15581 L
.97619 .125 L
.97619 .125 L
.97619 .14554 L
F
.97619 .125 m
.97619 .125 L
.97619 .11473 L
.97619 .125 L
.97619 .125 L
F
.97619 .125 m
.97619 .125 L
.97619 .10446 L
.97619 .11473 L
.97619 .125 L
F
.97619 .125 m
.97619 .125 L
.97619 .09419 L
.97619 .10446 L
.97619 .125 L
F
.97619 .125 m
.97619 .11473 L
.97619 .10516 L
.97619 .125 L
.97619 .125 L
F
.97619 .11473 m
.97619 .10446 L
.97619 .08532 L
.97619 .10516 L
.97619 .11473 L
F
.97619 .10446 m
.97619 .09419 L
.97619 .06548 L
.97619 .08532 L
.97619 .10446 L
F
.97619 .125 m
.97619 .10516 L
.97619 .09694 L
.97619 .125 L
.97619 .125 L
F
.97619 .10516 m
.97619 .08532 L
.97619 .06888 L
.97619 .09694 L
.97619 .10516 L
F
.97619 .08532 m
.97619 .06548 L
.97619 .04082 L
.97619 .06888 L
.97619 .08532 L
F
.97619 .125 m
.97619 .09694 L
.97619 .09063 L
.97619 .125 L
.97619 .125 L
F
.97619 .09694 m
.97619 .06888 L
.97619 .05627 L
.97619 .09063 L
.97619 .09694 L
F
.97619 .06888 m
.97619 .04082 L
.97619 .0219 L
.97619 .05627 L
.97619 .06888 L
F
.97619 .125 m
.97619 .09063 L
.97619 .08667 L
.97619 .125 L
.97619 .125 L
F
.97619 .09063 m
.97619 .05627 L
.97619 .04834 L
.97619 .08667 L
.97619 .09063 L
F
.97619 .05627 m
.97619 .0219 L
.97619 .01001 L
.97619 .04834 L
.97619 .05627 L
F
.97619 .125 m
.97619 .08667 L
.97619 .08532 L
.97619 .125 L
.97619 .125 L
F
.97619 .08667 m
.97619 .04834 L
.97619 .04563 L
.97619 .08532 L
.97619 .08667 L
F
.97619 .04834 m
.97619 .01001 L
.97619 .00595 L
.97619 .04563 L
.97619 .04834 L
F
.97619 .125 m
.97619 .08532 L
.97619 .08667 L
.97619 .125 L
.97619 .125 L
F
.97619 .08532 m
.97619 .04563 L
.97619 .04834 L
.97619 .08667 L
.97619 .08532 L
F
.97619 .04563 m
.97619 .00595 L
.97619 .01001 L
.97619 .04834 L
.97619 .04563 L
F
.97619 .125 m
.97619 .08667 L
.97619 .09063 L
.97619 .125 L
.97619 .125 L
F
.97619 .08667 m
.97619 .04834 L
.97619 .05627 L
.97619 .09063 L
.97619 .08667 L
F
.97619 .04834 m
.97619 .01001 L
.97619 .0219 L
.97619 .05627 L
.97619 .04834 L
F
.97619 .125 m
.97619 .09063 L
.97619 .09694 L
.97619 .125 L
.97619 .125 L
F
.97619 .09063 m
.97619 .05627 L
.97619 .06888 L
.97619 .09694 L
.97619 .09063 L
F
.97619 .05627 m
.97619 .0219 L
.97619 .04082 L
.97619 .06888 L
.97619 .05627 L
F
.97619 .125 m
.97619 .09694 L
.97619 .10516 L
.97619 .125 L
.97619 .125 L
F
.97619 .09694 m
.97619 .06888 L
.97619 .08532 L
.97619 .10516 L
.97619 .09694 L
F
.97619 .06888 m
.97619 .04082 L
.97619 .06548 L
.97619 .08532 L
.97619 .06888 L
F
.97619 .125 m
.97619 .10516 L
.97619 .11473 L
.97619 .125 L
.97619 .125 L
F
.97619 .10516 m
.97619 .08532 L
.97619 .10446 L
.97619 .11473 L
.97619 .10516 L
F
.97619 .08532 m
.97619 .06548 L
.97619 .09419 L
.97619 .10446 L
.97619 .08532 L
F
.97619 .125 m
.97619 .11473 L
.97619 .125 L
.97619 .125 L
.97619 .125 L
F
.97619 .11473 m
.97619 .10446 L
.97619 .125 L
.97619 .125 L
.97619 .11473 L
F
.97619 .10446 m
.97619 .09419 L
.97619 .125 L
.97619 .125 L
.97619 .10446 L
F
.97619 .125 m
.97619 .125 L
.97619 .13527 L
.97619 .125 L
.97619 .125 L
F
.97619 .125 m
.97619 .125 L
.97619 .14554 L
.97619 .13527 L
.97619 .125 L
F
.97619 .125 m
.97619 .125 L
.97619 .15581 L
.97619 .14554 L
.97619 .125 L
F
.97619 .125 m
.97619 .13527 L
.97619 .14484 L
.97619 .125 L
.97619 .125 L
F
.97619 .13527 m
.97619 .14554 L
.97619 .16468 L
.97619 .14484 L
.97619 .13527 L
F
.97619 .14554 m
.97619 .15581 L
.97619 .18452 L
.97619 .16468 L
.97619 .14554 L
F
.97619 .125 m
.97619 .14484 L
.97619 .15306 L
.97619 .125 L
.97619 .125 L
F
.97619 .14484 m
.97619 .16468 L
.97619 .18112 L
.97619 .15306 L
.97619 .14484 L
F
.97619 .16468 m
.97619 .18452 L
.97619 .20918 L
.97619 .18112 L
.97619 .16468 L
F
.97619 .125 m
.97619 .15306 L
.97619 .15937 L
.97619 .125 L
.97619 .125 L
F
.97619 .15306 m
.97619 .18112 L
.97619 .19373 L
.97619 .15937 L
.97619 .15306 L
F
.97619 .18112 m
.97619 .20918 L
.97619 .2281 L
.97619 .19373 L
.97619 .18112 L
F
.97619 .125 m
.97619 .15937 L
.97619 .16333 L
.97619 .125 L
.97619 .125 L
F
.97619 .15937 m
.97619 .19373 L
.97619 .20166 L
.97619 .16333 L
.97619 .15937 L
F
.97619 .19373 m
.97619 .2281 L
.97619 .23999 L
.97619 .20166 L
.97619 .19373 L
F
.97619 .125 m
.97619 .16333 L
.97619 .16468 L
.97619 .125 L
.97619 .125 L
F
.97619 .16333 m
.97619 .20166 L
.97619 .20437 L
.97619 .16468 L
.97619 .16333 L
F
.97619 .20166 m
.97619 .23999 L
.97619 .24405 L
.97619 .20437 L
.97619 .20166 L
F
0 g
.97619 .24405 m
.97619 .23999 L
.97619 .2281 L
.97619 .20918 L
.97619 .18452 L
.97619 .15581 L
.97619 .125 L
.97619 .09419 L
.97619 .06548 L
.97619 .04082 L
.97619 .0219 L
.97619 .01001 L
.97619 .00595 L
.97619 .01001 L
.97619 .0219 L
.97619 .04082 L
.97619 .06548 L
.97619 .09419 L
.97619 .125 L
.97619 .15581 L
.97619 .18452 L
.97619 .20918 L
.97619 .2281 L
.97619 .23999 L
.97619 .24405 L
s
.039 .916 .04 r
.02381 .01786 m
.52108 .01786 L
s
0 0 0 r
2.5 Mabswid
.52108 .01786 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .06071 m
.5074 .06071 L
s
0 0 0 r
2.5 Mabswid
.5074 .06071 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .10357 m
.50081 .10357 L
s
0 0 0 r
2.5 Mabswid
.50081 .10357 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14643 m
.50081 .14643 L
s
0 0 0 r
2.5 Mabswid
.50081 .14643 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18929 m
.5074 .18929 L
s
0 0 0 r
2.5 Mabswid
.5074 .18929 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23214 m
.52108 .23214 L
s
0 0 0 r
2.5 Mabswid
.52108 .23214 Mdot
.039 .916 .04 r
.5 Mabswid
.52108 .01786 m
.54473 .02111 L
s
0 0 0 r
2.5 Mabswid
.54473 .02111 Mdot
.039 .916 .04 r
.5 Mabswid
.5074 .06071 m
.54662 .06382 L
s
0 0 0 r
2.5 Mabswid
.54662 .06382 Mdot
.039 .916 .04 r
.5 Mabswid
.50081 .10357 m
.54751 .10478 L
s
0 0 0 r
2.5 Mabswid
.54751 .10478 Mdot
.039 .916 .04 r
.5 Mabswid
.50081 .14643 m
.54751 .14522 L
s
0 0 0 r
2.5 Mabswid
.54751 .14522 Mdot
.039 .916 .04 r
.5 Mabswid
.5074 .18929 m
.54662 .18618 L
s
0 0 0 r
2.5 Mabswid
.54662 .18618 Mdot
.039 .916 .04 r
.5 Mabswid
.52108 .23214 m
.54473 .22889 L
s
0 0 0 r
2.5 Mabswid
.54473 .22889 Mdot
.039 .916 .04 r
.5 Mabswid
.54473 .02111 m
.97619 .12604 L
s
0 0 0 r
2.5 Mabswid
.97619 .12604 Mdot
.039 .916 .04 r
.5 Mabswid
.54662 .06382 m
.97619 .12331 L
s
0 0 0 r
2.5 Mabswid
.97619 .12331 Mdot
.039 .916 .04 r
.5 Mabswid
.54751 .10478 m
.97619 .1241 L
s
0 0 0 r
2.5 Mabswid
.97619 .1241 Mdot
.039 .916 .04 r
.5 Mabswid
.54751 .14522 m
.97619 .1259 L
s
0 0 0 r
2.5 Mabswid
.97619 .1259 Mdot
.039 .916 .04 r
.5 Mabswid
.54662 .18618 m
.97619 .12669 L
s
0 0 0 r
2.5 Mabswid
.97619 .12669 Mdot
.039 .916 .04 r
.5 Mabswid
.54473 .22889 m
.97619 .12396 L
s
0 0 0 r
2.5 Mabswid
.97619 .12396 Mdot
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{476, 119},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007L0000Mb000`400?l00000o`00003oo`3ooooM
0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00n@3oool:00000</0oooo00<000000?ooo`3oool0
2`3oool00?T0oooo00<0000007moO`1oOgl01P1oOgl00`000000oooo0?ooo`390?ooo`030000003o
ool0oooo00/0oooo003h0?ooo`/00000b`3oool00`000000oooo0?ooo`0;0?ooo`00n03oool20000
00P0Ogmo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`00n03oool2000000P0
Ogmo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`00m`3oool00`000000Ogmo
0000000807moO`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool000`0oooojP09
jPX00`0000002NX:00WZ2P0500WZ2P@0Ogmo00<000000?ooo`3oool0b@3oool00`000000oooo0?oo
o`0;0?ooo`00mP3oool20000000307moO`000000Ogmo00<0Ogmo0`09jPX0100000002NX:00WZ2P09
jP[90?ooo`030000003oool0oooo00/0oooo003f0?ooo`030000001oOgl0Ogmo00X000000P3oool4
00WZ2/D0oooo00<000000?ooo`3oool02`3oool00?H0oooo00@0000007moO`1oOgl00000201oOgl0
0`000000oooo0?ooo`040?ooo`@02NX:`@3oool00`000000oooo0?ooo`0;0?ooo`00m@3oool01@00
0000Ogmo07moO`1oOgl0000000P0Ogmo0P0000090?ooo`@02NX:_@3oool00`000000oooo0?ooo`0;
0?ooo`00m@3oool01@000000Ogmo07moO`1oOgl0000000P0Ogmo0P00000=0?ooo`@02NX:^@3oool0
0`000000oooo0?ooo`0;0?ooo`00m@3oool01@000000Ogmo07moO`1oOgl0000000P0Ogmo0P00000A
0?ooo`@02NX:]@3oool00`000000oooo0?ooo`0;0?ooo`00m03oool00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00H0Ogmo0P00000E0?ooo`D02NX:/03oool00`000000oooo0?ooo`0;0?oo
o`00m03oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00H0Ogmo0P00000J0?ooo`@0
2NX:[03oool00`000000oooo0?ooo`0;0?ooo`00m03oool00`000000Ogmo07moO`0207moO`030000
001oOgl0Ogmo00H0Ogmo0P00000N0?ooo`@02NX:Z03oool00`000000oooo0?ooo`0;0?ooo`00l`3o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00H0Ogmo0P00000R0?ooo`@02NX:Y03o
ool00`000000oooo0?ooo`0;0?ooo`00l`3oool00`000000Ogmo07moO`0307moO`/000009P3oool4
00WZ2Z00oooo00<000000?ooo`3oool02`3oool00?<0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0607moO`800000:P3oool400WZ2Y`0oooo00<000000?ooo`3oool02`3oool00?80
oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0607moO`800000;P3oool400WZ2YP0
oooo00<000000?ooo`3oool02`3oool00?80oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0607moO`800000<P3oool400WZ2Y@0oooo00<000000?ooo`3oool02`3oool00?80oooo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0607moO`800000=P3oool400WZ2Y00oooo00<0
00000?ooo`3oool02`3oool00?40oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`06
07moO`800000>P3oool400WZ2X`0oooo00<000000?ooo`3oool02`3oool00?40oooo00<0000007mo
O`1oOgl01@1oOgl00`000000Ogmo07moO`0607moO`800000?P3oool400WZ2XP0oooo00<000000?oo
o`3oool02`3oool00?40oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0607moO`80
0000@P3oool400WZ2X@0oooo00<000000?ooo`3oool02`3oool00?40oooo00<0000007moO`1oOgl0
1@1oOgl00`000000Ogmo07moO`0607moO`800000AP3oool400WZ2X00oooo00<000000?ooo`3oool0
2`3oool000`0oooojP09jPX307moO`030000001oOgl0Ogmo00H0Ogmo0P00001:0?ooo`D02NX:N`3o
ool00`000000oooo0?ooo`0;0?ooo`00l03oool2000000@0Ogmo2@09jPX307moO`800000C`3oool4
00WZ2WL0oooo00<000000?ooo`3oool02`3oool00?00oooo00<0000007moO`1oOgl01P1oOgl60000
00<02NX:00<0000000WZ2P09jPX00`09jPY?0?ooo`@02NX:L`3oool00`000000oooo0?ooo`0;0?oo
o`00l03oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo00H0Ogmo0P0000040?ooo`L0
2NX:C03oool400WZ2Vl0oooo00<000000?ooo`3oool02`3oool00?00oooo00<0000007moO`1oOgl0
1P1oOgl00`000000Ogmo07moO`0607moO`8000002`3oool700WZ2TT0oooo1009jPY[0?ooo`030000
003oool0oooo00/0oooo003`0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl01P1o
Ogl200000180oooo1`09jPY60?ooo`@02NX:I`3oool00`000000oooo0?ooo`0;0?ooo`00k`3oool0
0`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00H0Ogmo0P00000I0?ooo`P02NX:@P3oool4
00WZ2V<0oooo00<000000?ooo`3oool02`3oool00>l0oooo00<0000007moO`1oOgl01`1oOgl00`00
0000Ogmo07moO`0607moO`8000008@3oool700WZ2Sl0oooo1009jPYO0?ooo`030000003oool0oooo
00/0oooo003_0?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl01P1oOgl2000002P0
oooo1`09jPXl0?ooo`@02NX:F`3oool00`000000oooo0?ooo`0;0?ooo`00k`3oool00`000000Ogmo
07moO`0707moO`030000001oOgl0Ogmo00H0Ogmo0P00000_0?ooo`L02NX:>@3oool400WZ2UL0oooo
00<000000?ooo`3oool02`3oool00>l0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07mo
O`0607moO`800000=P3oool800WZ2SD0oooo1009jPYC0?ooo`030000003oool0oooo00/0oooo003^
0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl01P1oOgl2000003h0oooo1`09jPXb
0?ooo`@02NX:C`3oool00`000000oooo0?ooo`0;0?ooo`00kP3oool00`000000Ogmo07moO`0807mo
O`030000001oOgl0Ogmo00H0Ogmo0P0000150?ooo`L02NX:;`3oool500WZ2TX0oooo00<000000?oo
o`3oool02`3oool00>h0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0607moO`80
0000C03oool700WZ2Rd0oooo1009jPY60?ooo`030000003oool0oooo00/0oooo003^0?ooo`030000
001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl01P1oOgl2000005<0oooo2009jPXY0?ooo`@02NX:
@P3oool00`000000oooo0?ooo`0;0?ooo`00kP3oool00`000000Ogmo07moO`0807moO`030000001o
Ogl0Ogmo00H0Ogmo0P00001K0?ooo`L02NX:9P3oool400WZ2Sh0oooo00<000000?ooo`3oool02`3o
ool00>h0oooo00<0000007moO`1oOgl0201oOgl;00000680oooo1`09jPXS0?ooo`@02NX:>P3oool0
0`000000oooo0?ooo`0;0?ooo`00kP3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo
00H0Ogmo0P00001Y0?ooo`L02NX:803oool400WZ2SH0oooo00<000000?ooo`3oool02`3oool00>h0
oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0607moO`800000L03oool800WZ2Q`0
oooo1009jPXb0?ooo`030000003oool0oooo00/0oooo003^0?ooo`030000001oOgl0Ogmo00P0Ogmo
00<0000007moO`1oOgl01P1oOgl2000007P0oooo1`09jPXI0?ooo`@02NX:;P3oool00`000000oooo
0?ooo`0;0?ooo`00303oooo]00WZ2P030000001oOgl0Ogmo00H0Ogmo0P00001o0?ooo`L02NX:5P3o
ool400WZ2RX0oooo00<000000?ooo`3oool02`3oool00>d0oooo0P00000:07moOaH02NX:N`3oool7
00WZ2Q<0oooo1009jPXV0?ooo`030000003oool0oooo00/0oooo003]0?ooo`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl01P1oOgl3000000X0oooo5`09jPY[0?ooo`P02NX:3`3oool400WZ
2R80oooo00<000000?ooo`3oool02`3oool00>d0oooo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0607moO`8000008P3ooolF00WZ2Ud0oooo1`09jPX<0?ooo`@02NX:7P3oool00`000000
oooo0?ooo`0;0?ooo`00k@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00H0Ogmo
0P00000h0?oooaL02NX:C@3oool700WZ2PT0oooo1009jPXJ0?ooo`030000003oool0oooo00/0oooo
003]0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl01P1oOgl2000004l0oooo5`09
jPXm0?ooo`L02NX:1P3oool500WZ2QD0oooo00<000000?ooo`3oool02`3oool00>d0oooo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0607moO`800000IP3ooolF00WZ2Rh0oooo2009jPX3
0?ooo`@02NX:4@3oool00`000000oooo0?ooo`0;0?ooo`00k@3oool00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00H0Ogmo0P00001l0?oooaL02NX:7`3oool;00WZ2Pd0oooo00<000000?oo
o`3oool02`3oool00>d0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0607moO`80
0000T`3ooolF00WZ2Q00oooo2009jPX90?ooo`030000003oool0oooo00/0oooo003]0?ooo`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl01P1oOgl200000:T0oooo7P09jPX20?ooo`800000
3@3oool00>d0oooo5`0000300?ooo`T02NX:0P00000=0?ooo`00k@3oool00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00H0Ogmo0P00002o0?ooo`X02NX:0P00000=0?ooo`00k@3oool00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00H0Ogmo0P00002X0?oooah02NX:0`3oool20000
00d0oooo003]0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl01P1oOgl200000980
oooo5P09jPX@0?ooo`P02NX:2P3oool00`000000oooo0?ooo`0;0?ooo`00k@3oool00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00H0Ogmo0P00001k0?oooaL02NX:7`3oool;00WZ2Ph0oooo
00<000000?ooo`3oool02`3oool00>d0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0607moO`800000I03ooolG00WZ2Rh0oooo2009jPX30?ooo`@02NX:4P3oool00`000000oooo0?oo
o`0;0?ooo`00k@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00H0Ogmo0P00001>
0?oooaH02NX:?P3oool700WZ2PH0oooo1@09jPXF0?ooo`030000003oool0oooo00/0oooo003]0?oo
o`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl01P1oOgl2000003L0oooo5`09jPY=0?oo
o`L02NX:2@3oool400WZ2Q/0oooo00<000000?ooo`3oool02`3oool00>d0oooo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0607moO`8000008@3ooolF00WZ2Ud0oooo1`09jPX<0?ooo`@0
2NX:7`3oool00`000000oooo0?ooo`0;0?ooo`00k@3oool00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo00H0Ogmo0P00000:0?oooaL02NX:J`3oool800WZ2Pl0oooo1009jPXS0?ooo`030000
003oool0oooo00/0oooo003]0?ooo`8000002@1oOglF00WZ2W/0oooo1`09jPXC0?ooo`@02NX:9`3o
ool00`000000oooo0?ooo`0;0?ooo`00303oooo/00WZ2P0307moO`000000Ogmo00L0Ogmo0`00001m
0?ooo`L02NX:5P3oool400WZ2R/0oooo00<000000?ooo`3oool02`3oool00>h0oooo00<0000007mo
O`1oOgl0201oOgl00`000000Ogmo07moO`0607moO`800000M`3oool700WZ2QT0oooo1009jPX_0?oo
o`030000003oool0oooo00/0oooo003^0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1o
Ogl01P1oOgl2000006l0oooo2009jPXL0?ooo`@02NX:<`3oool00`000000oooo0?ooo`0;0?ooo`00
kP3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo00H0Ogmo0P00001X0?ooo`L02NX:
803oool400WZ2SL0oooo00<000000?ooo`3oool02`3oool00>h0oooo00<0000007moO`1oOgl0201o
Ogl;00000640oooo1`09jPXS0?ooo`@02NX:>`3oool00`000000oooo0?ooo`0;0?ooo`00kP3oool0
0`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo00H0Ogmo0P00001J0?ooo`L02NX:9P3oool4
00WZ2Sl0oooo00<000000?ooo`3oool02`3oool00>h0oooo00<0000007moO`1oOgl0201oOgl00`00
0000Ogmo07moO`0607moO`800000DP3oool800WZ2RT0oooo1009jPY30?ooo`030000003oool0oooo
00/0oooo003^0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl01P1oOgl2000004/0
oooo1`09jPX]0?ooo`@02NX:A`3oool00`000000oooo0?ooo`0;0?ooo`00kP3oool00`000000Ogmo
07moO`0807moO`030000001oOgl0Ogmo00H0Ogmo0P0000140?ooo`L02NX:;`3oool500WZ2T/0oooo
00<000000?ooo`3oool02`3oool00>h0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07mo
O`0607moO`800000?@3oool700WZ2S80oooo1009jPY@0?ooo`030000003oool0oooo00/0oooo003^
0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl01P1oOgl2000003D0oooo2009jPXe
0?ooo`@02NX:E03oool00`000000oooo0?ooo`0;0?ooo`00k`3oool00`000000Ogmo07moO`0707mo
O`030000001oOgl0Ogmo00H0Ogmo0P00000^0?ooo`L02NX:>@3oool400WZ2UP0oooo00<000000?oo
o`3oool02`3oool00>l0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0607moO`80
00009`3oool700WZ2S`0oooo1009jPYL0?ooo`030000003oool0oooo00/0oooo003_0?ooo`030000
001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl01P1oOgl200000200oooo1`09jPXo0?ooo`@02NX:
H03oool00`000000oooo0?ooo`0;0?ooo`00k`3oool00`000000Ogmo07moO`0707moO`030000001o
Ogl0Ogmo00H0Ogmo0P00000H0?ooo`P02NX:@P3oool400WZ2V@0oooo00<000000?ooo`3oool02`3o
ool00>l0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0607moO`8000004@3oool7
00WZ2TH0oooo1009jPYX0?ooo`030000003oool0oooo00/0oooo003`0?ooo`030000001oOgl0Ogmo
00H0Ogmo00<0000007moO`1oOgl01P1oOgl2000000X0oooo1`09jPY90?ooo`@02NX:K03oool00`00
0000oooo0?ooo`0;0?ooo`00l03oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo00H0
Ogmo0P0000030?ooo`L02NX:C03oool400WZ2W00oooo00<000000?ooo`3oool02`3oool00?00oooo
00<0000007moO`1oOgl01P1oOgl5000000@02NX:00<0000000WZ2P09jPX00P09jPY?0?ooo`@02NX:
M03oool00`000000oooo0?ooo`0;0?ooo`00l03oool00`000000Ogmo07moO`0207moO`T02NX:101o
Ogl2000004h0oooo1009jPYh0?ooo`030000003oool0oooo00/0oooo000<0?ooonT02NX:101oOgl0
0`000000Ogmo07moO`0607moO`800000B@3oool500WZ2W`0oooo00<000000?ooo`3oool02`3oool0
0?00oooo0P00000707moO`030000001oOgl0Ogmo00H0Ogmo0P0000150?ooo`@02NX:P@3oool00`00
0000oooo0?ooo`0;0?ooo`00l@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00H0
Ogmo0P0000110?ooo`@02NX:Q@3oool00`000000oooo0?ooo`0;0?ooo`00l@3oool00`000000Ogmo
07moO`0507moO`030000001oOgl0Ogmo00H0Ogmo0P00000m0?ooo`@02NX:R@3oool00`000000oooo
0?ooo`0;0?ooo`00l@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00H0Ogmo0P00
000i0?ooo`@02NX:S@3oool00`000000oooo0?ooo`0;0?ooo`00l@3oool00`000000Ogmo07moO`05
07moO`030000001oOgl0Ogmo00H0Ogmo0P00000e0?ooo`@02NX:T@3oool00`000000oooo0?ooo`0;
0?ooo`00lP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00H0Ogmo0P00000a0?oo
o`@02NX:U@3oool00`000000oooo0?ooo`0;0?ooo`00lP3oool00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00H0Ogmo0P00000]0?ooo`@02NX:V@3oool00`000000oooo0?ooo`0;0?ooo`00
lP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00H0Ogmo0P00000Y0?ooo`@02NX:
W@3oool00`000000oooo0?ooo`0;0?ooo`00l`3oool00`000000Ogmo07moO`0307moO`/000009@3o
ool400WZ2Z40oooo00<000000?ooo`3oool02`3oool00?<0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0607moO`8000008@3oool400WZ2ZD0oooo00<000000?ooo`3oool02`3oool0
0?<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0607moO`8000007@3oool400WZ
2ZT0oooo00<000000?ooo`3oool02`3oool00?@0oooo00<0000007moO`1oOgl00P1oOgl00`000000
Ogmo07moO`0607moO`8000006@3oool400WZ2Zd0oooo00<000000?ooo`3oool02`3oool00?@0oooo
00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0607moO`800000503oool500WZ2[40oooo
00<000000?ooo`3oool02`3oool00?@0oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07mo
O`0607moO`800000403oool400WZ2[H0oooo00<000000?ooo`3oool02`3oool00?D0oooo00D00000
07moO`1oOgl0Ogmo0000000807moO`800000303oool400WZ2[X0oooo00<000000?ooo`3oool02`3o
ool00?D0oooo00D0000007moO`1oOgl0Ogmo0000000807moO`800000203oool400WZ2[h0oooo00<0
00000?ooo`3oool02`3oool00?H0oooo00@0000007moO`1oOgl00000201oOgl00`000000oooo0?oo
o`030?ooo`@02NX:`P3oool00`000000oooo0?ooo`0;0?ooo`00mP3oool00`000000Ogmo07moO`0:
000000030?ooo`09jPX02NX:00802NX:aP3oool00`000000oooo0?ooo`0;0?ooo`00mP3oool01000
0000Ogmo07moO`00000307moO`@02NX:00<0000000WZ2P09jPX0bP3oool00`000000oooo0?ooo`0;
0?ooo`00303ooooZ00WZ2P0300000009jPX02NX:00@02NX:1@1oOgl00`000000oooo0?ooo`390?oo
o`030000003oool0oooo00/0oooo003f0?ooo`80000000<0Ogmo0000001oOgl01`1oOgl00`000000
oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo003g0?ooo`030000001oOgl0000000P0Ogmo
00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`00n03oool2000000P0Ogmo00<0
00000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`00n03oool;00000</0oooo00<00000
0?ooo`3oool02`3oool00?P0oooo0P00000807moO`030000003oool0oooo0<T0oooo00<000000?oo
o`3oool02`3oool00?T0oooo2P00003;0?ooo`030000003oool0oooo00/0oooo003o0?ooomd0oooo
003o0?ooomd0oooo0000\
\>"],
  ImageRangeCache->{{{0, 475}, {118, 0}} -> {-5.66843, -26.2503, 0.44492, \
0.44492}},
  CellTags->"Lens Optimizations"]
}, Open  ]],

Cell["\<\
lenses = {Move[SphericalLens[{1/c1,100},{1/c2,-100},50,20],35],
\tMove[SphericalLens[{1/c3,300},{1/c4,-300},60,15,ComponentMedium->SF11],65]};\
\
\>", "Input",
  CellTags->"Lens Optimizations"],

Cell[CellGroupData[{

Cell["\<\
plot = TurboPlot[{
\tTable[Move[LineOfRays[5],0,angle],{angle,-20,20,10}],
\tlenses,
\tMove[Screen[100],155]}, PlotType->TopView, PlotPoints->50];\
\>", "Input",
  CellTags->"Lens Optimizations"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .64162 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0290345 0.00611068 0.320811 0.00611068 [
[ 0 0 0 0 ]
[ 1 .64162 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.26231 .16804 m
.34572 .16804 L
.34945 .18332 L
.25858 .18332 L
.26231 .16804 L
F
.25858 .18332 m
.34945 .18332 L
.35278 .1986 L
.25525 .1986 L
.25858 .18332 L
F
.25525 .1986 m
.35278 .1986 L
.35569 .21387 L
.25234 .21387 L
.25525 .1986 L
F
.25234 .21387 m
.35569 .21387 L
.35821 .22915 L
.24982 .22915 L
.25234 .21387 L
F
.24982 .22915 m
.35821 .22915 L
.36033 .24443 L
.2477 .24443 L
.24982 .22915 L
F
.2477 .24443 m
.36033 .24443 L
.36206 .2597 L
.24597 .2597 L
.2477 .24443 L
F
.24597 .2597 m
.36206 .2597 L
.3634 .27498 L
.24463 .27498 L
.24597 .2597 L
F
.24463 .27498 m
.3634 .27498 L
.36436 .29026 L
.24367 .29026 L
.24463 .27498 L
F
.24367 .29026 m
.36436 .29026 L
.36493 .30553 L
.2431 .30553 L
.24367 .29026 L
F
.2431 .30553 m
.36493 .30553 L
.36512 .32081 L
.24291 .32081 L
.2431 .30553 L
F
.24291 .32081 m
.36512 .32081 L
.36493 .33609 L
.2431 .33609 L
.24291 .32081 L
F
.2431 .33609 m
.36493 .33609 L
.36436 .35136 L
.24367 .35136 L
.2431 .33609 L
F
.24367 .35136 m
.36436 .35136 L
.3634 .36664 L
.24463 .36664 L
.24367 .35136 L
F
.24463 .36664 m
.3634 .36664 L
.36206 .38192 L
.24597 .38192 L
.24463 .36664 L
F
.24597 .38192 m
.36206 .38192 L
.36033 .39719 L
.2477 .39719 L
.24597 .38192 L
F
.2477 .39719 m
.36033 .39719 L
.35821 .41247 L
.24982 .41247 L
.2477 .39719 L
F
.24982 .41247 m
.35821 .41247 L
.35569 .42775 L
.25234 .42775 L
.24982 .41247 L
F
.25234 .42775 m
.35569 .42775 L
.35278 .44302 L
.25525 .44302 L
.25234 .42775 L
F
.25525 .44302 m
.35278 .44302 L
.34945 .4583 L
.25858 .4583 L
.25525 .44302 L
F
.25858 .4583 m
.34945 .4583 L
.34572 .47358 L
.26231 .47358 L
.25858 .4583 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.26231 .16804 m
.25858 .18332 L
.25525 .1986 L
.25234 .21387 L
.24982 .22915 L
.2477 .24443 L
.24597 .2597 L
.24463 .27498 L
.24367 .29026 L
.2431 .30553 L
.24291 .32081 L
.2431 .33609 L
.24367 .35136 L
.24463 .36664 L
.24597 .38192 L
.2477 .39719 L
.24982 .41247 L
.25234 .42775 L
.25525 .44302 L
.25858 .4583 L
.26231 .47358 L
.34572 .47358 L
.34945 .4583 L
.35278 .44302 L
.35569 .42775 L
.35821 .41247 L
.36033 .39719 L
.36206 .38192 L
.3634 .36664 L
.36436 .35136 L
.36493 .33609 L
.36512 .32081 L
.36493 .30553 L
.36436 .29026 L
.3634 .27498 L
.36206 .2597 L
.36033 .24443 L
.35821 .22915 L
.35569 .21387 L
.35278 .1986 L
.34945 .18332 L
.34572 .16804 L
.26231 .16804 L
s
.5 g
.26231 .32081 m
.34572 .32081 L
.34945 .32081 L
.25858 .32081 L
.26231 .32081 L
F
.25858 .32081 m
.34945 .32081 L
.35278 .32081 L
.25525 .32081 L
.25858 .32081 L
F
.25525 .32081 m
.35278 .32081 L
.35569 .32081 L
.25234 .32081 L
.25525 .32081 L
F
.25234 .32081 m
.35569 .32081 L
.35821 .32081 L
.24982 .32081 L
.25234 .32081 L
F
.24982 .32081 m
.35821 .32081 L
.36033 .32081 L
.2477 .32081 L
.24982 .32081 L
F
.2477 .32081 m
.36033 .32081 L
.36206 .32081 L
.24597 .32081 L
.2477 .32081 L
F
.24597 .32081 m
.36206 .32081 L
.3634 .32081 L
.24463 .32081 L
.24597 .32081 L
F
.24463 .32081 m
.3634 .32081 L
.36436 .32081 L
.24367 .32081 L
.24463 .32081 L
F
.24367 .32081 m
.36436 .32081 L
.36493 .32081 L
.2431 .32081 L
.24367 .32081 L
F
.2431 .32081 m
.36493 .32081 L
.36512 .32081 L
.24291 .32081 L
.2431 .32081 L
F
.24291 .32081 m
.36512 .32081 L
.36493 .32081 L
.2431 .32081 L
.24291 .32081 L
F
.2431 .32081 m
.36493 .32081 L
.36436 .32081 L
.24367 .32081 L
.2431 .32081 L
F
.24367 .32081 m
.36436 .32081 L
.3634 .32081 L
.24463 .32081 L
.24367 .32081 L
F
.24463 .32081 m
.3634 .32081 L
.36206 .32081 L
.24597 .32081 L
.24463 .32081 L
F
.24597 .32081 m
.36206 .32081 L
.36033 .32081 L
.2477 .32081 L
.24597 .32081 L
F
.2477 .32081 m
.36033 .32081 L
.35821 .32081 L
.24982 .32081 L
.2477 .32081 L
F
.24982 .32081 m
.35821 .32081 L
.35569 .32081 L
.25234 .32081 L
.24982 .32081 L
F
.25234 .32081 m
.35569 .32081 L
.35278 .32081 L
.25525 .32081 L
.25234 .32081 L
F
.25525 .32081 m
.35278 .32081 L
.34945 .32081 L
.25858 .32081 L
.25525 .32081 L
F
.25858 .32081 m
.34945 .32081 L
.34572 .32081 L
.26231 .32081 L
.25858 .32081 L
F
0 g
.26231 .32081 m
.25858 .32081 L
.25525 .32081 L
.25234 .32081 L
.24982 .32081 L
.2477 .32081 L
.24597 .32081 L
.24463 .32081 L
.24367 .32081 L
.2431 .32081 L
.24291 .32081 L
.2431 .32081 L
.24367 .32081 L
.24463 .32081 L
.24597 .32081 L
.2477 .32081 L
.24982 .32081 L
.25234 .32081 L
.25525 .32081 L
.25858 .32081 L
.26231 .32081 L
.34572 .32081 L
.34945 .32081 L
.35278 .32081 L
.35569 .32081 L
.35821 .32081 L
.36033 .32081 L
.36206 .32081 L
.3634 .32081 L
.36436 .32081 L
.36493 .32081 L
.36512 .32081 L
.36493 .32081 L
.36436 .32081 L
.3634 .32081 L
.36206 .32081 L
.36033 .32081 L
.35821 .32081 L
.35569 .32081 L
.35278 .32081 L
.34945 .32081 L
.34572 .32081 L
.26231 .32081 L
s
.26231 .47358 m
.34572 .47358 L
.34572 .47311 L
.26231 .47311 L
.26231 .47358 L
s
.26231 .47311 m
.34572 .47311 L
.34572 .4717 L
.26231 .4717 L
.26231 .47311 L
s
.26231 .4717 m
.34572 .4717 L
.34572 .46936 L
.26231 .46936 L
.26231 .4717 L
s
.26231 .46936 m
.34572 .46936 L
.34572 .4661 L
.26231 .4661 L
.26231 .46936 L
s
.26231 .4661 m
.34572 .4661 L
.34572 .46195 L
.26231 .46195 L
.26231 .4661 L
s
.26231 .46195 m
.34572 .46195 L
.34572 .45693 L
.26231 .45693 L
.26231 .46195 L
s
.26231 .45693 m
.34572 .45693 L
.34572 .45107 L
.26231 .45107 L
.26231 .45693 L
s
.26231 .45107 m
.34572 .45107 L
.34572 .4444 L
.26231 .4444 L
.26231 .45107 L
s
.26231 .4444 m
.34572 .4444 L
.34572 .43698 L
.26231 .43698 L
.26231 .4444 L
s
.26231 .43698 m
.34572 .43698 L
.34572 .42883 L
.26231 .42883 L
.26231 .43698 L
s
.26231 .42883 m
.34572 .42883 L
.34572 .42003 L
.26231 .42003 L
.26231 .42883 L
s
.26231 .42003 m
.34572 .42003 L
.34572 .41061 L
.26231 .41061 L
.26231 .42003 L
s
.26231 .41061 m
.34572 .41061 L
.34572 .40063 L
.26231 .40063 L
.26231 .41061 L
s
.26231 .40063 m
.34572 .40063 L
.34572 .39017 L
.26231 .39017 L
.26231 .40063 L
s
.26231 .39017 m
.34572 .39017 L
.34572 .37927 L
.26231 .37927 L
.26231 .39017 L
s
.26231 .37927 m
.34572 .37927 L
.34572 .36802 L
.26231 .36802 L
.26231 .37927 L
s
.26231 .36802 m
.34572 .36802 L
.34572 .35647 L
.26231 .35647 L
.26231 .36802 L
s
.26231 .35647 m
.34572 .35647 L
.34572 .34471 L
.26231 .34471 L
.26231 .35647 L
s
.26231 .34471 m
.34572 .34471 L
.34572 .3328 L
.26231 .3328 L
.26231 .34471 L
s
.26231 .3328 m
.34572 .3328 L
.34572 .32081 L
.26231 .32081 L
.26231 .3328 L
s
.26231 .32081 m
.34572 .32081 L
.34572 .30882 L
.26231 .30882 L
.26231 .32081 L
s
.26231 .30882 m
.34572 .30882 L
.34572 .29691 L
.26231 .29691 L
.26231 .30882 L
s
.26231 .29691 m
.34572 .29691 L
.34572 .28515 L
.26231 .28515 L
.26231 .29691 L
s
.26231 .28515 m
.34572 .28515 L
.34572 .2736 L
.26231 .2736 L
.26231 .28515 L
s
.26231 .2736 m
.34572 .2736 L
.34572 .26235 L
.26231 .26235 L
.26231 .2736 L
s
.26231 .26235 m
.34572 .26235 L
.34572 .25146 L
.26231 .25146 L
.26231 .26235 L
s
.26231 .25146 m
.34572 .25146 L
.34572 .24099 L
.26231 .24099 L
.26231 .25146 L
s
.26231 .24099 m
.34572 .24099 L
.34572 .23102 L
.26231 .23102 L
.26231 .24099 L
s
.26231 .23102 m
.34572 .23102 L
.34572 .2216 L
.26231 .2216 L
.26231 .23102 L
s
.26231 .2216 m
.34572 .2216 L
.34572 .21279 L
.26231 .21279 L
.26231 .2216 L
s
.26231 .21279 m
.34572 .21279 L
.34572 .20465 L
.26231 .20465 L
.26231 .21279 L
s
.26231 .20465 m
.34572 .20465 L
.34572 .19722 L
.26231 .19722 L
.26231 .20465 L
s
.26231 .19722 m
.34572 .19722 L
.34572 .19056 L
.26231 .19056 L
.26231 .19722 L
s
.26231 .19056 m
.34572 .19056 L
.34572 .18469 L
.26231 .18469 L
.26231 .19056 L
s
.26231 .18469 m
.34572 .18469 L
.34572 .17967 L
.26231 .17967 L
.26231 .18469 L
s
.26231 .17967 m
.34572 .17967 L
.34572 .17552 L
.26231 .17552 L
.26231 .17967 L
s
.26231 .17552 m
.34572 .17552 L
.34572 .17226 L
.26231 .17226 L
.26231 .17552 L
s
.26231 .17226 m
.34572 .17226 L
.34572 .16992 L
.26231 .16992 L
.26231 .17226 L
s
.26231 .16992 m
.34572 .16992 L
.34572 .16851 L
.26231 .16851 L
.26231 .16992 L
s
.26231 .16851 m
.34572 .16851 L
.34572 .16804 L
.26231 .16804 L
.26231 .16851 L
s
.26231 .16804 m
.34572 .16804 L
.34572 .16851 L
.26231 .16851 L
.26231 .16804 L
s
.26231 .16851 m
.34572 .16851 L
.34572 .16992 L
.26231 .16992 L
.26231 .16851 L
s
.26231 .16992 m
.34572 .16992 L
.34572 .17226 L
.26231 .17226 L
.26231 .16992 L
s
.26231 .17226 m
.34572 .17226 L
.34572 .17552 L
.26231 .17552 L
.26231 .17226 L
s
.26231 .17552 m
.34572 .17552 L
.34572 .17967 L
.26231 .17967 L
.26231 .17552 L
s
.26231 .17967 m
.34572 .17967 L
.34572 .18469 L
.26231 .18469 L
.26231 .17967 L
s
.26231 .18469 m
.34572 .18469 L
.34572 .19056 L
.26231 .19056 L
.26231 .18469 L
s
.26231 .19056 m
.34572 .19056 L
.34572 .19722 L
.26231 .19722 L
.26231 .19056 L
s
.26231 .19722 m
.34572 .19722 L
.34572 .20465 L
.26231 .20465 L
.26231 .19722 L
s
.26231 .20465 m
.34572 .20465 L
.34572 .21279 L
.26231 .21279 L
.26231 .20465 L
s
.26231 .21279 m
.34572 .21279 L
.34572 .2216 L
.26231 .2216 L
.26231 .21279 L
s
.26231 .2216 m
.34572 .2216 L
.34572 .23102 L
.26231 .23102 L
.26231 .2216 L
s
.26231 .23102 m
.34572 .23102 L
.34572 .24099 L
.26231 .24099 L
.26231 .23102 L
s
.26231 .24099 m
.34572 .24099 L
.34572 .25146 L
.26231 .25146 L
.26231 .24099 L
s
.26231 .25146 m
.34572 .25146 L
.34572 .26235 L
.26231 .26235 L
.26231 .25146 L
s
.26231 .26235 m
.34572 .26235 L
.34572 .2736 L
.26231 .2736 L
.26231 .26235 L
s
.26231 .2736 m
.34572 .2736 L
.34572 .28515 L
.26231 .28515 L
.26231 .2736 L
s
.26231 .28515 m
.34572 .28515 L
.34572 .29691 L
.26231 .29691 L
.26231 .28515 L
s
.26231 .29691 m
.34572 .29691 L
.34572 .30882 L
.26231 .30882 L
.26231 .29691 L
s
.26231 .30882 m
.34572 .30882 L
.34572 .32081 L
.26231 .32081 L
.26231 .30882 L
s
.26231 .32081 m
.34572 .32081 L
.34572 .3328 L
.26231 .3328 L
.26231 .32081 L
s
.26231 .3328 m
.34572 .3328 L
.34572 .34471 L
.26231 .34471 L
.26231 .3328 L
s
.26231 .34471 m
.34572 .34471 L
.34572 .35647 L
.26231 .35647 L
.26231 .34471 L
s
.26231 .35647 m
.34572 .35647 L
.34572 .36802 L
.26231 .36802 L
.26231 .35647 L
s
.26231 .36802 m
.34572 .36802 L
.34572 .37927 L
.26231 .37927 L
.26231 .36802 L
s
.26231 .37927 m
.34572 .37927 L
.34572 .39017 L
.26231 .39017 L
.26231 .37927 L
s
.26231 .39017 m
.34572 .39017 L
.34572 .40063 L
.26231 .40063 L
.26231 .39017 L
s
.26231 .40063 m
.34572 .40063 L
.34572 .41061 L
.26231 .41061 L
.26231 .40063 L
s
.26231 .41061 m
.34572 .41061 L
.34572 .42003 L
.26231 .42003 L
.26231 .41061 L
s
.26231 .42003 m
.34572 .42003 L
.34572 .42883 L
.26231 .42883 L
.26231 .42003 L
s
.26231 .42883 m
.34572 .42883 L
.34572 .43698 L
.26231 .43698 L
.26231 .42883 L
s
.26231 .43698 m
.34572 .43698 L
.34572 .4444 L
.26231 .4444 L
.26231 .43698 L
s
.26231 .4444 m
.34572 .4444 L
.34572 .45107 L
.26231 .45107 L
.26231 .4444 L
s
.26231 .45107 m
.34572 .45107 L
.34572 .45693 L
.26231 .45693 L
.26231 .45107 L
s
.26231 .45693 m
.34572 .45693 L
.34572 .46195 L
.26231 .46195 L
.26231 .45693 L
s
.26231 .46195 m
.34572 .46195 L
.34572 .4661 L
.26231 .4661 L
.26231 .46195 L
s
.26231 .4661 m
.34572 .4661 L
.34572 .46936 L
.26231 .46936 L
.26231 .4661 L
s
.26231 .46936 m
.34572 .46936 L
.34572 .4717 L
.26231 .4717 L
.26231 .46936 L
s
.26231 .4717 m
.34572 .4717 L
.34572 .47311 L
.26231 .47311 L
.26231 .4717 L
s
.26231 .47311 m
.34572 .47311 L
.34572 .47358 L
.26231 .47358 L
.26231 .47311 L
s
.5 g
.43542 .13749 m
.5087 .13749 L
.51045 .15582 L
.43367 .15582 L
.43542 .13749 L
F
.43367 .15582 m
.51045 .15582 L
.51201 .17415 L
.4321 .17415 L
.43367 .15582 L
F
.4321 .17415 m
.51201 .17415 L
.51339 .19249 L
.43073 .19249 L
.4321 .17415 L
F
.43073 .19249 m
.51339 .19249 L
.51459 .21082 L
.42953 .21082 L
.43073 .19249 L
F
.42953 .21082 m
.51459 .21082 L
.5156 .22915 L
.42852 .22915 L
.42953 .21082 L
F
.42852 .22915 m
.5156 .22915 L
.51642 .24748 L
.4277 .24748 L
.42852 .22915 L
F
.4277 .24748 m
.51642 .24748 L
.51706 .26581 L
.42705 .26581 L
.4277 .24748 L
F
.42705 .26581 m
.51706 .26581 L
.51752 .28415 L
.4266 .28415 L
.42705 .26581 L
F
.4266 .28415 m
.51752 .28415 L
.5178 .30248 L
.42632 .30248 L
.4266 .28415 L
F
.42632 .30248 m
.5178 .30248 L
.51789 .32081 L
.42623 .32081 L
.42632 .30248 L
F
.42623 .32081 m
.51789 .32081 L
.5178 .33914 L
.42632 .33914 L
.42623 .32081 L
F
.42632 .33914 m
.5178 .33914 L
.51752 .35748 L
.4266 .35748 L
.42632 .33914 L
F
.4266 .35748 m
.51752 .35748 L
.51706 .37581 L
.42705 .37581 L
.4266 .35748 L
F
.42705 .37581 m
.51706 .37581 L
.51642 .39414 L
.4277 .39414 L
.42705 .37581 L
F
.4277 .39414 m
.51642 .39414 L
.5156 .41247 L
.42852 .41247 L
.4277 .39414 L
F
.42852 .41247 m
.5156 .41247 L
.51459 .4308 L
.42953 .4308 L
.42852 .41247 L
F
.42953 .4308 m
.51459 .4308 L
.51339 .44914 L
.43073 .44914 L
.42953 .4308 L
F
.43073 .44914 m
.51339 .44914 L
.51201 .46747 L
.4321 .46747 L
.43073 .44914 L
F
.4321 .46747 m
.51201 .46747 L
.51045 .4858 L
.43367 .4858 L
.4321 .46747 L
F
.43367 .4858 m
.51045 .4858 L
.5087 .50413 L
.43542 .50413 L
.43367 .4858 L
F
0 g
.43542 .13749 m
.43367 .15582 L
.4321 .17415 L
.43073 .19249 L
.42953 .21082 L
.42852 .22915 L
.4277 .24748 L
.42705 .26581 L
.4266 .28415 L
.42632 .30248 L
.42623 .32081 L
.42632 .33914 L
.4266 .35748 L
.42705 .37581 L
.4277 .39414 L
.42852 .41247 L
.42953 .4308 L
.43073 .44914 L
.4321 .46747 L
.43367 .4858 L
.43542 .50413 L
.5087 .50413 L
.51045 .4858 L
.51201 .46747 L
.51339 .44914 L
.51459 .4308 L
.5156 .41247 L
.51642 .39414 L
.51706 .37581 L
.51752 .35748 L
.5178 .33914 L
.51789 .32081 L
.5178 .30248 L
.51752 .28415 L
.51706 .26581 L
.51642 .24748 L
.5156 .22915 L
.51459 .21082 L
.51339 .19249 L
.51201 .17415 L
.51045 .15582 L
.5087 .13749 L
.43542 .13749 L
s
.5 g
.43542 .32081 m
.5087 .32081 L
.51045 .32081 L
.43367 .32081 L
.43542 .32081 L
F
.43367 .32081 m
.51045 .32081 L
.51201 .32081 L
.4321 .32081 L
.43367 .32081 L
F
.4321 .32081 m
.51201 .32081 L
.51339 .32081 L
.43073 .32081 L
.4321 .32081 L
F
.43073 .32081 m
.51339 .32081 L
.51459 .32081 L
.42953 .32081 L
.43073 .32081 L
F
.42953 .32081 m
.51459 .32081 L
.5156 .32081 L
.42852 .32081 L
.42953 .32081 L
F
.42852 .32081 m
.5156 .32081 L
.51642 .32081 L
.4277 .32081 L
.42852 .32081 L
F
.4277 .32081 m
.51642 .32081 L
.51706 .32081 L
.42705 .32081 L
.4277 .32081 L
F
.42705 .32081 m
.51706 .32081 L
.51752 .32081 L
.4266 .32081 L
.42705 .32081 L
F
.4266 .32081 m
.51752 .32081 L
.5178 .32081 L
.42632 .32081 L
.4266 .32081 L
F
.42632 .32081 m
.5178 .32081 L
.51789 .32081 L
.42623 .32081 L
.42632 .32081 L
F
.42623 .32081 m
.51789 .32081 L
.5178 .32081 L
.42632 .32081 L
.42623 .32081 L
F
.42632 .32081 m
.5178 .32081 L
.51752 .32081 L
.4266 .32081 L
.42632 .32081 L
F
.4266 .32081 m
.51752 .32081 L
.51706 .32081 L
.42705 .32081 L
.4266 .32081 L
F
.42705 .32081 m
.51706 .32081 L
.51642 .32081 L
.4277 .32081 L
.42705 .32081 L
F
.4277 .32081 m
.51642 .32081 L
.5156 .32081 L
.42852 .32081 L
.4277 .32081 L
F
.42852 .32081 m
.5156 .32081 L
.51459 .32081 L
.42953 .32081 L
.42852 .32081 L
F
.42953 .32081 m
.51459 .32081 L
.51339 .32081 L
.43073 .32081 L
.42953 .32081 L
F
.43073 .32081 m
.51339 .32081 L
.51201 .32081 L
.4321 .32081 L
.43073 .32081 L
F
.4321 .32081 m
.51201 .32081 L
.51045 .32081 L
.43367 .32081 L
.4321 .32081 L
F
.43367 .32081 m
.51045 .32081 L
.5087 .32081 L
.43542 .32081 L
.43367 .32081 L
F
0 g
.43542 .32081 m
.43367 .32081 L
.4321 .32081 L
.43073 .32081 L
.42953 .32081 L
.42852 .32081 L
.4277 .32081 L
.42705 .32081 L
.4266 .32081 L
.42632 .32081 L
.42623 .32081 L
.42632 .32081 L
.4266 .32081 L
.42705 .32081 L
.4277 .32081 L
.42852 .32081 L
.42953 .32081 L
.43073 .32081 L
.4321 .32081 L
.43367 .32081 L
.43542 .32081 L
.5087 .32081 L
.51045 .32081 L
.51201 .32081 L
.51339 .32081 L
.51459 .32081 L
.5156 .32081 L
.51642 .32081 L
.51706 .32081 L
.51752 .32081 L
.5178 .32081 L
.51789 .32081 L
.5178 .32081 L
.51752 .32081 L
.51706 .32081 L
.51642 .32081 L
.5156 .32081 L
.51459 .32081 L
.51339 .32081 L
.51201 .32081 L
.51045 .32081 L
.5087 .32081 L
.43542 .32081 L
s
.43542 .50413 m
.5087 .50413 L
.5087 .50357 L
.43542 .50357 L
.43542 .50413 L
s
.43542 .50357 m
.5087 .50357 L
.5087 .50187 L
.43542 .50187 L
.43542 .50357 L
s
.43542 .50187 m
.5087 .50187 L
.5087 .49907 L
.43542 .49907 L
.43542 .50187 L
s
.43542 .49907 m
.5087 .49907 L
.5087 .49516 L
.43542 .49516 L
.43542 .49907 L
s
.43542 .49516 m
.5087 .49516 L
.5087 .49018 L
.43542 .49018 L
.43542 .49516 L
s
.43542 .49018 m
.5087 .49018 L
.5087 .48415 L
.43542 .48415 L
.43542 .49018 L
s
.43542 .48415 m
.5087 .48415 L
.5087 .47712 L
.43542 .47712 L
.43542 .48415 L
s
.43542 .47712 m
.5087 .47712 L
.5087 .46912 L
.43542 .46912 L
.43542 .47712 L
s
.43542 .46912 m
.5087 .46912 L
.5087 .46021 L
.43542 .46021 L
.43542 .46912 L
s
.43542 .46021 m
.5087 .46021 L
.5087 .45044 L
.43542 .45044 L
.43542 .46021 L
s
.43542 .45044 m
.5087 .45044 L
.5087 .43987 L
.43542 .43987 L
.43542 .45044 L
s
.43542 .43987 m
.5087 .43987 L
.5087 .42856 L
.43542 .42856 L
.43542 .43987 L
s
.43542 .42856 m
.5087 .42856 L
.5087 .4166 L
.43542 .4166 L
.43542 .42856 L
s
.43542 .4166 m
.5087 .4166 L
.5087 .40404 L
.43542 .40404 L
.43542 .4166 L
s
.43542 .40404 m
.5087 .40404 L
.5087 .39096 L
.43542 .39096 L
.43542 .40404 L
s
.43542 .39096 m
.5087 .39096 L
.5087 .37746 L
.43542 .37746 L
.43542 .39096 L
s
.43542 .37746 m
.5087 .37746 L
.5087 .36361 L
.43542 .36361 L
.43542 .37746 L
s
.43542 .36361 m
.5087 .36361 L
.5087 .34949 L
.43542 .34949 L
.43542 .36361 L
s
.43542 .34949 m
.5087 .34949 L
.5087 .33519 L
.43542 .33519 L
.43542 .34949 L
s
.43542 .33519 m
.5087 .33519 L
.5087 .32081 L
.43542 .32081 L
.43542 .33519 L
s
.43542 .32081 m
.5087 .32081 L
.5087 .30643 L
.43542 .30643 L
.43542 .32081 L
s
.43542 .30643 m
.5087 .30643 L
.5087 .29213 L
.43542 .29213 L
.43542 .30643 L
s
.43542 .29213 m
.5087 .29213 L
.5087 .27802 L
.43542 .27802 L
.43542 .29213 L
s
.43542 .27802 m
.5087 .27802 L
.5087 .26416 L
.43542 .26416 L
.43542 .27802 L
s
.43542 .26416 m
.5087 .26416 L
.5087 .25066 L
.43542 .25066 L
.43542 .26416 L
s
.43542 .25066 m
.5087 .25066 L
.5087 .23759 L
.43542 .23759 L
.43542 .25066 L
s
.43542 .23759 m
.5087 .23759 L
.5087 .22503 L
.43542 .22503 L
.43542 .23759 L
s
.43542 .22503 m
.5087 .22503 L
.5087 .21306 L
.43542 .21306 L
.43542 .22503 L
s
.43542 .21306 m
.5087 .21306 L
.5087 .20175 L
.43542 .20175 L
.43542 .21306 L
s
.43542 .20175 m
.5087 .20175 L
.5087 .19118 L
.43542 .19118 L
.43542 .20175 L
s
.43542 .19118 m
.5087 .19118 L
.5087 .18141 L
.43542 .18141 L
.43542 .19118 L
s
.43542 .18141 m
.5087 .18141 L
.5087 .1725 L
.43542 .1725 L
.43542 .18141 L
s
.43542 .1725 m
.5087 .1725 L
.5087 .1645 L
.43542 .1645 L
.43542 .1725 L
s
.43542 .1645 m
.5087 .1645 L
.5087 .15747 L
.43542 .15747 L
.43542 .1645 L
s
.43542 .15747 m
.5087 .15747 L
.5087 .15144 L
.43542 .15144 L
.43542 .15747 L
s
.43542 .15144 m
.5087 .15144 L
.5087 .14646 L
.43542 .14646 L
.43542 .15144 L
s
.43542 .14646 m
.5087 .14646 L
.5087 .14256 L
.43542 .14256 L
.43542 .14646 L
s
.43542 .14256 m
.5087 .14256 L
.5087 .13975 L
.43542 .13975 L
.43542 .14256 L
s
.43542 .13975 m
.5087 .13975 L
.5087 .13806 L
.43542 .13806 L
.43542 .13975 L
s
.43542 .13806 m
.5087 .13806 L
.5087 .13749 L
.43542 .13749 L
.43542 .13806 L
s
.43542 .13749 m
.5087 .13749 L
.5087 .13806 L
.43542 .13806 L
.43542 .13749 L
s
.43542 .13806 m
.5087 .13806 L
.5087 .13975 L
.43542 .13975 L
.43542 .13806 L
s
.43542 .13975 m
.5087 .13975 L
.5087 .14256 L
.43542 .14256 L
.43542 .13975 L
s
.43542 .14256 m
.5087 .14256 L
.5087 .14646 L
.43542 .14646 L
.43542 .14256 L
s
.43542 .14646 m
.5087 .14646 L
.5087 .15144 L
.43542 .15144 L
.43542 .14646 L
s
.43542 .15144 m
.5087 .15144 L
.5087 .15747 L
.43542 .15747 L
.43542 .15144 L
s
.43542 .15747 m
.5087 .15747 L
.5087 .1645 L
.43542 .1645 L
.43542 .15747 L
s
.43542 .1645 m
.5087 .1645 L
.5087 .1725 L
.43542 .1725 L
.43542 .1645 L
s
.43542 .1725 m
.5087 .1725 L
.5087 .18141 L
.43542 .18141 L
.43542 .1725 L
s
.43542 .18141 m
.5087 .18141 L
.5087 .19118 L
.43542 .19118 L
.43542 .18141 L
s
.43542 .19118 m
.5087 .19118 L
.5087 .20175 L
.43542 .20175 L
.43542 .19118 L
s
.43542 .20175 m
.5087 .20175 L
.5087 .21306 L
.43542 .21306 L
.43542 .20175 L
s
.43542 .21306 m
.5087 .21306 L
.5087 .22503 L
.43542 .22503 L
.43542 .21306 L
s
.43542 .22503 m
.5087 .22503 L
.5087 .23759 L
.43542 .23759 L
.43542 .22503 L
s
.43542 .23759 m
.5087 .23759 L
.5087 .25066 L
.43542 .25066 L
.43542 .23759 L
s
.43542 .25066 m
.5087 .25066 L
.5087 .26416 L
.43542 .26416 L
.43542 .25066 L
s
.43542 .26416 m
.5087 .26416 L
.5087 .27802 L
.43542 .27802 L
.43542 .26416 L
s
.43542 .27802 m
.5087 .27802 L
.5087 .29213 L
.43542 .29213 L
.43542 .27802 L
s
.43542 .29213 m
.5087 .29213 L
.5087 .30643 L
.43542 .30643 L
.43542 .29213 L
s
.43542 .30643 m
.5087 .30643 L
.5087 .32081 L
.43542 .32081 L
.43542 .30643 L
s
.43542 .32081 m
.5087 .32081 L
.5087 .33519 L
.43542 .33519 L
.43542 .32081 L
s
.43542 .33519 m
.5087 .33519 L
.5087 .34949 L
.43542 .34949 L
.43542 .33519 L
s
.43542 .34949 m
.5087 .34949 L
.5087 .36361 L
.43542 .36361 L
.43542 .34949 L
s
.43542 .36361 m
.5087 .36361 L
.5087 .37746 L
.43542 .37746 L
.43542 .36361 L
s
.43542 .37746 m
.5087 .37746 L
.5087 .39096 L
.43542 .39096 L
.43542 .37746 L
s
.43542 .39096 m
.5087 .39096 L
.5087 .40404 L
.43542 .40404 L
.43542 .39096 L
s
.43542 .40404 m
.5087 .40404 L
.5087 .4166 L
.43542 .4166 L
.43542 .40404 L
s
.43542 .4166 m
.5087 .4166 L
.5087 .42856 L
.43542 .42856 L
.43542 .4166 L
s
.43542 .42856 m
.5087 .42856 L
.5087 .43987 L
.43542 .43987 L
.43542 .42856 L
s
.43542 .43987 m
.5087 .43987 L
.5087 .45044 L
.43542 .45044 L
.43542 .43987 L
s
.43542 .45044 m
.5087 .45044 L
.5087 .46021 L
.43542 .46021 L
.43542 .45044 L
s
.43542 .46021 m
.5087 .46021 L
.5087 .46912 L
.43542 .46912 L
.43542 .46021 L
s
.43542 .46912 m
.5087 .46912 L
.5087 .47712 L
.43542 .47712 L
.43542 .46912 L
s
.43542 .47712 m
.5087 .47712 L
.5087 .48415 L
.43542 .48415 L
.43542 .47712 L
s
.43542 .48415 m
.5087 .48415 L
.5087 .49018 L
.43542 .49018 L
.43542 .48415 L
s
.43542 .49018 m
.5087 .49018 L
.5087 .49516 L
.43542 .49516 L
.43542 .49018 L
s
.43542 .49516 m
.5087 .49516 L
.5087 .49907 L
.43542 .49907 L
.43542 .49516 L
s
.43542 .49907 m
.5087 .49907 L
.5087 .50187 L
.43542 .50187 L
.43542 .49907 L
s
.43542 .50187 m
.5087 .50187 L
.5087 .50357 L
.43542 .50357 L
.43542 .50187 L
s
.43542 .50357 m
.5087 .50357 L
.5087 .50413 L
.43542 .50413 L
.43542 .50357 L
s
.97619 .01528 m
.97619 .04583 L
.97619 .07638 L
.97619 .10694 L
.97619 .13749 L
.97619 .16804 L
.97619 .1986 L
.97619 .22915 L
.97619 .2597 L
.97619 .29026 L
.97619 .32081 L
.97619 .35136 L
.97619 .38192 L
.97619 .41247 L
.97619 .44302 L
.97619 .47358 L
.97619 .50413 L
.97619 .53468 L
.97619 .56524 L
.97619 .59579 L
.97619 .62635 L
.97619 .62635 L
.97619 .59579 L
.97619 .56524 L
.97619 .53468 L
.97619 .50413 L
.97619 .47358 L
.97619 .44302 L
.97619 .41247 L
.97619 .38192 L
.97619 .35136 L
.97619 .32081 L
.97619 .29026 L
.97619 .2597 L
.97619 .22915 L
.97619 .1986 L
.97619 .16804 L
.97619 .13749 L
.97619 .10694 L
.97619 .07638 L
.97619 .04583 L
.97619 .01528 L
.97619 .01528 L
s
.97619 .32081 m
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
s
.97619 .62635 m
.97619 .6254 L
.97619 .62258 L
.97619 .6179 L
.97619 .61139 L
.97619 .60309 L
.97619 .59304 L
.97619 .58132 L
.97619 .56799 L
.97619 .55314 L
.97619 .53686 L
.97619 .51924 L
.97619 .5004 L
.97619 .48045 L
.97619 .45952 L
.97619 .43773 L
.97619 .41523 L
.97619 .39214 L
.97619 .36861 L
.97619 .34478 L
.97619 .32081 L
.97619 .29684 L
.97619 .27301 L
.97619 .24949 L
.97619 .2264 L
.97619 .20389 L
.97619 .1821 L
.97619 .16117 L
.97619 .14122 L
.97619 .12238 L
.97619 .10477 L
.97619 .08848 L
.97619 .07363 L
.97619 .0603 L
.97619 .04858 L
.97619 .03853 L
.97619 .03023 L
.97619 .02372 L
.97619 .01904 L
.97619 .01622 L
.97619 .01528 L
.97619 .01622 L
.97619 .01904 L
.97619 .02372 L
.97619 .03023 L
.97619 .03853 L
.97619 .04858 L
.97619 .0603 L
.97619 .07363 L
.97619 .08848 L
Mistroke
.97619 .10477 L
.97619 .12238 L
.97619 .14122 L
.97619 .16117 L
.97619 .1821 L
.97619 .20389 L
.97619 .2264 L
.97619 .24949 L
.97619 .27301 L
.97619 .29684 L
.97619 .32081 L
.97619 .34478 L
.97619 .36861 L
.97619 .39214 L
.97619 .41523 L
.97619 .43773 L
.97619 .45952 L
.97619 .48045 L
.97619 .5004 L
.97619 .51924 L
.97619 .53686 L
.97619 .55314 L
.97619 .56799 L
.97619 .58132 L
.97619 .59304 L
.97619 .60309 L
.97619 .61139 L
.97619 .6179 L
.97619 .62258 L
.97619 .6254 L
.97619 .62635 L
Mfstroke
.039 .916 .04 r
.02381 .30646 m
.25064 .22389 L
s
0 0 0 r
2.5 Mabswid
.25064 .22389 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .32081 m
.24813 .24107 L
s
0 0 0 r
2.5 Mabswid
.24813 .24107 Mdot
.039 .916 .04 r
.5 Mabswid
.03426 .33517 m
.24614 .25805 L
s
0 0 0 r
2.5 Mabswid
.24614 .25805 Mdot
.039 .916 .04 r
.5 Mabswid
.02638 .30577 m
.24527 .26717 L
s
0 0 0 r
2.5 Mabswid
.24527 .26717 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .32081 m
.24409 .28289 L
s
0 0 0 r
2.5 Mabswid
.24409 .28289 Mdot
.039 .916 .04 r
.5 Mabswid
.03169 .33586 m
.24331 .29854 L
s
0 0 0 r
2.5 Mabswid
.24331 .29854 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .30553 m
.2431 .30553 L
s
0 0 0 r
2.5 Mabswid
.2431 .30553 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .32081 m
.24291 .32081 L
s
0 0 0 r
2.5 Mabswid
.24291 .32081 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .33609 m
.2431 .33609 L
s
0 0 0 r
2.5 Mabswid
.2431 .33609 Mdot
.039 .916 .04 r
.5 Mabswid
.03169 .30577 m
.24331 .34308 L
s
0 0 0 r
2.5 Mabswid
.24331 .34308 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .32081 m
.24409 .35873 L
s
0 0 0 r
2.5 Mabswid
.24409 .35873 Mdot
.039 .916 .04 r
.5 Mabswid
.02638 .33586 m
.24527 .37445 L
s
0 0 0 r
2.5 Mabswid
.24527 .37445 Mdot
.039 .916 .04 r
.5 Mabswid
.03426 .30646 m
.24614 .38357 L
s
0 0 0 r
2.5 Mabswid
.24614 .38357 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .32081 m
.24813 .40056 L
s
0 0 0 r
2.5 Mabswid
.24813 .40056 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .33517 m
.25064 .41773 L
s
0 0 0 r
2.5 Mabswid
.25064 .41773 Mdot
.039 .916 .04 r
.5 Mabswid
.25064 .22389 m
.35432 .20643 L
s
0 0 0 r
2.5 Mabswid
.35432 .20643 Mdot
.039 .916 .04 r
.5 Mabswid
.24813 .24107 m
.357 .22148 L
s
0 0 0 r
2.5 Mabswid
.357 .22148 Mdot
.039 .916 .04 r
.5 Mabswid
.24614 .25805 m
.35927 .23644 L
s
0 0 0 r
2.5 Mabswid
.35927 .23644 Mdot
.039 .916 .04 r
.5 Mabswid
.24527 .26717 m
.36182 .25739 L
s
0 0 0 r
2.5 Mabswid
.36182 .25739 Mdot
.039 .916 .04 r
.5 Mabswid
.24409 .28289 m
.36315 .2718 L
s
0 0 0 r
2.5 Mabswid
.36315 .2718 Mdot
.039 .916 .04 r
.5 Mabswid
.24331 .29854 m
.36414 .28619 L
s
0 0 0 r
2.5 Mabswid
.36414 .28619 Mdot
.039 .916 .04 r
.5 Mabswid
.2431 .30553 m
.36496 .30658 L
s
0 0 0 r
2.5 Mabswid
.36496 .30658 Mdot
.039 .916 .04 r
.5 Mabswid
.24291 .32081 m
.36512 .32081 L
s
0 0 0 r
2.5 Mabswid
.36512 .32081 Mdot
.039 .916 .04 r
.5 Mabswid
.2431 .33609 m
.36496 .33505 L
s
0 0 0 r
2.5 Mabswid
.36496 .33505 Mdot
.039 .916 .04 r
.5 Mabswid
.24331 .34308 m
.36414 .35543 L
s
0 0 0 r
2.5 Mabswid
.36414 .35543 Mdot
.039 .916 .04 r
.5 Mabswid
.24409 .35873 m
.36315 .36982 L
s
0 0 0 r
2.5 Mabswid
.36315 .36982 Mdot
.039 .916 .04 r
.5 Mabswid
.24527 .37445 m
.36182 .38423 L
s
0 0 0 r
2.5 Mabswid
.36182 .38423 Mdot
.039 .916 .04 r
.5 Mabswid
.24614 .38357 m
.35927 .40518 L
s
0 0 0 r
2.5 Mabswid
.35927 .40518 Mdot
.039 .916 .04 r
.5 Mabswid
.24813 .40056 m
.357 .42014 L
s
0 0 0 r
2.5 Mabswid
.357 .42014 Mdot
.039 .916 .04 r
.5 Mabswid
.25064 .41773 m
.35432 .43519 L
s
0 0 0 r
2.5 Mabswid
.35432 .43519 Mdot
.039 .916 .04 r
.5 Mabswid
.35432 .20643 m
.43059 .19445 L
s
0 0 0 r
2.5 Mabswid
.43059 .19445 Mdot
.039 .916 .04 r
.5 Mabswid
.357 .22148 m
.42971 .20783 L
s
0 0 0 r
2.5 Mabswid
.42971 .20783 Mdot
.039 .916 .04 r
.5 Mabswid
.35927 .23644 m
.42894 .22124 L
s
0 0 0 r
2.5 Mabswid
.42894 .22124 Mdot
.039 .916 .04 r
.5 Mabswid
.36182 .25739 m
.4275 .25257 L
s
0 0 0 r
2.5 Mabswid
.4275 .25257 Mdot
.039 .916 .04 r
.5 Mabswid
.36315 .2718 m
.42707 .26543 L
s
0 0 0 r
2.5 Mabswid
.42707 .26543 Mdot
.039 .916 .04 r
.5 Mabswid
.36414 .28619 m
.42672 .27831 L
s
0 0 0 r
2.5 Mabswid
.42672 .27831 Mdot
.039 .916 .04 r
.5 Mabswid
.36496 .30658 m
.42627 .30811 L
s
0 0 0 r
2.5 Mabswid
.42627 .30811 Mdot
.039 .916 .04 r
.5 Mabswid
.36512 .32081 m
.42623 .32081 L
s
0 0 0 r
2.5 Mabswid
.42623 .32081 Mdot
.039 .916 .04 r
.5 Mabswid
.36496 .33505 m
.42627 .33351 L
s
0 0 0 r
2.5 Mabswid
.42627 .33351 Mdot
.039 .916 .04 r
.5 Mabswid
.36414 .35543 m
.42672 .36332 L
s
0 0 0 r
2.5 Mabswid
.42672 .36332 Mdot
.039 .916 .04 r
.5 Mabswid
.36315 .36982 m
.42707 .37619 L
s
0 0 0 r
2.5 Mabswid
.42707 .37619 Mdot
.039 .916 .04 r
.5 Mabswid
.36182 .38423 m
.4275 .38905 L
s
0 0 0 r
2.5 Mabswid
.4275 .38905 Mdot
.039 .916 .04 r
.5 Mabswid
.35927 .40518 m
.42894 .42038 L
s
0 0 0 r
2.5 Mabswid
.42894 .42038 Mdot
.039 .916 .04 r
.5 Mabswid
.357 .42014 m
.42971 .43379 L
s
0 0 0 r
2.5 Mabswid
.42971 .43379 Mdot
.039 .916 .04 r
.5 Mabswid
.35432 .43519 m
.43059 .44717 L
s
0 0 0 r
2.5 Mabswid
.43059 .44717 Mdot
.039 .916 .04 r
.5 Mabswid
.43059 .19445 m
.51321 .18986 L
s
0 0 0 r
2.5 Mabswid
.51321 .18986 Mdot
.039 .916 .04 r
.5 Mabswid
.42971 .20783 m
.514 .20148 L
s
0 0 0 r
2.5 Mabswid
.514 .20148 Mdot
.039 .916 .04 r
.5 Mabswid
.42894 .22124 m
.51472 .21312 L
s
0 0 0 r
2.5 Mabswid
.51472 .21312 Mdot
.039 .916 .04 r
.5 Mabswid
.4275 .25257 m
.51654 .25041 L
s
0 0 0 r
2.5 Mabswid
.51654 .25041 Mdot
.039 .916 .04 r
.5 Mabswid
.42707 .26543 m
.51693 .26167 L
s
0 0 0 r
2.5 Mabswid
.51693 .26167 Mdot
.039 .916 .04 r
.5 Mabswid
.42672 .27831 m
.51726 .27292 L
s
0 0 0 r
2.5 Mabswid
.51726 .27292 Mdot
.039 .916 .04 r
.5 Mabswid
.42627 .30811 m
.51786 .30967 L
s
0 0 0 r
2.5 Mabswid
.51786 .30967 Mdot
.039 .916 .04 r
.5 Mabswid
.42623 .32081 m
.51789 .32081 L
s
0 0 0 r
2.5 Mabswid
.51789 .32081 Mdot
.039 .916 .04 r
.5 Mabswid
.42627 .33351 m
.51786 .33195 L
s
0 0 0 r
2.5 Mabswid
.51786 .33195 Mdot
.039 .916 .04 r
.5 Mabswid
.42672 .36332 m
.51726 .3687 L
s
0 0 0 r
2.5 Mabswid
.51726 .3687 Mdot
.039 .916 .04 r
.5 Mabswid
.42707 .37619 m
.51693 .37995 L
s
0 0 0 r
2.5 Mabswid
.51693 .37995 Mdot
.039 .916 .04 r
.5 Mabswid
.4275 .38905 m
.51654 .39121 L
s
0 0 0 r
2.5 Mabswid
.51654 .39121 Mdot
.039 .916 .04 r
.5 Mabswid
.42894 .42038 m
.51472 .42851 L
s
0 0 0 r
2.5 Mabswid
.51472 .42851 Mdot
.039 .916 .04 r
.5 Mabswid
.42971 .43379 m
.514 .44014 L
s
0 0 0 r
2.5 Mabswid
.514 .44014 Mdot
.039 .916 .04 r
.5 Mabswid
.43059 .44717 m
.51321 .45176 L
s
0 0 0 r
2.5 Mabswid
.51321 .45176 Mdot
.039 .916 .04 r
.5 Mabswid
.51321 .18986 m
.97619 .16999 L
s
0 0 0 r
2.5 Mabswid
.97619 .16999 Mdot
.039 .916 .04 r
.5 Mabswid
.514 .20148 m
.97619 .16298 L
s
0 0 0 r
2.5 Mabswid
.97619 .16298 Mdot
.039 .916 .04 r
.5 Mabswid
.51472 .21312 m
.97619 .15619 L
s
0 0 0 r
2.5 Mabswid
.97619 .15619 Mdot
.039 .916 .04 r
.5 Mabswid
.51654 .25041 m
.97619 .24445 L
s
0 0 0 r
2.5 Mabswid
.97619 .24445 Mdot
.039 .916 .04 r
.5 Mabswid
.51693 .26167 m
.97619 .23892 L
s
0 0 0 r
2.5 Mabswid
.97619 .23892 Mdot
.039 .916 .04 r
.5 Mabswid
.51726 .27292 m
.97619 .23345 L
s
0 0 0 r
2.5 Mabswid
.97619 .23345 Mdot
.039 .916 .04 r
.5 Mabswid
.51786 .30967 m
.97619 .32591 L
s
0 0 0 r
2.5 Mabswid
.97619 .32591 Mdot
.039 .916 .04 r
.5 Mabswid
.51789 .32081 m
.97619 .32081 L
s
0 0 0 r
2.5 Mabswid
.97619 .32081 Mdot
.039 .916 .04 r
.5 Mabswid
.51786 .33195 m
.97619 .31571 L
s
0 0 0 r
2.5 Mabswid
.97619 .31571 Mdot
.039 .916 .04 r
.5 Mabswid
.51726 .3687 m
.97619 .40817 L
s
0 0 0 r
2.5 Mabswid
.97619 .40817 Mdot
.039 .916 .04 r
.5 Mabswid
.51693 .37995 m
.97619 .4027 L
s
0 0 0 r
2.5 Mabswid
.97619 .4027 Mdot
.039 .916 .04 r
.5 Mabswid
.51654 .39121 m
.97619 .39717 L
s
0 0 0 r
2.5 Mabswid
.97619 .39717 Mdot
.039 .916 .04 r
.5 Mabswid
.51472 .42851 m
.97619 .48543 L
s
0 0 0 r
2.5 Mabswid
.97619 .48543 Mdot
.039 .916 .04 r
.5 Mabswid
.514 .44014 m
.97619 .47865 L
s
0 0 0 r
2.5 Mabswid
.97619 .47865 Mdot
.039 .916 .04 r
.5 Mabswid
.51321 .45176 m
.97619 .47163 L
s
0 0 0 r
2.5 Mabswid
.97619 .47163 Mdot
0 0 m
1 0 L
1 .64162 L
0 .64162 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{659.812, 423.375},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 658.812}, {422.375, 0}} -> {-4.81662, -52.5006, \
0.248596, 0.248596}},
  CellTags->"Lens Optimizations"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Timing[sol1 = 
\tOptimizeSystem[{
\tMove[LineOfRays[5],0,22.5],
\tlenses,
\tMove[Screen[100],{155,27}]},MeritType->{Centered,SurfaceCoordinates}, 
\tSequentialTrace->True]]\
\>", "Input",
  CellTags->"Lens Optimizations"],

Cell[BoxData[
    \({107.29999999999995`\ Second, {SymbolicValues \[Rule] {c1 \[Rule] \
\(-0.027811559075633485`\), c2 \[Rule] \(-0.024985036875868272`\), 
            c3 \[Rule] 0.007972370709738238`, 
            c4 \[Rule] \(-0.0058879006728559165`\)}, 
        NumberOfCycles \[Rule] 1529, 
        FinalMerit \[Rule] 0.08849260863351482`}}\)], "Output",
  CellTags->"Lens Optimizations"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboPlot[plot,sol1, PlotType->TopView, PlotPoints->50];", "Input",
  CellTags->"Lens Optimizations"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .64162 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0290345 0.00611068 0.320811 0.00611068 [
[ 0 0 0 0 ]
[ 1 .64162 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.18111 .16804 m
.31154 .16804 L
.32282 .18332 L
.19457 .18332 L
.18111 .16804 L
F
.19457 .18332 m
.32282 .18332 L
.3324 .1986 L
.20578 .1986 L
.19457 .18332 L
F
.20578 .1986 m
.3324 .1986 L
.3405 .21387 L
.21513 .21387 L
.20578 .1986 L
F
.21513 .21387 m
.3405 .21387 L
.3473 .22915 L
.22288 .22915 L
.21513 .21387 L
F
.22288 .22915 m
.3473 .22915 L
.35289 .24443 L
.2292 .24443 L
.22288 .22915 L
F
.2292 .24443 m
.35289 .24443 L
.35737 .2597 L
.23424 .2597 L
.2292 .24443 L
F
.23424 .2597 m
.35737 .2597 L
.36079 .27498 L
.23808 .27498 L
.23424 .2597 L
F
.23808 .27498 m
.36079 .27498 L
.36321 .29026 L
.24077 .29026 L
.23808 .27498 L
F
.24077 .29026 m
.36321 .29026 L
.36464 .30553 L
.24238 .30553 L
.24077 .29026 L
F
.24238 .30553 m
.36464 .30553 L
.36512 .32081 L
.24291 .32081 L
.24238 .30553 L
F
.24291 .32081 m
.36512 .32081 L
.36464 .33609 L
.24238 .33609 L
.24291 .32081 L
F
.24238 .33609 m
.36464 .33609 L
.36321 .35136 L
.24077 .35136 L
.24238 .33609 L
F
.24077 .35136 m
.36321 .35136 L
.36079 .36664 L
.23808 .36664 L
.24077 .35136 L
F
.23808 .36664 m
.36079 .36664 L
.35737 .38192 L
.23424 .38192 L
.23808 .36664 L
F
.23424 .38192 m
.35737 .38192 L
.35289 .39719 L
.2292 .39719 L
.23424 .38192 L
F
.2292 .39719 m
.35289 .39719 L
.3473 .41247 L
.22288 .41247 L
.2292 .39719 L
F
.22288 .41247 m
.3473 .41247 L
.3405 .42775 L
.21513 .42775 L
.22288 .41247 L
F
.21513 .42775 m
.3405 .42775 L
.3324 .44302 L
.20578 .44302 L
.21513 .42775 L
F
.20578 .44302 m
.3324 .44302 L
.32282 .4583 L
.19457 .4583 L
.20578 .44302 L
F
.19457 .4583 m
.32282 .4583 L
.31154 .47358 L
.18111 .47358 L
.19457 .4583 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.18111 .16804 m
.19457 .18332 L
.20578 .1986 L
.21513 .21387 L
.22288 .22915 L
.2292 .24443 L
.23424 .2597 L
.23808 .27498 L
.24077 .29026 L
.24238 .30553 L
.24291 .32081 L
.24238 .33609 L
.24077 .35136 L
.23808 .36664 L
.23424 .38192 L
.2292 .39719 L
.22288 .41247 L
.21513 .42775 L
.20578 .44302 L
.19457 .4583 L
.18111 .47358 L
.31154 .47358 L
.32282 .4583 L
.3324 .44302 L
.3405 .42775 L
.3473 .41247 L
.35289 .39719 L
.35737 .38192 L
.36079 .36664 L
.36321 .35136 L
.36464 .33609 L
.36512 .32081 L
.36464 .30553 L
.36321 .29026 L
.36079 .27498 L
.35737 .2597 L
.35289 .24443 L
.3473 .22915 L
.3405 .21387 L
.3324 .1986 L
.32282 .18332 L
.31154 .16804 L
.18111 .16804 L
s
.5 g
.18111 .32081 m
.31154 .32081 L
.32282 .32081 L
.19457 .32081 L
.18111 .32081 L
F
.19457 .32081 m
.32282 .32081 L
.3324 .32081 L
.20578 .32081 L
.19457 .32081 L
F
.20578 .32081 m
.3324 .32081 L
.3405 .32081 L
.21513 .32081 L
.20578 .32081 L
F
.21513 .32081 m
.3405 .32081 L
.3473 .32081 L
.22288 .32081 L
.21513 .32081 L
F
.22288 .32081 m
.3473 .32081 L
.35289 .32081 L
.2292 .32081 L
.22288 .32081 L
F
.2292 .32081 m
.35289 .32081 L
.35737 .32081 L
.23424 .32081 L
.2292 .32081 L
F
.23424 .32081 m
.35737 .32081 L
.36079 .32081 L
.23808 .32081 L
.23424 .32081 L
F
.23808 .32081 m
.36079 .32081 L
.36321 .32081 L
.24077 .32081 L
.23808 .32081 L
F
.24077 .32081 m
.36321 .32081 L
.36464 .32081 L
.24238 .32081 L
.24077 .32081 L
F
.24238 .32081 m
.36464 .32081 L
.36512 .32081 L
.24291 .32081 L
.24238 .32081 L
F
.24291 .32081 m
.36512 .32081 L
.36464 .32081 L
.24238 .32081 L
.24291 .32081 L
F
.24238 .32081 m
.36464 .32081 L
.36321 .32081 L
.24077 .32081 L
.24238 .32081 L
F
.24077 .32081 m
.36321 .32081 L
.36079 .32081 L
.23808 .32081 L
.24077 .32081 L
F
.23808 .32081 m
.36079 .32081 L
.35737 .32081 L
.23424 .32081 L
.23808 .32081 L
F
.23424 .32081 m
.35737 .32081 L
.35289 .32081 L
.2292 .32081 L
.23424 .32081 L
F
.2292 .32081 m
.35289 .32081 L
.3473 .32081 L
.22288 .32081 L
.2292 .32081 L
F
.22288 .32081 m
.3473 .32081 L
.3405 .32081 L
.21513 .32081 L
.22288 .32081 L
F
.21513 .32081 m
.3405 .32081 L
.3324 .32081 L
.20578 .32081 L
.21513 .32081 L
F
.20578 .32081 m
.3324 .32081 L
.32282 .32081 L
.19457 .32081 L
.20578 .32081 L
F
.19457 .32081 m
.32282 .32081 L
.31154 .32081 L
.18111 .32081 L
.19457 .32081 L
F
0 g
.18111 .32081 m
.19457 .32081 L
.20578 .32081 L
.21513 .32081 L
.22288 .32081 L
.2292 .32081 L
.23424 .32081 L
.23808 .32081 L
.24077 .32081 L
.24238 .32081 L
.24291 .32081 L
.24238 .32081 L
.24077 .32081 L
.23808 .32081 L
.23424 .32081 L
.2292 .32081 L
.22288 .32081 L
.21513 .32081 L
.20578 .32081 L
.19457 .32081 L
.18111 .32081 L
.31154 .32081 L
.32282 .32081 L
.3324 .32081 L
.3405 .32081 L
.3473 .32081 L
.35289 .32081 L
.35737 .32081 L
.36079 .32081 L
.36321 .32081 L
.36464 .32081 L
.36512 .32081 L
.36464 .32081 L
.36321 .32081 L
.36079 .32081 L
.35737 .32081 L
.35289 .32081 L
.3473 .32081 L
.3405 .32081 L
.3324 .32081 L
.32282 .32081 L
.31154 .32081 L
.18111 .32081 L
s
.18111 .47358 m
.31154 .47358 L
.31154 .47311 L
.18111 .47311 L
.18111 .47358 L
s
.18111 .47311 m
.31154 .47311 L
.31154 .4717 L
.18111 .4717 L
.18111 .47311 L
s
.18111 .4717 m
.31154 .4717 L
.31154 .46936 L
.18111 .46936 L
.18111 .4717 L
s
.18111 .46936 m
.31154 .46936 L
.31154 .4661 L
.18111 .4661 L
.18111 .46936 L
s
.18111 .4661 m
.31154 .4661 L
.31154 .46195 L
.18111 .46195 L
.18111 .4661 L
s
.18111 .46195 m
.31154 .46195 L
.31154 .45693 L
.18111 .45693 L
.18111 .46195 L
s
.18111 .45693 m
.31154 .45693 L
.31154 .45107 L
.18111 .45107 L
.18111 .45693 L
s
.18111 .45107 m
.31154 .45107 L
.31154 .4444 L
.18111 .4444 L
.18111 .45107 L
s
.18111 .4444 m
.31154 .4444 L
.31154 .43698 L
.18111 .43698 L
.18111 .4444 L
s
.18111 .43698 m
.31154 .43698 L
.31154 .42883 L
.18111 .42883 L
.18111 .43698 L
s
.18111 .42883 m
.31154 .42883 L
.31154 .42003 L
.18111 .42003 L
.18111 .42883 L
s
.18111 .42003 m
.31154 .42003 L
.31154 .41061 L
.18111 .41061 L
.18111 .42003 L
s
.18111 .41061 m
.31154 .41061 L
.31154 .40063 L
.18111 .40063 L
.18111 .41061 L
s
.18111 .40063 m
.31154 .40063 L
.31154 .39017 L
.18111 .39017 L
.18111 .40063 L
s
.18111 .39017 m
.31154 .39017 L
.31154 .37927 L
.18111 .37927 L
.18111 .39017 L
s
.18111 .37927 m
.31154 .37927 L
.31154 .36802 L
.18111 .36802 L
.18111 .37927 L
s
.18111 .36802 m
.31154 .36802 L
.31154 .35647 L
.18111 .35647 L
.18111 .36802 L
s
.18111 .35647 m
.31154 .35647 L
.31154 .34471 L
.18111 .34471 L
.18111 .35647 L
s
.18111 .34471 m
.31154 .34471 L
.31154 .3328 L
.18111 .3328 L
.18111 .34471 L
s
.18111 .3328 m
.31154 .3328 L
.31154 .32081 L
.18111 .32081 L
.18111 .3328 L
s
.18111 .32081 m
.31154 .32081 L
.31154 .30882 L
.18111 .30882 L
.18111 .32081 L
s
.18111 .30882 m
.31154 .30882 L
.31154 .29691 L
.18111 .29691 L
.18111 .30882 L
s
.18111 .29691 m
.31154 .29691 L
.31154 .28515 L
.18111 .28515 L
.18111 .29691 L
s
.18111 .28515 m
.31154 .28515 L
.31154 .2736 L
.18111 .2736 L
.18111 .28515 L
s
.18111 .2736 m
.31154 .2736 L
.31154 .26235 L
.18111 .26235 L
.18111 .2736 L
s
.18111 .26235 m
.31154 .26235 L
.31154 .25146 L
.18111 .25146 L
.18111 .26235 L
s
.18111 .25146 m
.31154 .25146 L
.31154 .24099 L
.18111 .24099 L
.18111 .25146 L
s
.18111 .24099 m
.31154 .24099 L
.31154 .23102 L
.18111 .23102 L
.18111 .24099 L
s
.18111 .23102 m
.31154 .23102 L
.31154 .2216 L
.18111 .2216 L
.18111 .23102 L
s
.18111 .2216 m
.31154 .2216 L
.31154 .21279 L
.18111 .21279 L
.18111 .2216 L
s
.18111 .21279 m
.31154 .21279 L
.31154 .20465 L
.18111 .20465 L
.18111 .21279 L
s
.18111 .20465 m
.31154 .20465 L
.31154 .19722 L
.18111 .19722 L
.18111 .20465 L
s
.18111 .19722 m
.31154 .19722 L
.31154 .19056 L
.18111 .19056 L
.18111 .19722 L
s
.18111 .19056 m
.31154 .19056 L
.31154 .18469 L
.18111 .18469 L
.18111 .19056 L
s
.18111 .18469 m
.31154 .18469 L
.31154 .17967 L
.18111 .17967 L
.18111 .18469 L
s
.18111 .17967 m
.31154 .17967 L
.31154 .17552 L
.18111 .17552 L
.18111 .17967 L
s
.18111 .17552 m
.31154 .17552 L
.31154 .17226 L
.18111 .17226 L
.18111 .17552 L
s
.18111 .17226 m
.31154 .17226 L
.31154 .16992 L
.18111 .16992 L
.18111 .17226 L
s
.18111 .16992 m
.31154 .16992 L
.31154 .16851 L
.18111 .16851 L
.18111 .16992 L
s
.18111 .16851 m
.31154 .16851 L
.31154 .16804 L
.18111 .16804 L
.18111 .16851 L
s
.18111 .16804 m
.31154 .16804 L
.31154 .16851 L
.18111 .16851 L
.18111 .16804 L
s
.18111 .16851 m
.31154 .16851 L
.31154 .16992 L
.18111 .16992 L
.18111 .16851 L
s
.18111 .16992 m
.31154 .16992 L
.31154 .17226 L
.18111 .17226 L
.18111 .16992 L
s
.18111 .17226 m
.31154 .17226 L
.31154 .17552 L
.18111 .17552 L
.18111 .17226 L
s
.18111 .17552 m
.31154 .17552 L
.31154 .17967 L
.18111 .17967 L
.18111 .17552 L
s
.18111 .17967 m
.31154 .17967 L
.31154 .18469 L
.18111 .18469 L
.18111 .17967 L
s
.18111 .18469 m
.31154 .18469 L
.31154 .19056 L
.18111 .19056 L
.18111 .18469 L
s
.18111 .19056 m
.31154 .19056 L
.31154 .19722 L
.18111 .19722 L
.18111 .19056 L
s
.18111 .19722 m
.31154 .19722 L
.31154 .20465 L
.18111 .20465 L
.18111 .19722 L
s
.18111 .20465 m
.31154 .20465 L
.31154 .21279 L
.18111 .21279 L
.18111 .20465 L
s
.18111 .21279 m
.31154 .21279 L
.31154 .2216 L
.18111 .2216 L
.18111 .21279 L
s
.18111 .2216 m
.31154 .2216 L
.31154 .23102 L
.18111 .23102 L
.18111 .2216 L
s
.18111 .23102 m
.31154 .23102 L
.31154 .24099 L
.18111 .24099 L
.18111 .23102 L
s
.18111 .24099 m
.31154 .24099 L
.31154 .25146 L
.18111 .25146 L
.18111 .24099 L
s
.18111 .25146 m
.31154 .25146 L
.31154 .26235 L
.18111 .26235 L
.18111 .25146 L
s
.18111 .26235 m
.31154 .26235 L
.31154 .2736 L
.18111 .2736 L
.18111 .26235 L
s
.18111 .2736 m
.31154 .2736 L
.31154 .28515 L
.18111 .28515 L
.18111 .2736 L
s
.18111 .28515 m
.31154 .28515 L
.31154 .29691 L
.18111 .29691 L
.18111 .28515 L
s
.18111 .29691 m
.31154 .29691 L
.31154 .30882 L
.18111 .30882 L
.18111 .29691 L
s
.18111 .30882 m
.31154 .30882 L
.31154 .32081 L
.18111 .32081 L
.18111 .30882 L
s
.18111 .32081 m
.31154 .32081 L
.31154 .3328 L
.18111 .3328 L
.18111 .32081 L
s
.18111 .3328 m
.31154 .3328 L
.31154 .34471 L
.18111 .34471 L
.18111 .3328 L
s
.18111 .34471 m
.31154 .34471 L
.31154 .35647 L
.18111 .35647 L
.18111 .34471 L
s
.18111 .35647 m
.31154 .35647 L
.31154 .36802 L
.18111 .36802 L
.18111 .35647 L
s
.18111 .36802 m
.31154 .36802 L
.31154 .37927 L
.18111 .37927 L
.18111 .36802 L
s
.18111 .37927 m
.31154 .37927 L
.31154 .39017 L
.18111 .39017 L
.18111 .37927 L
s
.18111 .39017 m
.31154 .39017 L
.31154 .40063 L
.18111 .40063 L
.18111 .39017 L
s
.18111 .40063 m
.31154 .40063 L
.31154 .41061 L
.18111 .41061 L
.18111 .40063 L
s
.18111 .41061 m
.31154 .41061 L
.31154 .42003 L
.18111 .42003 L
.18111 .41061 L
s
.18111 .42003 m
.31154 .42003 L
.31154 .42883 L
.18111 .42883 L
.18111 .42003 L
s
.18111 .42883 m
.31154 .42883 L
.31154 .43698 L
.18111 .43698 L
.18111 .42883 L
s
.18111 .43698 m
.31154 .43698 L
.31154 .4444 L
.18111 .4444 L
.18111 .43698 L
s
.18111 .4444 m
.31154 .4444 L
.31154 .45107 L
.18111 .45107 L
.18111 .4444 L
s
.18111 .45107 m
.31154 .45107 L
.31154 .45693 L
.18111 .45693 L
.18111 .45107 L
s
.18111 .45693 m
.31154 .45693 L
.31154 .46195 L
.18111 .46195 L
.18111 .45693 L
s
.18111 .46195 m
.31154 .46195 L
.31154 .4661 L
.18111 .4661 L
.18111 .46195 L
s
.18111 .4661 m
.31154 .4661 L
.31154 .46936 L
.18111 .46936 L
.18111 .4661 L
s
.18111 .46936 m
.31154 .46936 L
.31154 .4717 L
.18111 .4717 L
.18111 .46936 L
s
.18111 .4717 m
.31154 .4717 L
.31154 .47311 L
.18111 .47311 L
.18111 .4717 L
s
.18111 .47311 m
.31154 .47311 L
.31154 .47358 L
.18111 .47358 L
.18111 .47311 L
s
.5 g
.44847 .13749 m
.50157 .13749 L
.50469 .15582 L
.4442 .15582 L
.44847 .13749 L
F
.4442 .15582 m
.50469 .15582 L
.50747 .17415 L
.44039 .17415 L
.4442 .15582 L
F
.44039 .17415 m
.50747 .17415 L
.50993 .19249 L
.43705 .19249 L
.44039 .17415 L
F
.43705 .19249 m
.50993 .19249 L
.51204 .21082 L
.43416 .21082 L
.43705 .19249 L
F
.43416 .21082 m
.51204 .21082 L
.51383 .22915 L
.43173 .22915 L
.43416 .21082 L
F
.43173 .22915 m
.51383 .22915 L
.5153 .24748 L
.42974 .24748 L
.43173 .22915 L
F
.42974 .24748 m
.5153 .24748 L
.51643 .26581 L
.4282 .26581 L
.42974 .24748 L
F
.4282 .26581 m
.51643 .26581 L
.51724 .28415 L
.42711 .28415 L
.4282 .26581 L
F
.42711 .28415 m
.51724 .28415 L
.51773 .30248 L
.42645 .30248 L
.42711 .28415 L
F
.42645 .30248 m
.51773 .30248 L
.51789 .32081 L
.42623 .32081 L
.42645 .30248 L
F
.42623 .32081 m
.51789 .32081 L
.51773 .33914 L
.42645 .33914 L
.42623 .32081 L
F
.42645 .33914 m
.51773 .33914 L
.51724 .35748 L
.42711 .35748 L
.42645 .33914 L
F
.42711 .35748 m
.51724 .35748 L
.51643 .37581 L
.4282 .37581 L
.42711 .35748 L
F
.4282 .37581 m
.51643 .37581 L
.5153 .39414 L
.42974 .39414 L
.4282 .37581 L
F
.42974 .39414 m
.5153 .39414 L
.51383 .41247 L
.43173 .41247 L
.42974 .39414 L
F
.43173 .41247 m
.51383 .41247 L
.51204 .4308 L
.43416 .4308 L
.43173 .41247 L
F
.43416 .4308 m
.51204 .4308 L
.50993 .44914 L
.43705 .44914 L
.43416 .4308 L
F
.43705 .44914 m
.50993 .44914 L
.50747 .46747 L
.44039 .46747 L
.43705 .44914 L
F
.44039 .46747 m
.50747 .46747 L
.50469 .4858 L
.4442 .4858 L
.44039 .46747 L
F
.4442 .4858 m
.50469 .4858 L
.50157 .50413 L
.44847 .50413 L
.4442 .4858 L
F
0 g
.44847 .13749 m
.4442 .15582 L
.44039 .17415 L
.43705 .19249 L
.43416 .21082 L
.43173 .22915 L
.42974 .24748 L
.4282 .26581 L
.42711 .28415 L
.42645 .30248 L
.42623 .32081 L
.42645 .33914 L
.42711 .35748 L
.4282 .37581 L
.42974 .39414 L
.43173 .41247 L
.43416 .4308 L
.43705 .44914 L
.44039 .46747 L
.4442 .4858 L
.44847 .50413 L
.50157 .50413 L
.50469 .4858 L
.50747 .46747 L
.50993 .44914 L
.51204 .4308 L
.51383 .41247 L
.5153 .39414 L
.51643 .37581 L
.51724 .35748 L
.51773 .33914 L
.51789 .32081 L
.51773 .30248 L
.51724 .28415 L
.51643 .26581 L
.5153 .24748 L
.51383 .22915 L
.51204 .21082 L
.50993 .19249 L
.50747 .17415 L
.50469 .15582 L
.50157 .13749 L
.44847 .13749 L
s
.5 g
.44847 .32081 m
.50157 .32081 L
.50469 .32081 L
.4442 .32081 L
.44847 .32081 L
F
.4442 .32081 m
.50469 .32081 L
.50747 .32081 L
.44039 .32081 L
.4442 .32081 L
F
.44039 .32081 m
.50747 .32081 L
.50993 .32081 L
.43705 .32081 L
.44039 .32081 L
F
.43705 .32081 m
.50993 .32081 L
.51204 .32081 L
.43416 .32081 L
.43705 .32081 L
F
.43416 .32081 m
.51204 .32081 L
.51383 .32081 L
.43173 .32081 L
.43416 .32081 L
F
.43173 .32081 m
.51383 .32081 L
.5153 .32081 L
.42974 .32081 L
.43173 .32081 L
F
.42974 .32081 m
.5153 .32081 L
.51643 .32081 L
.4282 .32081 L
.42974 .32081 L
F
.4282 .32081 m
.51643 .32081 L
.51724 .32081 L
.42711 .32081 L
.4282 .32081 L
F
.42711 .32081 m
.51724 .32081 L
.51773 .32081 L
.42645 .32081 L
.42711 .32081 L
F
.42645 .32081 m
.51773 .32081 L
.51789 .32081 L
.42623 .32081 L
.42645 .32081 L
F
.42623 .32081 m
.51789 .32081 L
.51773 .32081 L
.42645 .32081 L
.42623 .32081 L
F
.42645 .32081 m
.51773 .32081 L
.51724 .32081 L
.42711 .32081 L
.42645 .32081 L
F
.42711 .32081 m
.51724 .32081 L
.51643 .32081 L
.4282 .32081 L
.42711 .32081 L
F
.4282 .32081 m
.51643 .32081 L
.5153 .32081 L
.42974 .32081 L
.4282 .32081 L
F
.42974 .32081 m
.5153 .32081 L
.51383 .32081 L
.43173 .32081 L
.42974 .32081 L
F
.43173 .32081 m
.51383 .32081 L
.51204 .32081 L
.43416 .32081 L
.43173 .32081 L
F
.43416 .32081 m
.51204 .32081 L
.50993 .32081 L
.43705 .32081 L
.43416 .32081 L
F
.43705 .32081 m
.50993 .32081 L
.50747 .32081 L
.44039 .32081 L
.43705 .32081 L
F
.44039 .32081 m
.50747 .32081 L
.50469 .32081 L
.4442 .32081 L
.44039 .32081 L
F
.4442 .32081 m
.50469 .32081 L
.50157 .32081 L
.44847 .32081 L
.4442 .32081 L
F
0 g
.44847 .32081 m
.4442 .32081 L
.44039 .32081 L
.43705 .32081 L
.43416 .32081 L
.43173 .32081 L
.42974 .32081 L
.4282 .32081 L
.42711 .32081 L
.42645 .32081 L
.42623 .32081 L
.42645 .32081 L
.42711 .32081 L
.4282 .32081 L
.42974 .32081 L
.43173 .32081 L
.43416 .32081 L
.43705 .32081 L
.44039 .32081 L
.4442 .32081 L
.44847 .32081 L
.50157 .32081 L
.50469 .32081 L
.50747 .32081 L
.50993 .32081 L
.51204 .32081 L
.51383 .32081 L
.5153 .32081 L
.51643 .32081 L
.51724 .32081 L
.51773 .32081 L
.51789 .32081 L
.51773 .32081 L
.51724 .32081 L
.51643 .32081 L
.5153 .32081 L
.51383 .32081 L
.51204 .32081 L
.50993 .32081 L
.50747 .32081 L
.50469 .32081 L
.50157 .32081 L
.44847 .32081 L
s
.44847 .50413 m
.50157 .50413 L
.50157 .50357 L
.44847 .50357 L
.44847 .50413 L
s
.44847 .50357 m
.50157 .50357 L
.50157 .50187 L
.44847 .50187 L
.44847 .50357 L
s
.44847 .50187 m
.50157 .50187 L
.50157 .49907 L
.44847 .49907 L
.44847 .50187 L
s
.44847 .49907 m
.50157 .49907 L
.50157 .49516 L
.44847 .49516 L
.44847 .49907 L
s
.44847 .49516 m
.50157 .49516 L
.50157 .49018 L
.44847 .49018 L
.44847 .49516 L
s
.44847 .49018 m
.50157 .49018 L
.50157 .48415 L
.44847 .48415 L
.44847 .49018 L
s
.44847 .48415 m
.50157 .48415 L
.50157 .47712 L
.44847 .47712 L
.44847 .48415 L
s
.44847 .47712 m
.50157 .47712 L
.50157 .46912 L
.44847 .46912 L
.44847 .47712 L
s
.44847 .46912 m
.50157 .46912 L
.50157 .46021 L
.44847 .46021 L
.44847 .46912 L
s
.44847 .46021 m
.50157 .46021 L
.50157 .45044 L
.44847 .45044 L
.44847 .46021 L
s
.44847 .45044 m
.50157 .45044 L
.50157 .43987 L
.44847 .43987 L
.44847 .45044 L
s
.44847 .43987 m
.50157 .43987 L
.50157 .42856 L
.44847 .42856 L
.44847 .43987 L
s
.44847 .42856 m
.50157 .42856 L
.50157 .4166 L
.44847 .4166 L
.44847 .42856 L
s
.44847 .4166 m
.50157 .4166 L
.50157 .40404 L
.44847 .40404 L
.44847 .4166 L
s
.44847 .40404 m
.50157 .40404 L
.50157 .39096 L
.44847 .39096 L
.44847 .40404 L
s
.44847 .39096 m
.50157 .39096 L
.50157 .37746 L
.44847 .37746 L
.44847 .39096 L
s
.44847 .37746 m
.50157 .37746 L
.50157 .36361 L
.44847 .36361 L
.44847 .37746 L
s
.44847 .36361 m
.50157 .36361 L
.50157 .34949 L
.44847 .34949 L
.44847 .36361 L
s
.44847 .34949 m
.50157 .34949 L
.50157 .33519 L
.44847 .33519 L
.44847 .34949 L
s
.44847 .33519 m
.50157 .33519 L
.50157 .32081 L
.44847 .32081 L
.44847 .33519 L
s
.44847 .32081 m
.50157 .32081 L
.50157 .30643 L
.44847 .30643 L
.44847 .32081 L
s
.44847 .30643 m
.50157 .30643 L
.50157 .29213 L
.44847 .29213 L
.44847 .30643 L
s
.44847 .29213 m
.50157 .29213 L
.50157 .27802 L
.44847 .27802 L
.44847 .29213 L
s
.44847 .27802 m
.50157 .27802 L
.50157 .26416 L
.44847 .26416 L
.44847 .27802 L
s
.44847 .26416 m
.50157 .26416 L
.50157 .25066 L
.44847 .25066 L
.44847 .26416 L
s
.44847 .25066 m
.50157 .25066 L
.50157 .23759 L
.44847 .23759 L
.44847 .25066 L
s
.44847 .23759 m
.50157 .23759 L
.50157 .22503 L
.44847 .22503 L
.44847 .23759 L
s
.44847 .22503 m
.50157 .22503 L
.50157 .21306 L
.44847 .21306 L
.44847 .22503 L
s
.44847 .21306 m
.50157 .21306 L
.50157 .20175 L
.44847 .20175 L
.44847 .21306 L
s
.44847 .20175 m
.50157 .20175 L
.50157 .19118 L
.44847 .19118 L
.44847 .20175 L
s
.44847 .19118 m
.50157 .19118 L
.50157 .18141 L
.44847 .18141 L
.44847 .19118 L
s
.44847 .18141 m
.50157 .18141 L
.50157 .1725 L
.44847 .1725 L
.44847 .18141 L
s
.44847 .1725 m
.50157 .1725 L
.50157 .1645 L
.44847 .1645 L
.44847 .1725 L
s
.44847 .1645 m
.50157 .1645 L
.50157 .15747 L
.44847 .15747 L
.44847 .1645 L
s
.44847 .15747 m
.50157 .15747 L
.50157 .15144 L
.44847 .15144 L
.44847 .15747 L
s
.44847 .15144 m
.50157 .15144 L
.50157 .14646 L
.44847 .14646 L
.44847 .15144 L
s
.44847 .14646 m
.50157 .14646 L
.50157 .14256 L
.44847 .14256 L
.44847 .14646 L
s
.44847 .14256 m
.50157 .14256 L
.50157 .13975 L
.44847 .13975 L
.44847 .14256 L
s
.44847 .13975 m
.50157 .13975 L
.50157 .13806 L
.44847 .13806 L
.44847 .13975 L
s
.44847 .13806 m
.50157 .13806 L
.50157 .13749 L
.44847 .13749 L
.44847 .13806 L
s
.44847 .13749 m
.50157 .13749 L
.50157 .13806 L
.44847 .13806 L
.44847 .13749 L
s
.44847 .13806 m
.50157 .13806 L
.50157 .13975 L
.44847 .13975 L
.44847 .13806 L
s
.44847 .13975 m
.50157 .13975 L
.50157 .14256 L
.44847 .14256 L
.44847 .13975 L
s
.44847 .14256 m
.50157 .14256 L
.50157 .14646 L
.44847 .14646 L
.44847 .14256 L
s
.44847 .14646 m
.50157 .14646 L
.50157 .15144 L
.44847 .15144 L
.44847 .14646 L
s
.44847 .15144 m
.50157 .15144 L
.50157 .15747 L
.44847 .15747 L
.44847 .15144 L
s
.44847 .15747 m
.50157 .15747 L
.50157 .1645 L
.44847 .1645 L
.44847 .15747 L
s
.44847 .1645 m
.50157 .1645 L
.50157 .1725 L
.44847 .1725 L
.44847 .1645 L
s
.44847 .1725 m
.50157 .1725 L
.50157 .18141 L
.44847 .18141 L
.44847 .1725 L
s
.44847 .18141 m
.50157 .18141 L
.50157 .19118 L
.44847 .19118 L
.44847 .18141 L
s
.44847 .19118 m
.50157 .19118 L
.50157 .20175 L
.44847 .20175 L
.44847 .19118 L
s
.44847 .20175 m
.50157 .20175 L
.50157 .21306 L
.44847 .21306 L
.44847 .20175 L
s
.44847 .21306 m
.50157 .21306 L
.50157 .22503 L
.44847 .22503 L
.44847 .21306 L
s
.44847 .22503 m
.50157 .22503 L
.50157 .23759 L
.44847 .23759 L
.44847 .22503 L
s
.44847 .23759 m
.50157 .23759 L
.50157 .25066 L
.44847 .25066 L
.44847 .23759 L
s
.44847 .25066 m
.50157 .25066 L
.50157 .26416 L
.44847 .26416 L
.44847 .25066 L
s
.44847 .26416 m
.50157 .26416 L
.50157 .27802 L
.44847 .27802 L
.44847 .26416 L
s
.44847 .27802 m
.50157 .27802 L
.50157 .29213 L
.44847 .29213 L
.44847 .27802 L
s
.44847 .29213 m
.50157 .29213 L
.50157 .30643 L
.44847 .30643 L
.44847 .29213 L
s
.44847 .30643 m
.50157 .30643 L
.50157 .32081 L
.44847 .32081 L
.44847 .30643 L
s
.44847 .32081 m
.50157 .32081 L
.50157 .33519 L
.44847 .33519 L
.44847 .32081 L
s
.44847 .33519 m
.50157 .33519 L
.50157 .34949 L
.44847 .34949 L
.44847 .33519 L
s
.44847 .34949 m
.50157 .34949 L
.50157 .36361 L
.44847 .36361 L
.44847 .34949 L
s
.44847 .36361 m
.50157 .36361 L
.50157 .37746 L
.44847 .37746 L
.44847 .36361 L
s
.44847 .37746 m
.50157 .37746 L
.50157 .39096 L
.44847 .39096 L
.44847 .37746 L
s
.44847 .39096 m
.50157 .39096 L
.50157 .40404 L
.44847 .40404 L
.44847 .39096 L
s
.44847 .40404 m
.50157 .40404 L
.50157 .4166 L
.44847 .4166 L
.44847 .40404 L
s
.44847 .4166 m
.50157 .4166 L
.50157 .42856 L
.44847 .42856 L
.44847 .4166 L
s
.44847 .42856 m
.50157 .42856 L
.50157 .43987 L
.44847 .43987 L
.44847 .42856 L
s
.44847 .43987 m
.50157 .43987 L
.50157 .45044 L
.44847 .45044 L
.44847 .43987 L
s
.44847 .45044 m
.50157 .45044 L
.50157 .46021 L
.44847 .46021 L
.44847 .45044 L
s
.44847 .46021 m
.50157 .46021 L
.50157 .46912 L
.44847 .46912 L
.44847 .46021 L
s
.44847 .46912 m
.50157 .46912 L
.50157 .47712 L
.44847 .47712 L
.44847 .46912 L
s
.44847 .47712 m
.50157 .47712 L
.50157 .48415 L
.44847 .48415 L
.44847 .47712 L
s
.44847 .48415 m
.50157 .48415 L
.50157 .49018 L
.44847 .49018 L
.44847 .48415 L
s
.44847 .49018 m
.50157 .49018 L
.50157 .49516 L
.44847 .49516 L
.44847 .49018 L
s
.44847 .49516 m
.50157 .49516 L
.50157 .49907 L
.44847 .49907 L
.44847 .49516 L
s
.44847 .49907 m
.50157 .49907 L
.50157 .50187 L
.44847 .50187 L
.44847 .49907 L
s
.44847 .50187 m
.50157 .50187 L
.50157 .50357 L
.44847 .50357 L
.44847 .50187 L
s
.44847 .50357 m
.50157 .50357 L
.50157 .50413 L
.44847 .50413 L
.44847 .50357 L
s
.97619 .01528 m
.97619 .04583 L
.97619 .07638 L
.97619 .10694 L
.97619 .13749 L
.97619 .16804 L
.97619 .1986 L
.97619 .22915 L
.97619 .2597 L
.97619 .29026 L
.97619 .32081 L
.97619 .35136 L
.97619 .38192 L
.97619 .41247 L
.97619 .44302 L
.97619 .47358 L
.97619 .50413 L
.97619 .53468 L
.97619 .56524 L
.97619 .59579 L
.97619 .62635 L
.97619 .62635 L
.97619 .59579 L
.97619 .56524 L
.97619 .53468 L
.97619 .50413 L
.97619 .47358 L
.97619 .44302 L
.97619 .41247 L
.97619 .38192 L
.97619 .35136 L
.97619 .32081 L
.97619 .29026 L
.97619 .2597 L
.97619 .22915 L
.97619 .1986 L
.97619 .16804 L
.97619 .13749 L
.97619 .10694 L
.97619 .07638 L
.97619 .04583 L
.97619 .01528 L
.97619 .01528 L
s
.97619 .32081 m
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
s
.97619 .62635 m
.97619 .6254 L
.97619 .62258 L
.97619 .6179 L
.97619 .61139 L
.97619 .60309 L
.97619 .59304 L
.97619 .58132 L
.97619 .56799 L
.97619 .55314 L
.97619 .53686 L
.97619 .51924 L
.97619 .5004 L
.97619 .48045 L
.97619 .45952 L
.97619 .43773 L
.97619 .41523 L
.97619 .39214 L
.97619 .36861 L
.97619 .34478 L
.97619 .32081 L
.97619 .29684 L
.97619 .27301 L
.97619 .24949 L
.97619 .2264 L
.97619 .20389 L
.97619 .1821 L
.97619 .16117 L
.97619 .14122 L
.97619 .12238 L
.97619 .10477 L
.97619 .08848 L
.97619 .07363 L
.97619 .0603 L
.97619 .04858 L
.97619 .03853 L
.97619 .03023 L
.97619 .02372 L
.97619 .01904 L
.97619 .01622 L
.97619 .01528 L
.97619 .01622 L
.97619 .01904 L
.97619 .02372 L
.97619 .03023 L
.97619 .03853 L
.97619 .04858 L
.97619 .0603 L
.97619 .07363 L
.97619 .08848 L
Mistroke
.97619 .10477 L
.97619 .12238 L
.97619 .14122 L
.97619 .16117 L
.97619 .1821 L
.97619 .20389 L
.97619 .2264 L
.97619 .24949 L
.97619 .27301 L
.97619 .29684 L
.97619 .32081 L
.97619 .34478 L
.97619 .36861 L
.97619 .39214 L
.97619 .41523 L
.97619 .43773 L
.97619 .45952 L
.97619 .48045 L
.97619 .5004 L
.97619 .51924 L
.97619 .53686 L
.97619 .55314 L
.97619 .56799 L
.97619 .58132 L
.97619 .59304 L
.97619 .60309 L
.97619 .61139 L
.97619 .6179 L
.97619 .62258 L
.97619 .6254 L
.97619 .62635 L
Mfstroke
.039 .916 .04 r
.02381 .30646 m
.22474 .23332 L
s
0 0 0 r
2.5 Mabswid
.22474 .23332 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .32081 m
.23033 .24754 L
s
0 0 0 r
2.5 Mabswid
.23033 .24754 Mdot
.039 .916 .04 r
.5 Mabswid
.03426 .33517 m
.23493 .26213 L
s
0 0 0 r
2.5 Mabswid
.23493 .26213 Mdot
.039 .916 .04 r
.5 Mabswid
.02638 .30577 m
.23664 .26869 L
s
0 0 0 r
2.5 Mabswid
.23664 .26869 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .32081 m
.23974 .28366 L
s
0 0 0 r
2.5 Mabswid
.23974 .28366 Mdot
.039 .916 .04 r
.5 Mabswid
.03169 .33586 m
.2418 .29881 L
s
0 0 0 r
2.5 Mabswid
.2418 .29881 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .30553 m
.24238 .30553 L
s
0 0 0 r
2.5 Mabswid
.24238 .30553 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .32081 m
.24291 .32081 L
s
0 0 0 r
2.5 Mabswid
.24291 .32081 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .33609 m
.24238 .33609 L
s
0 0 0 r
2.5 Mabswid
.24238 .33609 Mdot
.039 .916 .04 r
.5 Mabswid
.03169 .30577 m
.2418 .34282 L
s
0 0 0 r
2.5 Mabswid
.2418 .34282 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .32081 m
.23974 .35796 L
s
0 0 0 r
2.5 Mabswid
.23974 .35796 Mdot
.039 .916 .04 r
.5 Mabswid
.02638 .33586 m
.23664 .37293 L
s
0 0 0 r
2.5 Mabswid
.23664 .37293 Mdot
.039 .916 .04 r
.5 Mabswid
.03426 .30646 m
.23493 .37949 L
s
0 0 0 r
2.5 Mabswid
.23493 .37949 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .32081 m
.23033 .39408 L
s
0 0 0 r
2.5 Mabswid
.23033 .39408 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .33517 m
.22474 .4083 L
s
0 0 0 r
2.5 Mabswid
.22474 .4083 Mdot
.039 .916 .04 r
.5 Mabswid
.22474 .23332 m
.32901 .19291 L
s
0 0 0 r
2.5 Mabswid
.32901 .19291 Mdot
.039 .916 .04 r
.5 Mabswid
.23033 .24754 m
.33794 .20876 L
s
0 0 0 r
2.5 Mabswid
.33794 .20876 Mdot
.039 .916 .04 r
.5 Mabswid
.23493 .26213 m
.34565 .22517 L
s
0 0 0 r
2.5 Mabswid
.34565 .22517 Mdot
.039 .916 .04 r
.5 Mabswid
.23664 .26869 m
.35322 .24545 L
s
0 0 0 r
2.5 Mabswid
.35322 .24545 Mdot
.039 .916 .04 r
.5 Mabswid
.23974 .28366 m
.35818 .26297 L
s
0 0 0 r
2.5 Mabswid
.35818 .26297 Mdot
.039 .916 .04 r
.5 Mabswid
.2418 .29881 m
.36182 .28077 L
s
0 0 0 r
2.5 Mabswid
.36182 .28077 Mdot
.039 .916 .04 r
.5 Mabswid
.24238 .30553 m
.36445 .30263 L
s
0 0 0 r
2.5 Mabswid
.36445 .30263 Mdot
.039 .916 .04 r
.5 Mabswid
.24291 .32081 m
.36512 .32081 L
s
0 0 0 r
2.5 Mabswid
.36512 .32081 Mdot
.039 .916 .04 r
.5 Mabswid
.24238 .33609 m
.36445 .33899 L
s
0 0 0 r
2.5 Mabswid
.36445 .33899 Mdot
.039 .916 .04 r
.5 Mabswid
.2418 .34282 m
.36182 .36085 L
s
0 0 0 r
2.5 Mabswid
.36182 .36085 Mdot
.039 .916 .04 r
.5 Mabswid
.23974 .35796 m
.35818 .37866 L
s
0 0 0 r
2.5 Mabswid
.35818 .37866 Mdot
.039 .916 .04 r
.5 Mabswid
.23664 .37293 m
.35322 .39617 L
s
0 0 0 r
2.5 Mabswid
.35322 .39617 Mdot
.039 .916 .04 r
.5 Mabswid
.23493 .37949 m
.34565 .41645 L
s
0 0 0 r
2.5 Mabswid
.34565 .41645 Mdot
.039 .916 .04 r
.5 Mabswid
.23033 .39408 m
.33794 .43287 L
s
0 0 0 r
2.5 Mabswid
.33794 .43287 Mdot
.039 .916 .04 r
.5 Mabswid
.22474 .4083 m
.32901 .44871 L
s
0 0 0 r
2.5 Mabswid
.32901 .44871 Mdot
.039 .916 .04 r
.5 Mabswid
.32901 .19291 m
.44311 .16084 L
s
0 0 0 r
2.5 Mabswid
.44311 .16084 Mdot
.039 .916 .04 r
.5 Mabswid
.33794 .20876 m
.4393 .17986 L
s
0 0 0 r
2.5 Mabswid
.4393 .17986 Mdot
.039 .916 .04 r
.5 Mabswid
.34565 .22517 m
.43595 .19914 L
s
0 0 0 r
2.5 Mabswid
.43595 .19914 Mdot
.039 .916 .04 r
.5 Mabswid
.35322 .24545 m
.43107 .23482 L
s
0 0 0 r
2.5 Mabswid
.43107 .23482 Mdot
.039 .916 .04 r
.5 Mabswid
.35818 .26297 m
.42923 .25305 L
s
0 0 0 r
2.5 Mabswid
.42923 .25305 Mdot
.039 .916 .04 r
.5 Mabswid
.36182 .28077 m
.42782 .27139 L
s
0 0 0 r
2.5 Mabswid
.42782 .27139 Mdot
.039 .916 .04 r
.5 Mabswid
.36445 .30263 m
.42644 .30278 L
s
0 0 0 r
2.5 Mabswid
.42644 .30278 Mdot
.039 .916 .04 r
.5 Mabswid
.36512 .32081 m
.42623 .32081 L
s
0 0 0 r
2.5 Mabswid
.42623 .32081 Mdot
.039 .916 .04 r
.5 Mabswid
.36445 .33899 m
.42644 .33884 L
s
0 0 0 r
2.5 Mabswid
.42644 .33884 Mdot
.039 .916 .04 r
.5 Mabswid
.36182 .36085 m
.42782 .37023 L
s
0 0 0 r
2.5 Mabswid
.42782 .37023 Mdot
.039 .916 .04 r
.5 Mabswid
.35818 .37866 m
.42923 .38857 L
s
0 0 0 r
2.5 Mabswid
.42923 .38857 Mdot
.039 .916 .04 r
.5 Mabswid
.35322 .39617 m
.43107 .4068 L
s
0 0 0 r
2.5 Mabswid
.43107 .4068 Mdot
.039 .916 .04 r
.5 Mabswid
.34565 .41645 m
.43595 .44248 L
s
0 0 0 r
2.5 Mabswid
.43595 .44248 Mdot
.039 .916 .04 r
.5 Mabswid
.33794 .43287 m
.4393 .46177 L
s
0 0 0 r
2.5 Mabswid
.4393 .46177 Mdot
.039 .916 .04 r
.5 Mabswid
.32901 .44871 m
.44311 .48078 L
s
0 0 0 r
2.5 Mabswid
.44311 .48078 Mdot
.039 .916 .04 r
.5 Mabswid
.44311 .16084 m
.50498 .15761 L
s
0 0 0 r
2.5 Mabswid
.50498 .15761 Mdot
.039 .916 .04 r
.5 Mabswid
.4393 .17986 m
.50764 .17531 L
s
0 0 0 r
2.5 Mabswid
.50764 .17531 Mdot
.039 .916 .04 r
.5 Mabswid
.43595 .19914 m
.51001 .19319 L
s
0 0 0 r
2.5 Mabswid
.51001 .19319 Mdot
.039 .916 .04 r
.5 Mabswid
.43107 .23482 m
.51415 .23275 L
s
0 0 0 r
2.5 Mabswid
.51415 .23275 Mdot
.039 .916 .04 r
.5 Mabswid
.42923 .25305 m
.51546 .24983 L
s
0 0 0 r
2.5 Mabswid
.51546 .24983 Mdot
.039 .916 .04 r
.5 Mabswid
.42782 .27139 m
.51649 .26699 L
s
0 0 0 r
2.5 Mabswid
.51649 .26699 Mdot
.039 .916 .04 r
.5 Mabswid
.42644 .30278 m
.51775 .30386 L
s
0 0 0 r
2.5 Mabswid
.51775 .30386 Mdot
.039 .916 .04 r
.5 Mabswid
.42623 .32081 m
.51789 .32081 L
s
0 0 0 r
2.5 Mabswid
.51789 .32081 Mdot
.039 .916 .04 r
.5 Mabswid
.42644 .33884 m
.51775 .33776 L
s
0 0 0 r
2.5 Mabswid
.51775 .33776 Mdot
.039 .916 .04 r
.5 Mabswid
.42782 .37023 m
.51649 .37463 L
s
0 0 0 r
2.5 Mabswid
.51649 .37463 Mdot
.039 .916 .04 r
.5 Mabswid
.42923 .38857 m
.51546 .3918 L
s
0 0 0 r
2.5 Mabswid
.51546 .3918 Mdot
.039 .916 .04 r
.5 Mabswid
.43107 .4068 m
.51415 .40887 L
s
0 0 0 r
2.5 Mabswid
.51415 .40887 Mdot
.039 .916 .04 r
.5 Mabswid
.43595 .44248 m
.51001 .44844 L
s
0 0 0 r
2.5 Mabswid
.51001 .44844 Mdot
.039 .916 .04 r
.5 Mabswid
.4393 .46177 m
.50764 .46631 L
s
0 0 0 r
2.5 Mabswid
.50764 .46631 Mdot
.039 .916 .04 r
.5 Mabswid
.44311 .48078 m
.50498 .48401 L
s
0 0 0 r
2.5 Mabswid
.50498 .48401 Mdot
.039 .916 .04 r
.5 Mabswid
.50498 .15761 m
.97619 .17295 L
s
0 0 0 r
2.5 Mabswid
.97619 .17295 Mdot
.039 .916 .04 r
.5 Mabswid
.50764 .17531 m
.97619 .17191 L
s
0 0 0 r
2.5 Mabswid
.97619 .17191 Mdot
.039 .916 .04 r
.5 Mabswid
.51001 .19319 m
.97619 .17168 L
s
0 0 0 r
2.5 Mabswid
.97619 .17168 Mdot
.039 .916 .04 r
.5 Mabswid
.51415 .23275 m
.97619 .24335 L
s
0 0 0 r
2.5 Mabswid
.97619 .24335 Mdot
.039 .916 .04 r
.5 Mabswid
.51546 .24983 m
.97619 .244 L
s
0 0 0 r
2.5 Mabswid
.97619 .244 Mdot
.039 .916 .04 r
.5 Mabswid
.51649 .26699 m
.97619 .24503 L
s
0 0 0 r
2.5 Mabswid
.97619 .24503 Mdot
.039 .916 .04 r
.5 Mabswid
.51775 .30386 m
.97619 .31954 L
s
0 0 0 r
2.5 Mabswid
.97619 .31954 Mdot
.039 .916 .04 r
.5 Mabswid
.51789 .32081 m
.97619 .32081 L
s
0 0 0 r
2.5 Mabswid
.97619 .32081 Mdot
.039 .916 .04 r
.5 Mabswid
.51775 .33776 m
.97619 .32208 L
s
0 0 0 r
2.5 Mabswid
.97619 .32208 Mdot
.039 .916 .04 r
.5 Mabswid
.51649 .37463 m
.97619 .39659 L
s
0 0 0 r
2.5 Mabswid
.97619 .39659 Mdot
.039 .916 .04 r
.5 Mabswid
.51546 .3918 m
.97619 .39762 L
s
0 0 0 r
2.5 Mabswid
.97619 .39762 Mdot
.039 .916 .04 r
.5 Mabswid
.51415 .40887 m
.97619 .39828 L
s
0 0 0 r
2.5 Mabswid
.97619 .39828 Mdot
.039 .916 .04 r
.5 Mabswid
.51001 .44844 m
.97619 .46994 L
s
0 0 0 r
2.5 Mabswid
.97619 .46994 Mdot
.039 .916 .04 r
.5 Mabswid
.50764 .46631 m
.97619 .46971 L
s
0 0 0 r
2.5 Mabswid
.97619 .46971 Mdot
.039 .916 .04 r
.5 Mabswid
.50498 .48401 m
.97619 .46867 L
s
0 0 0 r
2.5 Mabswid
.97619 .46867 Mdot
0 0 m
1 0 L
1 .64162 L
0 .64162 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{714.375, 458.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 713.375}, {457.375, 0}} -> {-4.8132, -52.5006, \
0.229573, 0.229573}},
  CellTags->"Lens Optimizations"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Timing[sol2 = 
\tOptimizeSystem[{
\tMove[LineOfRays[5],0,20],
\tlenses,
\tMove[Screen[150],155]}, MeritType->SurfaceCoordinates, 
\tSequentialTrace->True]]\
\>", "Input",
  CellTags->"Lens Optimizations"],

Cell[BoxData[
    \({60.44999999999982`\ Second, {SymbolicValues \[Rule] {c1 \[Rule] 
              0.001561880894421291`, c2 \[Rule] \(-0.01107832697378391`\), 
            c3 \[Rule] 0.001574216100770887`, 
            c4 \[Rule] \(-0.005347496312709482`\)}, 
        NumberOfCycles \[Rule] 644, 
        FinalMerit \[Rule] 5.265064670364064`*^-9}}\)], "Output",
  CellTags->"Lens Optimizations"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboPlot[plot,sol2, PlotType->TopView, PlotPoints->50];", "Input",
  CellTags->"Lens Optimizations"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .64162 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0290345 0.00611068 0.320811 0.00611068 [
[ 0 0 0 0 ]
[ 1 .64162 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.24589 .16804 m
.34355 .16804 L
.34771 .18332 L
.24533 .18332 L
.24589 .16804 L
F
.24533 .18332 m
.34771 .18332 L
.35141 .1986 L
.24482 .1986 L
.24533 .18332 L
F
.24482 .1986 m
.35141 .1986 L
.35466 .21387 L
.24437 .21387 L
.24482 .1986 L
F
.24437 .21387 m
.35466 .21387 L
.35745 .22915 L
.24398 .22915 L
.24437 .21387 L
F
.24398 .22915 m
.35745 .22915 L
.35981 .24443 L
.24365 .24443 L
.24398 .22915 L
F
.24365 .24443 m
.35981 .24443 L
.36173 .2597 L
.24339 .2597 L
.24365 .24443 L
F
.24339 .2597 m
.36173 .2597 L
.36321 .27498 L
.24318 .27498 L
.24339 .2597 L
F
.24318 .27498 m
.36321 .27498 L
.36428 .29026 L
.24303 .29026 L
.24318 .27498 L
F
.24303 .29026 m
.36428 .29026 L
.36491 .30553 L
.24294 .30553 L
.24303 .29026 L
F
.24294 .30553 m
.36491 .30553 L
.36512 .32081 L
.24291 .32081 L
.24294 .30553 L
F
.24291 .32081 m
.36512 .32081 L
.36491 .33609 L
.24294 .33609 L
.24291 .32081 L
F
.24294 .33609 m
.36491 .33609 L
.36428 .35136 L
.24303 .35136 L
.24294 .33609 L
F
.24303 .35136 m
.36428 .35136 L
.36321 .36664 L
.24318 .36664 L
.24303 .35136 L
F
.24318 .36664 m
.36321 .36664 L
.36173 .38192 L
.24339 .38192 L
.24318 .36664 L
F
.24339 .38192 m
.36173 .38192 L
.35981 .39719 L
.24365 .39719 L
.24339 .38192 L
F
.24365 .39719 m
.35981 .39719 L
.35745 .41247 L
.24398 .41247 L
.24365 .39719 L
F
.24398 .41247 m
.35745 .41247 L
.35466 .42775 L
.24437 .42775 L
.24398 .41247 L
F
.24437 .42775 m
.35466 .42775 L
.35141 .44302 L
.24482 .44302 L
.24437 .42775 L
F
.24482 .44302 m
.35141 .44302 L
.34771 .4583 L
.24533 .4583 L
.24482 .44302 L
F
.24533 .4583 m
.34771 .4583 L
.34355 .47358 L
.24589 .47358 L
.24533 .4583 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.24589 .16804 m
.24533 .18332 L
.24482 .1986 L
.24437 .21387 L
.24398 .22915 L
.24365 .24443 L
.24339 .2597 L
.24318 .27498 L
.24303 .29026 L
.24294 .30553 L
.24291 .32081 L
.24294 .33609 L
.24303 .35136 L
.24318 .36664 L
.24339 .38192 L
.24365 .39719 L
.24398 .41247 L
.24437 .42775 L
.24482 .44302 L
.24533 .4583 L
.24589 .47358 L
.34355 .47358 L
.34771 .4583 L
.35141 .44302 L
.35466 .42775 L
.35745 .41247 L
.35981 .39719 L
.36173 .38192 L
.36321 .36664 L
.36428 .35136 L
.36491 .33609 L
.36512 .32081 L
.36491 .30553 L
.36428 .29026 L
.36321 .27498 L
.36173 .2597 L
.35981 .24443 L
.35745 .22915 L
.35466 .21387 L
.35141 .1986 L
.34771 .18332 L
.34355 .16804 L
.24589 .16804 L
s
.5 g
.24589 .32081 m
.34355 .32081 L
.34771 .32081 L
.24533 .32081 L
.24589 .32081 L
F
.24533 .32081 m
.34771 .32081 L
.35141 .32081 L
.24482 .32081 L
.24533 .32081 L
F
.24482 .32081 m
.35141 .32081 L
.35466 .32081 L
.24437 .32081 L
.24482 .32081 L
F
.24437 .32081 m
.35466 .32081 L
.35745 .32081 L
.24398 .32081 L
.24437 .32081 L
F
.24398 .32081 m
.35745 .32081 L
.35981 .32081 L
.24365 .32081 L
.24398 .32081 L
F
.24365 .32081 m
.35981 .32081 L
.36173 .32081 L
.24339 .32081 L
.24365 .32081 L
F
.24339 .32081 m
.36173 .32081 L
.36321 .32081 L
.24318 .32081 L
.24339 .32081 L
F
.24318 .32081 m
.36321 .32081 L
.36428 .32081 L
.24303 .32081 L
.24318 .32081 L
F
.24303 .32081 m
.36428 .32081 L
.36491 .32081 L
.24294 .32081 L
.24303 .32081 L
F
.24294 .32081 m
.36491 .32081 L
.36512 .32081 L
.24291 .32081 L
.24294 .32081 L
F
.24291 .32081 m
.36512 .32081 L
.36491 .32081 L
.24294 .32081 L
.24291 .32081 L
F
.24294 .32081 m
.36491 .32081 L
.36428 .32081 L
.24303 .32081 L
.24294 .32081 L
F
.24303 .32081 m
.36428 .32081 L
.36321 .32081 L
.24318 .32081 L
.24303 .32081 L
F
.24318 .32081 m
.36321 .32081 L
.36173 .32081 L
.24339 .32081 L
.24318 .32081 L
F
.24339 .32081 m
.36173 .32081 L
.35981 .32081 L
.24365 .32081 L
.24339 .32081 L
F
.24365 .32081 m
.35981 .32081 L
.35745 .32081 L
.24398 .32081 L
.24365 .32081 L
F
.24398 .32081 m
.35745 .32081 L
.35466 .32081 L
.24437 .32081 L
.24398 .32081 L
F
.24437 .32081 m
.35466 .32081 L
.35141 .32081 L
.24482 .32081 L
.24437 .32081 L
F
.24482 .32081 m
.35141 .32081 L
.34771 .32081 L
.24533 .32081 L
.24482 .32081 L
F
.24533 .32081 m
.34771 .32081 L
.34355 .32081 L
.24589 .32081 L
.24533 .32081 L
F
0 g
.24589 .32081 m
.24533 .32081 L
.24482 .32081 L
.24437 .32081 L
.24398 .32081 L
.24365 .32081 L
.24339 .32081 L
.24318 .32081 L
.24303 .32081 L
.24294 .32081 L
.24291 .32081 L
.24294 .32081 L
.24303 .32081 L
.24318 .32081 L
.24339 .32081 L
.24365 .32081 L
.24398 .32081 L
.24437 .32081 L
.24482 .32081 L
.24533 .32081 L
.24589 .32081 L
.34355 .32081 L
.34771 .32081 L
.35141 .32081 L
.35466 .32081 L
.35745 .32081 L
.35981 .32081 L
.36173 .32081 L
.36321 .32081 L
.36428 .32081 L
.36491 .32081 L
.36512 .32081 L
.36491 .32081 L
.36428 .32081 L
.36321 .32081 L
.36173 .32081 L
.35981 .32081 L
.35745 .32081 L
.35466 .32081 L
.35141 .32081 L
.34771 .32081 L
.34355 .32081 L
.24589 .32081 L
s
.24589 .47358 m
.34355 .47358 L
.34355 .47311 L
.24589 .47311 L
.24589 .47358 L
s
.24589 .47311 m
.34355 .47311 L
.34355 .4717 L
.24589 .4717 L
.24589 .47311 L
s
.24589 .4717 m
.34355 .4717 L
.34355 .46936 L
.24589 .46936 L
.24589 .4717 L
s
.24589 .46936 m
.34355 .46936 L
.34355 .4661 L
.24589 .4661 L
.24589 .46936 L
s
.24589 .4661 m
.34355 .4661 L
.34355 .46195 L
.24589 .46195 L
.24589 .4661 L
s
.24589 .46195 m
.34355 .46195 L
.34355 .45693 L
.24589 .45693 L
.24589 .46195 L
s
.24589 .45693 m
.34355 .45693 L
.34355 .45107 L
.24589 .45107 L
.24589 .45693 L
s
.24589 .45107 m
.34355 .45107 L
.34355 .4444 L
.24589 .4444 L
.24589 .45107 L
s
.24589 .4444 m
.34355 .4444 L
.34355 .43698 L
.24589 .43698 L
.24589 .4444 L
s
.24589 .43698 m
.34355 .43698 L
.34355 .42883 L
.24589 .42883 L
.24589 .43698 L
s
.24589 .42883 m
.34355 .42883 L
.34355 .42003 L
.24589 .42003 L
.24589 .42883 L
s
.24589 .42003 m
.34355 .42003 L
.34355 .41061 L
.24589 .41061 L
.24589 .42003 L
s
.24589 .41061 m
.34355 .41061 L
.34355 .40063 L
.24589 .40063 L
.24589 .41061 L
s
.24589 .40063 m
.34355 .40063 L
.34355 .39017 L
.24589 .39017 L
.24589 .40063 L
s
.24589 .39017 m
.34355 .39017 L
.34355 .37927 L
.24589 .37927 L
.24589 .39017 L
s
.24589 .37927 m
.34355 .37927 L
.34355 .36802 L
.24589 .36802 L
.24589 .37927 L
s
.24589 .36802 m
.34355 .36802 L
.34355 .35647 L
.24589 .35647 L
.24589 .36802 L
s
.24589 .35647 m
.34355 .35647 L
.34355 .34471 L
.24589 .34471 L
.24589 .35647 L
s
.24589 .34471 m
.34355 .34471 L
.34355 .3328 L
.24589 .3328 L
.24589 .34471 L
s
.24589 .3328 m
.34355 .3328 L
.34355 .32081 L
.24589 .32081 L
.24589 .3328 L
s
.24589 .32081 m
.34355 .32081 L
.34355 .30882 L
.24589 .30882 L
.24589 .32081 L
s
.24589 .30882 m
.34355 .30882 L
.34355 .29691 L
.24589 .29691 L
.24589 .30882 L
s
.24589 .29691 m
.34355 .29691 L
.34355 .28515 L
.24589 .28515 L
.24589 .29691 L
s
.24589 .28515 m
.34355 .28515 L
.34355 .2736 L
.24589 .2736 L
.24589 .28515 L
s
.24589 .2736 m
.34355 .2736 L
.34355 .26235 L
.24589 .26235 L
.24589 .2736 L
s
.24589 .26235 m
.34355 .26235 L
.34355 .25146 L
.24589 .25146 L
.24589 .26235 L
s
.24589 .25146 m
.34355 .25146 L
.34355 .24099 L
.24589 .24099 L
.24589 .25146 L
s
.24589 .24099 m
.34355 .24099 L
.34355 .23102 L
.24589 .23102 L
.24589 .24099 L
s
.24589 .23102 m
.34355 .23102 L
.34355 .2216 L
.24589 .2216 L
.24589 .23102 L
s
.24589 .2216 m
.34355 .2216 L
.34355 .21279 L
.24589 .21279 L
.24589 .2216 L
s
.24589 .21279 m
.34355 .21279 L
.34355 .20465 L
.24589 .20465 L
.24589 .21279 L
s
.24589 .20465 m
.34355 .20465 L
.34355 .19722 L
.24589 .19722 L
.24589 .20465 L
s
.24589 .19722 m
.34355 .19722 L
.34355 .19056 L
.24589 .19056 L
.24589 .19722 L
s
.24589 .19056 m
.34355 .19056 L
.34355 .18469 L
.24589 .18469 L
.24589 .19056 L
s
.24589 .18469 m
.34355 .18469 L
.34355 .17967 L
.24589 .17967 L
.24589 .18469 L
s
.24589 .17967 m
.34355 .17967 L
.34355 .17552 L
.24589 .17552 L
.24589 .17967 L
s
.24589 .17552 m
.34355 .17552 L
.34355 .17226 L
.24589 .17226 L
.24589 .17552 L
s
.24589 .17226 m
.34355 .17226 L
.34355 .16992 L
.24589 .16992 L
.24589 .17226 L
s
.24589 .16992 m
.34355 .16992 L
.34355 .16851 L
.24589 .16851 L
.24589 .16992 L
s
.24589 .16851 m
.34355 .16851 L
.34355 .16804 L
.24589 .16804 L
.24589 .16851 L
s
.24589 .16804 m
.34355 .16804 L
.34355 .16851 L
.24589 .16851 L
.24589 .16804 L
s
.24589 .16851 m
.34355 .16851 L
.34355 .16992 L
.24589 .16992 L
.24589 .16851 L
s
.24589 .16992 m
.34355 .16992 L
.34355 .17226 L
.24589 .17226 L
.24589 .16992 L
s
.24589 .17226 m
.34355 .17226 L
.34355 .17552 L
.24589 .17552 L
.24589 .17226 L
s
.24589 .17552 m
.34355 .17552 L
.34355 .17967 L
.24589 .17967 L
.24589 .17552 L
s
.24589 .17967 m
.34355 .17967 L
.34355 .18469 L
.24589 .18469 L
.24589 .17967 L
s
.24589 .18469 m
.34355 .18469 L
.34355 .19056 L
.24589 .19056 L
.24589 .18469 L
s
.24589 .19056 m
.34355 .19056 L
.34355 .19722 L
.24589 .19722 L
.24589 .19056 L
s
.24589 .19722 m
.34355 .19722 L
.34355 .20465 L
.24589 .20465 L
.24589 .19722 L
s
.24589 .20465 m
.34355 .20465 L
.34355 .21279 L
.24589 .21279 L
.24589 .20465 L
s
.24589 .21279 m
.34355 .21279 L
.34355 .2216 L
.24589 .2216 L
.24589 .21279 L
s
.24589 .2216 m
.34355 .2216 L
.34355 .23102 L
.24589 .23102 L
.24589 .2216 L
s
.24589 .23102 m
.34355 .23102 L
.34355 .24099 L
.24589 .24099 L
.24589 .23102 L
s
.24589 .24099 m
.34355 .24099 L
.34355 .25146 L
.24589 .25146 L
.24589 .24099 L
s
.24589 .25146 m
.34355 .25146 L
.34355 .26235 L
.24589 .26235 L
.24589 .25146 L
s
.24589 .26235 m
.34355 .26235 L
.34355 .2736 L
.24589 .2736 L
.24589 .26235 L
s
.24589 .2736 m
.34355 .2736 L
.34355 .28515 L
.24589 .28515 L
.24589 .2736 L
s
.24589 .28515 m
.34355 .28515 L
.34355 .29691 L
.24589 .29691 L
.24589 .28515 L
s
.24589 .29691 m
.34355 .29691 L
.34355 .30882 L
.24589 .30882 L
.24589 .29691 L
s
.24589 .30882 m
.34355 .30882 L
.34355 .32081 L
.24589 .32081 L
.24589 .30882 L
s
.24589 .32081 m
.34355 .32081 L
.34355 .3328 L
.24589 .3328 L
.24589 .32081 L
s
.24589 .3328 m
.34355 .3328 L
.34355 .34471 L
.24589 .34471 L
.24589 .3328 L
s
.24589 .34471 m
.34355 .34471 L
.34355 .35647 L
.24589 .35647 L
.24589 .34471 L
s
.24589 .35647 m
.34355 .35647 L
.34355 .36802 L
.24589 .36802 L
.24589 .35647 L
s
.24589 .36802 m
.34355 .36802 L
.34355 .37927 L
.24589 .37927 L
.24589 .36802 L
s
.24589 .37927 m
.34355 .37927 L
.34355 .39017 L
.24589 .39017 L
.24589 .37927 L
s
.24589 .39017 m
.34355 .39017 L
.34355 .40063 L
.24589 .40063 L
.24589 .39017 L
s
.24589 .40063 m
.34355 .40063 L
.34355 .41061 L
.24589 .41061 L
.24589 .40063 L
s
.24589 .41061 m
.34355 .41061 L
.34355 .42003 L
.24589 .42003 L
.24589 .41061 L
s
.24589 .42003 m
.34355 .42003 L
.34355 .42883 L
.24589 .42883 L
.24589 .42003 L
s
.24589 .42883 m
.34355 .42883 L
.34355 .43698 L
.24589 .43698 L
.24589 .42883 L
s
.24589 .43698 m
.34355 .43698 L
.34355 .4444 L
.24589 .4444 L
.24589 .43698 L
s
.24589 .4444 m
.34355 .4444 L
.34355 .45107 L
.24589 .45107 L
.24589 .4444 L
s
.24589 .45107 m
.34355 .45107 L
.34355 .45693 L
.24589 .45693 L
.24589 .45107 L
s
.24589 .45693 m
.34355 .45693 L
.34355 .46195 L
.24589 .46195 L
.24589 .45693 L
s
.24589 .46195 m
.34355 .46195 L
.34355 .4661 L
.24589 .4661 L
.24589 .46195 L
s
.24589 .4661 m
.34355 .4661 L
.34355 .46936 L
.24589 .46936 L
.24589 .4661 L
s
.24589 .46936 m
.34355 .46936 L
.34355 .4717 L
.24589 .4717 L
.24589 .46936 L
s
.24589 .4717 m
.34355 .4717 L
.34355 .47311 L
.24589 .47311 L
.24589 .4717 L
s
.24589 .47311 m
.34355 .47311 L
.34355 .47358 L
.24589 .47358 L
.24589 .47311 L
s
.5 g
.43056 .13749 m
.50309 .13749 L
.50592 .15582 L
.42974 .15582 L
.43056 .13749 L
F
.42974 .15582 m
.50592 .15582 L
.50844 .17415 L
.429 .17415 L
.42974 .15582 L
F
.429 .17415 m
.50844 .17415 L
.51066 .19249 L
.42835 .19249 L
.429 .17415 L
F
.42835 .19249 m
.51066 .19249 L
.51258 .21082 L
.42779 .21082 L
.42835 .19249 L
F
.42779 .21082 m
.51258 .21082 L
.51421 .22915 L
.42731 .22915 L
.42779 .21082 L
F
.42731 .22915 m
.51421 .22915 L
.51553 .24748 L
.42692 .24748 L
.42731 .22915 L
F
.42692 .24748 m
.51553 .24748 L
.51657 .26581 L
.42662 .26581 L
.42692 .24748 L
F
.42662 .26581 m
.51657 .26581 L
.5173 .28415 L
.4264 .28415 L
.42662 .26581 L
F
.4264 .28415 m
.5173 .28415 L
.51774 .30248 L
.42627 .30248 L
.4264 .28415 L
F
.42627 .30248 m
.51774 .30248 L
.51789 .32081 L
.42623 .32081 L
.42627 .30248 L
F
.42623 .32081 m
.51789 .32081 L
.51774 .33914 L
.42627 .33914 L
.42623 .32081 L
F
.42627 .33914 m
.51774 .33914 L
.5173 .35748 L
.4264 .35748 L
.42627 .33914 L
F
.4264 .35748 m
.5173 .35748 L
.51657 .37581 L
.42662 .37581 L
.4264 .35748 L
F
.42662 .37581 m
.51657 .37581 L
.51553 .39414 L
.42692 .39414 L
.42662 .37581 L
F
.42692 .39414 m
.51553 .39414 L
.51421 .41247 L
.42731 .41247 L
.42692 .39414 L
F
.42731 .41247 m
.51421 .41247 L
.51258 .4308 L
.42779 .4308 L
.42731 .41247 L
F
.42779 .4308 m
.51258 .4308 L
.51066 .44914 L
.42835 .44914 L
.42779 .4308 L
F
.42835 .44914 m
.51066 .44914 L
.50844 .46747 L
.429 .46747 L
.42835 .44914 L
F
.429 .46747 m
.50844 .46747 L
.50592 .4858 L
.42974 .4858 L
.429 .46747 L
F
.42974 .4858 m
.50592 .4858 L
.50309 .50413 L
.43056 .50413 L
.42974 .4858 L
F
0 g
.43056 .13749 m
.42974 .15582 L
.429 .17415 L
.42835 .19249 L
.42779 .21082 L
.42731 .22915 L
.42692 .24748 L
.42662 .26581 L
.4264 .28415 L
.42627 .30248 L
.42623 .32081 L
.42627 .33914 L
.4264 .35748 L
.42662 .37581 L
.42692 .39414 L
.42731 .41247 L
.42779 .4308 L
.42835 .44914 L
.429 .46747 L
.42974 .4858 L
.43056 .50413 L
.50309 .50413 L
.50592 .4858 L
.50844 .46747 L
.51066 .44914 L
.51258 .4308 L
.51421 .41247 L
.51553 .39414 L
.51657 .37581 L
.5173 .35748 L
.51774 .33914 L
.51789 .32081 L
.51774 .30248 L
.5173 .28415 L
.51657 .26581 L
.51553 .24748 L
.51421 .22915 L
.51258 .21082 L
.51066 .19249 L
.50844 .17415 L
.50592 .15582 L
.50309 .13749 L
.43056 .13749 L
s
.5 g
.43056 .32081 m
.50309 .32081 L
.50592 .32081 L
.42974 .32081 L
.43056 .32081 L
F
.42974 .32081 m
.50592 .32081 L
.50844 .32081 L
.429 .32081 L
.42974 .32081 L
F
.429 .32081 m
.50844 .32081 L
.51066 .32081 L
.42835 .32081 L
.429 .32081 L
F
.42835 .32081 m
.51066 .32081 L
.51258 .32081 L
.42779 .32081 L
.42835 .32081 L
F
.42779 .32081 m
.51258 .32081 L
.51421 .32081 L
.42731 .32081 L
.42779 .32081 L
F
.42731 .32081 m
.51421 .32081 L
.51553 .32081 L
.42692 .32081 L
.42731 .32081 L
F
.42692 .32081 m
.51553 .32081 L
.51657 .32081 L
.42662 .32081 L
.42692 .32081 L
F
.42662 .32081 m
.51657 .32081 L
.5173 .32081 L
.4264 .32081 L
.42662 .32081 L
F
.4264 .32081 m
.5173 .32081 L
.51774 .32081 L
.42627 .32081 L
.4264 .32081 L
F
.42627 .32081 m
.51774 .32081 L
.51789 .32081 L
.42623 .32081 L
.42627 .32081 L
F
.42623 .32081 m
.51789 .32081 L
.51774 .32081 L
.42627 .32081 L
.42623 .32081 L
F
.42627 .32081 m
.51774 .32081 L
.5173 .32081 L
.4264 .32081 L
.42627 .32081 L
F
.4264 .32081 m
.5173 .32081 L
.51657 .32081 L
.42662 .32081 L
.4264 .32081 L
F
.42662 .32081 m
.51657 .32081 L
.51553 .32081 L
.42692 .32081 L
.42662 .32081 L
F
.42692 .32081 m
.51553 .32081 L
.51421 .32081 L
.42731 .32081 L
.42692 .32081 L
F
.42731 .32081 m
.51421 .32081 L
.51258 .32081 L
.42779 .32081 L
.42731 .32081 L
F
.42779 .32081 m
.51258 .32081 L
.51066 .32081 L
.42835 .32081 L
.42779 .32081 L
F
.42835 .32081 m
.51066 .32081 L
.50844 .32081 L
.429 .32081 L
.42835 .32081 L
F
.429 .32081 m
.50844 .32081 L
.50592 .32081 L
.42974 .32081 L
.429 .32081 L
F
.42974 .32081 m
.50592 .32081 L
.50309 .32081 L
.43056 .32081 L
.42974 .32081 L
F
0 g
.43056 .32081 m
.42974 .32081 L
.429 .32081 L
.42835 .32081 L
.42779 .32081 L
.42731 .32081 L
.42692 .32081 L
.42662 .32081 L
.4264 .32081 L
.42627 .32081 L
.42623 .32081 L
.42627 .32081 L
.4264 .32081 L
.42662 .32081 L
.42692 .32081 L
.42731 .32081 L
.42779 .32081 L
.42835 .32081 L
.429 .32081 L
.42974 .32081 L
.43056 .32081 L
.50309 .32081 L
.50592 .32081 L
.50844 .32081 L
.51066 .32081 L
.51258 .32081 L
.51421 .32081 L
.51553 .32081 L
.51657 .32081 L
.5173 .32081 L
.51774 .32081 L
.51789 .32081 L
.51774 .32081 L
.5173 .32081 L
.51657 .32081 L
.51553 .32081 L
.51421 .32081 L
.51258 .32081 L
.51066 .32081 L
.50844 .32081 L
.50592 .32081 L
.50309 .32081 L
.43056 .32081 L
s
.43056 .50413 m
.50309 .50413 L
.50309 .50357 L
.43056 .50357 L
.43056 .50413 L
s
.43056 .50357 m
.50309 .50357 L
.50309 .50187 L
.43056 .50187 L
.43056 .50357 L
s
.43056 .50187 m
.50309 .50187 L
.50309 .49907 L
.43056 .49907 L
.43056 .50187 L
s
.43056 .49907 m
.50309 .49907 L
.50309 .49516 L
.43056 .49516 L
.43056 .49907 L
s
.43056 .49516 m
.50309 .49516 L
.50309 .49018 L
.43056 .49018 L
.43056 .49516 L
s
.43056 .49018 m
.50309 .49018 L
.50309 .48415 L
.43056 .48415 L
.43056 .49018 L
s
.43056 .48415 m
.50309 .48415 L
.50309 .47712 L
.43056 .47712 L
.43056 .48415 L
s
.43056 .47712 m
.50309 .47712 L
.50309 .46912 L
.43056 .46912 L
.43056 .47712 L
s
.43056 .46912 m
.50309 .46912 L
.50309 .46021 L
.43056 .46021 L
.43056 .46912 L
s
.43056 .46021 m
.50309 .46021 L
.50309 .45044 L
.43056 .45044 L
.43056 .46021 L
s
.43056 .45044 m
.50309 .45044 L
.50309 .43987 L
.43056 .43987 L
.43056 .45044 L
s
.43056 .43987 m
.50309 .43987 L
.50309 .42856 L
.43056 .42856 L
.43056 .43987 L
s
.43056 .42856 m
.50309 .42856 L
.50309 .4166 L
.43056 .4166 L
.43056 .42856 L
s
.43056 .4166 m
.50309 .4166 L
.50309 .40404 L
.43056 .40404 L
.43056 .4166 L
s
.43056 .40404 m
.50309 .40404 L
.50309 .39096 L
.43056 .39096 L
.43056 .40404 L
s
.43056 .39096 m
.50309 .39096 L
.50309 .37746 L
.43056 .37746 L
.43056 .39096 L
s
.43056 .37746 m
.50309 .37746 L
.50309 .36361 L
.43056 .36361 L
.43056 .37746 L
s
.43056 .36361 m
.50309 .36361 L
.50309 .34949 L
.43056 .34949 L
.43056 .36361 L
s
.43056 .34949 m
.50309 .34949 L
.50309 .33519 L
.43056 .33519 L
.43056 .34949 L
s
.43056 .33519 m
.50309 .33519 L
.50309 .32081 L
.43056 .32081 L
.43056 .33519 L
s
.43056 .32081 m
.50309 .32081 L
.50309 .30643 L
.43056 .30643 L
.43056 .32081 L
s
.43056 .30643 m
.50309 .30643 L
.50309 .29213 L
.43056 .29213 L
.43056 .30643 L
s
.43056 .29213 m
.50309 .29213 L
.50309 .27802 L
.43056 .27802 L
.43056 .29213 L
s
.43056 .27802 m
.50309 .27802 L
.50309 .26416 L
.43056 .26416 L
.43056 .27802 L
s
.43056 .26416 m
.50309 .26416 L
.50309 .25066 L
.43056 .25066 L
.43056 .26416 L
s
.43056 .25066 m
.50309 .25066 L
.50309 .23759 L
.43056 .23759 L
.43056 .25066 L
s
.43056 .23759 m
.50309 .23759 L
.50309 .22503 L
.43056 .22503 L
.43056 .23759 L
s
.43056 .22503 m
.50309 .22503 L
.50309 .21306 L
.43056 .21306 L
.43056 .22503 L
s
.43056 .21306 m
.50309 .21306 L
.50309 .20175 L
.43056 .20175 L
.43056 .21306 L
s
.43056 .20175 m
.50309 .20175 L
.50309 .19118 L
.43056 .19118 L
.43056 .20175 L
s
.43056 .19118 m
.50309 .19118 L
.50309 .18141 L
.43056 .18141 L
.43056 .19118 L
s
.43056 .18141 m
.50309 .18141 L
.50309 .1725 L
.43056 .1725 L
.43056 .18141 L
s
.43056 .1725 m
.50309 .1725 L
.50309 .1645 L
.43056 .1645 L
.43056 .1725 L
s
.43056 .1645 m
.50309 .1645 L
.50309 .15747 L
.43056 .15747 L
.43056 .1645 L
s
.43056 .15747 m
.50309 .15747 L
.50309 .15144 L
.43056 .15144 L
.43056 .15747 L
s
.43056 .15144 m
.50309 .15144 L
.50309 .14646 L
.43056 .14646 L
.43056 .15144 L
s
.43056 .14646 m
.50309 .14646 L
.50309 .14256 L
.43056 .14256 L
.43056 .14646 L
s
.43056 .14256 m
.50309 .14256 L
.50309 .13975 L
.43056 .13975 L
.43056 .14256 L
s
.43056 .13975 m
.50309 .13975 L
.50309 .13806 L
.43056 .13806 L
.43056 .13975 L
s
.43056 .13806 m
.50309 .13806 L
.50309 .13749 L
.43056 .13749 L
.43056 .13806 L
s
.43056 .13749 m
.50309 .13749 L
.50309 .13806 L
.43056 .13806 L
.43056 .13749 L
s
.43056 .13806 m
.50309 .13806 L
.50309 .13975 L
.43056 .13975 L
.43056 .13806 L
s
.43056 .13975 m
.50309 .13975 L
.50309 .14256 L
.43056 .14256 L
.43056 .13975 L
s
.43056 .14256 m
.50309 .14256 L
.50309 .14646 L
.43056 .14646 L
.43056 .14256 L
s
.43056 .14646 m
.50309 .14646 L
.50309 .15144 L
.43056 .15144 L
.43056 .14646 L
s
.43056 .15144 m
.50309 .15144 L
.50309 .15747 L
.43056 .15747 L
.43056 .15144 L
s
.43056 .15747 m
.50309 .15747 L
.50309 .1645 L
.43056 .1645 L
.43056 .15747 L
s
.43056 .1645 m
.50309 .1645 L
.50309 .1725 L
.43056 .1725 L
.43056 .1645 L
s
.43056 .1725 m
.50309 .1725 L
.50309 .18141 L
.43056 .18141 L
.43056 .1725 L
s
.43056 .18141 m
.50309 .18141 L
.50309 .19118 L
.43056 .19118 L
.43056 .18141 L
s
.43056 .19118 m
.50309 .19118 L
.50309 .20175 L
.43056 .20175 L
.43056 .19118 L
s
.43056 .20175 m
.50309 .20175 L
.50309 .21306 L
.43056 .21306 L
.43056 .20175 L
s
.43056 .21306 m
.50309 .21306 L
.50309 .22503 L
.43056 .22503 L
.43056 .21306 L
s
.43056 .22503 m
.50309 .22503 L
.50309 .23759 L
.43056 .23759 L
.43056 .22503 L
s
.43056 .23759 m
.50309 .23759 L
.50309 .25066 L
.43056 .25066 L
.43056 .23759 L
s
.43056 .25066 m
.50309 .25066 L
.50309 .26416 L
.43056 .26416 L
.43056 .25066 L
s
.43056 .26416 m
.50309 .26416 L
.50309 .27802 L
.43056 .27802 L
.43056 .26416 L
s
.43056 .27802 m
.50309 .27802 L
.50309 .29213 L
.43056 .29213 L
.43056 .27802 L
s
.43056 .29213 m
.50309 .29213 L
.50309 .30643 L
.43056 .30643 L
.43056 .29213 L
s
.43056 .30643 m
.50309 .30643 L
.50309 .32081 L
.43056 .32081 L
.43056 .30643 L
s
.43056 .32081 m
.50309 .32081 L
.50309 .33519 L
.43056 .33519 L
.43056 .32081 L
s
.43056 .33519 m
.50309 .33519 L
.50309 .34949 L
.43056 .34949 L
.43056 .33519 L
s
.43056 .34949 m
.50309 .34949 L
.50309 .36361 L
.43056 .36361 L
.43056 .34949 L
s
.43056 .36361 m
.50309 .36361 L
.50309 .37746 L
.43056 .37746 L
.43056 .36361 L
s
.43056 .37746 m
.50309 .37746 L
.50309 .39096 L
.43056 .39096 L
.43056 .37746 L
s
.43056 .39096 m
.50309 .39096 L
.50309 .40404 L
.43056 .40404 L
.43056 .39096 L
s
.43056 .40404 m
.50309 .40404 L
.50309 .4166 L
.43056 .4166 L
.43056 .40404 L
s
.43056 .4166 m
.50309 .4166 L
.50309 .42856 L
.43056 .42856 L
.43056 .4166 L
s
.43056 .42856 m
.50309 .42856 L
.50309 .43987 L
.43056 .43987 L
.43056 .42856 L
s
.43056 .43987 m
.50309 .43987 L
.50309 .45044 L
.43056 .45044 L
.43056 .43987 L
s
.43056 .45044 m
.50309 .45044 L
.50309 .46021 L
.43056 .46021 L
.43056 .45044 L
s
.43056 .46021 m
.50309 .46021 L
.50309 .46912 L
.43056 .46912 L
.43056 .46021 L
s
.43056 .46912 m
.50309 .46912 L
.50309 .47712 L
.43056 .47712 L
.43056 .46912 L
s
.43056 .47712 m
.50309 .47712 L
.50309 .48415 L
.43056 .48415 L
.43056 .47712 L
s
.43056 .48415 m
.50309 .48415 L
.50309 .49018 L
.43056 .49018 L
.43056 .48415 L
s
.43056 .49018 m
.50309 .49018 L
.50309 .49516 L
.43056 .49516 L
.43056 .49018 L
s
.43056 .49516 m
.50309 .49516 L
.50309 .49907 L
.43056 .49907 L
.43056 .49516 L
s
.43056 .49907 m
.50309 .49907 L
.50309 .50187 L
.43056 .50187 L
.43056 .49907 L
s
.43056 .50187 m
.50309 .50187 L
.50309 .50357 L
.43056 .50357 L
.43056 .50187 L
s
.43056 .50357 m
.50309 .50357 L
.50309 .50413 L
.43056 .50413 L
.43056 .50357 L
s
.97619 .01528 m
.97619 .04583 L
.97619 .07638 L
.97619 .10694 L
.97619 .13749 L
.97619 .16804 L
.97619 .1986 L
.97619 .22915 L
.97619 .2597 L
.97619 .29026 L
.97619 .32081 L
.97619 .35136 L
.97619 .38192 L
.97619 .41247 L
.97619 .44302 L
.97619 .47358 L
.97619 .50413 L
.97619 .53468 L
.97619 .56524 L
.97619 .59579 L
.97619 .62635 L
.97619 .62635 L
.97619 .59579 L
.97619 .56524 L
.97619 .53468 L
.97619 .50413 L
.97619 .47358 L
.97619 .44302 L
.97619 .41247 L
.97619 .38192 L
.97619 .35136 L
.97619 .32081 L
.97619 .29026 L
.97619 .2597 L
.97619 .22915 L
.97619 .1986 L
.97619 .16804 L
.97619 .13749 L
.97619 .10694 L
.97619 .07638 L
.97619 .04583 L
.97619 .01528 L
.97619 .01528 L
s
.97619 .32081 m
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
.97619 .32081 L
s
.97619 .62635 m
.97619 .6254 L
.97619 .62258 L
.97619 .6179 L
.97619 .61139 L
.97619 .60309 L
.97619 .59304 L
.97619 .58132 L
.97619 .56799 L
.97619 .55314 L
.97619 .53686 L
.97619 .51924 L
.97619 .5004 L
.97619 .48045 L
.97619 .45952 L
.97619 .43773 L
.97619 .41523 L
.97619 .39214 L
.97619 .36861 L
.97619 .34478 L
.97619 .32081 L
.97619 .29684 L
.97619 .27301 L
.97619 .24949 L
.97619 .2264 L
.97619 .20389 L
.97619 .1821 L
.97619 .16117 L
.97619 .14122 L
.97619 .12238 L
.97619 .10477 L
.97619 .08848 L
.97619 .07363 L
.97619 .0603 L
.97619 .04858 L
.97619 .03853 L
.97619 .03023 L
.97619 .02372 L
.97619 .01904 L
.97619 .01622 L
.97619 .01528 L
.97619 .01622 L
.97619 .01904 L
.97619 .02372 L
.97619 .03023 L
.97619 .03853 L
.97619 .04858 L
.97619 .0603 L
.97619 .07363 L
.97619 .08848 L
Mistroke
.97619 .10477 L
.97619 .12238 L
.97619 .14122 L
.97619 .16117 L
.97619 .1821 L
.97619 .20389 L
.97619 .2264 L
.97619 .24949 L
.97619 .27301 L
.97619 .29684 L
.97619 .32081 L
.97619 .34478 L
.97619 .36861 L
.97619 .39214 L
.97619 .41523 L
.97619 .43773 L
.97619 .45952 L
.97619 .48045 L
.97619 .5004 L
.97619 .51924 L
.97619 .53686 L
.97619 .55314 L
.97619 .56799 L
.97619 .58132 L
.97619 .59304 L
.97619 .60309 L
.97619 .61139 L
.97619 .6179 L
.97619 .62258 L
.97619 .6254 L
.97619 .62635 L
Mfstroke
.039 .916 .04 r
.02381 .30646 m
.24405 .22629 L
s
0 0 0 r
2.5 Mabswid
.24405 .22629 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .32081 m
.24369 .24268 L
s
0 0 0 r
2.5 Mabswid
.24369 .24268 Mdot
.039 .916 .04 r
.5 Mabswid
.03426 .33517 m
.2434 .25905 L
s
0 0 0 r
2.5 Mabswid
.2434 .25905 Mdot
.039 .916 .04 r
.5 Mabswid
.02638 .30577 m
.24327 .26752 L
s
0 0 0 r
2.5 Mabswid
.24327 .26752 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .32081 m
.24309 .28307 L
s
0 0 0 r
2.5 Mabswid
.24309 .28307 Mdot
.039 .916 .04 r
.5 Mabswid
.03169 .33586 m
.24297 .2986 L
s
0 0 0 r
2.5 Mabswid
.24297 .2986 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .30553 m
.24294 .30553 L
s
0 0 0 r
2.5 Mabswid
.24294 .30553 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .32081 m
.24291 .32081 L
s
0 0 0 r
2.5 Mabswid
.24291 .32081 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .33609 m
.24294 .33609 L
s
0 0 0 r
2.5 Mabswid
.24294 .33609 Mdot
.039 .916 .04 r
.5 Mabswid
.03169 .30577 m
.24297 .34302 L
s
0 0 0 r
2.5 Mabswid
.24297 .34302 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .32081 m
.24309 .35855 L
s
0 0 0 r
2.5 Mabswid
.24309 .35855 Mdot
.039 .916 .04 r
.5 Mabswid
.02638 .33586 m
.24327 .3741 L
s
0 0 0 r
2.5 Mabswid
.24327 .3741 Mdot
.039 .916 .04 r
.5 Mabswid
.03426 .30646 m
.2434 .38257 L
s
0 0 0 r
2.5 Mabswid
.2434 .38257 Mdot
.039 .916 .04 r
.5 Mabswid
.02903 .32081 m
.24369 .39894 L
s
0 0 0 r
2.5 Mabswid
.24369 .39894 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .33517 m
.24405 .41533 L
s
0 0 0 r
2.5 Mabswid
.24405 .41533 Mdot
.039 .916 .04 r
.5 Mabswid
.24405 .22629 m
.35224 .2023 L
s
0 0 0 r
2.5 Mabswid
.35224 .2023 Mdot
.039 .916 .04 r
.5 Mabswid
.24369 .24268 m
.3554 .21773 L
s
0 0 0 r
2.5 Mabswid
.3554 .21773 Mdot
.039 .916 .04 r
.5 Mabswid
.2434 .25905 m
.35813 .23323 L
s
0 0 0 r
2.5 Mabswid
.35813 .23323 Mdot
.039 .916 .04 r
.5 Mabswid
.24327 .26752 m
.36112 .25453 L
s
0 0 0 r
2.5 Mabswid
.36112 .25453 Mdot
.039 .916 .04 r
.5 Mabswid
.24309 .28307 m
.36275 .2697 L
s
0 0 0 r
2.5 Mabswid
.36275 .2697 Mdot
.039 .916 .04 r
.5 Mabswid
.24297 .2986 m
.36395 .28492 L
s
0 0 0 r
2.5 Mabswid
.36395 .28492 Mdot
.039 .916 .04 r
.5 Mabswid
.24294 .30553 m
.36491 .3057 L
s
0 0 0 r
2.5 Mabswid
.36491 .3057 Mdot
.039 .916 .04 r
.5 Mabswid
.24291 .32081 m
.36512 .32081 L
s
0 0 0 r
2.5 Mabswid
.36512 .32081 Mdot
.039 .916 .04 r
.5 Mabswid
.24294 .33609 m
.36491 .33592 L
s
0 0 0 r
2.5 Mabswid
.36491 .33592 Mdot
.039 .916 .04 r
.5 Mabswid
.24297 .34302 m
.36395 .3567 L
s
0 0 0 r
2.5 Mabswid
.36395 .3567 Mdot
.039 .916 .04 r
.5 Mabswid
.24309 .35855 m
.36275 .37192 L
s
0 0 0 r
2.5 Mabswid
.36275 .37192 Mdot
.039 .916 .04 r
.5 Mabswid
.24327 .3741 m
.36112 .38709 L
s
0 0 0 r
2.5 Mabswid
.36112 .38709 Mdot
.039 .916 .04 r
.5 Mabswid
.2434 .38257 m
.35813 .40839 L
s
0 0 0 r
2.5 Mabswid
.35813 .40839 Mdot
.039 .916 .04 r
.5 Mabswid
.24369 .39894 m
.3554 .42389 L
s
0 0 0 r
2.5 Mabswid
.3554 .42389 Mdot
.039 .916 .04 r
.5 Mabswid
.24405 .41533 m
.35224 .43932 L
s
0 0 0 r
2.5 Mabswid
.35224 .43932 Mdot
.039 .916 .04 r
.5 Mabswid
.35224 .2023 m
.4286 .1853 L
s
0 0 0 r
2.5 Mabswid
.4286 .1853 Mdot
.039 .916 .04 r
.5 Mabswid
.3554 .21773 m
.4281 .20022 L
s
0 0 0 r
2.5 Mabswid
.4281 .20022 Mdot
.039 .916 .04 r
.5 Mabswid
.35813 .23323 m
.42767 .21522 L
s
0 0 0 r
2.5 Mabswid
.42767 .21522 Mdot
.039 .916 .04 r
.5 Mabswid
.36112 .25453 m
.42692 .24764 L
s
0 0 0 r
2.5 Mabswid
.42692 .24764 Mdot
.039 .916 .04 r
.5 Mabswid
.36275 .2697 m
.42668 .26195 L
s
0 0 0 r
2.5 Mabswid
.42668 .26195 Mdot
.039 .916 .04 r
.5 Mabswid
.36395 .28492 m
.42648 .27628 L
s
0 0 0 r
2.5 Mabswid
.42648 .27628 Mdot
.039 .916 .04 r
.5 Mabswid
.36491 .3057 m
.42625 .30669 L
s
0 0 0 r
2.5 Mabswid
.42625 .30669 Mdot
.039 .916 .04 r
.5 Mabswid
.36512 .32081 m
.42623 .32081 L
s
0 0 0 r
2.5 Mabswid
.42623 .32081 Mdot
.039 .916 .04 r
.5 Mabswid
.36491 .33592 m
.42625 .33493 L
s
0 0 0 r
2.5 Mabswid
.42625 .33493 Mdot
.039 .916 .04 r
.5 Mabswid
.36395 .3567 m
.42648 .36534 L
s
0 0 0 r
2.5 Mabswid
.42648 .36534 Mdot
.039 .916 .04 r
.5 Mabswid
.36275 .37192 m
.42668 .37968 L
s
0 0 0 r
2.5 Mabswid
.42668 .37968 Mdot
.039 .916 .04 r
.5 Mabswid
.36112 .38709 m
.42692 .39398 L
s
0 0 0 r
2.5 Mabswid
.42692 .39398 Mdot
.039 .916 .04 r
.5 Mabswid
.35813 .40839 m
.42767 .42641 L
s
0 0 0 r
2.5 Mabswid
.42767 .42641 Mdot
.039 .916 .04 r
.5 Mabswid
.3554 .42389 m
.4281 .4414 L
s
0 0 0 r
2.5 Mabswid
.4281 .4414 Mdot
.039 .916 .04 r
.5 Mabswid
.35224 .43932 m
.4286 .45632 L
s
0 0 0 r
2.5 Mabswid
.4286 .45632 Mdot
.039 .916 .04 r
.5 Mabswid
.4286 .1853 m
.50878 .1768 L
s
0 0 0 r
2.5 Mabswid
.50878 .1768 Mdot
.039 .916 .04 r
.5 Mabswid
.4281 .20022 m
.51044 .19057 L
s
0 0 0 r
2.5 Mabswid
.51044 .19057 Mdot
.039 .916 .04 r
.5 Mabswid
.42767 .21522 m
.51194 .20438 L
s
0 0 0 r
2.5 Mabswid
.51194 .20438 Mdot
.039 .916 .04 r
.5 Mabswid
.42692 .24764 m
.51525 .24325 L
s
0 0 0 r
2.5 Mabswid
.51525 .24325 Mdot
.039 .916 .04 r
.5 Mabswid
.42668 .26195 m
.51608 .25654 L
s
0 0 0 r
2.5 Mabswid
.51608 .25654 Mdot
.039 .916 .04 r
.5 Mabswid
.42648 .27628 m
.51675 .26984 L
s
0 0 0 r
2.5 Mabswid
.51675 .26984 Mdot
.039 .916 .04 r
.5 Mabswid
.42625 .30669 m
.51781 .30767 L
s
0 0 0 r
2.5 Mabswid
.51781 .30767 Mdot
.039 .916 .04 r
.5 Mabswid
.42623 .32081 m
.51789 .32081 L
s
0 0 0 r
2.5 Mabswid
.51789 .32081 Mdot
.039 .916 .04 r
.5 Mabswid
.42625 .33493 m
.51781 .33395 L
s
0 0 0 r
2.5 Mabswid
.51781 .33395 Mdot
.039 .916 .04 r
.5 Mabswid
.42648 .36534 m
.51675 .37178 L
s
0 0 0 r
2.5 Mabswid
.51675 .37178 Mdot
.039 .916 .04 r
.5 Mabswid
.42668 .37968 m
.51608 .38508 L
s
0 0 0 r
2.5 Mabswid
.51608 .38508 Mdot
.039 .916 .04 r
.5 Mabswid
.42692 .39398 m
.51525 .39837 L
s
0 0 0 r
2.5 Mabswid
.51525 .39837 Mdot
.039 .916 .04 r
.5 Mabswid
.42767 .42641 m
.51194 .43724 L
s
0 0 0 r
2.5 Mabswid
.51194 .43724 Mdot
.039 .916 .04 r
.5 Mabswid
.4281 .4414 m
.51044 .45105 L
s
0 0 0 r
2.5 Mabswid
.51044 .45105 Mdot
.039 .916 .04 r
.5 Mabswid
.4286 .45632 m
.50878 .46482 L
s
0 0 0 r
2.5 Mabswid
.50878 .46482 Mdot
.039 .916 .04 r
.5 Mabswid
.50878 .1768 m
.97619 .13504 L
s
0 0 0 r
2.5 Mabswid
.97619 .13504 Mdot
.039 .916 .04 r
.5 Mabswid
.51044 .19057 m
.97619 .13504 L
s
0 0 0 r
2.5 Mabswid
.97619 .13504 Mdot
.039 .916 .04 r
.5 Mabswid
.51194 .20438 m
.97619 .13504 L
s
0 0 0 r
2.5 Mabswid
.97619 .13504 Mdot
.039 .916 .04 r
.5 Mabswid
.51525 .24325 m
.97619 .22704 L
s
0 0 0 r
2.5 Mabswid
.97619 .22704 Mdot
.039 .916 .04 r
.5 Mabswid
.51608 .25654 m
.97619 .22717 L
s
0 0 0 r
2.5 Mabswid
.97619 .22717 Mdot
.039 .916 .04 r
.5 Mabswid
.51675 .26984 m
.97619 .22729 L
s
0 0 0 r
2.5 Mabswid
.97619 .22729 Mdot
.039 .916 .04 r
.5 Mabswid
.51781 .30767 m
.97619 .32064 L
s
0 0 0 r
2.5 Mabswid
.97619 .32064 Mdot
.039 .916 .04 r
.5 Mabswid
.51789 .32081 m
.97619 .32081 L
s
0 0 0 r
2.5 Mabswid
.97619 .32081 Mdot
.039 .916 .04 r
.5 Mabswid
.51781 .33395 m
.97619 .32098 L
s
0 0 0 r
2.5 Mabswid
.97619 .32098 Mdot
.039 .916 .04 r
.5 Mabswid
.51675 .37178 m
.97619 .41433 L
s
0 0 0 r
2.5 Mabswid
.97619 .41433 Mdot
.039 .916 .04 r
.5 Mabswid
.51608 .38508 m
.97619 .41445 L
s
0 0 0 r
2.5 Mabswid
.97619 .41445 Mdot
.039 .916 .04 r
.5 Mabswid
.51525 .39837 m
.97619 .41458 L
s
0 0 0 r
2.5 Mabswid
.97619 .41458 Mdot
.039 .916 .04 r
.5 Mabswid
.51194 .43724 m
.97619 .50659 L
s
0 0 0 r
2.5 Mabswid
.97619 .50659 Mdot
.039 .916 .04 r
.5 Mabswid
.51044 .45105 m
.97619 .50659 L
s
0 0 0 r
2.5 Mabswid
.97619 .50659 Mdot
.039 .916 .04 r
.5 Mabswid
.50878 .46482 m
.97619 .50659 L
s
0 0 0 r
2.5 Mabswid
.97619 .50659 Mdot
0 0 m
1 0 L
1 .64162 L
0 .64162 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{768.75, 493.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 767.75}, {492.25, 0}} -> {-4.81106, -52.5006, \
0.213308, 0.213308}},
  CellTags->"Lens Optimizations"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Prism Examples", "Section",
  CellTags->"Prism Examples"],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[{
\tMove[RainbowOfRays[{.45,.65},NumberOfRays->11],{0,-2},30],
\tMove[Prism[{60, 10, 60}, 10, Centered->True],5,15],
\tMove[Screen[10],{50,-4.5}]
\t},PlotType->TopView, ShowLabels->False];\
\>", "Input",
  CellTags->"Prism Examples"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .28665 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.187777 0.0190476 [
[ 0 0 0 0 ]
[ 1 .28665 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.09439 .09574 m
.14371 .27982 L
.14371 .27982 L
.09439 .09574 L
.09439 .09574 L
s
.27842 .14505 m
.14366 .2798 L
.14366 .2798 L
.27842 .14505 L
.27842 .14505 L
s
.09435 .09577 m
.27843 .1451 L
.27843 .1451 L
.09435 .09577 L
.09435 .09577 L
s
.09436 .09575 m
.14368 .27982 L
.27844 .14507 L
.09436 .09575 L
s
.09436 .09575 m
.14368 .27982 L
.27844 .14507 L
.09436 .09575 L
s
.97619 .00682 m
.97619 .03857 L
.97619 .07032 L
.97619 .10206 L
.97619 .13381 L
.97619 .16556 L
.97619 .1973 L
.97619 .1973 L
.97619 .16556 L
.97619 .13381 L
.97619 .10206 L
.97619 .07032 L
.97619 .03857 L
.97619 .00682 L
.97619 .00682 L
s
.97619 .10206 m
.97619 .10206 L
.97619 .10206 L
.97619 .10206 L
.97619 .10206 L
.97619 .10206 L
.97619 .10206 L
.97619 .10206 L
.97619 .10206 L
.97619 .10206 L
.97619 .10206 L
.97619 .10206 L
.97619 .10206 L
.97619 .10206 L
.97619 .10206 L
s
.97619 .1973 m
.97619 .19406 L
.97619 .18454 L
.97619 .16941 L
.97619 .14968 L
.97619 .12671 L
.97619 .10206 L
.97619 .07741 L
.97619 .05444 L
.97619 .03472 L
.97619 .01958 L
.97619 .01007 L
.97619 .00682 L
.97619 .01007 L
.97619 .01958 L
.97619 .03472 L
.97619 .05444 L
.97619 .07741 L
.97619 .10206 L
.97619 .12671 L
.97619 .14968 L
.97619 .16941 L
.97619 .18454 L
.97619 .19406 L
.97619 .1973 L
s
.001 .092 .901 r
.02381 .14968 m
.1244 .20776 L
s
% Start of user PostScript
0 -2. 5.28109 1.04904 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1244 .20776 Mdot
.003 .238 .772 r
.5 Mabswid
.02381 .14968 m
.1244 .20776 L
s
% Start of user PostScript
0 -2. 5.28109 1.04904 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1244 .20776 Mdot
.006 .736 .203 r
.5 Mabswid
.02381 .14968 m
.1244 .20776 L
s
% Start of user PostScript
0 -2. 5.28109 1.04904 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1244 .20776 Mdot
.014 .88 .073 r
.5 Mabswid
.02381 .14968 m
.1244 .20776 L
s
% Start of user PostScript
0 -2. 5.28109 1.04904 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1244 .20776 Mdot
.035 .914 .042 r
.5 Mabswid
.02381 .14968 m
.1244 .20776 L
s
% Start of user PostScript
0 -2. 5.28109 1.04904 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1244 .20776 Mdot
.197 .923 .028 r
.5 Mabswid
.02381 .14968 m
.1244 .20776 L
s
% Start of user PostScript
0 -2. 5.28109 1.04904 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1244 .20776 Mdot
.897 .912 .021 r
.5 Mabswid
.02381 .14968 m
.1244 .20776 L
s
% Start of user PostScript
0 -2. 5.28109 1.04904 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1244 .20776 Mdot
.941 .824 .016 r
.5 Mabswid
.02381 .14968 m
.1244 .20776 L
s
% Start of user PostScript
0 -2. 5.28109 1.04904 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1244 .20776 Mdot
.95 .123 .013 r
.5 Mabswid
.02381 .14968 m
.1244 .20776 L
s
% Start of user PostScript
0 -2. 5.28109 1.04904 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1244 .20776 Mdot
.951 .031 .011 r
.5 Mabswid
.02381 .14968 m
.1244 .20776 L
s
% Start of user PostScript
0 -2. 5.28109 1.04904 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1244 .20776 Mdot
.947 .013 .01 r
.5 Mabswid
.02381 .14968 m
.1244 .20776 L
s
% Start of user PostScript
0 -2. 5.28109 1.04904 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1244 .20776 Mdot
.001 .092 .901 r
.5 Mabswid
.1244 .20776 m
.199 .22447 L
s
% Start of user PostScript
5.28109 1.04904 9.19739 1.92633 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.199 .22447 Mdot
.003 .238 .772 r
.5 Mabswid
.1244 .20776 m
.19896 .22451 L
s
% Start of user PostScript
5.28109 1.04904 9.19541 1.92831 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19896 .22451 Mdot
.006 .736 .203 r
.5 Mabswid
.1244 .20776 m
.19893 .22454 L
s
% Start of user PostScript
5.28109 1.04904 9.19367 1.93005 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19893 .22454 Mdot
.014 .88 .073 r
.5 Mabswid
.1244 .20776 m
.1989 .22457 L
s
% Start of user PostScript
5.28109 1.04904 9.19213 1.93159 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1989 .22457 Mdot
.035 .914 .042 r
.5 Mabswid
.1244 .20776 m
.19887 .2246 L
s
% Start of user PostScript
5.28109 1.04904 9.19076 1.93296 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19887 .2246 Mdot
.197 .923 .028 r
.5 Mabswid
.1244 .20776 m
.19885 .22462 L
s
% Start of user PostScript
5.28109 1.04904 9.18953 1.9342 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19885 .22462 Mdot
.897 .912 .021 r
.5 Mabswid
.1244 .20776 m
.19883 .22464 L
s
% Start of user PostScript
5.28109 1.04904 9.18842 1.93531 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19883 .22464 Mdot
.941 .824 .016 r
.5 Mabswid
.1244 .20776 m
.19881 .22466 L
s
% Start of user PostScript
5.28109 1.04904 9.18741 1.93631 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19881 .22466 Mdot
.95 .123 .013 r
.5 Mabswid
.1244 .20776 m
.19879 .22468 L
s
% Start of user PostScript
5.28109 1.04904 9.18649 1.93723 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19879 .22468 Mdot
.951 .031 .011 r
.5 Mabswid
.1244 .20776 m
.19877 .22469 L
s
% Start of user PostScript
5.28109 1.04904 9.18565 1.93807 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19877 .22469 Mdot
.947 .013 .01 r
.5 Mabswid
.1244 .20776 m
.19876 .22471 L
s
% Start of user PostScript
5.28109 1.04904 9.18487 1.93885 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19876 .22471 Mdot
.001 .092 .901 r
.5 Mabswid
.199 .22447 m
.97619 .09113 L
s
% Start of user PostScript
9.19739 1.92633 50. -5.0739 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .09113 Mdot
.003 .238 .772 r
.5 Mabswid
.19896 .22451 m
.97619 .09348 L
s
% Start of user PostScript
9.19541 1.92831 50. -4.95071 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .09348 Mdot
.006 .736 .203 r
.5 Mabswid
.19893 .22454 m
.97619 .09553 L
s
% Start of user PostScript
9.19367 1.93005 50. -4.84302 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .09553 Mdot
.014 .88 .073 r
.5 Mabswid
.1989 .22457 m
.97619 .09734 L
s
% Start of user PostScript
9.19213 1.93159 50. -4.74813 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .09734 Mdot
.035 .914 .042 r
.5 Mabswid
.19887 .2246 m
.97619 .09894 L
s
% Start of user PostScript
9.19076 1.93296 50. -4.66394 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .09894 Mdot
.197 .923 .028 r
.5 Mabswid
.19885 .22462 m
.97619 .10037 L
s
% Start of user PostScript
9.18953 1.9342 50. -4.58873 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .10037 Mdot
.897 .912 .021 r
.5 Mabswid
.19883 .22464 m
.97619 .10166 L
s
% Start of user PostScript
9.18842 1.93531 50. -4.52113 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .10166 Mdot
.941 .824 .016 r
.5 Mabswid
.19881 .22466 m
.97619 .10282 L
s
% Start of user PostScript
9.18741 1.93631 50. -4.46002 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .10282 Mdot
.95 .123 .013 r
.5 Mabswid
.19879 .22468 m
.97619 .10388 L
s
% Start of user PostScript
9.18649 1.93723 50. -4.40447 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .10388 Mdot
.951 .031 .011 r
.5 Mabswid
.19877 .22469 m
.97619 .10485 L
s
% Start of user PostScript
9.18565 1.93807 50. -4.35371 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .10485 Mdot
.947 .013 .01 r
.5 Mabswid
.19876 .22471 m
.97619 .10574 L
s
% Start of user PostScript
9.18487 1.93885 50. -4.30711 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .10574 Mdot
0 0 m
1 0 L
1 .28665 L
0 .28665 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{691.812, 198.312},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:c0000aR000`400?l00000o`00003ooooooooo
oooookGooooo003ooooooooooooo]Oooool00?ooooooooooooneooooo`00oooooooooooookGooooo
003ooooooooooooo]Oooool00?oooooooooooonSooooo`03o`000?oooooooooo00oooooo003ooooo
ooooooooXoooool00ol0003oooooooooo`0?ooooo`00oooooooooooooj?ooooo00?o0000oooooooo
ool03oooool00?oooooooooooonSooooo`03o`000?oooooooooo00oooooo003oooooooooooooXooo
ool00ol0003oooooooooo`0?ooooo`00oooooooooooooj?ooooo00?o0000ooooooooool03oooool0
0?oooooooooooonSooooo`03o`000?oooooooooo00oooooo003oooooooooooooXoooool00ol0003o
ooooooooo`0?ooooo`00oooooooooooooj?ooooo00?o0000ooooooooool03oooool00?oooooooooo
oonSooooo`03o`000?oooooooooo00oooooo003oooooooooooooXoooool00ol0003oooooooooo`0?
ooooo`00oooooooooooooj?ooooo00?o0000ooooooooool03oooool00?oooooooooooonSooooo`03
o`000?oooooooooo00oooooo003oooooooooooooXoooool00ol0003oooooooooo`0?ooooo`00oooo
oooooooooj?ooooo00?o0000ooooooooool03oooool00?oooooooooooonSooooo`03o`000?oooooo
oooo00oooooo003oooooooooooooXoooool00ol0003oooooooooo`0?ooooo`00oooooooooooooj?o
oooo00?o0000ooooooooool03oooool00?oooooooooooonSooooo`03o`000?oooooooooo00oooooo
003oooooooooooooXoooool00ol0003oooooooooo`0?ooooo`00oooooooooooooj?ooooo00?o0000
ooooooooool03oooool00?oooooooooooonSooooo`03o`000?oooooooooo00oooooo003ooooooooo
ooooXoooool00ol0003oooooooooo`0?ooooo`00oooooooooooooj?ooooo00?o0000ooooooooool0
3oooool00?oooooooooooonSooooo`03o`000?oooooooooo00oooooo003oooooooooooooXoooool0
0ol0003oooooooooo`0?ooooo`00oooooooooooooj?ooooo00?o0000ooooooooool03oooool00?oo
oooooooooonSooooo`03o`000?oooooooooo00oooooo003oooooooooooooXoooool00ol0003ooooo
ooooo`0?ooooo`00oooooooooooooj?ooooo00?o0000ooooooooool03oooool00?oooooooooooonS
ooooo`03o`000?oooooooooo00oooooo003oooooooooooooXoooool00ol0003oooooooooo`0?oooo
o`00oooooooooooooj?ooooo00?o0000ooooooooool03oooool00?oooooooooooonSooooo`03o`00
0?oooooooooo00oooooo003oooooooooooooXoooool00ol0003oooooooooo`0?ooooo`00oooooooo
oooooj?ooooo00?o0000ooooooooool03oooool00?oooooooooooonSooooo`03o`000?oooooooooo
00oooooo003oooooooooooooXoooool00ol0003oooooooooo`0?ooooo`00oooooooooooooj?ooooo
00?o0000ooooooooool03oooool00?oooooooooooonSooooo`03o`000?oooooooooo00oooooo003o
ooooooooooooXoooool00ol0003oooooooooo`0?ooooo`00oooooooooooooj?ooooo00?o0000oooo
ooooool03oooool00?oooooooooooonSooooo`03o`000?oooooooooo00oooooo003ooooooooooooo
Xoooool00ol0003oooooooooo`0?ooooo`00oooooooooooooj?ooooo00?o0000ooooooooool03ooo
ool00?oooooooooooonSooooo`03o`000?oooooooooo00oooooo003oooooooooooooXoooool00ol0
003oooooooooo`0?ooooo`00oooooooooooooj?ooooo00?o0000ooooooooool03oooool00?oooooo
oooooonSooooo`03o`000?oooooooooo00oooooo003oooooooooooooXoooool00ol0003ooooooooo
o`0?ooooo`00oooooooooooooj?ooooo00?o0000ooooooooool03oooool00?oooooooooooonSoooo
o`03o`000?oooooooooo00oooooo003oooooooooooooXoooool00ol0003oooooooooo`0?ooooo`00
oooooooooooooj?ooooo00?o0000ooooooooool03oooool00?oooooooooooonSooooo`03o`000?oo
oooooooo00oooooo003oooooooooooooXoooool00ol0003oooooooooo`0?ooooo`00oooooooooooo
oj?ooooo00?o0000ooooooooool03oooool00?oooooooooooonJooooo`Ko01OV0_ooool2o`00017o
oooo003oooooooooooooW?ooool6o`0GiP;o00004Oooool00?oooooooooooonJooooo`Ko03c50_l0
5nH2o`00017ooooo003oooooooooooooU?ooool6o`0GiPKo0K`c0_l0?<D2o`00017ooooo0012oooo
o`?o0000oooooooooooood[ooooo1Ol05nH6ooooo`;o03c51_l1_3<2o`00017ooooo0012ooooo`03
o`000?oooooooooo00Co0000oooooooooooood3ooooo1_l05nH5ooooo`Ko03c52?l3hA82o`00017o
oooo0012ooooo`03o`000?oooooooooo00Cooooo0ol0003ooooooooooooo=oooool6o`0GiPGooooo
1_l0?<D6o`6l<`So2>T:0_l0000Aooooo`00@oooool00ol0003oooooooooo`06ooooo`Co0000oooo
ooooooooobgooooo1_l05nH5ooooo`Ko03c51_l1_3<6o`?Q4PKoiNT50_lbk0L2o`00017ooooo0013
ooooo`03o`000?oooooooooo00[ooooo1?l0003ooooooooooooo8oooool6o`0GiPGooooo1_l0?<D6
o`6l<`Ko0n4B1_l8j@X6oo3B10;oiNT50_l0000Aooooo`00@oooool00ol0003oooooooooo`0>oooo
o`?o0000oooooooooooooa_ooooo1Ol05nH5ooooo`Ko03c51_l1_3<5o`?Q4PKo2>T:1olbk0L6oo<O
0`;ol=840_l0000Aooooo`00@oooool00ol0003oooooooooo`0Aooooo`Co0000oooooooooooooa7o
oooo1_l05nH4ooooo`Ko03c51_l1_3<5o`?Q4PKo2>T:1_lbk0L6onGY1@03oo3B1?ob0`;olP<200Co
lP<20_oc1`82o`00017ooooo0014ooooo`03o`000?oooooooooo01Cooooo1?l0003ooooooooooooo
1oooool6o`0GiPCooooo1_l0?<D5o`6l<`Ko0n4B1_l8j@X6oc;/1`KoiNT51_o`dP@3oo<70PKolP<2
0_l0000Aooooo`00A?ooool00ol0003oooooooooo`0Hooooo`Co0000ooooooolooooo`Ko01OV1Ooo
ool5o`0la@Go0K`c1_l3hA86o`SY2PKo<^`71_oUj@D6oo3B10Kol`L22Oob0`800ooooooo0000oooo
o`0@ooooo`00A?ooool00ol0003oooooooooo`0Looooo`?o0000ooooooocooooo`Ko01OV1Oooool5
o`0la@Go0K`c1_l3hA86o`SY2PGo<^`71_oUj@D6oo3B10Ool`L21_ob0`82ooooo`04oo<O0oob0`;o
lP<2oo830PCooooo00?o0000ooooooooool03oooool004Gooooo00?o0000ooooooooool07_ooool4
o`000?oooooojOooool6o`0GiPGooooo1Ol0?<D5o`6l<`Ko0n4B1Ol8j@X6oc;/1`KoiNT51_o`dP@6
oo<70POolP<22?ooool00oob0`;oooooooooo`05ooooo`03o`000?oooooooooo00oooooo0015oooo
o`03o`000?oooooooooo02;ooooo1?l0003oooooon3ooooo1Ol05nH5ooooo`Go03c51Ol1_3<6o`?Q
4PGo2>T:1_lbk0L6onGY1@Kol=841_oc1`86oo830QOooooo00?o0000ooooooooool03oooool004Go
oooo00?o0000ooooooooool09_ooool3o`000?ooooooeoooool6o`0GiPCooooo1Ol0?<D5o`6l<`Go
0n4B1_l8j@X5oc;/1`KoiNT51_o`dP@6oo<70POolP<27Oooool00ol0003oooooooooo`0?ooooo`00
AOooool00ol0003oooooooooo`0Yooooo`Co0000ooooooo=ooooo`Ko01OV1?ooool5o`0la@Go0K`c
1Ol3hA86o`SY2PGo<^`71_oUj@D6oo3B10Kol`L21_ob0`8Tooooo`03o`000?oooooooooo00oooooo
0016ooooo`03o`000?oooooooooo02cooooo1?l0003ooooool?ooooo1_l05nH4ooooo`Go03c51Ol1
_3<5o`?Q4PGo2>T:1_lbk0L5onGY1@Kol=841_oc1`87oo830R[ooooo00?o0000ooooooooool03ooo
ool004Kooooo00?o0000ooooooooool0<?ooool3o`000?oooooo^_ooool6o`0GiPCooooo1Ol0?<D5
o`6l<`Go0n4B1Ol8j@X6oc;/1`GoiNT51_o`dP@6oo<70PKolP<2<Oooool00ol0003oooooooooo`0?
ooooo`00A_ooool00ol0003oooooooooo`0cooooo`Co0000oooooonaooooo`Go01OV1?ooool5o`0l
a@Go0K`c1Ol3hA85o`SY2PGo<^`71_oUj@D5oo3B10Kol`L21oob0`8gooooo`03o`000?oooooooooo
00oooooo0016ooooo`03o`000?oooooooooo03Oooooo1?l0003oooooojOooooo1_l05nH3ooooo`Go
03c51Ol1_3<5o`?Q4PGo2>T:1Olbk0L5onGY1@Kol=841Ooc1`87oo830Skooooo00?o0000oooooooo
ool03oooool004Oooooo00?o0000ooooooooool0>_ooool4o`000?ooooooWOooool6o`0GiP?ooooo
1Ol0?<D5o`6l<`Go0n4B1Ol8j@X5oc;/1`GoiNT51Oo`dP@6oo<70PKolP<2AOooool00ol0003ooooo
ooooo`0?ooooo`00Aoooool00ol0003oooooooooo`0nooooo`?o0000oooooonDooooo`Ko01OV0ooo
ool5o`0la@Go0K`c1?l3hA85o`SY2PGo<^`71_oUj@D5oo3B10Gol`L21oob0`9;ooooo`03o`000?oo
oooooooo00oooooo0017ooooo`03o`000?oooooooooo047ooooo1?l0003ooooooh[ooooo1_l05nH3
ooooo`Go03c51?l1_3<5o`?Q4PGo2>T:1Olbk0L5onGY1@Kol=841Ooc1`86oo830U;ooooo00?o0000
ooooooooool03oooool004Oooooo00?o0000ooooooooool0AOooool4o`000?ooooooPOooool5o`0G
iP?ooooo1Ol0?<D4o`6l<`Go0n4B1Ol8j@X5oc;/1`GoiNT51Oo`dP@5oo<70POolP<2F?ooool00ol0
003oooooooooo`0?ooooo`00B?ooool00ol0003oooooooooo`18ooooo`?o0000oooooomhooooo`Ko
01OV0_ooool5o`0la@Co0K`c1Ol3hA85o`SY2PGo<^`71OoUj@D5oo3B10Gol`L21_ob0`9Oooooo`03
o`000?oooooooooo00oooooo0018ooooo`03o`000?oooooooooo04_ooooo1?l0003oooooofkooooo
1_l05nH2ooooo`Go03c51?l1_3<5o`?Q4PCo2>T:1Olbk0L5onGY1@Gol=841Ooc1`87oo830VGooooo
00?o0000ooooooooool03oooool004Sooooo00?o0000ooooooooool0Coooool4o`000?ooooooI?oo
ool6o`0GiP;ooooo1Ol0?<D4o`6l<`Go0n4B1?l8j@X5oc;/1`GoiNT51Oo`dP@5oo<70PKolP<2K?oo
ool00ol0003oooooooooo`0?ooooo`00BOooool00ol0003oooooooooo`1Booooo`Co0000oooooomJ
ooooo`Ko01OV0_ooool5o`0la@Co0K`c1?l3hA85o`SY2PGo<^`71?oUj@D5oo3B10Gol`L21oob0`9b
ooooo`03o`000?oooooooooo00oooooo0019ooooo`03o`000?oooooooooo05Kooooo0ol0003ooooo
oe7ooooo1_l05nH3ooooo`Co03c51?l1_3<4o`?Q4PGo2>T:1?lbk0L5onGY1@Gol=841Ooc1`86oo83
0WWooooo00?o0000ooooooooool03oooool004Wooooo00?o0000ooooooooool0FOooool4o`000?oo
ooooB?ooool5o`0GiP?ooooo1?l0?<D4o`6l<`Co0n4B1Ol8j@X4oc;/1`GoiNT51?o`dP@5oo<70POo
lP<2Ooooool00ol0003oooooooooo`0?ooooo`00BOooool00ol0003oooooooooo`1Mooooo`Co0000
oooooolnooooo`Ko01OV0_ooool4o`0la@Co0K`c1?l3hA84o`SY2PGo<^`71?oUj@D5oo3B10Gol`L2
1_ob0`:6ooooo`03o`000?oooooooooo00oooooo001:ooooo`03o`000?oooooooooo063ooooo0ol0
003oooooocGooooo1_l05nH2ooooo`Co03c51?l1_3<4o`?Q4PCo2>T:1?lbk0L5onGY1@Gol=841?oc
1`87oo830Xcooooo00?o0000ooooooooool03oooool004[ooooo00?o0000ooooooooool0Hoooool4
o`000?oooooo:oooool6o`0GiP;ooooo1?l0?<D4o`6l<`Co0n4B1?l8j@X4oc;/1`GoiNT51?o`dP@5
oo<70PKolP<2Toooool00ol0003oooooooooo`0?ooooo`00B_ooool00ol0003oooooooooo`1Woooo
o`Co0000oooooolQooooo`Ko01OV0_ooool4o`0la@Co0K`c1?l3hA84o`SY2PCo<^`71?oUj@D5oo3B
10Col`L21oob0`:Iooooo`03o`000?oooooooooo00oooooo001:ooooo`03o`000?oooooooooo06_o
oooo0ol0003ooooooaWooooo1Ol05nH2ooooo`Co03c50ol1_3<4o`?Q4PCo2>T:1Olbk0L4onGY1@Co
l=841Ooc1`86oo830Z3ooooo00?o0000ooooooooool03oooool004_ooooo00?o0000ooooooooool0
KOooool4o`000?oooooo3oooool6o`0GiP03ooooool0?<Go03c500;o03c50ol1_3<4o`?Q4PCo2>T:
1?lbk0L4onGY1@Gol=841?oc1`87oo830ZKooooo00?o0000ooooooooool03oooool004_ooooo00?o
0000ooooooooool0LOooool3o`000?oooooo1_ooool6o`0GiP03ooooool0?<Go03c500;o03c50ol1
_3<4o`?Q4PCo2>T:1?lbk0L4onGY1@Col=841Ooc1`86oo830Zgooooo00?o0000ooooooooool03ooo
ool004_ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`3nooooo`Ko01OV00?ooooo
o`0laOl0?<D00_l0?<D3o`6l<`Co0n4B1?l8j@X4oc;/1`CoiNT51?o`dP@4oo<70POolP<2/oooool0
0ol0003oooooooooo`0?ooooo`00C?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
0?Wooooo1_l05nH00ooooooo03c5o`0la@02o`0la@?o0K`c1?l3hA84o`SY2P?o<^`71?oUj@D4oo3B
10Gol`L21_ob0`:jooooo`03o`000?oooooooooo00oooooo000Aooooo`;olP<2>Oooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo0?Cooooo1_l05nH00ooooooo03c5o`0la@02o`0la@?o
0K`c1?l3hA83o`SY2PCo<^`71?oUj@D4oo3B10Col`L21oob0`;0ooooo`03o`000?oooooooooo00oo
oooo000Cooooo`;olP<2=oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo0?3ooooo
1Ol05nH00ooooooo03c5o`0la@02o`0la@?o0K`c1?l3hA83o`SY2PCo<^`71?oUj@D4oo3B10?ol`L2
1oob0`;7ooooo`03o`000?oooooooooo00oooooo000Eooooo`03oo830_oooooooooo03Cooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`3[ooooo`Ko01OV1?l0?<D3o`6l<`?o0n4B1?l8
j@X4oc;/1`?oiNT51?o`dP@4oo<70PKolP<2c_ooool00ol0003oooooooooo`0?ooooo`005_ooool2
oo830SGooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`3Vooooo`Ko01OV1?l0?<D3
o`6l<`?o0n4B1?l8j@X3oc;/1`CoiNT51?o`dP@3oo<70POolP<2e?ooool00ol0003oooooooooo`0?
ooooo`006?ooool2oo830S?ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`3Qoooo
o`Ko01OV1?l0?<D3o`6l<`?o0n4B0ol8j@X4oc;/1`CoiNT50oo`dP@4oo<70PKolP<2foooool00ol0
003oooooooooo`0?ooooo`006_ooool00oob0`;oooooooooo`0`ooooo`03o`000?oooooooooo06Wo
oooo00?o0000ooooooooool0g?ooool6o`0GiPCo03c50ol1_3<3o`?Q4P?o2>T:1?lbk0L3onGY1@Co
l=840ooc1`87oo830^7ooooo00?o0000ooooooooool03oooool001_ooooo0_ob0`8`ooooo`03o`00
0?oooooooooo06Sooooo00?o0000ooooooooool0f?ooool5o`0GiPCo03c50ol1_3<3o`?Q4P?o2>T:
0olbk0L4onGY1@?ol=841?oc1`86oo830^Sooooo00?o0000ooooooooool03oooool001gooooo0_ob
0`8_ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0doooool6o`0GiP;o03c51?l1
_3<3o`?Q4P?o2>T:0olbk0L3onGY1@Col=840ooc1`87oo830^kooooo00?o0000ooooooooool03ooo
ool001oooooo0_ob0`8]ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0c_ooool6
o`0GiP;o03c50ol1_3<3o`?Q4PCo2>T:0olbk0L3onGY1@?ol=841?oc1`86oo830_Gooooo00?o0000
ooooooooool03oooool0027ooooo00?olP<2ooooooooool0:_ooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooooooo0<Wooooo1_l05nH2o`0la@?o0K`c0ol3hA83o`SY2P?o<^`71?oUj@D3oo3B
10?ol`L21oob0`;kooooo`03o`000?oooooooooo00oooooo000Rooooo`;olP<2:_ooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo0<Cooooo1_l05nH2o`0la@?o0K`c0ol3hA83o`SY2P?o
<^`70ooUj@D3oo3B10Col`L21_ob0`;oooooo`?ooooo00?o0000ooooooooool03oooool002Cooooo
0_ob0`8Yooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0`?ooool5o`0GiP;o03c5
0ol1_3<3o`?Q4P?o2>T:0olbk0L3onGY1@?ol=840ooc1`87oo830_oooooo2Oooool00ol0003ooooo
ooooo`0?ooooo`009_ooool2oo830ROooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`2kooooo`Go01OV0_l0?<D3o`6l<`?o0n4B0ol8j@X3oc;/1`?oiNT50oo`dP@3oo<70PKolP<2oooo
ool@ooooo`03o`000?oooooooooo00oooooo000Xooooo`03oo830_oooooooooo02Cooooo00?o0000
ooooooooool0Goooool00ol0003oooooooooo`2fooooo`Go01OV0_l0?<D3o`6l<`?o0n4B0ol8j@X2
oc;/1`?oiNT50oo`dP@3oo<70POolP<2oooooolFooooo`03o`000?oooooooooo00oooooo000Yoooo
o`;olP<29Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo0;7ooooo1Ol05nH2o`0l
a@?o0K`c0ol3hA82o`SY2P?o<^`70ooUj@D3oo3B10?ol`L21_ob0`;ooooooagooooo00?o0000oooo
ooooool03oooool002_ooooo0_ob0`8Sooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool0[?ooool5o`0GiP;o03c50ol1_3<2o`?Q4P?o2>T:0olbk0L2onGY1@?ol=840ooc1`87oo830_oo
oooo8oooool00ol0003oooooooooo`0?ooooo`00;Oooool00oob0`;oooooooooo`0Pooooo`03o`00
0?oooooooooo05_ooooo00?o0000ooooooooool0Yoooool5o`0GiP;o03c50ol1_3<2o`?Q4P?o2>T:
0_lbk0L3onGY1@?ol=840ooc1`86oo830_oooooo:_ooool00ol0003oooooooooo`0?ooooo`00;_oo
ool2oo830R3ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`2Sooooo`Co01OV0_l0
?<D3o`6l<`;o0n4B0ol8j@X2oc;/1`?oiNT50_o`dP@3oo<70POolP<2ooooool`ooooo`03o`000?oo
oooooooo00oooooo000`ooooo`;olP<27oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooo
oooo09kooooo1?l05nH2o`0la@?o0K`c0_l3hA82o`SY2P?o<^`70_oUj@D3oo3B10?ol`L21_ob0`;o
ooooocOooooo00?o0000ooooooooool03oooool003;ooooo0_ob0`8Mooooo`03o`000?oooooooooo
05Oooooo00?o0000ooooooooool0VOooool4o`0GiP;o03c50ol1_3<2o`?Q4P;o2>T:0olbk0L2onGY
1@;ol=840ooc1`87oo830_oooooo?Oooool00ol0003oooooooooo`0?ooooo`00=?ooool00oob0`;o
ooooooooo`0Jooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0U?ooool4o`0GiP;o
03c50ol1_3<2o`?Q4P;o2>T:0_lbk0L3onGY1@;ol=840ooc1`86oo830_ooooooA?ooool00ol0003o
ooooooooo`0?ooooo`00=Oooool2oo830Q[ooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`2?ooooo`Co01OV0_l0?<D2o`6l<`?o0n4B0_l8j@X2oc;/1`;oiNT50oo`dP@2oo<70POolP<2
oooooom:ooooo`03o`000?oooooooooo00oooooo000gooooo`;olP<26Oooool00ol0003ooooooooo
o`1Cooooo`03o`000?oooooooooo08_ooooo0ol05nH2o`0la@;o0K`c0_l3hA83o`SY2P;o<^`70_oU
j@D2oo3B10;ol`L21oob0`;ooooooe7ooooo00?o0000ooooooooool03oooool003Wooooo0_ob0`8G
ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0Q_ooool3o`0GiP;o03c50_l1_3<2
o`?Q4P;o2>T:0_lbk0L3onGY1@;ol=840_oc1`86oo830_ooooooF?ooool00ol0003oooooooooo`0?
ooooo`00>oooool00oob0`;oooooooooo`0Dooooo`03o`000?oooooooooo057ooooo00?o0000oooo
ooooool0POooool3o`0GiP;o03c50_l1_3<2o`?Q4P;o2>T:0_lbk0L2onGY1@;ol=840_oc1`87oo83
0_ooooooG_ooool00ol0003oooooooooo`0?ooooo`00??ooool2oo830QCooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`1looooo`Co01OV00?o03c5o`6l<ol1_3<00_l3hA82o`SY2P;o
<^`70_oUj@D2oo3B10;ol`L21_ob0`;oooooofGooooo00?o0000ooooooooool03oooool003kooooo
0_ob0`8Cooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0Moooool4o`0GiP03o`0l
aOl1_3?o0K`c00;o0n4B0_l8j@X00olbk0OoiNT5onGY1@02oo3B10;ol`L21oob0`;oooooof_ooooo
00?o0000ooooooooool03oooool0043ooooo00?olP<2ooooooooool04?ooool00ol0003ooooooooo
o`1=ooooo`03o`000?oooooooooo07;ooooo1?l05nH00ol0?<Go0K`co`6l<`02o`?Q4P03o`SY2_lb
k0Oo<^`700;oiNT50_o`dP@2oo<70PKolP<2oooooombooooo`03o`000?oooooooooo00oooooo0011
ooooo`;olP<24?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo06kooooo0ol05nH0
0ol0?<Go0K`co`6l<`02o`?Q4P03o`SY2_lbk0Oo<^`700;oiNT500?ol=84oo<70_oc1`801oob0`;o
ooooogSooooo00?o0000ooooooooool03oooool004?ooooo0_ob0`8?ooooo`03o`000?oooooooooo
04[ooooo00?o0000ooooooooool0JOooool3o`0GiP04o`0laOl1_3?o0K`co`?Q4P;o2>T:0_lbk0L0
0ooUj@Gol=84oo3B1002oo<70PKolP<2oooooomoooooo`03o`000?oooooooooo00oooooo0015oooo
o`;olP<23Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo06Cooooo0ol05nH01?l0
?<Go0K`co`6l<ol3hA82o`SY2P03oc;/1ooUj@GoiNT500;ol=8400?ol`L2oo830_ob0`801Oob0`;o
ooooohGooooo00?o0000ooooooooool03oooool004Oooooo00?olP<2ooooooooool02_ooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo05oooooo0ol05nH01?l0?<Go0K`co`6l<ol3hA82
o`SY2P04oc;/1ooUj@GoiNT5oo3B10;ol`L21_ob0`;oooooohcooooo00?o0000ooooooooool03ooo
ool004Sooooo0_ob0`8:ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0F_ooool3
o`0GiP05o`0laOl1_3?o0K`co`?Q4_l8j@X00_lbk0L01?oUj@Gol=84oo3B1?oc1`87oo830_oooooo
T_ooool00ol0003oooooooooo`0?ooooo`00B_ooool2oo830PWooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`1Fooooo`;o01OV00Ko03c5o`6l<ol3hA;o0n4Bo`SY2_lbk0L2onGY1@03
oo3B1?oc1`;ol`L200KolP<2oooooonIooooo`03o`000?oooooooooo00oooooo001<ooooo`;olP<2
1oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo057ooooo0_l05nH01ol0?<Go0K`c
o`?Q4_l3hA;o2>T:oc;/1ooUj@D00_o`dP@00ooc1`;olP<2oo830P05oo830_oooooo/Oooool004ko
oooo00ColP<2ooooooob0`;olP<20oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
04cooooo0_l05nH00ol0?<Go0K`co`?Q4P02o`SY2P03oc;/1ooUj@Gol=8400;ol`L21_ob0`;ooooo
okSooooo001?ooooo`ColP<20_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04Oo
oooo0_l05nH01?l0?<Go0K`co`?Q4_l8j@X2oc;/1`03onGY1Oo`dPCol`L200OolP<2oooooonnoooo
o`00D?ooool4oo830P;ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`12ooooo`;o
01OV00Oo03c5o`6l<ol3hA;o2>T:oc;/1ooUj@Gol=8400;ol`L21_ob0`;oooooolGooooo001>oooo
o`OolP<200?oooooo`000?ooool0@?ooool00ol0003oooooooooo`0nooooo`09o`0Gi_l0?<Go0K`c
o`?Q4_l8j@[o<^`7onGY1Oo`dPCol`L200OolP<2ooooooo;ooooo`00DOooool5oo830P03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0>Oooool02Ol05nKo03c5o`6l<ol3hA;o2>T:oc;/1ooU
j@Gol=84oo<70P06oo830_ooooood_ooool005Gooooo1?ob0`8mooooo`03o`000?oooooooooo03Co
oooo00So01OVo`0laOl1_3?o0n4Bo`SY2_oUj@Gol=84oo<70POolP<2oooooooHooooo`00E_ooool2
o`000003ooooooob0`;olP<200?olP<2=oooool00ol0003oooooooooo`0_ooooo`08o`0Gi_l0?<Go
0K`co`?Q4_lbk0OoiNT5oo3B1?oc1`86oo830_oooooogoooool005Oooooo00?o0000ooooooooool0
1?ooool4oo830S;ooooo00?o0000ooooooooool0:_ooool01ol05nKo03c5o`6l<ol8j@[o<^`7onGY
1Ooc1`801oob0`;oooooonGooooo001Gooooo`03o`000?oooooooooo00Sooooo1?ob0`8]ooooo`03
o`000?oooooooooo02Gooooo0_l05nH01?l1_3?o2>T:onGY1Oo`dP@7oo830_ooooook?ooool005So
oooo00?o0000ooooooooool02oooool5oo830ROooooo00?o0000ooooooooool08Oooool01Ol05nKo
0K`co`SY2_oUj@Gol`L200KolP<2ooooooocooooo`00F?ooool00ol0003oooooooooo`0@ooooo`Co
lP<28_ooool00ol0003oooooooooo`0Looooo`04o`0Gi_l1_3?o<^`7oo3B10OolP<2oooooooioooo
o`00F?ooool00ol0003oooooooooo`0Dooooo`ColP<27Oooool00ol0003oooooooooo`0Gooooo`04
o`0Gi_l3hA;o<^`7oo<70PKolP<2ooooooooooooo`7ooooo001Hooooo`03o`000?oooooooooo01So
oooo1Oob0`8Gooooo`03o`000?oooooooooo01;ooooo00?o01OVo`?Q4_oUj@D01oob0`;ooooooooo
oooo1oooool005Wooooo00?o0000ooooooooool07?ooool4oo830PKooooo0_ob0`8:ooooo`03o`00
0?oooooooooo00gooooo00?o01OVo`?Q4_o`dP@01_ob0`;ooooooooooooo3_ooool005Wooooo00?o
0000ooooooooool08?ooool4oo830P;ooooo1?ob0`87ooooo`03o`000?oooooooooo00Wooooo00?o
2>T:oo830_ob0`801Oob0`;ooooooooooooo5?ooool005Wooooo00?o0000ooooooooool09?ooool8
oo830PCooooo00?o0000ooooooooool01?ooool00ooUj@GolP<2oo830P04oo830_oooooooooooolK
ooooo`00FOooool00ol0003oooooooooo`0Vooooo`03oc;/1oob0`;olP<200ColP<20ol000000ooo
oooolP<2oo830P05oo830_oooooooooooolQooooo`00F_ooool00ol0003oooooooooo`0Tooooo`So
lP<200Co0000oo830_ob0`;olP<2ooooooooooooobSooooo001Jooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool0ooooooooooooobWooooo001Jooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0ooooooooooooob[ooooo001Jooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0ooooooooooooob_ooooo001Kooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0ooooooooooooobcooooo001Kooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0ooooooooooooobgooooo001Kooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0ooooooooooooobkooooo001Looooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
oooooooooooooboooooo001Looooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0oooo
oooooooooc3ooooo001Looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0oooooooo
oooooc7ooooo001Looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0oooooooooooo
oc;ooooo001Mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0oooooooooooooc?o
oooo001Mooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0ooooooooooooocCooooo
001Mooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0ooooooooooooocGooooo001M
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0ooooooooooooocKooooo001Noooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0ooooooooooooocOooooo001Nooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0ooooooooooooocSooooo001Nooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0ooooooooooooocWooooo001Oooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0oooooooooooooc[ooooo001Oooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0oooooooooooooc_ooooo001Oooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0oooooooooooooccooooo001Oooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0ooooooooooooocgooooo001Pooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0ooooooooooooockooooo001Pooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0ooooooooooooocoooooo001Pooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0oooooooooooood3ooooo001Pooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0oooooooooooood7ooooo001Qooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0oooooooooooood;ooooo001Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
oooooooooooood?ooooo001Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0oooo
ooooooooodCooooo001Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0oooooooo
ooooodGooooo001Rooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooooooooo
odKooooo001Rooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooooooooooodOo
oooo001Rooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0ooooooooooooodSooooo
001Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0ooooooooooooodWooooo001S
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooooooooood[ooooo001Soooo
o`05o`000?ooooooooooooooool00000ooooooooooooodgooooo001Sooooo`04o`000?oooooooooo
o`000?oooooooooooom>ooooo`00I?ooool2o`000?oooooooooooom?ooooo`00I?ooool00ol0003o
ooooooooo`3oooooooooooooC_ooool00?ooooooooooooneooooo`00oooooooooooookGooooo003o
oooooooooooo]Oooool00?ooooooooooooneooooo`00\
\>"],
  ImageRangeCache->{{{0, 690.812}, {197.312, 0}} -> {-1.34457, -9.85838, \
0.0762713, 0.0762713}},
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[
{SingleRay[],
Move[WedgePrism[20, 25, 3],30],
Boundary[100,GraphicDesign->Off]},
PlotType->TopView];\
\>", "Input",
  CellTags->"Prism Examples"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25013 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.125062 0.00952381 [
[ 0 0 0 0 ]
[ 1 .25013 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.30952 .00596 m
.42478 .00596 L
.41033 .04566 L
.30952 .04566 L
.30952 .00596 L
F
.30952 .04566 m
.41033 .04566 L
.39588 .08536 L
.30952 .08536 L
.30952 .04566 L
F
.30952 .08536 m
.39588 .08536 L
.38143 .12506 L
.30952 .12506 L
.30952 .08536 L
F
.30952 .12506 m
.38143 .12506 L
.36697 .16476 L
.30952 .16476 L
.30952 .12506 L
F
.30952 .16476 m
.36697 .16476 L
.35252 .20447 L
.30952 .20447 L
.30952 .16476 L
F
.30952 .20447 m
.35252 .20447 L
.33807 .24417 L
.30952 .24417 L
.30952 .20447 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.30952 .00596 m
.30952 .04566 L
.30952 .08536 L
.30952 .12506 L
.30952 .16476 L
.30952 .20447 L
.30952 .24417 L
.33807 .24417 L
.35252 .20447 L
.36697 .16476 L
.38143 .12506 L
.39588 .08536 L
.41033 .04566 L
.42478 .00596 L
.30952 .00596 L
s
.5 g
.30952 .12506 m
.38143 .12506 L
.38143 .12506 L
.30952 .12506 L
.30952 .12506 L
F
.30952 .12506 m
.38143 .12506 L
.38143 .12506 L
.30952 .12506 L
.30952 .12506 L
F
.30952 .12506 m
.38143 .12506 L
.38143 .12506 L
.30952 .12506 L
.30952 .12506 L
F
.30952 .12506 m
.38143 .12506 L
.38143 .12506 L
.30952 .12506 L
.30952 .12506 L
F
.30952 .12506 m
.38143 .12506 L
.38143 .12506 L
.30952 .12506 L
.30952 .12506 L
F
.30952 .12506 m
.38143 .12506 L
.38143 .12506 L
.30952 .12506 L
.30952 .12506 L
F
0 g
.30952 .12506 m
.30952 .12506 L
.30952 .12506 L
.30952 .12506 L
.30952 .12506 L
.30952 .12506 L
.30952 .12506 L
.38143 .12506 L
.38143 .12506 L
.38143 .12506 L
.38143 .12506 L
.38143 .12506 L
.38143 .12506 L
.38143 .12506 L
.30952 .12506 L
s
.30952 .24417 m
.33807 .24417 L
.33955 .24011 L
.30952 .24011 L
.30952 .24417 L
s
.30952 .24011 m
.33955 .24011 L
.34388 .22821 L
.30952 .22821 L
.30952 .24011 L
s
.30952 .22821 m
.34388 .22821 L
.35077 .20928 L
.30952 .20928 L
.30952 .22821 L
s
.30952 .20928 m
.35077 .20928 L
.35975 .18462 L
.30952 .18462 L
.30952 .20928 L
s
.30952 .18462 m
.35975 .18462 L
.3702 .15589 L
.30952 .15589 L
.30952 .18462 L
s
.30952 .15589 m
.3702 .15589 L
.38143 .12506 L
.30952 .12506 L
.30952 .15589 L
s
.30952 .12506 m
.38143 .12506 L
.39265 .09424 L
.30952 .09424 L
.30952 .12506 L
s
.30952 .09424 m
.39265 .09424 L
.4031 .06551 L
.30952 .06551 L
.30952 .09424 L
s
.30952 .06551 m
.4031 .06551 L
.41208 .04084 L
.30952 .04084 L
.30952 .06551 L
s
.30952 .04084 m
.41208 .04084 L
.41897 .02191 L
.30952 .02191 L
.30952 .04084 L
s
.30952 .02191 m
.41897 .02191 L
.4233 .01001 L
.30952 .01001 L
.30952 .02191 L
s
.30952 .01001 m
.4233 .01001 L
.42478 .00596 L
.30952 .00596 L
.30952 .01001 L
s
.30952 .00596 m
.42478 .00596 L
.4233 .01001 L
.30952 .01001 L
.30952 .00596 L
s
.30952 .01001 m
.4233 .01001 L
.41897 .02191 L
.30952 .02191 L
.30952 .01001 L
s
.30952 .02191 m
.41897 .02191 L
.41208 .04084 L
.30952 .04084 L
.30952 .02191 L
s
.30952 .04084 m
.41208 .04084 L
.4031 .06551 L
.30952 .06551 L
.30952 .04084 L
s
.30952 .06551 m
.4031 .06551 L
.39265 .09424 L
.30952 .09424 L
.30952 .06551 L
s
.30952 .09424 m
.39265 .09424 L
.38143 .12506 L
.30952 .12506 L
.30952 .09424 L
s
.30952 .12506 m
.38143 .12506 L
.3702 .15589 L
.30952 .15589 L
.30952 .12506 L
s
.30952 .15589 m
.3702 .15589 L
.35975 .18462 L
.30952 .18462 L
.30952 .15589 L
s
.30952 .18462 m
.35975 .18462 L
.35077 .20928 L
.30952 .20928 L
.30952 .18462 L
s
.30952 .20928 m
.35077 .20928 L
.34388 .22821 L
.30952 .22821 L
.30952 .20928 L
s
.30952 .22821 m
.34388 .22821 L
.33955 .24011 L
.30952 .24011 L
.30952 .22821 L
s
.30952 .24011 m
.33955 .24011 L
.33807 .24417 L
.30952 .24417 L
.30952 .24011 L
s
.039 .916 .04 r
.02381 .12506 m
.30952 .12506 L
s
% Start of user PostScript
0 0 30. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30952 .12506 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .12506 m
.38143 .12506 L
s
% Start of user PostScript
30. 0 37.5496 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.38143 .12506 Mdot
.039 .916 .04 r
.5 Mabswid
.38143 .12506 m
.97619 .00619 L
s
% Start of user PostScript
37.5496 0 100. -12.4812 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .00619 Mdot
0 0 m
1 0 L
1 .25013 L
0 .25013 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{646.438, 161.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:60000XB000`400?l00000o`00003ooooooooo
ooooohSooooo003oooooooooooooR?ooool00?oooooooooooon8ooooo`00ooooooooooooofkooooo
1Ol9jPX3ooooo`;o00004?ooool00<SoooooBol0003ooooooe_ooooo1ol9jPX2o`00013ooooo0038
ooooo`03o`000?moOgooOgmo04OoOgmo00?o0000ooooooooool0oooooomHooooo`Oo2NX:4oooool0
0<SoooooB_l0003ooooooeKooooo1Ol9jPX2ooooo`;o2NX:5_ooool00<Sooooo00?o0000ogmoOomo
Ogl0A_moOgl00ol0003oooooooooo`3oooooodoooooo1Ol9jPX6ooooo`03o`WZ2_oooooooooo01Ko
oooo0038ooooo`03o`000?moOgooOgmo04GoOgmo0_l0003oooooodcooooo1Ol9jPXTooooo`00b?oo
ool00ol0003oOgmoogmoO`15ogmoO`03o`000?oooooooooo0?ooooooA_ooool5o`WZ2RWooooo0038
ooooo`03o`000?moOgooOgmo04GoOgmo00?o0000ooooooooool0oooooom1ooooo`Go2NX:;_ooool0
0<Sooooo00?o0000ogmoOomoOgl0A?moOgl2o`000?oooooo?_ooool5o`WZ2S?ooooo0038ooooo`03
o`000?moOgooOgmo04CoOgmo00?o0000ooooooooool0oooooolhooooo`Go2NX:>?ooool00<Sooooo
00?o0000ogmoOomoOgl0A?moOgl00ol0003oooooooooo`3ooooooc?ooooo1Ol9jPXmooooo`00b?oo
oom8o`000?oooooo<?ooool5o`WZ2T;ooooo0038ooooo`03o`000?moOgooOgmo04?oOgmo00?o0000
ooooooooool0oooooolZooooo`Go2NX:Aoooool00<Sooooo00?o0000ogmoOomoOgl0@_moOgl2o`00
0?oooooo9oooool5o`WZ2Tcooooo0038ooooo`03o`000?moOgooOgmo04;oOgmo00?o0000oooooooo
ool0oooooolQooooo`Go2NX:DOooool00<Sooooo00?o0000ogmoOomoOgl0@_moOgl00ol0003ooooo
ooooo`3ooooooacooooo1Ol9jPYFooooo`00b?ooool00ol0003oOgmoogmoO`11ogmoO`;o0000oooo
oolIooooo`Go2NX:Foooool00<Sooooo00?o0000ogmoOomoOgl0@OmoOgl00ol0003oooooooooo`3o
oooooa?ooooo1Ol9jPYPooooo`00b?ooool00ol0003oOgmoogmoO`11ogmoO`03o`000?oooooooooo
0?oooooo3_ooool5o`WZ2VGooooo0038ooooo`03o`000?moOgooOgmo043oOgmo0_l0003oooooo`_o
oooo1Ol9jPYZooooo`00b?ooool00ol0003oOgmoogmoO`10ogmoO`03o`000?oooooooooo0?oooooo
1Oooool5o`WZ2Voooooo0038ooooo`03o`000?moOgooOgmo043oOgmo00?o0000ooooooooool0oooo
ool5o`WZ2WCooooo0038ooooo`03o`000?moOgooOgmo03ooOgmo0_l0003looooo`Go2NX:NOooool0
0<Sooooo@ol0003hooooo`Go2NX:O_ooool00<Sooooo00?o0000ogmoOomoOgl0?omoOgl00ol0003o
ooooooooo`3aooooo`Go2NX:Poooool00<Sooooo00?o0000ogmoOomoOgl0?_moOgl2o`000>kooooo
1Ol9jPZ8ooooo`00b?ooool00ol0003oOgmoogmoO`0nogmoO`03o`000?oooooooooo0>Sooooo1Ol9
jPZ=ooooo`00b?ooool00ol0003oOgmoogmoO`0nogmoO`03o`000?oooooooooo0>?ooooo1Ol9jPZB
ooooo`00b?ooool00ol0003oOgmoogmoO`0mogmoO`03o`000?oooooooooo0=oooooo1Ol9jPZGoooo
o`00b?ooool00ol0003oOgmoogmoO`0mogmoO`03o`000?oooooooooo0=[ooooo1Ol9jPZLooooo`00
b?ooool00ol0003oOgmoogmoO`0mogmoO`03o`000?oooooooooo0=Gooooo1Ol9jPZQooooo`00b?oo
ool00ol0003oOgmoogmoO`0logmoO`03o`000?oooooooooo0=7ooooo1Ol9jPZVooooo`00b?ooool0
0ol0003oOgmoogmoO`0logmoO`03o`000?oooooooooo0<cooooo1Ol9jPZ[ooooo`00b?ooool00ol0
003oOgmoogmoO`0kogmoO`03o`000?oooooooooo0<Sooooo1Ol9jPZ`ooooo`00b?ooool00ol0003o
OgmoogmoO`0kogmoO`03o`000?oooooooooo0<?ooooo1Ol9jPZeooooo`00b?ooool00ol0003oOgmo
ogmoO`0kogmoO`03o`000?oooooooooo0;kooooo1Ol9jPZjooooo`00b?ooool00ol0003oOgmoogmo
O`0jogmoO`03o`000?oooooooooo0;[ooooo1Ol9jPZoooooo`00b?ooool00ol0003oOgmoogmoO`0j
ogmoO`03o`000?oooooooooo0;Gooooo1Ol9jP[4ooooo`00b?ooool00ol0003oOgmoogmoO`0jogmo
O`03o`000?oooooooooo0;3ooooo1Ol9jP[9ooooo`00b?oooolmo`000:gooooo1_l9jP[>ooooo`00
b?ooool00ol0003oOgmoogmoO`0iogmoO`03o`000?oooooooooo0:Kooooo1Ol9jP[Dooooo`00b?oo
ool00ol0003oOgmoogmoO`0hogmoO`03o`000?oooooooooo0:;ooooo1Ol9jP[Iooooo`00b?ooool0
0ol0003oOgmoogmoO`0hogmoO`03o`000?oooooooooo09gooooo1Ol9jP[Nooooo`00b?ooool00ol0
003oOgmoogmoO`0hogmoO`03o`000?oooooooooo09Sooooo1Ol9jP[Sooooo`00b?ooool00ol0003o
OgmoogmoO`0gogmoO`03o`000?oooooooooo09Cooooo1Ol9jP[Xooooo`00b?ooool00ol0003oOgmo
ogmoO`0gogmoO`03o`000?oooooooooo08oooooo1Ol9jP[]ooooo`00b?ooool00ol0003oOgmoogmo
O`0fogmoO`03o`000?oooooooooo08_ooooo1Ol9jP[booooo`00b?ooool00ol0003oOgmoogmoO`0f
ogmoO`03o`000?oooooooooo08Kooooo1Ol9jP[gooooo`00b?ooool00ol0003oOgmoogmoO`0fogmo
O`03o`000?oooooooooo087ooooo1Ol9jP[looooo`00b?ooool00ol0003oOgmoogmoO`0eogmoO`03
o`000?oooooooooo07gooooo1Ol9jP[oooooo`;ooooo0038ooooo`03o`000?moOgooOgmo03GoOgmo
00?o0000ooooooooool0N?ooool5o`WZ2_oooooo1oooool00<Sooooo00?o0000ogmoOomoOgl0=Omo
Ogl00ol0003oooooooooo`1cooooo`Go2NX:ooooool<ooooo`00b?ooool00ol0003oOgmoogmoO`0d
ogmoO`03o`000?oooooooooo06oooooo1Ol9jP[ooooooa7ooooo0038ooooo`03o`000?moOgooOgmo
03CoOgmo00?o0000ooooooooool0J_ooool5o`WZ2_oooooo5_ooool00<Sooooo00?o0000ogmoOomo
Ogl0<omoOgl00ol0003oooooooooo`1Vooooo`Go2NX:oooooolKooooo`00b?ooool00ol0003oOgmo
ogmoO`0cogmoO`03o`000?oooooooooo067ooooo1Ol9jP[oooooob3ooooo0038ooooo`03o`000?mo
OgooOgmo03?oOgmo00?o0000ooooooooool0G?ooool5o`WZ2_oooooo9Oooool00<Sooooo=_l0001J
ooooo`Go2NX:oooooolZooooo`00b?ooool00ol0003oOgmoogmoO`0bogmoO`03o`000?oooooooooo
05?ooooo1Ol9jP[ooooooboooooo0038ooooo`03o`000?moOgooOgmo037oOgmo0_l0001@ooooo`Go
2NX:ooooooldooooo`00b?ooool00ol0003oOgmoogmoO`0aogmoO`03o`000?oooooooooo04[ooooo
1Ol9jP[oooooocWooooo0038ooooo`03o`000?moOgooOgmo037oOgmo00?o0000ooooooooool0AOoo
ool5o`WZ2_oooooo?_ooool00<Sooooo00?o0000ogmoOomoOgl0<?moOgl2o`0004;ooooo1Ol9jP[o
oooood?ooooo0038ooooo`03o`000?moOgooOgmo033oOgmo00?o0000ooooooooool0??ooool5o`WZ
2_ooooooB?ooool00<Sooooo00?o0000ogmoOomoOgl0<?moOgl00ol0003oooooooooo`0gooooo`Go
2NX:oooooom=ooooo`00b?ooool00ol0003oOgmoogmoO`0_ogmoO`03o`000?oooooooooo03?ooooo
1Ol9jP[ooooooe;ooooo0038ooooo`03o`000?moOgooOgmo02ooOgmo00?o0000ooooooooool0;_oo
ool5o`WZ2_ooooooEoooool00<Sooooo00?o0000ogmoOomoOgl0;omoOgl00ol0003oooooooooo`0Y
ooooo`Go2NX:oooooomLooooo`00b?ooool00ol0003oOgmoogmoO`0^ogmoO`03o`000?oooooooooo
02Gooooo1Ol9jP[oooooof7ooooo0038ooooo`03o`000?moOgooOgmo02koOgmo00?o0000oooooooo
ool08?ooool5o`WZ2_ooooooI_ooool00<Sooooo00?o0000ogmoOomoOgl0;_moOgl00ol0003ooooo
ooooo`0Kooooo`Go2NX:oooooom[ooooo`00b?ooool00ol0003oOgmoogmoO`0]ogmoO`03o`000?oo
oooooooo01Oooooo1Ol9jP[oooooog3ooooo0038ooooo`03o`000?moOgooOgmo02goOgmo00?o0000
ooooooooool04_ooool5o`WZ2_ooooooMOooool00<Sooooo00?o0000ogmoOomoOgl0;OmoOgl00ol0
003oooooooooo`0=ooooo`Go2NX:oooooomjooooo`00b?ooool00ol0003oOgmoogmoO`0/ogmoO`03
o`000?oooooooooo00Wooooo1Ol9jP[oooooogoooooo0030ooooo`?o2NX:1Oooool00ol0003oOgmo
ogmoO`0SogmoO`?o2NX:1_moOgl00ol0003oooooooooo`04ooooo`Go2NX:oooooon4ooooo`00`Ooo
ool6o`WZ2P03ooooool0003oOgmo02GoOgmo1_l9jPX2ogmoO`03o`000?oooooo2NX:00Co2NX:oooo
oon9ooooo`004?oooongo`WZ2P03o`000?l9jP[o2NX:02oo2NX:oooooon>ooooo`00`Oooool5o`WZ
2P03ooooool0003o000002KoOgmo1Ol9jPX2ogmoO`;o0000oooooon?ooooo`00`?ooool2o`WZ2PKo
oooo00?o0000ogmoOomoOgl08omoOgl2o`WZ2PGoOgmo00?o0000ooooooooool0oooooon?ooooo`00
b?ooool00ol0003oOgmoogmoO`0ZogmoO`03o`000?oooooooooo0?ooooooSoooool00<Sooooo00?o
0000ogmoOomoOgl0:_moOgl00ol0003oooooooooo`3oooooohoooooo0038ooooo`03o`000?moOgoo
Ogmo02WoOgmo00?o0000ooooooooool0oooooon@ooooo`00b?ooool00ol0003oOgmoogmoO`0Yogmo
O`03o`000?oooooooooo0?ooooooT?ooool00<Sooooo00?o0000ogmoOomoOgl0:OmoOgl00ol0003o
ooooooooo`3ooooooi3ooooo0038ooooo`03o`000?moOgooOgmo02SoOgmo00?o0000ooooooooool0
oooooonAooooo`00b?ooool00ol0003oOgmoogmoO`0XogmoO`03o`000?oooooooooo0?ooooooTOoo
ool00<Sooooo00?o0000ogmoOomoOgl0:?moOgl00ol0003oooooooooo`3ooooooi7ooooo0038oooo
o`03o`000?moOgooOgmo02OoOgmo00?o0000ooooooooool0oooooonBooooo`00b?ooool00ol0003o
OgmoogmoO`0WogmoO`03o`000?oooooooooo0?ooooooT_ooool00<Sooooo00?o0000ogmoOomoOgl0
9omoOgl00ol0003oooooooooo`3ooooooi;ooooo0038ooooo`03o`000?moOgooOgmo02KoOgmo00?o
0000ooooooooool0oooooonCooooo`00b?ooool00ol0003oOgmoogmoO`0VogmoO`03o`000?oooooo
oooo0?ooooooToooool00<Sooooo00?o0000ogmoOomoOgl09_moOgl00ol0003oooooooooo`3ooooo
oi?ooooo0038ooooo`03o`000?moOgooOgmo02GoOgmo00?o0000ooooooooool0oooooonDooooo`00
b?ooool00ol0003oOgmoogmoO`0UogmoO`03o`000?oooooooooo0?ooooooU?ooool00<Sooooo00?o
0000ogmoOomoOgl09OmoOgl00ol0003oooooooooo`3ooooooiCooooo0038ooooobSo0000oooooonG
ooooo`00b?ooool00ol0003oOgmoogmoO`0TogmoO`03o`000?oooooooooo0?ooooooUOooool00<So
oooo00?o0000ogmoOomoOgl08omoOgl2o`000?ooooooUoooool00<Sooooo00?o0000ogmoOomoOgl0
8omoOgl00ol0003oooooooooo`3ooooooiKooooo0038ooooo`03o`000?moOgooOgmo02?oOgmo00?o
0000ooooooooool0oooooonFooooo`00b?ooool00ol0003oOgmoogmoO`0RogmoO`;o0000oooooonH
ooooo`00b?ooool00ol0003oOgmoogmoO`0RogmoO`03o`000?oooooooooo0?ooooooUoooool00<So
oooo00?o0000ogmoOomoOgl08OmoOgl2o`000?ooooooVOooool00<Sooooo00?o0000ogmoOomoOgl0
8OmoOgl00ol0003oooooooooo`3ooooooiSooooo0038ooooo`03o`000?moOgooOgmo027oOgmo00?o
0000ooooooooool0oooooonHooooo`00b?ooool00ol0003oOgmoogmoO`0PogmoO`;o0000oooooonJ
ooooo`00b?ooool00ol0003oOgmoogmoO`0PogmoO`03o`000?oooooooooo0?ooooooVOooool00<So
oooo00?o0000ogmoOomoOgl08?moOgl00ol0003oooooooooo`3ooooooiWooooo0038ooooo`03o`00
0?moOgooOgmo01ooOgmo0_l0003ooooooi_ooooo0038ooooo`03o`000?moOgooOgmo01ooOgmo00?o
0000ooooooooool0oooooonJooooo`00b?ooool00ol0003oOgmoogmoO`0NogmoO`;o0000oooooonL
ooooo`00b?ooool00ol0003oOgmoogmoO`0NogmoO`;o0000oooooonLooooo`00b?ooool00ol0003o
OgmoogmoO`0NogmoO`03o`000?oooooooooo0?ooooooVoooool00<Sooooo8_l0003ooooooigooooo
0038ooooo`03o`000?moOgooOgmo01goOgmo00?o0000ooooooooool0oooooonLooooo`00b?ooool0
0ol0003oOgmoogmoO`0LogmoO`;o0000oooooonNooooo`00b?ooool00ol0003oOgmoogmoO`0Logmo
O`;o0000oooooonNooooo`00b?ooool00ol0003oOgmoogmoO`0LogmoO`03o`000?oooooooooo0?oo
ooooWOooool00<Sooooo00?o0000ogmoOomoOgl06omoOgl2o`000?ooooooWoooool00<Sooooo00?o
0000ogmoOomoOgl06omoOgl2o`000?ooooooWoooool00<Sooooo00?o0000ogmoOomoOgl06omoOgl0
0ol0003oooooooooo`3ooooooikooooo0038ooooo`03o`000?moOgooOgmo01[oOgmo0_l0003ooooo
oj3ooooo0038ooooo`03o`000?moOgooOgmo01[oOgmo0_l0003ooooooj3ooooo0038ooooo`03o`00
0?moOgooOgmo01WoOgmo0_l0003ooooooj7ooooo0038ooooo`03o`000?moOgooOgmo01WoOgmo0_l0
003ooooooj7ooooo0038ooooo`03o`000?moOgooOgmo01WoOgmo0_l0003ooooooj7ooooo0038oooo
o`03o`000?moOgooOgmo01SoOgmo0_l0003ooooooj;ooooo0038ooooo`03o`000?moOgooOgmo01So
Ogmo0_l0003ooooooj;ooooo0038ooooo`03o`000?moOgooOgmo01SoOgmo00?o0000ooooooooool0
oooooonQooooo`00b?oooolLo`000?ooooooXoooool00<Sooooo00?o0000ogmoOomoOgl05omoOgl2
o`000?ooooooXoooool00<Sooooo00?o0000ogmoOomoOgl05_moOgl2o`000?ooooooY?ooool00<So
oooo00?o0000ogmoOomoOgl05_moOgl2o`000?ooooooY?ooool00<Sooooo00?o0000ogmoOomoOgl0
5_moOgl00ol0003oooooooooo`3ooooooj?ooooo0038ooooo`03o`000?moOgooOgmo01GoOgmo0_l0
003oooooojGooooo0038ooooo`03o`000?moOgooOgmo01GoOgmo0_l0003oooooojGooooo0038oooo
o`03o`000?moOgooOgmo01GoOgmo00?o0000ooooooooool0oooooonTooooo`00b?ooool00ol0003o
OgmoogmoO`0DogmoO`;o0000oooooonVooooo`00b?ooool00ol0003oOgmoogmoO`0DogmoO`;o0000
oooooonVooooo`00b?ooool00ol0003oOgmoogmoO`0DogmoO`03o`000?oooooooooo0?ooooooYOoo
ool00<Sooooo00?o0000ogmoOomoOgl04omoOgl2o`000?ooooooYoooool00<Sooooo5ol0003ooooo
ojSooooo0038ooooo`03o`000?moOgooOgmo01?oOgmo00?o0000ooooooooool0oooooonVooooo`00
b?ooool00ol0003oOgmoogmoO`0BogmoO`;o0000oooooonXooooo`00b?ooool00ol0003oOgmoogmo
O`0BogmoO`03o`000?oooooooooo0?ooooooYoooool00<Sooooo00?o0000ogmoOomoOgl04_moOgl0
0ol0003oooooooooo`3oooooojOooooo0038ooooo`03o`000?moOgooOgmo017oOgmo00?o0000oooo
ooooool0oooooonXooooo`00b?ooool00ol0003oOgmoogmoO`0AogmoO`03o`000?oooooooooo0?oo
ooooZ?ooool00<Sooooo00?o0000ogmoOomoOgl04OmoOgl00ol0003oooooooooo`3oooooojSooooo
0038oooooaCo0000oooooon[ooooo`00b?ooool00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooo
oooo0?ooooooZOooool00<Sooooo00?o0000ogmoOomoOgl03omoOgl2o`000?ooooooZoooool00<So
oooo4ol0003oooooojcooooo003oooooooooooooR?ooool00?oooooooooooon8ooooo`00oooooooo
ooooohSooooo0000\
\>"],
  ImageRangeCache->{{{0, 645.438}, {160.625, 0}} -> {-2.76798, -13.1316, \
0.163511, 0.163511}},
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[
{SingleRay[WaveLength->.650],
Move[AnamorphicPrisms[{12,12}, 8.5, 21.2, 1.5, 6.0, 5.3],30],
Boundary[75,GraphicDesign->Off]},
PlotType->TopView];\
\>", "Input",
  CellTags->"Prism Examples"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .20855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0126984 0.148078 0.0126984 [
[ 0 0 0 0 ]
[ 1 .20855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.43772 .05353 m
.33707 .09257 L
.35963 .11107 L
.44691 .07722 L
.43772 .05353 L
F
.44691 .07722 m
.35963 .11107 L
.3822 .12958 L
.4561 .10091 L
.44691 .07722 L
F
.4561 .10091 m
.3822 .12958 L
.40476 .14808 L
.46529 .1246 L
.4561 .10091 L
F
.46529 .1246 m
.40476 .14808 L
.42733 .16658 L
.47447 .14829 L
.46529 .1246 L
F
.47447 .14829 m
.42733 .16658 L
.44989 .18508 L
.48366 .17198 L
.47447 .14829 L
F
.48366 .17198 m
.44989 .18508 L
.47246 .20358 L
.49285 .19567 L
.48366 .17198 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.43772 .05353 m
.44691 .07722 L
.4561 .10091 L
.46529 .1246 L
.47447 .14829 L
.48366 .17198 L
.49285 .19567 L
.47246 .20358 L
.44989 .18508 L
.42733 .16658 L
.40476 .14808 L
.3822 .12958 L
.35963 .11107 L
.33707 .09257 L
.43772 .05353 L
s
.5 g
.46529 .1246 m
.40476 .14808 L
.40476 .14808 L
.46529 .1246 L
.46529 .1246 L
F
.46529 .1246 m
.40476 .14808 L
.40476 .14808 L
.46529 .1246 L
.46529 .1246 L
F
.46529 .1246 m
.40476 .14808 L
.40476 .14808 L
.46529 .1246 L
.46529 .1246 L
F
.46529 .1246 m
.40476 .14808 L
.40476 .14808 L
.46529 .1246 L
.46529 .1246 L
F
.46529 .1246 m
.40476 .14808 L
.40476 .14808 L
.46529 .1246 L
.46529 .1246 L
F
.46529 .1246 m
.40476 .14808 L
.40476 .14808 L
.46529 .1246 L
.46529 .1246 L
F
0 g
.46529 .1246 m
.46529 .1246 L
.46529 .1246 L
.46529 .1246 L
.46529 .1246 L
.46529 .1246 L
.46529 .1246 L
.40476 .14808 L
.40476 .14808 L
.40476 .14808 L
.40476 .14808 L
.40476 .14808 L
.40476 .14808 L
.40476 .14808 L
.46529 .1246 L
s
.5 g
.60983 .15659 m
.50247 .16787 L
.51408 .1411 L
.60718 .13132 L
.60983 .15659 L
F
.60718 .13132 m
.51408 .1411 L
.52569 .11433 L
.60452 .10605 L
.60718 .13132 L
F
.60452 .10605 m
.52569 .11433 L
.5373 .08756 L
.60187 .08078 L
.60452 .10605 L
F
.60187 .08078 m
.5373 .08756 L
.54892 .06079 L
.59921 .05551 L
.60187 .08078 L
F
.59921 .05551 m
.54892 .06079 L
.56053 .03402 L
.59655 .03024 L
.59921 .05551 L
F
.59655 .03024 m
.56053 .03402 L
.57214 .00725 L
.5939 .00497 L
.59655 .03024 L
F
0 g
.60983 .15659 m
.60718 .13132 L
.60452 .10605 L
.60187 .08078 L
.59921 .05551 L
.59655 .03024 L
.5939 .00497 L
.57214 .00725 L
.56053 .03402 L
.54892 .06079 L
.5373 .08756 L
.52569 .11433 L
.51408 .1411 L
.50247 .16787 L
.60983 .15659 L
s
.5 g
.60187 .08078 m
.5373 .08756 L
.5373 .08756 L
.60187 .08078 L
.60187 .08078 L
F
.60187 .08078 m
.5373 .08756 L
.5373 .08756 L
.60187 .08078 L
.60187 .08078 L
F
.60187 .08078 m
.5373 .08756 L
.5373 .08756 L
.60187 .08078 L
.60187 .08078 L
F
.60187 .08078 m
.5373 .08756 L
.5373 .08756 L
.60187 .08078 L
.60187 .08078 L
F
.60187 .08078 m
.5373 .08756 L
.5373 .08756 L
.60187 .08078 L
.60187 .08078 L
F
.60187 .08078 m
.5373 .08756 L
.5373 .08756 L
.60187 .08078 L
.60187 .08078 L
F
0 g
.60187 .08078 m
.60187 .08078 L
.60187 .08078 L
.60187 .08078 L
.60187 .08078 L
.60187 .08078 L
.60187 .08078 L
.5373 .08756 L
.5373 .08756 L
.5373 .08756 L
.5373 .08756 L
.5373 .08756 L
.5373 .08756 L
.5373 .08756 L
.60187 .08078 L
s
.43772 .05353 m
.33707 .09257 L
.35963 .11107 L
.44691 .07722 L
.43772 .05353 L
s
.44691 .07722 m
.35963 .11107 L
.3822 .12958 L
.4561 .10091 L
.44691 .07722 L
s
.4561 .10091 m
.3822 .12958 L
.40476 .14808 L
.46529 .1246 L
.4561 .10091 L
s
.46529 .1246 m
.40476 .14808 L
.42733 .16658 L
.47447 .14829 L
.46529 .1246 L
s
.47447 .14829 m
.42733 .16658 L
.44989 .18508 L
.48366 .17198 L
.47447 .14829 L
s
.48366 .17198 m
.44989 .18508 L
.47246 .20358 L
.49285 .19567 L
.48366 .17198 L
s
.49285 .19567 m
.47246 .20358 L
.47246 .20358 L
.49285 .19567 L
.49285 .19567 L
s
.49285 .19567 m
.47246 .20358 L
.47246 .20358 L
.49285 .19567 L
.49285 .19567 L
s
.49285 .19567 m
.47246 .20358 L
.47246 .20358 L
.49285 .19567 L
.49285 .19567 L
s
.49285 .19567 m
.47246 .20358 L
.47246 .20358 L
.49285 .19567 L
.49285 .19567 L
s
.49285 .19567 m
.47246 .20358 L
.47246 .20358 L
.49285 .19567 L
.49285 .19567 L
s
.49285 .19567 m
.47246 .20358 L
.47246 .20358 L
.49285 .19567 L
.49285 .19567 L
s
.49285 .19567 m
.47246 .20358 L
.44989 .18508 L
.48366 .17198 L
.49285 .19567 L
s
.48366 .17198 m
.44989 .18508 L
.42733 .16658 L
.47447 .14829 L
.48366 .17198 L
s
.47447 .14829 m
.42733 .16658 L
.40476 .14808 L
.46529 .1246 L
.47447 .14829 L
s
.46529 .1246 m
.40476 .14808 L
.3822 .12958 L
.4561 .10091 L
.46529 .1246 L
s
.4561 .10091 m
.3822 .12958 L
.35963 .11107 L
.44691 .07722 L
.4561 .10091 L
s
.44691 .07722 m
.35963 .11107 L
.33707 .09257 L
.43772 .05353 L
.44691 .07722 L
s
.43772 .05353 m
.33707 .09257 L
.33707 .09257 L
.43772 .05353 L
.43772 .05353 L
s
.43772 .05353 m
.33707 .09257 L
.33707 .09257 L
.43772 .05353 L
.43772 .05353 L
s
.43772 .05353 m
.33707 .09257 L
.33707 .09257 L
.43772 .05353 L
.43772 .05353 L
s
.43772 .05353 m
.33707 .09257 L
.33707 .09257 L
.43772 .05353 L
.43772 .05353 L
s
.43772 .05353 m
.33707 .09257 L
.33707 .09257 L
.43772 .05353 L
.43772 .05353 L
s
.43772 .05353 m
.33707 .09257 L
.33707 .09257 L
.43772 .05353 L
.43772 .05353 L
s
.60983 .15659 m
.50247 .16787 L
.51408 .1411 L
.60718 .13132 L
.60983 .15659 L
s
.60718 .13132 m
.51408 .1411 L
.52569 .11433 L
.60452 .10605 L
.60718 .13132 L
s
.60452 .10605 m
.52569 .11433 L
.5373 .08756 L
.60187 .08078 L
.60452 .10605 L
s
.60187 .08078 m
.5373 .08756 L
.54892 .06079 L
.59921 .05551 L
.60187 .08078 L
s
.59921 .05551 m
.54892 .06079 L
.56053 .03402 L
.59655 .03024 L
.59921 .05551 L
s
.59655 .03024 m
.56053 .03402 L
.57214 .00725 L
.5939 .00497 L
.59655 .03024 L
s
.5939 .00497 m
.57214 .00725 L
.57214 .00725 L
.5939 .00497 L
.5939 .00497 L
s
.5939 .00497 m
.57214 .00725 L
.57214 .00725 L
.5939 .00497 L
.5939 .00497 L
s
.5939 .00497 m
.57214 .00725 L
.57214 .00725 L
.5939 .00497 L
.5939 .00497 L
s
.5939 .00497 m
.57214 .00725 L
.57214 .00725 L
.5939 .00497 L
.5939 .00497 L
s
.5939 .00497 m
.57214 .00725 L
.57214 .00725 L
.5939 .00497 L
.5939 .00497 L
s
.5939 .00497 m
.57214 .00725 L
.57214 .00725 L
.5939 .00497 L
.5939 .00497 L
s
.5939 .00497 m
.57214 .00725 L
.56053 .03402 L
.59655 .03024 L
.5939 .00497 L
s
.59655 .03024 m
.56053 .03402 L
.54892 .06079 L
.59921 .05551 L
.59655 .03024 L
s
.59921 .05551 m
.54892 .06079 L
.5373 .08756 L
.60187 .08078 L
.59921 .05551 L
s
.60187 .08078 m
.5373 .08756 L
.52569 .11433 L
.60452 .10605 L
.60187 .08078 L
s
.60452 .10605 m
.52569 .11433 L
.51408 .1411 L
.60718 .13132 L
.60452 .10605 L
s
.60718 .13132 m
.51408 .1411 L
.50247 .16787 L
.60983 .15659 L
.60718 .13132 L
s
.60983 .15659 m
.50247 .16787 L
.50247 .16787 L
.60983 .15659 L
.60983 .15659 L
s
.60983 .15659 m
.50247 .16787 L
.50247 .16787 L
.60983 .15659 L
.60983 .15659 L
s
.60983 .15659 m
.50247 .16787 L
.50247 .16787 L
.60983 .15659 L
.60983 .15659 L
s
.60983 .15659 m
.50247 .16787 L
.50247 .16787 L
.60983 .15659 L
.60983 .15659 L
s
.60983 .15659 m
.50247 .16787 L
.50247 .16787 L
.60983 .15659 L
.60983 .15659 L
s
.60983 .15659 m
.50247 .16787 L
.50247 .16787 L
.60983 .15659 L
.60983 .15659 L
s
.947 .013 .01 r
.02381 .14808 m
.40476 .14808 L
s
% Start of user PostScript
0 0 30. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .14808 Mdot
.947 .013 .01 r
.5 Mabswid
.40476 .14808 m
.46379 .12075 L
s
% Start of user PostScript
30. 0 34.6486 -2.15206 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.46379 .12075 Mdot
.947 .013 .01 r
.5 Mabswid
.46379 .12075 m
.54032 .08061 L
s
% Start of user PostScript
34.6486 -2.15206 40.6751 -5.31299 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.54032 .08061 Mdot
.947 .013 .01 r
.5 Mabswid
.54032 .08061 m
.60156 .07789 L
s
% Start of user PostScript
40.6751 -5.31299 45.498 -5.52752 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.60156 .07789 Mdot
.947 .013 .01 r
.5 Mabswid
.60156 .07789 m
.97619 .07881 L
s
% Start of user PostScript
45.498 -5.52752 75. -5.4548 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .07881 Mdot
0 0 m
1 0 L
1 .20855 L
0 .20855 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{752.188, 156.875},
  ImageMargins->{{13, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;`0000W2000`400?l00000o`00003ooooooooo
oooooo;ooooo003oooooooooooool_ooool00?ooooooooooooobooooo`00oooooonjooooo`Ko0000
oooooolbooooo`00oooooonbooooo`So00001?moOgl00ol0003oooooooooo`3ooooooc7ooooo003o
ooooojkooooo1?l0000<ogmoO`03o`000?oooooooooo0?oooooo<Oooool00?oooooo[_ooool00ol0
003oOgmoogmoO`0=ogmoO`03o`000?oooooooooo0?oooooo<Oooool00?oooooo[Oooool00ol0003o
OgmoogmoO`0>ogmoO`03o`000?oooooooooo0?oooooo<Oooool00?oooooo[Oooool00ol0003oOgmo
ogmoO`0>ogmoO`03o`000?oooooooooo0?oooooo<Oooool00?oooooo[?ooool00ol0003oOgmoogmo
O`0@ogmoO`03o`000?oooooooooo0?oooooo<?ooool00?oooooo[?ooool00ol0003oOgmoogmoO`0@
ogmoO`03o`000?oooooooooo0?oooooo<?ooool00?oooooo[?ooool00ol0003oOgmoogmoO`0@ogmo
O`03o`000?oooooooooo0?oooooo<?ooool00?ooooooZoooool00ol0003oOgmoogmoO`0AogmoO`03
o`000?oooooooooo0?oooooo<?ooool00?ooooooZoooool00ol0003oOgmoogmoO`0AogmoO`03o`00
0?oooooooooo0?oooooo<?ooool00?ooooooZ_ooool00ol0003oOgmoogmoO`0BogmoO`03o`000?oo
oooooooo0?oooooo<?ooool00?ooooooZ_ooool00ol0003oOgmoogmoO`0BogmoO`03o`000?oooooo
oooo0?oooooo<?ooool00?ooooooZOooool00ol0003oOgmoogmoO`0CogmoO`03o`000?oooooooooo
0?oooooo<?ooool00?ooooooZOooool00ol0003oOgmoogmoO`0CogmoO`03o`000?oooooooooo0?oo
oooo<?ooool00?ooooooZ?ooool00ol0003oOgmoogmoO`0EogmoO`03o`000?oooooooooo0?oooooo
;oooool00?ooooooZ?ooool00ol0003oOgmoogmoO`0EogmoO`03o`000?oooooooooo0?oooooo;ooo
ool00?ooooooYoooool00ol0003oOgmoogmoO`0FogmoO`03o`000?oooooooooo0?oooooo;oooool0
0?ooooooYoooool00ol0003oOgmoogmoO`0FogmoO`03o`000?oooooooooo0?oooooo;oooool00?oo
ooooYoooool00ol0003oOgmoogmoO`0BogmoO`Go0000oooooolaooooo`00oooooonVooooo`03o`00
0?moOgooOgmo00[oOgmo2Ol00004ogmoO`03o`000?oooooooooo0?oooooo;oooool00?ooooooY_oo
ool01?l0003oOgmoogmoOomoOgl9o`0000goOgmo00?o0000ooooooooool0ooooool_ooooo`00oooo
oonUooooo`Go00005_moOgl00ol0003oooooooooo`3ooooooboooooo003oooooojGooooo00?o0000
ogmoOomoOgl06?moOgl00ol0003oooooooooo`3ooooooboooooo003oooooojCooooo00?o0000ogmo
OomoOgl06OmoOgl00ol0003oooooooooo`3ooooooboooooo003oooooojCooooo00?o0000ogmoOomo
Ogl06_moOgl00ol0003oooooooooo`3oooooobkooooo003oooooojCooooo00?o0000ogmoOomoOgl0
6_moOgl00ol0003oooooooooo`3oooooobkooooo003ooooooj?ooooo00?o0000ogmoOomoOgl06omo
Ogl00ol0003oooooooooo`3oooooobkooooo003ooooooj?ooooo00?o0000ogmoOomoOgl06omoOgl0
0ol0003oooooooooo`3oooooobkooooo003ooooooj;ooooo00?o0000ogmoOomoOgl07?moOgl00ol0
003oooooooooo`3oooooobkooooo003ooooooj;ooooo00?o0000ogmoOomoOgl07?moOgl00ol0003o
ooooooooo`3oooooobkooooo003ooooooj;ooooo00?o0000ogmoOomoOgl07?moOgl00ol0003ooooo
ooooo`3oooooobkooooo003ooooooj7ooooo00?o0000ogmoOomoOgl07OmoOgl00ol0003ooooooooo
o`3oooooobkooooo003ooooooj7ooooo00?o0000ogmoOomoOgl07OmoOgl00ol0003oooooooooo`3o
ooooobkooooo003ooooooj3ooooo00?o0000ogmoOomoOgl07omoOgl00ol0003oooooooooo`3ooooo
obgooooo003ooooooj3ooooo00?o0000ogmoOomoOgl07omoOgl00ol0003oooooooooo`3oooooobgo
oooo003ooooood[ooooo00?o0000ooooooooool0Doooool00ol0003oOgmoogmoO`0OogmoO`03o`00
0?oooooooooo0?oooooo;Oooool00?ooooooBOooool2o`0005Cooooo00?o0000ogmoOomoOgl08?mo
Ogl00ol0003oooooooooo`3oooooobgooooo003oooooodKooooo0ol000000omoOgoo0000ooooo`1C
ooooo`03o`000?moOgooOgmo01_oOgmo1_l0003ooooooboooooo003ooooood?ooooo0ol00005ogmo
O`03o`000?oooooooooo053ooooo00?o0000ogmoOomoOgl04omoOgl9o`0000GoOgmo00?o0000oooo
ooooool0ooooool]ooooo`00oooooom1ooooo`;o00002?moOgl00ol0003oooooooooo`1@ooooo`03
o`000?moOgooOgmo00[oOgmo2Ol0000>ogmoO`03o`000?oooooooooo0?oooooo;Oooool00?oooooo
?_ooool3o`0000[oOgmo00?o0000ooooooooool0D?ooool01?l0003oOgmoogmoOomoOgl9o`0001Oo
Ogmo00?o0000ooooooooool0ooooool]ooooo`00oooooollooooo`;o00003_moOgl00ol0003ooooo
ooooo`1>ooooo`Go00008?moOgl00ol0003oooooooooo`3oooooobgooooo003oooooocWooooo0ol0
000@ogmoO`03o`000?oooooooooo04kooooo00?o0000ogmoOomoOgl08_moOgl00ol0003ooooooooo
o`3oooooobgooooo003oooooocKooooo0ol0000CogmoO`03o`000?oooooooooo04gooooo00?o0000
ogmoOomoOgl09?moOgl00ol0003oooooooooo`3oooooobcooooo003oooooocCooooo0_l0000Gogmo
O`03o`000?oooooooooo04cooooo00?o0000ogmoOomoOgl09?moOgl00ol0003oooooooooo`3ooooo
obcooooo003ooooooc7ooooo0ol0000IogmoO`03o`000?oooooooooo04_ooooo00?o0000ogmoOomo
Ogl09OmoOgl00ol0003oooooooooo`3oooooobcooooo003oooooobkooooo0ol0000LogmoO`03o`00
0?oooooooooo04_ooooo00?o0000ogmoOomoOgl09OmoOgl00ol0003oooooooooo`3oooooobcooooo
003oooooobcooooo0_l0000PogmoO`03o`000?oooooooooo04[ooooo00?o0000ogmoOomoOgl09Omo
Ogl00ol0003oooooooooo`3oooooobcooooo003oooooobWooooo0ol0000RogmoO`03o`000?oooooo
oooo04Wooooo00?o0000ogmoOomoOgl09_moOgl00ol0003oooooooooo`3oooooobcooooo003ooooo
obOooooo0_l0000UogmoO`03o`000?oooooooooo04Wooooo00?o0000ogmoOomoOgl09_moOgl00ol0
003oooooooooo`3oooooobcooooo003oooooobCooooo0ol0000XogmoO`03o`000?oooooooooo04Oo
oooo00?o0000ogmoOomoOgl09omoOgl00ol0003oooooooooo`3oooooobcooooo003oooooob7ooooo
0ol0000[ogmoO`03o`000?oooooooooo04Oooooo00?o0000ogmoOomoOgl09omoOgl00ol0003ooooo
ooooo`3oooooobcooooo003ooooooaoooooo0_l0000^ogmoO`03o`000?oooooooooo04Kooooo00?o
0000ogmoOomoOgl08OmoOgl3oo830PGoOgmo00?o0000ooooooooool0ooooool[ooooo`00oooooolL
ooooo`?o0000<?moOgl2o`0004Oooooo00?o0000ogmoOomoOgl08_moOgl6oo830P03ogmoOol0003o
00000?oooooo3oooool3oo830Q[ooooo003ooooooa[ooooo0_l0000`ogmoO`?o000000?oOgmoo`00
0?ooool0AOooool00ol0003oOgmoogmoO`0OogmoOiSolP<2Q?ooool6oo830P03ooooool0003o0000
01?ooooo003ooooooaOooooo0ol0000`ogmoO`;o00001OmoOgl00ol0003oooooooooo`12ooooo`;o
00002_moOglGoo830PCoOgmo1Oob0`82ogmoO`03o`000?oooooooooo08[oooooRoob0`82o`0001?o
oooo003ooooooaCooooo0ol0000`ogmoO`?o00001omoOgl00ol0003oooooooooo`10ooooo`kolP<2
6_moOgl2oo830P03ogmoOol0003o000000Co0000oooooolAooooo`GolP<25oooool00?oooooo4_oo
ool2o`00037oOgmo0_l0000:ogmoO`03o`000?oooooooooo03cooooo1Oob0`800ooooooo0000ogmo
O`0NogmoO`Wo00001OmoOgl00ol0003oooooooooo`3oooooo`kooooo0_ob0`8Kooooo`00ooooool?
ooooo`?o0000<?moOgl3o`0000goOgmo00?o0000ooooooooool0>Oooool6oo830P;ooooo00?o0000
ogmoOomoOgl04omoOgl:o`0000koOgmo00?o0000ooooooooool0ooooool[ooooo`00ooooool<oooo
o`?o0000<OmoOgl2o`00013oOgmo00?o0000ooooooooool0>_ooool4oo830P;ooooo00?o0000ogmo
OomoOgl02_moOgl:o`0001SoOgmo00?o0000ooooooooool0ooooool[ooooo`00ooooool:ooooo`;o
0000<OmoOgl3o`0001?oOgmo00?o0000ooooooooool0=oooool2oo830P;ooooo00GolP<2oooooooo
ooooooooo`000003ogmoO`Wo00008_moOgl00ol0003oooooooooo`3oooooob_ooooo003oooooo`Oo
oooo0ol0000aogmoO`;o00005_moOgl00ol0003oooooooooo`0fooooo`05oo830_oooooooooooooo
ooob0`800oooool5o`0002_oOgmo00?o0000ooooooooool0ooooool[ooooo`00ooooool5ooooo`;o
0000<OmoOgl3o`0001SoOgmo00?o0000ooooooooool0=?ooool2oo830PSooooo00?o0000ogmoOomo
Ogl0;_moOgl00ol0003oooooooooo`3oooooob[ooooo003oooooo`;ooooo0ol0000aogmoO`;o0000
7?moOgl00ol0003oooooooooo`0aooooo`;olP<22Oooool00ol0003oOgmoogmoO`0_ogmoO`03o`00
0?oooooooooo0?oooooo:_ooool00?kooooo0ol0000aogmoO`?o00007_moOgl00ol0003ooooooooo
o`0_ooooo`;olP<22oooool00ol0003oOgmoogmoO`0_ogmoO`03o`000?oooooooooo0?oooooo:_oo
ool00?gooooo0_l0000aogmoO`;o00008OmoOgl00ol0003oooooooooo`0]ooooo`;olP<23?ooool0
0ol0003oOgmoogmoO`0`ogmoO`03o`000?oooooooooo0?oooooo:_ooool00?oooooo00?o0000ogmo
OomoOgl0:omoOgl3o`0002CoOgmo00?o0000ooooooooool0:_ooool2oo830Pkooooo00?o0000ogmo
OomoOgl0<?moOgl00ol0003oooooooooo`3oooooob[ooooo003oooooo`7ooooo00?o0000ogmoOomo
Ogl0:?moOgl2o`0002OoOgmo00?o0000ooooooooool0:?ooool2oo830Q3ooooo00?o0000ogmoOomo
Ogl0<?moOgl00ol0003oooooooooo`3oooooob[ooooo003oooooo`;ooooo00?o0000ogmoOomoOgl0
9?moOgl3o`0002[oOgmo00?o0000ooooooooool09Oooool2oo830Q7ooooo00?o0000ogmoOomoOgl0
<OmoOgl00ol0003oooooooooo`3oooooob[ooooo003oooooo`?ooooo00?o0000ogmoOomoOgl08Omo
Ogl2o`0002goOgmo00?o0000ooooooooool08oooool2oo830Q?ooooo00?o0000ogmoOomoOgl0<Omo
Ogl00ol0003oooooooooo`3oooooob[ooooo003oooooo`Cooooo0_l0000NogmoO`?o0000;omoOgl0
0ol0003oooooooooo`0Qooooo`;olP<25?ooool00ol0003oOgmoogmoO`0bogmoO`03o`000?oooooo
oooo0?oooooo:_ooool00?oooooo1_ooool00ol0003oOgmoogmoO`0IogmoO`;o0000<_moOgl2o`00
027ooooo00?olP<2ooooooooool05?ooool00ol0003oOgmoogmoO`0cogmoO`03o`000?oooooooooo
0?oooooo:Oooool00?oooooo1oooool00ol0003oOgmoogmoO`0EogmoO`?o0000<OmoOgl3o`000003
ogmoOol0003ooooo01kooooo0_ob0`8Fooooo`03o`000?moOgooOgmo03CoOgmo00?o0000oooooooo
ool0oooooolYooooo`00ooooool8ooooo`03o`000?moOgooOgmo01;oOgmo0_l0000aogmoO`?o0000
1OmoOgl00ol0003oooooooooo`0Jooooo`;olP<26?ooool00ol0003oOgmoogmoO`0dogmoO`03o`00
0?oooooooooo0?oooooo:Oooool00?oooooo2Oooool2o`0000ooOgmo0ol0000aogmoO`;o00002?mo
Ogl00ol0003oooooooooo`0Hooooo`;olP<26Oooool00ol0003oOgmoogmoO`0eogmoO`03o`000?oo
oooooooo0?oooooo:Oooool00?oooooo2oooool00ol0003oOgmoogmoO`0:ogmoO`;o0000<OmoOgl3
o`0000[oOgmo00?o0000ooooooooool05_ooool2oo830Q_ooooo00?o0000ogmoOomoOgl0<?moOgl6
o`000?oooooo:oooool00?oooooo3?ooool00ol0003oOgmoogmoO`06ogmoO`?o0000<OmoOgl2o`00
00koOgmo00?o0000ooooooooool04oooool2oo830Qcooooo00?o0000ogmoOomoOgl09omoOgl:o`00
00GoOgmo00?o0000ooooooooool0oooooolYooooo`00ooooool=ooooo`03o`000?moOgooOgmo00?o
Ogmo0_l0000aogmoO`?o00004?moOgl00ol0003oooooooooo`0Aooooo`;olP<27_ooool00ol0003o
OgmoogmoO`0MogmoO`[o00003omoOgl00ol0003oooooooooo`3oooooobWooooo003oooooo`kooooo
00?o0000ogmoOol000000_l0000`ogmoO`?o00005?moOgl00ol0003oooooooooo`0>ooooo`;olP<2
8?ooool00ol0003oOgmoogmoO`0DogmoO`Wo00006OmoOgl00ol0003oooooooooo`3oooooobWooooo
003oooooo`oooooo0_l0000`ogmoO`;o00005omoOgl00ol0003oooooooooo`0<ooooo`;olP<28Ooo
ool00ol0003oOgmoogmoO`0;ogmoO`[o00008_moOgl00ol0003oooooooooo`3oooooobWooooo003o
oooooa7ooooo00?o0000ogmoOomoOgl0:_moOgl3o`0001WoOgmo00?o0000ooooooooool02_ooool2
oo830R?ooooo00Co0000ogmoOomoOgooOgmo2_l0000/ogmoO`03o`000?oooooooooo0?oooooo:Ooo
ool00?oooooo4_ooool00ol0003oOgmoogmoO`0VogmoO`?o00007OmoOgl00ol0003oooooooooo`08
ooooo`03oo830_oooooooooo02;ooooo1Ol0000gogmoO`03o`000?oooooooooo0?oooooo:?ooool0
0?oooooo4oooool2o`0002CoOgmo0_l0000PogmoO`03o`000?oooooooooo00Kooooo0_ob0`8Uoooo
o`03o`000?moOgooOgmo03WoOgmo00?o0000ooooooooool0oooooolXooooo`00oooooolEooooo`03
o`000?moOgooOgmo01koOgmo0ol0000RogmoO`03o`000?oooooooooo00Cooooo0_ob0`8Vooooo`03
o`000?moOgooOgmo03[oOgmo00?o0000ooooooooool0oooooolXooooo`00oooooolFooooo`03o`00
0?moOgooOgmo01_oOgmo0_l0000VogmoO`04o`000?ooooooooooooooo`;olP<2:?ooool00ol0003o
OgmoogmoO`0jogmoO`03o`000?oooooooooo0?oooooo:?ooool00?oooooo5oooool2o`0001SoOgmo
0ol0000XogmoO`;o00000_ob0`8Zooooo`03o`000?moOgooOgmo03[oOgmo00?o0000ooooooooool0
oooooolXooooo`00oooooolIooooo`03o`000?moOgooOgmo01;oOgmo0ol0000XogmoO`GolP<200?o
0000ooooooooool0:?ooool00ol0003oOgmoogmoO`0kogmoO`03o`000?oooooooooo0?oooooo:?oo
ool00?oooooo6_ooool00ol0003oOgmoogmoO`0?ogmoO`;o00009omoOgl7oo830P03ogmoOol0003o
oooo02[ooooo00?o0000ogmoOomoOgl0>omoOgl00ol0003oooooooooo`3oooooobSooooo003ooooo
oa_ooooo00?o0000ogmoOomoOgl02omoOgl3o`0002_oOgmo1?ob0`82ogmoO`03o`000?oooooooooo
02Sooooo00?o0000ogmoOomoOgl0??moOgl00ol0003oooooooooo`3oooooobSooooo003ooooooaco
oooo0_l00009ogmoO`;o0000;?moOgl2oo830P03ogmoOoob0`;olP<200?oOgmo0_l0000Yooooo`03
o`000?moOgooOgmo03coOgmo00?o0000ooooooooool0oooooolXooooo`00oooooolNooooo`03o`00
0?moOgooOgmo00?oOgmo0ol0000/ogmoO`;olP<20_moOgl2oo830P06ogmoOol0003o0000o`000?mo
Ogoo0000:Oooool00ol0003oOgmoogmoO`0mogmoO`03o`000?oooooooooo0?oooooo9oooool00?oo
oooo7oooool00ol0003oOgmoo`000002o`0002goOgmo0_ob0`84ogmoO`03oo830_l0003o000000Go
Ogmo00?o0000ooooooooool09Oooool00ol0003oOgmoogmoO`0nogmoO`03o`000?oooooooooo0?oo
oooo9oooool00?oooooo8?ooool2o`0002goOgmo0_ob0`84ogmoO`;o00002?moOgl00ol0003ooooo
ooooo`0Uooooo`03o`000?moOgooOgmo03koOgmo00?o0000ooooooooool0oooooolWooooo`00oooo
oolRooooo`03o`000?moOgooOgmo02OoOgmo0oob0`83ogmoO`?o00002_moOgl00ol0003ooooooooo
o`0Tooooo`03o`000?moOgooOgmo03ooOgmo00?o0000ooooooooool0oooooolWooooo`00oooooolS
ooooo`03o`000?moOgooOgmo02CoOgmo0_ob0`83ogmoO`?o00003_moOgl00ol0003oooooooooo`0S
ooooo`03o`000?moOgooOgmo03[oOgmo1_l0003oooooobWooooo003oooooobCooooo00?o0000ogmo
OomoOgl08OmoOgl2oo830P?oOgmo0_l0000AogmoO`03o`000?oooooooooo02?ooooo00?o0000ogmo
OomoOgl0<?moOgl:o`0000GoOgmo00?o0000ooooooooool0oooooolWooooo`00oooooolUooooo`03
o`000?moOgooOgmo01koOgmo0_ob0`82ogmoO`?o00005?moOgl00ol0003oooooooooo`0Qooooo`03
o`000?moOgooOgmo02OoOgmo2_l0000?ogmoO`03o`000?oooooooooo0?oooooo9oooool00?oooooo
9_ooool2o`0001coOgmo0_ob0`801?moOgoo0000o`000?l0000GogmoO`03o`000?oooooooooo027o
oooo00?o0000ogmoOomoOgl07OmoOgl:o`0001WoOgmo00?o0000ooooooooool0oooooolWooooo`00
oooooolXooooo`03o`000?moOgooOgmo01KoOgmo0oob0`800omoOgoo0000o`00000KogmoO`03o`00
0?oooooooooo01oooooo00?o0000ogmoOomoOgl05OmoOgl9o`0002?oOgmo00?o0000ooooooooool0
oooooolWooooo`00oooooolYooooo`03o`000?moOgooOgmo01?oOgmo0_ob0`801?moOgoo0000o`00
0?l0000MogmoO`03o`000?oooooooooo01oooooo00?o0000ogmoOomoOgl02omoOgl:o`0002coOgmo
00?o0000ooooooooool0oooooolWooooo`00oooooolZooooo`03o`000?moOgooOgmo013oOgmo0_ob
0`800omoOgoo0000o`00000PogmoO`03o`000?oooooooooo01oooooo00Co0000ogmoOomoOgooOgmo
2_l0000gogmoO`03o`000?oooooooooo0?oooooo9_ooool00?oooooo:oooool2o`0000koOgmo0_ob
0`83o`0002?oOgmo00?o0000ooooooooool07Oooool5o`00047oOgmo00?o0000ooooooooool0oooo
oolVooooo`00ooooool]ooooo`03o`000?moOgooOgmo00WoOgmo0_ob0`82o`0002KoOgmo00?o0000
ooooooooool07Oooool00ol0003oOgmoogmoO`13ogmoO`03o`000?oooooooooo0?oooooo9_ooool0
0?oooooo;_ooool00ol0003oOgmoogmoO`05ogmoO`?olP<200?o0000ogmoOomoOgl0:?moOgl00ol0
003oooooooooo`0Kooooo`03o`000?moOgooOgmo04CoOgmo00?o0000ooooooooool0oooooolVoooo
o`00oooooolYooooo`?olP<20oooool00ol0003oOgmoogmoO`02ogmoO`;olP<20_l0000/ogmoO`03
o`000?oooooooooo01_ooooo00?o0000ogmoOomoOgl0A?moOgl00ol0003oooooooooo`3oooooobKo
oooo003oooooob[ooooo1_ob0`801Ol0003oOgmooo830_ob0`;o000002ooOgmo00?o0000oooooooo
ool06_ooool00ol0003oOgmoogmoO`15ogmoO`03o`000?oooooooooo0?oooooo9_ooool001?ooooo
ooob0`8Moo830P03o`000?ob0`;o0000037oOgmo0_l0000Kooooo`03o`000?moOgooOgmo04GoOgmo
00?o0000ooooooooool0oooooolVooooo`00oooooolZooooo`GolP<200Goooooo`000?l0003ooooo
o`00000]ogmoO`?o000000?oOgmoo`000?ooool06_ooool00ol0003oOgmoogmoO`15ogmoO`03o`00
0?oooooooooo0?oooooo9_ooool00?oooooo:Oooool2oo830PWooooo00?o0000ogmoOomoOgl0:?mo
Ogl2o`0000GoOgmo00?o0000ooooooooool05oooool00ol0003oOgmoogmoO`16ogmoO`03o`000?oo
oooooooo0?oooooo9_ooool00?oooooo=Oooool00ol0003oOgmoogmoO`0TogmoO`?o00001omoOgl0
0ol0003oooooooooo`0Gooooo`03o`000?moOgooOgmo04OoOgmo00?o0000ooooooooool0oooooolU
ooooo`00oooooolfooooo`03o`000?moOgooOgmo027oOgmo0_l0000:ogmoO`03o`000?oooooooooo
01Kooooo00?o0000ogmoOomoOgl0B?moOgl00ol0003oooooooooo`3oooooobGooooo003oooooocOo
oooo0_l0000NogmoO`?o00003OmoOgl00ol0003oooooooooo`0Eooooo`03o`000?moOgooOgmo04So
Ogmo00?o0000ooooooooool0oooooolUooooo`00ooooooliooooo`03o`000?moOgooOgmo01WoOgmo
0_l0000@ogmoO`03o`000?oooooooooo01Cooooo00?o0000ogmoOomoOgl0BOmoOgl00ol0003ooooo
ooooo`3oooooobGooooo003ooooooc[ooooo00?o0000ogmoOomoOgl05OmoOgl3o`0001?oOgmo00?o
0000ooooooooool04oooool00ol0003oOgmoogmoO`14ogmoO`Ko0000oooooolWooooo`00oooooolk
ooooo`03o`000?moOgooOgmo01;oOgmo0_l0000FogmoO`03o`000?oooooooooo01;ooooo00?o0000
ogmoOomoOgl0>omoOgl:o`000?oooooo;Oooool00?oooooo??ooool2o`0000ooOgmo0ol0000Hogmo
O`03o`000?oooooooooo01;ooooo00?o0000ogmoOomoOgl0<OmoOgl:o`000?oooooo=oooool00?oo
oooo?_ooool00ol0003oOgmoogmoO`0:ogmoO`;o00007?moOgl00ol0003oooooooooo`0@ooooo`03
o`000?moOgooOgmo02SoOgmo2_l0003ooooood7ooooo003oooooocoooooo00?o0000ogmoOomoOgl0
1_moOgl3o`0001koOgmo00?o0000ooooooooool04?ooool00ol0003oOgmoogmoO`0NogmoO`[o0000
oooooom;ooooo`00oooooom0ooooo`03o`000?moOgooOgmo00?oOgmo0_l0000QogmoO`03o`000?oo
oooooooo013ooooo00?o0000ogmoOomoOgl05?moOgl:o`000?ooooooEOooool00?oooooo@Oooool0
0ol0003oOgmoo`000002o`0002CoOgmo00?o0000ooooooooool03_ooool00ol0003oOgmoogmoO`0;
ogmoO`[o0000oooooomOooooo`00oooooom2ooooo`;o00009_moOgl00ol0003oooooooooo`0>oooo
o`04o`000?moOgooOgmoogmoO`[o0000oooooomYooooo`00oooooom4ooooo`03o`000?moOgooOgmo
02CoOgmo00?o0000ooooooooool03?ooool5o`000?ooooooLoooool00?ooooooAOooool00ol0003o
OgmoogmoO`0SogmoO`03o`000?oooooooooo0?ooooooQ?ooool00?ooooooA_ooool00ol0003oOgmo
ogmoO`0RogmoO`03o`000?oooooooooo0?ooooooQ?ooool00?ooooooAoooool00ol0003oOgmoogmo
O`0QogmoO`;o0000oooooon5ooooo`00oooooom8ooooo`;o00007_moOgl3o`000003ogmoOol0003o
oooo0?ooooooQ?ooool00?ooooooB_ooool00ol0003oOgmoogmoO`0IogmoO`;o00001OmoOgl00ol0
003oooooooooo`3ooooooh;ooooo003ooooood_ooooo00?o0000ogmoOomoOgl05OmoOgl3o`0000Oo
Ogmo00?o0000ooooooooool0oooooon2ooooo`00oooooom<ooooo`03o`000?moOgooOgmo01;oOgmo
0_l0000:ogmoO`03o`000?oooooooooo0?ooooooP_ooool00?ooooooCOooool2o`0000ooOgmo0ol0
000=ogmoO`03o`000?oooooooooo0?ooooooPOooool00?ooooooCoooool00ol0003oOgmoogmoO`0:
ogmoO`;o00004?moOgl00ol0003oooooooooo`3ooooooh7ooooo003ooooooe3ooooo00?o0000ogmo
OomoOgl01_moOgl3o`0001?oOgmo00?o0000ooooooooool0oooooon0ooooo`00oooooomAooooo`03
o`000?moOgooOgmo00?oOgmo0_l0000FogmoO`03o`000?oooooooooo0?ooooooP?ooool00?oooooo
D_ooool00ol0003oOgmoo`000002o`0001SoOgmo00?o0000ooooooooool0oooooon0ooooo`00oooo
oomCooooo`;o00006omoOgl00ol0003oooooooooo`3oooooogoooooo003ooooooeGooooo00?o0000
ogmoOomoOgl06?moOgl00ol0003oooooooooo`3oooooogoooooo003ooooooeKooooo00?o0000ogmo
OomoOgl05omoOgl00ol0003oooooooooo`3oooooogoooooo003ooooooeOooooo00?o0000ogmoOomo
Ogl05omoOgl00ol0003oooooooooo`3oooooogkooooo003ooooooeSooooo00?o0000ogmoOomoOgl0
5_moOgl00ol0003oooooooooo`3oooooogkooooo003ooooooeWooooo0_l0000GogmoO`03o`000?oo
oooooooo0?ooooooOOooool00?ooooooFoooool00ol0003oOgmoogmoO`0DogmoO`03o`000?oooooo
oooo0?ooooooOOooool00?ooooooG?ooool00ol0003oOgmoogmoO`0CogmoO`03o`000?oooooooooo
0?ooooooOOooool00?ooooooGOooool00ol0003oOgmoogmoO`0BogmoO`;o0000oooooomnooooo`00
oooooomNooooo`;o00003omoOgl3o`000?ooooooP?ooool00?ooooooH?ooool00ol0003oOgmoogmo
O`0:ogmoO`;o0000oooooon3ooooo`00oooooomQooooo`03o`000?moOgooOgmo00KoOgmo0ol0003o
ooooohGooooo003oooooof;ooooo00?o0000ogmoOomoOgl00omoOgl2o`000?ooooooR?ooool00?oo
ooooHoooool00ol0003oOgmoo`000002o`000?ooooooR_ooool00?ooooooI?ooool00ol0003ooooo
ooooo`3ooooooh_ooooo003oooooooooooool_ooool00?ooooooooooooobooooo`00oooooooooooo
oo;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 751.188}, {155.875, 0}} -> {-2.07373, -11.6612, \
0.105363, 0.105363}},
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnalyzeSystem[\ {\n\t\tSingleRay[], \n\t\tMove[
            RhomboidPrism[Automatic, 10, 50], 25], \n\t\tBoundary[100, 
            GraphicDesign -> Off]}, PlotType -> TopView];\)\)], "Input",
  CellTags->"Prism Examples"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .26372 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.037681 0.00952381 [
[ 0 0 0 0 ]
[ 1 .26372 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.30955 .00633 m
.21426 .06904 L
.21426 .06904 L
.30955 .00633 L
.30955 .00633 L
s
.65175 .25742 m
.21418 .06897 L
.21418 .06897 L
.65175 .25742 L
.65175 .25742 L
s
.7469 .19468 m
.65162 .25739 L
.65162 .25739 L
.7469 .19468 L
.7469 .19468 L
s
.74699 .19475 m
.30941 .00629 L
.30941 .00629 L
.74699 .19475 L
.74699 .19475 L
s
.30944 .00628 m
.21415 .06899 L
.65173 .25744 L
.74701 .19473 L
.30944 .00628 L
s
.30944 .00628 m
.21415 .06899 L
.65173 .25744 L
.74701 .19473 L
.30944 .00628 L
s
.039 .916 .04 r
.02381 .03768 m
.2619 .03768 L
s
% Start of user PostScript
0 0 25. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.2619 .03768 Mdot
.039 .916 .04 r
.5 Mabswid
.2619 .03768 m
.69934 .22598 L
s
% Start of user PostScript
25. 0 70.9311 19.7717 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69934 .22598 Mdot
.039 .916 .04 r
.5 Mabswid
.69934 .22598 m
.97619 .22598 L
s
% Start of user PostScript
70.9311 19.7717 100. 19.7717 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .22598 Mdot
0 0 m
1 0 L
1 .26372 L
0 .26372 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{567.5, 149.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0000UB000`400?l00000o`00003ooooooooo
ooooocWooooo003ooooooooooooo>Oooool00?ooooooooooooliooooo`00[_ooool3o`000?oooooo
Qoooool00:gooooo00Co0000oooooooooooooooo0_l0003oooooohGooooo002[ooooo`;o00001_oo
ool3o`000?ooooooP_ooool00:[ooooo00?o0000ooooooooool02Oooool2o`000?ooooooP?ooool0
0:Sooooo0_l0000>ooooo`;o0000oooooomnooooo`00Yoooool00ol0003oooooooooo`0@ooooo`?o
0000oooooomkooooo`00YOooool2o`0001Kooooo0_l0003oooooogWooooo002Tooooo`03o`000?oo
oooooooo01Sooooo0_l0003oooooogOooooo002Rooooo`;o00007Oooool3o`000?ooooooM?ooool0
0:7ooooo00?o0000ooooooooool08?ooool2o`000?ooooooL_ooool00:3ooooo00?o0000oooooooo
ool08oooool2o`000?ooooooL?ooool009kooooo0_l0000Xooooo`?o0000oooooom]ooooo`00WOoo
ool00ol0003oooooooooo`0[ooooo`;o0000oooooom[ooooo`00Voooool2o`00033ooooo0_l0003o
ooooofWooooo002Jooooo`03o`000?oooooooooo03;ooooo0_l0003oooooofOooooo002Hooooo`;o
0000=oooool3o`000?ooooooI?ooool008gooooo0ol9jPX7ooooo`03o`000?oooooooooo03[ooooo
0_l0003oooooof;ooooo002>ooooo`Ko2NX:00?oooooo`000?l00000?oooool2o`000?ooooooH?oo
ool000koooooQ_l9jPX00ol0003o2NX:o`WZ2P11ooooo`?o0000oooooomMooooo`00S_ooool5o`WZ
2P?o000000?oooooo`WZ2_l9jPX0@_ooool2o`000?ooooooFoooool008gooooo0_l9jPX2ooooo`03
o`000?oooooooooo00Gooooo0ol9jPY1ooooo`;o0000oooooomIooooo`00Soooool2o`0000_ooooo
0_l9jPY1ooooo`?o0000oooooomFooooo`00S_ooool00ol0003oooooooooo`0=ooooo`;o2NX:@_oo
ool2o`000?ooooooE?ooool008cooooo0_l0000Booooo`?o2NX:@Oooool2o`000?ooooooD_ooool0
08_ooooo00?o0000ooooooooool05Oooool2o`WZ2T7ooooo0ol0003oooooodoooooo0029ooooo`;o
00006_ooool2o`WZ2T;ooooo0_l0003oooooodgooooo0028ooooo`03o`000?oooooooooo01cooooo
0ol9jPY1ooooo`;o0000oooooom;ooooo`00Qoooool00ol0003oooooooooo`0Pooooo`;o2NX:@Ooo
ool2o`000?ooooooBOooool008Gooooo0_l0000Uooooo`;o2NX:@Oooool3o`000?ooooooA_ooool0
08Cooooo00?o0000ooooooooool09oooool3o`WZ2T7ooooo0_l0003oooooodCooooo0022ooooo`;o
0000;Oooool2o`WZ2T7ooooo0_l0003ooooood;ooooo0021ooooo`03o`000?oooooooooo02oooooo
0_l9jPY1ooooo`?o0000ooooooloooooo`00Ooooool2o`0003Cooooo0ol9jPY1ooooo`;o0000oooo
oolmooooo`00O_ooool00ol0003oooooooooo`0gooooo`;o2NX:@Oooool2o`000?oooooo>oooool0
07cooooo0_l0000looooo`;o2NX:@Oooool3o`000?oooooo>?ooool007[ooooo0_l00010ooooo`?o
2NX:@Oooool2o`000?oooooo=_ooool007[ooooo0_l00013ooooo`;o2NX:@Oooool2o`000?oooooo
=?ooool007cooooo0_l00013ooooo`;o2NX:@Oooool3o`000?oooooo<Oooool007kooooo0ol00012
ooooo`?o2NX:@Oooool2o`000?oooooo;oooool0087ooooo0_l00013ooooo`;o2NX:@Oooool2o`00
0?oooooo;Oooool008?ooooo0_l00013ooooo`;o2NX:@Oooool2o`000?oooooo:oooool008Gooooo
0ol00012ooooo`?o2NX:@?ooool3o`000?oooooo:?ooool008Sooooo0_l00013ooooo`;o2NX:@Ooo
ool2o`000?oooooo9_ooool008[ooooo0_l00013ooooo`;o2NX:@Oooool2o`000?oooooo9?ooool0
08cooooo0ol00012ooooo`?o2NX:@?ooool3o`000?oooooo8Oooool008oooooo0_l00013ooooo`;o
2NX:@Oooool2o`000?oooooo7oooool0097ooooo0_l00013ooooo`;o2NX:@Oooool2o`000?oooooo
7Oooool009?ooooo0ol00012ooooo`;o2NX:@Oooool3o`000?oooooo6_ooool009Kooooo0_l00012
ooooo`?o2NX:@Oooool2o`000?oooooo6?ooool009Sooooo0_l00013ooooo`;o2NX:@Oooool2o`00
0?oooooo5_ooool009[ooooo0ol00012ooooo`;o2NX:@Oooool3o`000?oooooo4oooool009gooooo
0_l00012ooooo`?o2NX:@Oooool2o`000?oooooo4Oooool009oooooo0_l00013ooooo`;o2NX:@Ooo
ool2o`000?oooooo3oooool00:7ooooo0ol00012ooooo`;o2NX:@Oooool3o`000?oooooo3?ooool0
0:Cooooo0_l00012ooooo`?o2NX:@Oooool2o`000?oooooo2_ooool00:Kooooo0_l00013ooooo`;o
2NX:@Oooool2o`000?oooooo2?ooool00:Sooooo0ol00012ooooo`;o2NX:@Oooool2o`000?oooooo
1_ooool00:_ooooo0_l00012ooooo`?o2NX:@?ooool3o`000?oooooo0oooool00:gooooo0_l00013
ooooo`;o2NX:@Oooool2o`000?oooooo0Oooool00:oooooo0ol00012ooooo`;o2NX:@Oooool2o`00
0?kooooo002booooo`;o0000@_ooool3o`WZ2T3ooooo0ol0003kooooo`00]?ooool2o`0004?ooooo
0_l9jPY1ooooo`;o0000nOooool00;Kooooo0ol00012ooooo`;o2NX:@Oooool2o`000?Oooooo002i
ooooo`;o0000@_ooool3o`WZ2T3ooooo0ol0003dooooo`00^oooool2o`0004?ooooo0_l9jPY1oooo
o`;o0000l_ooool00;gooooo0_l00013ooooo`;o2NX:@Oooool2o`000?3ooooo002oooooo`?o0000
@_ooool3o`WZ2T3ooooo0ol0003]ooooo`00`_ooool2o`0004?ooooo0_l9jPY1ooooo`;o0000jooo
ool00<Cooooo0_l00013ooooo`;o2NX:@Oooool2o`000>Wooooo0036ooooo`?o0000@_ooool3o`WZ
2T3ooooo0_l0003Wooooo`00bOooool2o`0004?ooooo0_l9jPY0ooooo`?o0000i?ooool00<_ooooo
0_l00013ooooo`;o2NX:@Oooool2o`000>;ooooo003=ooooo`?o0000@_ooool2o`WZ2T7ooooo0_l0
003Pooooo`00d?ooool2o`0004;ooooo0ol9jPY0ooooo`?o0000gOooool00=;ooooo0_l00013oooo
o`;o2NX:@Oooool2o`000=_ooooo003Dooooo`?o0000@_ooool2o`WZ2T7ooooo0_l0003Iooooo`00
eoooool2o`0004;ooooo0ol9jPY0ooooo`?o0000e_ooool00=Wooooo0_l00013ooooo`;o2NX:@Ooo
ool2o`000=Cooooo003Kooooo`?o0000@_ooool2o`WZ2T7ooooo0_l0003Booooo`00g_ooool2o`00
04;ooooo0ol9jPY0ooooo`?o0000coooool00>3ooooo0_l00013ooooo`;o2NX:@Oooool2o`000<go
oooo003Rooooo`?o0000@_ooool2o`WZ2T7ooooo0_l0003;ooooo`00iOooool2o`0004;ooooo0ol9
jPY0ooooo`;o0000bOooool00>Oooooo0_l00013ooooo`;o2NX:@?ooool3o`000<Kooooo003Yoooo
o`?o0000@_ooool2o`WZ2T7ooooo0_l00034ooooo`00k?ooool2o`0004;ooooo0ol9jPY0ooooo`;o
0000`_ooool00>kooooo0_l00013ooooo`;o2NX:@?ooool3o`000;oooooo003`ooooo`?o0000@_oo
ool2o`WZ2T7ooooo0_l0002mooooo`00loooool2o`0004;ooooo0ol9jPY0ooooo`;o0000^oooool0
0?Gooooo0_l00013ooooo`;o2NX:@?ooool3o`000;Sooooo003gooooo`;o0000@oooool2o`WZ2T7o
oooo0_l0002fooooo`00nOooool3o`0004;ooooo0ol9jPY0ooooo`;o0000]?ooool00?cooooo0_l0
0013ooooo`;o2NX:@?ooool3o`000;7ooooo003nooooo`;o0000@oooool2o`WZ2T7ooooo0_l0002_
ooooo`00ooooool1ooooo`?o0000@_ooool3o`WZ2T3ooooo0_l0002]ooooo`00ooooool4ooooo`;o
0000@oooool2o`WZ2T3ooooo0_l0002[ooooo`00ooooool6ooooo`;o0000@oooool2o`WZ2T3ooooo
0ol0002Xooooo`00ooooool8ooooo`?o0000@_ooool3o`WZ2T3ooooo0_l0002Vooooo`00ooooool;
ooooo`;o0000@oooool2o`WZ2T3ooooo0_l0002Tooooo`00ooooool=ooooo`;o0000@oooool2o`WZ
2T3ooooo0ol0002Qooooo`00ooooool?ooooo`?o0000@_ooool2o`WZ2T7ooooo0_l0002Oooooo`00
oooooolBooooo`;o0000@_ooool3o`WZ2T3ooooo0_l0002Mooooo`00oooooolDooooo`;o0000@ooo
ool2o`WZ2T3ooooo0ol0002Jooooo`00oooooolFooooo`?o0000@_ooool2o`WZ2T7ooooo0_l0002H
ooooo`00oooooolIooooo`;o0000@_ooool3o`WZ2T3ooooo0_l0002Fooooo`00oooooolKooooo`;o
0000@oooool2o`WZ2T3ooooo0ol0002Cooooo`00oooooolMooooo`?o0000@_ooool2o`WZ2T7ooooo
0ol0002@ooooo`00oooooolPooooo`;o0000@_ooool3o`WZ2Soooooo0_l0002@ooooo`00oooooolR
ooooo`;o0000@oooool2o`WZ2Scooooo00?o0000ooooooooool0T?ooool00?oooooo9?ooool3o`00
04;ooooo0_l9jPXhooooo`;o0000Toooool00?oooooo9oooool2o`0004;ooooo0ol9jPXdooooo`03
o`000?oooooooooo09?ooooo003oooooobWooooo0_l00013ooooo`;o2NX:<?ooool2o`0009Kooooo
003oooooob_ooooo0ol00012ooooo`;o2NX:;Oooool00ol0003oooooooooo`2Fooooo`00ooooool^
ooooo`;o0000@_ooool3o`WZ2RSooooo0_l0002Iooooo`00ooooool`ooooo`;o0000@oooool2o`WZ
2RCooooo0_l0002Kooooo`00oooooolbooooo`?o0000@_ooool2o`WZ2R7ooooo00?o0000oooooooo
ool0Voooool00?oooooo=Oooool2o`0004;ooooo0ol9jPXLooooo`;o0000W_ooool00?oooooo=ooo
ool2o`0004?ooooo0_l9jPXIooooo`03o`000?oooooooooo09kooooo003oooooocWooooo0_l00013
ooooo`;o2NX:5Oooool2o`000:7ooooo003ooooooc_ooooo0ol00012ooooo`?o2NX:0oooool2o`WZ
2Pcooooo00?o0000ooooooooool0XOooool00?oooooo?_ooool2o`0004?ooooo0_l9jPX01?oooooo
2NX:o`WZ2_l9jPX9ooooo`;o0000Y?ooool00?oooooo@?ooool2o`0004?ooooo1Ol9jPX7ooooo`03
o`000?oooooooooo0:Cooooo003ooooood;ooooo0ol00011ooooo`Go2NX:1?ooool2o`0008oooooo
0ol9jPXEooooo`00oooooom5ooooo`;o0000?Oooool8o`WZ2P;ooooo00?o0000ooooooooool0T?oo
ool6o`WZ2Q7ooooo003oooooodOooooo0_l00010oooooioo2NX:0_l0000>ooooo`00oooooom9oooo
o`?o0000?_ooool4o`0009?ooooo1Ol9jPX2ooooo`;o00003_ooool00?ooooooC?ooool2o`0003_o
oooo00?o0000ooooooooool0U?ooool2o`WZ2QKooooo003oooooodkooooo0_l0000gooooo`;o0000
[oooool00?ooooooD?ooool3o`0003?ooooo00?o0000ooooooooool0[oooool00?ooooooDoooool2
o`0002oooooo0_l0002booooo`00oooooomEooooo`;o0000;?ooool00ol0003oooooooooo`2boooo
o`00oooooomGooooo`?o00009oooool2o`000;Gooooo003ooooooe[ooooo0_l0000Tooooo`03o`00
0?oooooooooo0;Gooooo003ooooooecooooo0_l0000Pooooo`;o0000^?ooool00?ooooooG_ooool3
o`0001cooooo00?o0000ooooooooool0^?ooool00?ooooooHOooool2o`0001Sooooo0_l0002koooo
o`00oooooomSooooo`;o00005?ooool2o`000;gooooo003oooooofGooooo0ol0000@ooooo`03o`00
0?oooooooooo0;gooooo003oooooofSooooo0_l0000<ooooo`;o0000`?ooool00?ooooooJ_ooool2
o`0000Wooooo00?o0000ooooooooool0`?ooool00?ooooooK?ooool3o`0000Cooooo0_l00033oooo
o`00oooooom_ooooo`;o000000?oooooo`000?ooool0a?ooool00?ooooooLOooool2o`000<Gooooo
003ooooooooooooo>Oooool00?ooooooooooooliooooo`00ooooooooooooocWooooo0000\
\>"],
  ImageRangeCache->{{{0, 566.5}, {148.625, 0}} -> {-2.77336, -3.95664, \
0.186314, 0.186314}},
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[
{LineOfRays[2,WaveLength->0.680], 
LineOfRays[2,WaveLength->0.710], 
LineOfRays[2,WaveLength->0.410],
Move[PellinBrocaPrism[60,40.0,23.5,79.5,10.0,ComponentMedium->BK7],{30,8},-33]\
,
Move[Prism[{45,40,45},10,ComponentMedium->BK7],{58,-150},-47],
Move[Prism[{45,40,45},10,ComponentMedium->BK7],{308,-150},47],
Boundary[{0,-200,-50},{350,50,50}]},PlotType->TopView
];\
\>", "Input",
  CellTags->"Prism Examples"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .71429 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00272109 0.561224 0.00272109 [
[.8264 .06711 -18 -4.5 ]
[.8264 .06711 18 4.5 ]
[.1333 .52597 -54 -4.5 ]
[.1333 .52597 54 4.5 ]
[.09837 .19447 -18 -4.5 ]
[.09837 .19447 18 4.5 ]
[ 0 0 0 0 ]
[ 1 .71429 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.19672 .5237 m
.23156 .57736 L
.23156 .57736 L
.19672 .5237 L
.19672 .5237 L
s
.19675 .5237 m
.10542 .58301 L
.10542 .58301 L
.19675 .5237 L
.19675 .5237 L
s
.15589 .6087 m
.10543 .58299 L
.10543 .58299 L
.15589 .6087 L
.15589 .6087 L
s
.15586 .6087 m
.23157 .57733 L
.23157 .57733 L
.15586 .6087 L
.15586 .6087 L
s
.10541 .583 m
.19674 .52369 L
.23158 .57734 L
.15587 .60871 L
.10541 .583 L
s
.10541 .583 m
.19674 .52369 L
.23158 .57734 L
.15587 .60871 L
.10541 .583 L
s
.1445 .19286 m
.22145 .19018 L
.22145 .19018 L
.1445 .19286 L
.1445 .19286 L
s
.21875 .11324 m
.22143 .1902 L
.22143 .1902 L
.21875 .11324 L
.21875 .11324 L
s
.1445 .19288 m
.21877 .11324 L
.21877 .11324 L
.1445 .19288 L
.1445 .19288 L
s
.14449 .19288 m
.22145 .19019 L
.21876 .11323 L
.14449 .19288 L
s
.14449 .19288 m
.22145 .19019 L
.21876 .11323 L
.14449 .19288 L
s
.82479 .11324 m
.8221 .1902 L
.8221 .1902 L
.82479 .11324 L
.82479 .11324 L
s
.89904 .19286 m
.82208 .19018 L
.82208 .19018 L
.89904 .19286 L
.89904 .19286 L
s
.82477 .11324 m
.89904 .19288 L
.89904 .19288 L
.82477 .11324 L
.82477 .11324 L
s
.82478 .11323 m
.82209 .19019 L
.89905 .19288 L
.82478 .11323 L
s
.82478 .11323 m
.82209 .19019 L
.89905 .19288 L
.82478 .11323 L
s
.97619 .69728 m
.97619 .01701 L
.97619 .01701 L
.97619 .69728 L
.97619 .69728 L
s
.97619 .01701 m
.02381 .01701 L
.02381 .01701 L
.97619 .01701 L
.97619 .01701 L
s
.02381 .01701 m
.02381 .69728 L
.02381 .69728 L
.02381 .01701 L
.02381 .01701 L
s
.02381 .69728 m
.97619 .69728 L
.97619 .69728 L
.02381 .69728 L
.02381 .69728 L
s
.97619 .01701 m
.97619 .69728 L
.02381 .69728 L
.02381 .01701 L
.97619 .01701 L
s
.97619 .69728 m
.97619 .01701 L
.02381 .01701 L
.02381 .69728 L
.97619 .69728 L
s
.927 .004 .008 r
.02381 .5585 m
.14315 .5585 L
s
% Start of user PostScript
0 -1. 43.8588 -1. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.14315 .5585 Mdot
.927 .004 .008 r
.5 Mabswid
.02381 .56122 m
.13896 .56122 L
s
% Start of user PostScript
0 0 42.3189 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.13896 .56122 Mdot
.927 .004 .008 r
.5 Mabswid
.02381 .56395 m
.13477 .56395 L
s
% Start of user PostScript
0 1. 40.7791 1. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.13477 .56395 Mdot
.844 .001 .007 r
.5 Mabswid
.02381 .5585 m
.14315 .5585 L
s
% Start of user PostScript
0 -1. 43.8588 -1. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.14315 .5585 Mdot
.844 .001 .007 r
.5 Mabswid
.02381 .56122 m
.13896 .56122 L
s
% Start of user PostScript
0 0 42.3189 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.13896 .56122 Mdot
.844 .001 .007 r
.5 Mabswid
.02381 .56395 m
.13477 .56395 L
s
% Start of user PostScript
0 1. 40.7791 1. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.13477 .56395 Mdot
.001 .037 .937 r
.5 Mabswid
.02381 .5585 m
.14315 .5585 L
s
% Start of user PostScript
0 -1. 43.8588 -1. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.14315 .5585 Mdot
.001 .037 .937 r
.5 Mabswid
.02381 .56122 m
.13896 .56122 L
s
% Start of user PostScript
0 0 42.3189 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.13896 .56122 Mdot
.001 .037 .937 r
.5 Mabswid
.02381 .56395 m
.13477 .56395 L
s
% Start of user PostScript
0 1. 40.7791 1. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.13477 .56395 Mdot
.927 .004 .008 r
.5 Mabswid
.14315 .5585 m
.20872 .5868 L
s
% Start of user PostScript
43.8588 -1. 67.9554 9.39865 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20872 .5868 Mdot
.927 .004 .008 r
.5 Mabswid
.13896 .56122 m
.20337 .58902 L
s
% Start of user PostScript
42.3189 0 65.9873 10.2139 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20337 .58902 Mdot
.927 .004 .008 r
.5 Mabswid
.13477 .56395 m
.19801 .59124 L
s
% Start of user PostScript
40.7791 1. 64.0192 11.0291 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19801 .59124 Mdot
.844 .001 .007 r
.5 Mabswid
.14315 .5585 m
.20875 .58679 L
s
% Start of user PostScript
43.8588 -1. 67.9674 9.39365 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20875 .58679 Mdot
.844 .001 .007 r
.5 Mabswid
.13896 .56122 m
.2034 .589 L
s
% Start of user PostScript
42.3189 0 65.9991 10.2089 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.2034 .589 Mdot
.844 .001 .007 r
.5 Mabswid
.13477 .56395 m
.19804 .59122 L
s
% Start of user PostScript
40.7791 1. 64.0308 11.0242 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19804 .59122 Mdot
.001 .037 .937 r
.5 Mabswid
.14315 .5585 m
.20809 .58706 L
s
% Start of user PostScript
43.8588 -1. 67.7229 9.49494 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20809 .58706 Mdot
.001 .037 .937 r
.5 Mabswid
.13896 .56122 m
.20275 .58927 L
s
% Start of user PostScript
42.3189 0 65.7589 10.3084 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20275 .58927 Mdot
.001 .037 .937 r
.5 Mabswid
.13477 .56395 m
.1974 .59149 L
s
% Start of user PostScript
40.7791 1. 63.795 11.1219 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1974 .59149 Mdot
.927 .004 .008 r
.5 Mabswid
.20872 .5868 m
.21972 .55911 L
s
0 0 0 r
2 Mabswid
.21972 .55911 Mdot
.927 .004 .008 r
.5 Mabswid
.20337 .58902 m
.21694 .55484 L
s
0 0 0 r
2 Mabswid
.21694 .55484 Mdot
.927 .004 .008 r
.5 Mabswid
.19801 .59124 m
.21416 .55056 L
s
0 0 0 r
2 Mabswid
.21416 .55056 Mdot
.844 .001 .007 r
.5 Mabswid
.20875 .58679 m
.21974 .55915 L
s
0 0 0 r
2 Mabswid
.21974 .55915 Mdot
.844 .001 .007 r
.5 Mabswid
.2034 .589 m
.21696 .55488 L
s
0 0 0 r
2 Mabswid
.21696 .55488 Mdot
.844 .001 .007 r
.5 Mabswid
.19804 .59122 m
.21419 .5506 L
s
0 0 0 r
2 Mabswid
.21419 .5506 Mdot
.001 .037 .937 r
.5 Mabswid
.20809 .58706 m
.21925 .55839 L
s
0 0 0 r
2 Mabswid
.21925 .55839 Mdot
.001 .037 .937 r
.5 Mabswid
.20275 .58927 m
.21644 .55407 L
s
0 0 0 r
2 Mabswid
.21644 .55407 Mdot
.001 .037 .937 r
.5 Mabswid
.1974 .59149 m
.21364 .54976 L
s
0 0 0 r
2 Mabswid
.21364 .54976 Mdot
.927 .004 .008 r
.5 Mabswid
.21972 .55911 m
.19344 .19115 L
s
% Start of user PostScript
71.9955 -0.775671 62.3405 -136.001 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19344 .19115 Mdot
.927 .004 .008 r
.5 Mabswid
.21694 .55484 m
.19098 .19124 L
s
% Start of user PostScript
70.9751 -2.34697 61.4346 -135.969 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19098 .19124 Mdot
.927 .004 .008 r
.5 Mabswid
.21416 .55056 m
.18851 .19133 L
s
% Start of user PostScript
69.9547 -3.91826 60.5286 -135.938 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.18851 .19133 Mdot
.844 .001 .007 r
.5 Mabswid
.21974 .55915 m
.19416 .19113 L
s
% Start of user PostScript
72.0044 -0.76202 62.6031 -136.01 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19416 .19113 Mdot
.844 .001 .007 r
.5 Mabswid
.21696 .55488 m
.19169 .19122 L
s
% Start of user PostScript
70.9845 -2.33254 61.6945 -135.978 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19169 .19122 Mdot
.844 .001 .007 r
.5 Mabswid
.21419 .5506 m
.18921 .1913 L
s
% Start of user PostScript
69.9646 -3.90307 60.786 -135.947 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.18921 .1913 Mdot
.001 .037 .937 r
.5 Mabswid
.21925 .55839 m
.17893 .19166 L
s
% Start of user PostScript
71.8227 -1.04177 57.0062 -135.815 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.17893 .19166 Mdot
.001 .037 .937 r
.5 Mabswid
.21644 .55407 m
.17661 .19174 L
s
% Start of user PostScript
70.7926 -2.6281 56.1537 -135.785 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.17661 .19174 Mdot
.001 .037 .937 r
.5 Mabswid
.21364 .54976 m
.17429 .19182 L
s
% Start of user PostScript
69.7624 -4.21443 55.3012 -135.755 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.17429 .19182 Mdot
.927 .004 .008 r
.5 Mabswid
.19344 .19115 m
.19063 .14342 L
s
0 0 0 r
2 Mabswid
.19063 .14342 Mdot
.927 .004 .008 r
.5 Mabswid
.19098 .19124 m
.1883 .14591 L
s
0 0 0 r
2 Mabswid
.1883 .14591 Mdot
.927 .004 .008 r
.5 Mabswid
.18851 .19133 m
.18598 .1484 L
s
0 0 0 r
2 Mabswid
.18598 .1484 Mdot
.844 .001 .007 r
.5 Mabswid
.19416 .19113 m
.19136 .14263 L
s
0 0 0 r
2 Mabswid
.19136 .14263 Mdot
.844 .001 .007 r
.5 Mabswid
.19169 .19122 m
.18902 .14514 L
s
0 0 0 r
2 Mabswid
.18902 .14514 Mdot
.844 .001 .007 r
.5 Mabswid
.18921 .1913 m
.18669 .14764 L
s
0 0 0 r
2 Mabswid
.18669 .14764 Mdot
.001 .037 .937 r
.5 Mabswid
.17893 .19166 m
.17618 .15891 L
s
0 0 0 r
2 Mabswid
.17618 .15891 Mdot
.001 .037 .937 r
.5 Mabswid
.17661 .19174 m
.17405 .1612 L
s
0 0 0 r
2 Mabswid
.17405 .1612 Mdot
.001 .037 .937 r
.5 Mabswid
.17429 .19182 m
.17191 .16348 L
s
0 0 0 r
2 Mabswid
.17191 .16348 Mdot
.927 .004 .008 r
.5 Mabswid
.19063 .14342 m
.21979 .1431 L
s
0 0 0 r
2 Mabswid
.21979 .1431 Mdot
.927 .004 .008 r
.5 Mabswid
.1883 .14591 m
.21988 .14556 L
s
0 0 0 r
2 Mabswid
.21988 .14556 Mdot
.927 .004 .008 r
.5 Mabswid
.18598 .1484 m
.21996 .14803 L
s
0 0 0 r
2 Mabswid
.21996 .14803 Mdot
.844 .001 .007 r
.5 Mabswid
.19136 .14263 m
.21976 .14229 L
s
0 0 0 r
2 Mabswid
.21976 .14229 Mdot
.844 .001 .007 r
.5 Mabswid
.18902 .14514 m
.21985 .14476 L
s
0 0 0 r
2 Mabswid
.21985 .14476 Mdot
.844 .001 .007 r
.5 Mabswid
.18669 .14764 m
.21993 .14723 L
s
0 0 0 r
2 Mabswid
.21993 .14723 Mdot
.001 .037 .937 r
.5 Mabswid
.17618 .15891 m
.22036 .15952 L
s
0 0 0 r
2 Mabswid
.22036 .15952 Mdot
.001 .037 .937 r
.5 Mabswid
.17405 .1612 m
.22044 .16184 L
s
0 0 0 r
2 Mabswid
.22044 .16184 Mdot
.001 .037 .937 r
.5 Mabswid
.17191 .16348 m
.22053 .16416 L
s
0 0 0 r
2 Mabswid
.22053 .16416 Mdot
.927 .004 .008 r
.5 Mabswid
.21979 .1431 m
.82372 .14398 L
s
% Start of user PostScript
72.0229 -153.661 293.966 -153.336 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.82372 .14398 Mdot
.927 .004 .008 r
.5 Mabswid
.21988 .14556 m
.82363 .14645 L
s
% Start of user PostScript
72.0545 -152.755 293.934 -152.43 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.82363 .14645 Mdot
.927 .004 .008 r
.5 Mabswid
.21996 .14803 m
.82354 .14891 L
s
% Start of user PostScript
72.0862 -151.849 293.902 -151.524 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.82354 .14891 Mdot
.844 .001 .007 r
.5 Mabswid
.21976 .14229 m
.82378 .14204 L
s
% Start of user PostScript
72.0125 -153.958 293.991 -154.05 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.82378 .14204 Mdot
.844 .001 .007 r
.5 Mabswid
.21985 .14476 m
.8237 .14451 L
s
% Start of user PostScript
72.0443 -153.05 293.959 -153.141 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.8237 .14451 Mdot
.844 .001 .007 r
.5 Mabswid
.21993 .14723 m
.82361 .14699 L
s
% Start of user PostScript
72.076 -152.141 293.927 -152.233 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.82361 .14699 Mdot
.001 .037 .937 r
.5 Mabswid
.22036 .15952 m
.82234 .18342 L
s
% Start of user PostScript
72.2336 -147.627 293.46 -138.843 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.82234 .18342 Mdot
.001 .037 .937 r
.5 Mabswid
.22044 .16184 m
.82226 .18573 L
s
% Start of user PostScript
72.2634 -146.774 293.43 -137.993 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.82226 .18573 Mdot
.001 .037 .937 r
.5 Mabswid
.22053 .16416 m
.82218 .18805 L
s
% Start of user PostScript
72.2932 -145.922 293.4 -137.143 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.82218 .18805 Mdot
.927 .004 .008 r
.5 Mabswid
.82372 .14398 m
.8538 .14437 L
s
0 0 0 r
2 Mabswid
.8538 .14437 Mdot
.927 .004 .008 r
.5 Mabswid
.82363 .14645 m
.85613 .14687 L
s
0 0 0 r
2 Mabswid
.85613 .14687 Mdot
.927 .004 .008 r
.5 Mabswid
.82354 .14891 m
.85845 .14936 L
s
0 0 0 r
2 Mabswid
.85845 .14936 Mdot
.844 .001 .007 r
.5 Mabswid
.82378 .14204 m
.85193 .14237 L
s
0 0 0 r
2 Mabswid
.85193 .14237 Mdot
.844 .001 .007 r
.5 Mabswid
.8237 .14451 m
.85426 .14487 L
s
0 0 0 r
2 Mabswid
.85426 .14487 Mdot
.844 .001 .007 r
.5 Mabswid
.82361 .14699 m
.85659 .14737 L
s
0 0 0 r
2 Mabswid
.85659 .14737 Mdot
.001 .037 .937 r
.5 Mabswid
.82234 .18342 m
.89271 .1861 L
s
% Start of user PostScript
293.46 -138.843 319.322 -137.859 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.89271 .1861 Mdot
.001 .037 .937 r
.5 Mabswid
.82226 .18573 m
.89495 .1885 L
s
% Start of user PostScript
293.43 -137.993 320.145 -136.976 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.89495 .1885 Mdot
.001 .037 .937 r
.5 Mabswid
.82218 .18805 m
.89719 .1909 L
s
% Start of user PostScript
293.4 -137.143 320.968 -136.094 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.89719 .1909 Mdot
.927 .004 .008 r
.5 Mabswid
.8538 .14437 m
.85113 .19119 L
s
0 0 0 r
2 Mabswid
.85113 .19119 Mdot
.927 .004 .008 r
.5 Mabswid
.85613 .14687 m
.85359 .19128 L
s
0 0 0 r
2 Mabswid
.85359 .19128 Mdot
.927 .004 .008 r
.5 Mabswid
.85845 .14936 m
.85606 .19136 L
s
0 0 0 r
2 Mabswid
.85606 .19136 Mdot
.844 .001 .007 r
.5 Mabswid
.85193 .14237 m
.84909 .19112 L
s
0 0 0 r
2 Mabswid
.84909 .19112 Mdot
.844 .001 .007 r
.5 Mabswid
.85426 .14487 m
.85156 .19121 L
s
0 0 0 r
2 Mabswid
.85156 .19121 Mdot
.844 .001 .007 r
.5 Mabswid
.85659 .14737 m
.85403 .19129 L
s
0 0 0 r
2 Mabswid
.85403 .19129 Mdot
.001 .037 .937 r
.5 Mabswid
.89271 .1861 m
.8925 .19264 L
s
0 0 0 r
2 Mabswid
.8925 .19264 Mdot
.001 .037 .937 r
.5 Mabswid
.89495 .1885 m
.89482 .19272 L
s
0 0 0 r
2 Mabswid
.89482 .19272 Mdot
.001 .037 .937 r
.5 Mabswid
.89719 .1909 m
.89713 .1928 L
s
0 0 0 r
2 Mabswid
.89713 .1928 Mdot
.927 .004 .008 r
.5 Mabswid
.85113 .19119 m
.81648 .69728 L
s
% Start of user PostScript
304.039 -135.988 291.308 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.81648 .69728 Mdot
.927 .004 .008 r
.5 Mabswid
.85359 .19128 m
.81895 .69728 L
s
% Start of user PostScript
304.945 -135.956 292.216 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.81895 .69728 Mdot
.927 .004 .008 r
.5 Mabswid
.85606 .19136 m
.82143 .69728 L
s
% Start of user PostScript
305.851 -135.924 293.124 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.82143 .69728 Mdot
.844 .001 .007 r
.5 Mabswid
.84909 .19112 m
.81348 .69728 L
s
% Start of user PostScript
303.29 -136.014 290.205 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.81348 .69728 Mdot
.844 .001 .007 r
.5 Mabswid
.85156 .19121 m
.81596 .69728 L
s
% Start of user PostScript
304.198 -135.982 291.116 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.81596 .69728 Mdot
.844 .001 .007 r
.5 Mabswid
.85403 .19129 m
.81844 .69728 L
s
% Start of user PostScript
305.107 -135.95 292.027 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.81844 .69728 Mdot
.001 .037 .937 r
.5 Mabswid
.8925 .19264 m
.8773 .69728 L
s
% Start of user PostScript
319.245 -135.457 313.656 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.8773 .69728 Mdot
.001 .037 .937 r
.5 Mabswid
.89482 .19272 m
.87961 .69728 L
s
% Start of user PostScript
320.095 -135.427 314.507 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.87961 .69728 Mdot
.001 .037 .937 r
.5 Mabswid
.89713 .1928 m
.88193 .69728 L
s
% Start of user PostScript
320.945 -135.397 315.358 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.88193 .69728 Mdot
[(Prism2)] .8264 .06711 0 0 Mshowa
[(Pellin-Broca Prism)] .1333 .52597 0 0 Mshowa
[(Prism1)] .09837 .19447 0 0 Mshowa
0 0 m
1 0 L
1 .71429 L
0 .71429 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600.625, 429.062},
  ImageMargins->{{43, 0}, {0, 3}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0001[B000`400?l00000o`00003ooooooooo
oooooe[ooooo003oooooooooooooF_ooool00?oooooooooooomJooooo`00oooooooooooooe[ooooo
003oooooooooooooF_ooool00?oooooooooooomJooooo`00oooooooooooooe[ooooo003ooooooooo
ooooF_ooool00?oooooooooooomJooooo`00oooooooooooooe[ooooo000>ooooo`03o`000?oooooo
oooo0?ooooooooooooljooooo`03o`000?oooooooooo00cooooo000>oooooooo0000ool0000no`00
00kooooo000>ooooo`03o`000?oooooooooo0?ooooooooooooljooooo`03o`000?oooooooooo00co
oooo000>ooooo`03o`000?oooooooooo0?ooooooooooooljooooo`03o`000?oooooooooo00cooooo
000>ooooo`03o`000?oooooooooo0?ooooooooooooljooooo`03o`000?oooooooooo00cooooo000>
ooooo`03o`000?oooooooooo0?ooooooooooooljooooo`03o`000?oooooooooo00cooooo000>oooo
o`03o`000?oooooooooo0?ooooooooooooljooooo`03o`000?oooooooooo00cooooo000>ooooo`03
o`000?oooooooooo0?ooooooooooooljooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`00
0?oooooooooo0?ooooooooooooljooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oo
oooooooo0?ooooooooooooljooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooo
oooo0?ooooooooooooljooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo
0?ooooooooooooljooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo0?oo
ooooooooooljooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo0?oooooo
ooooooljooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo0?oooooooooo
ooljooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo0?oooooooooooolj
ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo0?ooooooooooooljoooo
o`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo0?ooooooooooooljooooo`03
o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo0?ooooooooooooljooooo`03o`00
0?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo0?ooooooooooooljooooo`03o`000?oo
oooooooo00cooooo000>ooooo`03o`000?oooooooooo0?ooooooooooooljooooo`03o`000?oooooo
oooo00cooooo000>ooooo`03o`000?oooooooooo0?ooooooooooooljooooo`03o`000?oooooooooo
00cooooo000>ooooo`03o`000?oooooooooo0?ooooooooooooljooooo`03o`000?oooooooooo00co
oooo000>ooooo`03o`000?oooooooooo0?ooooooooooooljooooo`03o`000?oooooooooo00cooooo
000>ooooo`03o`000?oooooooooo0?ooooooooooooljooooo`03o`000?oooooooooo00cooooo000>
ooooo`03o`000?oooooooooo0?ooooooooooooljooooo`03o`000?oooooooooo00cooooo000>oooo
o`03o`000?oooooooooo0?ooooooooooooljooooo`03o`000?oooooooooo00cooooo000>ooooo`03
o`000?oooooooooo0?ooooooooooooljooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`00
0?oooooooooo0?oooooodOooool3o`0000Cooooo2?l00002ooooo`04o`000?oooooo0000ooooo`Go
0000C_ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3oooooom;ooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool00004ooooo`09o`000?oooooo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`0<ooooo`003_ooool00ol0003oooooooooo`3oooooom;ooooo0ol00003ooooo`04o`000?oooooo
ooooo`0000;ooooo0_l00002ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo0?ooooood_oo
ool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool01Ol0
003oooooo`000?oooooo000000;ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0<
ooooo`003_ooool00ol0003oooooooooo`3oooooom;ooooo00Go0000oooooooooooo0000ooooo`05
o`0000;ooooo2?l00004ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool03?ooool0
00kooooo00?o0000ooooooooool0oooooooBooooo`04o`000?ooooooooooo`0001;ooooo00?o0000
ooooool00000C_ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3ooooo
om7ooooo1?l00006ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3ooooooooooooo>_ooool00ol0003o
ooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3ooooooooooooo>_ooool00ol0003ooooo
ooooo`0<ooooo`003_ooool00ol0003oooooooooo`3ooooooooooooo>_ooool00ol0003ooooooooo
o`0<ooooo`003_ooool00ol0003oooooooooo`3ooooooooooooo>_ooool00ol0003oooooooooo`0<
ooooo`003_ooool00ol0003oooooooooo`3ooooooooooooo>_ooool00ol0003oooooooooo`0<oooo
o`003_ooool00ol0003oooooooooo`3ooooooooooooo>_ooool00ol0003oooooooooo`0<ooooo`00
3_ooool00ol0003oooooooooo`3ooooooooooooo>_ooool00ol0003oooooooooo`0<ooooo`003_oo
ool00ol0003oooooooooo`3ooooooooooooo>_ooool00ol0003oooooooooo`0<ooooo`003_ooool0
0ol0003oooooooooo`3ooooooooooooo>_ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0
003oooooooooo`3ooooooooooooo>_ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003o
ooooooooo`3ooooooooooooo>_ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003ooooo
ooooo`3ooooooooooooo>_ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003ooooooooo
o`3ooooooooooooo>_ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3o
oooooooooooo>_ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3ooooo
oooooooo>_ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3ooooooooo
oooo>_ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3ooooooooooooo
>_ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3ooooooooooooo>_oo
ool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3ooooooooooooo>_ooool0
0ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3ooooooooooooo>_ooool00ol0
003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3ooooooooooooo>_ooool00ol0003o
ooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3ooooooooooooo>_ooool00ol0003ooooo
ooooo`0<ooooo`003_ooool00ol0003oooooooooo`3ooooooooooooo>_ooool00ol0003ooooooooo
o`0<ooooo`003_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo0?ooooooJOooool0
0ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool0oooooomYooooo`03o`000?oooooooooo05Sooooo00?o0000oooo
ooooool03?ooool000kooooo00?o0000ooooooooool0LOooool2o`000?ooooooJoooool2o`0005Wo
oooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0L?ooool00ol0003ooooo
o`00003oooooof_ooooo00?o0000ooooool00000F?ooool00ol0003oooooooooo`0<ooooo`003_oo
ool00ol0003oooooooooo`1_ooooo`04o`000?ooooooooooo`000?ooooooJoooool01?l0003ooooo
ooooool0001Gooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06kooooo
00Go0000ooooooooooooooooo`00003oooooof_ooooo00Go0000ooooooooooooooooo`00001Foooo
o`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`3oooooofWooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooofWooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oo
oooooooo06_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooofWooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00cooooo000>
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooofWooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooo
oooo00cooooo000>ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3oooooofWooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3oooooofWooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`3oooooofSooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oo
oooooooo06Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3oooooofSooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00cooooo000>
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3o
ooooofSooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo00cooooo000>ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`3oooooofSooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06?ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`3oooooof3ooooo0ooH0045ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003ooooo
ooooo`1Qooooo`?o00003_ooool2o`000?ooooooHOooool7omP00@03ooooool0003o000000kooooo
0ol00019ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo063ooooo00?o
0000omP00OoH0040oooH006<omP00@;o0000B?ooool00ol0003oooooooooo`0<ooooo`003_ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oH007of0010?oof001SOoH00400oo]0@;of001ooooo`17
ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo05kooooo0_l0003oond1
0WGok@421ooH004Bond10P05omP00Oo]0@;of001ond10_l00000A_ooool00ol0003oooooooooo`0<
ooooo`003_ooool00ol0003oooooooooo`1Nooooo`03ond10_oH007of0010?oof001S_oH00400oo]
0@;of001omP00@02o`0004Gooooo00?o0000ooooooooool03?ooool000kooooo00?o0000oooooooo
ool0G_ooool01?l0003of001omP00OoH004@ooooo`;o0000]?oooon]ond10PGof0014oo]0@801_oH
007ok@42omP00OoH007ok@42o`0004Gooooo00?o0000ooooooooool03?ooool000kooooo00?o0000
ooooooooool0GOooool00ol0003ok@42omP00@02omP00A3ooooo00?o0000ooooooooool0oooooomP
ooooo`;of0011?o]0@82ooooo`03o`000?oooooooooo00kooooo00Kof001ond10_oH007of001ond1
0_l00015ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooo]0@800ooH004Aooooo`03o`000?oooooooooo0?ooooooGoooool2ond10PKooooo00?o
0000ooooooooool03_ooool01ooH007ok@42omP00OoH007ok@42ooooool00000A?ooool00ol0003o
ooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Kooooo`04o`000?ooooooooooond10P?o
f0014Oooool00ol0003oooooooooo`3oooooofOooooo00?o0000ooooooooool03_ooool01ooH007o
k@42omP00OoH007ok@42ooooool00000A?ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0
003oooooooooo`1Jooooo`05o`000?ooooooooooooooooo]0@800_oH00400ooooooof001ooooo`0?
ooooo`03o`000?oooooooooo0?ooooooIoooool00ol0003oooooooooo`0>ooooo`05omP00Oo]0@;o
f001omP00Oo]0@800_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00cooooo000>
ooooo`03o`000?oooooooooo05Sooooo0_l00004ooooo`03ond10_oH007ok@4200;of0014?ooool0
0ol0003oooooooooo`3oooooofOooooo00?o0000ooooooooool03_ooool2omP00@03oooooooH007o
k@4200?ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0
003oooooooooo`1Hoooooa[o00W_00?o0000o`09kol02Nl03?l02Noooooooecooooo00?o0000oooo
ooooool03_ooool3omP00@03ooooooo]0@;ooooo00?ooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Fooooo`03o`000?l02Noo00W_01Wo
00W_00?o0000o`09kol02Nl02ol02Nl00ooooooo00W_o`09k`0Ho`09kooooooo@_ooool00ol0003o
ooooooooo`0>ooooo`?of00100?oooooond10_ooool01?ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo05Gooooo00?o0000o`09kol02Nl0
3_l02Nl<ooooo`;o00003?oooolHo`09k`?ooooo6Ol02NooooooobWooooo00?o0000ooooooooool0
3_ooool3omP00@03ooooooo]0@;ooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Eooooo`;o00000_l02Nl6ooooo`04omP00Oo]
0@;of001omP00@?ooooo3?l02Nl00ol0003o00W_o`09k`0<o`09kaOooooo6?l02Nl4oooooa[o00W_
ooooool?ooooo`03o`000?oooooooooo00kooooo0ooH00400oooooook@42ooooo`06ooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0E?oo
ool00ol0003oooooo`09k`02o`09k`Kooooo00Cof001ond10_oH007of0014?ooool00ol0003ooooo
ooooo`0;oooooa[o00W_5OoooolHo`09k`Kooooo6_l02Nodooooo`03o`000?oooooooooo00kooooo
0ooH00400oooooook@42ooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
3?ooool000kooooo00?o0000ooooooooool0E?ooool00ol0003oooooo`09k`02o`09k`Kooooo00Co
f001ond10_oH007of0014?ooool00ol0003oooooooooo`0UoooooaWo00W_5?oooolHo`09k`Sooooo
6Ol02NoKooooo`03o`000?oooooooooo00gooooo00Kof001oooooooH007of001ooooooo]0@89oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool03?ooool000kooooo00?o0000oooooooo
ool0Doooool01Ol0003oooooooooool02Noooooo00;o00W_1Oooool01?oH007oooooomP00OoH004@
ooooo`03o`000?oooooooooo03kooooo6_l02NlBoooooaSo00W_2OoooolJo`09kl7ooooo00?o0000
ooooooooool03Oooool01_oH007ok@42omP00OoH007oooooond10P[ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Booooo`06o`000?oo
ooooooooooooool02Noooooo0_l02Nl5ooooo`04ond10_oH007of001omP00A3ooooo00?o0000oooo
ooooool0F?oooolJo`09ka3ooooo6?l02Nl;oooooa[o00W_Y_ooool00ol0003oooooooooo`0>oooo
o`05omP00Oo]0@;of001omP00Oo]0@803?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo00cooooo000>ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool00_ooool01?l0
2Nooooooo`09kol02Nl5ooooo`04ond10_oH007of001omP00A3ooooo00?o0000ooooooooool0L_oo
oolIo`09k`oooooo6?l02Nl=oooooa[o00W_S?ooool00ol0003oooooooooo`0>ooooo`05omP00Oo]
0@;of001omP00Oo]0@803Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00cooooo
000>ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool00oooool01?l02Nooooooo`09
kol02Nl5ooooo`04ond10_oH007of001omP00A3ooooo00?o0000ooooooooool0RooooolJo`09k`go
oooo6?l02Nl?oooooaWo00W_Loooool00ol0003oooooooooo`0>ooooo`05omP00Oo]0@;of001omP0
0Oo]0@803Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00cooooo000>ooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool01?ooool01?l02Nooooooo`09kol02Nl5oooo
o`04ond10_oH007of001omP00A3ooooo00?o0000ooooooooool0YOoooolJo`09k`_ooooo6?l02Nl@
oooooa[o00W_FOooool00ol0003oooooooooo`0>ooooo`05omP00Oo]0@;of001omP00Oo]0@803_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool01_ooool3o`09k`Gooooo00Cok@42omP00OoH007of0014?oo
ool00ol0003oooooooooo`2ooooooa[o00W_2OoooolHo`09ka;ooooo6_l02Nloooooo`03o`000?oo
oooooooo00kooooo00Gof001ond10_oH007of001ond10P0?ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`07ooooo`?o00W_1Oooool01?o]0@;of001omP00OoH004@ooooo`03o`000?oooooooooo0=Wooooo
6Ol02Nl8oooooaSo00W_5?oooolIo`09kaoooooo0ol02Nl4ooooo`03o`000?oooooooooo00kooooo
00Gof001ond10_oH007of001ond10P0@ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool03?ooool000kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`08ooooo`?o00W_
1_ooool01?oH007ok@42omP00OoH004?ooooo`03o`000?oooooooooo0?;ooooo6_l02Nl6oooooaSo
00W_5OoooolJo`09k`Cooooo1ol02Nl00ooooooo0000ooooo`0?ooooo`?of00100?oooooond10_oo
ool04?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool02Oooool3o`09k`Kooooo00Cof001ond10_oH007o
f0013oooool00ol0003oooooooooo`3oooooo`gooooo6_l02Nl4oooooaSo00W_5ooooolHo`09k`Go
oooo0ooH00400oooooook@42ooooo`0<ooooo`?o00W_0_ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
2_ooool01?l02Nooooooo`09kol02Nl5ooooo`04omP00Oo]0@;of001omP00@oooooo00?o0000oooo
ooooool0oooooolWoooooaWo00W_0ooooolHo`09k`?ooooo2?l02Nl2o`0000[ooooo1Ol02Nl3omP0
0@03o`09koo]0@;o00W_00[o00W_0oooool6o`09k`;o0000<Oooool00ol0003oooooooooo`0<oooo
o`003_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00_ooooo00Co00W_ooooool0
2Noo00W_1Oooool01?oH007ok@42omP00OoH004?ooooo`03o`000?oooooooooo0?oooooo@?oooolJ
o`09k`03ooooool02Noo00W_01[o00W_0ooH00400ol02Nook@42o`09k`0:ooooo`_o00W_<Oooool0
0ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
00cooooo00Co00W_ooooool02Noo00W_1Oooool01?oH007ok@42omP00OoH004?ooooo`03o`000?oo
oooooooo0?ooooooF_oooolHo`09k`Gooooo0ooH00400oooooook@42ooooo`0Fo`09kc3ooooo00?o
0000ooooooooool03?ooool000kooooo00?o0000ooooooooool07?ooool3o`0000Cooooo2?l00002
ooooo`04o`000?oooooo0000ooooo`;o000000Coooooo`000?l0003o00004?ooool00ol0003ooooo
ooooo`0=ooooo`04o`09kooooooo00W_o`09k`Gooooo00Gof001ond10_oH007of001o`000003oooo
o`go0000oooooomPooooo`Go00W_0_ooool<o`0000Co00W_0_l00002omP00@03o`09koo]0@;o00W_
01Ko00W_0_l0000^ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00004ooooo`07o`000?oooooo0000
ooooool0003oooooo`000003ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?oo
ool6o`000004o`09kol0003o00W_o`09k`Go000000Cof001ond10_oH007of0011?l0003oooooofco
oooo0_l02NlCooooo`Co00000ooH00400ol0003ok@42o`00000<o`0000Oo00W_1Ol0000^ooooo`03
o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo01gooooo0ol00003ooooo`04o`00
0?ooooooooooo`0000;ooooo0_l00002ooooo`05o`000?oooooo0000ooooool000000oooool00ol0
003oooooooooo`0=ooooo`co00001_ooool4o`0000Cooooo1?l000000ooH007oooooooooo`3ooooo
ohOooooo0ooH00400ol0003ok@42ooooo`0=ooooo`;o00001?l02Nl01?l0003o00W_o`09kol02Nl2
o`0002gooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool07Oooool01?l0
003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool01Ol0003ooooo
o`000?oooooo000000?ooooo00?o0000ooooooooool07oooool5o`09k`Cooooo1OoH007oooooohSo
oooo0ooH00400oooooook@42ooooo`0>ooooo`;o00W_1?ooool3o`09kboooooo00?o0000oooooooo
ool03?ooool000kooooo00?o0000ooooooooool07Oooool01Ol0003oooooooooool0003ooooo00Go
00000_ooool8o`0000Cooooo00?o0000ooooooooool07oooool5o`09k`?ooooo00?ok@42omP00OoH
00400ooH007oooooohSooooo0ooH00400oooooook@42ooooo`0Dooooo`?o00W_;oooool00ol0003o
ooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0001Co
oooo00?o0000ooooooooool07oooool5o`09k`?ooooo00?ok@42omP00OoH00400ooH007oooooohSo
oooo0ooH00400oooooook@42ooooo`0Dooooo`?o00W_;oooool00ol0003oooooooooo`0<ooooo`00
3_ooool00ol0003oooooooooo`0Looooo`Co00001_ooool00ol0003oooooooooo`0;ooooo`;o0000
8?ooool7o`09k`;ooooo1ooH007oooooohOooooo0ooH00400oooooook@42ooooo`0Dooooo`?o00W_
;oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Fooooo`Oo00W_0_oo
ool7omP00OooooooQoooool3omP00@03ooooooo]0@;ooooo01Cooooo0ol02Nl_ooooo`03o`000?oo
oooooooo00cooooo000>ooooo`03o`000?oooooooooo05Kooooo1ol02Nl00oooooook@42omP00@06
omP00OooooooQoooool3omP00@03ooooooo]0@;ooooo01Cooooo0ol02Nl_ooooo`03o`000?oooooo
oooo00cooooo000>ooooo`03o`000?oooooooooo05Kooooo1_l02Nl00ooooooo00W_ond10P06omP0
0@03ond10_oH007ooooo0?ooooooQ?ooool3omP00@03ooooooo]0@;ooooo01Gooooo0ol02Nl_oooo
o`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo05Kooooo0ol02Nl00ooooooo
00W_o`09k`05ooooo`04omP00Oo]0@;of001omP00OooooooQoooool3omP00@03ooooooo]0@;ooooo
01Gooooo0ol02Nl_ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo05So
oooo00Co00W_ooooool02Noo00W_1Oooool01?oH007ok@42omP00OoH007oooooohOooooo0ooH0040
0oooooook@42ooooo`0Eooooo`?o00W_;oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0
003oooooooooo`1Hooooo`04o`09kooooooo00W_o`09k`Gooooo00Cof001ond10_oH007of001oooo
oon7ooooo`?of00100?oooooond10_ooool05Oooool3o`09kboooooo00?o0000ooooooooool03?oo
ool000kooooo00?o0000ooooooooool0F?ooool01?l02Nooooooo`09kol02Nl5ooooo`04omP00Oo]
0@;of001omP00OooooooQoooool3omP00@03ooooooo]0@;ooooo01Gooooo0ol02Nl_ooooo`03o`00
0?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo05Sooooo00Co00W_ooooool02Noo00W_
1Oooool01?oH007ok@42omP00OoH007oooooohOooooo0ooH00400oooooook@42ooooo`0Eooooo`?o
00W_;oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Iooooo`?o00W_
1Oooool01?oH007ok@42omP00OoH007oooooohOooooo0ooH00400oooooook@42ooooo`0Eooooo`?o
00W_;oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Iooooo`04o`09
kooooooo00W_o`09k`Cooooo00Cof001ond10_oH007of001oooooon7ooooo`?of00100?oooooond1
0_ooool05Oooool3o`09kboooooo00?o0000ooooooooool03?ooool000kooooo00?o0000oooooooo
ool0FOooool01?l02Nooooooo`09kol02Nl4ooooo`04omP00Oo]0@;of001omP00OooooooQoooool3
omP00@03ooooooo]0@;ooooo01Gooooo0ol02Nl_ooooo`03o`000?oooooooooo00cooooo000>oooo
o`03o`000?oooooooooo05Wooooo00Co00W_ooooool02Noo00W_1?ooool01?oH007ok@42omP00OoH
007oooooohOooooo0ooH00400oooooook@42ooooo`0Dooooo`04o`09kooooooo00W_o`09kboooooo
00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0FOooool01?l02Nooooooo`09
kol02Nl4ooooo`04omP00Oo]0@;of001omP00OooooooQoooool3omP00@03ooooooo]0@;ooooo01Co
oooo00Co00W_ooooool02Noo00W_;oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003o
ooooooooo`1Iooooo`04o`09kooooooo00W_o`09k`Cooooo00Cof001ond10_oH007of001oooooon7
ooooo`?of00100?oooooond10_ooool05?ooool3o`09kc3ooooo00?o0000ooooooooool03?ooool0
00kooooo00?o0000ooooooooool0FOooool01?l02Nooooooo`09kol02Nl4ooooo`04omP00Oo]0@;o
f001omP00OooooooQoooool3omP00@03ooooooo]0@;ooooo01Cooooo0ol02Nl`ooooo`03o`000?oo
oooooooo00cooooo000>ooooo`03o`000?oooooooooo05Wooooo00Co00W_ooooool02Noo00W_1?oo
ool01?oH007oooooomP00OoH007oooooohOooooo0ooH00400oooooook@42ooooo`0Dooooo`?o00W_
<?ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Iooooo`04o`09kooo
oooo00W_o`09k`Gooooo0ooH007oooooohKooooo00Kof001oooooooH007of001ooooooo]0@8Eoooo
o`?o00W_<?ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Jooooo`?o
00W_1Oooool01?oH007ok@42omP00OoH007oooooohGooooo0ooH00400oooooook@42ooooo`0Eoooo
o`?o00W_<?ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Jooooo`;o
00W_00?oooooo`09koooool00oooool01?oH007ok@42omP00OoH007oooooohGooooo0ooH00400ooo
ooook@42ooooo`0Eooooo`?o00W_<?ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003o
ooooooooo`1Jooooo`04o`09kooooooo00W_o`09k`Cooooo00Cof001ond10_oH007of001oooooon5
ooooo`?of00100?oooooond10_ooool05Oooool3o`09kc3ooooo00?o0000ooooooooool03?ooool0
00kooooo00?o0000ooooooooool0F_ooool01?l02Nooooooo`09kol02Nl4ooooo`04omP00Oo]0@;o
f001omP00OooooooQOooool3omP00@03ooooooo]0@;ooooo01Gooooo0ol02Nl`ooooo`03o`000?oo
oooooooo00cooooo000>ooooo`03o`000?oooooooooo05[ooooo00Co00W_ooooool02Noo00W_1?oo
ool01?oH007ok@42omP00OoH007oooooohGooooo0ooH00400oooooook@42ooooo`0Eooooo`?o00W_
<?ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Jooooo`04o`09kooo
oooo00W_o`09k`Cooooo00Cof001ond10_oH007of001oooooon5ooooo`?of00100?oooooond10_oo
ool05Oooool3o`09kc3ooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0
F_ooool01?l02Nooooooo`09kol02Nl4ooooo`04omP00Oo]0@;of001omP00OooooooQOooool3omP0
0@03ooooooo]0@;ooooo01Gooooo0ol02Nl`ooooo`03o`000?oooooooooo00cooooo000>ooooo`03
o`000?oooooooooo05[ooooo00Co00W_ooooool02Noo00W_1?ooool01?oH007ok@42omP00OoH007o
ooooohGooooo0ooH00400oooooook@42ooooo`0Eooooo`?o00W_<?ooool00ol0003oooooooooo`0<
ooooo`003_ooool00ol0003oooooooooo`1Jooooo`04o`09kooooooo00W_o`09k`Cooooo00Cof001
ond10_oH007of001oooooon5ooooo`?of00100?oooooond10_ooool05Oooool3o`09kc3ooooo00?o
0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0Foooool3o`09k`Cooooo00Cof001
ond10_oH007of001oooooon5ooooo`?of00100?oooooond10_ooool05Oooool3o`09kc3ooooo00?o
0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0Foooool2o`09k`03ooooool02Noo
oooo00;ooooo00Cof001ond10_oH007of001oooooon5ooooo`?of00100?oooooond10_ooool05Ooo
ool3o`09kc3ooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0Foooool0
1?l02Nooooooo`09kol02Nl3ooooo`04omP00Oo]0@;of001omP00OooooooQOooool3omP00@03oooo
ooo]0@;ooooo01Gooooo0ol02Nl`ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oo
oooooooo05_ooooo00Co00W_ooooool02Noo00W_0oooool01?oH007oooooomP00OoH007oooooohCo
oooo00Kof001oooooooH007of001ooooooo]0@8Fooooo`?o00W_<?ooool00ol0003oooooooooo`0<
ooooo`003_ooool00ol0003oooooooooo`1Kooooo`04o`09kooooooo00W_o`09k`?ooooo00Cof001
oooooooH007of001oooooon4ooooo`06omP00Ooooooof001omP00Oooooook@425_ooool3o`09kc3o
oooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0Foooool01?l02Noooooo
o`09kol02Nl4ooooo`03omP00Oo]0@;of0010?ooooooQ?ooool3omP00@03ooooooo]0@;ooooo01Ko
oooo0ol02Nl`ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo05_ooooo
00Co00W_ooooool02Noo00W_1?ooool01?oH007ok@42omP00OoH007ooooooh?ooooo0ooH00400ooo
ooook@42ooooo`0Fooooo`?o00W_<?ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003o
ooooooooo`1Kooooo`04o`09kooooooo00W_o`09k`Cooooo00Cof001ond10_oH007of001oooooon3
ooooo`?of00100?oooooond10_ooool05_ooool3o`09kc3ooooo00?o0000ooooooooool03?ooool0
00kooooo00?o0000ooooooooool0Foooool01?l02Nooooooo`09kol02Nl4ooooo`04omP00Oo]0@;o
f001omP00OooooooPoooool3omP00@03ooooooo]0@;ooooo01Kooooo0ol02Nl`ooooo`03o`000?oo
oooooooo00cooooo000>ooooo`03o`000?oooooooooo05cooooo0ol02Nl4ooooo`04omP00Oo]0@;o
f001omP00OooooooPoooool3omP00@03ooooooo]0@;ooooo01Kooooo0ol02Nl`ooooo`03o`000?oo
oooooooo00cooooo000>ooooo`03o`000?oooooooooo05cooooo0_l02Nl00ooooooo00W_ooooo`02
ooooo`04omP00Oo]0@;of001omP00OooooooPoooool3omP00@03ooooooo]0@;ooooo01Kooooo0ol0
2Nl`ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo05cooooo00Co00W_
ooooool02Noo00W_0oooool01?oH007ok@42omP00OoH007ooooooh?ooooo0ooH00400oooooook@42
ooooo`0Fooooo`?o00W_<?ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003ooooooooo
o`1Looooo`04o`09kooooooo00W_o`09k`?ooooo00Cof001ond10_oH007of001oooooon3ooooo`?o
f00100?oooooond10_ooool05_ooool3o`09kc3ooooo00?o0000ooooooooool03?ooool000kooooo
00?o0000ooooooooool0G?ooool01?l02Nooooooo`09kol02Nl3ooooo`04omP00Oo]0@;of001omP0
0OooooooPoooool3omP00@03ooooooo]0@;ooooo01Kooooo0ol02Nl`ooooo`03o`000?oooooooooo
00cooooo000>ooooo`03o`000?oooooooooo05cooooo00Co00W_ooooool02Noo00W_0oooool01?oH
007ok@42omP00OoH007ooooooh?ooooo0ooH00400oooooook@42ooooo`0Fooooo`?o00W_<?ooool0
0ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Looooo`04o`09kooooooo00W_
o`09k`?ooooo00Cof001ond10_oH007of001oooooon3ooooo`?of00100?oooooond10_ooool05Ooo
ool01?l02Nooooooo`09kol02Nl`ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oo
oooooooo05cooooo00Co00W_ooooool02Noo00W_0oooool01?oH007ok@42omP00OoH007ooooooh?o
oooo0ooH00400oooooook@42ooooo`0Eooooo`04o`09kooooooo00W_o`09kc3ooooo00?o0000oooo
ooooool03?ooool000kooooo00?o0000ooooooooool0G?ooool01?l02Nooooooo`09kol02Nl3oooo
o`04omP00Ooooooof001omP00OooooooP_ooool01_oH007oooooomP00OoH007oooooond10QKooooo
00Co00W_ooooool02Noo00W_<?ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003ooooo
ooooo`1Mooooo`?o00W_0oooool01?oH007oooooomP00OoH007ooooooh;ooooo00Kof001oooooooH
007of001ooooooo]0@8Fooooo`04o`09kooooooo00W_o`09kc3ooooo00?o0000ooooooooool03?oo
ool000kooooo00?o0000ooooooooool0GOooool2o`09k`03ooooool02Noooooo00;ooooo0ooH007o
oooooh;ooooo0ooH00400oooooook@42ooooo`0Fooooo`04o`09kooooooo00W_o`09kc3ooooo00?o
0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0GOooool2o`09k`03ooooool02Noo
oooo00;ooooo00Cof001ond10_oH007ok@42oooooon1ooooo`?of00100?oooooond10_ooool05_oo
ool3o`09kc7ooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0GOooool0
1?l02Nooooooo`09kol02Nl3ooooo`04omP00Oo]0@;of001omP00OooooooPOooool3omP00@03oooo
ooo]0@;ooooo01Kooooo0ol02Nlaooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oo
oooooooo05gooooo00Co00W_ooooool02Noo00W_0oooool01?oH007ok@42omP00OoH007ooooooh7o
oooo0ooH00400oooooook@42ooooo`0Fooooo`?o00W_<Oooool00ol0003oooooooooo`0<ooooo`00
3_ooool00ol0003oooooooooo`1Mooooo`04o`09kooooooo00W_o`09k`?ooooo00Cof001ond10_oH
007of001oooooon1ooooo`?of00100?oooooond10_ooool05_ooool3o`09kc7ooooo00?o0000oooo
ooooool03?ooool000kooooo00?o0000ooooooooool0GOooool01?l02Nooooooo`09kol02Nl3oooo
o`04omP00Oo]0@;of001omP00OooooooPOooool3omP00@03ooooooo]0@;ooooo01Kooooo0ol02Nla
ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo05gooooo00Co00W_oooo
ool02Noo00W_0oooool01?oH007ok@42omP00OoH007ooooooh7ooooo0ooH00400oooooook@42oooo
o`0Fooooo`?o00W_<Oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1M
ooooo`04o`09kooooooo00W_o`09k`?ooooo00Cof001ond10_oH007of001oooooon1ooooo`?of001
00?oooooond10_ooool05_ooool3o`09kc7ooooo00?o0000ooooooooool03?ooool000kooooo00?o
0000ooooooooool0G_ooool3o`09k`?ooooo00Cof001ond10_oH007of001oooooon1ooooo`?of001
00?oooooond10_ooool05_ooool3o`09kc7ooooo00?o0000ooooooooool03?ooool000kooooo00?o
0000ooooooooool0G_ooool3o`09k`?ooooo00Cof001ond10_oH007of001oooooon1ooooo`?of001
00?oooooond10_ooool05_ooool3o`09kc7ooooo00?o0000ooooooooool03?ooool000kooooo00?o
0000ooooooooool0G_ooool2o`09k`06ooooool02NoooooooooooooH007ok@420_oH007ooooooh7o
oooo0ooH00400oooooook@42ooooo`0Fooooo`?o00W_<Oooool00ol0003oooooooooo`0<ooooo`00
3_ooool00ol0003oooooooooo`1Nooooo`04o`09kooooooo00W_o`09k`;ooooo00Cof001oooooooH
007of001oooooon1ooooo`?of00100?oooooond10_ooool05_ooool3o`09kc7ooooo00?o0000oooo
ooooool03?ooool000kooooo00?o0000ooooooooool0G_ooool01?l02Nooooooo`09kol02Nl2oooo
o`04omP00Ooooooof001omP00OooooooP?ooool01_oH007oooooomP00OoH007oooooond10QOooooo
0ol02Nlaooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo05kooooo00Co
00W_ooooool02Noo00W_0_ooool01?oH007oooooomP00OoH007ooooooh3ooooo00Kof001oooooooH
007of001ooooooo]0@8Gooooo`?o00W_<Oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0
003oooooooooo`1Nooooo`04o`09kooooooo00W_o`09k`?ooooo0ooH007ooooooh3ooooo00Kof001
oooooooH007of001ooooooo]0@8Gooooo`?o00W_<Oooool00ol0003oooooooooo`0<ooooo`003_oo
ool00ol0003oooooooooo`1Nooooo`04o`09kooooooo00W_o`09k`?ooooo00?of001ond10_oH0040
oooooon0ooooo`?of00100?oooooond10_ooool05oooool3o`09kc7ooooo00?o0000ooooooooool0
3?ooool000kooooo00?o0000ooooooooool0G_ooool01?l02Nooooooo`09kol02Nl3ooooo`04omP0
0Oo]0@;of001omP00OooooooOoooool3omP00@03ooooooo]0@;ooooo01Oooooo0ol02Nlaooooo`03
o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo05oooooo0ol02Nl3ooooo`04omP0
0Oo]0@;of001omP00OooooooOoooool3omP00@03ooooooo]0@;ooooo01Oooooo0ol02Nlaooooo`03
o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo05oooooo0ol02Nl3ooooo`04omP0
0Oo]0@;of001omP00OooooooOoooool3omP00@03ooooooo]0@;ooooo01Oooooo0ol02Nlaooooo`03
o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo05oooooo0_l02Nl01_oooooo00W_
oooooooooooof001ond10P;of001oooooomoooooo`?of00100?oooooond10_ooool05oooool3o`09
kc7ooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0Goooool2o`09k`06
ooooool02NoooooooooooooH007ok@420_oH007oooooogoooooo0ooH00400oooooook@42ooooo`0G
ooooo`?o00W_<Oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Ooooo
o`04o`09kooooooo00W_o`09k`;ooooo00Cof001ond10_oH007of001oooooomoooooo`?of00100?o
ooooond10_ooool05oooool3o`09kc7ooooo00?o0000ooooooooool03?ooool000kooooo00?o0000
ooooooooool0Goooool01?l02Nooooooo`09kol02Nl2ooooo`04omP00Oo]0@;of001omP00Ooooooo
Ooooool3omP00@03ooooooo]0@;ooooo01Oooooo0ol02Nlaooooo`03o`000?oooooooooo00cooooo
000>ooooo`03o`000?oooooooooo05oooooo00Co00W_ooooool02Noo00W_0_ooool01?oH007ok@42
omP00OoH007oooooogoooooo0ooH00400oooooook@42ooooo`0Gooooo`?o00W_<Oooool00ol0003o
ooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Oooooo`04o`09kooooooo00W_o`09k`;o
oooo00Cof001ond10_oH007of001oooooomoooooo`?of00100?oooooond10_ooool05oooool3o`09
kc7ooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0Goooool01?l02Noo
ooooo`09kol02Nl2ooooo`04omP00Ooooooof001omP00OooooooOoooool3omP00@03ooooooo]0@;o
oooo01Oooooo0ol02Nlaooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo
063ooooo0ol02Nl2ooooo`04omP00Ooooooof001omP00OooooooO_ooool01_oH007oooooomP00OoH
007oooooond10QOooooo00Co00W_ooooool02Noo00W_<Oooool00ol0003oooooooooo`0<ooooo`00
3_ooool00ol0003oooooooooo`1Pooooo`?o00W_0_ooool01?oH007oooooomP00OoH007oooooogko
oooo00Kof001oooooooH007of001ooooooo]0@8Gooooo`04o`09kooooooo00W_o`09kc7ooooo00?o
0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0H?ooool2o`09k`05ooooool02Noo
ooooomP00Oooool00_oH007oooooogkooooo00Kof001oooooooH007of001ooooooo]0@8Gooooo`04
o`09kooooooo00W_o`09kc7ooooo00?o0000ooooooooool03?ooool000kooooo00?o0000oooooooo
ool0H?ooool2o`09k`04ooooool02Nooooooooooo`?of001oooooomnooooo`?of00100?oooooond1
0_ooool05oooool01?l02Nooooooo`09kol02Nlaooooo`03o`000?oooooooooo00cooooo000>oooo
o`03o`000?oooooooooo063ooooo00Co00W_ooooool02Noo00W_0_ooool00ooH007ok@42omP00@3o
ooooogkooooo0ooH00400oooooook@42ooooo`0Gooooo`04o`09kooooooo00W_o`09kc7ooooo00?o
0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0H?ooool01?l02Nooooooo`09kol0
2Nl2ooooo`04omP00Oo]0@;of001omP00OooooooOOooool3omP00@03ooooooo]0@;ooooo01Oooooo
00Co00W_ooooool02Noo00W_<Oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003ooooo
ooooo`1Pooooo`04o`09kooooooo00W_o`09k`;ooooo00Cof001ond10_oH007of001oooooommoooo
o`?of00100?oooooond10_ooool05oooool01?l02Nooooooo`09kol02Nlaooooo`03o`000?oooooo
oooo00cooooo000>ooooo`03o`000?oooooooooo063ooooo00Co00W_ooooool02Noo00W_0_ooool0
1?oH007ok@42omP00OoH007ooooooggooooo0ooH00400oooooook@42ooooo`0Gooooo`04o`09kooo
oooo00W_o`09kc7ooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0H?oo
ool01?l02Nooooooo`09kol02Nl2ooooo`04omP00Oo]0@;of001omP00OooooooOOooool3omP00@03
ooooooo]0@;ooooo01Oooooo00Co00W_ooooool02Noo00W_<Oooool00ol0003oooooooooo`0<oooo
o`003_ooool00ol0003oooooooooo`1Qooooo`?o00W_0_ooool01?oH007ok@42omP00OoH007ooooo
oggooooo0ooH00400oooooook@42ooooo`0Gooooo`?o00W_<_ooool00ol0003oooooooooo`0<oooo
o`003_ooool00ol0003oooooooooo`1Qooooo`?o00W_0_ooool01?oH007ok@42omP00OoH007ooooo
oggooooo0ooH00400oooooook@42ooooo`0Gooooo`?o00W_<_ooool00ol0003oooooooooo`0<oooo
o`003_ooool00ol0003oooooooooo`1Qooooo`;o00W_00Goooooo`09kooooooof001ond10P02omP0
0OooooooOOooool3omP00@03ooooooo]0@;ooooo01Oooooo0ol02Nlbooooo`03o`000?oooooooooo
00cooooo000>ooooo`03o`000?oooooooooo067ooooo0_l02Nl01Ooooooo00W_oooooooH007ok@42
00;of001oooooommooooo`?of00100?oooooond10_ooool05oooool3o`09kc;ooooo00?o0000oooo
ooooool03?ooool000kooooo00?o0000ooooooooool0HOooool2o`09k`05ooooool02NooooooomP0
0Oooool00_oH007ooooooggooooo0ooH00400oooooook@42ooooo`0Gooooo`?o00W_<_ooool00ol0
003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Qooooo`07o`09kooooooo00W_o`09
kooooooof001ooooo`02omP00OooooooO?ooool01_oH007oooooomP00OoH007oooooond10QSooooo
0ol02Nlbooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo067ooooo00Oo
00W_ooooool02Noo00W_oooooooH007ooooo00;of001oooooomlooooo`06omP00Ooooooof001omP0
0Oooooook@426?ooool3o`09kc;ooooo00?o0000ooooooooool03?ooool000kooooo00?o0000oooo
ooooool0HOooool01ol02Nooooooo`09kol02NooooooomP00Oooool00_oH007oooooogcooooo00Ko
f001oooooooH007of001ooooooo]0@8Hooooo`?o00W_<_ooool00ol0003oooooooooo`0<ooooo`00
3_ooool00ol0003oooooooooo`1Qooooo`04o`09kooooooo00W_o`09k`;ooooo0ooH007oooooogco
oooo00Kof001oooooooH007of001ooooooo]0@8Hooooo`?o00W_<_ooool00ol0003oooooooooo`0<
ooooo`003_ooool00ol0003oooooooooo`1Rooooo`?o00W_0_ooool00ooH007ok@42omP00@3ooooo
ogcooooo0ooH00400oooooook@42ooooo`0Hooooo`?o00W_<_ooool00ol0003oooooooooo`0<oooo
o`003_ooool00ol0003oooooooooo`1Rooooo`?o00W_0_ooool01?oH007ok@42omP00Oo]0@;ooooo
og_ooooo0ooH00400oooooook@42ooooo`0Hooooo`?o00W_<_ooool00ol0003oooooooooo`0<oooo
o`003_ooool00ol0003oooooooooo`1Rooooo`;o00W_00Goooooo`09kooooooof001ond10P02omP0
0OooooooNoooool3omP00@03ooooooo]0@;ooooo01Sooooo0ol02Nlbooooo`03o`000?oooooooooo
00cooooo000>ooooo`03o`000?oooooooooo06;ooooo0_l02Nl01Ooooooo00W_oooooooH007ok@42
00;of001oooooomkooooo`?of00100?oooooond10_ooool06?ooool3o`09kc;ooooo00?o0000oooo
ooooool03?ooool000kooooo00?o0000ooooooooool0H_ooool2o`09k`05ooooool02NooooooomP0
0Oo]0@800_oH007oooooog_ooooo0ooH00400oooooook@42ooooo`0Hooooo`?o00W_<_ooool00ol0
003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Rooooo`07o`09kooooooo00W_o`09
kooooooof001ond10P02omP00OooooooNoooool3omP00@03ooooooo]0@;ooooo01Sooooo0ol02Nlb
ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06;ooooo00Oo00W_oooo
ool02Noo00W_oooooooH007ok@4200;of001oooooomkooooo`?of00100?oooooond10_ooool06?oo
ool3o`09kc;ooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0H_ooool0
1ol02Nooooooo`09kol02NooooooomP00Oo]0@800_oH007oooooog_ooooo0ooH00400oooooook@42
ooooo`0Hooooo`?o00W_<_ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003ooooooooo
o`1Rooooo`07o`09kooooooo00W_o`09kooooooof001ooooo`02omP00OooooooNoooool3omP00@03
ooooooo]0@;ooooo01Sooooo0ol02Nlbooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`00
0?oooooooooo06?ooooo0ol02Nl00ooooooof001ooooo`02omP00OooooooN_ooool01_oH007ooooo
omP00OoH007oooooond10QWooooo0ol02Nlbooooo`03o`000?oooooooooo00cooooo000>ooooo`03
o`000?oooooooooo06?ooooo0ol02Nl00ooooooof001ooooo`02omP00OooooooN_ooool01_oH007o
ooooomP00OoH007oooooond10QWooooo0ol02Nlbooooo`03o`000?oooooooooo00cooooo000>oooo
o`03o`000?oooooooooo06?ooooo0_l02Nl01?oooooo00W_omP00Oooool2omP00OooooooN_ooool0
1_oH007oooooomP00OoH007oooooond10QWooooo0ol02Nlbooooo`03o`000?oooooooooo00cooooo
000>ooooo`03o`000?oooooooooo06?ooooo0_l02Nl01?oooooo00W_omP00Oooool2omP00Ooooooo
N_ooool01_oH007oooooomP00OoH007oooooond10QWooooo0ol02Nlbooooo`03o`000?oooooooooo
00cooooo000>ooooo`03o`000?oooooooooo06?ooooo0_l02Nl00ooooooo00W_ooooo`03omP00Ooo
ooooN_ooool01_oH007oooooomP00OoH007oooooond10QSooooo00Co00W_ooooool02Noo00W_<_oo
ool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Sooooo`05o`09kooooooo
00W_o`09koooool00ooH007oooooog[ooooo0ooH00400oooooook@42ooooo`0Hooooo`04o`09kooo
oooo00W_o`09kc;ooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0Hooo
ool02?l02Nooooooo`09kol02NooooooomP00Oo]0@;of001oooooomjooooo`?of00100?oooooond1
0_ooool06?ooool01?l02Nooooooo`09kol02Nlbooooo`03o`000?oooooooooo00cooooo000>oooo
o`03o`000?oooooooooo06?ooooo00Oo00W_ooooool02Noo00W_oooooooH007ok@4200;of001oooo
oomiooooo`?of00100?oooooond10_ooool06?ooool01?l02Nooooooo`09kol02Nlbooooo`03o`00
0?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06?ooooo00Oo00W_ooooool02Noo00W_
oooooooH007ok@4200;of001oooooomiooooo`?of00100?oooooond10_ooool06?ooool01?l02Noo
ooooo`09kol02Nlbooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06Co
oooo0ol02Nl00ooooooof001ond10P02omP00OooooooNOooool3omP00@03ooooooo]0@;ooooo01So
oooo00Co00W_ooooool02Noo00W_<_ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003o
ooooooooo`1Tooooo`?o00W_00?oooooomP00Oo]0@800_oH007oooooogWooooo0ooH00400ooooooo
k@42ooooo`0Hooooo`04o`09kooooooo00W_o`09kc;ooooo00?o0000ooooooooool03?ooool000ko
oooo00?o0000ooooooooool0I?ooool3o`09k`03oooooooH007ok@4200;of001oooooomiooooo`?o
f00100?oooooond10_ooool06?ooool01?l02Nooooooo`09kol02Nlbooooo`03o`000?oooooooooo
00cooooo000>ooooo`03o`000?oooooooooo06Cooooo0_l02Nl01?oooooo00W_omP00Oo]0@82omP0
0OooooooNOooool3omP00@03ooooooo]0@;ooooo01Sooooo00Co00W_ooooool02Noo00W_<_ooool0
0ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Tooooo`;o00W_00Coooooo`09
kooH007ooooo0_oH007oooooogWooooo0ooH00400oooooook@42ooooo`0Hooooo`04o`09kooooooo
00W_o`09kc;ooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0I?ooool2
o`09k`04ooooool02Noof001ooooo`;of001oooooomhooooo`06omP00Ooooooof001omP00Ooooooo
k@426Oooool01?l02Nooooooo`09kol02Nlbooooo`03o`000?oooooooooo00cooooo000>ooooo`03
o`000?oooooooooo06Cooooo00Ko00W_ooooool02Noo00W_omP00Oooool2omP00OooooooN?ooool0
1_oH007oooooomP00OoH007oooooond10QWooooo0ol02Nlcooooo`03o`000?oooooooooo00cooooo
000>ooooo`03o`000?oooooooooo06Cooooo00Ko00W_ooooool02Noo00W_omP00Oooool2omP00Ooo
ooooN?ooool01_oH007oooooomP00OoH007oooooond10QWooooo0ol02Nlcooooo`03o`000?oooooo
oooo00cooooo000>ooooo`03o`000?oooooooooo06Cooooo00Ko00W_ooooool02Noo00W_omP00Ooo
ool2omP00OooooooN?ooool01_oH007oooooomP00OoH007oooooond10QWooooo0ol02Nlcooooo`03
o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06Gooooo0ol02Nl01?oH007ooooo
omP00OoH007oooooogSooooo00Kof001oooooooH007of001ooooooo]0@8Iooooo`?o00W_<oooool0
0ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Uooooo`?o00W_00CoooooomP0
0OoH007of001oooooomhooooo`06omP00Ooooooof001omP00Oooooook@426Oooool3o`09kc?ooooo
00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0IOooool3o`09k`04oooooooH
007of001omP00OooooooN?ooool3omP00@03ooooooo]0@;ooooo01Wooooo0ol02Nlcooooo`03o`00
0?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06Gooooo0_l02Nl01Ooooooo00W_omP0
0Oo]0@;of0010?ooooooN?ooool3omP00@03ooooooo]0@;ooooo01Wooooo0ol02Nlcooooo`03o`00
0?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06Gooooo0_l02Nl01?oooooo00W_omP0
0Oo]0@82omP00OooooooMoooool3omP00@03ooooooo]0@;ooooo01Wooooo0ol02Nlcooooo`03o`00
0?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06Gooooo0_l02Nl01?oooooo00W_omP0
0Oo]0@82omP00OooooooMoooool3omP00@03ooooooo]0@;ooooo01Wooooo0ol02Nlcooooo`03o`00
0?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06Gooooo00Ko00W_ooooool02Noo00W_
omP00Oo]0@82omP00OooooooMoooool3omP00@03ooooooo]0@;ooooo01Wooooo0ol02Nlcooooo`03
o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06Gooooo00Ko00W_ooooool02Noo
00W_omP00Oo]0@82omP00OooooooMoooool3omP00@03ooooooo]0@;ooooo01Wooooo0ol02Nlcoooo
o`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06Gooooo00Ko00W_ooooool0
2Noo00W_omP00Oooool2omP00OooooooMoooool3omP00@03ooooooo]0@;ooooo01Wooooo0ol02Nlc
ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06Kooooo0ol02Nl01?oH
007oooooomP00OoH007oooooogOooooo0ooH00400oooooook@42ooooo`0Iooooo`?o00W_<oooool0
0ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Vooooo`?o00W_00Cof001oooo
oooH007of001oooooomfooooo`06omP00Ooooooof001omP00Oooooook@426_ooool3o`09kc?ooooo
00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0I_ooool3o`09k`04omP00Ooo
oooof001omP00OooooooM_ooool01_oH007oooooomP00OoH007oooooond10Q[ooooo0ol02Nlcoooo
o`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06Kooooo0_l02Nl00ooooooo
00W_ooooo`02omP00OooooooM_ooool01_oH007oooooomP00OoH007oooooond10Q[ooooo0ol02Nlc
ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06Kooooo0_l02Nl00ooo
oooo00W_ooooo`02omP00OooooooM_ooool01_oH007oooooomP00OoH007oooooond10Q[ooooo0ol0
2Nlcooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06Kooooo0_l02Nl0
0ooooooo00W_ooooo`02omP00OooooooM_ooool01_oH007oooooomP00OoH007oooooond10Q[ooooo
0ol02Nlcooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06Kooooo0_l0
2Nl00ooooooo00W_omP00@02omP00OooooooM_ooool01_oH007oooooomP00OoH007oooooond10Q[o
oooo0ol02Nlcooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06Kooooo
00Co00W_ooooool02Noo00W_0ooH007oooooogKooooo0ooH00400oooooook@42ooooo`0Iooooo`04
o`09kooooooo00W_o`09kc?ooooo00?o0000ooooooooool03?ooool000kooooo00?o0000oooooooo
ool0I_ooool01ol02Nooooooo`09kol02Noof001ond10_oH0040oooooomfooooo`?of00100?ooooo
ond10_ooool06Oooool01?l02Nooooooo`09kol02Nlcooooo`03o`000?oooooooooo00cooooo000>
ooooo`03o`000?oooooooooo06Oooooo0ol02Nl01?oH007ok@42omP00Oo]0@;oooooogGooooo0ooH
00400oooooook@42ooooo`0Iooooo`04o`09kooooooo00W_o`09kc?ooooo00?o0000ooooooooool0
3?ooool000kooooo00?o0000ooooooooool0Ioooool3o`09k`04omP00Oo]0@;of001omP00Ooooooo
MOooool3omP00@03ooooooo]0@;ooooo01Wooooo00Co00W_ooooool02Noo00W_<oooool00ol0003o
ooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Wooooo`?o00W_00Cof001ond10_oH007o
f001oooooomeooooo`?of00100?oooooond10_ooool06Oooool01?l02Nooooooo`09kol02Nlcoooo
o`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06Oooooo0_l02Nl00ooooooo
00W_ond10P02omP00OooooooMOooool3omP00@03ooooooo]0@;ooooo01Wooooo00Co00W_ooooool0
2Noo00W_<oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Wooooo`;o
00W_00?oooooo`09koooool00_oH007oooooogGooooo0ooH00400oooooook@42ooooo`0Iooooo`04
o`09kooooooo00W_o`09kc?ooooo00?o0000ooooooooool03?ooool000kooooo00?o0000oooooooo
ool0Ioooool2o`09k`03ooooool02Noooooo00;of001oooooomeooooo`?of00100?oooooond10_oo
ool06Oooool01?l02Nooooooo`09kol02Nlcooooo`03o`000?oooooooooo00cooooo000>ooooo`03
o`000?oooooooooo06Oooooo0_l02Nl00ooooooo00W_ooooo`02omP00OooooooM?ooool01_oH007o
ooooomP00OoH007oooooond10Q[ooooo00Co00W_ooooool02Noo00W_<oooool00ol0003ooooooooo
o`0<ooooo`003_ooool00ol0003oooooooooo`1Wooooo`05o`09kooooooo00W_o`09koooool00_oH
007oooooogCooooo00Kof001oooooooH007of001ooooooo]0@8Jooooo`04o`09kooooooo00W_o`09
kc?ooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0Ioooool01Ol02Noo
ooooo`09kol02Noooooo00;of001oooooomdooooo`06omP00Ooooooof001omP00Oooooook@426_oo
ool01?l02Nooooooo`09kol02Nlcooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oo
oooooooo06Sooooo0ol02Nl00ooooooof001omP00@3oooooogCooooo00Kof001oooooooH007of001
ooooooo]0@8Jooooo`04o`09kooooooo00W_o`09kc?ooooo00?o0000ooooooooool03?ooool000ko
oooo00?o0000ooooooooool0J?ooool3o`09k`03oooooooH007of0010?ooooooM?ooool01_oH007o
ooooomP00OoH007oooooond10Q[ooooo00Co00W_ooooool02Noo00W_<oooool00ol0003ooooooooo
o`0<ooooo`003_ooool00ol0003oooooooooo`1Xooooo`?o00W_0ooH007oooooogCooooo00Kof001
oooooooH007of001ooooooo]0@8Jooooo`04o`09kooooooo00W_o`09kc?ooooo00?o0000oooooooo
ool03?ooool000kooooo00?o0000ooooooooool0J?ooool2o`09k`04ooooool02Noof001omP00Ooo
ooooM?ooool3omP00@03ooooooo]0@;ooooo01[ooooo00Co00W_ooooool02Noo00W_<oooool00ol0
003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Xooooo`;o00W_00Coooooo`09kooH
007of001oooooomdooooo`?of00100?oooooond10_ooool06_ooool3o`09kcCooooo00?o0000oooo
ooooool03?ooool000kooooo00?o0000ooooooooool0J?ooool2o`09k`04ooooool02Nook@42omP0
0OooooooM?ooool3omP00@03ooooooo]0@;ooooo01[ooooo0ol02Nldooooo`03o`000?oooooooooo
00cooooo000>ooooo`03o`000?oooooooooo06Sooooo0_l02Nl01Ooooooo00W_ond10_oH007ok@42
0?ooooooLoooool3omP00@03ooooooo]0@;ooooo01[ooooo0ol02Nldooooo`03o`000?oooooooooo
00cooooo000>ooooo`03o`000?oooooooooo06Sooooo0_l02Nl00ooooooo00W_ond10P02omP00Ooo
ooooLoooool3omP00@03ooooooo]0@;ooooo01[ooooo0ol02Nldooooo`03o`000?oooooooooo00co
oooo000>ooooo`03o`000?oooooooooo06Sooooo00Go00W_ooooool02Noo00W_ond10P02omP00Ooo
ooooLoooool3omP00@03ooooooo]0@;ooooo01[ooooo0ol02Nldooooo`03o`000?oooooooooo00co
oooo000>ooooo`03o`000?oooooooooo06Wooooo0ol02Nl00ooooooof001omP00@3oooooog?ooooo
0ooH00400oooooook@42ooooo`0Jooooo`?o00W_=?ooool00ol0003oooooooooo`0<ooooo`003_oo
ool00ol0003oooooooooo`1Yooooo`?o00W_00?oooooomP00OoH0040oooooombooooo`06omP00Ooo
oooof001omP00Oooooook@426oooool3o`09kcCooooo00?o0000ooooooooool03?ooool000kooooo
00?o0000ooooooooool0JOooool3o`09k`03oooooooH007of0010?ooooooL_ooool01_oH007ooooo
omP00OoH007oooooond10Q_ooooo0ol02Nldooooo`03o`000?oooooooooo00cooooo000>ooooo`03
o`000?oooooooooo06Wooooo0_l02Nl01?oH007o00W_omP00OoH007oooooog;ooooo00Kof001oooo
oooH007of001ooooooo]0@8Kooooo`?o00W_=?ooool00ol0003oooooooooo`0<ooooo`003_ooool0
0ol0003oooooooooo`1Yooooo`;o00W_00Cof001o`09kooH007of001oooooombooooo`06omP00Ooo
oooof001omP00Oooooook@426oooool3o`09kcCooooo00?o0000ooooooooool03?ooool000kooooo
00?o0000ooooooooool0JOooool2o`09k`04omP00Ol02Noof001omP00OooooooL_ooool01_oH007o
ooooomP00OoH007oooooond10Q_ooooo0ol02Nldooooo`03o`000?oooooooooo00cooooo000>oooo
o`03o`000?oooooooooo06Wooooo0_l02Nl01?oH007o00W_omP00OoH007oooooog;ooooo00Kof001
oooooooH007of001ooooooo]0@8Kooooo`?o00W_=?ooool00ol0003oooooooooo`0<ooooo`003_oo
ool00ol0003oooooooooo`1Yooooo`;o00W_00Cof001o`09kooH007of001oooooombooooo`06omP0
0Ooooooof001omP00Oooooook@426oooool3o`09kcCooooo00?o0000ooooooooool03?ooool000ko
oooo00?o0000ooooooooool0JOooool01?l02Nooooooo`09kol02Nl2omP00OooooooL_ooool01_oH
007oooooomP00OoH007oooooond10Q_ooooo0ol02Nldooooo`03o`000?oooooooooo00cooooo000>
ooooo`03o`000?oooooooooo06[ooooo0ol02Nl2omP00OooooooL_ooool3omP00@03ooooooo]0@;o
oooo01_ooooo0ol02Nldooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo
06[ooooo0ol02Nl00oo]0@;of001ooooo`3oooooog7ooooo0ooH00400oooooook@42ooooo`0Joooo
o`04o`09kooooooo00W_o`09kcCooooo00?o0000ooooooooool03?ooool000kooooo00?o0000oooo
ooooool0J_ooool3o`09k`03ond10_oH007ooooo0?ooooooLOooool3omP00@03ooooooo]0@;ooooo
01[ooooo00Co00W_ooooool02Noo00W_=?ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0
003oooooooooo`1Zooooo`?o00W_00?ok@42omP00OoH0040oooooomaooooo`?of00100?oooooond1
0_ooool06_ooool01?l02Nooooooo`09kol02Nldooooo`03o`000?oooooooooo00cooooo000>oooo
o`03o`000?oooooooooo06[ooooo0_l02Nl01?oH007o00W_omP00OoH007oooooog7ooooo0ooH0040
0oooooook@42ooooo`0Jooooo`04o`09kooooooo00W_o`09kcCooooo00?o0000ooooooooool03?oo
ool000kooooo00?o0000ooooooooool0J_ooool2o`09k`04omP00Ol02Noof001omP00OooooooLOoo
ool3omP00@03ooooooo]0@;ooooo01[ooooo00Co00W_ooooool02Noo00W_=?ooool00ol0003ooooo
ooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Zooooo`;o00W_00Cof001o`09kooH007of001
oooooom`ooooo`06omP00Ooooooof001omP00Oooooook@426oooool01?l02Nooooooo`09kol02Nld
ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06[ooooo0_l02Nl01?oH
007o00W_omP00OoH007oooooog3ooooo00Kof001oooooooH007of001ooooooo]0@8Kooooo`04o`09
kooooooo00W_o`09kcCooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0
J_ooool2o`09k`04omP00Ol02Noof001omP00OooooooL?ooool01_oH007oooooomP00OoH007ooooo
ond10Q_ooooo00Co00W_ooooool02Noo00W_=?ooool00ol0003oooooooooo`0<ooooo`003_ooool0
0ol0003oooooooooo`1[ooooo`?o00W_0_oH007oooooog3ooooo00Kof001oooooooH007of001oooo
ooo]0@8Kooooo`04o`09kooooooo00W_o`09kcCooooo00?o0000ooooooooool03?ooool000kooooo
00?o0000ooooooooool0Joooool3o`09k`;of001oooooom`ooooo`06omP00Ooooooof001omP00Ooo
ooook@426oooool01?l02Nooooooo`09kol02Nldooooo`03o`000?oooooooooo00cooooo000>oooo
o`03o`000?oooooooooo06_ooooo0ol02Nl2omP00OooooooL?ooool01_oH007oooooomP00OoH007o
ooooond10Q_ooooo00Co00W_ooooool02Noo00W_=?ooool00ol0003oooooooooo`0<ooooo`003_oo
ool00ol0003oooooooooo`1[ooooo`?o00W_0_oH007oooooog3ooooo00Kof001oooooooH007of001
ooooooo]0@8Kooooo`04o`09kooooooo00W_o`09kcCooooo00?o0000ooooooooool03?ooool000ko
oooo00?o0000ooooooooool0Joooool2o`09k`03omP00Ol02Noof0010?ooooooL?ooool01_oH007o
ooooomP00OoH007oooooond10Q_ooooo00Co00W_ooooool02Noo00W_=?ooool00ol0003ooooooooo
o`0<ooooo`003_ooool00ol0003oooooooooo`1[ooooo`;o00W_00?of001o`09kooH0040oooooom`
ooooo`?of00100?oooooond10_ooool06oooool01?l02Nooooooo`09kol02Nldooooo`03o`000?oo
oooooooo00cooooo000>ooooo`03o`000?oooooooooo06_ooooo0_l02Nl00ooH007o00W_omP00@3o
ooooog3ooooo0ooH00400oooooook@42ooooo`0Kooooo`04o`09kooooooo00W_o`09kcCooooo00?o
0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0Joooool2o`09k`03omP00Ol02Noo
f0010?ooooooL?ooool3omP00@03ooooooo]0@;ooooo01_ooooo00Co00W_ooooool02Noo00W_=?oo
ool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1[ooooo`;o00W_00Cof001
o`09kooH007ok@42oooooom_ooooo`?of00100?oooooond10_ooool06oooool01?l02Nooooooo`09
kol02Nldooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo06cooooo0ol0
2Nl2omP00OooooooKoooool3omP00@03ooooooo]0@;ooooo01_ooooo00Co00W_ooooool02Noo00W_
=?ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1/ooooo`?o00W_0_oH
007oooooofoooooo0ooH00400oooooook@42ooooo`0Kooooo`04o`09kooooooo00W_o`09kcCooooo
00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0K?ooool3o`09k`;of001oooo
oom^ooooo`06omP00Ooooooof001omP00Oooooook@427?ooool3o`09kcGooooo00?o0000oooooooo
ool03?ooool000kooooo00?o0000ooooooooool0K?ooool3o`09k`;of001oooooom^ooooo`06omP0
0Ooooooof001omP00Oooooook@427?ooool3o`09kcGooooo00?o0000ooooooooool03?ooool000ko
oooo00?o0000ooooooooool0K?ooool2o`09k`03ooooool02Noof0010?ooooooK_ooool01_oH007o
ooooomP00OoH007oooooond10Qcooooo0ol02Nleooooo`03o`000?oooooooooo00cooooo000>oooo
o`03o`000?oooooooooo06cooooo0_l02Nl00ooooooo00W_omP00@3oooooofkooooo00Kof001oooo
oooH007of001ooooooo]0@8Looooo`?o00W_=Oooool00ol0003oooooooooo`0<ooooo`003_ooool0
0ol0003oooooooooo`1/ooooo`;o00W_00?oooooo`09kooH0040oooooom^ooooo`06omP00Ooooooo
f001omP00Oooooook@427?ooool3o`09kcGooooo00?o0000ooooooooool03?ooool000kooooo00?o
0000ooooooooool0K?ooool2o`09k`03ooooool02Noof0010?ooooooK_ooool01_oH007oooooomP0
0OoH007oooooond10Qcooooo0ol02Nleooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`00
0?oooooooooo06cooooo0_l02Nl00ooooooo00W_omP00@3oooooofkooooo00Kof001oooooooH007o
f001ooooooo]0@8Looooo`?o00W_=Oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003o
ooooooooo`1]ooooo`?o00W_00?of001ooooooooool0oooooom/ooooo`06omP00Ooooooof001omP0
0Oooooook@427?ooool3o`09kcGooooo00?o0000ooooooooool03?ooool000kooooo00?o0000oooo
ooooool0KOooool3o`09k`03omP00Ooooooooooo0?ooooooK?ooool01_oH007oooooomP00OoH007o
ooooond10Qcooooo0ol02Nleooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooo
oooo06gooooo0ol02Nl00ooH007oooooooooo`3oooooofcooooo0ooH00400oooooook@42ooooo`0L
ooooo`?o00W_=Oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1]oooo
o`?o00W_00?of001ooooooooool0oooooom/ooooo`?of00100?oooooond10_ooool07?ooool3o`09
kcGooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool06Oooool3o`0000Co
oooo0_l000000ooooooo0000o`000007o`000003ooooool0003ooooo00;o00000oooool5o`0000?o
oooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000_ooool3o`0000?ooooo0ol00004oooo
o`So00000_ooool01?l0003oooooo`000?ooool2o`0000Sooooo0_l02Nl00oo]0@;o00W_ooooo`3o
ooooofgooooo0ooH00400oooooook@42ooooo`0Kooooo`04o`09kooooooo00W_o`09kcGooooo00?o
0000ooooooooool03?ooool000kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01_l0003ooooooooo
ool0003oooooo`0000Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo0000
00?ooooo0_l00002ooooo`;o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000Cooooo00Ko0000ooooool0003oooooo`000?ooool3o`0000Oooooo
0_l02Nl00ooooooo00W_ond10P3oooooofgooooo0ooH00400oooooook@42ooooo`0Kooooo`04o`09
kooooooo00W_o`09kcGooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0
6_ooool3o`0000;ooooo1?l000001Ooooooo0000oooooooooooo000000;ooooo00Oo0000oooooooo
oooo0000ooooool0003ooooo00;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooool000000oooool2o`0000Cooooo0_l00005ooooo`?o00000oooool01?l0003ooooooooo
ool00002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool000001oooool2o`09
k`03ooooool02Noof0010?ooooooKOooool3omP00@03ooooooo]0@;ooooo01_ooooo00Co00W_oooo
ool02Noo00W_=Oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`0Joooo
o`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooool000001Oooool4o`0000?ooooo00?o0000ooooool00000
0oooool2o`0000;ooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00002oooo
o`06o`000?ooooooooooo`000?oooooo00001?ooool00ol0003oooooo`000002o`0000;ooooo00?o
0000ooooooooool01?ooool2o`09k`03ooooool02Noof0010?ooooooK?ooool01_oH007oooooomP0
0OoH007oooooond10Qcooooo00Co00W_ooooool02Noo00W_=Oooool00ol0003oooooooooo`0<oooo
o`003_ooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000;ooooo0_l00002oooo
o`05o`000?ooooooooooo`000?ooool00_l000001?oooooo0000o`000?l00006ooooo`06o`000?oo
ooooooooooooool0003ooooo0ol000001?oooooo0000o`000?l00002ooooo`Go00001_ooool01Ol0
003oooooooooool0003ooooo00Go00000_ooool8o`0000Cooooo00?o0000ooooooooool00oooool2
o`09k`03ooooool02Noof0010?ooooooK?ooool01_oH007oooooomP00OoH007oooooond10Qcooooo
00Co00W_ooooool02Noo00W_=Oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003ooooo
ooooo`0Jooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo00003Oooool01Ol0
003ooooooooooooooooo000001Gooooo00Co0000oooooooooooo00002oooool2o`0000Oooooo00?o
0000ooooooooool01?ooool01?l02Nooooooo`09kooH007oooooofcooooo00Kof001oooooooH007o
f001ooooooo]0@8Looooo`04o`09kooooooo00W_o`09kcGooooo00?o0000ooooooooool03?ooool0
00kooooo00?o0000ooooooooool06Oooool4o`0000Kooooo0_l000000ooooooo0000o`000002oooo
o`03o`000?oooooooooo00Oooooo1Ol0000Eooooo`Co00001_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool3o`09k`03omP00Ooooooooooo
0?ooooooJ_ooool01_oH007oooooomP00OoH007oooooond10Qcooooo00Co00W_ooooool02Noo00W_
=Oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Kooooo`;o00002ooo
ool00ol0003oooooooooo`03ooooo`?o00W_00?of001ooooooooool0oooooomZooooo`06omP00Ooo
oooof001omP00Oooooook@427?ooool01?l02Nooooooo`09kol02Nleooooo`03o`000?oooooooooo
00cooooo000>ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`02ooooo`?o00W_00?of001ooooooooool0oooooomZooooo`06omP00Ooooooof001omP0
0Oooooook@427?ooool01?l02Nooooooo`09kol02Nleooooo`03o`000?oooooooooo00cooooo000>
ooooo`03o`000?oooooooooo05Sooooo0_l0000@ooooo`04o`000?ooooooooooooooo`;o00W_00?o
f001o`09koooool0oooooom[ooooo`06omP00Ooooooof001omP00Oooooook@427?ooool01?l02Noo
ooooo`09kol02Nleooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo05Ko
oooo0_l0000Booooo`04o`000?ooooooooooooooo`;o00W_00?of001o`09koooool0oooooom[oooo
o`06omP00Ooooooof001omP00Oooooook@427?ooool01?l02Nooooooo`09kol02Nleooooo`03o`00
0?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`02o`09k`03omP00Ol02Noooooo0?ooooooJoooool01_oH007oooooomP0
0OoH007oooooond10Qcooooo00Co00W_ooooool02Noo00W_=Oooool00ol0003oooooooooo`0<oooo
o`003_ooool00ol0003oooooooooo`1Cooooo`;o00005oooool01_l0003oooooo`09kol02Noof001
o`09koooooooK?ooool3omP00@03ooooooo]0@;ooooo01cooooo00Co00W_ooooool02Noo00W_=Ooo
ool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo01Oooooo00Ko0000ooooool02Noo00W_omP00Ol02Nooooooofcooooo0ooH00400oooooook@42
ooooo`0Looooo`04o`09kooooooo00W_o`09kcGooooo00?o0000ooooooooool03?ooool000kooooo
00?o0000ooooooooool0D?ooool2o`0001_ooooo00Go0000ooooool02Nooooooo`09k`3oooooofco
oooo0ooH00400oooooook@42ooooo`0Looooo`04o`09kooooooo00W_o`09kcGooooo00?o0000oooo
ooooool03?ooool000kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooo00W_00;o00W_oooooom/ooooo`?of00100?oooooond10_ooool07?ooool01?l02Noo
ooooo`09kol02Nleooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo04go
oooo0_l0000Oooooo`05o`000?l02Noo00W_o`09koo]0@80oooooomZooooo`06omP00Ooooooof001
omP00Oooooook@427Oooool01?l02Nooooooo`09kol02Nleooooo`03o`000?oooooooooo00cooooo
000>ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool07oooool01Ol0003o00W_o`09
kol02Noof0010?ooooooJ_ooool01_oH007oooooomP00OoH007oooooond10Qgooooo00Co00W_oooo
ool02Noo00W_=Oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`1:oooo
o`;o00008oooool2o`09k`03omP00Ol02Noooooo0?ooooooJOooool01_oH007oooooomP00OoH007o
ooooond10Qgooooo00Co00W_ooooool02Noo00W_=Oooool00ol0003oooooooooo`0<ooooo`003_oo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02;ooooo00Go00W_ooooool02Noof001
o`09k`3oooooof[ooooo00Kof001oooooooH007of001ooooooo]0@8Mooooo`04o`09kooooooo00W_
o`09kcGooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0??ooool3o`09
k`Sooooo0_l0000Uooooo`05o`09kooooooo0000omP00Ol02Nl0oooooomZooooo`06omP00Ooooooo
f001omP00Oooooook@427Oooool01?l02Nooooooo`09kol02Nleooooo`03o`000?oooooooooo00co
oooo000>ooooo`03o`000?oooooooooo03gooooo1_l02Nl3ooooo`03o`000?oooooooooo02Gooooo
0_l02Nl00ooooooof001o`09k`3oooooof[ooooo00Kof001oooooooH007of001ooooooo]0@8Moooo
o`04o`09kooooooo00W_o`09kcGooooo00?o0000ooooooooool03?ooool000koooooBOl02NlWoooo
o`07o`09kooooooo00W_omP00Ooooooo00W_o`00003oooooofWooooo00Kof001oooooooH007of001
ooooooo]0@8Mooooo`?o00W_=_ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003ooooo
ooooo`0gooooo`?o00W_00?oooooo`09kol02Nl01?l02Nl5o`0000;o00W_00?of001ooooooooool0
8_ooool01ol02Nooooooo`09kooH007oooooomP00Ol00000oooooomYooooo`06omP00Ooooooof001
omP00Oooooook@427Oooool3o`09kcKooooo00?o0000ooooooooool03?ooool000koooooA?l02Nl0
0ol0003o00W_o`09k`04ooooo`?o00W_8Oooool02?l02Nooooooo`09kooooooof001o`09kooH007o
0000oooooomYooooo`06omP00Ooooooof001omP00Oooooook@427Oooool3o`09kcKooooo00?o0000
ooooooooool03?ooool000koooooA?l02Nl3ooooo`;o00W_00?of001ooooooooool00_ooool2o`09
kaoooooo00Ko00W_ooooool02Noof001ooooool02Nl2ooooo`03o`000?oooooooooo0?ooooooI_oo
ool01_oH007oooooomP00OoH007oooooond10Qgooooo0ol02Nlfooooo`03o`000?oooooooooo00co
oooo000>ooooo`03o`000?oooooooooo03Sooooo1Ol02Nl01?oooooo0000o`000?l00002o`09k`?o
oooo0ol02Nl4ooooo`;o00W_00?of001ooooooooool06_ooool01_l02Nooooooo`09kooH007ooooo
o`09k`;ooooo00?o0000ooooooooool0oooooomVooooo`06omP00Ooooooof001omP00Oooooook@42
7Oooool3o`09kcKooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0=ooo
ool2o`09k`Cooooo00?o0000ooooooooool00oooool3o`09k`?ooooo0_l02Nl01?oH007ooooooooo
ooooool3o`09kaWooooo00Oo00W_ooooool02Noof001ooooool02Noof00100?ooooo00?o0000oooo
ooooool0oooooomUooooo`?of00100?oooooond10_ooool07Oooool3o`09kcKooooo00?o0000oooo
ooooool03?ooool000kooooo00?o0000ooooooooool0>oooool2o`0000Wooooo0_l02Nl3ooooo`;o
00W_00?of001ooooooooool00_ooool2o`09kaOooooo00Ko00W_ooooool02Noof001ooooool02Nl5
ooooo`03o`000?oooooooooo0?ooooooI?ooool3omP00@03ooooooo]0@;ooooo01gooooo0ol02Nlf
ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo03Wooooo0_l0000=oooo
o`;o00W_0oooool2o`09k`03omP00Ooooooooooo00;ooooo0_l02Nl00ooH007oooooooooo`0Aoooo
o`07o`09koooooooooooo`09kooH007o00W_omP00@05ooooo`03o`000?oooooooooo0?ooooooI?oo
ool3omP00@03ooooooo]0@;ooooo01gooooo0ol02Nlfooooo`03o`000?oooooooooo00cooooo000>
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool03oooool2o`09k`?ooooo0ol02Nl0
1?oH007oooooooooooooool3o`09ka7ooooo00Oo00W_ooooool02Noof001ooooool02Noof00100Ko
oooo00?o0000ooooooooool0oooooomRooooo`06omP00Ooooooof001omP00Oooooook@427Oooool0
1?l02Nooooooo`09kol02Nlfooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooo
oooo03Kooooo0_l0000Dooooo`?o00W_0oooool2o`09k`03omP00Ooooooooooo00;ooooo0_l02Nl?
ooooo`06o`09kooooooo00W_omP00Ol02Noof0011oooool00ol0003oooooooooo`3oooooof;ooooo
00Kof001oooooooH007of001ooooooo]0@8Mooooo`04o`09kooooooo00W_o`09kcKooooo00?o0000
ooooooooool03?ooool000kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Goooo
o`;o00W_0oooool2o`09k`;of0010oooool2o`09k`03omP00Ooooooooooo00Wooooo00Oo00W_oooo
ool02Noof001ooooool02Noof00100Sooooo00?o0000ooooooooool0oooooomQooooo`06omP00Ooo
oooof001omP00Oooooook@427Oooool01?l02Nooooooo`09kol02Nlfooooo`03o`000?oooooooooo
00cooooo000>ooooo`03o`000?oooooooooo03?ooooo0_l0000Looooo`;o00W_0oooool2o`09k`;o
f0010oooool2o`09k`03omP00Ooooooooooo00Oooooo00Ko00W_ooooool02Noof001ooooool02Nl9
ooooo`?o0000oooooomQooooo`06omP00Ooooooof001omP00Oooooook@427Oooool01?l02Noooooo
o`09kol02Nlfooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool07_ooool2o`09k`?ooooo0_l02Nl3omP00@;ooooo0ol02Nl3ooooo`;o00W_
00Soooooo`09koooooooooooo`09kooH007o00W_omP00@Kooooo0ol0003oooooofCooooo00Kof001
oooooooH007of001ooooooo]0@8Mooooo`04o`09kooooooo00W_o`09kcKooooo00?o0000oooooooo
ool03?ooool000kooooo00?o0000ooooooooool0<?ooool2o`0002?ooooo0_l02Nl3ooooo`?o00W_
0_oH0043ooooo`;o00W_00?of001o`09kol02Nl00_l02Nl01_oooooo00W_omP00Ooooooo00W_omP0
0@Cooooo0_l0003oooooofOooooo00Kof001oooooooH007of001ooooooo]0@8Mooooo`04o`09kooo
oooo00W_o`09kcKooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0Uooooo`?o00W_0oooool2o`09k`;of00100?oooooo`09kol02Nl01Ol0
2Nl01OoH007o00W_omP00Ol02Noof00100?ooooo0_l0003oooooofWooooo00Kof001oooooooH007o
f001ooooooo]0@8Mooooo`04o`09kooooooo00W_o`09kcKooooo00?o0000ooooooooool03?ooool0
00kooooo00?o0000ooooooooool0;_ooool2o`0002[ooooo0_l02Nl2ooooo`?o00W_00?of001o`09
kol02Nl01ol02Nl00ooooooo00W_omP00@03o`000?ooooooJoooool01_oH007oooooomP00OoH007o
ooooond10Qgooooo00Co00W_ooooool02Noo00W_=_ooool00ol0003oooooooooo`0<ooooo`003_oo
ool00ol0003oooooooooo`0`ooooo`;o0000:_ooool>o`09k`;of00100?o00W_omP00Oooool0oooo
oom]ooooo`06omP00Ooooooof001omP00Oooooook@427Oooool01?l02Nooooooo`09kol02Nlfoooo
o`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo03;ooooo0_l0000Zooooo`Wo
00W_00Kof001o`09kol02Noof001o`09kooH007oooooofoooooo00Kof001oooooooH007of001oooo
ooo]0@8Mooooo`04o`09kooooooo00W_o`09kcKooooo00?o0000ooooooooool03?ooool000kooooo
00?o0000ooooooooool0=?ooool2o`0002Oooooo00?of001o`09kol02Nl02?l02Nl00ol0003o00W_
ooooo`02o`000?ooooooKoooool01_oH007oooooomP00OoH007oooooond10Qgooooo00Co00W_oooo
ool02Noo00W_=_ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`0foooo
o`;o00009Oooool7o`09k`;o00000ol02Nl00ol0003oooooooooo`3oooooog3ooooo0ooH00400ooo
ooook@42ooooo`0Mooooo`04o`09kooooooo00W_o`09kcKooooo00?o0000ooooooooool03?ooool0
00kooooo00?o0000ooooooooool0>?ooool2o`0002Sooooo0_l02Nl00ol0003o00W_o`00003ooooo
ogGooooo0ooH00400oooooook@42ooooo`0Mooooo`04o`09kooooooo00W_o`09kcKooooo00?o0000
ooooooooool03?ooool000kooooo00?o0000ooooooooool0>_ooool2o`0002Cooooo0_l0003ooooo
og[ooooo0ooH00400oooooook@42ooooo`0Mooooo`04o`09kooooooo00W_o`09kcKooooo00?o0000
ooooooooool03?ooool000kooooo00?o0000ooooooooool0??ooool2o`00023ooooo0_l0003ooooo
og_ooooo00Kof001oooooooH007of001ooooooo]0@8Nooooo`04o`09kooooooo00W_o`09kcKooooo
00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0?_ooool2o`0001_ooooo0ol0
003ooooooggooooo00Kof001oooooooH007of001ooooooo]0@8Nooooo`04o`09kooooooo00W_o`09
kcKooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0@?ooool2o`0001Oo
oooo0_l0003ooooooh3ooooo00Kof001oooooooH007of001ooooooo]0@8Nooooo`04o`09kooooooo
00W_o`09kcKooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0@_ooool2
o`0001?ooooo0_l0003ooooooh;ooooo00Kof001oooooooH007of001ooooooo]0@8Nooooo`04o`09
kooooooo00W_o`09kcKooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0
A?ooool2o`0000kooooo0ol0003oooooohCooooo00Kof001oooooooH007of001ooooooo]0@8Noooo
o`04o`09kooooooo00W_o`09kcKooooo00?o0000ooooooooool03?ooool000kooooo00?o0000oooo
ooooool0A_ooool2o`0000[ooooo0_l0003oooooohOooooo00Kof001oooooooH007of001ooooooo]
0@8Nooooo`04o`09kooooooo00W_o`09kcKooooo00?o0000ooooooooool03?ooool000kooooo00?o
0000ooooooooool0B?ooool2o`0000Kooooo0_l0003oooooohWooooo00Kof001oooooooH007of001
ooooooo]0@8Nooooo`04o`09kooooooo00W_o`09kcKooooo00?o0000ooooooooool03?ooool000ko
oooo00?o0000ooooooooool0B_ooool2o`000004ooooool0003o0000o`000?ooooooRoooool01_oH
007oooooomP00OoH007oooooond10Qkooooo00Co00W_ooooool02Noo00W_=_ooool00ol0003ooooo
ooooo`0<ooooo`003_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo0?ooooooS?oo
ool01_oH007oooooomP00OoH007oooooond10Qkooooo00Co00W_ooooool02Noo00W_=_ooool00ol0
003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3oooooom_ooooo00Kof001oooooooH
007of001ooooooo]0@8Nooooo`04o`09kooooooo00W_o`09kcKooooo00?o0000ooooooooool03?oo
ool000kooooo00?o0000ooooooooool0oooooooKooooo`06omP00Ooooooof001omP00Oooooook@42
7_ooool01?l02Nooooooo`09kol02Nlfooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`00
0?oooooooooo0?oooooofoooool3omP00@03ooooooo]0@;ooooo01kooooo00Co00W_ooooool02Noo
00W_=_ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3oooooom_ooooo
0ooH00400oooooook@42ooooo`0Nooooo`?o00W_=oooool00ol0003oooooooooo`0<ooooo`003_oo
ool00ol0003oooooooooo`3oooooom_ooooo0ooH00400oooooook@42ooooo`0Nooooo`?o00W_=ooo
ool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3oooooom[ooooo00Kof001
oooooooH007of001ooooooo]0@8Oooooo`?o00W_=oooool00ol0003oooooooooo`0<ooooo`003_oo
ool00ol0003oooooooooo`3oooooom[ooooo00Kof001oooooooH007of001ooooooo]0@8Oooooo`?o
00W_=oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3oooooom[ooooo
00Kof001oooooooH007of001ooooooo]0@8Oooooo`?o00W_=oooool00ol0003oooooooooo`0<oooo
o`003_ooool00ol0003oooooooooo`3oooooom[ooooo00Kof001oooooooH007of001ooooooo]0@8N
ooooo`04o`09kooooooo00W_o`09kcOooooo00?o0000ooooooooool03?ooool000kooooo00?o0000
ooooooooool0oooooooJooooo`06omP00Ooooooof001omP00Oooooook@427_ooool01?l02Noooooo
o`09kol02Nlgooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo0?oooooo
f_ooool01_oH007oooooomP00OoH007oooooond10Qkooooo00Co00W_ooooool02Noo00W_=oooool0
0ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3oooooom[ooooo00Kof001oooo
oooH007of001ooooooo]0@8Nooooo`04o`09kooooooo00W_o`09kcOooooo00?o0000ooooooooool0
3?ooool000kooooo00?o0000ooooooooool0oooooooJooooo`06omP00Ooooooof001omP00Ooooooo
k@427_ooool01?l02Nooooooo`09kol02Nlgooooo`03o`000?oooooooooo00cooooo000>ooooo`03
o`000?oooooooooo0?oooooof_ooool01_oH007oooooomP00OoH007oooooond10Qkooooo00Co00W_
ooooool02Noo00W_=oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3o
ooooom[ooooo00Kof001oooooooH007of001ooooooo]0@8Nooooo`04o`09kooooooo00W_o`09kcOo
oooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0oooooooJooooo`06omP0
0Ooooooof001omP00Oooooook@427_ooool01?l02Nooooooo`09kol02Nlgooooo`03o`000?oooooo
oooo00cooooo000>ooooo`03o`000?oooooooooo0?oooooof_ooool01_oH007oooooomP00OoH007o
ooooond10Qkooooo00Co00W_ooooool02Noo00W_=oooool00ol0003oooooooooo`0<ooooo`003_oo
ool00ol0003oooooooooo`3oooooom[ooooo0ooH00400oooooook@42ooooo`0Nooooo`04o`09kooo
oooo00W_o`09kcOooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0oooo
oooJooooo`?of00100?oooooond10_ooool07_ooool01?l02Nooooooo`09kol02Nlgooooo`03o`00
0?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo0?oooooofOooool01_oH007oooooomP0
0OoH007oooooond10Qoooooo00Co00W_ooooool02Noo00W_=oooool00ol0003oooooooooo`0<oooo
o`003_ooool00ol0003oooooooooo`3oooooomWooooo00Kof001oooooooH007of001ooooooo]0@8O
ooooo`04o`09kooooooo00W_o`09kcOooooo00?o0000ooooooooool03?ooool000kooooo00?o0000
ooooooooool0oooooooIooooo`06omP00Ooooooof001omP00Oooooook@427oooool01?l02Noooooo
o`09kol02Nlgooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo0?oooooo
fOooool01_oH007oooooomP00OoH007oooooond10Qoooooo00Co00W_ooooool02Noo00W_=oooool0
0ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3oooooomWooooo00Kof001oooo
oooH007of001ooooooo]0@8Oooooo`04o`09kooooooo00W_o`09kcOooooo00?o0000ooooooooool0
3?ooool000kooooo00?o0000ooooooooool0oooooooIooooo`06omP00Ooooooof001omP00Ooooooo
k@427oooool01?l02Nooooooo`09kol02Nlgooooo`03o`000?oooooooooo00cooooo000>ooooo`03
o`000?oooooooooo0?oooooofOooool01_oH007oooooomP00OoH007oooooond10Qoooooo00Co00W_
ooooool02Noo00W_=oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3o
ooooomWooooo00Kof001oooooooH007of001ooooooo]0@8Oooooo`04o`09kooooooo00W_o`09kcOo
oooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0oooooooIooooo`06omP0
0Ooooooof001omP00Oooooook@427oooool01?l02Nooooooo`09kol02Nlgooooo`03o`000?oooooo
oooo00cooooo000>ooooo`03o`000?oooooooooo0?oooooofOooool01_oH007oooooomP00OoH007o
ooooond10Qoooooo00Co00W_ooooool02Noo00W_=oooool00ol0003oooooooooo`0<ooooo`003_oo
ool00ol0003oooooooooo`3oooooomWooooo00Kof001oooooooH007of001ooooooo]0@8Oooooo`04
o`09kooooooo00W_o`09kcOooooo00?o0000ooooooooool03?ooool000kooooo00?o0000oooooooo
ool0oooooooIooooo`06omP00Ooooooof001omP00Oooooook@427oooool01?l02Nooooooo`09kol0
2Nlgooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo0?oooooofOooool3
omP00@03ooooooo]0@;ooooo01oooooo00Co00W_ooooool02Noo00W_=oooool00ol0003ooooooooo
o`0<ooooo`003_ooool00ol0003oooooooooo`3oooooomSooooo00Kof001oooooooH007of001oooo
ooo]0@8Pooooo`04o`09kooooooo00W_o`09kcOooooo00?o0000ooooooooool03?ooool000kooooo
00?o0000ooooooooool0oooooooHooooo`06omP00Ooooooof001omP00Oooooook@428?ooool01?l0
2Nooooooo`09kol02Nlgooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo
0?oooooof?ooool01_oH007oooooomP00OoH007oooooond10R3ooooo00Co00W_ooooool02Noo00W_
=oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3oooooomSooooo00Ko
f001oooooooH007of001ooooooo]0@8Pooooo`04o`09kooooooo00W_o`09kcOooooo00?o0000oooo
ooooool03?ooool000kooooo00?o0000ooooooooool0oooooooHooooo`06omP00Ooooooof001omP0
0Oooooook@428?ooool3o`09kcSooooo00?o0000ooooooooool03?ooool000kooooo00?o0000oooo
ooooool0oooooooHooooo`06omP00Ooooooof001omP00Oooooook@428?ooool3o`09kcSooooo00?o
0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0oooooooHooooo`06omP00Ooooooo
f001omP00Oooooook@427oooool01?l02Nooooooo`09kol02Nlhooooo`03o`000?oooooooooo00co
oooo000>ooooo`03o`000?oooooooooo0?oooooof?ooool01_oH007oooooomP00OoH007oooooond1
0Qoooooo00Co00W_ooooool02Noo00W_>?ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0
003oooooooooo`3oooooomSooooo00Kof001oooooooH007of001ooooooo]0@8Oooooo`04o`09kooo
oooo00W_o`09kcSooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0oooo
oooHooooo`06omP00Ooooooof001omP00Oooooook@427oooool01?l02Nooooooo`09kol02Nlhoooo
o`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo0?oooooof?ooool01_oH007o
ooooomP00OoH007oooooond10Qoooooo00Co00W_ooooool02Noo00W_>?ooool00ol0003ooooooooo
o`0<ooooo`003_ooool00ol0003oooooooooo`3oooooomSooooo00Kof001oooooooH007of001oooo
ooo]0@8Oooooo`04o`09kooooooo00W_o`09kcSooooo00?o0000ooooooooool03?ooool000kooooo
00?o0000ooooooooool0oooooooFooooo`Kof00100?oooooomP00Oo]0@807Oooool7o`09kcKooooo
00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0oooooooFooooo`Sof00100?o
k@42ooooooooool06oooool7o`09kcKooooo00?o0000ooooooooool03?ooool000kooooo00?o0000
ooooooooool0oooooooFooooo`Oof0010_o]0@8Mooooo`Oo00W_=_ooool00ol0003oooooooooo`0<
ooooo`003_ooool00ol0003oooooooooo`3oooooomKooooo1ooH00400oo]0@;oooooooooo`0Loooo
o`Ko00W_=oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`3oooooomKo
oooo1ooH00400oo]0@;oooooooooo`0Looooo`Ko00W_=oooool00ol0003oooooooooo`0<ooooo`00
3_ooool00ol0003oooooooooo`3oooooomOooooo1OoH0042ond10Qoooooo1Ol02Nlgooooo`03o`00
0?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo0?ooooooeoooool5omP00@;ok@427ooo
ool5o`09kcOooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0oooooooG
ooooo`Gof00100?ok@42ooooooooool07_ooool4o`09kcSooooo00?o0000ooooooooool03?ooool0
00koooooool0003oo`0003ko00003_ooool00?ooooooj?ooool6o`00023ooooo1Ol00016ooooo`00
oooooooooooooe[ooooo003oooooooooooooF_ooool00?oooooooooooomJooooo`00oooooooooooo
oe[ooooo003oooooooooooooF_ooool00?oooooooooooomJooooo`00oooooooooooooe[ooooo003o
ooooooooooooF_ooool00?oooooooooooomJooooo`00\
\>"],
  ImageRangeCache->{{{0, 599.625}, {428.062, 0}} -> {-8.85641, -206.251, \
0.613238, 0.613238}},
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[
\t{LineOfRays[5],
\tMove[ReversionPrism[10,10],5],
\tBoundary[45,GraphicDesign->Off]},PlotType->TopView
];\
\>", "Input",
  CellTags->"Prism Examples"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .44467 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.021164 0.116548 0.021164 [
[ 0 0 0 0 ]
[ 1 .44467 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.12963 .01067 m
.12963 .22242 L
.12963 .22242 L
.12963 .01067 L
.12963 .01067 L
s
.12958 .22232 m
.34132 .43406 L
.34132 .43406 L
.12958 .22232 L
.12958 .22232 L
s
.12954 .01067 m
.49629 .22242 L
.49629 .22242 L
.12954 .01067 L
.12954 .01067 L
s
.5 g
.65121 .43401 m
.34119 .43401 L
.34119 .43401 L
.65121 .43401 L
.65121 .43401 L
F
0 g
.65121 .43401 m
.34119 .43401 L
.34119 .43401 L
.65121 .43401 L
.65121 .43401 L
s
.72862 .35652 m
.65111 .43403 L
.65111 .43403 L
.72862 .35652 L
.72862 .35652 L
s
.86281 .22233 m
.72856 .35658 L
.72856 .35658 L
.86281 .22233 L
.86281 .22233 L
s
.86286 .01067 m
.49611 .22242 L
.49611 .22242 L
.86286 .01067 L
.86286 .01067 L
s
.86277 .01067 m
.86277 .22242 L
.86277 .22242 L
.86277 .01067 L
.86277 .01067 L
s
.1295 .01059 m
.1295 .22233 L
.34124 .43408 L
.65126 .43408 L
.72876 .35657 L
.1295 .01059 L
s
.49608 .22238 m
.72859 .35662 L
.86284 .22238 L
.86284 .01063 L
.49608 .22238 L
s
.1295 .01059 m
.1295 .22233 L
.34124 .43408 L
.65126 .43408 L
.72876 .35657 L
.1295 .01059 L
s
.49608 .22238 m
.72859 .35662 L
.86284 .22238 L
.86284 .01063 L
.49608 .22238 L
s
.039 .916 .04 r
.02381 .06364 m
.12963 .06364 L
s
% Start of user PostScript
0 -2.5 5. -2.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12963 .06364 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .11655 m
.12963 .11655 L
s
% Start of user PostScript
0 0 5. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12963 .11655 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16946 m
.12963 .16946 L
s
% Start of user PostScript
0 2.5 5. 2.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12963 .16946 Mdot
.039 .916 .04 r
.5 Mabswid
.12963 .06364 m
.22127 .06364 L
s
% Start of user PostScript
5. -2.5 9.33013 -2.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.22127 .06364 Mdot
.039 .916 .04 r
.5 Mabswid
.12963 .11655 m
.31292 .11655 L
s
% Start of user PostScript
5. 0 13.6603 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.31292 .11655 Mdot
.039 .916 .04 r
.5 Mabswid
.12963 .16946 m
.40456 .16946 L
s
% Start of user PostScript
5. 2.5 17.9904 2.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40456 .16946 Mdot
.039 .916 .04 r
.5 Mabswid
.22127 .06364 m
.43511 .43401 L
s
% Start of user PostScript
9.33013 -2.5 19.4338 15. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.43511 .43401 Mdot
.039 .916 .04 r
.5 Mabswid
.31292 .11655 m
.4962 .43401 L
s
% Start of user PostScript
13.6603 0 22.3205 15. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.4962 .43401 Mdot
.039 .916 .04 r
.5 Mabswid
.40456 .16946 m
.5573 .43401 L
s
% Start of user PostScript
17.9904 2.5 25.2073 15. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5573 .43401 Mdot
.039 .916 .04 r
.5 Mabswid
.43511 .43401 m
.58784 .16946 L
s
% Start of user PostScript
19.4338 15. 26.6506 2.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.58784 .16946 Mdot
.039 .916 .04 r
.5 Mabswid
.4962 .43401 m
.67949 .11655 L
s
% Start of user PostScript
22.3205 15. 30.9808 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.67949 .11655 Mdot
.039 .916 .04 r
.5 Mabswid
.5573 .43401 m
.77113 .06364 L
s
% Start of user PostScript
25.2073 15. 35.3109 -2.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.77113 .06364 Mdot
.039 .916 .04 r
.5 Mabswid
.58784 .16946 m
.86277 .16946 L
s
% Start of user PostScript
26.6506 2.5 39.641 2.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.86277 .16946 Mdot
.039 .916 .04 r
.5 Mabswid
.67949 .11655 m
.86277 .11655 L
s
% Start of user PostScript
30.9808 0 39.641 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.86277 .11655 Mdot
.039 .916 .04 r
.5 Mabswid
.77113 .06364 m
.86277 .06364 L
s
% Start of user PostScript
35.3109 -2.5 39.641 -2.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.86277 .06364 Mdot
.039 .916 .04 r
.5 Mabswid
.86277 .16946 m
.97619 .16946 L
s
% Start of user PostScript
39.641 2.5 45. 2.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .16946 Mdot
.039 .916 .04 r
.5 Mabswid
.86277 .11655 m
.97619 .11655 L
s
% Start of user PostScript
39.641 0 45. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .11655 Mdot
.039 .916 .04 r
.5 Mabswid
.86277 .06364 m
.97619 .06364 L
s
% Start of user PostScript
39.641 -2.5 45. -2.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .06364 Mdot
0 0 m
1 0 L
1 .44467 L
0 .44467 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{369.438, 164.25},
  ImageMargins->{{148, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005a0000Y2000`400?l00000o`00003ooooooomb
ooooo`00oooooombooooo`00oooooombooooo`00oooooombooooo`00<?ooool2o`000?oooooo2ooo
ool2o`0003?ooooo000`ooooo`04o`000?oooooo0000o`000?oooooo1oooool2o`000003ooooool0
003ooooo03;ooooo000`ooooo`05o`000?ooooooooooooooool00000ooooool5ooooo`05o`000?oo
ooooooooooooool00000<oooool0033ooooo00?o0000ooooooooool00_ooool2o`000?oooooo0Ooo
ool2o`0000Cooooo00?o0000ooooooooool0<Oooool0033ooooo00?o0000ooooooooool01?ooool2
o`000?cooooo0_l00006ooooo`03o`000?oooooooooo037ooooo000`ooooo`03o`000?oooooooooo
00Kooooo0_l0003hooooo`;o00002?ooool00ol0003oooooooooo`0aooooo`00<?ooool00ol0003o
ooooooooo`07ooooo`;o0000m_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo037o
oooo000`ooooo`03o`000?oooooooooo00Wooooo0_l0003booooo`;o00002oooool00ol0003ooooo
ooooo`0aooooo`00<?ooool00ol0003oooooooooo`0;ooooo`;o0000k_ooool2o`0000gooooo00?o
0000ooooooooool0<Oooool0033ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3Z
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<Oooool0033ooooo00?o0000oooo
ooooool03_ooool2o`000>Sooooo0_l0000@ooooo`03o`000?oooooooooo037ooooo000`ooooo`03
o`000?oooooooooo013ooooo0_l0003Tooooo`;o00004_ooool00ol0003oooooooooo`0aooooo`00
<?ooool00ol0003oooooooooo`0Booooo`;o0000h?ooool2o`0001Cooooo00?o0000ooooooooool0
<Oooool0033ooooo00?o0000ooooooooool04oooool2o`000=kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0aooooo`00<?ooool00ol0003oooooooooo`0Eooooo`;o0000f_ooool2
o`0001Oooooo00?o0000ooooooooool0<Oooool0033ooooo00?o0000ooooooooool05oooool2o`00
0=Kooooo0_l0000Iooooo`03o`000?oooooooooo037ooooo000`ooooo`03o`000?oooooooooo01Wo
oooo0_l0003Booooo`;o00006oooool00ol0003oooooooooo`0aooooo`00<?ooool00ol0003ooooo
ooooo`0Jooooo`;o0000d?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo037ooooo
000Xooooo`?o2NX:1Oooool00ol0003oooooooooo`0Fooooo`?o2NX:0oooool2o`000<cooooo0_l0
000Fooooo`?o2NX:1Oooool00ol0003oooooooooo`0Oooooo`?o2NX:3oooool002Wooooo1_l9jPX2
o`0001Wooooo1_l9jPX00ooooooo0000o`000038ooooo`;o00006Oooool6o`WZ2P;o00008_ooool6
o`WZ2P;o00002Oooool000Wooooo9_l9jPX00ol0003o2NX:o`WZ2P0Po`WZ2P?o0000aOooool00ol0
003o2NX:o`WZ2P0Oo`WZ2P03o`000?l9jP[o2NX:02Oo2NX:0_l00009ooooo`00:Oooool5o`WZ2P;o
oooo00?o0000ooooooooool05oooool5o`WZ2P;ooooo00?o2NX:ooooooooool00_l00032ooooo`;o
000000?oooooo`WZ2_ooool06Oooool5o`WZ2P;ooooo00?o0000ooooooooool08?ooool5o`WZ2Pco
oooo000Xooooo`;o2NX:1_ooool00ol0003oooooooooo`0Fooooo`;o2NX:1oooool01?l9jP[ooooo
ooooooooool2o`000;kooooo0_l00002ooooo`;o2NX:6Oooool2o`WZ2PKooooo00?o0000oooooooo
ool07oooool2o`WZ2Q3ooooo000`ooooo`03o`000?oooooooooo01oooooo00?o2NX:ooooooooool0
0oooool2o`000;[ooooo0_l00003ooooo`;o2NX:8_ooool00ol0003oooooooooo`0aooooo`00<?oo
ool00ol0003oooooooooo`0Pooooo`03o`WZ2_oooooooooo00?ooooo0_l0002hooooo`03o`000?oo
oooooooo00;ooooo0ol9jPXRooooo`03o`000?oooooooooo037ooooo000`ooooo`03o`000?oooooo
oooo027ooooo00?o2NX:ooooooooool01?ooool2o`000;Cooooo0_l00004ooooo`Co2NX:8_ooool0
0ol0003oooooooooo`0aooooo`00<?ooool00ol0003oooooooooo`0Qooooo`03o`WZ2_oooooooooo
00Kooooo0_l0002`ooooo`;o00001Oooool00ol9jP[oooooo`WZ2P02o`WZ2R;ooooo00?o0000oooo
ooooool0<Oooool0033ooooo00?o0000ooooooooool08_ooool00ol9jP[oooooooooo`07ooooo`;o
0000[?ooool2o`0000Sooooo00?o2NX:ooooool9jPX08oooool00ol0003oooooooooo`0aooooo`00
<?ooool00ol0003oooooooooo`0Rooooo`03o`WZ2_oooooooooo00Sooooo0_l0002Zooooo`03o`00
0?oooooooooo00Sooooo00?o2NX:ooooool9jPX08oooool00ol0003oooooooooo`0aooooo`00<?oo
ool00ol0003oooooooooo`0Sooooo`03o`WZ2_oooooooooo00Wooooo0_l0002Vooooo`;o00002_oo
ool00ol9jP[oooooooooo`0Tooooo`03o`000?oooooooooo037ooooo000`ooooo`03o`000?oooooo
oooo02Cooooo00?o2NX:ooooooooool02_ooool2o`000:;ooooo0_l0000<ooooo`03o`WZ2_oooooo
oooo02Cooooo00?o0000ooooooooool0<Oooool0033ooooo00?o0000ooooooooool09?ooool00ol9
jP[oooooooooo`0;ooooo`?o0000W_ooool2o`0000gooooo00?o2NX:ooooooooool09Oooool00ol0
003oooooooooo`0aooooo`00<?ooool00ol0003oooooooooo`0Uooooo`03o`WZ2_oooooooooo00co
oooo0_l0002Looooo`03o`000?oooooooooo00cooooo00?o2NX:ooooooooool09_ooool00ol0003o
ooooooooo`0aooooo`00<?ooool00ol0003oooooooooo`0Uooooo`03o`WZ2_oooooooooo00kooooo
0_l0002Hooooo`;o00003oooool00ol9jP[oooooooooo`0Vooooo`03o`000?oooooooooo037ooooo
000`ooooo`03o`000?oooooooooo02Kooooo00?o2NX:ooooooooool03oooool2o`0009Cooooo0_l0
000@ooooo`03o`WZ2_oooooooooo02Oooooo00?o0000ooooooooool0<Oooool0033ooooo00?o0000
ooooooooool09_ooool00ol9jP[oooooooooo`0@ooooo`;o0000T_ooool00ol0003oooooooooo`0@
ooooo`03o`WZ2_oooooooooo02Oooooo00?o0000ooooooooool0<Oooool0033ooooo00?o0000oooo
ooooool09oooool00ol9jP[oooooooooo`0Aooooo`;o0000S_ooool2o`0001;ooooo00?o2NX:oooo
ooooool0:?ooool00ol0003oooooooooo`0aooooo`00:?ooool3o`WZ2PGooooo00?o0000oooooooo
ool0:?ooool00ol9jP[oooooooooo`0=ooooo`?o2NX:0_ooool2o`0008[ooooo0_l0000Dooooo`03
o`WZ2_oooooooooo023ooooo0ol9jPX5ooooo`03o`000?oooooooooo01oooooo0ol9jPX?ooooo`00
:Oooool6o`WZ2P03ooooool0003ooooo02Wooooo00?o2NX:ooooooooool03_ooool6o`WZ2P;o0000
Q_ooool2o`0001Gooooo00?o2NX:ooooooooool08_ooool6o`WZ2P03ooooool0003ooooo027ooooo
1_l9jPX;ooooo`002OoooolVo`WZ2P03o`000?l9jP[o2NX:04;o2NX:00?o0000ooooooooool0P_oo
ool00ol0003o2NX:o`WZ2P10o`WZ2P03o`000?l9jP[o2NX:02Oo2NX:0_l00009ooooo`00:Oooool5
o`WZ2P03ooooool0003o000002_ooooo00?o2NX:ooooooooool03Oooool5o`WZ2P;ooooo00Co2NX:
o`000?l0003o0000P?ooool4o`0001Gooooo00?o2NX:ooooooooool08oooool5o`WZ2P03ooooool0
003o000002;ooooo1Ol9jPX00ooooooo0000o`000009ooooo`00:?ooool2o`WZ2PKooooo00?o0000
ooooooooool0:_ooool00ol9jP[oooooooooo`0;ooooo`;o2NX:1oooool00ol9jP[oooooooooo`02
o`0007cooooo0_l000000ooooooo2NX:o`WZ2P0Eooooo`03o`WZ2_oooooooooo02?ooooo0_l9jPX6
ooooo`03o`000?oooooooooo01oooooo0_l9jPX@ooooo`00<?ooool00ol0003oooooooooo`0Zoooo
o`03o`WZ2_oooooooooo01Cooooo00Co2NX:oooooooooooooooo0ol0001hooooo`;o00000_ooool3
o`WZ2QGooooo00?o2NX:ooooooooool0:oooool00ol0003oooooooooo`0aooooo`00<?ooool00ol0
003oooooooooo`0[ooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool00_ooool2o`00
07Kooooo00Co0000oooooooooooooooo1?l9jPXDooooo`03o`WZ2_oooooooooo02cooooo00?o0000
ooooooooool0<Oooool0033ooooo00?o0000ooooooooool0;?ooool00ol9jP[oooooooooo`0Doooo
o`03o`WZ2_oooooooooo00?ooooo0_l0001booooo`;o00000oooool4o`WZ2QGooooo00?o2NX:oooo
ooooool0;?ooool00ol0003oooooooooo`0aooooo`00<?ooool00ol0003oooooooooo`0/ooooo`03
o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool01?ooool3o`0006kooooo0_l00004ooooo`;o
2NX:00?oooooo`WZ2_l9jPX05?ooool00ol9jP[oooooooooo`0]ooooo`03o`000?oooooooooo037o
oooo000`ooooo`03o`000?oooooooooo02gooooo00?o2NX:ooooooooool05?ooool00ol9jP[ooooo
ooooo`05ooooo`?o0000Joooool00ol0003oooooooooo`06ooooo`?o2NX:4oooool00ol9jP[ooooo
ooooo`0^ooooo`03o`000?oooooooooo037ooooo000`ooooo`03o`000?oooooooooo02gooooo00?o
2NX:ooooooooool05?ooool00ol9jP[oooooooooo`07ooooo`;o0000J?ooool2o`0000Wooooo0_l9
jPXDooooo`03o`WZ2_oooooooooo02kooooo00?o0000ooooooooool0<Oooool0033ooooo00?o0000
ooooooooool0;_ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo00Sooooo0_l0001T
ooooo`;o00002_ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo02oooooo00?o0000
ooooooooool0<Oooool0033ooooo00?o0000ooooooooool0;oooool00ol9jP[oooooooooo`0Coooo
o`03o`WZ2_oooooooooo00Wooooo0ol0001Pooooo`;o00002oooool00ol9jP[oooooooooo`0Doooo
o`03o`WZ2_oooooooooo02oooooo00?o0000ooooooooool0<Oooool0033ooooo00?o0000oooooooo
ool0;oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo00[ooooo0_l0001Nooooo`03
o`000?oooooooooo00_ooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`0`ooooo`03
o`000?oooooooooo037ooooo000`ooooo`03o`000?oooooooooo033ooooo00?o2NX:ooooooooool0
5?ooool00ol9jP[oooooooooo`0;ooooo`;o0000F_ooool2o`0000gooooo00?o2NX:ooooooooool0
5?ooool00ol9jP[oooooooooo`0`ooooo`03o`000?oooooooooo037ooooo000`ooooo`03o`000?oo
oooooooo033ooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0<ooooo`?o0000E_oo
ool2o`0000oooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`0aooooo`03o`000?oo
oooooooo037ooooo000`ooooo`03o`000?oooooooooo037ooooo00?o2NX:ooooooooool05?ooool0
0ol9jP[oooooooooo`0=ooooo`?o0000D_ooool2o`00013ooooo00?o2NX:ooooooooool04oooool0
0ol9jP[oooooooooo`0booooo`03o`000?oooooooooo037ooooo000`ooooo`03o`000?oooooooooo
037ooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0?ooooo`;o0000D?ooool00ol0
003oooooooooo`0@ooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool0<_ooool00ol0
003oooooooooo`0aooooo`00<?ooool00ol0003oooooooooo`0booooo`03o`WZ2_oooooooooo01Co
oooo00?o2NX:ooooooooool04?ooool2o`0004cooooo0_l0000Booooo`03o`WZ2_oooooooooo01?o
oooo00?o2NX:ooooooooool0<oooool00ol0003oooooooooo`0aooooo`00:?ooool3o`WZ2PGooooo
00?o0000ooooooooool0<oooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo00kooooo
0ol9jPX3o`0004Sooooo0_l0000Cooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool0
:oooool3o`WZ2PGooooo00?o0000ooooooooool07oooool3o`WZ2Poooooo000Yooooo`Ko2NX:00?o
ooooo`000?ooool0=?ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo00kooooo1_l9
jPX00ol0003oooooooooo`12ooooo`;o00005Oooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oo
oooooooo02gooooo1_l9jPX00ooooooo0000ooooo`0Qooooo`Ko2NX:2oooool000Wooooo9_l9jPX0
0ol0003o2NX:o`WZ2P1Ro`WZ2P03o`000?l9jP[ooooo043ooooo00?o0000o`WZ2_l9jPX0H_l9jPX0
0ol0003o2NX:o`WZ2P0Wo`WZ2P;o00002Oooool002Wooooo1Ol9jPX00ooooooo0000o`00000foooo
o`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool03Oooool5o`WZ2P03ooooool0003o2NX:
00;o0000?_ooool3o`0001Kooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`0^oooo
o`Go2NX:00?oooooo`000?l000008_ooool5o`WZ2P03ooooool0003o000000Wooooo000Xooooo`;o
2NX:1_ooool00ol0003oooooooooo`0eooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:oooooooo
ool02oooool2o`WZ2POooooo00Co2NX:o`000?l0003o0000>_ooool2o`0000?o2NX:5Oooool00ol9
jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo02kooooo0_l9jPX6ooooo`03o`000?oooooooooo
01oooooo0_l9jPX@ooooo`00<?ooool00ol0003oooooooooo`0fooooo`03o`WZ2_oooooooooo01?o
oooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`03o`0003Oooooo00?o0000ooooool9
jPX00_l9jPXFooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool0=_ooool00ol0003o
ooooooooo`0aooooo`00<?ooool00ol0003oooooooooo`0fooooo`03o`WZ2_oooooooooo01Cooooo
00?o2NX:ooooooooool05?ooool01?l9jP[oooooooooooooool2o`0003Cooooo0_l000000ooooooo
2NX:o`WZ2P02o`WZ2QGooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`0gooooo`03
o`000?oooooooooo037ooooo000`ooooo`03o`000?oooooooooo03Oooooo00?o2NX:ooooooooool0
4oooool00ol9jP[oooooooooo`0Eooooo`04o`WZ2_ooooooooooooooo`?o0000<?ooool2o`0000;o
oooo1Ol9jPXDooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool0=oooool00ol0003o
ooooooooo`0aooooo`00<?ooool00ol0003oooooooooo`0gooooo`03o`WZ2_oooooooooo01Cooooo
00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`03ooooo`?o0000;?ooool2o`0000?ooooo
1_l9jPXDooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool0>?ooool00ol0003ooooo
ooooo`0aooooo`00<?ooool00ol0003oooooooooo`0hooooo`03o`WZ2_oooooooooo01Cooooo00?o
2NX:ooooooooool05?ooool00ol9jP[oooooooooo`04ooooo`;o0000:_ooool00ol0003ooooooooo
o`05ooooo`?o2NX:5?ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo03Wooooo00?o
0000ooooooooool0<Oooool0033ooooo00?o0000ooooooooool0>?ooool00ol9jP[oooooooooo`0D
ooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool01_ooool2o`0002Kooooo0_l00008
ooooo`03o`WZ2_oooooo2NX:01Cooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`0i
ooooo`03o`000?oooooooooo037ooooo000`ooooo`03o`000?oooooooooo03Wooooo00?o2NX:oooo
ooooool05?ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo00Kooooo0ol0000Roooo
o`;o00002Oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:oooo
ooooool0>_ooool00ol0003oooooooooo`0aooooo`00<?ooool00ol0003oooooooooo`0jooooo`03
o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`08ooooo`?o
00007_ooool2o`0000_ooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`0Dooooo`03
o`WZ2_oooooooooo03[ooooo00?o0000ooooooooool0<Oooool0033ooooo00?o0000ooooooooool0
>_ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool0
2Oooool2o`0001cooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ
2_oooooooooo01?ooooo00?o2NX:ooooooooool0>oooool00ol0003oooooooooo`0aooooo`00<?oo
ool00ol0003oooooooooo`0kooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool05Ooo
ool00ol9jP[oooooooooo`09ooooo`?o00006?ooool2o`0000cooooo00?o2NX:ooooooooool05?oo
ool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo03_ooooo00?o0000ooooooooool0<Ooo
ool0033ooooo00?o0000ooooooooool0>oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooo
oooo01Cooooo00?o2NX:ooooooooool02oooool3o`0001Cooooo0_l0000>ooooo`03o`WZ2_oooooo
oooo01Cooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`0looooo`03o`000?oooooo
oooo037ooooo000`ooooo`03o`000?oooooooooo03cooooo00?o2NX:ooooooooool05?ooool00ol9
jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo00cooooo0ol0000Aooooo`03o`000?oooooooooo
00gooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo
03gooooo00?o0000ooooooooool0<Oooool0033ooooo00?o0000ooooooooool0??ooool00ol9jP[o
ooooooooo`0Dooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool03_ooool2o`0000ko
oooo0_l0000@ooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool04oooool00ol9jP[o
ooooooooo`0mooooo`03o`000?oooooooooo037ooooo000`ooooo`03o`000?oooooooooo03gooooo
00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo00kooooo
0ol0000:ooooo`;o00004Oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo01?ooooo
00?o2NX:ooooooooool0?_ooool00ol0003oooooooooo`0aooooo`00<?ooool00ol0003ooooooooo
o`0nooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool05?ooool00ol9jP[ooooooooo
o`0@ooooo`?o00001_ooool2o`0001?ooooo00?o2NX:ooooooooool04oooool00ol9jP[ooooooooo
o`0Dooooo`03o`WZ2_oooooooooo03kooooo00?o0000ooooooooool0<Oooool0033ooooo00?o0000
ooooooooool0?_ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:
ooooooooool04Oooool3o`0000?ooooo00?o0000ooooooooool04_ooool00ol9jP[oooooooooo`0D
ooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool0?oooool00ol0003oooooooooo`0a
ooooo`00<?ooool00ol0003oooooooooo`0oooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:oooo
ooooool05Oooool00ol9jP[oooooooooo`0Aooooo`Go00005?ooool00ol9jP[oooooooooo`0Doooo
o`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool0?oooool00ol0003oooooooooo`0aoooo
o`00<?ooool00ol0003oooooooooo`0oooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:oooooooo
ool05?ooool00ol9jP[oooooooooo`0Cooooo`?o00005?ooool00ol9jP[oooooooooo`0Dooooo`03
o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool0@?ooool00ol0003oooooooooo`0aooooo`00
<?ooool00ol0003oooooooooo`10ooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool0
5?ooool00ol9jP[oooooooooo`0Dooooo`?o00004Oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ
2_oooooooooo01?ooooo00?o2NX:ooooooooool0@?ooool00ol0003oooooooooo`0booooo`00<Ooo
ool00ol0003oooooooooo`10ooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool05?oo
ool00ol9jP[oooooooooo`0Fooooo`;o00004?ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oo
oooooooo01Cooooo00?o2NX:ooooooooool0?oooool00ol0003oooooooooo`0cooooo`00<_ooool0
0ol0003oooooooooo`0oooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool05?ooool0
0ol9jP[oooooooooo`0Fooooo`?o00003Oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooo
oooo01?ooooo00?o2NX:ooooooooool0?oooool00ol0003oooooooooo`0dooooo`00<oooool00ol0
003oooooooooo`0oooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool05?ooool00ol9
jP[oooooooooo`0Hooooo`?o00002oooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo
01Cooooo00?o2NX:ooooooooool0?_ooool00ol0003oooooooooo`0eooooo`00=?ooool00ol0003o
ooooooooo`0nooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool05?ooool00ol9jP[o
ooooooooo`0Iooooo`?o00002?ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo01?o
oooo00?o2NX:ooooooooool0?_ooool00ol0003oooooooooo`0fooooo`00=Oooool00ol0003ooooo
ooooo`0nooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool05Oooool00ol9jP[ooooo
ooooo`0Jooooo`;o00001_ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo01Cooooo
00?o2NX:ooooooooool0?Oooool00ol0003oooooooooo`0gooooo`00=_ooool00ol0003ooooooooo
o`0mooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool05?ooool00ol9jP[ooooooooo
o`0Kooooo`?o00001?ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo01?ooooo00?o
2NX:ooooooooool0?Oooool00ol0003oooooooooo`0hooooo`00=oooool00ol0003oooooooooo`0m
ooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0L
ooooo`?o000000?oooooo`WZ2_ooool05Oooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooo
oooo03gooooo00?o0000ooooooooool0>Oooool003Sooooo00?o0000ooooooooool0?Oooool00ol9
jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool07_ooool2o`00
0003o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0loooo
o`03o`000?oooooooooo03[ooooo000iooooo`03o`000?oooooooooo03cooooo00?o2NX:oooooooo
ool05?ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:o`000?l0
00005?ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo03cooooo00?o0000oooooooo
ool0>oooool003[ooooo00?o0000ooooooooool0??ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ
2_oooooooooo01Cooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooo`000002o`00017ooooo
00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0kooooo`03o`000?oooooooooo03cooooo
000kooooo`03o`000?oooooooooo03_ooooo00?o2NX:ooooooooool05?ooool00ol9jP[ooooooooo
o`0Dooooo`03o`WZ2_oooooooooo01cooooo00?o2NX:ooooooooool00_ooool3o`0000oooooo00?o
2NX:ooooooooool04oooool00ol9jP[oooooooooo`0kooooo`03o`000?oooooooooo03gooooo000l
ooooo`03o`000?oooooooooo03_ooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`0E
ooooo`03o`WZ2_oooooooooo01[ooooo00?o2NX:ooooooooool01Oooool3o`0000cooooo00?o2NX:
ooooooooool05?ooool00ol9jP[oooooooooo`0jooooo`03o`000?oooooooooo03kooooo000moooo
o`03o`000?oooooooooo03_ooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`0Doooo
o`03o`WZ2_oooooooooo01[ooooo00?o2NX:ooooooooool01oooool2o`0000[ooooo00?o2NX:oooo
ooooool05?ooool00ol9jP[oooooooooo`0jooooo`03o`000?oooooooooo03oooooo000nooooo`03
o`000?oooooooooo03[ooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0Dooooo`03
o`WZ2_oooooooooo01Sooooo00?o2NX:ooooooooool02Oooool3o`0000Sooooo00?o2NX:oooooooo
ool04oooool00ol9jP[oooooooooo`0jooooo`03o`000?oooooooooo043ooooo000oooooo`03o`00
0?oooooooooo03[ooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ
2_oooooooooo01Sooooo00?o2NX:ooooooooool02oooool3o`0000Gooooo00?o2NX:ooooooooool0
5?ooool00ol9jP[oooooooooo`0iooooo`03o`000?oooooooooo047ooooo0010ooooo`03o`000?oo
oooooooo03Wooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oo
oooooooo01Kooooo00?o2NX:ooooooooool03_ooool2o`0000Cooooo00?o2NX:ooooooooool04ooo
ool00ol9jP[oooooooooo`0iooooo`03o`000?oooooooooo04;ooooo0011ooooo`03o`000?oooooo
oooo03Wooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooo
oooo01Kooooo00?o2NX:ooooooooool04?ooool2o`000003ooooool9jP[ooooo01Gooooo00?o2NX:
ooooooooool0>?ooool00ol0003oooooooooo`13ooooo`00@_ooool00ol0003oooooooooo`0hoooo
o`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0Doooo
o`03o`WZ2_oooooooooo01;ooooo0_l000000ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo
03Sooooo00?o0000ooooooooool0A?ooool004?ooooo00?o0000ooooooooool0>?ooool00ol9jP[o
ooooooooo`0Dooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool04_ooool00ol9jP[o
ooooooooo`0Dooooo`04o`WZ2_l0003o0000o`0001?ooooo00?o2NX:ooooooooool0=oooool00ol0
003oooooooooo`15ooooo`00A?ooool00ol0003oooooooooo`0hooooo`03o`WZ2_oooooooooo01?o
oooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0Booooo`03o`WZ2_oooooooooo01?o
oooo00Co2NX:oooooooooooooooo0_l0000Aooooo`03o`WZ2_oooooooooo03Oooooo00?o0000oooo
ooooool0A_ooool004Gooooo00?o0000ooooooooool0=oooool00ol9jP[oooooooooo`0Dooooo`03
o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool04?ooool00ol9jP[oooooooooo`0Dooooo`03
o`WZ2_oooooooooo00?ooooo0_l0000>ooooo`03o`WZ2_oooooooooo03Oooooo00?o0000oooooooo
ool0Aoooool004Kooooo00?o0000ooooooooool0=oooool00ol9jP[oooooooooo`0Cooooo`03o`WZ
2_oooooooooo01Cooooo00?o2NX:ooooooooool04?ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ
2_oooooooooo00Gooooo0ol0000<ooooo`03o`WZ2_oooooooooo03Kooooo00?o0000ooooooooool0
B?ooool004Oooooo00?o0000ooooooooool0=_ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oo
oooooooo01Cooooo00?o2NX:ooooooooool03_ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oo
oooooooo00Oooooo0ol00009ooooo`03o`WZ2_oooooooooo03Kooooo00?o0000ooooooooool0BOoo
ool004Sooooo00?o0000ooooooooool0=_ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooo
oooo01Cooooo00?o2NX:ooooooooool03_ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooo
oooo00[ooooo0_l00008ooooo`03o`WZ2_oooooooooo03Gooooo00?o0000ooooooooool0B_ooool0
04Wooooo00?o0000ooooooooool0=_ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo
01Cooooo00?o2NX:ooooooooool03?ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo
00cooooo0_l00005ooooo`03o`WZ2_oooooooooo03Gooooo00?o0000ooooooooool0Boooool004[o
oooo00?o0000ooooooooool0=Oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo01Co
oooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo00oo
oooo0_l00003ooooo`03o`WZ2_oooooooooo03Cooooo00?o0000ooooooooool0C?ooool004_ooooo
00?o0000ooooooooool0=Oooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo01Cooooo
00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo017ooooo
0_l000000ooooooo2NX:ooooo`0eooooo`03o`000?oooooooooo04gooooo001<ooooo`03o`000?oo
oooooooo03Cooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oo
oooooooo00Sooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_l0
003ooooo03Cooooo00?o0000ooooooooool0C_ooool004gooooo00?o0000ooooooooool0=?ooool0
0ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool02?ooool0
0ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo01Cooooo00Co2NX:ooooool0003o0000<_oo
ool00ol0003oooooooooo`1?ooooo`00C_ooool00ol0003oooooooooo`0cooooo`03o`WZ2_oooooo
oooo01Cooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooo
oooo01Cooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`02ooooo`;o0000;oooool0
0ol0003oooooooooo`1@ooooo`00Coooool00ol0003oooooooooo`0cooooo`03o`WZ2_oooooooooo
01?ooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo
01?ooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`03ooooo`;o0000;Oooool00ol0
003oooooooooo`1Aooooo`00D?ooool00ol0003oooooooooo`0cooooo`03o`WZ2_oooooooooo01?o
oooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo01?o
oooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`06ooooo`;o0000:_ooool00ol0003o
ooooooooo`1Booooo`00DOooool00ol0003oooooooooo`0booooo`03o`WZ2_oooooooooo01Cooooo
00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo01Cooooo
00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`08ooooo`;o00009oooool00ol0003ooooo
ooooo`1Cooooo`00D_ooool00ol0003oooooooooo`0booooo`03o`WZ2_oooooooooo01?ooooo00?o
2NX:ooooooooool05?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo01?ooooo00?o
2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0;ooooo`;o00009?ooool00ol0003ooooooooo
o`1Dooooo`00Doooool00ol0003oooooooooo`0aooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:
ooooooooool05?ooool01?l9jP[oooooooooool9jPXFooooo`03o`WZ2_oooooooooo01?ooooo00?o
2NX:ooooooooool03Oooool2o`0002;ooooo00?o0000ooooooooool0EOooool005Cooooo00?o0000
ooooooooool0<Oooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo01Cooooo00Co2NX:
oooooooooooo2NX:5Oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo00oooooo0_l0
000Oooooo`03o`000?oooooooooo05Kooooo001Eooooo`03o`000?oooooooooo033ooooo00?o2NX:
ooooooooool05?ooool00ol9jP[oooooooooo`0Dooooo`;o2NX:5_ooool00ol9jP[oooooooooo`0C
ooooo`03o`WZ2_oooooooooo01;ooooo0_l0000Looooo`03o`000?oooooooooo05Oooooo001Foooo
o`03o`000?oooooooooo033ooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`0Doooo
o`;o2NX:5Oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo01Cooooo0_l0000Ioooo
o`03o`000?oooooooooo05Sooooo001Gooooo`03o`000?oooooooooo033ooooo00?o2NX:oooooooo
ool04oooool00ol9jP[oooooooooo`0Cooooo`;o2NX:5?ooool00ol9jP[oooooooooo`0Dooooo`03
o`WZ2_oooooooooo01Kooooo0_l0000Gooooo`03o`000?oooooooooo05Wooooo001Hooooo`03o`00
0?oooooooooo02oooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0Aooooo`04o`WZ
2_ooooooooooo`WZ2Q?ooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0Hooooo`;o
00005?ooool00ol0003oooooooooo`1Jooooo`00FOooool00ol0003oooooooooo`0_ooooo`03o`WZ
2_oooooooooo01?ooooo00?o2NX:ooooooooool04Oooool01?l9jP[oooooooooool9jPXBooooo`03
o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool06oooool2o`00017ooooo00?o0000oooooooo
ool0Foooool005[ooooo00?o0000ooooooooool0;_ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ
2_oooooooooo00oooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`0?ooooo`03o`WZ
2_oooooooooo01?ooooo00?o2NX:ooooooooool07_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo05cooooo001Kooooo`03o`000?oooooooooo02kooooo00?o2NX:ooooooooool04ooo
ool00ol9jP[oooooooooo`0?ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool03_oo
ool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo01oooooo0_l0000<ooooo`03o`000?oo
oooooooo05gooooo001Looooo`03o`000?oooooooooo02kooooo00?o2NX:ooooooooool04oooool0
0ol9jP[oooooooooo`0=ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool03?ooool0
0ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo02;ooooo0_l00009ooooo`03o`000?oooooo
oooo05kooooo001Mooooo`03o`000?oooooooooo02gooooo00?o2NX:ooooooooool04oooool00ol9
jP[oooooooooo`0=ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool03?ooool00ol9
jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo02Cooooo0_l00006ooooo`03o`000?oooooooooo
05oooooo001Nooooo`03o`000?oooooooooo02gooooo00?o2NX:ooooooooool04oooool00ol9jP[o
ooooooooo`0;ooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool02_ooool00ol9jP[o
ooooooooo`0Dooooo`03o`WZ2_oooooooooo02Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Pooooo`00Goooool00ol0003oooooooooo`0/ooooo`03o`WZ2_oooooooooo01Cooooo
00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00Wooooo
00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`0Yooooo`;o000000?oooooo`000?ooool0
H_ooool0063ooooo00?o0000ooooooooool0;?ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oo
oooooooo00Wooooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oo
oooooooo01Cooooo00?o2NX:ooooooooool0:oooool00ol0003oooooooooo`1Rooooo`00HOooool0
0ol0003oooooooooo`0[ooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool01oooool0
0ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool04oooool0
0ol9jP[oooooooooo`0[ooooo`03o`000?oooooooooo06?ooooo001Rooooo`03o`000?oooooooooo
02_ooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo
00[ooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo
02[ooooo00?o0000ooooooooool0I?ooool006?ooooo00?o0000ooooooooool0:oooool00ol9jP[o
ooooooooo`0Cooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool03?ooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool0:_ooool00ol0003o
ooooooooo`1Uooooo`00I?ooool00ol0003oooooooooo`0Zooooo`03o`WZ2_oooooooooo01?ooooo
00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`0<ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0Yooooo`03o`000?oooooooooo06Kooooo
001Uooooo`03o`000?oooooooooo02[ooooo00?o2NX:ooooooooool04oooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00kooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`0Dooooo`03o`WZ2_oooooooooo02Wooooo00?o0000ooooooooool0Ioooool006Kooooo00?o0000
ooooooooool0:Oooool00ol9jP[oooooooooo`0Dooooo`05o`WZ2_ooooooooooooooool9jPX04_oo
ool01Ol9jP[ooooooooooooooooo2NX:01Gooooo00?o2NX:ooooooooool0:Oooool00ol0003ooooo
ooooo`1Xooooo`00Ioooool00ol0003oooooooooo`0Yooooo`03o`WZ2_oooooooooo01?ooooo00Go
2NX:ooooooooooooooooo`WZ2P0Booooo`04o`WZ2_ooooooooooo`WZ2QKooooo00?o2NX:oooooooo
ool0:?ooool00ol0003oooooooooo`1Yooooo`00J?ooool00ol0003oooooooooo`0Yooooo`03o`WZ
2_oooooooooo01?ooooo00?o2NX:ooooool9jPX05?ooool2o`WZ2QKooooo00?o2NX:ooooooooool0
:?ooool00ol0003oooooooooo`1Zooooo`00JOooool00ol0003oooooooooo`0Xooooo`03o`WZ2_oo
oooooooo01?ooooo00?o2NX:ooooool9jPX05?ooool2o`WZ2QKooooo00?o2NX:ooooooooool09ooo
ool00ol0003oooooooooo`1[ooooo`00J_ooool00ol0003oooooooooo`0Xooooo`03o`WZ2_oooooo
oooo01?ooooo00?o2NX:ooooooooool04oooool2o`WZ2QGooooo00?o2NX:ooooooooool09oooool0
0ol0003oooooooooo`1/ooooo`00Joooool00ol0003oooooooooo`0Wooooo`03o`WZ2_oooooooooo
01?ooooo00?o2NX:ooooooooool04oooool2o`WZ2QGooooo00?o2NX:ooooooooool09_ooool00ol0
003oooooooooo`1]ooooo`00K?ooool00ol0003oooooooooo`0Wooooo`03o`WZ2_oooooooooo017o
oooo00?o2NX:ooooool9jPX04oooool01?l9jP[oooooooooool9jPXCooooo`03o`WZ2_oooooooooo
02Kooooo00?o0000ooooooooool0K_ooool006gooooo00?o0000ooooooooool09_ooool00ol9jP[o
ooooooooo`0@ooooo`05o`WZ2_ooooooooooooooool9jPX04_ooool01Ol9jP[ooooooooooooooooo
2NX:017ooooo00?o2NX:ooooooooool09_ooool00ol0003oooooooooo`1_ooooo`00K_ooool00ol0
003oooooooooo`0Vooooo`03o`WZ2_oooooooooo00oooooo00Go2NX:ooooooooooooooooo`WZ2P0A
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool03oooool00ol9jP[oooooooooo`0U
ooooo`03o`000?oooooooooo073ooooo001_ooooo`03o`000?oooooooooo02Kooooo00?o2NX:oooo
ooooool03Oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00gooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`0=ooooo`03o`WZ2_oooooooooo02Gooooo00?o0000oooo
ooooool0LOooool0073ooooo00?o0000ooooooooool09Oooool00ol9jP[oooooooooo`0=ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool03Oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00gooooo00?o2NX:ooooooooool09?ooool00ol0003oooooooooo`1booooo`00
LOooool00ol0003oooooooooo`0Uooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool0
1Oooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool0
2oooool00ol9jP[oooooooooo`0Tooooo`03o`000?oooooooooo07?ooooo001booooo`03o`000?oo
oooooooo02Cooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oo
oooooooo00_ooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oo
oooooooo02?ooooo00?o0000ooooooooool0M?ooool007?ooooo00?o0000ooooooooool09?ooool0
0ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool02Oooool0
0ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool08oooool0
0ol0003oooooooooo`1eooooo`00M?ooool00ol0003oooooooooo`0Sooooo`03o`WZ2_oooooooooo
00Sooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`0Sooooo`03o`000?oooooooooo
07Kooooo001eooooo`03o`000?oooooooooo02?ooooo00Co2NX:oooooooooooo2NX:1_ooool00ol9
jP[oooooooooo`09ooooo`04o`WZ2_ooooooooooo`WZ2PKooooo00?o2NX:ooooooooool02_ooool0
0ol9jP[oooooo`WZ2P07ooooo`03o`WZ2_oooooooooo02;ooooo00?o0000ooooooooool0Moooool0
07Kooooo00?o0000ooooooooool08oooool00ol9jP[oooooo`WZ2P05ooooo`03o`WZ2_oooooooooo
00_ooooo00?o2NX:ooooool9jPX01Oooool00ol9jP[oooooooooo`0<ooooo`;o2NX:1_ooool00ol9
jP[oooooooooo`0Rooooo`03o`000?oooooooooo07Sooooo001gooooo`03o`000?oooooooooo023o
oooo1Ol9jPX5ooooo`03o`WZ2_oooooooooo00[ooooo1?l9jPX5ooooo`03o`WZ2_oooooooooo00[o
oooo1Ol9jPX5ooooo`03o`WZ2_oooooooooo027ooooo00?o0000ooooooooool0NOooool007Sooooo
00?o0000ooooooooool08?ooool5o`WZ2P?ooooo00?o2NX:ooooooooool02oooool5o`WZ2P?ooooo
00?o2NX:ooooooooool03?ooool4o`WZ2PCooooo00?o2NX:ooooooooool08Oooool00ol0003ooooo
ooooo`1jooooo`00NOooool00ol0003oooooooooo`0Pooooo`Co2NX:0oooool00ol9jP[ooooooooo
o`0<ooooo`Co2NX:0oooool00ol9jP[oooooooooo`0=ooooo`?o2NX:1?ooool00ol9jP[ooooooooo
o`0Pooooo`03o`000?oooooooooo07_ooooo001jooooo`03o`000?oooooooooo023ooooo0ol9jPX2
ooooo`03o`WZ2_oooooooooo00kooooo0ol9jPX2ooooo`03o`WZ2_oooooooooo00oooooo0ol9jPX2
ooooo`03o`WZ2_oooooooooo023ooooo00?o0000ooooooooool0O?ooool007_ooooo00?o0000oooo
ooooool08?ooool2o`WZ2P03ooooool9jP[ooooo017ooooo0_l9jPX00ooooooo2NX:ooooo`0Boooo
o`;o2NX:00?oooooo`WZ2_ooool08Oooool00ol0003oooooooooo`1mooooo`00O?ooool00ol0003o
ooooo`00000Pooooo`;o000000?o2NX:ooooooooool04Oooool00ol9jP[o0000o`WZ2P0Dooooo`;o
000000?o2NX:ooooooooool07_ooool2o`00083ooooo001mooooob?o000000?o2NX:o`000?l00000
4ol000000ol9jP[o0000o`00000Do`000003o`WZ2_l0003o0000023o0000POooool00?ooooooL_oo
ool00?ooooooL_ooool00?ooooooL_ooool00001\
\>"],
  ImageRangeCache->{{{0, 368.438}, {163.25, 0}} -> {-1.20962, -5.507, \
0.128704, 0.128704}},
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[
{LineOfRays[8],
Move[PentaPrism[10,10],3],
Boundary[20,GraphicDesign->Off]},
PlotType->TopView];\
\>", "Input",
  CellTags->"Prism Examples"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11665 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.055546 0.582047 0.055546 [
[ 0 0 0 0 ]
[ 1 1.11665 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.19045 .30418 m
.19045 .85992 L
.19045 .85992 L
.19045 .30418 L
.19045 .30418 L
s
.5 g
.19031 .85972 m
.74605 1.08991 L
.74605 1.08991 L
.19031 .85972 L
.19031 .85972 L
F
0 g
.19031 .85972 m
.74605 1.08991 L
.74605 1.08991 L
.19031 .85972 L
.19031 .85972 L
s
.5 g
.97604 .85972 m
.74585 1.08991 L
.74585 1.08991 L
.97604 .85972 L
.97604 .85972 L
F
0 g
.97604 .85972 m
.74585 1.08991 L
.74585 1.08991 L
.97604 .85972 L
.97604 .85972 L
s
.5 g
.74585 .30418 m
.97604 .85992 L
.97604 .85992 L
.74585 .30418 L
.74585 .30418 L
F
0 g
.74585 .30418 m
.97604 .85992 L
.97604 .85992 L
.74585 .30418 L
.74585 .30418 L
s
.19031 .30432 m
.74605 .30432 L
.74605 .30432 L
.19031 .30432 L
.19031 .30432 L
s
.19026 .30413 m
.19026 .85987 L
.746 1.09006 L
.97619 .85987 L
.746 .30413 L
.19026 .30413 L
s
.19026 .30413 m
.19026 .85987 L
.746 1.09006 L
.97619 .85987 L
.746 .30413 L
.19026 .30413 L
s
.039 .916 .04 r
.02381 .35986 m
.19045 .35986 L
s
% Start of user PostScript
0 -4. 3. -4. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19045 .35986 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .58205 m
.19045 .58205 L
s
% Start of user PostScript
0 0 3. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19045 .58205 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .80423 m
.19045 .80423 L
s
% Start of user PostScript
0 4. 3. 4. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19045 .80423 Mdot
.039 .916 .04 r
.5 Mabswid
.19045 .35986 m
.76892 .35986 L
s
% Start of user PostScript
3. -4. 13.4142 -4. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.76892 .35986 Mdot
.039 .916 .04 r
.5 Mabswid
.19045 .58205 m
.86095 .58205 L
s
% Start of user PostScript
3. 0 15.0711 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.86095 .58205 Mdot
.039 .916 .04 r
.5 Mabswid
.19045 .80423 m
.95298 .80423 L
s
% Start of user PostScript
3. 4. 16.7279 4. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.95298 .80423 Mdot
.039 .916 .04 r
.5 Mabswid
.76892 .35986 m
.24599 .88279 L
s
% Start of user PostScript
13.4142 -4. 4. 5.41421 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.24599 .88279 Mdot
.039 .916 .04 r
.5 Mabswid
.86095 .58205 m
.46818 .97482 L
s
% Start of user PostScript
15.0711 0 8. 7.07107 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.46818 .97482 Mdot
.039 .916 .04 r
.5 Mabswid
.95298 .80423 m
.69036 1.06685 L
s
% Start of user PostScript
16.7279 4. 12. 8.72792 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69036 1.06685 Mdot
.039 .916 .04 r
.5 Mabswid
.24599 .88279 m
.24599 .30432 L
s
% Start of user PostScript
4. 5.41421 4. -5. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.24599 .30432 Mdot
.039 .916 .04 r
.5 Mabswid
.46818 .97482 m
.46818 .30432 L
s
% Start of user PostScript
8. 7.07107 8. -5. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.46818 .30432 Mdot
.039 .916 .04 r
.5 Mabswid
.69036 1.06685 m
.69036 .30432 L
s
% Start of user PostScript
12. 8.72792 12. -5. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69036 .30432 Mdot
.039 .916 .04 r
.5 Mabswid
.24599 .30432 m
.24599 .02659 L
s
% Start of user PostScript
4. -5. 4. -10. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.24599 .02659 Mdot
.039 .916 .04 r
.5 Mabswid
.46818 .30432 m
.46818 .02659 L
s
% Start of user PostScript
8. -5. 8. -10. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.46818 .02659 Mdot
.039 .916 .04 r
.5 Mabswid
.69036 .30432 m
.69036 .02659 L
s
% Start of user PostScript
12. -5. 12. -10. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69036 .02659 Mdot
0 0 m
1 0 L
1 1.11665 L
0 1.11665 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{244.375, 272.875},
  ImageMargins->{{222, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003d000142000`400?l00000o`00003om?ooool0
0?Cooooo003dooooo`00m?ooool00?Cooooo003dooooo`00>oooool2o`0003Cooooo0_l0000doooo
o`;o0000Boooool003_ooooo0_l0000dooooo`;o0000=?ooool2o`0004_ooooo000kooooo`03o`WZ
2_oooooooooo03?ooooo00?o2NX:ooooooooool0=?ooool00ol9jP[oooooooooo`19ooooo`00>_oo
ool3o`WZ2S?ooooo0ol9jPXdooooo`?o2NX:B_ooool003[ooooo0ol9jPXcooooo`?o2NX:=?ooool3
o`WZ2T[ooooo000jooooo`?o2NX:<oooool3o`WZ2SCooooo0ol9jPY:ooooo`00>_ooool3o`WZ2S?o
oooo0ol9jPXdooooo`?o2NX:B_ooool003Wooooo1Ol9jPXaooooo`Go2NX:<_ooool5o`WZ2TWooooo
000iooooo`05o`WZ2_oooooo2NX:ooooool9jPX0<Oooool01Ol9jP[oooooo`WZ2_oooooo2NX:03;o
oooo00Go2NX:ooooool9jP[oooooo`WZ2P19ooooo`00>oooool00ol9jP[oooooooooo`0cooooo`03
o`WZ2_oooooooooo03Cooooo00?o2NX:ooooooooool0BOooool003_ooooo00?o2NX:ooooooooool0
<oooool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo04Wooooo000kooooo`03o`WZ2_oo
oooooooo03?ooooo00?o2NX:ooooooooool0=?ooool00ol9jP[oooooooooo`19ooooo`00>oooool0
0ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo03Cooooo00?o2NX:ooooooooool0BOooool0
03_ooooo00?o2NX:ooooooooool0<oooool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo
04Wooooo000kooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool0=?ooool00ol9jP[o
ooooooooo`19ooooo`00>oooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo03Cooooo
00?o2NX:ooooooooool0BOooool003_ooooo00?o2NX:ooooooooool0<oooool00ol9jP[ooooooooo
o`0dooooo`03o`WZ2_oooooooooo04Wooooo000kooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:
ooooooooool0=?ooool00ol9jP[oooooooooo`19ooooo`00>oooool00ol9jP[oooooooooo`0coooo
o`03o`WZ2_oooooooooo03Cooooo00?o2NX:ooooooooool0BOooool003_ooooo00?o2NX:oooooooo
ool0<oooool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo04Wooooo000kooooo`03o`WZ
2_oooooooooo03?ooooo00?o2NX:ooooooooool0=?ooool00ol9jP[oooooooooo`19ooooo`00>ooo
ool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo03Cooooo00?o2NX:ooooooooool0BOoo
ool003_ooooo00?o2NX:ooooooooool0<oooool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooo
oooo04Wooooo000kooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool0=?ooool00ol9
jP[oooooooooo`19ooooo`00>oooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo03Co
oooo00?o2NX:ooooooooool0BOooool003_ooooo00?o2NX:ooooooooool0<oooool00ol9jP[ooooo
ooooo`0dooooo`03o`WZ2_oooooooooo04Wooooo000kooooo`03o`WZ2_oooooooooo03?ooooo00?o
2NX:ooooooooool0=?ooool00ol9jP[oooooooooo`19ooooo`00>oooool00ol9jP[oooooooooo`0c
ooooo`03o`WZ2_oooooooooo03Cooooo00?o2NX:ooooooooool0BOooool003_ooooo00?o2NX:oooo
ooooool0<oooool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo04Wooooo000kooooo`03
o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool0=?ooool00ol9jP[oooooooooo`19ooooo`00
>oooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo03Cooooo00?o2NX:ooooooooool0
BOooool003_ooooo00?o2NX:ooooooooool0<oooool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oo
oooooooo04Wooooo000kooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool0=?ooool0
0ol9jP[oooooooooo`19ooooo`00>oooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo
03Cooooo00?o2NX:ooooooooool0BOooool003_ooooo00?o2NX:ooooooooool0<oooool00ol9jP[o
ooooooooo`0dooooo`03o`WZ2_oooooooooo04Wooooo000kooooo`03o`WZ2_oooooooooo03?ooooo
00?o2NX:ooooooooool0=?ooool00ol9jP[oooooooooo`19ooooo`00>oooool00ol9jP[ooooooooo
o`0cooooo`03o`WZ2_oooooooooo03Cooooo00?o2NX:ooooooooool0BOooool003_ooooo00?o2NX:
ooooooooool0<oooool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo04Wooooo000koooo
o`03o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool0=?ooool00ol9jP[oooooooooo`19oooo
o`00>oooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo03Cooooo00?o2NX:oooooooo
ool0BOooool003_ooooo00?o2NX:ooooooooool0<oooool00ol9jP[oooooooooo`0dooooo`03o`WZ
2_oooooooooo04Wooooo000kooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool0=?oo
ool00ol9jP[oooooooooo`19ooooo`00>oooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooo
oooo03Cooooo00?o2NX:ooooooooool0BOooool003_ooooo00?o2NX:ooooooooool0<oooool00ol9
jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo04Wooooo000kooooo`03o`WZ2_oooooooooo03?o
oooo00?o2NX:ooooooooool0=?ooool00ol9jP[oooooooooo`19ooooo`00>oooool00ol9jP[ooooo
ooooo`0cooooo`03o`WZ2_oooooooooo03Cooooo00?o2NX:ooooooooool0BOooool003_ooooo00?o
2NX:ooooooooool0<oooool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo04Wooooo000k
ooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool0=?ooool00ol9jP[oooooooooo`19
ooooo`00>oooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo03Cooooo00?o2NX:oooo
ooooool0BOooool003_ooooo00?o2NX:ooooooooool0<oooool00ol9jP[oooooooooo`0dooooo`03
o`WZ2_oooooooooo04Wooooo000kooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool0
=?ooool00ol9jP[oooooooooo`19ooooo`00>oooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oo
oooooooo03Cooooo00?o2NX:ooooooooool0BOooool003_ooooo00?o2NX:ooooooooool0<oooool0
0ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo04Wooooo000kooooo`03o`WZ2_oooooooooo
03?ooooo00?o2NX:ooooooooool0=?ooool00ol9jP[oooooooooo`19ooooo`00>oooool00ol9jP[o
ooooooooo`0cooooo`03o`WZ2_oooooooooo03Cooooo00?o2NX:ooooooooool0BOooool003_ooooo
00?o2NX:ooooooooool0<oooool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo04Wooooo
000kooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool0=?ooool00ol9jP[ooooooooo
o`19ooooo`00>oooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo03Cooooo00?o2NX:
ooooooooool0BOooool003_ooooo00?o2NX:ooooooooool0<oooool00ol9jP[oooooooooo`0doooo
o`03o`WZ2_oooooooooo04Wooooo000kooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:oooooooo
ool0=?ooool00ol9jP[oooooooooo`19ooooo`00>oooool00ol9jP[oooooooooo`0cooooo`03o`WZ
2_oooooooooo03Cooooo00?o2NX:ooooooooool0BOooool003_ooooo00?o2NX:ooooooooool0<ooo
ool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo04Wooooo000kooooo`03o`WZ2_oooooo
oooo03?ooooo00?o2NX:ooooooooool0=?ooool00ol9jP[oooooooooo`19ooooo`00>oooool00ol9
jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo03Cooooo00?o2NX:ooooooooool0BOooool003_o
oooo00?o2NX:ooooooooool0<oooool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo04Wo
oooo000kooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool0=?ooool00ol9jP[ooooo
ooooo`19ooooo`00>oooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo03Cooooo00?o
2NX:ooooooooool0BOooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[o0000ooooo`0c
ooooo`03o`WZ2_l0003ooooo03?ooooo00?o0000o`WZ2_ooool02oooool00ol0003oooooooooo`0l
ooooo`00;_ooool=o`000003o`WZ2_l0003o000003?o000000?o2NX:o`000?l00000=?l000000ol9
jP[o0000o`00000;o`0003kooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o2NX:oooooooo
ool0<oooool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo00[ooooo00?o0000oooooooo
ool0??ooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ
2_oooooooooo03Cooooo00?o2NX:ooooooooool02oooool00ol0003oooooooooo`0kooooo`00;_oo
ool00ol0003oooooooooo`09ooooo`?o2NX:<oooool3o`WZ2SCooooo0ol9jPX<ooooo`03o`000?oo
oooooooo03_ooooo000^ooooo`03o`000?oooooooooo00Wooooo0ol9jPXcooooo`?o2NX:=?ooool3
o`WZ2Pcooooo00?o0000ooooooooool0>oooool002kooooo00?o0000ooooooooool02Oooool3o`WZ
2S?ooooo0ol9jPXdooooo`?o2NX:3Oooool00ol0003oooooooooo`0jooooo`00;_ooool00ol0003o
ooooooooo`09ooooo`?o2NX:<oooool3o`WZ2SCooooo0ol9jPX=ooooo`03o`000?oooooooooo03[o
oooo000^ooooo`03o`000?oooooooooo00Sooooo1Ol9jPXaooooo`Go2NX:<_ooool5o`WZ2Pgooooo
00?o0000ooooooooool0>Oooool002kooooo00?o0000ooooooooool02?ooool01Ol9jP[oooooo`WZ
2_oooooo2NX:037ooooo00Go2NX:ooooool9jP[oooooo`WZ2P0booooo`05o`WZ2_oooooo2NX:oooo
ool9jPX03Oooool00ol0003oooooooooo`0iooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03
o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool0=?ooool00ol9jP[oooooooooo`0>ooooo`03
o`000?oooooooooo03Sooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool0
<oooool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo00kooooo00?o0000ooooooooool0
>?ooool002Kooooo0ol9jPX5ooooo`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool0<ooo
ool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo00Sooooo0ol9jPX3ooooo`03o`000?oo
oooooooo03Sooooo000Wooooo`Ko2NX:00?oooooo`000?ooool02oooool00ol9jP[oooooooooo`0c
ooooo`03o`WZ2_oooooooooo03Cooooo00?o2NX:ooooooooool02Oooool6o`WZ2P03o`000?oooooo
oooo03Oooooo0005ooooobSo2NX:00?o0000o`WZ2_l9jPX0R_l9jPX00ol0003o2NX:ooooo`0goooo
o`009oooool5o`WZ2P03ooooool0003o000000cooooo00?o2NX:ooooooooool0<oooool00ol9jP[o
ooooooooo`0dooooo`03o`WZ2_oooooooooo00Wooooo1Ol9jPX00ooooooo2NX:o`00000hooooo`00
9_ooool2o`WZ2PKooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ
2_oooooooooo03Cooooo00?o2NX:ooooooooool02?ooool2o`WZ2PCooooo00?o2NX:ooooool00000
>?ooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oo
oooooooo03Cooooo00?o2NX:ooooooooool03Oooool01?l9jP[oooooooooool0000hooooo`00;_oo
ool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool0=?oo
ool00ol9jP[oooooooooo`0<ooooo`03o`WZ2_oooooooooo00;ooooo00?o0000ooooooooool0=Ooo
ool002kooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooo
oooo03Cooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`03ooooo`03o`000?oooooo
oooo03Gooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool0<oooool00ol9
jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool01Oooool00ol0
003oooooooooo`0dooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo03?o
oooo00?o2NX:ooooooooool0=?ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Ko
oooo00?o0000ooooooooool0=?ooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[ooooo
ooooo`0cooooo`03o`WZ2_oooooooooo03Cooooo00?o2NX:ooooooooool02?ooool00ol9jP[ooooo
ooooo`08ooooo`03o`000?oooooooooo03?ooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o
2NX:ooooooooool0<oooool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo00Oooooo00?o
2NX:ooooooooool02Oooool00ol0003oooooooooo`0cooooo`00;_ooool00ol0003oooooooooo`0:
ooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool0=?ooool00ol9jP[oooooooooo`06
ooooo`03o`WZ2_oooooooooo00[ooooo00?o0000ooooooooool0<oooool002kooooo00?o0000oooo
ooooool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo03Cooooo00?o2NX:oooo
ooooool01Oooool00ol9jP[oooooooooo`0<ooooo`03o`000?oooooooooo03;ooooo000^ooooo`03
o`000?oooooooooo00[ooooo00?o2NX:ooooooooool0<oooool00ol9jP[oooooooooo`0dooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool03Oooool00ol0003oooooooooo`0booooo`00
;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool0
=?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00oooooo00?o0000ooooooooool0
<Oooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oo
oooooooo03Cooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`0@ooooo`03o`000?oo
oooooooo037ooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool0<oooool0
0ol9jP[oooooooooo`0dooooo`05o`WZ2_ooooooooooooooool9jPX04oooool00ol0003ooooooooo
o`0aooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:
ooooooooool0=?ooool01?l9jP[oooooooooool9jPXEooooo`03o`000?oooooooooo033ooooo000^
ooooo`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool0<oooool00ol9jP[oooooooooo`0d
ooooo`03o`WZ2_oooooo2NX:01Kooooo00?o0000ooooooooool0<?ooool002kooooo00?o0000oooo
ooooool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo03Cooooo0_l9jPXHoooo
o`03o`000?oooooooooo02oooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o2NX:oooooooo
ool0<oooool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo01Oooooo00?o0000oooooooo
ool0;oooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ
2_oooooooooo03?ooooo0_l9jPXIooooo`03o`000?oooooooooo02oooooo000^ooooo`03o`000?oo
oooooooo00[ooooo00?o2NX:ooooooooool0<oooool00ol9jP[oooooooooo`0booooo`03o`WZ2_oo
oooo2NX:01[ooooo00?o0000ooooooooool0;_ooool002kooooo00?o0000ooooooooool02_ooool0
0ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo037ooooo00Co2NX:oooooooooooo2NX:6_oo
ool00ol0003oooooooooo`0^ooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooo
oooo03?ooooo00?o2NX:ooooooooool0<?ooool01Ol9jP[ooooooooooooooooo2NX:01_ooooo00?o
0000ooooooooool0;Oooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0c
ooooo`03o`WZ2_oooooooooo02oooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`0I
ooooo`03o`000?oooooooooo02gooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o2NX:oooo
ooooool0<oooool00ol9jP[oooooooooo`0^ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool06_ooool00ol0003oooooooooo`0/ooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03
o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool0;Oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo01[ooooo00?o0000ooooooooool0;?ooool002kooooo00?o0000ooooooooool0
2_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo02cooooo00?o2NX:ooooooooool0
1Oooool00ol9jP[oooooooooo`0Jooooo`03o`000?oooooooooo02cooooo000^ooooo`03o`000?oo
oooooooo00[ooooo00?o2NX:ooooooooool0<oooool00ol9jP[oooooooooo`0[ooooo`03o`WZ2_oo
oooooooo00Kooooo00?o2NX:ooooooooool06oooool00ol0003oooooooooo`0[ooooo`00;_ooool0
0ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool0:_ooool0
0ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo01_ooooo00?o0000ooooooooool0:oooool0
02kooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo
02Wooooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`0Looooo`03o`000?oooooooooo
02[ooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool0<oooool00ol9jP[o
ooooooooo`0Xooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool07?ooool00ol0003o
ooooooooo`0Zooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo03?ooooo
00?o2NX:ooooooooool09oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo01cooooo
00?o0000ooooooooool0:_ooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[ooooooooo
o`0cooooo`03o`WZ2_oooooooooo02Kooooo00?o2NX:ooooooooool02oooool00ol9jP[ooooooooo
o`0Mooooo`03o`000?oooooooooo02Wooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o2NX:
ooooooooool0<oooool00ol9jP[oooooooooo`0Uooooo`03o`WZ2_oooooooooo00cooooo00?o2NX:
ooooooooool07Oooool00ol0003oooooooooo`0Yooooo`00;_ooool00ol0003oooooooooo`0:oooo
o`03o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool09?ooool00ol9jP[oooooooooo`0=oooo
o`03o`WZ2_oooooooooo01kooooo00?o0000ooooooooool0:?ooool002kooooo00?o0000oooooooo
ool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo02?ooooo00?o2NX:oooooooo
ool03_ooool00ol9jP[oooooooooo`0Nooooo`03o`000?oooooooooo02Sooooo000^ooooo`03o`00
0?oooooooooo00[ooooo00?o2NX:ooooooooool0<oooool00ol9jP[oooooooooo`0Rooooo`03o`WZ
2_oooooooooo00oooooo00?o2NX:ooooooooool07oooool00ol0003oooooooooo`0Wooooo`00;_oo
ool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool08Ooo
ool00ol9jP[oooooooooo`0@ooooo`03o`WZ2_oooooooooo01oooooo00?o0000ooooooooool09ooo
ool002kooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooo
oooo023ooooo00?o2NX:ooooooooool04Oooool00ol9jP[oooooooooo`0Oooooo`03o`000?oooooo
oooo02Oooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool0<oooool00ol9
jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01;ooooo00?o2NX:ooooooooool08?ooool00ol0
003oooooooooo`0Vooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo03?o
oooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo023o
oooo00?o0000ooooooooool09_ooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[ooooo
ooooo`0cooooo`03o`WZ2_oooooooooo01gooooo00?o2NX:ooooooooool05?ooool00ol9jP[ooooo
ooooo`0Qooooo`03o`000?oooooooooo02Gooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o
2NX:ooooooooool0<oooool00ol9jP[oooooooooo`0Looooo`03o`WZ2_oooooooooo01Gooooo00?o
2NX:ooooooooool08Oooool00ol0003oooooooooo`0Uooooo`00;_ooool00ol0003oooooooooo`0:
ooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool06oooool00ol9jP[oooooooooo`0F
ooooo`03o`WZ2_oooooooooo027ooooo00?o0000ooooooooool09Oooool002kooooo00?o0000oooo
ooooool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo01[ooooo00?o2NX:oooo
ooooool05oooool00ol9jP[oooooooooo`0Rooooo`03o`000?oooooooooo02Cooooo000^ooooo`03
o`000?oooooooooo00[ooooo00?o2NX:ooooooooool0<oooool00ol9jP[oooooooooo`0Iooooo`03
o`WZ2_oooooooooo01Sooooo00?o2NX:ooooooooool08_ooool00ol0003oooooooooo`0Tooooo`00
;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool0
6?ooool00ol9jP[oooooooooo`0Iooooo`03o`WZ2_oooooooooo02?ooooo00?o0000ooooooooool0
8oooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oo
oooooooo01Oooooo00?o2NX:ooooooooool06_ooool00ol9jP[oooooooooo`0Sooooo`03o`000?oo
oooooooo02?ooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool0<oooool0
0ol9jP[oooooooooo`0Fooooo`03o`WZ2_oooooooooo01_ooooo00?o2NX:ooooooooool09?ooool0
0ol0003oooooooooo`0Rooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo
03?ooooo00?o2NX:ooooooooool05Oooool00ol9jP[oooooooooo`0Looooo`03o`WZ2_oooooooooo
02Cooooo00?o0000ooooooooool08_ooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[o
ooooooooo`0cooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool07Oooool00ol9jP[o
ooooooooo`0Tooooo`03o`000?oooooooooo02;ooooo000Vooooo`?o2NX:1Oooool00ol0003ooooo
ooooo`0:ooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:ooooooooool04oooool00ol9jP[ooooo
ooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo0ol9jPX4ooooo`03o`000?oooooooooo027ooooo
000Wooooo`Ko2NX:00?oooooo`000?ooool02oooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oo
oooooooo01;ooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`Ko2NX:00?o
0000ooooooooool08Oooool000Gooooo:?l9jPX00ol0003o2NX:o`WZ2P2Ro`WZ2P03o`000?oooooo
oooo01oooooo000Wooooo`Go2NX:00?oooooo`000?l000003?ooool00ol9jP[oooooooooo`0coooo
o`03o`WZ2_oooooooooo013ooooo00?o2NX:ooooooooool08Oooool00ol9jP[oooooooooo`0Ooooo
o`Go2NX:00Coooooo`WZ2_l0003o00008Oooool002Kooooo0_l9jPX6ooooo`03o`000?oooooooooo
00[ooooo00?o2NX:ooooooooool0<oooool00ol9jP[oooooooooo`0?ooooo`03o`WZ2_oooooooooo
02;ooooo00?o2NX:ooooooooool07_ooool2o`WZ2PCooooo00?o2NX:ooooool000008_ooool002ko
oooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo00ko
oooo00?o2NX:ooooooooool08oooool00ol9jP[oooooooooo`0Sooooo`05o`WZ2_oooooooooooooo
ool000008Oooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0cooooo`03
o`WZ2_oooooooooo00gooooo00?o2NX:ooooooooool09?ooool00ol9jP[oooooooooo`0Rooooo`03
o`WZ2_oooooooooo00;ooooo00?o0000ooooooooool07oooool002kooooo00?o0000ooooooooool0
2_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo00cooooo00?o2NX:ooooooooool0
9Oooool00ol9jP[oooooooooo`0Qooooo`03o`WZ2_oooooooooo00Cooooo00?o0000ooooooooool0
7_ooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oo
oooooooo00_ooooo00?o2NX:ooooooooool09_ooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oo
oooooooo00Gooooo00?o0000ooooooooool07_ooool002kooooo00?o0000ooooooooool02_ooool0
0ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool09oooool0
0ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo00Kooooo00?o0000ooooooooool07_ooool0
02kooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool0:?ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo
00Sooooo00?o0000ooooooooool07Oooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[o
ooooooooo`0cooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool0:Oooool00ol9jP[o
ooooooooo`0Mooooo`03o`WZ2_oooooooooo00Wooooo00?o0000ooooooooool07Oooool002kooooo
00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo00Oooooo
00?o2NX:ooooooooool0:_ooool00ol9jP[oooooooooo`0Looooo`03o`WZ2_oooooooooo00_ooooo
00?o0000ooooooooool07?ooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[ooooooooo
o`0cooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool0:oooool00ol9jP[ooooooooo
o`0Kooooo`03o`WZ2_oooooooooo00cooooo00?o0000ooooooooool07?ooool002kooooo00?o0000
ooooooooool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:
ooooooooool0;?ooool00ol9jP[oooooooooo`0Jooooo`03o`WZ2_oooooooooo00kooooo00?o0000
ooooooooool06oooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0coooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0;Oooool00ol9jP[oooooooooo`0Ioooo
o`03o`WZ2_oooooooooo00oooooo00?o0000ooooooooool06oooool002kooooo00?o0000oooooooo
ool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool0;_ooool00ol9jP[oooooooooo`0Hooooo`03o`WZ2_oooooooooo013ooooo00?o0000oooooooo
ool06oooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0cooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool0;oooool00ol9jP[oooooooooo`0Gooooo`03o`WZ
2_oooooooooo01;ooooo00?o0000ooooooooool06_ooool002kooooo00?o0000ooooooooool02_oo
ool00ol9jP[oooooooooo`0cooooo`05o`WZ2_ooooooooooooooool9jPX0<_ooool00ol9jP[ooooo
ooooo`0Fooooo`03o`WZ2_oooooooooo01?ooooo00?o0000ooooooooool06_ooool002kooooo00?o
0000ooooooooool02_ooool00ol9jP[oooooooooo`0cooooo`04o`WZ2_ooooooooooo`WZ2S?ooooo
00?o2NX:ooooooooool05Oooool00ol9jP[oooooooooo`0Eooooo`03o`000?oooooooooo01Wooooo
000^ooooo`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool0<oooool00ol9jP[oooooo`WZ
2P0dooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool05_ooool00ol0003ooooooooo
o`0Iooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo03?ooooo0_l9jPXe
ooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool05oooool00ol0003oooooooooo`0I
ooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo03?ooooo00?o2NX:oooo
ooooool0=?ooool00ol9jP[oooooooooo`0Booooo`03o`WZ2_oooooooooo01Wooooo00?o0000oooo
ooooool06?ooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0booooo`;o
2NX:=_ooool00ol9jP[oooooooooo`0Aooooo`03o`WZ2_oooooooooo01[ooooo00?o0000oooooooo
ool06?ooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0aooooo`03o`WZ
2_oooooo2NX:03Kooooo00?o2NX:ooooooooool04?ooool00ol9jP[oooooooooo`0Looooo`03o`00
0?oooooooooo01Oooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool0<?oo
ool01?l9jP[oooooooooool9jPXfooooo`03o`WZ2_oooooooooo00oooooo00?o2NX:ooooooooool0
7Oooool00ol0003oooooooooo`0Gooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oo
oooooooo02oooooo00Go2NX:ooooooooooooooooo`WZ2P0fooooo`03o`WZ2_oooooooooo00kooooo
00?o2NX:ooooooooool07oooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003ooooooooo
o`0:ooooo`03o`WZ2_oooooooooo02kooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`0dooooo`03o`WZ2_oooooooooo00gooooo00?o2NX:ooooooooool08?ooool00ol0003ooooooooo
o`0Fooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo02gooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo00cooooo00?o2NX:
ooooooooool08Oooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`0:oooo
o`03o`WZ2_oooooooooo02cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0doooo
o`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool08oooool00ol0003oooooooooo`0Eoooo
o`00;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo02_ooooo00?o2NX:oooooooo
ool01Oooool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:oooooooo
ool09?ooool00ol0003oooooooooo`0Eooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ
2_oooooooooo02[ooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`0dooooo`03o`WZ
2_oooooooooo00Wooooo00?o2NX:ooooooooool09_ooool00ol0003oooooooooo`0Dooooo`00;_oo
ool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo02Wooooo00?o2NX:ooooooooool01ooo
ool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool09ooo
ool00ol0003oooooooooo`0Dooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooo
oooo02Sooooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooo
oooo00Oooooo00?o2NX:ooooooooool0:?ooool00ol0003oooooooooo`0Dooooo`00;_ooool00ol0
003oooooooooo`0:ooooo`03o`WZ2_oooooooooo02Oooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool0:_ooool00ol0
003oooooooooo`0Cooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo02Ko
oooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo00Go
oooo00?o2NX:ooooooooool0:oooool00ol0003oooooooooo`0Cooooo`00;_ooool00ol0003ooooo
ooooo`0:ooooo`03o`WZ2_oooooooooo02Gooooo00?o2NX:ooooooooool02oooool00ol9jP[ooooo
ooooo`0dooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0;Oooool00ol0003ooooo
ooooo`0Booooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo02Cooooo00?o
2NX:ooooooooool03?ooool00ol9jP[oooooooooo`0dooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool0;_ooool00ol0003oooooooooo`0Booooo`00;_ooool00ol0003oooooooooo`0:
ooooo`03o`WZ2_oooooooooo02?ooooo00?o2NX:ooooooooool03Oooool00ol9jP[oooooooooo`0d
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0<?ooool00ol0003oooooooooo`0A
ooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo02;ooooo00?o2NX:oooo
ooooool03_ooool00ol9jP[oooooooooo`0dooooo`05o`WZ2_ooooooooooooooool9jPX0<oooool0
0ol0003oooooooooo`0Aooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo
027ooooo00?o2NX:ooooooooool03oooool00ol9jP[oooooooooo`0dooooo`04o`WZ2_oooooooooo
o`WZ2SCooooo00?o0000ooooooooool04Oooool002kooooo00?o0000ooooooooool02_ooool00ol9
jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo013ooooo00?o2NX:ooooooooool0=?ooool00ol9
jP[oooooo`WZ2P0fooooo`03o`000?oooooooooo013ooooo000^ooooo`03o`000?oooooooooo00[o
oooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Aooooo`03o`WZ2_oooooooooo03Co
oooo0_l9jPXgooooo`03o`000?oooooooooo013ooooo000^ooooo`03o`000?oooooooooo00[ooooo
00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Booooo`03o`WZ2_oooooooooo03Cooooo
00?o2NX:ooooooooool0=oooool00ol0003oooooooooo`0?ooooo`00;_ooool00ol0003ooooooooo
o`0:ooooo`03o`WZ2_oooooooooo01gooooo00?o2NX:ooooooooool04oooool00ol9jP[ooooooooo
o`0cooooo`;o2NX:>Oooool00ol0003oooooooooo`0?ooooo`00;_ooool00ol0003oooooooooo`0:
ooooo`03o`WZ2_oooooooooo01cooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0b
ooooo`03o`WZ2_oooooo2NX:03Wooooo00?o0000ooooooooool03oooool002kooooo00?o0000oooo
ooooool02_ooool00ol9jP[oooooooooo`0Kooooo`03o`WZ2_oooooooooo01Gooooo00?o2NX:oooo
ooooool0<Oooool01?l9jP[oooooooooool9jPXjooooo`03o`000?oooooooooo00kooooo000^oooo
o`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool06_ooool00ol9jP[oooooooooo`0Foooo
o`03o`WZ2_oooooooooo033ooooo00Go2NX:ooooooooooooooooo`WZ2P0jooooo`03o`000?oooooo
oooo00kooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool06Oooool00ol9
jP[oooooooooo`0Gooooo`03o`WZ2_oooooooooo02oooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooooooo`0iooooo`03o`000?oooooooooo00gooooo000^ooooo`03o`000?oooooooooo00[o
oooo00?o2NX:ooooooooool06?ooool00ol9jP[oooooooooo`0Hooooo`03o`WZ2_oooooooooo02ko
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0iooooo`03o`000?oooooooooo00go
oooo000^ooooo`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool05oooool00ol9jP[ooooo
ooooo`0Iooooo`03o`WZ2_oooooooooo02gooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`0iooooo`03o`000?oooooooooo00gooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o
2NX:ooooooooool05_ooool00ol9jP[oooooooooo`0Jooooo`03o`WZ2_oooooooooo02cooooo00?o
2NX:ooooooooool01Oooool00ol9jP[oooooooooo`0jooooo`03o`000?oooooooooo00cooooo000^
ooooo`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool05Oooool00ol9jP[oooooooooo`0K
ooooo`03o`WZ2_oooooooooo02_ooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`0j
ooooo`03o`000?oooooooooo00cooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o2NX:oooo
ooooool05?ooool00ol9jP[oooooooooo`0Looooo`03o`WZ2_oooooooooo02[ooooo00?o2NX:oooo
ooooool01oooool00ol9jP[oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo000Vooooo`?o
2NX:1Oooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:oooooooo
ool07Oooool00ol9jP[oooooooooo`0Yooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:oooooooo
ool0=?ooool3o`WZ2PCooooo00?o0000ooooooooool02oooool002Oooooo1_l9jPX00ooooooo0000
ooooo`0;ooooo`03o`WZ2_oooooooooo01;ooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooo
ooooo`0Xooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool0=Oooool6o`WZ2P03oooo
ool0003ooooo00_ooooo0005ooooobSo2NX:00?o0000o`WZ2_l9jPX0^?l9jPX00ol0003ooooooooo
o`09ooooo`009oooool5o`WZ2P03ooooool0003o000000cooooo00?o2NX:ooooooooool04?ooool0
0ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo02Kooooo00?o2NX:ooooooooool02oooool0
0ol9jP[oooooooooo`0eooooo`Go2NX:0_ooool00ol9jP[o0000ooooo`0:ooooo`009_ooool2o`WZ
2PKooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0?ooooo`03o`WZ2_oooooooooo
027ooooo00?o2NX:ooooooooool09Oooool00ol9jP[oooooooooo`0<ooooo`03o`WZ2_oooooooooo
03Cooooo0_l9jPX5ooooo`03o`WZ2_oooooo000000_ooooo000^ooooo`03o`000?oooooooooo00[o
oooo00?o2NX:ooooooooool03_ooool00ol9jP[oooooooooo`0Rooooo`03o`WZ2_oooooooooo02Co
oooo00?o2NX:ooooooooool03Oooool00ol9jP[oooooooooo`0jooooo`04o`WZ2_ooooooooooo`00
00_ooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool03Oooool00ol9jP[o
ooooooooo`0Sooooo`03o`WZ2_oooooooooo02?ooooo00?o2NX:ooooooooool03_ooool00ol9jP[o
ooooooooo`0iooooo`03o`WZ2_oooooooooo00;ooooo00?o0000ooooooooool02?ooool002kooooo
00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0<ooooo`03o`WZ2_oooooooooo02Cooooo
00?o2NX:ooooooooool08_ooool00ol9jP[oooooooooo`0?ooooo`03o`WZ2_oooooooooo03Sooooo
00?o2NX:ooooooooool00oooool00ol0003oooooooooo`08ooooo`00;_ooool00ol0003ooooooooo
o`0:ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool09Oooool00ol9jP[ooooooooo
o`0Qooooo`03o`WZ2_oooooooooo013ooooo00?o2NX:ooooooooool0=oooool00ol9jP[ooooooooo
o`04ooooo`03o`000?oooooooooo00Sooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o2NX:
ooooooooool02_ooool00ol9jP[oooooooooo`0Vooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:
ooooooooool04Oooool00ol9jP[oooooooooo`0fooooo`03o`WZ2_oooooooooo00Kooooo00?o0000
ooooooooool01oooool002kooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo02Oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Boooo
o`03o`WZ2_oooooooooo03Gooooo00?o2NX:ooooooooool01oooool00ol0003oooooooooo`07oooo
o`00;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:oooooooo
ool0:?ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:oooooooo
ool0=?ooool00ol9jP[oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo000^ooooo`03o`00
0?oooooooooo00[ooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`0Yooooo`03o`WZ
2_oooooooooo01gooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0cooooo`03o`WZ
2_oooooooooo00[ooooo00?o0000ooooooooool01_ooool002kooooo00?o0000ooooooooool02_oo
ool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo02[ooooo00?o2NX:ooooooooool07?oo
ool00ol9jP[oooooooooo`0Eooooo`03o`WZ2_oooooooooo03;ooooo00?o2NX:ooooooooool03?oo
ool00ol0003oooooooooo`05ooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooo
oooo00;ooooo00Co2NX:oooooooooooo2NX:;Oooool00ol9jP[oooooooooo`0Kooooo`03o`WZ2_oo
oooooooo01Kooooo00?o2NX:ooooooooool0<Oooool00ol9jP[oooooooooo`0=ooooo`03o`000?oo
oooooooo00Gooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooo`WZ2P0^ooooo`03o`WZ2_oooooooooo01[ooooo00?o2NX:ooooooooool05oooool0
0ol9jP[oooooooooo`0`ooooo`03o`WZ2_oooooooooo00kooooo00?o0000ooooooooool01Oooool0
02kooooo0_l0000;ooooo`04o`WZ2_ooooooooooooooo`?o2NX:;oooool00ol9jP[oooooooooo`0I
ooooo`03o`WZ2_oooooooooo01Sooooo00?o2NX:ooooooooool0;oooool00ol9jP[oooooooooo`0@
ooooo`03o`000?oooooooooo00Cooooo000`ooooo`?o00002?ooool00ol9jP[oooooooooo`05o`WZ
2Rkooooo00?o2NX:ooooooooool06?ooool00ol9jP[oooooooooo`0Iooooo`03o`WZ2_oooooooooo
02kooooo00?o2NX:ooooooooool04?ooool00ol0003oooooooooo`05ooooo`00<oooool2o`0000Ko
oooo00?o2NX:ooooooooool00ol9jPX`ooooo`03o`WZ2_oooooooooo01Oooooo00?o2NX:oooooooo
ool06_ooool00ol9jP[oooooooooo`0]ooooo`03o`WZ2_oooooooooo013ooooo00?o0000oooooooo
ool01_ooool003Gooooo0_l00004ooooo`03o`WZ2_oooooo2NX:00;o2NX:<Oooool00ol9jP[ooooo
ooooo`0Fooooo`03o`WZ2_oooooooooo01_ooooo00?o2NX:ooooooooool0;?ooool00ol9jP[ooooo
ooooo`0@ooooo`03o`000?oooooooooo00Oooooo000gooooo`?o000000Coooooo`WZ2_oooooo2NX:
<oooool00ol9jP[oooooooooo`0Eooooo`03o`WZ2_oooooooooo01cooooo00?o2NX:ooooooooool0
:oooool00ol9jP[oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo000jooooo`03o`000?l9
jP[o000003Cooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0Mooooo`03o`WZ2_oo
oooooooo02[ooooo00?o2NX:ooooooooool04?ooool00ol0003oooooooooo`09ooooo`00>oooool0
1?l9jP[o0000o`000?l0000booooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool07_oo
ool00ol9jP[oooooooooo`0Yooooo`03o`WZ2_oooooooooo013ooooo00?o0000ooooooooool02_oo
ool003oooooo0_l0000`ooooo`03o`WZ2_oooooooooo01;ooooo00?o2NX:ooooooooool07oooool0
0ol9jP[oooooooooo`0Xooooo`03o`WZ2_oooooooooo013ooooo00?o0000ooooooooool02oooool0
047ooooo0_l0000^ooooo`03o`WZ2_oooooooooo017ooooo00?o2NX:ooooooooool08?ooool00ol9
jP[oooooooooo`0Wooooo`03o`WZ2_oooooooooo013ooooo00?o0000ooooooooool03?ooool004?o
oooo0ol0000[ooooo`03o`WZ2_oooooooooo013ooooo00?o2NX:ooooooooool08Oooool00ol9jP[o
ooooooooo`0Vooooo`03o`WZ2_oooooooooo013ooooo00?o0000ooooooooool03Oooool004Kooooo
0_l0000Yooooo`03o`WZ2_oooooooooo00oooooo00?o2NX:ooooooooool08_ooool00ol9jP[ooooo
ooooo`0Uooooo`03o`WZ2_oooooooooo013ooooo00?o0000ooooooooool03_ooool004Sooooo0ol0
000Vooooo`03o`WZ2_oooooooooo00kooooo00?o2NX:ooooooooool08oooool00ol9jP[ooooooooo
o`0Tooooo`03o`WZ2_oooooooooo013ooooo00?o0000ooooooooool03oooool004_ooooo0_l0000T
ooooo`03o`WZ2_oooooooooo00gooooo00?o2NX:ooooooooool09?ooool00ol9jP[oooooooooo`0S
ooooo`03o`WZ2_oooooooooo013ooooo00?o0000ooooooooool04?ooool004gooooo0ol0000Qoooo
o`03o`WZ2_oooooooooo00cooooo00?o2NX:ooooooooool09Oooool00ol9jP[oooooooooo`0Roooo
o`03o`WZ2_oooooooooo013ooooo00?o0000ooooooooool04Oooool0053ooooo0_l0000Oooooo`03
o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool09_ooool00ol9jP[oooooooooo`0Qooooo`03
o`WZ2_oooooooooo013ooooo00?o0000ooooooooool04_ooool005;ooooo0_l0000Mooooo`03o`WZ
2_oooooooooo00[ooooo00?o2NX:ooooooooool09oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ
2_oooooooooo013ooooo00?o0000ooooooooool04oooool005Cooooo0ol0000Jooooo`03o`WZ2_oo
oooooooo00Wooooo00?o2NX:ooooooooool0:?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oo
oooooooo013ooooo00?o0000ooooooooool05?ooool005Oooooo0_l0000Hooooo`03o`WZ2_oooooo
oooo00Sooooo00?o2NX:ooooooooool0:Oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo013ooooo00?o0000ooooooooool05Oooool005Wooooo0ol0000Eooooo`03o`WZ2_oooooooooo
00Oooooo00?o2NX:ooooooooool0:_ooool00ol9jP[oooooooooo`0Mooooo`03o`WZ2_oooooooooo
013ooooo00?o0000ooooooooool05_ooool005cooooo0_l0000Cooooo`03o`WZ2_oooooooooo00Ko
oooo00?o2NX:ooooooooool0:oooool00ol9jP[oooooooooo`0Looooo`03o`WZ2_oooooooooo013o
oooo00?o0000ooooooooool05oooool005kooooo0_l0000Aooooo`03o`WZ2_oooooooooo00Gooooo
00?o2NX:ooooooooool0;?ooool00ol9jP[oooooooooo`0Kooooo`03o`WZ2_oooooooooo013ooooo
00?o0000ooooooooool06?ooool0063ooooo0ol0000>ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooool9jPX0;oooool00ol9jP[oooooooooo`0Jooooo`03o`WZ2_oooooooooo013ooooo00?o
0000ooooooooool06Oooool006?ooooo0_l0000<ooooo`03o`WZ2_oooooooooo00;ooooo0_l9jPX`
ooooo`03o`WZ2_oooooooooo01Wooooo00?o2NX:ooooooooool04?ooool00ol0003oooooooooo`0J
ooooo`00IOooool3o`0000Wooooo00Co2NX:oooooooooooooooo0_l9jPXaooooo`03o`WZ2_oooooo
oooo01Sooooo00?o2NX:ooooooooool04?ooool00ol0003oooooooooo`0Kooooo`00J?ooool2o`00
00Oooooo00?o2NX:ooooooooool01_l9jPX^ooooo`03o`WZ2_oooooooooo01Oooooo00?o2NX:oooo
ooooool04?ooool00ol0003oooooooooo`0Looooo`00J_ooool2o`0000Gooooo00?o2NX:ooooool9
jPX01?l9jPX`ooooo`03o`WZ2_oooooooooo01Kooooo00?o2NX:ooooooooool04?ooool00ol0003o
ooooooooo`0Mooooo`00K?ooool3o`0000;ooooo00?o2NX:ooooool9jPX00_l9jPXbooooo`03o`WZ
2_oooooooooo01Gooooo00?o2NX:ooooooooool04?ooool00ol0003oooooooooo`0Nooooo`00Kooo
ool2o`000003o`WZ2_l0003o2NX:03Cooooo00?o2NX:ooooooooool05?ooool00ol9jP[ooooooooo
o`0@ooooo`03o`000?oooooooooo01oooooo001aooooo`03o`WZ2_l0003o000003Cooooo00?o2NX:
ooooooooool04oooool00ol9jP[oooooooooo`0@ooooo`03o`000?oooooooooo023ooooo001doooo
o`;o0000<_ooool00ol9jP[oooooooooo`0Booooo`03o`WZ2_oooooooooo013ooooo00?o0000oooo
ooooool08Oooool007Kooooo0ol0000_ooooo`03o`WZ2_oooooooooo017ooooo00?o2NX:oooooooo
ool04?ooool00ol0003oooooooooo`0Rooooo`00NOooool2o`0002gooooo00?o2NX:ooooooooool0
4?ooool00ol9jP[oooooooooo`0@ooooo`03o`000?oooooooooo02?ooooo001kooooo`;o0000:ooo
ool00ol9jP[oooooooooo`0?ooooo`03o`WZ2_oooooooooo013ooooo00?o0000ooooooooool09?oo
ool007gooooo0ol0000Xooooo`03o`WZ2_oooooooooo00kooooo00?o2NX:ooooooooool04?ooool0
0ol0003oooooooooo`0Uooooo`00P?ooool2o`0002Kooooo00?o2NX:ooooooooool03Oooool00ol9
jP[oooooooooo`0@ooooo`03o`000?oooooooooo02Kooooo0022ooooo`?o00008oooool00ol9jP[o
ooooooooo`0<ooooo`03o`WZ2_oooooooooo013ooooo00?o0000ooooooooool09oooool008Gooooo
0_l0000Qooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool04?ooool00ol0003ooooo
ooooo`0Xooooo`00Qoooool2o`0001oooooo00?o2NX:ooooooooool02_ooool00ol9jP[ooooooooo
o`0@ooooo`03o`000?oooooooooo02Wooooo0029ooooo`?o00007?ooool00ol9jP[oooooooooo`09
ooooo`03o`WZ2_oooooooooo013ooooo00?o0000ooooooooool0:_ooool008cooooo0_l0000Joooo
o`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool04?ooool00ol0003oooooooooo`0[oooo
o`00S_ooool3o`0001Oooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`0@ooooo`03
o`000?oooooooooo02cooooo002Aooooo`;o00005Oooool00ol9jP[oooooooooo`06ooooo`03o`WZ
2_oooooooooo013ooooo00?o0000ooooooooool0;Oooool009?ooooo0_l0000Cooooo`03o`WZ2_oo
oooooooo00Gooooo00?o2NX:ooooooooool04?ooool00ol0003oooooooooo`0^ooooo`00UOooool3
o`00013ooooo00Go2NX:ooooooooooooooooo`WZ2P02ooooo`03o`WZ2_oooooooooo013ooooo00?o
0000ooooooooool0;oooool009Sooooo0_l0000>ooooo`07o`WZ2_ooooooooooooooool9jP[ooooo
o`WZ2P0Booooo`03o`000?oooooooooo033ooooo002Jooooo`?o00002oooool00ol9jP[ooooooooo
o`03o`WZ2Q;ooooo00?o0000ooooooooool0<Oooool009gooooo0_l00009ooooo`03o`WZ2_oooooo
oooo00Go2NX:3oooool00ol0003oooooooooo`0booooo`00Woooool3o`0000Kooooo00?o2NX:oooo
ool9jPX00ol9jPX@ooooo`03o`000?oooooooooo03?ooooo002Rooooo`;o00001?ooool4o`WZ2Q7o
oooo00?o0000ooooooooool0=?ooool00:Cooooo0_l00002ooooo`?o2NX:4Oooool00ol0003ooooo
ooooo`0eooooo`00Y_ooool2o`000003o`WZ2_oooooooooo013ooooo00?o0000ooooooooool0=_oo
ool00:Oooooo1?l0000?ooooo`03o`000?oooooooooo03Oooooo002[ooooo`?o00002oooool00ol0
003oooooooooo`0hooooo`00[_ooool2o`0000Sooooo00?o0000ooooooooool0>Oooool00;3ooooo
0_l00005ooooo`03o`000?oooooooooo03[ooooo002booooo`?o000000?oooooo`000?ooool0??oo
ool00;Gooooo00?o0000ooooooooool0??ooool00?Cooooo003dooooo`00m?ooool00?Cooooo003d
ooooo`00m?ooool00001\
\>"],
  ImageRangeCache->{{{0, 243.375}, {271.875, 0}} -> {-0.428735, -10.4828, \
0.0739734, 0.0739734}},
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[
{CircleOfRays[6,NumberOfRays->8],
Move[RoofPrism[10],3],
Boundary[25,GraphicDesign->Off]}];\
\>", "Input",
  CellTags->"Prism Examples"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.13398 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0784161 1.1637 1.11022e-16 1.1637 [
[ 0 0 0 0 ]
[ 1 1.13398 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.13398 L
0 1.13398 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.32729 .31277 m
.53803 .5506 L
s
.53803 .5506 m
.77783 .47307 L
s
.53816 .55053 m
.41142 .7075 L
s
.32743 .31269 m
.53816 .55053 L
s
.41134 .70743 m
.53808 .55046 L
s
.53808 .55046 m
.7779 .47293 L
s
.41145 .70737 m
.18358 .48482 L
s
.40601 .94059 m
.41145 .70737 L
s
.41142 .7075 m
.18353 .48496 L
s
.40589 .94067 m
.41134 .70743 L
s
0 0 0 r
2 Mabswid
.58595 .32495 Mdot
.039 .916 .04 r
.5 Mabswid
.58888 .45131 m
.58595 .32495 L
s
0 0 0 r
2 Mabswid
.67988 .31846 Mdot
.039 .916 .04 r
.5 Mabswid
.68615 .44496 m
.67988 .31846 L
s
0 0 0 r
2 Mabswid
.51317 .2849 Mdot
.039 .916 .04 r
.5 Mabswid
.51352 .41209 m
.51317 .2849 L
s
0 0 0 r
2 Mabswid
.74431 .26863 Mdot
.039 .916 .04 r
.5 Mabswid
.75307 .39614 m
.74431 .26863 L
s
0 g
.77785 .47292 m
.40586 .94065 L
s
.87581 .36653 m
.77785 .47292 L
s
.77783 .47307 m
.8758 .36669 L
s
.7779 .47293 m
.40589 .94067 L
s
0 0 0 r
2 Mabswid
.58888 .45131 Mdot
.039 .916 .04 r
.5 Mabswid
.59516 .7226 m
.58888 .45131 L
s
.2375 .7833 m
.3468 .75038 L
s
0 0 0 r
2 Mabswid
.68615 .44496 Mdot
.039 .916 .04 r
.5 Mabswid
.69347 .5925 m
.68615 .44496 L
s
0 0 0 r
2 Mabswid
.50327 .21877 Mdot
.039 .916 .04 r
.5 Mabswid
.50327 .34722 m
.50327 .21877 L
s
.25288 .87821 m
.36353 .84667 L
s
0 0 0 r
2 Mabswid
.7409 .20156 Mdot
.039 .916 .04 r
.5 Mabswid
.74979 .33032 m
.7409 .20156 L
s
.18989 .70826 m
.30003 .67347 L
s
0 0 0 r
2 Mabswid
.51352 .41209 Mdot
.039 .916 .04 r
.5 Mabswid
.51471 .84053 m
.51352 .41209 L
s
.3468 .75038 m
.64426 .66078 L
s
0 0 0 r
2 Mabswid
.3468 .75038 Mdot
0 g
.5 Mabswid
.34498 1.0349 m
.40601 .94059 L
s
.40586 .94065 m
.34482 1.03495 L
s
0 0 0 r
2 Mabswid
.75307 .39614 Mdot
.039 .916 .04 r
.5 Mabswid
.76114 .51362 m
.75307 .39614 L
s
.36353 .84667 m
.52898 .79951 L
s
0 0 0 r
2 Mabswid
.36353 .84667 Mdot
.56657 .1645 Mdot
.039 .916 .04 r
.5 Mabswid
.56897 .29388 m
.56657 .1645 L
s
0 0 0 r
2 Mabswid
.66699 .15708 Mdot
.039 .916 .04 r
.5 Mabswid
.67323 .28658 m
.66699 .15708 L
s
.30003 .67347 m
.76337 .52711 L
s
0 0 0 r
2 Mabswid
.30003 .67347 Mdot
0 g
.5 Mabswid
.8757 .3667 m
.78665 .23283 L
s
.84397 .42557 m
.8757 .3667 L
s
.84408 .42538 m
.87581 .36653 L
s
.8758 .36669 m
.78675 .23281 L
s
.039 .916 .04 r
.22698 .94238 m
.34049 .91107 L
s
0 0 0 r
2 Mabswid
.69347 .5925 Mdot
.039 .916 .04 r
.5 Mabswid
.39344 .66548 m
.69347 .5925 L
s
0 0 0 r
2 Mabswid
.50327 .34722 Mdot
.039 .916 .04 r
.5 Mabswid
.50325 .62441 m
.50327 .34722 L
s
.13484 .6948 m
.24755 .65862 L
s
0 0 0 r
2 Mabswid
.74979 .33032 Mdot
.039 .916 .04 r
.5 Mabswid
.76337 .52711 m
.74979 .33032 L
s
.52898 .79951 m
.57179 .44555 L
s
0 0 0 r
2 Mabswid
.52898 .79951 Mdot
.76114 .51362 Mdot
.039 .916 .04 r
.5 Mabswid
.55527 .55985 m
.76114 .51362 L
s
.34049 .91107 m
.47491 .874 L
s
0 0 0 r
2 Mabswid
.34049 .91107 Mdot
0 g
.5 Mabswid
.32746 .31274 m
.18357 .48501 L
s
.58701 .21608 m
.32746 .31274 L
s
.58684 .21611 m
.32729 .31277 L
s
.18353 .48496 m
.32743 .31269 L
s
.039 .916 .04 r
.64426 .66078 m
.679 .40629 L
s
0 0 0 r
2 Mabswid
.64426 .66078 Mdot
.039 .916 .04 r
.5 Mabswid
.24755 .65862 m
.55527 .55985 L
s
0 0 0 r
2 Mabswid
.24755 .65862 Mdot
.56897 .29388 Mdot
.039 .916 .04 r
.5 Mabswid
.57179 .44555 m
.56897 .29388 L
s
0 0 0 r
2 Mabswid
.59516 .7226 Mdot
.039 .916 .04 r
.5 Mabswid
.37577 .78262 m
.59516 .7226 L
s
0 0 0 r
2 Mabswid
.67323 .28658 Mdot
.039 .916 .04 r
.5 Mabswid
.679 .40629 m
.67323 .28658 L
s
0 g
.18357 .48501 m
.16233 .73221 L
s
.18358 .48482 m
.16234 .73201 L
s
.039 .916 .04 r
.17178 .93631 m
.28805 .90384 L
s
.1043 .75583 m
.21996 .71969 L
s
.47491 .874 m
.50325 .62441 L
s
0 0 0 r
2 Mabswid
.47491 .874 Mdot
0 g
.5 Mabswid
.21867 .93578 m
.34496 1.03481 L
s
.34496 1.03481 m
.42949 .948 L
s
.21869 .93587 m
.34498 1.0349 L
s
.34482 1.03495 m
.42934 .94815 L
s
.039 .916 .04 r
.11953 .85813 m
.23672 .8236 L
s
.28805 .90384 m
.51471 .84053 L
s
0 0 0 r
2 Mabswid
.28805 .90384 Mdot
0 g
.5 Mabswid
.78681 .23272 m
.84413 .42545 L
s
.58691 .21602 m
.78681 .23272 L
s
.78665 .23283 m
.84397 .42557 L
s
.78675 .23281 m
.58684 .21611 L
s
.039 .916 .04 r
.21996 .71969 m
.39344 .66548 L
s
0 0 0 r
2 Mabswid
.21996 .71969 Mdot
0 g
.5 Mabswid
.84413 .42545 m
.4294 .9482 L
s
.42934 .94815 m
.84408 .42538 L
s
.16223 .73213 m
.58691 .21602 L
s
.16233 .73221 m
.58701 .21608 L
s
0 0 0 r
2 Mabswid
.679 .40629 Mdot
.76337 .52711 Mdot
.039 .916 .04 r
.5 Mabswid
.76337 .52711 m
.76337 .52711 L
s
0 0 0 r
2 Mabswid
.76337 .52711 Mdot
.039 .916 .04 r
.5 Mabswid
.23672 .8236 m
.37577 .78262 L
s
0 0 0 r
2 Mabswid
.23672 .8236 Mdot
.57179 .44555 Mdot
.55527 .55985 Mdot
.50325 .62441 Mdot
.39344 .66548 Mdot
.51471 .84053 Mdot
.039 .916 .04 r
.5 Mabswid
.51471 .84053 m
.51471 .84053 L
s
0 0 0 r
2 Mabswid
.51471 .84053 Mdot
.37577 .78262 Mdot
0 g
.5 Mabswid
.42949 .948 m
.21867 .93578 L
s
.4294 .9482 m
.21858 .93599 L
s
.21858 .93599 m
.16223 .73213 L
s
.16234 .73201 m
.21869 .93587 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{341.938, 391.688},
  ImageMargins->{{126, 0}, {0, 0}},
  ImageRegion->{{-0.0965089, 1.12283}, {-0.135152, 1.07133}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005E0001Qb000`400?l00000o`00003ooooooomF
ooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00oooooomF
ooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00oooooomF
ooooo`00oooooomFooooo`00loooool00ol0003o2NX:ooooo`1Oooooo`00loooool00ol0003o2NX:
ooooo`1Oooooo`00m?ooool00ol9jP[oooooooooo`1Nooooo`00b_ooool00ol9jP[o0000ooooo`0W
ooooo`03o`WZ2_oooooooooo05kooooo003:ooooo`03o`WZ2_l0003ooooo02Oooooo00?o2NX:oooo
ooooool0G_ooool00<[ooooo00?o2NX:ooooooooool09oooool00ol9jP[oooooooooo`1Nooooo`00
b_ooool00ol9jP[oooooooooo`0Wooooo`03o`WZ2_oooooooooo05kooooo003:ooooo`03o`WZ2_oo
oooooooo02Oooooo00?o2NX:ooooooooool0G_ooool00<[ooooo00?o2NX:ooooooooool09oooool0
0ol9jP[oooooooooo`1Nooooo`00b_ooool00ol9jP[oooooooooo`0Wooooo`03o`WZ2_oooooooooo
05kooooo003:ooooo`03o`WZ2_oooooooooo02Oooooo00?o2NX:ooooooooool0G_ooool00<[ooooo
00?o2NX:ooooooooool09oooool00ol9jP[oooooooooo`1Nooooo`00b_ooool00ol9jP[ooooooooo
o`0Wooooo`03o`WZ2_oooooooooo05kooooo003:ooooo`03o`WZ2_oooooooooo02Oooooo00?o2NX:
ooooooooool0G_ooool00<[ooooo00?o2NX:ooooooooool0:?ooool00ol9jP[oooooooooo`1Moooo
o`00b_ooool00ol9jP[oooooooooo`0Xooooo`03o`WZ2_oooooooooo05gooooo003:ooooo`03o`WZ
2_oooooooooo02Sooooo00?o2NX:ooooooooool0GOooool00<[ooooo00?o2NX:ooooooooool0:?oo
ool00ol9jP[oooooooooo`1Mooooo`00b_ooool00ol9jP[oooooooooo`0Xooooo`03o`WZ2_oooooo
oooo01[ooooo0_l00011ooooo`00b_ooool00ol9jP[oooooooooo`0Xooooo`03o`WZ2_oooooooooo
01[ooooo00?o0000o`WZ2_ooool0@?ooool00<[ooooo00?o2NX:ooooooooool0:?ooool00ol9jP[o
ooooooooo`0Kooooo`03o`WZ2_oooooooooo03oooooo003:ooooo`03o`WZ2_oooooooooo02Sooooo
00?o2NX:ooooooooool06oooool00ol9jP[oooooooooo`0oooooo`00b_ooool00ol9jP[ooooooooo
o`0Xooooo`03o`WZ2_oooooooooo01_ooooo00?o2NX:ooooooooool0?oooool00<[ooooo00?o2NX:
ooooooooool0:?ooool00ol9jP[oooooooooo`0Kooooo`03o`WZ2_oooooooooo03oooooo003:oooo
o`03o`WZ2_oooooooooo02Sooooo00?o2NX:ooooooooool06oooool00ol9jP[oooooooooo`0ooooo
o`00[oooool2o`0001Wooooo00?o2NX:ooooooooool01Oooool8o`0001_ooooo00?o2NX:oooooooo
ool06oooool00ol9jP[oooooooooo`0oooooo`00[oooool00ol0003o2NX:ooooo`0Hooooo`03o`WZ
2_oooooooooo00;ooooo0ol000000ooooooo0000ooooo`05ooooo`co00003oooool00ol9jP[ooooo
ooooo`0Kooooo`03o`WZ2_oooooooooo03oooooo002`ooooo`03o`WZ2_oooooooooo01Oooooo00?o
2NX:ooooool000000_l00003ooooo`03o`000?oooooooooo017ooooo3?l00003ooooo`03o`WZ2_oo
oooooooo01_ooooo00?o2NX:ooooooooool0?oooool00;3ooooo00?o2NX:ooooooooool05oooool2
o`0000Gooooo00?o0000ooooooooool07_ooool<o`0001Gooooo00?o2NX:ooooooooool0?oooool0
0;3ooooo00?o2NX:ooooooooool05?ooool3o`000003o`WZ2_oooooooooo00?ooooo00?o0000oooo
ooooool08_ooool00ol9jP[oooooooooo`06ooooo`_o00002oooool00ol9jP[oooooooooo`0noooo
o`00/?ooool00ol9jP[oooooooooo`0Aooooo`?o00000oooool00ol9jP[oooooooooo`02ooooo`03
o`000?oooooooooo02?ooooo00?o2NX:ooooooooool04Oooool<o`00043ooooo002`ooooo`03o`WZ
2_oooooooooo00kooooo0ol00007ooooo`04o`WZ2_ooooooooooo`0002Kooooo00?o2NX:oooooooo
ool07?ooool00ol9jP[o0000o`00000:o`0003Cooooo002`ooooo`03o`WZ2_oooooooooo00cooooo
0_l0000:ooooo`04o`WZ2_ooooooooooo`0002Kooooo00?o2NX:ooooooooool07?ooool00ol9jP[o
ooooooooo`0:ooooo`Ko0000;_ooool00;3ooooo00?o2NX:ooooooooool02Oooool3o`0000cooooo
00?o2NX:ooooool000009oooool00ol9jP[oooooooooo`0Looooo`03o`WZ2_oooooooooo00oooooo
00?o0000ooooooooool0;?ooool00;3ooooo00?o2NX:ooooooooool01_ooool3o`0000oooooo00?o
2NX:o`000?ooool09oooool00ol9jP[oooooooooo`0Looooo`03o`WZ2_oooooooooo00oooooo0_l0
000]ooooo`00/?ooool00ol9jP[oooooooooo`04ooooo`;o00004_ooool00ol0003oooooooooo`0W
ooooo`03o`WZ2_oooooooooo01cooooo00?o2NX:ooooooooool04?ooool2o`0002cooooo002`oooo
o`04o`WZ2_ooooooooooooooo`?o00004oooool00ol0003o2NX:ooooo`0Xooooo`03o`WZ2_oooooo
oooo01cooooo00?o2NX:ooooooooool04?ooool2o`0002cooooo002`ooooo`04o`WZ2_l0003o0000
o`0001Gooooo00?o0000ooooool9jPX0:Oooool00ol9jP[oooooooooo`0Looooo`03o`WZ2_oooooo
oooo013ooooo00?o0000ooooool00000:oooool00:oooooo0_l0000Hooooo`03o`000?oooooo2NX:
02Wooooo00?o2NX:ooooooooool07?ooool00ol9jP[oooooooooo`0Aooooo`03o`000?oooooo0000
02[ooooo002/ooooo`?o000000?oooooo`WZ2_ooool05_ooool01?l0003oooooooooool9jPXYoooo
o`03o`WZ2_oooooooooo01cooooo00?o2NX:ooooooooool04Oooool00ol0003oooooo`00000Zoooo
o`00ZOooool3o`0000Cooooo00?o2NX:ooooooooool05?ooool01Ol0003ooooooooooooooooo2NX:
02Wooooo00?o2NX:ooooooooool07?ooool00ol9jP[oooooooooo`0Aooooo`04o`000?oooooooooo
o`0002Wooooo002Vooooo`?o00001oooool00ol9jP[oooooooooo`0Cooooo`03o`000?oooooooooo
00;ooooo00?o2NX:ooooooooool0:?ooool00ol9jP[oooooooooo`0Kooooo`03o`WZ2_oooooooooo
017ooooo0_l00002ooooo`03o`000?oooooooooo02Kooooo002Tooooo`;o00002_ooool00ol9jP[o
ooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o2NX:ooooooooool0:?ooool00ol9jP[o
ooooooooo`0Kooooo`03o`WZ2_oooooooooo01;ooooo00Co0000oooooooooooo0000:?ooool00:7o
oooo0ol0000<ooooo`03o`WZ2_oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol9jP[o
ooooooooo`0Xooooo`03o`WZ2_oooooooooo01_ooooo00?o2NX:ooooooooool04_ooool01Ol0003o
oooooooooooooooo000002Oooooo002Nooooo`?o00003oooool00ol9jP[oooooooooo`0Aooooo`03
o`000?oooooooooo00Cooooo00?o2NX:ooooooooool0:?ooool00ol9jP[oooooooooo`0Kooooo`03
o`WZ2_oooooooooo01;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Tooooo`00
W?ooool2o`0001;ooooo00?o2NX:ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`WZ
2_oooooooooo02Sooooo00?o2NX:ooooooooool06oooool00ol9jP[oooooooooo`0Cooooo`05o`00
0?ooooooooooooooool000009_ooool009Wooooo0ol0000Dooooo`03o`WZ2_oooooooooo00oooooo
00?o0000ooooooooool01_ooool00ol9jP[oooooooooo`0Xooooo`03o`WZ2_oooooooooo01_ooooo
00?o0000o`WZ2_ooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02?ooooo
002Fooooo`?o00005oooool00ol9jP[oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o
2NX:ooooooooool0:?ooool00ol9jP[oooooooooo`0Kooooo`;o2NX:5?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02;ooooo002Dooooo`;o00006_ooool00ol9jP[oooooooooo`0=
ooooo`03o`000?oooooooooo00Sooooo00?o2NX:ooooooooool0:?ooool00ol9jP[oooooooooo`0K
ooooo`;o2NX:5?ooool2o`0000Cooooo00?o0000ooooooooool08_ooool0097ooooo0ol0000Loooo
o`03o`WZ2_oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol9jP[oooooooooo`0Xoooo
o`03o`WZ2_oooooooooo01_ooooo0_l9jPXEooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool08Oooool008kooooo0ol0000Oooooo`03o`WZ2_oooooooooo00cooooo00?o0000oooooooo
ool02Oooool00ol9jP[oooooooooo`0Xooooo`03o`WZ2_oooooooooo01_ooooo0_l9jPXEooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool08?ooool008_ooooo0ol0000Rooooo`03o`WZ
2_oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0Xooooo`03o`WZ
2_oooooooooo01_ooooo0_l9jPXEooooo`;o00001Oooool00ol0003oooooooooo`0Pooooo`00ROoo
ool2o`0002Gooooo00?o2NX:ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`WZ2_oo
oooooooo02Sooooo00?o2NX:ooooooooool06oooool2o`WZ2QKooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Oooooo`00Q_ooool3o`0002Oooooo00Go2NX:oooooooooooo0000o`WZ
2P07ooooo`03o`000?oooooooooo00cooooo00?o2NX:ooooooooool0:?ooool00ol9jP[ooooooooo
o`0Kooooo`;o2NX:5_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo0023
ooooo`?o0000:_ooool01Ol9jP[oooooooooool0003o2NX:00Kooooo00?o0000ooooooooool03Ooo
ool00ol9jP[oooooooooo`0Xooooo`03o`WZ2_l0003ooooo01_ooooo0_l9jPXFooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool07_ooool0087ooooo0_l0000]ooooo`05o`WZ2_oooooo
ooooooooool9jPX01_ooool00ol0003oooooooooo`0=ooooo`03o`WZ2_oooooooooo02Sooooo00?o
2NX:o`000?ooool07?ooool00ol9jP[oooooooooo`0Dooooo`;o00001oooool00ol0003ooooooooo
o`0Mooooo`00O_ooool3o`0002oooooo00Go2NX:ooooooooooooooooo`WZ2P05ooooo`03o`000?oo
oooooooo00kooooo00?o2NX:ooooooooool0:?ooool00ol9jP[oooooooooo`0Looooo`03o`WZ2_oo
oooooooo01Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`00Noooool3
o`0003;ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`03o`000?oooooooooo00oooooo00?o
2NX:o`000?ooool0:?ooool00ol9jP[oooooooooo`0Looooo`03o`WZ2_oooooooooo01Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`00NOooool2o`0003Gooooo00Go2NX:
ooooooooooooooooo`WZ2P03ooooo`03o`000?oooooooooo013ooooo00?o2NX:o`000?ooool0:?oo
ool00ol9jP[oooooooooo`0Looooo`03o`WZ2_oooooooooo01Gooooo0_l00008ooooo`03o`000?oo
oooooooo01_ooooo001fooooo`?o0000=oooool01Ol9jP[ooooooooooooooooo2NX:00;ooooo00?o
0000ooooooooool04Oooool00ol9jP[oooooooooo`0Xooooo`03o`WZ2_oooooooooo01cooooo00?o
2NX:ooooooooool05_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo001c
ooooo`?o0000>_ooool01ol9jP[ooooooooooooooooo2NX:ooooool000005?ooool00ol9jP[ooooo
ooooo`0Xooooo`03o`WZ2_oooooooooo01cooooo00?o2NX:ooooooooool05_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01Wooooo001`ooooo`?o0000?Oooool01ol9jP[ooooooooo
oooooooo2NX:ooooool000005?ooool00ol9jP[oooooooooo`0Xooooo`03o`WZ2_oooooooooo01co
oooo00?o2NX:ooooooooool05_ooool2o`0000Wooooo00?o0000ooooooooool06Oooool006kooooo
0_l00010ooooo`06o`WZ2_ooooooooooooooool9jP[o00005Oooool00ol9jP[oooooooooo`0Xoooo
o`03o`WZ2_oooooooooo01cooooo00?o2NX:ooooooooool05_ooool2o`0000[ooooo00?o0000oooo
ooooool06?ooool006_ooooo0ol00012ooooo`05o`WZ2_ooooooooooooooool000005_ooool00ol9
jP[oooooooooo`0Yooooo`03o`WZ2_oooooooooo01_ooooo00?o2NX:ooooooooool05oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01Oooooo001Xooooo`?o0000AOooool01Ol9jP[o
ooooooooool0003o2NX:01Kooooo00?o2NX:ooooooooool0:Oooool00ol9jP[oooooooooo`0Koooo
o`;o2NX:6?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oooooo001Wooooo`03
o`000?oooooooooo04Kooooo00Go2NX:ooooool0003oooooo`WZ2P0Fooooo`03o`WZ2_oooooooooo
02Wooooo00?o2NX:ooooooooool06oooool2o`WZ2QSooooo0_l0000;ooooo`03o`000?oooooooooo
01Kooooo001Wooooo`03o`000?oooooooooo04Kooooo00Go2NX:ooooool0003oooooo`WZ2P0Foooo
o`03o`WZ2_oooooooooo02Wooooo00?o2NX:ooooooooool06oooool2o`WZ2QWooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Eooooo`00I_ooool00ol0003oooooo`000017ooooo`05
o`WZ2_l0003oooooooooool9jPX05_ooool00ol9jP[oooooooooo`0Yooooo`04o`WZ2_oooooo2NX:
o`0001[ooooo0_l9jPXIooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool0
06Gooooo00Go0000ooooooooooooooooo`000016ooooo`05o`000?ooooooooooooooool9jPX05_oo
ool00ol9jP[oooooooooo`0Yooooo`04o`WZ2_oooooo2NX:o`0001_ooooo00?o2NX:ooooooooool0
5oooool2o`0000cooooo00?o0000ooooooooool05?ooool006Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`12ooooo`03o`000?l9jP[ooooo00;ooooo00?o2NX:ooooooooool05?oo
ool00ol9jP[oooooooooo`0Yooooo`03o`WZ2_oooooo2NX:01cooooo00?o2NX:ooooooooool05ooo
ool2o`0000gooooo00?o0000ooooooooool04oooool006?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooo2NX:00?ooooo00?o2NX:ooooooooool05?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_l0003ooooo02;ooooo00?o2NX:ooooool9jPX07?ooool0
0ol9jP[oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool0
06;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0nooooo`04o`000?oooooooooo
o`WZ2P?ooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_l0003o
oooo02;ooooo00?o2NX:ooooool9jPX07?ooool00ol9jP[oooooooooo`0Hooooo`;o00003Oooool0
0ol0003oooooooooo`0Booooo`00H_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03gooooo00Co0000oooooooooooo2NX:0oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool08_ooool00ol9jP[oooooo`WZ2P0Looooo`03o`WZ2_l0003o
oooo01Sooooo0_l0000>ooooo`03o`000?oooooooooo017ooooo001Qooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0>oooool01Ol0003ooooooooooooooooo2NX:00?ooooo00?o2NX:
ooooooooool05?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo02;ooooo00?o2NX:
ooooool9jPX07?ooool00ol9jP[o0000ooooo`0Iooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool04Oooool0063ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P0Fooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool08_ooool00ol9jP[oooooo`WZ2P0Looooo`03o`WZ2_oooooo
oooo01Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`00Goooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool00oooool01Ol9
jP[ooooooooooooooooo2NX:01Kooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0R
ooooo`03o`WZ2_oooooo2NX:01cooooo00?o2NX:ooooooooool06Oooool2o`0000oooooo00?o0000
ooooooooool03oooool005kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo00Cooooo00Go2NX:ooooooooooooooooo`WZ2P0Fooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool08_ooool00ol9jP[oooooo`WZ2P0Looooo`03o`WZ2_oooooo
oooo01[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`00GOooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01Oooool01Ol9
jP[ooooooooooooooooo2NX:01Kooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0R
ooooo`04o`WZ2_ooooooooooo`WZ2Q_ooooo00?o2NX:ooooooooool06_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00kooooo001Mooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`05ooooo`05o`WZ2_ooooooooooooooool9jPX05_oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo02;ooooo00Co2NX:oooooooooooo2NX:
6oooool00ol9jP[oooooooooo`0Jooooo`;o00004?ooool00ol0003oooooooooo`0=ooooo`00G?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01Ooo
ool00ol0003o2NX:ooooo`02ooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`0Rooooo`04o`WZ2_ooooooooooo`WZ2Q_ooooo00?o2NX:ooooooooool0
6_ooool2o`00013ooooo00?o0000ooooooooool03Oooool005_ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Kooooo00?o0000o`WZ2_ooool00_oo
ool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool08ooo
ool00ol9jP[oooooo`WZ2P0Kooooo`;o2NX:7?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00cooooo001Jooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`08ooooo`05o`WZ2_ooooooooooooooool9jPX05_ooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo02?ooooo00?o2NX:ooooool9jPX07?ooool00ol9jP[ooooooooo
o`0Jooooo`;o00004Oooool00ol0003oooooooooo`0;ooooo`00FOooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02Oooool01Ol9jP[ooooooooooooo
oooo2NX:01Kooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Sooooo`03o`WZ2_oo
oooo2NX:01cooooo00?o2NX:ooooooooool06_ooool2o`00017ooooo00?o0000ooooooooool02ooo
ool005Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo00[ooooo00Go2NX:ooooooooooooooooo`WZ2P0Fooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool08oooool00ol9jP[oooooo`WZ2P0Looooo`03o`WZ2_oooooooooo01_ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`00F?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool01Ol9jP[ooooooooooooo
oooo2NX:01Kooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Sooooo`03o`WZ2_oo
oooo2NX:01cooooo00?o2NX:ooooooooool06oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Wooooo001Gooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0;ooooo`05o`WZ2_ooooooooooooooool9jPX05_ooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo02?ooooo00?o2NX:ooooool9jPX07?ooool00ol9jP[ooooooooo
o`0Kooooo`;o00004_ooool00ol0003oooooooooo`09ooooo`00E_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool01Ol9jP[ooooooooooooo
oooo2NX:01Kooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Sooooo`03o`WZ2_oo
oooo2NX:01cooooo00?o2NX:ooooooooool06oooool2o`0001?ooooo00?o0000ooooooooool02?oo
ool005Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00gooooo00Go2NX:ooooooooooooooooo`WZ2P0Fooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool08oooool00ol9jP[oooooo`WZ2P0Looooo`03o`WZ2_oooooooooo01cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`00E?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03_ooool01Ol9jP[ooooooooooooo
oooo2NX:01Kooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Sooooo`03o`WZ2_oo
oooo2NX:01cooooo00?o2NX:ooooooooool07?ooool2o`0001?ooooo00?o0000ooooooooool01ooo
ool005?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00oooooo00Go2NX:ooooooooooooooooo`WZ2P0Gooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool08oooool00ol9jP[oooooo`WZ2P0Looooo`03o`WZ2_oooooooooo01cooooo0_l0
000Booooo`03o`000?oooooooooo00Sooooo001Cooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0?ooooo`05o`WZ2_ooooooooooooooool9jPX05ooo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo02?ooooo00?o2NX:ooooool9jPX07?oo
ool00ol9jP[oooooooooo`0Mooooo`03o`000?oooooooooo00oooooo0_l0000:ooooo`00D_ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04?ooool0
1Ol9jP[ooooooooooooooooo2NX:01Oooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`0Sooooo`03o`WZ2_oooooo2NX:01cooooo00?o2NX:ooooooooool07Oooool2o`0000oooooo0_l0
000;ooooo`00DOooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool04Oooool01Ol9jP[ooooooooooooooooo2NX:01Oooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`0Sooooo`03o`WZ2_oooooo2NX:01cooooo00?o2NX:ooooooooool07Ooo
ool2o`0000kooooo0ol0000;ooooo`00D?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool04_ooool01Ol9jP[ooooooooooooooooo2NX:01Oooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`0Sooooo`03o`WZ2_oooooo2NX:01cooooo0_l9
jPXNooooo`;o00003Oooool00ol0003oooooo`00000<ooooo`00Coooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04oooool01Ol9jP[ooooooooooooo
oooo2NX:01Oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0Sooooo`04o`WZ2_oo
ooooooooo`WZ2Qcooooo00?o2NX:ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`04o`00
0?oooooo0000o`0000cooooo001>ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Cooooo`05o`WZ2_ooooooooooooooool9jPX05oooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo02?ooooo00Co2NX:oooooooooooo2NX:7?ooool00ol9
jP[oooooooooo`0Mooooo`;o00002_ooool01?l0003oooooooooool0000=ooooo`00C_ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool01Ol9
jP[ooooooooooooooooo2NX:01Oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0S
ooooo`04o`WZ2_ooooooooooo`WZ2Qcooooo00?o2NX:ooooooooool07Oooool2o`0000Wooooo00?o
0000ooooooooool00_l0000=ooooo`00COooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool05Oooool01Ol9jP[ooooooooooooooooo2NX:01Oooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Sooooo`03o`WZ2_oooooo2NX:01cooooo00?o
2NX:ooooooooool07_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000
3_ooool004cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01Kooooo00Go2NX:ooooooooooooooooo`WZ2P0Gooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool08oooool00ol9jP[oooooo`WZ2P0Looooo`03o`WZ2_oooooooooo01kooooo
0_l00006ooooo`04o`000?ooooooooooooooo`;o00003_ooool004_ooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo00Go2NX:oooooooooooo
ooooo`WZ2P0Gooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool08oooool00ol9jP[o
ooooo`WZ2P0Kooooo`03o`000?l9jP[ooooo01oooooo0_l00006ooooo`05o`000?oooooooooooooo
ool000003oooool004[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01Sooooo00Go2NX:ooooooooooooooooo`WZ2P0Gooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool08oooool00ol9jP[oooooo`WZ2P0Kooooo`03o`000?l9jP[ooooo
01oooooo0_l00005ooooo`05o`000?ooooooooooooooool000004?ooool004Wooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Sooooo00Go2NX:oooo
ooooooooooooo`WZ2P0Gooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool08oooool0
0ol9jP[oooooo`WZ2P0Looooo`03o`WZ2_oooooooooo01oooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`;o00004?ooool004Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01Wooooo00Go2NX:ooooooooooooooooo`WZ2P0Gooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool08oooool00ol9jP[oooooo`WZ2P0Looooo`03o`WZ2_oo
oooooooo01oooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03ooo
ool004Sooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01[ooooo00Go2NX:ooooooooooooooooo`WZ2P0Gooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool08_ooool2o`000003ooooool9jP[ooooo01_ooooo00?o2NX:ooooooooool07ooo
ool2o`000003ooooool0003ooooo00?ooooo0_l0000Aooooo`00Aoooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06oooool01Ol9jP[ooooooooooooo
oooo2NX:01Oooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Rooooo`;o000000?o
ooooo`WZ2_ooool06oooool00ol9jP[oooooooooo`0Pooooo`;o00001Oooool00ol0003ooooooooo
o`0@ooooo`00A_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool07?ooool01Ol9jP[ooooooooooooooooo2NX:01Oooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`0Sooooo`03o`WZ2_oooooo2NX:01cooooo00?o2NX:ooooooooool08?oo
ool2o`0000Cooooo0_l0000Booooo`00AOooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool07Oooool01_l9jP[ooooooooooooooooo2NX:o`0001Kooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Sooooo`03o`WZ2_oooooo2NX:01cooooo
00?o2NX:ooooooooool07oooool3o`0000Cooooo00?o0000ooooooooool04Oooool004Cooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo00Ko
2NX:ooooooooooooooooo`WZ2_l0000Fooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool08oooool00ol9jP[oooooo`WZ2P0Looooo`;o2NX:7oooool01?l0003oooooo`000?l00003oooo
o`;o00004oooool004Cooooo00?o0000ooooooooool0AOooool01?l0003oooooooooool0000Poooo
o`05o`WZ2_ooooooooooooooool9jPX05oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo02?ooooo00?o2NX:ooooool9jPX07?ooool2o`WZ2Qkooooo00Co0000oooooooooooooooo0_l0
0002ooooo`03o`000?oooooooooo01;ooooo0013ooooo`03o`000?oooooooooo04Oooooo0_l0000Q
ooooo`05o`WZ2_ooooooooooooooool9jPX05oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo02;ooooo00Co2NX:oooooooooooo2NX:7Oooool00ol9jP[oooooooooo`0Kooooo`03o`00
0?oooooooooo00;ooooo0_l000000ooooooo0000o`00000Dooooo`00@_ooool00ol0003ooooooooo
o`18ooooo`;o00008Oooool01Ol9jP[ooooooooooooooooo2NX:01Oooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`0Rooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00?o2NX:oooooooo
ool06_ooool00ol0003oooooooooo`03ooooo`Co00005Oooool0047ooooo00?o0000ooooooooool0
B?ooool01?l0003oooooooooool0000Pooooo`05o`WZ2_ooooooooooooooool9jPX05oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo02;ooooo00Co2NX:oooooooooooo2NX:7Oooool0
0ol9jP[oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo0ol0000Eooooo`00@?ooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool01Ol9
jP[ooooooooooooooooo2NX:01Oooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0R
ooooo`05o`WZ2_ooooooooooooooool9jPX07?ooool00ol9jP[oooooooooo`0Iooooo`03o`000?oo
oooooooo00Gooooo0_l0000Fooooo`00?oooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool07?ooool01Ol9jP[ooooooooooooooooo2NX:01Oooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Rooooo`05o`WZ2_ooooooooooooooool9jPX0
7?ooool00ol9jP[oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
5?ooool003oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01_ooooo00Go2NX:ooooooooooooooooo`WZ2P0Gooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool08_ooool01Ol9jP[ooooooooooooooooo2NX:01cooooo00?o2NX:oooooooo
ool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo000nooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`05o`WZ
2_ooooooooooooooool9jPX05oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo02;o
oooo00Go2NX:ooooooooooooooooo`WZ2P0Looooo`03o`WZ2_oooooooooo01Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Fooooo`00?Oooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool06_ooool01Ol9jP[ooooooooooooooooo2NX:
01Oooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Qooooo`03o`WZ2_oooooooooo
00;ooooo00?o2NX:ooooooooool06_ooool00ol9jP[oooooooooo`0Eooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool05oooool003cooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00Go2NX:ooooooooooooooooo`WZ2P0Goooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool08Oooool00ol9jP[oooooooooo`02oooo
o`03o`WZ2_oooooooooo01[ooooo00?o2NX:ooooooooool05?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01Sooooo000kooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Hooooo`05o`WZ2_ooooooooooooooool9jPX05oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo027ooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooooooo`0Jooooo`03o`WZ2_oooooooooo01?ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Hooooo`00>_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool05oooool01Ol9jP[ooooooooooooooooo2NX:01Oooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`0Qooooo`04o`WZ2_ooooooooooooooo`;o00007?ooool0
0ol9jP[oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06Oooool0
03[ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Kooooo00Go2NX:ooooooooooooooooo`WZ2P0Gooooo`;o00001Oooool00ol9jP[oooooooooo`0Q
ooooo`06o`WZ2_ooooooooooooooool0003o2NX:7?ooool00ol9jP[oooooooooo`0Aooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool06_ooool003Wooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo00Go2NX:oooooooooooooooo
o`WZ2P0Gooooo`;o00001Oooool00ol9jP[oooooooooo`0Qooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool06_ooool2o`WZ2Q7ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Kooooo`00>?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool05?ooool01Ol9jP[ooooooooooooooooo2NX:01Oooooo00?o2NX:ooooooooool0
1?ooool2o`0002;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`0Jooooo`;o2NX:
4Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo000gooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Cooooo`05o`WZ2_oo
ooooooooooooool9jPX05oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_l0003ooooo023ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0Jooooo`;o2NX:4?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01cooooo000fooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Cooooo`05o`WZ2_ooooooooooooooool9jPX0
5oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`0Jooooo`;o2NX:3oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01gooooo000eooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Booooo`05o`WZ2_ooooooooooooooool9jPX05_ooool00ol9jP[ooooo
ooooo`05ooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`0Kooooo`03o`WZ2_oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Nooooo`00=Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool04Oooool01Ol9jP[ooooooooooooooooo2NX:01Kooooo00?o2NX:ooooooooool0
1Oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
6oooool00ol9jP[oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
7oooool003Cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo013ooooo00Go2NX:ooooooooooooooooo`WZ2P0Fooooo`03o`WZ2_oooooooooo00Gooooo
00?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo01_ooooo
00?o2NX:ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo
000cooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0?ooooo`05o`WZ2_ooooooooooooooool9jPX05_ooool00ol9jP[oooooooooo`05ooooo`03o`WZ
2_oooooooooo023ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0Kooooo`03o`WZ
2_oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Pooooo`00<_oo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03_oo
ool01Ol9jP[ooooooooooooooooo2NX:01Kooooo00?o2NX:ooooooooool01Oooool00ol9jP[ooooo
ooooo`0Pooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool06oooool00ol9jP[ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool0037ooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00gooooo00Go
2NX:ooooooooooooooooo`WZ2P0Fooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool0
7oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo01_ooooo00?o2NX:ooooooooool0
1oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo000`ooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`05o`WZ2_oo
ooooooooooooool9jPX05_ooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo01oooooo
00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`0Jooooo`03o`WZ2_oooooooooo00Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`00<?ooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03?ooool01Ol9jP[ooooooooo
oooooooo2NX:01Kooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ
2_oooooooooo00Gooooo00?o2NX:ooooooooool06_ooool00ol9jP[oooooooooo`03ooooo`?o0000
2oooool00ol0003oooooooooo`0Tooooo`00;oooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool02oooool01Ol9jP[ooooooooooooooooo2NX:01Kooooo
00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo00Gooooo
00?o2NX:ooooooooool06_ooool00ol9jP[oooooooooo`03o`0000;ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Tooooo`00;_ooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool02_ooool01Ol9jP[ooooooooooooooooo2NX:01Gooooo
00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo00Gooooo
00?o2NX:ooooooooool06_ooool2o`WZ2P03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Uooooo`00;Oooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool02Oooool01Ol9jP[ooooooooooooooooo2NX:01Gooooo
00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo00Gooooo
00?o2NX:ooooooooool05oooool3o`0000;o2NX:1?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02Kooooo000/ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`08ooooo`05o`WZ2_ooooooooooooooool9jPX05Oooool00ol9jP[ooooo
ooooo`06ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool01Oooool00ol9jP[ooooo
ooooo`0Dooooo`?o00000oooool2o`WZ2P?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Wooooo`00:oooool2o`0004[ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`07ooooo`05o`WZ2_ooooooooooooooool9jPX05Oooool00ol9jP[oooooooooo`06ooooo`03o`WZ
2_oooooooooo01kooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`0Aooooo`?o0000
1_ooool2o`WZ2P;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Xooooo`00:ooo
ool00ol0003oooooo`000018ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool01_oo
ool01Ol9jP[ooooooooooooooooo2NX:01Gooooo00?o2NX:ooooooooool01_ooool00ol9jP[ooooo
ooooo`0Nooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool03_ooool3o`0000Wooooo
0_l9jPX2ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool002_ooooo00Co
0000oooooooooooo0000A_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Gooooo
00Go2NX:ooooooooooooooooo`WZ2P0Eooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo00_ooooo0ol0000<ooooo`;o
2NX:00?oooooo`000?ooool02_ooool00ol0003oooooooooo`0Yooooo`00:oooool01Ol0003ooooo
oooooooooooo000004Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`05ooooo`05
o`WZ2_ooooooooooooooool9jPX05Oooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo
01kooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`07ooooo`Co00003oooool2o`WZ
2P03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:_ooool002_ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool01?ooool01Ol9jP[ooooooooooooooooo2NX:01Gooooo00?o2NX:ooooooooool01_ooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool01?ooool3o`00
01Cooooo00?o2NX:ooooooooool02Oooool00ol0003oooooooooo`0[ooooo`00:oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`03ooooo`05o`WZ2_ooooooooooooooool9jPX05Oooool00ol9jP[oooooooooo`06oooo
o`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool01_ooool01?l9jP[oooooooooooooool3
o`0001Kooooo00?o0000o`WZ2_ooool02Oooool00ol0003oooooooooo`0/ooooo`00:oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX05?ooool00ol9jP[oooooooooo`08
ooooo`03o`WZ2_oooooooooo01gooooo00?o2NX:ooooooooool01_ooool01?l9jP[o0000o`000?l0
000Iooooo`03o`000?l9jP[ooooo00Wooooo00?o0000ooooooooool0;?ooool002[ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Sooooo00Go0000
ooooooooooooooooo`WZ2P03ooooo`03o`WZ2_oooooooooo01;ooooo00?o2NX:ooooooooool02?oo
ool00ol9jP[oooooooooo`0Looooo`03o`WZ2_oooooooooo00Gooooo0_l000000ol9jP[ooooooooo
o`0Iooooo`03o`000?oooooo2NX:00Wooooo00?o0000ooooooooool0;Oooool002[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03[ooooo00Co0000
oooooooooooo2NX:0oooool00ol9jP[oooooooooo`0Booooo`03o`WZ2_oooooooooo00Sooooo00?o
2NX:ooooooooool07?ooool00ol9jP[oooooooooo`02ooooo`?o00000_ooool00ol9jP[ooooooooo
o`0Hooooo`04o`000?ooooooooooo`WZ2PSooooo00?o0000ooooooooool0;_ooool002[ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03cooooo00?o
0000ooooool9jPX00oooool00ol9jP[oooooooooo`0Booooo`03o`WZ2_oooooooooo00Sooooo00?o
2NX:ooooooooool07?ooool00ol9jP[oooooo`000002o`0000Gooooo00?o2NX:ooooooooool05ooo
ool01Ol0003ooooooooooooooooo2NX:00Oooooo00?o0000ooooooooool0;oooool002[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03gooooo00?o
0000o`WZ2_ooool00_ooool00ol9jP[oooooooooo`0Booooo`03o`WZ2_oooooooooo00Sooooo00?o
2NX:ooooooooool06oooool00ol0003o2NX:o`000008ooooo`03o`WZ2_oooooooooo01Kooooo00?o
0000ooooooooool00_ooool00ol9jP[oooooooooo`04ooooo`03o`000?oooooooooo033ooooo000Z
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0o
ooooo`05o`WZ2_ooooooooooooooool9jPX05?ooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oo
oooooooo01Oooooo1?l000000ooooooo2NX:ooooo`08ooooo`03o`WZ2_oooooooooo01Kooooo00?o
0000ooooooooool00ol9jPX00ol0003oooooooooo`03ooooo`03o`000?oooooooooo033ooooo000Z
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`10
ooooo`05o`WZ2_ooooooooooooooool9jPX05?ooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oo
oooooooo01Cooooo0ol00005ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool05Ooo
ool4o`WZ2P;ooooo0_l00004ooooo`03o`000?oooooooooo037ooooo000Zooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`11ooooo`05o`WZ2_l0003o
ooooooooool9jPX05?ooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo017ooooo0ol0
0008ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool04?ooool5o`WZ2POooooo00Go
2NX:ooooooooooooooooo`00000dooooo`00:_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0@_ooool01Ol9jP[oooooo`000?oooooo2NX:01?ooooo
00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0>ooooo`?o00002_ooool00ol9jP[ooooo
ooooo`09ooooo`03o`WZ2_oooooooooo00_ooooo1?l9jPX3ooooo`03o`000?oooooooooo00Kooooo
00Co2NX:oooooooooooo0000=Oooool002[ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo04?ooooo00Go2NX:oooooooooooo0000o`WZ2P0Cooooo`03
o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02oooool3o`0000gooooo00?o2NX:oooooooo
ool02Oooool00ol9jP[oooooooooo`07ooooo`Co2NX:1_ooool00ol0003oooooooooo`07ooooo`04
o`WZ2_ooooooooooo`0003Gooooo000Zooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`13ooooo`05o`WZ2_ooooooooooooooool9jPX04oooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Sooooo0ol0000@ooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool00_ooool5o`WZ2P[ooooo00?o0000ooooooooool01oooool00ol9
jP[oooooo`00000fooooo`00:_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0A?ooool01_l9jP[ooooooooooooooooo2NX:o`0001;ooooo00?o2NX:
ooooooooool02Oooool00ol9jP[oooooooooo`05ooooo`?o00004oooool00ol9jP[oooooooooo`09
ooooo`Go2NX:3_ooool00ol0003oooooooooo`06ooooo`04o`WZ2_l0003o0000o`0003Oooooo000Y
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`15
ooooo`07o`WZ2_ooooooooooooooool9jP[oooooo`00000Aooooo`03o`WZ2_oooooooooo00Wooooo
00?o2NX:ooooooooool00_ooool3o`0001Kooooo00?o2NX:ooooooooool01_ooool4o`WZ2Q7ooooo
00?o0000ooooooooool01?ooool3o`WZ2P03ooooool0003o000003Sooooo000Yooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`16ooooo`05o`WZ2_oo
ooooooooooooool9jPX00_ooool00ol0003oooooooooo`0>ooooo`03o`WZ2_oooooooooo00Wooooo
00?o2NX:o`000?l000000_l0000Iooooo`04o`WZ2_ooooooooooooooo`Go2NX:0oooool00ol9jP[o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo0ol9jPX4ooooo`03o`000?oooooooooo03Oo
oooo000Yooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`17ooooo`05o`WZ2_ooooooooooooooool9jPX00_ooool00ol0003oooooooooo`0>ooooo`03
o`WZ2_oooooooooo00Oooooo0_l000000ol9jP[oooooooooo`0Kooooo`Co2NX:2?ooool00ol9jP[o
ooooooooo`0=ooooo`03o`000?oooooooooo00?o2NX:1oooool00ol0003oooooooooo`0gooooo`00
:Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
B?ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00?o0000ooooooooool03Oooool00ol9jP[o
ooooooooo`04ooooo`?o00000_ooool00ol9jP[oooooooooo`0Gooooo`Co2NX:3?ooool00ol9jP[o
ooooooooo`0=ooooo`?o2NX:2Oooool00ol0003oooooooooo`0hooooo`00:Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0B?ooool01Ol9jP[ooooo
oooooooooooo2NX:00Cooooo00?o0000ooooooooool03?ooool01?l9jP[oooooooooooooool3o`00
00Gooooo00?o2NX:ooooooooool04oooool4o`WZ2P?ooooo00?o2NX:ooooooooool02_ooool00ol9
jP[oooooooooo`0:ooooo`?o2NX:2oooool00ol0003oooooooooo`0iooooo`00:Oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0BOooool01Ol9jP[o
oooooooooooooooo2NX:00Gooooo00?o0000ooooooooool02_ooool00ol9jP[oooooo`000002o`00
00Sooooo00?o2NX:ooooooooool03_ooool5o`WZ2POooooo00?o2NX:ooooooooool02_ooool00ol9
jP[oooooooooo`06ooooo`Co2NX:00?oooooo`000?ooool02_ooool00ol0003oooooooooo`0joooo
o`00:Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0B_ooool01Ol9jP[ooooooooooooooooo2NX:00Kooooo00?o0000ooooooooool02?ooool00ol0
003o2NX:o`00000;ooooo`03o`WZ2_oooooooooo00[ooooo1?l9jPX<ooooo`03o`WZ2_oooooooooo
00[ooooo00?o2NX:ooooooooool00oooool3o`WZ2PCooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0kooooo`00:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0Boooool01Ol9jP[ooooooooooooooooo2NX:00Oooooo00?o0000oooo
ooooool01?ooool3o`000003ooooool9jP[ooooo00_ooooo00?o2NX:ooooooooool01_ooool4o`WZ
2Q3ooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`03o`WZ2PKooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0kooooo`00:Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0C?ooool01Ol9jP[ooooooooooooooooo2NX:
00Sooooo00?o0000ooooooooool00ol00004ooooo`03o`WZ2_oooooooooo00[ooooo00Co2NX:oooo
oooooooooooo1Ol9jPXDooooo`03o`WZ2_oooooooooo00[ooooo0ol9jPX9ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0??ooool002Wooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo04gooooo00Go2NX:ooooooooooooooooo`WZ2P09
ooooo`;o00001oooool00ol9jP[oooooooooo`0:ooooo`Co2NX:6Oooool00ol9jP[oooooooooo`07
ooooo`Co2NX:2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03gooooo000Yoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1=oooo
o`05o`WZ2_ooooooooooooooool9jPX02Oooool00ol0003oooooooooo`06ooooo`03o`WZ2_oooooo
oooo00Kooooo1Ol9jPXKooooo`03o`WZ2_oooooooooo00Gooooo0ol9jPX3ooooo`03o`WZ2_oooooo
oooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0nooooo`00:?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0C_ooool01Ol9
jP[ooooooooooooooooo2NX:00Sooooo00?o0000ooooooooool01oooool01?l9jP[ooooooooooooo
ool5o`WZ2PCooooo00?o2NX:ooooooooool06Oooool01?l9jP[oooooooooooooool4o`WZ2PKooooo
00?o2NX:ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03oooooo
000Xooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1?ooooo`05o`WZ2_ooooooooooooooool9jPX01oooool00ol0003oooooooooo`06ooooo`;o0000
1?l9jPX9ooooo`03o`WZ2_oooooooooo01Wooooo1?l9jPX:ooooo`03o`WZ2_oooooooooo00Gooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0oooooo`00:?ooool00ol0003ooooooooo
o`0Pooooo`;o00004?ooool00ol0003oooooooooo`1@ooooo`05o`WZ2_ooooooooooooooool9jPX0
1_ooool00ol0003oooooooooo`05ooooo`;o2NX:0_l000000ol9jP[oooooooooo`0:ooooo`03o`WZ
2_oooooooooo01Oooooo0ol9jPX=ooooo`03o`WZ2_oooooooooo00Gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`10ooooo`00:?ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0DOooool01Ol9jP[ooooooooooooooooo2NX:00Gooooo
00?o0000ooooooooool00oooool3o`WZ2P?ooooo00?o2NX:ooooooooool02oooool00ol9jP[ooooo
ooooo`0Dooooo`?o2NX:0_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo00Cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`11ooooo`00:?ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0D_ooool01Ol9jP[ooooooooo
oooooooo2NX:00Gooooo00?o0000ooooooooool00ol9jPX6ooooo`03o`WZ2_oooooooooo00_ooooo
00?o2NX:ooooooooool04Oooool3o`WZ2PGooooo00?o2NX:ooooooooool02oooool00ol9jP[ooooo
ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0@_ooool002Sooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05;ooooo00Go
2NX:ooooooooooooooooo`WZ2P04ooooo`04o`000?l9jP[o2NX:o`WZ2PWooooo00?o2NX:oooooooo
ool02oooool00ol9jP[oooooooooo`0>ooooo`?o2NX:2?ooool00ol9jP[oooooooooo`0;ooooo`03
o`WZ2_oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`13ooooo`00
:?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Doooool01Ol9jP[ooooooooooooooooo2NX:00;ooooo0ol9jPX<ooooo`03o`WZ2_oooooooooo00_o
oooo00?o2NX:ooooooooool02_ooool4o`WZ2P[ooooo00?o2NX:ooooooooool03Oooool01?l9jP[o
ooooooooool0000<ooooo`03o`000?oooooooooo04?ooooo000Xooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Dooooo`04o`WZ2_oooooooooooooo
o`?o2NX:00?o0000ooooooooool03?ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo
00Oooooo0ol9jPX>ooooo`03o`WZ2_oooooooooo00gooooo00Co2NX:oooooooooooo00002oooool0
0ol0003oooooooooo`14ooooo`00:?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0EOooool5o`WZ2P03ooooool0003ooooo00kooooo00?o2NX:oooo
ooooool02oooool00ol9jP[oooooooooo`04ooooo`?o2NX:4Oooool00ol9jP[oooooooooo`0=oooo
o`03o`WZ2_oooooo000000_ooooo00?o0000ooooooooool0AOooool002Sooooo00?o0000oooooooo
ool0:?ooool01Ol0003ooooooooooooooooo000005Kooooo0ol9jPX3ooooo`03o`WZ2_oooooo0000
00oooooo00?o2NX:ooooooooool02oooool01?l9jP[oooooooooooooool3o`WZ2QCooooo00?o2NX:
ooooooooool03Oooool00ol9jP[o0000ooooo`0:ooooo`03o`000?oooooooooo04Kooooo000Xoooo
o`03o`000?oooooooooo02Wooooo00Co0000oooooooooooo0000Doooool3o`WZ2P;ooooo00Ko2NX:
ooooooooooooooooo`WZ2_l0000@ooooo`03o`WZ2_oooooooooo00_ooooo1?l9jPXGooooo`03o`WZ
2_oooooooooo00gooooo00?o2NX:ooooooooool02Oooool00ol0003oooooooooo`17ooooo`00:?oo
ool00ol0003oooooooooo`0Zooooo`;o0000DOooool3o`WZ2PGooooo00Go2NX:oooooooooooooooo
o`WZ2P0@ooooo`03o`WZ2_oooooooooo00[ooooo0ol9jPXJooooo`03o`WZ2_oooooooooo00cooooo
00?o0000o`WZ2_ooool02_ooool00ol0003oooooooooo`17ooooo`009oooool00ol0003ooooooooo
o`0[ooooo`;o0000COooool4o`WZ2PSooooo00Go2NX:oooooooooooo0000o`WZ2P0@ooooo`03o`WZ
2_oooooooooo00Kooooo1?l9jPX2ooooo`03o`WZ2_oooooooooo01Sooooo00?o2NX:ooooooooool0
3?ooool00ol0003o2NX:ooooo`09ooooo`03o`000?oooooooooo04Sooooo000Wooooo`03o`000?oo
oooooooo02[ooooo00Co0000oooooooooooo0000BOooool3o`WZ2Pcooooo00Go2NX:ooooool0003o
ooooo`WZ2P0@ooooo`03o`WZ2_oooooooooo00?ooooo0ol9jPX6ooooo`03o`WZ2_oooooooooo01Oo
oooo00?o2NX:ooooooooool03?ooool00ol0003oooooo`WZ2P09ooooo`03o`000?oooooooooo04Wo
oooo000Wooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`13ooooo`?o2NX:3oooool01Ol9jP[oooooo`000?oooooo2NX:013ooooo00?o2NX:oooooooo
ool00ol9jPX:ooooo`03o`WZ2_oooooooooo01Kooooo00?o2NX:ooooooooool02oooool01?l0003o
ooooooooool9jPX8ooooo`03o`000?oooooooooo04[ooooo000Wooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`?o2NX:4_ooool01Ol9jP[o
0000oooooooooooo2NX:013ooooo0ol9jPX=ooooo`03o`WZ2_oooooooooo01Kooooo00?o2NX:oooo
ooooool02_ooool00ol0003oooooo`WZ2P02o`WZ2POooooo00?o0000ooooooooool0Boooool002Oo
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03_o
oooo0ol9jPXEooooo`05o`WZ2_ooooooooooooooool9jPX03Oooool4o`WZ2Poooooo00?o2NX:oooo
ooooool05_ooool00ol9jP[oooooooooo`08ooooo`Co2NX:00?oooooo`000?l000001oooool00ol0
003oooooooooo`1;ooooo`009oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0=oooool3o`WZ2QOooooo00?o0000o`WZ2_ooool00_ooool00ol9jP[o
ooooooooo`08ooooo`?o2NX:0oooool00ol9jP[oooooooooo`0=ooooo`03o`WZ2_oooooooooo01Ko
oooo00?o2NX:ooooooooool01?ooool4o`WZ2P03ooooool0003ooooo00[ooooo00?o0000oooooooo
ool0C?ooool002Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo03?ooooo0ol9jPXIooooo`03o`000?oooooo2NX:00?ooooo00?o2NX:ooooooooool0
1?ooool4o`WZ2PKooooo00?o2NX:ooooooooool03Oooool00ol9jP[oooooooooo`0Fooooo`03o`WZ
2_oooooooooo00Co2NX:1?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04gooooo
000Wooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0_ooooo`?o2NX:7?ooool00ol0003oooooo`WZ2P03ooooo`04o`WZ2_ooooooooooooooo`?o2NX:
2_ooool00ol9jP[oooooooooo`0=ooooo`03o`WZ2_oooooooooo01Gooooo1?l9jPX7ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0C_ooool002Oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02_ooooo0ol9jPXNooooo`04o`000?oo
ooooooooo`WZ2P?ooooo1?l9jPX<ooooo`03o`WZ2_oooooooooo00kooooo00?o2NX:ooooooooool0
4Oooool5o`WZ2PWooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1?ooooo`009ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09ooo
ool3o`WZ2R3ooooo00Ko0000ooooooooooooooooo`WZ2_ooool3o`WZ2Poooooo00?o2NX:oooooooo
ool03_ooool00ol9jP[oooooooooo`0=ooooo`Co2NX:1?ooool00ol9jP[oooooooooo`06ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0Coooool002Oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02;ooooo1?l9jPXRooooo`04o`00
0?ooooooooooooooo`?o2NX:0_ooool00ol9jP[oooooooooo`0=ooooo`03o`WZ2_oooooooooo00ko
oooo00?o2NX:ooooooooool02Oooool4o`WZ2PSooooo00?o2NX:ooooooooool01_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo053ooooo000Vooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Nooooo`?o2NX:9Oooool00ol0003ooooo
o`WZ2P02o`WZ2P03ooooool9jP[ooooo00;ooooo00?o2NX:ooooooooool03Oooool00ol9jP[ooooo
ooooo`0>ooooo`03o`WZ2_oooooooooo00Gooooo1?l9jPX<ooooo`03o`WZ2_oooooooooo00Gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Aooooo`009_ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06_ooool3o`WZ2ROooooo0ol9
jPX4ooooo`05o`WZ2_ooooooooooooooool9jPX03oooool00ol9jP[oooooooooo`0>ooooo`04o`WZ
2_ooooooooooooooo`Co2NX:4?ooool00ol9jP[oooooooooo`04ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0D_ooool002Kooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo01Kooooo0ol9jPXVooooo`Co2NX:00?o0000ooooooooool0
1?ooool01Ol9jP[ooooooooooooooooo2NX:00oooooo00?o2NX:ooooooooool03_ooool4o`WZ2QCo
oooo00?o2NX:ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05?o
oooo000Vooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Booooo`?o2NX:9_ooool3o`WZ2P?ooooo00?o0000ooooooooool01Oooool01Ol9jP[ooooo
oooooooooooo2NX:00oooooo00?o2NX:ooooooooool02_ooool5o`WZ2QOooooo00?o2NX:oooooooo
ool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?ooooo000Vooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0>ooooo`?o2NX:
9_ooool3o`WZ2PGooooo00?o0000ooooooooool01_ooool01Ol9jP[ooooooooooooooooo2NX:00oo
oooo00?o2NX:ooooooooool01_ooool4o`WZ2PCooooo00?o2NX:ooooooooool05?ooool00ol9jP[o
ooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E?ooool002Kooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00[ooooo
0ol9jPXVooooo`?o2NX:1oooool00ol0003oooooooooo`06ooooo`;o00000oooool00ol9jP[ooooo
ooooo`0<ooooo`03o`WZ2_oooooooooo00?ooooo1?l9jPX8ooooo`03o`WZ2_oooooooooo01Cooooo
00?o2NX:ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Gooooo
000Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`06ooooo`?o2NX:9_ooool3o`WZ2P[ooooo00?o0000ooooooooool01_ooool2o`0000?ooooo00?o
2NX:ooooooooool03?ooool00ol9jP[oooooo`WZ2P03o`WZ2Pcooooo00?o2NX:ooooooooool05?oo
ool01Ol9jP[ooooooooooooooooo000000_ooooo00?o0000ooooooooool0E_ooool002Kooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00;ooooo0ol9
jPXVooooo`?o2NX:3?ooool00ol0003oooooooooo`08ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool02?ooool5o`WZ2Q3ooooo00?o2NX:ooooooooool05?ooool01?l9jP[ooooooooo
ool0000;ooooo`03o`000?oooooooooo05Oooooo000Vooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool08Oooool01?l0003o2NX:o`WZ2_l9jPXUooooo`Co2NX:3_ooool00ol0003ooooo
ooooo`09ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool01?ooool4o`WZ2P?ooooo
00?o2NX:ooooooooool03oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooo000000cooooo
00?o0000ooooooooool0Eoooool002Kooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Pooooo`?o2NX:0_l0000Sooooo`?o2NX:4Oooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooooooool01?l9jPX7ooooo`03o`WZ2_oooooooooo00oooooo00?o
2NX:ooooooooool05?ooool00ol9jP[oooooo`00000;ooooo`03o`000?oooooooooo05Sooooo000V
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07Oooool4o`WZ2PGooooo00?o0000
ooooooooool07Oooool3o`WZ2Q?ooooo00?o0000ooooooooool02oooool01?l9jP[ooooooooooooo
ool4o`WZ2P_ooooo00?o2NX:ooooooooool03oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_l0
003ooooo00[ooooo00?o0000ooooooooool0FOooool002Gooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Jooooo`?o2NX:2_ooool00ol0003oooooooooo`0Iooooo`?o2NX:5_ooool0
0ol0003oooooooooo`0:ooooo`Go2NX:00?oooooo`WZ2_ooool03?ooool00ol9jP[oooooooooo`0?
ooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:o`000?ooool02_ooool00ol0003oooooooooo`1J
ooooo`009Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Sooooo0ol9jPX>oooo
o`03o`000?oooooooooo01Gooooo0ol9jPXHooooo`03o`000?oooooooooo00Sooooo1?l9jPX5oooo
o`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool03oooool00ol9jP[oooooooooo`0Coooo
o`03o`WZ2_oooooooooo00Wooooo00?o0000ooooooooool0Foooool002Gooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Fooooo`?o2NX:4_ooool00ol0003oooooooooo`0Aooooo`?o
2NX:6_ooool00ol0003oooooooooo`05ooooo`Co2NX:0oooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool03oooool00ol9jP[oooooooooo`0Booooo`03
o`000?l9jP[ooooo00[ooooo00?o0000ooooooooool0Foooool002Gooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Dooooo`?o2NX:5_ooool00ol0003oooooooooo`0<ooooo`Co2NX:
7?ooool00ol0003oooooooooo`02ooooo`Co2NX:1oooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00[ooooo00?o2NX:ooooooooool04?ooool00ol9jP[oooooooooo`0Booooo`03o`00
0?l9jP[ooooo00Wooooo00?o0000ooooooooool0G?ooool002Gooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Booooo`?o2NX:6_ooool00ol0003oooooooooo`08ooooo`?o2NX:7ooo
ool00ol0003oooooo`WZ2P03o`WZ2P_ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`0:ooooo`03o`WZ2_oooooooooo013ooooo00?o2NX:ooooooooool04Oooool00ol0003oooooo`WZ
2P09ooooo`03o`000?oooooooooo05gooooo000Uooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool03oooool3o`WZ2Qkooooo00?o0000ooooooooool01?ooool3o`WZ2R3ooooo1?l9jPX?
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`0@
ooooo`03o`WZ2_oooooooooo013ooooo00Co0000oooooooooooo2NX:2?ooool00ol0003ooooooooo
o`1Nooooo`009Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00gooooo0ol9jPXR
ooooo`03o`000?oooooooooo00?o2NX:7oooool4o`WZ2P03ooooool0003ooooo013ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo013ooooo00?o2NX:
ooooooooool03oooool01Ol0003ooooooooooooooooo2NX:00Oooooo00?o0000ooooooooool0Gooo
ool002Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;ooooo`?o2NX:9Oooool3
o`WZ2Qkooooo1?l9jPX4ooooo`03o`000?oooooooooo013ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo013ooooo00?o2NX:ooooooooool03_ooool0
1Ol0003ooooooooooooooooo2NX:00Sooooo00?o0000ooooooooool0Goooool002Gooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`06ooooo`;o000000Coooooo`WZ2_l9jP[o2NX:9Ooo
ool3o`WZ2P;ooooo00?o0000ooooooooool06?ooool4o`WZ2POooooo00?o0000ooooooooool04Ooo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool04?oo
ool00ol9jP[oooooooooo`0>ooooo`05o`000?ooooooooooooooool9jPX01oooool00ol0003ooooo
ooooo`1Pooooo`009Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00Co
2NX:o`000?l0003o2NX:9?ooool4o`WZ2PKooooo00?o0000ooooooooool04oooool4o`WZ2P[ooooo
00?o0000ooooooooool04Oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00[ooooo
00?o2NX:ooooooooool04?ooool00ol9jP[oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo
0_l00005ooooo`03o`000?oooooooooo067ooooo000Uooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool01?ooool3o`WZ2RGooooo0ol9jPX;ooooo`03o`000?oooooooooo00kooooo1?l9
jPX>ooooo`03o`000?oooooooooo017ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`0:ooooo`03o`WZ2_oooooooooo013ooooo00?o2NX:ooooooooool03?ooool01?l0003ooooooooo
ooooool2o`WZ2P;o00001?ooool00ol0003oooooooooo`1Rooooo`009Oooool00ol0003ooooooooo
o`0Booooo`04o`000?ooooooooooooooo`?o2NX:9Oooool3o`WZ2Poooooo00?o0000ooooooooool0
1oooool2o`0000Co2NX:4Oooool00ol0003oooooooooo`0Booooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`0@ooooo`03o`WZ2_oooooooooo00_ooooo
00?o0000ooooool9jPX00_l9jPX7ooooo`03o`000?oooooooooo06?ooooo000Tooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooool9jPX00_l9jPXUooooo`?o2NX:4oooool00ol0003ooooooooo
o`04ooooo`;o2NX:0_l0000Dooooo`03o`000?oooooooooo01?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo017ooooo00?o2NX:ooooooooool02_oo
ool3o`WZ2P[ooooo00?o0000ooooooooool0Hoooool002Cooooo00?o0000ooooooooool04Oooool0
0ol0003o2NX:o`WZ2P0Uooooo`?o2NX:5oooool00ol0003oooooooooo`03o`WZ2QOooooo00?o0000
ooooooooool05?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:
ooooooooool04Oooool00ol9jP[oooooooooo`06ooooo`Co2NX:00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1Tooooo`009?ooool00ol0003oooooooooo`0>ooooo`;o2NX:00?o0000oooo
ooooool08Oooool2o`0000?o2NX:6_ooool3o`WZ2QWooooo00?o0000ooooooooool05Oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool04Oooool00ol9
jP[oooooooooo`03ooooo`?o2NX:0oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
06Gooooo000Tooooo`03o`000?oooooooooo00_ooooo0ol9jPX00ooooooo0000ooooo`0Qooooo`;o
2NX:0_l0000Jooooo`?o2NX:0_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Go
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo017o
oooo00?o2NX:ooooooooool00ol9jPX5ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0I_ooool002Cooooo00?o0000ooooooooool01oooool4o`WZ2P?ooooo00?o0000ooooooooool0
7_ooool3o`WZ2Q[ooooo1?l9jPX6ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
5_ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool0
4?ooool4o`WZ2POooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Wooooo`009?oo
ool00ol0003oooooooooo`04ooooo`?o2NX:1oooool00ol0003oooooooooo`0Kooooo`?o2NX:6_oo
ool3o`WZ2P_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Fooooo`03o`WZ2_oo
oooooooo00Gooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0=ooooo`?o2NX:0_oo
ool00ol9jP[oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Iooo
ool002Cooooo00Co0000oooooooooooooooo0ol9jPX9ooooo`03o`000?oooooooooo01Wooooo0ol9
jPXJooooo`?o2NX:3oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Oooooo00?o
2NX:ooooooooool01Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo0ol9
jPX5ooooo`03o`WZ2_oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Xooooo`009?ooool01?l0003o2NX:o`WZ2_l9jPX;ooooo`03o`000?oooooooooo01Oooooo0ol9
jPXIooooo`Co2NX:4oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00?o
2NX:ooooooooool01Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Kooooo1?l9
jPX8ooooo`03o`WZ2_oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Yooooo`008_ooool2o`WZ2P03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool4
o`WZ2QWooooo0ol9jPXHooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06?ooool0
0ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool01?ooool3
o`WZ2Pcooooo00?o2NX:ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo06[ooooo000Oooooo`?o2NX:0_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01;ooooo0ol9jPXJooooo`?o2NX:7?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01Wooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`08ooooo`04o`WZ2_oooooooooo
ooooo`?o2NX:3oooool00ol9jP[oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0Joooool001cooooo0ol9jPX5ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool04?ooool3o`WZ2Q[ooooo0ol9jPXPooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool06_ooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00Sooooo1?l9jPXBoooo
o`05o`WZ2_ooooooooooooooool000003?ooool00ol0003oooooooooo`1[ooooo`006Oooool3o`WZ
2POooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`?o2NX:6Oooool4o`WZ
2RCooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`WZ2_oooooooooo
00Gooooo00?o2NX:ooooooooool01Oooool4o`WZ2QGooooo00Go2NX:ooooooooooooooooo`00000;
ooooo`03o`000?oooooooooo06cooooo000Gooooo`;o2NX:2_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo1?l9jPXIooooo`?o2NX::Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01cooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`02oooo
o`?o2NX:0oooool00ol9jP[oooooooooo`0Cooooo`04o`WZ2_ooooooooooo`0000_ooooo00?o0000
ooooooooool0KOooool002?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`?o2NX:6_ooool3o`WZ2Rgooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Loooo
o`03o`WZ2_oooooooooo00Gooooo1Ol9jPX6ooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:oooo
ool000002oooool00ol0003oooooooooo`1^ooooo`008oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo0ol9jPXJooooo`?o2NX:<Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01cooooo00?o2NX:ooooooooool01?ooool3o`WZ2P[ooooo00?o2NX:oooooooo
ool04oooool00ol9jP[o0000ooooo`0;ooooo`03o`000?oooooooooo06kooooo000Sooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01?ooool3o`WZ2QWooooo1?l9jPXeooooo`05o`00
0?ooooooooooooooool000007oooool01?l9jP[oooooooooooooool3o`WZ2P;ooooo00?o2NX:oooo
ooooool02?ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo00[ooooo00?o0000oooo
ooooool0Koooool002?ooooo00?o0000ooooooooool01_ooool01?l0003oooooooooooooool3o`WZ
2QWooooo0ol9jPXjooooo`03o`000?oooooo0000023ooooo1?l9jPX5ooooo`03o`WZ2_oooooooooo
00Sooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`09ooooo`03o`000?oooooooooo
073ooooo000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_l9jPXIooooo`?o
2NX:?_ooool00ol0003oooooooooo`0Looooo`Co2NX:2?ooool00ol9jP[oooooooooo`07ooooo`03
o`WZ2_oooooooooo01?ooooo00?o0000o`WZ2_ooool02Oooool00ol0003oooooooooo`1aooooo`00
8oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo1?l9jPY1ooooo`03o`00
0?oooooooooo01Wooooo0ol9jPX3ooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool0
1oooool00ol9jP[oooooooooo`0Booooo`03o`000?oooooo2NX:00Wooooo00?o0000ooooooooool0
L_ooool002?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`?o2NX:AOoo
ool00ol0003oooooooooo`0Fooooo`?o2NX:1_ooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oo
oooooooo00Oooooo00?o2NX:ooooooooool04Oooool01?l0003oooooooooool9jPX9ooooo`03o`00
0?oooooooooo07;ooooo000Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?oo
ool3o`WZ2TSooooo00?o0000ooooooooool04_ooool4o`WZ2PWooooo00?o2NX:ooooooooool01_oo
ool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo017ooooo00Co0000oooooooooooo2NX:
2?ooool00ol0003oooooooooo`1cooooo`008oooool01Ol0003ooooooooooooooooo000001Cooooo
0ol9jPY;ooooo`03o`000?oooooooooo00oooooo0ol9jPX=ooooo`03o`WZ2_oooooooooo00Kooooo
00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`0@ooooo`05o`000?ooooooooooooooool9
jPX01oooool00ol0003oooooooooo`1dooooo`008_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00kooooo0_l9jPX2o`0004kooooo00?o0000ooooooooool03?ooool3o`WZ2Q3ooooo
00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo00oooooo
00?o0000ooooooooool00_ooool00ol9jP[oooooooooo`04ooooo`03o`000?oooooooooo07Gooooo
000Rooooo`05o`000?ooooooooooooooool000003_ooool3o`WZ2P;ooooo0_l0001>ooooo`03o`00
0?oooooooooo00Sooooo1?l9jPXBooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool0
1oooool00ol9jP[oooooooooo`0>ooooo`04o`000?ooooooooooooooo`?o2NX:00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1fooooo`008_ooool01?l0003oooooooooool0000<ooooo`?o
2NX:EOooool00ol0003oooooooooo`05ooooo`?o2NX:5_ooool00ol9jP[oooooooooo`07ooooo`03
o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool03Oooool00ol0003oooooo`WZ2P02o`WZ2P;o
oooo0_l00004ooooo`03o`000?oooooooooo07Kooooo000Rooooo`03o`000?oooooo000000[ooooo
0ol9jPYHooooo`03o`000?oooooooooo00;ooooo0ol9jPXIooooo`03o`WZ2_oooooooooo00Oooooo
00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`0;ooooo`Co2NX:2_ooool00ol0003ooooo
ooooo`1gooooo`008_ooool2o`0000Sooooo0ol9jPYKooooo`03o`000?l9jP[o2NX:00;o2NX:7?oo
ool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool02?oo
ool4o`WZ2P03ooooool0003ooooo00[ooooo00?o0000ooooooooool0N?ooool002;ooooo00?o0000
ooooooooool00oooool4o`WZ2Ucooooo0ol9jPXPooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:
ooooooooool01_ooool00ol9jP[oooooooooo`05ooooo`?o2NX:1?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo07Wooooo000Rooooo`03o`000?oooooooooo00?o2NX:GOooool3o`WZ
2P;ooooo00?o0000ooooooooool07_ooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo
00Kooooo00Co2NX:oooooooooooooooo1?l9jPX6ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0N_ooool002;ooooo00?o0000o`WZ2_l9jPX0G?ooool4o`WZ2PGooooo00?o0000oooo
ooooool07_ooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo00Kooooo1?l9jPX9oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0N_ooool001oooooo0ol9jPX00ooooooo
0000ooooo`1Iooooo`?o2NX:2Oooool00ol0003oooooooooo`0Nooooo`03o`WZ2_oooooooooo00Oo
oooo00?o2NX:ooooooooool00oooool4o`WZ2Pcooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1kooooo`007?ooool3o`WZ2PCooooo00?o0000ooooooooool0EOooool3o`WZ2Pcooooo
00?o0000ooooooooool07Oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooo2NX:00?o2NX:
0oooool00ol9jP[oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
O?ooool001Sooooo1?l9jPX7ooooo`03o`000?oooooooooo057ooooo1?l9jPX?ooooo`03o`000?oo
oooooooo01gooooo00?o2NX:ooooooooool01_ooool4o`WZ2POooooo00?o2NX:ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07gooooo000Eooooo`?o2NX:2oooool2
o`0004oooooo0ol9jPXCooooo`03o`000?oooooooooo01gooooo00?o2NX:ooooooooool00oooool3
o`WZ2P;ooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`07ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0O_ooool001;ooooo0ol9jPX?ooooo`03o`000?oooooooooo
04Oooooo0_l000001?oooooo2NX:o`WZ2_l9jPXEooooo`03o`000?oooooooooo01kooooo00?o2NX:
ooooool9jPX00ol9jPX5ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool01oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07kooooo000?ooooo`?o2NX:4_ooool00ol0
003oooooooooo`16ooooo`04o`WZ2_l0003o0000o`WZ2QSooooo00?o0000ooooooooool07?ooool4
o`WZ2PWooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`07ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0Ooooool000cooooo0ol9jPXEooooo`03o`000?oooooooooo
04?ooooo0ol9jPXLooooo`03o`000?oooooooooo01Wooooo0ol9jPX2ooooo`03o`WZ2_oooooooooo
00Sooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`06ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0P?ooool000[ooooo0_l9jPXIooooo`03o`000?oooooooooo03oo
oooo0ol9jPXOooooo`03o`000?oooooooooo01Gooooo1?l9jPX5ooooo`03o`WZ2_oooooooooo00So
oooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`05ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0POooool002Gooooo00?o0000ooooooooool0>oooool4o`WZ2R;ooooo
00?o0000ooooooooool04_ooool3o`WZ2PWooooo00?o2NX:ooooooooool02?ooool00ol9jP[ooooo
ooooo`05ooooo`03o`WZ2_oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`22ooooo`009Oooool00ol0003oooooooooo`0hooooo`?o2NX:9_ooool00ol0003ooooooooo
o`0>ooooo`Co2NX:3?ooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00Gooooo00?o
2NX:ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08;ooooo000U
ooooo`;o0000=_ooool3o`WZ2RWooooo00?o0000ooooooooool02_ooool4o`WZ2Poooooo00?o2NX:
ooooooooool02Oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00?ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`23ooooo`009_ooool00ol0003oooooooooo`0aoooo
o`?o2NX:;?ooool00ol0003oooooooooo`07ooooo`?o2NX:4oooool00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool00_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo08Cooooo000Vooooo`03o`000?oooooooooo02gooooo1?l9jPX_ooooo`03
o`000?oooooooooo00?ooooo1?l9jPXFooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooooooo
ool01Oooool01Ol9jP[ooooooooooooooooo000000_ooooo00?o0000ooooooooool0QOooool002Ko
oooo00?o0000ooooooooool0:_ooool3o`WZ2S?ooooo00?o0000ooooool9jPX00ol9jPXJooooo`03
o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool01?ooool01Ol9jP[ooooooooooooooooo0000
00_ooooo00?o0000ooooooooool0Q_ooool002Kooooo0_l0000Xooooo`?o2NX:=Oooool3o`WZ2Qko
oooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`04ooooo`04o`WZ2_ooooooooooo`00
00cooooo00?o0000ooooooooool0Q_ooool002Oooooo00?o0000ooooooooool08_ooool4o`WZ2SCo
oooo1?l9jPX00ooooooo0000ooooo`0Nooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooooooo
ool01?ooool01?l9jP[oooooooooool0000;ooooo`03o`000?oooooooooo08Oooooo000Wooooo`03
o`000?oooooooooo01oooooo0ol9jPXdooooo`Co2NX:1Oooool00ol0003oooooooooo`0Mooooo`03
o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooo`00000;ooooo`03
o`000?oooooooooo08Sooooo000Wooooo`;o00007Oooool3o`WZ2SCooooo0ol9jPX9ooooo`03o`00
0?oooooooooo01gooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_l0003ooooo00[ooooo00?o0000ooooooooool0ROooool002Sooooo00?o0000ooooooooool06?oo
ool3o`WZ2S?ooooo00Co2NX:o`000?l0003o2NX:3?ooool00ol0003oooooooooo`0Looooo`03o`WZ
2_oooooooooo00[ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`09ooooo`03o`00
0?oooooooooo08[ooooo000Xooooo`03o`000?oooooooooo01Kooooo0_l9jPXcooooo`?o2NX:00?o
ooooo`000?l000003Oooool00ol0003oooooooooo`0Looooo`03o`WZ2_oooooooooo00[ooooo00?o
2NX:ooooooooool00oooool00ol0003o2NX:ooooo`0:ooooo`03o`000?oooooooooo08[ooooo000X
ooooo`03o`000?oooooooooo04Oooooo1?l9jPXCooooo`03o`000?oooooooooo01cooooo00?o2NX:
ooooooooool02_ooool00ol9jP[oooooooooo`03ooooo`03o`000?l9jP[ooooo00Wooooo00?o0000
ooooooooool0Roooool002Sooooo0_l00015ooooo`?o2NX:5oooool00ol0003oooooooooo`0Loooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool00_ooool00ol0003oooooo`WZ2P09oooo
o`03o`000?oooooooooo08cooooo000Yooooo`03o`000?oooooooooo043ooooo0ol9jPXJooooo`03
o`000?oooooooooo01cooooo00?o2NX:ooooooooool02_ooool01ol9jP[ooooooooooooooooo0000
ooooool9jPX02Oooool00ol0003oooooooooo`2=ooooo`00:Oooool00ol0003oooooooooo`0loooo
o`Co2NX:7Oooool00ol0003oooooooooo`0Looooo`03o`WZ2_oooooooooo00[ooooo00Co2NX:oooo
oooooooo00000_ooool00ol9jP[oooooooooo`06ooooo`03o`000?oooooooooo08kooooo000Yoooo
o`03o`000?oooooooooo03Wooooo0ol9jPXQooooo`03o`000?oooooooooo01cooooo00?o2NX:oooo
ooooool02_ooool00ol9jP[oooooo`000003ooooo`03o`WZ2_oooooooooo00Kooooo00?o0000oooo
ooooool0S_ooool002Wooooo0_l0000fooooo`Co2NX:9?ooool00ol0003oooooooooo`0Looooo`03
o`WZ2_oooooooooo00[ooooo00Go2NX:ooooool0003oooooo`WZ2P02o`0000Oooooo00?o0000oooo
ooooool0Soooool002[ooooo00?o0000ooooooooool0<Oooool3o`WZ2RSooooo00?o0000oooooooo
ool07?ooool00ol9jP[oooooooooo`0:ooooo`Co2NX:00?oooooo`000?l000001_ooool00ol0003o
ooooooooo`2@ooooo`00:_ooool00ol0003oooooooooo`0^ooooo`?o2NX::oooool00ol0003ooooo
ooooo`0Kooooo`03o`WZ2_oooooooooo00Sooooo1?l9jPX;ooooo`03o`000?oooooooooo097ooooo
000Zooooo`;o0000:oooool4o`WZ2Rkooooo00?o0000ooooooooool06oooool00ol9jP[ooooooooo
o`05ooooo`?o2NX:0_ooool00ol0003o2NX:ooooo`09ooooo`03o`000?oooooooooo09;ooooo000[
ooooo`03o`000?oooooooooo02Kooooo0ol9jPXbooooo`03o`000?oooooooooo01_ooooo00Co2NX:
oooooooooooooooo1?l9jPX4ooooo`03o`000?oooooo2NX:00[ooooo00?o0000ooooooooool0T_oo
ool002_ooooo00?o0000ooooooooool08_ooool4o`WZ2SGooooo00?o0000ooooooooool06oooool4
o`WZ2PSooooo00?o0000ooooool9jPX02Oooool00ol0003oooooooooo`2Cooooo`00:oooool00ol0
003oooooooooo`0Oooooo`?o2NX:>Oooool00ol0003oooooooooo`0Iooooo`?o2NX:2_ooool01?l0
003oooooooooool9jPX8ooooo`03o`000?oooooooooo09Cooooo000[ooooo`;o00007Oooool3o`WZ
2Scooooo00?o0000ooooooooool05Oooool4o`WZ2P;ooooo00?o2NX:ooooooooool01oooool01Ol0
003ooooooooooooooooo2NX:00Oooooo00?o0000ooooooooool0UOooool002cooooo00?o0000oooo
ooooool05oooool4o`WZ2Soooooo00?o0000ooooooooool04_ooool3o`WZ2PKooooo00?o2NX:oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`WZ2_oooooooooo00Cooooo00?o0000oooo
ooooool0U_ooool002cooooo00?o0000ooooooooool05?ooool3o`WZ2T?ooooo00?o0000oooooooo
ool03_ooool4o`WZ2PWooooo00?o2NX:ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o0000ooooooooool0U_ooool002cooooo0_l0000Aooooo`;o2NX:
0_l00016ooooo`03o`000?oooooooooo00_ooooo0ol9jPX=ooooo`03o`WZ2_oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`000?oooooooooo09Oooooo
000/ooooo`;o00003_ooool3o`WZ2P;ooooo0_l00015ooooo`03o`000?oooooooooo00Sooooo1?l9
jPX?ooooo`03o`WZ2_oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol9jP[ooooooooo
o`02ooooo`03o`000?oooooooooo09Sooooo000]ooooo`03o`000?oooooooooo00Wooooo0ol9jPY<
ooooo`03o`000?oooooooooo00Gooooo0ol9jPXCooooo`03o`WZ2_oooooooooo00Cooooo00?o0000
ooooooooool01Oooool01Ol9jP[ooooooooooooooooo000009_ooooo000]ooooo`03o`000?oooooo
oooo00Kooooo0ol9jPY?ooooo`04o`000?ooooooooooooooo`Co2NX:5_ooool00ol9jP[ooooooooo
o`03ooooo`03o`000?oooooooooo00Kooooo00Co2NX:oooooooooooo0000W?ooool002gooooo0_l0
0003ooooo`Co2NX:D_ooool01?l0003o2NX:o`WZ2_l9jPXJooooo`03o`WZ2_oooooooooo00;ooooo
00?o0000ooooooooool01oooool01?l9jP[oooooooooool0002Looooo`00;_ooool01?l0003o2NX:
o`WZ2_l9jPYDooooo`?o2NX:7Oooool00ol9jP[oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o2NX:ooooool00000WOooool002cooooo0_l9jPX00ol0003oooooooooo`1Aooooo`Co2NX:
0_ooool00ol0003oooooooooo`0Kooooo`05o`WZ2_ooooooooooooooool000002_ooool00ol9jP[o
0000ooooo`2Mooooo`00:?ooool4o`WZ2P;ooooo0_l0001?ooooo`?o2NX:1_ooool00ol0003ooooo
ooooo`0Kooooo`04o`WZ2_ooooooooooo`0000Wooooo00?o2NX:o`000?l00000Woooool002Gooooo
0ol9jPX6ooooo`;o0000Boooool4o`WZ2PWooooo00?o0000ooooooooool06oooool00ol9jP[ooooo
o`000007ooooo`?o2NX:00?oooooo`000?l00000Woooool002;ooooo0ol9jPX:ooooo`03o`000?oo
oooooooo04?ooooo0_l000001?oooooo2NX:o`WZ2_l9jPX=ooooo`03o`000?oooooooooo01[ooooo
00?o2NX:ooooool000001?ooool4o`WZ2PCooooo00?o0000ooooooooool0W_ooool001oooooo0ol9
jPX=ooooo`03o`000?oooooooooo04;ooooo00Co2NX:o`000?l0003o2NX:4?ooool00ol0003ooooo
ooooo`0Jooooo`04o`WZ2_oooooo0000ooooo`?o2NX:1oooool00ol0003oooooooooo`2Oooooo`00
6oooool4o`WZ2Q3ooooo0_l00010ooooo`?o2NX:5?ooool00ol0003oooooooooo`0Jooooo`Co2NX:
2Oooool00ol0003oooooooooo`2Pooooo`006?ooool3o`WZ2QCooooo0_l0000looooo`Co2NX:5ooo
ool00ol0003oooooooooo`0Gooooo`Co2NX:2oooool00ol0003oooooooooo`2Qooooo`005Oooool3
o`WZ2QSooooo00?o0000ooooooooool0=oooool3o`WZ2Q_ooooo00?o0000ooooooooool04oooool4
o`WZ2P;ooooo00?o0000o`WZ2_ooool02Oooool00ol0003oooooooooo`2Rooooo`004_ooool3o`WZ
2Q_ooooo0_l0000dooooo`Co2NX:7_ooool00ol0003oooooooooo`0@ooooo`?o2NX:1Oooool00ol0
003oooooo`WZ2P0:ooooo`03o`000?oooooooooo0:;ooooo000@ooooo`;o2NX:7_ooool2o`00037o
oooo0ol9jPXRooooo`03o`000?oooooooooo00cooooo1?l9jPX8ooooo`03o`000?oooooo2NX:00Wo
oooo00?o0000ooooooooool0Xoooool0033ooooo0_l0000]ooooo`Co2NX:9Oooool00ol0003ooooo
ooooo`09ooooo`?o2NX:2oooool01?l0003oooooooooool9jPX8ooooo`03o`000?oooooooooo0:Co
oooo000aooooo`03o`000?oooooooooo02Oooooo1?l9jPXYooooo`03o`000?oooooooooo00Gooooo
1?l9jPX=ooooo`05o`000?ooooooooooooooool9jPX01oooool00ol0003oooooooooo`2Uooooo`00
<Oooool2o`0002Gooooo0ol9jPX]ooooo`03o`000?oooooooooo00;ooooo0ol9jPX@ooooo`05o`00
0?ooooooooooooooool9jPX02?ooool00ol0003oooooooooo`2Uooooo`00<Oooool2o`00027ooooo
1?l9jPX`ooooo`03o`000?l9jP[o2NX:00;o2NX:4_ooool00ol0003oooooooooo`02ooooo`03o`WZ
2_oooooooooo00Gooooo00?o0000ooooooooool0Y_ooool003;ooooo00?o0000ooooooooool07?oo
ool3o`WZ2S7ooooo1?l9jPXFooooo`03o`000?oooooooooo00;ooooo00?o2NX:ooooooooool01?oo
ool00ol0003oooooooooo`2Wooooo`00<_ooool2o`0001Wooooo1?l9jPXaooooo`?o2NX:0oooool0
0ol0003oooooooooo`0Cooooo`04o`000?ooooooooooooooo`;o2NX:0_l00004ooooo`03o`000?oo
oooooooo0:Sooooo000booooo`;o00005_ooool3o`WZ2S7ooooo1?l9jPX6ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooool9jPX00_l9jPX2ooooo`;o00000oooool00ol0003oooooooooo`2Y
ooooo`00<_ooool2o`0001Cooooo0_l9jPXaooooo`?o2NX:2_ooool00ol0003oooooooooo`0@oooo
o`Co2NX:2_ooool00ol0003oooooooooo`2Yooooo`00<oooool00ol0003oooooooooo`11ooooo`Co
2NX:3Oooool00ol0003oooooooooo`0=ooooo`?o2NX:00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`2Zooooo`00<oooool2o`0003oooooo0ol9jPXAooooo`03o`000?oooooooooo00Wooooo
1?l9jPX3ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Zoooool003?ooooo0_l0
000kooooo`Co2NX:5?ooool00ol0003oooooooooo`06ooooo`?o2NX:1_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo0:cooooo000cooooo`;o0000>?ooool3o`WZ2QSooooo00?o0000
ooooooooool00_ooool4o`WZ2PSooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2]
ooooo`00=?ooool00ol0003oooooooooo`0booooo`Co2NX:6oooool00ol0003oooooo`WZ2P02o`WZ
2P_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2]ooooo`00=?ooool2o`00033o
oooo0ol9jPXMooooo`Co2NX:3Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:ko
oooo000dooooo`;o0000;?ooool4o`WZ2Qgooooo0ol9jPX2ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`2_ooooo`00=Oooool00ol0003ooooooooo
o`0Wooooo`?o2NX:7Oooool4o`WZ2PGooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo0;3ooooo000eooooo`;o00009?ooool4o`WZ2Qgooooo0ol9jPX9
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2a
ooooo`00=Oooool2o`0001oooooo0_l00003o`WZ2Qgooooo1?l9jPX<ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2aooooo`00=Oooool2o`0001go
oooo0_l9jPX2o`0001gooooo0ol9jPX?ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`2booooo`00=_ooool00ol0003oooooooooo`0Gooooo`Co2NX:
7Oooool4o`WZ2Q;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo0;?ooooo000fooooo`;o00005Oooool3o`WZ2Qcooooo0_l00003o`WZ2QKooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;Cooooo000f
ooooo`;o00004Oooool4o`WZ2Qgooooo0_l9jPX2o`0001Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;Gooooo000fooooo`;o00003Oooool4o`WZ
2Qkooooo0ol9jPXMooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`2eooooo`00=oooool2o`0000Wooooo0ol9jPXNooooo`Co2NX:8?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0]_ooool003Oooooo
0_l00005ooooo`Co2NX:7Oooool4o`WZ2RCooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo0;Oooooo000gooooo`;o000000?oooooo`WZ2_l9jPX00_l9
jPXNooooo`?o2NX::?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0^?ooool003Oooooo00?o2NX:o`000?l9jPX07_ooool4o`WZ2R_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;Wooooo000coooo
o`Co2NX:00?oooooo`000?l000006_ooool4o`WZ2Roooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo0;Wooooo000_ooooo`Co2NX:1Oooool2o`0001Oo
oooo0ol9jPXcooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`2joooo
o`00;?ooool3o`WZ2PWooooo0_l0000Cooooo`Co2NX:=_ooool01Ol0003ooooooooooooooooo0000
00_ooooo00?o0000ooooooooool0^oooool002Sooooo1?l9jPX=ooooo`;o00003oooool3o`WZ2S[o
oooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`2looooo`009_ooool2o`WZ2Q7o
oooo2_l00003ooooo`Co2NX:?Oooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo0;go
oooo000kooooo`;o00001Oooool00ol9jP[o0000o`00000?o`0003?ooooo0_l0000<ooooo`03o`00
0?oooooooooo0;gooooo000looooo`;o000000Coooooo`WZ2_l9jP[o2NX:4_oooolBo`00027ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2nooooo`00?Oooool2o`0002Oooooo4_l0
000?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0_oooool003oooooo0_l0000g
oooooa7o00002Oooool00ol0003oooooooooo`30ooooo`00@?ooool2o`0004?ooooo00Co0000oooo
oooooooooooo2Ol00033ooooo`00@Oooool2o`0004;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`31ooooo`00@_ooool3o`0003oooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`32ooooo`00A?ooool2o`0003gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`33ooooo`00AOooool2o`0003cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`34ooooo`00A_ooool2o`0003[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`35
ooooo`00B?ooool2o`0003Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`36oooo
o`00BOooool2o`0003Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`37ooooo`00
B_ooool2o`0003Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`38ooooo`00Booo
ool2o`0003?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`39ooooo`00COooool2
o`00033ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3:ooooo`00C_ooool2o`00
02kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3;ooooo`00Coooool2o`0002go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3<ooooo`00DOooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0cOooool005;ooooo0_l0
000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0c_ooool005?ooooo0_l0000W
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0coooool005Gooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=3ooooo001Fooooo`;o
00008_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=7ooooo001Gooooo`;o0000
8Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0=;ooooo001Hooooo`;o00007ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0=?ooooo001Jooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3Dooooo`00Foooool2o`00
01_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3Eooooo`00G?ooool2o`0001Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3Fooooo`00G_ooool00ol0003ooooo
ooooo`0Fooooo`05o`000?ooooooooooooooool00000fOooool005oooooo00?o0000ooooooooool0
5?ooool01Ol0003ooooooooooooooooo00000=[ooooo001Pooooo`;o00004oooool01Ol0003ooooo
oooooooooooo00000=_ooooo001Qooooo`;o00004_ooool01?l0003oooooooooool0003Looooo`00
Hoooool00ol0003oooooooooo`0>ooooo`04o`000?ooooooooooo`000=gooooo001Tooooo`03o`00
0?oooooooooo00cooooo00Co0000oooooooooooo0000g_ooool006Gooooo0_l0000<ooooo`03o`00
0?oooooo00000=oooooo001Wooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool00000h?oo
ool006Sooooo00?o0000ooooooooool01oooool2o`000>7ooooo001Yooooo`;o00001_ooool2o`00
0>;ooooo001Zooooo`;o00001?ooool2o`000>?ooooo001/ooooo`05o`000?ooooooooooooooool0
0000i?ooool006gooooo00?o0000ooooool00000iOooool006kooooo00?o0000ooooooooool0i?oo
ool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_oo
ool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_oo
ool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00001\
\>"],
  ImageRangeCache->{{{-33, 382.938}, {443.562, -27.9375}} -> {0.135433, \
-0.0577446, 0.00206675, 0.00206675}},
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%, PlotType->SideView];", "Input",
  CellTags->"Prism Examples"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.05831 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0575842 0.745001 0.0575842 [
[ 0 0 0 0 ]
[ 1 1.05831 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.19656 .45692 m
.19656 .82936 L
.19656 1.03305 L
.19656 1.03305 L
.19656 .82936 L
.19656 .45692 L
.19656 .45692 L
s
.4 .25349 m
.77243 .25349 L
.97613 .25349 L
.97613 .25349 L
.77243 .25349 L
.4 .25349 L
.4 .25349 L
s
.19637 .82942 m
.19637 1.03312 L
.40006 1.03312 L
.97619 .45699 L
.97619 .25329 L
.7725 .25329 L
.19637 .82942 L
s
.7725 .25329 m
.97619 .25329 L
.97619 .45699 L
.40006 1.03312 L
.19637 1.03312 L
.19637 .82942 L
.7725 .25329 L
s
.40016 .25339 m
.7726 .25339 L
.19646 .82952 L
.19646 .45708 L
.40016 .25339 L
s
.19646 .45708 m
.19646 .82952 L
.7726 .25339 L
.40016 .25339 L
.19646 .45708 L
s
.976 .25345 m
.976 .45715 L
.976 .25345 L
.976 .25345 L
s
.19653 1.03292 m
.40022 1.03292 L
.19653 1.03292 L
.19653 1.03292 L
s
.4002 .25344 m
.4002 .25344 L
.19651 .45713 L
.19651 .45713 L
.4002 .25344 L
s
.039 .916 .04 r
.02381 .745 m
.19656 .745 L
s
% Start of user PostScript
0 0 3. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19656 .745 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .86716 m
.19656 .86716 L
s
% Start of user PostScript
0 2.12132 3. 2.12132 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19656 .86716 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .91775 m
.19656 .91775 L
s
% Start of user PostScript
0 3. 3. 3. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19656 .91775 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .86716 m
.19656 .86716 L
s
% Start of user PostScript
0 2.12132 3. 2.12132 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19656 .86716 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .745 m
.19656 .745 L
s
% Start of user PostScript
0 0 3. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19656 .745 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .62285 m
.19656 .62285 L
s
% Start of user PostScript
0 -2.12132 3. -2.12132 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19656 .62285 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .57225 m
.19656 .57225 L
s
% Start of user PostScript
0 -3. 3. -3. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19656 .57225 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .62285 m
.19656 .62285 L
s
% Start of user PostScript
0 -2.12132 3. -2.12132 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.19656 .62285 Mdot
.039 .916 .04 r
.5 Mabswid
.19656 .745 m
.44377 .745 L
s
% Start of user PostScript
3. 0 7.29291 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.44377 .745 Mdot
.039 .916 .04 r
.5 Mabswid
.19656 .86716 m
.39317 .86716 L
s
% Start of user PostScript
3. 2.12132 6.41423 2.12132 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.39317 .86716 Mdot
.039 .916 .04 r
.5 Mabswid
.19656 .91775 m
.51532 .91775 L
s
% Start of user PostScript
3. 3. 8.53552 3. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.51532 .91775 Mdot
.039 .916 .04 r
.5 Mabswid
.19656 .86716 m
.39317 .86716 L
s
% Start of user PostScript
3. 2.12132 6.4142 2.12132 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.39317 .86716 Mdot
.039 .916 .04 r
.5 Mabswid
.19656 .745 m
.44376 .745 L
s
% Start of user PostScript
3. 0 7.29288 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.44376 .745 Mdot
.039 .916 .04 r
.5 Mabswid
.19656 .62285 m
.63748 .62285 L
s
% Start of user PostScript
3. -2.12132 10.6568 -2.12132 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.63748 .62285 Mdot
.039 .916 .04 r
.5 Mabswid
.19656 .57225 m
.86083 .57225 L
s
% Start of user PostScript
3. -3. 14.5355 -3. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.86083 .57225 Mdot
.039 .916 .04 r
.5 Mabswid
.19656 .62285 m
.63748 .62285 L
s
% Start of user PostScript
3. -2.12132 10.6569 -2.12132 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.63748 .62285 Mdot
.039 .916 .04 r
.5 Mabswid
.44377 .745 m
.68807 .50069 L
s
% Start of user PostScript
7.29291 0 11.5355 -4.24263 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68807 .50069 Mdot
.039 .916 .04 r
.5 Mabswid
.39317 .86716 m
.56592 .6944 L
s
% Start of user PostScript
6.41423 2.12132 9.41421 -0.878666 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.56592 .6944 Mdot
.039 .916 .04 r
.5 Mabswid
.51532 .91775 m
.51532 .91775 L
s
0 0 0 r
2 Mabswid
.51532 .91775 Mdot
.039 .916 .04 r
.5 Mabswid
.39317 .86716 m
.56592 .6944 L
s
% Start of user PostScript
6.4142 2.12132 9.41421 -0.878694 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.56592 .6944 Mdot
.039 .916 .04 r
.5 Mabswid
.44376 .745 m
.68807 .50069 L
s
% Start of user PostScript
7.29288 0 11.5355 -4.24265 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68807 .50069 Mdot
.039 .916 .04 r
.5 Mabswid
.63748 .62285 m
.81023 .45009 L
s
% Start of user PostScript
10.6568 -2.12132 13.6569 -5.12133 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.81023 .45009 Mdot
.039 .916 .04 r
.5 Mabswid
.86083 .57225 m
.86083 .57225 L
s
0 0 0 r
2 Mabswid
.86083 .57225 Mdot
.039 .916 .04 r
.5 Mabswid
.63748 .62285 m
.81023 .45009 L
s
% Start of user PostScript
10.6569 -2.12132 13.6569 -5.12131 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.81023 .45009 Mdot
.039 .916 .04 r
.5 Mabswid
.68807 .50069 m
.68807 .25349 L
s
% Start of user PostScript
11.5355 -4.24263 11.5355 -8.53553 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68807 .25349 Mdot
.039 .916 .04 r
.5 Mabswid
.56592 .6944 m
.56592 .25349 L
s
% Start of user PostScript
9.41421 -0.878666 9.41421 -8.53553 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.56592 .25349 Mdot
.039 .916 .04 r
.5 Mabswid
.51532 .91775 m
.51532 .25349 L
s
% Start of user PostScript
8.53553 2.99999 8.53553 -8.53553 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.51532 .25349 Mdot
.039 .916 .04 r
.5 Mabswid
.56592 .6944 m
.56592 .25349 L
s
% Start of user PostScript
9.41421 -0.878694 9.41421 -8.53553 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.56592 .25349 Mdot
.039 .916 .04 r
.5 Mabswid
.68807 .50069 m
.68807 .25349 L
s
% Start of user PostScript
11.5355 -4.24265 11.5355 -8.53553 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68807 .25349 Mdot
.039 .916 .04 r
.5 Mabswid
.81023 .45009 m
.81023 .25349 L
s
% Start of user PostScript
13.6569 -5.12133 13.6569 -8.53553 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.81023 .25349 Mdot
.039 .916 .04 r
.5 Mabswid
.86083 .57225 m
.86083 .25349 L
s
% Start of user PostScript
14.5355 -3.00001 14.5355 -8.53553 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.86083 .25349 Mdot
.039 .916 .04 r
.5 Mabswid
.81023 .45009 m
.81023 .25349 L
s
% Start of user PostScript
13.6569 -5.12131 13.6569 -8.53553 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.81023 .25349 Mdot
.039 .916 .04 r
.5 Mabswid
.68807 .25349 m
.68807 .0252 L
s
% Start of user PostScript
11.5355 -8.53553 11.5355 -12.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68807 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.56592 .25349 m
.56592 .0252 L
s
% Start of user PostScript
9.41421 -8.53553 9.41421 -12.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.56592 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.51532 .25349 m
.51532 .0252 L
s
% Start of user PostScript
8.53553 -8.53553 8.53553 -12.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.51532 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.56592 .25349 m
.56592 .0252 L
s
% Start of user PostScript
9.41421 -8.53553 9.41421 -12.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.56592 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.68807 .25349 m
.68807 .0252 L
s
% Start of user PostScript
11.5355 -8.53553 11.5355 -12.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68807 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.81023 .25349 m
.81023 .0252 L
s
% Start of user PostScript
13.6569 -8.53553 13.6569 -12.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.81023 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.86083 .25349 m
.86083 .0252 L
s
% Start of user PostScript
14.5355 -8.53553 14.5355 -12.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.86083 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.81023 .25349 m
.81023 .0252 L
s
% Start of user PostScript
13.6569 -8.53553 13.6569 -12.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.81023 .0252 Mdot
0 0 m
1 0 L
1 1.05831 L
0 1.05831 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{272.125, 287.938},
  ImageMargins->{{158, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004@00017b000`400?l00000o`00003ooooooolA
ooooo`00oooooolAooooo`00oooooolAooooo`00oooooolAooooo`00oooooolAooooo`00oooooolA
ooooo`00Roooool2o`0000_ooooo0_l0000Pooooo`;o00007oooool2o`0000_ooooo0_l0000Voooo
o`00Roooool2o`0000_ooooo0_l0000Pooooo`;o00007oooool2o`0000_ooooo0_l0000Vooooo`00
Roooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool0
7_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo02Cooooo002:ooooo`?o2NX:2ooo
ool3o`WZ2Qkooooo0ol9jPXNooooo`?o2NX:2oooool3o`WZ2RGooooo002:ooooo`?o2NX:2oooool3
o`WZ2Qkooooo0ol9jPXNooooo`?o2NX:2oooool3o`WZ2RGooooo002:ooooo`?o2NX:2oooool3o`WZ
2Qkooooo0ol9jPXNooooo`?o2NX:2oooool3o`WZ2RGooooo002:ooooo`?o2NX:2oooool3o`WZ2Qko
oooo0ol9jPXNooooo`?o2NX:2oooool3o`WZ2RGooooo0029ooooo`Go2NX:2Oooool5o`WZ2Qcooooo
1Ol9jPXLooooo`Go2NX:2Oooool5o`WZ2RCooooo0029ooooo`05o`WZ2_oooooo2NX:ooooool9jPX0
2Oooool01Ol9jP[oooooo`WZ2_oooooo2NX:01cooooo00Go2NX:ooooool9jP[oooooo`WZ2P0Loooo
o`05o`WZ2_oooooo2NX:ooooool9jPX02Oooool01Ol9jP[oooooo`WZ2_oooooo2NX:02Cooooo002;
ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool09?ooool008_ooooo00?o2NX:oooo
ooooool02oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooo
ooooool02oooool00ol9jP[oooooooooo`0Tooooo`00Roooool00ol9jP[oooooooooo`0;ooooo`03
o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0;ooooo`03
o`WZ2_oooooooooo02Cooooo002;ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool0
7_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool0
9?ooool008_ooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oo
oooooooo01kooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Tooooo`00Roooool0
0ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo02Cooooo002;ooooo`03o`WZ2_oooooooooo
00_ooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo
00_ooooo00?o2NX:ooooooooool09?ooool008_ooooo00?o2NX:ooooooooool02oooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool02oooool00ol9jP[o
ooooooooo`0Tooooo`00Roooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01kooooo
00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo02Cooooo
002;ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool09?ooool008_ooooo00?o2NX:
ooooooooool02oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:
ooooooooool02oooool00ol9jP[oooooooooo`0Tooooo`00Roooool00ol9jP[oooooooooo`0;oooo
o`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0;oooo
o`03o`WZ2_oooooooooo02Cooooo002;ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:oooooooo
ool09?ooool008_ooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ
2_oooooooooo01kooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Tooooo`00Rooo
ool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_oo
ool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo02Cooooo002;ooooo`03o`WZ2_oooooo
oooo00_ooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo00_ooooo00?o2NX:ooooooooool09?ooool008_ooooo00?o2NX:ooooooooool02oooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool02oooool00ol9
jP[oooooooooo`0Tooooo`00Roooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01ko
oooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo02Co
oooo002;ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooo
ooooo`0Nooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool09?ooool008_ooooo00?o
2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o
2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Tooooo`00Roooool00ol9jP[oooooooooo`0;
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0;
ooooo`03o`WZ2_oooooooooo02Cooooo002;ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:oooo
ooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:oooo
ooooool09?ooool008_ooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Tooooo`00
Roooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool0
7_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo02Cooooo002;ooooo`03o`WZ2_oo
oooooooo00_ooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oo
oooooooo00_ooooo00?o2NX:ooooooooool09?ooool008_ooooo00?o2NX:ooooooooool02oooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool02oooool0
0ol9jP[oooooooooo`0Tooooo`00Roooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo
01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo
02Cooooo002;ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool09?ooool008_ooooo
00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo
00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Tooooo`00Roooool00ol9jP[ooooooooo
o`0;ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooooooo
o`0;ooooo`03o`WZ2_oooooooooo02Cooooo002;ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:
ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:
ooooooooool09?ooool008_ooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Noooo
o`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Toooo
o`00Roooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo02Cooooo002;ooooo`03o`WZ
2_oooooooooo00_ooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ
2_oooooooooo00_ooooo00?o2NX:ooooooooool09?ooool008_ooooo00?o2NX:ooooooooool02ooo
ool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool02ooo
ool00ol9jP[oooooooooo`0Tooooo`00Roooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooo
oooo02Cooooo002;ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool07_ooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool09?ooool008_o
oooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01ko
oooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Tooooo`00Roooool00ol9jP[ooooo
ooooo`0;ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooo
ooooo`0;ooooo`03o`WZ2_oooooooooo02Cooooo002;ooooo`03o`WZ2_oooooooooo00_ooooo00?o
2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo00_ooooo00?o
2NX:ooooooooool09?ooool008_ooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0T
ooooo`00Roooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooo
ooooool07_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo02Cooooo002;ooooo`03
o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool09?ooool008_ooooo00?o2NX:ooooooooool0
2oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool0
2oooool00ol9jP[oooooooooo`0Tooooo`00Roooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oo
oooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oo
oooooooo02Cooooo002;ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool09?ooool0
08_ooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo
01kooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Tooooo`00Roooool00ol9jP[o
ooooooooo`0;ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0;ooooo`03o`WZ2_oooooooooo02Cooooo002;ooooo`03o`WZ2_oooooooooo00_ooooo
00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo00_ooooo
00?o2NX:ooooooooool09?ooool008_ooooo00?o2NX:ooooooooool02oooool00ol9jP[ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool02oooool00ol9jP[ooooooooo
o`0Tooooo`00Roooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:
ooooooooool07_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo02Cooooo002;oooo
o`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Noooo
o`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool09?ooool008_ooooo00?o2NX:oooooooo
ool02oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool02oooool00ol9jP[oooooooooo`0Tooooo`00K?oooolOo`000003o`WZ2_l0003o000000_o0000
00?o2NX:o`000?l000007_l000000ol9jP[o0000o`00000No`000003o`WZ2_l0003o000000_o0000
00?o2NX:o`000?l000007Ol00007ooooo`00Joooool2o`0001kooooo0_l0000;ooooo`;o00008?oo
ool2o`0001Cooooo00?o0000ooooooooool02?ooool2o`0000_ooooo0_l0000Nooooo`03o`000?oo
oooooooo00Gooooo001Zooooo`;o00007oooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03o`WZ2_oooooo
oooo00_ooooo00?o2NX:ooooooooool07?ooool00ol0003oooooooooo`05ooooo`00JOooool2o`00
01oooooo0ol9jPX;ooooo`?o2NX:7_ooool3o`WZ2Q;ooooo00?o0000ooooooooool02Oooool3o`WZ
2P_ooooo0ol9jPXMooooo`03o`000?oooooooooo00Gooooo001Xooooo`;o00008?ooool3o`WZ2P_o
oooo0ol9jPXNooooo`?o2NX:4Oooool00ol0003oooooooooo`0:ooooo`?o2NX:2oooool3o`WZ2Qgo
oooo00?o0000ooooooooool01Oooool006Oooooo0_l0000Qooooo`?o2NX:2oooool3o`WZ2Qkooooo
0ol9jPX@ooooo`03o`000?oooooooooo00_ooooo0ol9jPX;ooooo`?o2NX:7Oooool00ol0003ooooo
ooooo`05ooooo`00I_ooool2o`0002;ooooo0ol9jPX;ooooo`?o2NX:7_ooool3o`WZ2Poooooo00?o
0000ooooooooool03?ooool3o`WZ2P_ooooo0ol9jPXMooooo`03o`000?oooooooooo00Gooooo001U
ooooo`;o00008_ooool5o`WZ2PWooooo1Ol9jPXLooooo`Go2NX:3Oooool00ol0003oooooooooo`0<
ooooo`Go2NX:2Oooool5o`WZ2Qcooooo00?o0000ooooooooool01Oooool006Cooooo0_l0000Soooo
o`05o`WZ2_oooooo2NX:ooooool9jPX02Oooool01Ol9jP[oooooo`WZ2_oooooo2NX:01cooooo00Go
2NX:ooooool9jP[oooooo`WZ2P0<ooooo`03o`000?oooooooooo00gooooo00Go2NX:ooooool9jP[o
ooooo`WZ2P09ooooo`05o`WZ2_oooooo2NX:ooooool9jPX07?ooool00ol0003oooooooooo`05oooo
o`00Hoooool2o`0002Kooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo00_ooooo00?o0000ooooooooool04?ooool00ol9jP[oooooooooo`0;ooooo`03
o`WZ2_oooooooooo01cooooo00?o0000ooooooooool01Oooool006;ooooo0_l0000Wooooo`03o`WZ
2_oooooooooo00_ooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0:ooooo`03o`00
0?oooooooooo017ooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Looooo`03o`00
0?oooooooooo00Gooooo001Qooooo`;o0000:?ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oo
oooooooo01kooooo00?o2NX:ooooooooool02Oooool00ol0003oooooooooo`0Booooo`03o`WZ2_oo
oooooooo00_ooooo00?o2NX:ooooooooool07?ooool00ol0003oooooooooo`05ooooo`00H?ooool2
o`0002Wooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo00Sooooo00?o0000ooooooooool04oooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooo
oooo01cooooo00?o0000ooooooooool01Oooool005oooooo0_l0000Zooooo`03o`WZ2_oooooooooo
00_ooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`07ooooo`03o`000?oooooooooo
01Cooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Looooo`03o`000?oooooooooo
00Gooooo001Nooooo`;o0000:oooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01ko
oooo00?o2NX:ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`WZ2_oooooooooo00_o
oooo00?o2NX:ooooooooool07?ooool00ol0003oooooooooo`05ooooo`00GOooool2o`0002cooooo
00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo00Gooooo
00?o0000ooooooooool05_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01cooooo
00?o0000ooooooooool01Oooool005cooooo0_l0000]ooooo`03o`WZ2_oooooooooo00_ooooo00?o
2NX:ooooooooool07_ooool00ol9jP[oooooooooo`04ooooo`03o`000?oooooooooo01Oooooo00?o
2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo001K
ooooo`;o0000;_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:
ooooooooool00oooool00ol0003oooooooooo`0Hooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:
ooooooooool07?ooool00ol0003oooooooooo`05ooooo`00F_ooool2o`0002oooooo00?o2NX:oooo
ooooool02oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo00;ooooo00?o0000oooo
ooooool06Oooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01cooooo00?o0000oooo
ooooool01Oooool005Wooooo0_l0000`ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:oooooooo
ool07_ooool01Ol9jP[ooooooooooooooooo000001cooooo00?o2NX:ooooooooool02oooool00ol9
jP[oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo001Hooooo`;o0000<Oooool00ol9jP[o
ooooooooo`0;ooooo`03o`WZ2_oooooooooo01kooooo00Co2NX:oooooooooooo00007Oooool00ol9
jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01cooooo00?o0000ooooooooool01Oooool005Oo
oooo0_l0000booooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooo`00000Nooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool07?ooool00ol0003o
ooooooooo`05ooooo`00E_ooool2o`0003?ooooo00?o2NX:ooooooooool02oooool00ol9jP[ooooo
ooooo`0Nooooo`03o`WZ2_l0003ooooo01kooooo00?o2NX:ooooooooool02oooool00ol9jP[ooooo
ooooo`0Looooo`03o`000?oooooooooo00Gooooo001Eooooo`;o0000=?ooool00ol9jP[ooooooooo
o`0;ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooooooo
o`0;ooooo`03o`WZ2_oooooooooo01cooooo00?o0000ooooooooool01Oooool005Cooooo0_l0000e
ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool07Oooool00ol0003o2NX:ooooo`0O
ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool07?ooool00ol0003oooooooooo`05
ooooo`00Doooool2o`0003Kooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Loooo
o`03o`000?oooooo2NX:023ooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Loooo
o`03o`000?oooooooooo00Gooooo001Booooo`;o0000=oooool00ol9jP[oooooooooo`0;ooooo`03
o`WZ2_oooooooooo01_ooooo00Co0000oooooooooooo2NX:8?ooool00ol9jP[oooooooooo`0;oooo
o`03o`WZ2_oooooooooo01cooooo00?o0000ooooooooool01Oooool0057ooooo0_l0000hooooo`03
o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool06_ooool01Ol0003ooooooooooooooooo2NX:
023ooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Looooo`03o`000?oooooooooo
00Gooooo001@ooooo`;o0000>Oooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01Wo
oooo00?o0000ooooooooool00_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo00_o
oooo00?o2NX:ooooooooool07?ooool00ol0003oooooooooo`05ooooo`00Coooool2o`0003[ooooo
00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo
00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01cooooo
00?o0000ooooooooool01Oooool004kooooo0_l0000kooooo`03o`WZ2_oooooooooo00_ooooo00?o
2NX:ooooooooool05oooool00ol0003oooooooooo`04ooooo`03o`WZ2_oooooooooo01kooooo00?o
2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo001=
ooooo`;o0000??ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01Kooooo00?o0000
ooooooooool01Oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:
ooooooooool07?ooool00ol0003oooooooooo`05ooooo`00C?ooool2o`0003gooooo00?o2NX:oooo
ooooool02oooool00ol9jP[oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo00?o2NX:oooo
ooooool07_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01cooooo00?o0000oooo
ooooool01Oooool004_ooooo0_l0000nooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:oooooooo
ool05?ooool00ol0003oooooooooo`07ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool02oooool00ol9jP[oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo001:ooooo`;o0000
?oooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01?ooooo00?o0000ooooooooool0
2?ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool0
7?ooool00ol0003oooooooooo`05ooooo`00BOooool2o`00043ooooo00?o2NX:ooooooooool02ooo
ool00ol9jP[oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o2NX:ooooooooool07_oo
ool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01cooooo00?o0000ooooooooool01Ooo
ool004Sooooo0_l00011ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool04Oooool0
0ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool02oooool0
0ol9jP[oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo0017ooooo`;o0000@_ooool00ol9
jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo013ooooo00?o0000ooooooooool02oooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool07?ooool00ol0
003oooooooooo`05ooooo`00A_ooool2o`0004?ooooo00?o2NX:ooooooooool02oooool00ol9jP[o
ooooooooo`0?ooooo`03o`000?oooooooooo00cooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0;ooooo`03o`WZ2_oooooooooo01cooooo00?o0000ooooooooool01Oooool004Gooooo
0_l00014ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool02oooool00ol9jP[ooooo
ooooo`0Looooo`03o`000?oooooooooo00Gooooo0014ooooo`;o0000AOooool00ol9jP[ooooooooo
o`0;ooooo`03o`WZ2_oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol9jP[ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool07?ooool00ol0003ooooooooo
o`05ooooo`00@oooool2o`0004Kooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0<
ooooo`03o`000?oooooooooo00oooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0;
ooooo`03o`WZ2_oooooooooo01cooooo00?o0000ooooooooool01Oooool004;ooooo0_l00017oooo
o`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool02oooool00ol0003oooooooooo`0@oooo
o`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Loooo
o`03o`000?oooooooooo00Gooooo0011ooooo`;o0000B?ooool00ol9jP[oooooooooo`0;ooooo`03
o`WZ2_oooooooooo00[ooooo00?o0000ooooooooool04Oooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool07?ooool00ol0003oooooooooo`05ooooo`00
@?ooool2o`0004Wooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`09ooooo`03o`00
0?oooooooooo01;ooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ
2_oooooooooo01cooooo00?o0000ooooooooool01Oooool003oooooo0_l0001:ooooo`03o`WZ2_oo
oooooooo00_ooooo00?o2NX:ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`03o`WZ2_oo
oooooooo01kooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Looooo`03o`000?oo
oooooooo00Gooooo000nooooo`;o0000Boooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooo
oooo00Oooooo00?o0000ooooooooool05?ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo00_ooooo00?o2NX:ooooooooool07?ooool00ol0003oooooooooo`05ooooo`00?Oooool2o`00
04cooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`06ooooo`03o`000?oooooooooo
01Gooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo
01cooooo00?o0000ooooooooool01Oooool003cooooo0_l0001=ooooo`03o`WZ2_oooooooooo00_o
oooo00?o2NX:ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`03o`WZ2_oooooooooo01ko
oooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Looooo`03o`000?oooooooooo00Go
oooo000kooooo`;o0000C_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo00Cooooo
00?o0000ooooooooool05oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo00_ooooo
00?o2NX:ooooooooool07?ooool00ol0003oooooooooo`05ooooo`00>_ooool2o`0004oooooo00?o
2NX:ooooooooool02oooool00ol9jP[oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo00?o
2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01cooooo00?o
0000ooooooooool01Oooool003Wooooo0_l0001@ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:
ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:
ooooooooool02oooool00ol9jP[oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo000hoooo
o`;o0000DOooool00ol9jP[oooooooooo`0;ooooo`05o`WZ2_ooooooooooooooool000007?ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool07?ooool0
0ol0003oooooooooo`05ooooo`00=oooool2o`0005;ooooo00?o2NX:ooooooooool02oooool01?l9
jP[oooooooooool0000Mooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:o`000?ooool02oooool0
0ol9jP[oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo000fooooo`;o0000Doooool00ol9
jP[oooooooooo`0;ooooo`03o`WZ2_oooooo000001kooooo00?o2NX:ooooooooool07Oooool2o`WZ
2P03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool07?ooool00ol0003oooooooooo`05oooo
o`00=Oooool2o`0005Cooooo00?o2NX:ooooooooool02oooool00ol9jP[o0000ooooo`0Nooooo`03
o`WZ2_oooooooooo01_ooooo1?l9jPX=ooooo`03o`WZ2_oooooooooo01cooooo00?o0000oooooooo
ool01Oooool003Gooooo00?o0000ooooooooool0Doooool00ol9jP[oooooooooo`0;ooooo`03o`WZ
2_oooooooooo01kooooo00?o2NX:ooooooooool06_ooool4o`WZ2Pkooooo00?o2NX:ooooooooool0
7?ooool00ol0003oooooooooo`05ooooo`00=Oooool00ol0003oooooooooo`1Cooooo`03o`WZ2_oo
oooooooo00[ooooo00?o0000o`WZ2_ooool07oooool00ol9jP[oooooooooo`0Hooooo`Ko2NX:3_oo
ool00ol9jP[oooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo000eooooo`03o`000?oooooo
oooo05?ooooo00?o2NX:ooooooooool02Oooool00ol0003oooooo`WZ2P0Pooooo`03o`WZ2_oooooo
oooo01Oooooo1_l9jPX?ooooo`03o`WZ2_oooooooooo01[ooooo00?o0000ooooooooool01oooool0
03Gooooo00?o0000ooooooooool0Doooool00ol9jP[oooooooooo`08ooooo`04o`000?oooooooooo
o`WZ2R3ooooo00?o2NX:ooooooooool06?ooool01?l9jP[oooooo`WZ2_l9jPX@ooooo`03o`WZ2_oo
oooooooo01Wooooo00?o0000ooooooooool02?ooool003Gooooo00?o0000ooooooooool0Doooool0
0ol9jP[oooooooooo`07ooooo`05o`000?ooooooooooooooool9jPX08?ooool00ol9jP[ooooooooo
o`0Gooooo`03o`WZ2_oooooooooo00;o2NX:4?ooool00ol9jP[oooooooooo`0Hooooo`03o`000?oo
oooooooo00Wooooo000eooooo`03o`000?oooooooooo05?ooooo00?o2NX:ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool05_ooool0
1Ol9jP[ooooooooooooooooo2NX:017ooooo00?o2NX:ooooooooool05oooool00ol0003ooooooooo
o`0:ooooo`00=Oooool00ol0003oooooooooo`1Cooooo`03o`WZ2_oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01Gooooo00?o2NX:
ooooooooool05?ooool00ol9jP[oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo000eoooo
o`03o`000?oooooooooo05?ooooo00?o2NX:ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0Eoooo
o`03o`WZ2_oooooooooo01Gooooo00?o0000ooooooooool03?ooool003Gooooo00?o0000oooooooo
ool0Doooool00ol9jP[oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo01Kooooo00?o2NX:oooooooo
ool05?ooool00ol0003oooooooooo`0=ooooo`00=Oooool00ol0003oooooooooo`1Cooooo`03o`WZ
2_oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ
2_oooooooooo01;ooooo00?o2NX:ooooooooool05oooool00ol9jP[oooooooooo`0Cooooo`03o`00
0?oooooooooo00kooooo000eooooo`03o`000?oooooooooo05?ooooo00Go2NX:oooooooooooooooo
o`000009ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool04Oooool00ol9jP[ooooo
ooooo`0Hooooo`03o`WZ2_oooooooooo01;ooooo00?o0000ooooooooool03oooool003Gooooo00?o
0000ooooooooool0Doooool01?l9jP[oooooooooool0000:ooooo`03o`WZ2_oooooooooo01gooooo
0_l9jPX00ol0003oooooooooo`0?ooooo`03o`WZ2_oooooooooo01Wooooo00?o2NX:ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`00=Oooool00ol0003oooooooooo`1Cooooo`03o`WZ2_oo
oooo000000_ooooo00?o2NX:ooooooooool07?ooool2o`WZ2P;o00004?ooool00ol9jP[ooooooooo
o`0Jooooo`03o`WZ2_oooooooooo013ooooo00?o0000ooooooooool04Oooool003Gooooo00?o0000
ooooooooool0Doooool00ol9jP[o0000ooooo`0;ooooo`03o`WZ2_oooooooooo01[ooooo1?l9jPXA
ooooo`03o`WZ2_oooooooooo01_ooooo00?o2NX:ooooooooool03oooool00ol0003oooooooooo`0B
ooooo`00=Oooool00ol0003oooooooooo`1Cooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:oooo
ooooool06Oooool5o`WZ2Q3ooooo00?o2NX:ooooooooool07?ooool00ol9jP[oooooooooo`0>oooo
o`03o`000?oooooooooo01?ooooo000eooooo`03o`000?oooooooooo05;ooooo00?o0000o`WZ2_oo
ool03?ooool00ol9jP[oooooooooo`0Hooooo`Go2NX:4?ooool00ol9jP[oooooooooo`0Mooooo`03
o`WZ2_oooooooooo00gooooo00?o0000ooooooooool05?ooool003Gooooo00?o0000ooooooooool0
DOooool00ol0003oooooo`WZ2P0=ooooo`03o`WZ2_oooooooooo01Oooooo1Ol9jPX@ooooo`03o`WZ
2_oooooooooo01kooooo00?o2NX:ooooooooool03?ooool00ol0003oooooooooo`0Eooooo`00=Ooo
ool00ol0003oooooooooo`1@ooooo`04o`000?ooooooooooo`WZ2Pgooooo00?o2NX:ooooooooool0
6Oooool3o`WZ2Poooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0;ooooo`03o`00
0?oooooooooo01Kooooo000eooooo`03o`000?oooooooooo04oooooo00Go0000oooooooooooooooo
o`WZ2P0=ooooo`03o`WZ2_oooooooooo01Sooooo00?o2NX:ooooool9jPX03oooool00ol9jP[ooooo
ooooo`0Pooooo`03o`WZ2_oooooooooo00[ooooo00?o0000ooooooooool05oooool003Gooooo00?o
0000ooooooooool0C_ooool00ol0003oooooooooo`02ooooo`03o`WZ2_oooooooooo00_ooooo00?o
2NX:ooooooooool05oooool00ol9jP[oooooooooo`0?ooooo`03o`WZ2_oooooooooo027ooooo00?o
2NX:ooooooooool02Oooool00ol0003oooooooooo`0Hooooo`00=Oooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo00?ooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0F
ooooo`03o`WZ2_oooooooooo00oooooo00?o2NX:ooooooooool08_ooool00ol9jP[oooooooooo`08
ooooo`03o`000?oooooooooo01Wooooo000eooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool01?ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo01Gooooo00?o2NX:oooo
ooooool03oooool00ol9jP[oooooooooo`0Sooooo`03o`WZ2_oooooooooo00Oooooo00?o0000oooo
ooooool06_ooool003Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`05ooooo`03
o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0?ooooo`03
o`WZ2_oooooooooo02Cooooo00?o2NX:ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`00
=Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00Kooooo00?o2NX:ooooooooool0
2oooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo00oooooo00?o2NX:ooooooooool0
9Oooool00ol9jP[oooooooooo`05ooooo`03o`000?oooooooooo01cooooo000eooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool01oooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oo
oooooooo01;ooooo00?o2NX:ooooooooool03oooool00ol9jP[oooooooooo`0Vooooo`03o`WZ2_oo
oooooooo00Cooooo00?o0000ooooooooool07Oooool003Gooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`08ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool04Oooool0
0ol9jP[oooooooooo`0?ooooo`03o`WZ2_oooooooooo02Oooooo00?o2NX:ooooooooool00oooool0
0ol0003oooooooooo`0Nooooo`00=Oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
00Wooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0@ooooo`03o`WZ2_oooooooooo
00oooooo00?o2NX:ooooooooool0:?ooool00ol9jP[oooooooooo`02ooooo`03o`000?oooooooooo
01oooooo000eooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool02_ooool00ol9jP[o
ooooooooo`0;ooooo`03o`WZ2_oooooooooo00oooooo00?o2NX:ooooooooool03oooool00ol9jP[o
ooooooooo`0Yooooo`05o`WZ2_ooooooooooooooool000008_ooool003Gooooo00?o0000oooooooo
ool0AOooool00ol0003oooooooooo`0;ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:oooooooo
ool03_ooool00ol9jP[oooooooooo`0?ooooo`03o`WZ2_oooooooooo02[ooooo00Co2NX:oooooooo
oooo00008oooool002gooooo0ol9jPX5ooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool03?ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo00gooooo00?o2NX:oooooooo
ool03oooool00ol9jP[oooooooooo`0Sooooo`?o2NX:1Oooool00ol9jP[oooooo`00000Tooooo`00
;_ooool6o`WZ2P;o0000AOooool00ol0003oooooooooo`0=ooooo`03o`WZ2_oooooooooo00_ooooo
00?o2NX:ooooooooool03?ooool00ol9jP[oooooooooo`0?ooooo`03o`WZ2_oooooooooo02Gooooo
1_l9jPX00ol0003o2NX:o`00000Uooooo`001_ooool^o`WZ2P03o`000?l9jP[o2NX:0;7o2NX:00?o
0000o`WZ2_ooool09Oooool002kooooo1Ol9jPX2ooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool03oooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:
ooooooooool03oooool00ol9jP[oooooooooo`0Wooooo`Go2NX:00?oooooo`000?ooool09_ooool0
02gooooo0_l9jPX6ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool04?ooool00ol9
jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool03oooool00ol9
jP[oooooooooo`0Wooooo`;o2NX:1?ooool00ol0003oooooooooo`0Vooooo`00=Oooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo017ooooo00?o2NX:ooooooooool02oooool00ol9jP[o
ooooooooo`08ooooo`03o`WZ2_oooooooooo00oooooo00?o2NX:ooooooooool0;Oooool00ol0003o
ooooooooo`0Wooooo`00=Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01;ooooo
00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo00oooooo
00?o2NX:ooooooooool0;Oooool00ol0003oooooooooo`0Xooooo`00=Oooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01?ooooo00?o2NX:ooooooooool02oooool00ol9jP[ooooooooo
o`06ooooo`03o`WZ2_oooooooooo00oooooo00?o2NX:ooooooooool0;Oooool00ol0003ooooooooo
o`0Yooooo`00=Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo01Cooooo00?o2NX:
ooooooooool02oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00oooooo00?o2NX:
ooooooooool0;Oooool00ol0003oooooooooo`0Zooooo`00=Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo01Gooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00oooooo00?o2NX:ooooooooool0;Oooool00ol0003oooooooooo`0[oooo
o`00=Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01Kooooo00?o2NX:oooooooo
ool02oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00oooooo00?o2NX:oooooooo
ool0;Oooool00ol0003oooooooooo`0/ooooo`00=Oooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo01Oooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00oooooo00?o2NX:ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`00=Ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Sooooo00?o2NX:ooooooooool02ooo
ool01Ol9jP[ooooooooooooooooo2NX:017ooooo00?o2NX:ooooooooool0;Oooool00ol0003ooooo
ooooo`0^ooooo`00;Oooool3o`WZ2PGooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0Iooooo`03o`WZ2_oooooooooo00_ooooo00Co2NX:oooooooooooo2NX:1oooool3o`WZ2POooooo
00?o2NX:ooooooooool0;Oooool00ol0003oooooooooo`0_ooooo`00;_ooool6o`WZ2P03ooooool0
003ooooo03Oooooo00?o0000ooooooooool06_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oo
oooo2NX:00Wooooo1_l9jPX2ooooo`03o`WZ2_oooooooooo02gooooo00?o0000ooooooooool0<?oo
ool000Kooooo;_l9jPX00ol0003o2NX:o`WZ2P1fo`WZ2P03o`000?oooooooooo02cooooo00?o0000
ooooooooool0<Oooool002kooooo1Ol9jPX00ooooooo0000o`00000fooooo`03o`000?oooooooooo
01cooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`09ooooo`Go2NX:0_ooool2o`00
02gooooo00?o0000ooooooooool0<_ooool002gooooo0_l9jPX6ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool07Oooool00ol9jP[oooooooooo`0:ooooo`;o2NX:2_ooool2o`WZ2SCo
oooo00?o0000ooooooooool0<oooool003Gooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0Nooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooool9jPX0?oooool00ol0003ooooo
ooooo`0dooooo`00=Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01oooooo00?o
2NX:ooooooooool02?ooool01?l9jP[oooooooooool9jPXnooooo`03o`000?oooooooooo03Gooooo
000eooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool08?ooool00ol9jP[ooooooooo
o`07ooooo`05o`WZ2_ooooooooooooooool9jPX0?Oooool00ol0003oooooooooo`0fooooo`00=Ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo027ooooo00?o2NX:ooooooooool01_oo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo03[ooooo00?o0000ooooooooool0=ooo
ool003Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Rooooo`03o`WZ2_oooooo
oooo00Gooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0iooooo`03o`000?oooooo
oooo03Sooooo000eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool08oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0>?ooool00ol0
003oooooooooo`0iooooo`00=Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02Co
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo03Oo
oooo00?o0000ooooooooool0>_ooool003Gooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0Uooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool01_ooool00ol9jP[ooooo
ooooo`0fooooo`03o`000?oooooooooo03_ooooo000eooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool09_ooool01Ol9jP[ooooooooooooooooo2NX:00Wooooo00?o2NX:ooooooooool0
=Oooool00ol0003oooooooooo`0looooo`00=Oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo02Oooooo00Co2NX:oooooooooooo2NX:2_ooool00ol9jP[oooooooooo`0dooooo`03o`00
0?oooooooooo03gooooo000eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:?oo
ool00ol9jP[oooooo`WZ2P0;ooooo`03o`WZ2_oooooooooo03?ooooo00?o0000ooooooooool0?_oo
ool003Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Yooooo`;o2NX:3?ooool0
0ol9jP[oooooooooo`0booooo`03o`000?oooooooooo03oooooo000eooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0:_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo
037ooooo00?o0000ooooooooool0@?ooool003Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Zooooo`;o2NX:3Oooool00ol9jP[oooooooooo`0`ooooo`03o`000?oooooooooo047o
oooo000eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:_ooool00ol9jP[ooooo
o`WZ2P0=ooooo`03o`WZ2_oooooooooo02oooooo00?o0000ooooooooool0@_ooool003Gooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Zooooo`04o`WZ2_ooooooooooo`WZ2Pgooooo
00?o2NX:ooooooooool0;_ooool00ol0003oooooooooo`13ooooo`00=Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo02[ooooo00Go2NX:ooooooooooooooooo`WZ2P0<ooooo`03o`00
0?l9jP[ooooo02kooooo00?o0000ooooooooool0A?ooool003Gooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Zooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool02_oo
ool00ol0003o2NX:ooooo`0]ooooo`03o`000?oooooooooo04Gooooo000eooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0:_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Sooooo1?l9jPX]ooooo`03o`000?oooooooooo04Kooooo000eooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0:_ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00Oooooo1?l9jPX]ooooo`03o`000?oooooooooo04Oooooo000eooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0:_ooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00Go
oooo1_l9jPX/ooooo`03o`000?oooooooooo04Sooooo000eooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0:_ooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo00Cooooo
1_l9jPX/ooooo`03o`000?oooooooooo04Wooooo000eooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0:_ooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo00Kooooo0ol9
jPX/ooooo`03o`000?oooooooooo04[ooooo000eooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0:_ooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00Gooooo00Co2NX:
ooooool9jP[o2NX::oooool00ol0003oooooooooo`1;ooooo`00=Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo02[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`04
ooooo`04o`WZ2_ooooooooooo`WZ2R_ooooo00?o0000ooooooooool0C?ooool003Gooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`0/ooooo`03o`000?oooooooooo04gooooo000eoooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol9jP[oooooooooo`0;oooo
o`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0;?ooool00ol0003oooooooooo`1>oooo
o`00=Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02[ooooo00?o2NX:oooooooo
ool03?ooool01Ol9jP[ooooooooooooooooo2NX:02kooooo00?o0000ooooooooool0Coooool003Go
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Zooooo`03o`WZ2_oooooooooo00go
oooo00Co2NX:oooooooooooo2NX:;_ooool00ol0003oooooooooo`1@ooooo`00;Oooool3o`WZ2PGo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Pooooo`?o2NX:1oooool00ol9jP[o
ooooooooo`0>ooooo`03o`WZ2_oooooo2NX:02kooooo00?o0000ooooooooool0DOooool002kooooo
1_l9jPX2o`0001Kooooo00?o0000ooooooooool08_ooool6o`WZ2P;o000000?o2NX:ooooooooool0
3oooool2o`WZ2Rkooooo00?o0000ooooooooool0D_ooool000Kooooo;_l9jPX00ol0003o2NX:o`WZ
2P10o`WZ2P03o`000?l9jP[ooooo017ooooo00?o2NX:ooooooooool0;?ooool00ol0003ooooooooo
o`1Cooooo`00;_ooool5o`WZ2P;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0T
ooooo`Go2NX:5?ooool2o`WZ2Rgooooo00?o0000ooooooooool0E?ooool002gooooo0_l9jPX6oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool09?ooool2o`WZ2QOooooo00?o2NX:oooo
ool9jPX0;?ooool00ol0003oooooooooo`1Eooooo`00=Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo03gooooo00Co2NX:oooooooooooo2NX::oooool00ol0003oooooooooo`1Foooo
o`00=Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03gooooo00Go2NX:oooooooo
ooooooooo`WZ2P0Zooooo`03o`000?oooooooooo05Oooooo000eooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0?Oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo02Oo
oooo00?o0000ooooooooool0F?ooool003Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0mooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool09_ooool00ol0003ooooo
ooooo`1Iooooo`00=Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03gooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Uooooo`03o`000?oooooooooo05[ooooo000e
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?Oooool00ol9jP[oooooooooo`05
ooooo`03o`WZ2_oooooooooo02Cooooo00?o0000ooooooooool0Foooool003Gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0mooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:oooo
ooooool08oooool00ol0003oooooooooo`1Looooo`00=Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo03gooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`0Rooooo`03
o`000?oooooooooo05gooooo000eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
?Oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo027ooooo00?o0000ooooooooool0
G_ooool003Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0mooooo`03o`WZ2_oo
oooooooo00Wooooo00?o2NX:ooooooooool08?ooool00ol0003oooooooooo`1Oooooo`00=Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03gooooo00?o2NX:ooooooooool02_ooool0
0ol9jP[oooooooooo`0Oooooo`03o`000?oooooooooo063ooooo000eooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0?Oooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo
01kooooo00?o0000ooooooooool0HOooool003Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0mooooo`03o`WZ2_oooooooooo00cooooo00?o2NX:ooooooooool07Oooool00ol0003o
ooooooooo`1Rooooo`00=Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03gooooo
00?o2NX:ooooooooool03Oooool00ol9jP[oooooooooo`0Looooo`03o`000?oooooooooo06?ooooo
000eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0?Oooool00ol9jP[ooooooooo
o`0>ooooo`03o`WZ2_oooooooooo01_ooooo00?o0000ooooooooool0I?ooool003Gooooo00Go0000
ooooooooooooooooo`00000oooooo`03o`WZ2_oooooooooo00oooooo00?o2NX:ooooooooool06_oo
ool00ol0003oooooooooo`1Uooooo`00=Oooool01?l0003oooooooooool0000oooooo`03o`WZ2_oo
oooooooo013ooooo00?o2NX:ooooooooool06Oooool00ol0003oooooooooo`1Vooooo`00=Oooool0
0ol0003oooooo`00000oooooo`03o`WZ2_oooooooooo017ooooo00?o2NX:ooooooooool06?ooool0
0ol0003oooooooooo`1Wooooo`00=Oooool2o`0003oooooo00?o2NX:ooooooooool04_ooool00ol9
jP[oooooooooo`0Gooooo`03o`000?oooooooooo06Sooooo000eooooo`03o`000?oooooooooo03go
oooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`0Fooooo`03o`000?oooooooooo06Wo
oooo000eooooo`03o`000?oooooooooo03cooooo00?o2NX:ooooooooool05?ooool00ol9jP[ooooo
ooooo`0Eooooo`03o`000?oooooooooo06[ooooo000eooooo`03o`000?oooooooooo03_ooooo00?o
2NX:ooooooooool05Oooool00ol9jP[oooooooooo`0Dooooo`03o`000?oooooooooo06_ooooo000e
ooooo`03o`000?oooooooooo03[ooooo00?o2NX:ooooooooool05_ooool00ol9jP[oooooooooo`0C
ooooo`03o`000?oooooooooo06cooooo000eooooo`03o`000?oooooooooo03Wooooo00?o2NX:oooo
ooooool05oooool00ol9jP[oooooooooo`0Booooo`03o`000?oooooooooo06gooooo000eooooo`03
o`000?oooooooooo03Sooooo00?o2NX:ooooooooool06?ooool00ol9jP[oooooooooo`0Aooooo`03
o`000?oooooooooo06kooooo000eooooo`03o`000?oooooooooo03Oooooo00?o2NX:ooooooooool0
6Oooool00ol9jP[oooooooooo`0@ooooo`03o`000?oooooooooo06oooooo000eooooo`03o`000?oo
oooooooo03Kooooo00?o2NX:ooooooooool06_ooool00ol9jP[oooooooooo`0?ooooo`03o`000?oo
oooooooo073ooooo000eooooo`03o`000?oooooooooo03Gooooo00?o2NX:ooooooooool06oooool0
0ol9jP[oooooooooo`0>ooooo`03o`000?oooooooooo077ooooo000]ooooo`?o2NX:1Oooool00ol0
003oooooooooo`0Zooooo`?o2NX:1oooool00ol9jP[oooooooooo`0Looooo`03o`WZ2_oooooooooo
00gooooo00?o0000ooooooooool0L_ooool002kooooo1_l9jPX2o`0002gooooo1_l9jPX00ooooooo
0000o`WZ2P0Oooooo`03o`WZ2_oooooooooo00cooooo00?o0000ooooooooool0Loooool000Kooooo
;_l9jPX00ol0003o2NX:o`WZ2P0do`WZ2P03o`000?oooooooooo01gooooo00?o2NX:ooooooooool0
2oooool00ol0003oooooooooo`1dooooo`00;_ooool5o`WZ2P;ooooo00?o0000ooooooooool0:ooo
ool5o`WZ2R?ooooo00?o2NX:ooooooooool02_ooool00ol0003oooooooooo`1eooooo`00;Oooool2
o`WZ2PKooooo00?o0000ooooooooool0:_ooool2o`WZ2ROooooo00?o2NX:ooooooooool02Oooool0
0ol0003oooooooooo`1fooooo`00=Oooool00ol0003oooooooooo`1Cooooo`03o`WZ2_oooooooooo
00Sooooo00?o0000ooooooooool0Moooool003Gooooo00?o0000ooooooooool0Doooool00ol9jP[o
ooooooooo`07ooooo`03o`000?oooooooooo07Sooooo000eooooo`03o`000?oooooooooo05?ooooo
00?o2NX:ooooooooool01_ooool00ol0003oooooooooo`1iooooo`00=Oooool00ol0003ooooooooo
o`1Cooooo`03o`WZ2_oooooooooo00Gooooo00?o0000ooooooooool0N_ooool003Gooooo00?o0000
ooooooooool0Doooool00ol9jP[oooooooooo`04ooooo`03o`000?oooooooooo07_ooooo000eoooo
o`03o`000?oooooooooo05?ooooo00?o2NX:ooooooooool00oooool00ol0003oooooooooo`1loooo
o`00=Oooool00ol0003oooooooooo`1Cooooo`03o`WZ2_oooooooooo00;ooooo00?o0000oooooooo
ool0OOooool003Gooooo00?o0000ooooooooool0Doooool01Ol9jP[ooooooooooooooooo0000083o
oooo000]ooooo`?o2NX:1Oooool00ol0003oooooooooo`1;ooooo`?o2NX:1Oooool01?l9jP[ooooo
ooooool00021ooooo`00;_ooool6o`WZ2P03ooooool0003ooooo04gooooo1_l9jPX01?oooooo2NX:
ooooool00022ooooo`001_ooool^o`WZ2P03o`000?l9jP[o2NX:05Go2NX:00?o0000ooooooooool0
POooool002kooooo1Ol9jPX00ooooooo0000o`00001>ooooo`Go2NX:0_ooool2o`0008?ooooo000]
ooooo`;o2NX:1_ooool00ol0003oooooooooo`1;ooooo`;o2NX:1Oooool00ol0003oooooooooo`23
ooooo`00=Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo08Cooooo000eooooo`03
o`000?oooooooooo053ooooo00?o0000ooooooooool0QOooool003Gooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`26ooooo`00=Oooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo08Oooooo000eooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0R?ooool0
03Gooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`29ooooo`00=Oooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo08[ooooo000eooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool0Roooool003Gooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`2<ooooo`00=Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo08gooooo000eoooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0S_ooool003Gooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`2?ooooo`00=Oooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo093ooooo000eooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0TOoo
ool003Gooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`2Booooo`00=Oooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo09?ooooo000eooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0U?ooool003Gooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`2Eooooo`00=Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo09Kooooo000e
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0Uoooool003Gooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`2Hooooo`00=Oooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo09Wooooo000eooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
V_ooool003Gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2Kooooo`00=Oooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo09cooooo000eooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool0WOooool003Gooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`2Nooooo`00=Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo09oooooo
000eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0X?ooool003Gooooo>?l0002S
ooooo`00oooooolAooooo`00oooooolAooooo`00oooooolAooooo`00oooooolAooooo`00oooooolA
ooooo`00oooooolAooooo`00\
\>"],
  ImageRangeCache->{{{0, 271.125}, {286.938, 0}} -> {-0.41356, -12.9378, \
0.0640518, 0.0640518}},
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[{
CircleOfRays[35,NumberOfRays->7],
Move[HollowCornerCube[50,FullForm->False],{50,0},5],
Boundary[100,GraphicDesign->Off]},PlotType->TopView];\
\>", "Input",
  CellTags->"Prism Examples"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .67202 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0111278 0.33601 0.0111278 [
[ 0 0 0 0 ]
[ 1 .67202 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.72728 .34888 m
.72566 .62799 L
.97619 .37065 L
.72728 .34888 L
F
.72728 .34888 m
.97619 .37065 L
.77416 .07372 L
.72728 .34888 L
F
.72728 .34888 m
.77416 .07372 L
.58626 .26673 L
.72728 .34888 L
F
.72728 .34888 m
.58626 .26673 L
.57414 .40529 L
.72728 .34888 L
F
.72728 .34888 m
.57414 .40529 L
.72566 .62799 L
.72728 .34888 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .37065 m
.77416 .07372 L
.58626 .26673 L
.57414 .40529 L
.72566 .62799 L
.97619 .37065 L
s
.5 g
.74062 .19645 m
.77416 .07372 L
.97619 .37065 L
.74062 .19645 L
F
.74062 .19645 m
.97619 .37065 L
.74991 .35086 L
.74062 .19645 L
F
.74062 .19645 m
.74991 .35086 L
.59838 .12816 L
.74062 .19645 L
F
.74062 .19645 m
.59838 .12816 L
.60445 .05887 L
.74062 .19645 L
F
.74062 .19645 m
.60445 .05887 L
.77416 .07372 L
.74062 .19645 L
F
0 g
.97619 .37065 m
.74991 .35086 L
.59838 .12816 L
.60445 .05887 L
.77416 .07372 L
.97619 .37065 L
s
.5 g
.71395 .5013 m
.74991 .35086 L
.97619 .37065 L
.71395 .5013 L
F
.71395 .5013 m
.97619 .37065 L
.72566 .62799 L
.71395 .5013 L
F
.71395 .5013 m
.72566 .62799 L
.55595 .61315 L
.71395 .5013 L
F
.71395 .5013 m
.55595 .61315 L
.56201 .54386 L
.71395 .5013 L
F
.71395 .5013 m
.56201 .54386 L
.74991 .35086 L
.71395 .5013 L
F
0 g
.97619 .37065 m
.72566 .62799 L
.55595 .61315 L
.56201 .54386 L
.74991 .35086 L
.97619 .37065 L
s
.5 g
.55595 .61315 m
.5547 .62744 L
.55557 .61751 L
.55678 .6037 L
.55595 .61315 L
F
.55678 .6037 m
.55557 .61751 L
.55812 .58839 L
.5592 .57602 L
.55678 .6037 L
F
.5592 .57602 m
.55812 .58839 L
.56217 .54208 L
.56305 .53197 L
.5592 .57602 L
F
.56305 .53197 m
.56217 .54208 L
.56745 .48172 L
.56808 .47458 L
.56305 .53197 L
F
.56808 .47458 m
.56745 .48172 L
.5736 .41144 L
.57392 .40774 L
.56808 .47458 L
F
.57392 .40774 m
.5736 .41144 L
.5802 .33601 L
.5802 .33601 L
.57392 .40774 L
F
.5802 .33601 m
.5802 .33601 L
.5868 .26058 L
.58647 .26428 L
.5802 .33601 L
F
.58647 .26428 m
.5868 .26058 L
.59295 .1903 L
.59232 .19744 L
.58647 .26428 L
F
.59232 .19744 m
.59295 .1903 L
.59823 .12994 L
.59734 .14004 L
.59232 .19744 L
F
.59734 .14004 m
.59823 .12994 L
.60228 .08363 L
.6012 .096 L
.59734 .14004 L
F
.6012 .096 m
.60228 .08363 L
.60483 .05451 L
.60362 .06832 L
.6012 .096 L
F
.60362 .06832 m
.60483 .05451 L
.6057 .04458 L
.60445 .05887 L
.60362 .06832 L
F
.60445 .05887 m
.6057 .04458 L
.60483 .05451 L
.60362 .06832 L
.60445 .05887 L
F
.60362 .06832 m
.60483 .05451 L
.60228 .08363 L
.6012 .096 L
.60362 .06832 L
F
.6012 .096 m
.60228 .08363 L
.59823 .12994 L
.59734 .14004 L
.6012 .096 L
F
.59734 .14004 m
.59823 .12994 L
.59295 .1903 L
.59232 .19744 L
.59734 .14004 L
F
.59232 .19744 m
.59295 .1903 L
.5868 .26058 L
.58647 .26428 L
.59232 .19744 L
F
.58647 .26428 m
.5868 .26058 L
.5802 .33601 L
.5802 .33601 L
.58647 .26428 L
F
.5802 .33601 m
.5802 .33601 L
.5736 .41144 L
.57392 .40774 L
.5802 .33601 L
F
.57392 .40774 m
.5736 .41144 L
.56745 .48172 L
.56808 .47458 L
.57392 .40774 L
F
.56808 .47458 m
.56745 .48172 L
.56217 .54208 L
.56305 .53197 L
.56808 .47458 L
F
.56305 .53197 m
.56217 .54208 L
.55812 .58839 L
.5592 .57602 L
.56305 .53197 L
F
.5592 .57602 m
.55812 .58839 L
.55557 .61751 L
.55678 .6037 L
.5592 .57602 L
F
.55678 .6037 m
.55557 .61751 L
.5547 .62744 L
.55595 .61315 L
.55678 .6037 L
F
.5547 .62744 m
.55345 .64173 L
.55436 .63131 L
.55557 .61751 L
.5547 .62744 L
F
.55557 .61751 m
.55436 .63131 L
.55704 .60077 L
.55812 .58839 L
.55557 .61751 L
F
.55812 .58839 m
.55704 .60077 L
.56129 .55219 L
.56217 .54208 L
.55812 .58839 L
F
.56217 .54208 m
.56129 .55219 L
.56683 .48887 L
.56745 .48172 L
.56217 .54208 L
F
.56745 .48172 m
.56683 .48887 L
.57328 .41514 L
.5736 .41144 L
.56745 .48172 L
F
.5736 .41144 m
.57328 .41514 L
.5802 .33601 L
.5802 .33601 L
.5736 .41144 L
F
.5802 .33601 m
.5802 .33601 L
.58712 .25688 L
.5868 .26058 L
.5802 .33601 L
F
.5868 .26058 m
.58712 .25688 L
.59357 .18315 L
.59295 .1903 L
.5868 .26058 L
F
.59295 .1903 m
.59357 .18315 L
.59911 .11983 L
.59823 .12994 L
.59295 .1903 L
F
.59823 .12994 m
.59911 .11983 L
.60336 .07125 L
.60228 .08363 L
.59823 .12994 L
F
.60228 .08363 m
.60336 .07125 L
.60603 .04071 L
.60483 .05451 L
.60228 .08363 L
F
.60483 .05451 m
.60603 .04071 L
.60695 .03029 L
.6057 .04458 L
.60483 .05451 L
F
.6057 .04458 m
.60695 .03029 L
.60603 .04071 L
.60483 .05451 L
.6057 .04458 L
F
.60483 .05451 m
.60603 .04071 L
.60336 .07125 L
.60228 .08363 L
.60483 .05451 L
F
.60228 .08363 m
.60336 .07125 L
.59911 .11983 L
.59823 .12994 L
.60228 .08363 L
F
.59823 .12994 m
.59911 .11983 L
.59357 .18315 L
.59295 .1903 L
.59823 .12994 L
F
.59295 .1903 m
.59357 .18315 L
.58712 .25688 L
.5868 .26058 L
.59295 .1903 L
F
.5868 .26058 m
.58712 .25688 L
.5802 .33601 L
.5802 .33601 L
.5868 .26058 L
F
.5802 .33601 m
.5802 .33601 L
.57328 .41514 L
.5736 .41144 L
.5802 .33601 L
F
.5736 .41144 m
.57328 .41514 L
.56683 .48887 L
.56745 .48172 L
.5736 .41144 L
F
.56745 .48172 m
.56683 .48887 L
.56129 .55219 L
.56217 .54208 L
.56745 .48172 L
F
.56217 .54208 m
.56129 .55219 L
.55704 .60077 L
.55812 .58839 L
.56217 .54208 L
F
.55812 .58839 m
.55704 .60077 L
.55436 .63131 L
.55557 .61751 L
.55812 .58839 L
F
.55557 .61751 m
.55436 .63131 L
.55345 .64173 L
.5547 .62744 L
.55557 .61751 L
F
.55345 .64173 m
.5522 .65602 L
.55316 .64512 L
.55436 .63131 L
.55345 .64173 L
F
.55436 .63131 m
.55316 .64512 L
.55595 .61315 L
.55704 .60077 L
.55436 .63131 L
F
.55704 .60077 m
.55595 .61315 L
.5604 .56229 L
.56129 .55219 L
.55704 .60077 L
F
.56129 .55219 m
.5604 .56229 L
.5662 .49601 L
.56683 .48887 L
.56129 .55219 L
F
.56683 .48887 m
.5662 .49601 L
.57295 .41883 L
.57328 .41514 L
.56683 .48887 L
F
.57328 .41514 m
.57295 .41883 L
.5802 .33601 L
.5802 .33601 L
.57328 .41514 L
F
.5802 .33601 m
.5802 .33601 L
.58745 .25319 L
.58712 .25688 L
.5802 .33601 L
F
.58712 .25688 m
.58745 .25319 L
.5942 .17601 L
.59357 .18315 L
.58712 .25688 L
F
.59357 .18315 m
.5942 .17601 L
.6 .10973 L
.59911 .11983 L
.59357 .18315 L
F
.59911 .11983 m
.6 .10973 L
.60445 .05887 L
.60336 .07125 L
.59911 .11983 L
F
.60336 .07125 m
.60445 .05887 L
.60724 .0269 L
.60603 .04071 L
.60336 .07125 L
F
.60603 .04071 m
.60724 .0269 L
.6082 .016 L
.60695 .03029 L
.60603 .04071 L
F
.60695 .03029 m
.6082 .016 L
.60724 .0269 L
.60603 .04071 L
.60695 .03029 L
F
.60603 .04071 m
.60724 .0269 L
.60445 .05887 L
.60336 .07125 L
.60603 .04071 L
F
.60336 .07125 m
.60445 .05887 L
.6 .10973 L
.59911 .11983 L
.60336 .07125 L
F
.59911 .11983 m
.6 .10973 L
.5942 .17601 L
.59357 .18315 L
.59911 .11983 L
F
.59357 .18315 m
.5942 .17601 L
.58745 .25319 L
.58712 .25688 L
.59357 .18315 L
F
.58712 .25688 m
.58745 .25319 L
.5802 .33601 L
.5802 .33601 L
.58712 .25688 L
F
.5802 .33601 m
.5802 .33601 L
.57295 .41883 L
.57328 .41514 L
.5802 .33601 L
F
.57328 .41514 m
.57295 .41883 L
.5662 .49601 L
.56683 .48887 L
.57328 .41514 L
F
.56683 .48887 m
.5662 .49601 L
.5604 .56229 L
.56129 .55219 L
.56683 .48887 L
F
.56129 .55219 m
.5604 .56229 L
.55595 .61315 L
.55704 .60077 L
.56129 .55219 L
F
.55704 .60077 m
.55595 .61315 L
.55316 .64512 L
.55436 .63131 L
.55704 .60077 L
F
.55436 .63131 m
.55316 .64512 L
.5522 .65602 L
.55345 .64173 L
.55436 .63131 L
F
0 g
.55595 .61315 m
.55678 .6037 L
.5592 .57602 L
.56305 .53197 L
.56808 .47458 L
.57392 .40774 L
.5802 .33601 L
.58647 .26428 L
.59232 .19744 L
.59734 .14004 L
.6012 .096 L
.60362 .06832 L
.60445 .05887 L
.60362 .06832 L
.6012 .096 L
.59734 .14004 L
.59232 .19744 L
.58647 .26428 L
.5802 .33601 L
.57392 .40774 L
.56808 .47458 L
.56305 .53197 L
.5592 .57602 L
.55678 .6037 L
.55595 .61315 L
s
.5522 .65602 m
.55316 .64512 L
.55595 .61315 L
.5604 .56229 L
.5662 .49601 L
.57295 .41883 L
.5802 .33601 L
.58745 .25319 L
.5942 .17601 L
.6 .10973 L
.60445 .05887 L
.60724 .0269 L
.6082 .016 L
.60724 .0269 L
.60445 .05887 L
.6 .10973 L
.5942 .17601 L
.58745 .25319 L
.5802 .33601 L
.57295 .41883 L
.5662 .49601 L
.5604 .56229 L
.55595 .61315 L
.55316 .64512 L
.5522 .65602 L
s
.039 .916 .04 r
.02381 .53075 m
.56316 .53075 L
s
% Start of user PostScript
0 17.5 48.4689 17.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.56316 .53075 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .45743 m
.56958 .45743 L
s
% Start of user PostScript
0 10.9111 49.0454 10.9111 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.56958 .45743 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .29268 m
.58399 .29268 L
s
% Start of user PostScript
0 -3.89412 50.3407 -3.89412 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.58399 .29268 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16056 m
.59555 .16056 L
s
% Start of user PostScript
0 -15.767 51.3794 -15.767 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.59555 .16056 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16056 m
.59555 .16056 L
s
% Start of user PostScript
0 -15.767 51.3794 -15.767 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.59555 .16056 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .29268 m
.58399 .29268 L
s
% Start of user PostScript
0 -3.89412 50.3407 -3.89412 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.58399 .29268 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .45743 m
.56958 .45743 L
s
% Start of user PostScript
0 10.9111 49.0454 10.9111 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.56958 .45743 Mdot
.039 .916 .04 r
.5 Mabswid
.56316 .53075 m
.7409 .53075 L
s
% Start of user PostScript
48.4689 17.5 64.4415 17.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.7409 .53075 Mdot
.039 .916 .04 r
.5 Mabswid
.56958 .45743 m
.72762 .45743 L
s
% Start of user PostScript
49.0454 10.9111 63.2483 10.9111 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.72762 .45743 Mdot
.039 .916 .04 r
.5 Mabswid
.58399 .29268 m
.77437 .29268 L
s
% Start of user PostScript
50.3407 -3.89412 67.4496 -3.89412 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.77437 .29268 Mdot
.039 .916 .04 r
.5 Mabswid
.59555 .16056 m
.70621 .16056 L
s
% Start of user PostScript
51.3794 -15.767 61.3242 -15.767 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.70621 .16056 Mdot
.039 .916 .04 r
.5 Mabswid
.59555 .16056 m
.81455 .16056 L
s
% Start of user PostScript
51.3794 -15.767 71.06 -15.767 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.81455 .16056 Mdot
.039 .916 .04 r
.5 Mabswid
.58399 .29268 m
.71349 .29268 L
s
% Start of user PostScript
50.3407 -3.89412 61.9785 -3.89412 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.71349 .29268 Mdot
.039 .916 .04 r
.5 Mabswid
.56958 .45743 m
.75246 .45743 L
s
% Start of user PostScript
49.0454 10.9111 65.4803 10.9111 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.75246 .45743 Mdot
.039 .916 .04 r
.5 Mabswid
.7409 .53075 m
.84548 .35922 L
s
% Start of user PostScript
64.4415 17.5 73.8392 2.08568 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.84548 .35922 Mdot
.039 .916 .04 r
.5 Mabswid
.72762 .45743 m
.84109 .27132 L
s
% Start of user PostScript
63.2483 10.9111 73.4445 -5.81323 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.84109 .27132 Mdot
.039 .916 .04 r
.5 Mabswid
.77437 .29268 m
.80566 .43053 L
s
% Start of user PostScript
67.4496 -3.89412 70.2606 8.49445 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.80566 .43053 Mdot
.039 .916 .04 r
.5 Mabswid
.70621 .16056 m
.78339 .50069 L
s
% Start of user PostScript
61.3242 -15.767 68.2597 14.7991 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.78339 .50069 Mdot
.039 .916 .04 r
.5 Mabswid
.81455 .16056 m
.82591 .2106 L
s
% Start of user PostScript
71.06 -15.767 72.0804 -11.2699 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.82591 .2106 Mdot
.039 .916 .04 r
.5 Mabswid
.71349 .29268 m
.81647 .27506 L
s
% Start of user PostScript
61.9785 -3.89412 71.2328 -5.47706 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.81647 .27506 Mdot
.039 .916 .04 r
.5 Mabswid
.75246 .45743 m
.82597 .44485 L
s
% Start of user PostScript
65.4803 10.9111 72.0866 9.78107 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.82597 .44485 Mdot
.039 .916 .04 r
.5 Mabswid
.84548 .35922 m
.81175 .21056 L
s
% Start of user PostScript
73.8392 2.08568 70.808 -11.2733 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.81175 .21056 Mdot
.039 .916 .04 r
.5 Mabswid
.84109 .27132 m
.76764 .28388 L
s
% Start of user PostScript
73.4445 -5.81323 66.8448 -4.68434 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.76764 .28388 Mdot
.039 .916 .04 r
.5 Mabswid
.80566 .43053 m
.69985 .44863 L
s
% Start of user PostScript
70.2606 8.49445 60.7523 10.1208 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69985 .44863 Mdot
.039 .916 .04 r
.5 Mabswid
.78339 .50069 m
.73458 .58075 L
s
% Start of user PostScript
68.2597 14.7991 63.8734 21.9937 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.73458 .58075 Mdot
.039 .916 .04 r
.5 Mabswid
.82591 .2106 m
.60024 .58075 L
s
% Start of user PostScript
72.0804 -11.2699 51.8007 21.9937 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.60024 .58075 Mdot
.039 .916 .04 r
.5 Mabswid
.81647 .27506 m
.71065 .44863 L
s
% Start of user PostScript
71.2328 -5.47706 61.7232 10.1208 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.71065 .44863 Mdot
.039 .916 .04 r
.5 Mabswid
.82597 .44485 m
.78945 .28388 L
s
% Start of user PostScript
72.0866 9.78107 68.8043 -4.68434 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.78945 .28388 Mdot
.039 .916 .04 r
.5 Mabswid
.81175 .21056 m
.59117 .21056 L
s
% Start of user PostScript
70.808 -11.2733 50.9863 -11.2733 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.59117 .21056 Mdot
.039 .916 .04 r
.5 Mabswid
.76764 .28388 m
.58476 .28388 L
s
% Start of user PostScript
66.8448 -4.68434 50.4098 -4.68434 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.58476 .28388 Mdot
.039 .916 .04 r
.5 Mabswid
.69985 .44863 m
.57035 .44863 L
s
% Start of user PostScript
60.7523 10.1208 49.1145 10.1208 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.57035 .44863 Mdot
.039 .916 .04 r
.5 Mabswid
.73458 .58075 m
.55879 .58075 L
s
% Start of user PostScript
63.8734 21.9937 48.0758 21.9937 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.55879 .58075 Mdot
.039 .916 .04 r
.5 Mabswid
.60024 .58075 m
.55879 .58075 L
s
0 0 0 r
2 Mabswid
.55879 .58075 Mdot
.039 .916 .04 r
.5 Mabswid
.71065 .44863 m
.57035 .44863 L
s
% Start of user PostScript
61.7232 10.1208 49.1145 10.1208 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.57035 .44863 Mdot
.039 .916 .04 r
.5 Mabswid
.78945 .28388 m
.58476 .28388 L
s
% Start of user PostScript
68.8043 -4.68434 50.4098 -4.68434 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.58476 .28388 Mdot
.039 .916 .04 r
.5 Mabswid
.59117 .21056 m
.02381 .21056 L
s
% Start of user PostScript
50.9863 -11.2733 0 -11.2733 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.02381 .21056 Mdot
.039 .916 .04 r
.5 Mabswid
.58476 .28388 m
.02381 .28388 L
s
% Start of user PostScript
50.4098 -4.68434 0 -4.68434 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.02381 .28388 Mdot
.039 .916 .04 r
.5 Mabswid
.57035 .44863 m
.02381 .44863 L
s
% Start of user PostScript
49.1145 10.1208 0 10.1208 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.02381 .44863 Mdot
.039 .916 .04 r
.5 Mabswid
.55879 .58075 m
.02381 .58075 L
s
% Start of user PostScript
48.0758 21.9937 0 21.9937 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.02381 .58075 Mdot
.039 .916 .04 r
.5 Mabswid
.55879 .58075 m
.02381 .58075 L
s
% Start of user PostScript
48.0758 21.9937 0 21.9937 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.02381 .58075 Mdot
.039 .916 .04 r
.5 Mabswid
.57035 .44863 m
.02381 .44863 L
s
% Start of user PostScript
49.1145 10.1208 0 10.1208 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.02381 .44863 Mdot
.039 .916 .04 r
.5 Mabswid
.58476 .28388 m
.02381 .28388 L
s
% Start of user PostScript
50.4098 -4.68434 0 -4.68434 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.02381 .28388 Mdot
0 0 m
1 0 L
1 .67202 L
0 .67202 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 193.5},
  ImageMargins->{{147, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000`B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00[_ooool0
0ol0003oooooooooo`1_ooooo`00[_ooool00ol0003oooooooooo`1_ooooo`00[_ooool00ol0003o
ooooooooo`1_ooooo`00[_ooool00ol0003oooooooooo`1_ooooo`00[_ooool00ol0003ooooooooo
o`1_ooooo`00[_ooool00ol0003oooooooooo`1_ooooo`00[_ooool00ol0003oooooooooo`1_oooo
o`00[Oooool00omoOgoo0000ooooo`1`ooooo`00[Oooool00ol0003oooooooooo`1`ooooo`00[Ooo
ool00ol0003oooooooooo`1`ooooo`00[Oooool00ol0003oooooooooo`1`ooooo`00[Oooool00ol0
003oooooooooo`1`ooooo`00[Oooool7o`0006cooooo002]ooooo`03o`000?moOgooOgmo00CoOgmo
3?l0001Pooooo`00[Oooool00ol0003oOgmoogmoO`0@ogmoO`go0000Doooool00:gooooo00?o0000
ogmoOomoOgl07OmoOgl<o`0004Oooooo002]ooooo`03o`000?moOgooOgmo02WoOgmo1_l00011oooo
o`00[?ooool00omoOgoo0000ogmoO`0_ogmoO`03o`000?oooooooooo03oooooo002/ooooo`03ogmo
Ool0003oOgmo033oOgmo00?o0000ooooooooool0?_ooool00:cooooo0_l0000bogmoO`03o`000?oo
oooooooo03gooooo002/ooooo`03o`000?moOgooOgmo037oOgmo00?o0000ooooooooool0?Oooool0
0:cooooo00?o0000ogmoOomoOgl0<_moOgl00ol0003oooooooooo`0looooo`00[?ooool00ol0003o
OgmoogmoO`0cogmoO`03o`000?oooooooooo03_ooooo002/ooooo`03o`000?moOgooOgmo03?oOgmo
00?o0000ooooooooool0>oooool00:cooooo00?o0000ogmoOomoOgl0=?moOgl00ol0003ooooooooo
o`0jooooo`00[?ooool00ol0003oOgmoogmoO`0eogmoO`03o`000?oooooooooo03Wooooo002/oooo
o`03o`000?moOgooOgmo03GoOgmo00?o0000ooooooooool0>Oooool00:_ooooo00?oOgmoo`000?mo
Ogl0=omoOgl00ol0003oooooooooo`0hooooo`00Zoooool00omoOgoo0000ogmoO`0hogmoO`03o`00
0?oooooooooo03Oooooo002[ooooo`;o0000>OmoOgl00ol0003oooooooooo`0gooooo`00Zoooool2
o`0003[oOgmo00?o0000ooooooooool0=_ooool00:_ooooo0_l0000kogmoO`03o`000?oooooooooo
03Gooooo002[ooooo`03o`000?moOgooOgmo03[oOgmo00?o0000ooooooooool0=Oooool00:_ooooo
00?o0000ogmoOomoOgl0>omoOgl00ol0003oooooooooo`0dooooo`00Zoooool2o`0003goOgmo00?o
0000ooooooooool0<oooool00:_ooooo00?o0000ooooool00000??moOgl00ol0003oooooooooo`0c
ooooo`00Zoooool00ol0003oooooo`00000mogmoO`03o`000?oooooooooo03;ooooo002[ooooo`04
o`000?ooooooooooo`0003goOgmo00?o0000ooooooooool0<Oooool00:_ooooo00Go0000oooooooo
ooooooooo`00000logmoO`03o`000?oooooooooo037ooooo002Rooooo`?o2NX:1_ooool01Ol0003o
oooooooooooooooo000001;oOgmo0ol9jPXLogmoO`?o2NX:2OmoOgl00ol0003oooooooooo`0`oooo
o`00Xoooool6o`WZ2P03ooooool0003o000000Cooooo00?o0000ogmoOomoOgl04?moOgl6o`WZ2P03
ogmoOol0003o000001KoOgmo1_l9jPX00omoOgoo0000o`000003ogmoO`03o`000?oooooooooo02oo
oooo0007ooooon?o2NX:00Go0000ogmoOomoOgooOgmoo`00000aooooo`00Xoooool5o`WZ2P;ooooo
00?o0000ooooooooool01Oooool00ol0003oOgmoogmoO`0>ogmoO`Go2NX:0_moOgl00ol9jP[oOgmo
ogmoO`0EogmoO`Go2NX:0_moOgl00ol9jP[oOgmoogmoO`03ogmoO`03o`000?oooooooooo02kooooo
002Rooooo`;o2NX:1_ooool00ol0003oooooooooo`05ooooo`03o`000?moOgooOgmo00goOgmo0_l9
jPX6ogmoO`03o`WZ2_moOgooOgmo01CoOgmo0_l9jPX6ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00?o
0000ooooooooool0;Oooool00:[ooooo00?o0000ooooooooool01_ooool00ol0003oOgmoogmoO`0E
ogmoO`03o`WZ2_moOgooOgmo01coOgmo00?o2NX:ogmoOomoOgl00omoOgl00ol0003oooooooooo`0]
ooooo`00Z_ooool00ol0003oooooooooo`07ooooo`03o`000?moOgooOgmo01CoOgmo00?o2NX:ogmo
OomoOgl07?moOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`000?oooooooooo02cooooo002Zooooo`03
o`000?oooooooooo00Oooooo00?o0000ogmoOomoOgl05?moOgl00ol9jP[oOgmoogmoO`0LogmoO`03
o`WZ2_moOgooOgmo00GoOgmo00?o0000ooooooooool0:oooool00:[ooooo00?o0000ooooooooool0
2?ooool00ol0003oOgmoogmoO`0CogmoO`03o`WZ2_moOgooOgmo01coOgmo00Co2NX:ogmoOomoOgoo
2NX:1?moOgl00ol0003oooooooooo`0[ooooo`00Z_ooool00ol0003oooooooooo`09ooooo`03o`00
0?moOgooOgmo01;oOgmo00?o2NX:ogmoOomoOgl06omoOgl2o`WZ2P;oOgmo00?o2NX:ogmoOomoOgl0
0omoOgl00ol0003oooooooooo`0Zooooo`00ZOooool2o`0000_ooooo00?o0000ogmoOomoOgl04omo
Ogl00ol9jP[oOgmoogmoO`0JogmoO`Go2NX:1_moOgl00ol0003oooooooooo`0Yooooo`00ZOooool2
o`0000cooooo00?o0000ogmoOomoOgl04_moOgl00ol9jP[oOgmoogmoO`0KogmoO`Co2NX:1_moOgl0
0ol0003oooooooooo`0Yooooo`00ZOooool2o`0000gooooo00?o0000ogmoOomoOgl04OmoOgl00ol9
jP[oOgmoogmoO`0KogmoO`Co2NX:1omoOgl00ol0003oooooooooo`0Xooooo`00ZOooool00ol0003o
ooooooooo`0<ooooo`03o`000?moOgooOgmo017oOgmo00?o2NX:ogmoOomoOgl07?moOgl2o`WZ2PWo
Ogmo00?o0000ooooooooool09oooool000gooooo0ol9jPZIooooo`03o`000?oooooooooo00?ooooo
0ol9jPX7ooooo`03o`000?moOgooOgmo017oOgmo00?o2NX:ogmoOomoOgl06omoOgl2o`WZ2PWoOgmo
00?o0000ooooooooool09oooool000Wooooo1_l9jPZJooooo`03o`000?oooooo2NX:00Go2NX:2?oo
ool2o`0001;oOgmo00?o2NX:ogmoOomoOgl06omoOgl2o`WZ2P[oOgmo00?o0000ooooooooool09_oo
ool000Kooooo0_l0002Ro`WZ2P03o`000?l9jP[o2NX:03co2NX:00Go0000ogmoOomoOgoo2NX:o`00
000:ogmoO`03o`000?oooooooooo02Gooooo0006ooooo`;o00000_ooool5o`WZ2Y[ooooo0_l00000
0ooooooo2NX:o`WZ2P03o`WZ2PKooooo00Go0000ogmoOomoOgooOgmoo`00000AogmoO`03o`WZ2_mo
OgooOgmo01SoOgmo0_l00002ogmoO`03o`WZ2_l0003oOgmo00WoOgmo00?o0000ooooooooool09Ooo
ool000kooooo0_l9jPZIooooo`03o`000?oooooooooo00Cooooo0_l9jPX4ooooo`03o`000?moOgoo
Ogmo00?oOgmo00?o0000ogmoOomoOgl03omoOgl00ol9jP[oOgmoogmoO`0GogmoO`;o2NX:00?oOgmo
o`WZ2_moOgl03?moOgl00ol0003oooooooooo`0Tooooo`00ZOooool00ol0003oooooooooo`09oooo
o`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl03_moOgl00ol9jP[oOgmoogmoO`0Gogmo
O`?o2NX:3omoOgl00ol0003oooooooooo`0Sooooo`00ZOooool00ol0003oooooooooo`08ooooo`03
o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl03_moOgl00ol9jP[oOgmoogmoO`0GogmoO`?o
2NX:4?moOgl00ol0003oooooooooo`0Rooooo`00ZOooool00ol0003oooooooooo`07ooooo`03o`00
0?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl03OmoOgl00ol9jP[oOgmoogmoO`0GogmoO`?o2NX:
4?moOgl00ol0003oooooooooo`0Rooooo`00ZOooool00ol0003oooooooooo`06ooooo`03o`000?mo
OgooOgmo00[oOgmo00?o0000ogmoOomoOgl03?moOgl00ol9jP[oOgmoogmoO`0GogmoO`Co2NX:4?mo
Ogl00ol0003oooooooooo`0Qooooo`00Z?ooool2o`0000Oooooo00?o0000ogmoOomoOgl02omoOgl0
0ol0003oOgmoogmoO`0=ogmoO`03o`WZ2_moOgooOgmo01KoOgmo1?l9jPXAogmoO`03o`000?oooooo
oooo023ooooo002Xooooo`03o`000?oooooooooo00Gooooo00?o0000ogmoOomoOgl03OmoOgl00ol0
003oOgmoogmoO`0<ogmoO`03o`WZ2_moOgooOgmo01GoOgmo1?l9jPX00omoOgoo2NX:ogmoO`0?ogmo
O`03o`000?oooooooooo023ooooo002Xooooo`03o`000?oooooooooo00Cooooo00?o0000ogmoOomo
Ogl03omoOgl00ol0003oOgmoogmoO`0;ogmoO`03o`WZ2_moOgooOgmo01GoOgmo0_l9jPX00omoOgoo
2NX:ogmoO`0BogmoO`03o`000?oooooooooo01oooooo002Xooooo`03o`000?oooooooooo00?ooooo
00?o0000ogmoOomoOgl04?moOgl00ol0003oOgmoogmoO`0;ogmoO`03o`WZ2_moOgooOgmo01CoOgmo
00Go2NX:ogmoOomoOgooOgmoo`WZ2P0DogmoO`03o`000?oooooooooo01kooooo002Xooooo`03o`00
0?oooooooooo00;ooooo00?o0000ogmoOomoOgl04_moOgl00ol0003oOgmoogmoO`0;ogmoO`03o`WZ
2_moOgooOgmo01?oOgmo00Go2NX:ogmoOomoOgooOgmoo`WZ2P0DogmoO`03o`000?oooooooooo01ko
oooo002Xooooo`05o`000?ooooooooooooooool000005_moOgl00ol0003oOgmoogmoO`0:ogmoO`03
o`WZ2_moOgooOgmo01;oOgmo00?o2NX:ogmoOomoOgl00omoOgl00ol9jP[oOgmoogmoO`0BogmoO`03
o`000?oooooooooo01gooooo002Xooooo`04o`000?ooooooooooo`0001OoOgmo00?o0000ogmoOomo
Ogl02_moOgl00ol9jP[oOgmoogmoO`0AogmoO`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomo
Ogl04omoOgl00ol0003oooooooooo`0Looooo`00Z?ooool00ol0003oooooo`00000IogmoO`03o`00
0?moOgooOgmo00WoOgmo00?o2NX:ogmoOomoOgl04OmoOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ
2_moOgooOgmo01?oOgmo00?o0000ooooooooool07?ooool00:Sooooo0_l0000KogmoO`03o`000?mo
OgooOgmo00SoOgmo00?o2NX:ogmoOomoOgl04?moOgl00ol9jP[oOgmoogmoO`05ogmoO`03o`WZ2_mo
OgooOgmo01CoOgmo00?o0000ooooooooool06oooool00:Sooooo00?o0000ogmoOomoOgl06_moOgl0
0ol0003oOgmoogmoO`09ogmoO`03o`WZ2_moOgooOgmo00ooOgmo00?o2NX:ogmoOomoOgl01_moOgl0
0ol9jP[oOgmoogmoO`0DogmoO`03o`000?oooooooooo01[ooooo002Xooooo`03o`000?moOgooOgmo
01_oOgmo00?o0000ogmoOomoOgl02?moOgl00ol9jP[oOgmoogmoO`0>ogmoO`03o`WZ2_moOgooOgmo
00OoOgmo00Co2NX:ogmoOomoOgooOgmo0_l0000AogmoO`03o`000?oooooooooo01[ooooo002Xoooo
o`03o`000?moOgooOgmo01coOgmo00?o0000ogmoOomoOgl01omoOgl00ol9jP[oOgmoogmoO`0=ogmo
O`Ko2NX:0_moOgl2o`000003ogmoOol9jP[oOgmo00Co2NX:4_moOgl00ol0003oooooooooo`0Ioooo
o`003Oooool3o`WZ2YSooooo00?o0000ogmoOomoOgl00_moOgl3o`WZ2QSoOgmo00?o0000ogmoOomo
Ogl01_moOgl00ol9jP[oOgmoogmoO`0;ogmoO`oo2NX:0_moOgl2o`WZ2Q?oOgmo00?o0000oooooooo
ool06?ooool000Wooooo1_l9jPZHooooo`;o00001_l9jPXIogmoO`03o`000?moOgooOgmo00OoOgmo
00?o2NX:ogmoOomoOgl02?moOgl<o`WZ2P06ogmoOol9jP[oOgmoogmoOol9jP[oOgmo0_l9jPXDogmo
O`03o`000?oooooooooo01Sooooo0006ooooo`;o0000X?l9jPX00ol0003o2NX:o`WZ2P0ko`WZ2P?o
Ogmo00Co2NX:ogmoOomoOgooOgmo1?l9jPXEogmoO`03o`000?oooooooooo01Oooooo0006ooooo`;o
00000_ooool5o`WZ2Y3ooooo0ol9jPX5ooooo`;o000000?oOgmoo`WZ2_l9jPX00ol9jPXEogmoO`?o
2NX:0omoOgl00ol0003oOgmoogmoO`05ogmoO`03o`WZ2_moOgooOgmo00Ko2NX:0_l00002ogmoO`04
o`WZ2_moOgoo0000o`0000;o2NX:0omoOgl00ol9jP[oOgmoogmoO`02ogmoO`Co2NX:5_moOgl00ol0
003oooooooooo`0Fooooo`003_ooool2o`WZ2Y3ooooo1_l9jPX00ooooooo0000o`000005ogmoO`;o
2NX:5OmoOgl6o`WZ2P04ogmoOol0003o0000ogmoO`Ko2NX:0_moOgl6o`WZ2P03o`000?l9jP[oOgmo
00;oOgmo0_l9jPX4ogmoO`04o`WZ2_moOgooOgmoogmoO`Co2NX:5omoOgl00ol0003oooooooooo`0F
ooooo`001ooooooFo`WZ2P03o`000?l9jP[oOgmo00;oOgmo0_l9jPX3ogmoO`04o`WZ2_moOgooOgmo
ogmoO`Go2NX:6?moOgl00ol0003oooooooooo`0Eooooo`00X?ooool5o`WZ2P;ooooo00?o0000ogmo
OomoOgl06omoOgl5o`WZ2P;oOgmo00?o0000ogmoOomoOgl01?moOgl01?l9jP[oOgmoogmoOomoOgl5
o`WZ2P03ogmoOol9jP[o2NX:00?oOgmo0ol9jPX2ogmoO`03o`WZ2_moOgooOgmo00?oOgmo0ol9jPXI
ogmoO`03o`000?oooooooooo01Cooooo002Oooooo`;o2NX:1_ooool00ol0003oOgmoogmoO`0Jogmo
O`;o2NX:1_moOgl00ol0003oOgmoogmoO`04ogmoO`03o`WZ2_moOgooOgmo00;o2NX:1OmoOgl2o`WZ
2P?oOgmo0ol9jPX00omoOgoo2NX:ogmoO`04ogmoO`03o`WZ2_moOgoo2NX:01[oOgmo00?o0000oooo
ooooool05?ooool00:Oooooo00?o0000ogmoOomoOgl08omoOgl00ol0003oOgmoogmoO`03ogmoO`03
o`WZ2_moOgooOgmo00KoOgmo00Co2NX:ogmoOomoOgoo2NX:0_moOgl4o`WZ2PKoOgmo00?o2NX:ogmo
Ool9jPX06omoOgl00ol0003oooooooooo`0Cooooo`00Yoooool00ol0003oOgmoogmoO`0TogmoO`03
o`000?moOgooOgmo00;oOgmo00?o2NX:ogmoOomoOgl01OmoOgl01Ol9jP[oOgmoogmoOomoOgoo2NX:
00;oOgmo0_l9jPX00omoOgoo2NX:ogmoO`04ogmoO`04o`WZ2_moOgooOgmoo`WZ2QcoOgmo00?o0000
ooooooooool04_ooool00:Oooooo00?o0000ogmoOomoOgl09?moOgl00ol0003oOgmoogmoO`03ogmo
O`03o`WZ2_moOgooOgmo00CoOgmo00Go2NX:ogmoOomoOgooOgmoo`WZ2P02ogmoO`05o`WZ2_moOgoo
2NX:ogmoOol9jPX00omoOgl00ol9jP[oOgmoogmoO`02ogmoO`03o`WZ2_moOgooOgmo01WoOgmo00?o
0000ooooooooool04_ooool00:Oooooo00?o0000ogmoOomoOgl09OmoOgl00ol0003oOgmoogmoO`02
ogmoO`03o`WZ2_moOgooOgmo00?oOgmo00?o2NX:ogmoOomoOgl00_moOgl00ol9jP[oOgmoogmoO`03
o`WZ2PGoOgmo00?o2NX:ogmoOomoOgl00_moOgl00ol9jP[oOgmoogmoO`0JogmoO`03o`000?oooooo
oooo017ooooo002Vooooo`;o0000:?moOgl01Ol0003oOgmoogmoOomoOgoo2NX:00GoOgmo00?o2NX:
ogmoOomoOgl00omoOgl00ol9jP[oOgmoogmoO`02o`WZ2PCoOgmo00?o2NX:ogmoOomoOgl00omoOgl0
0ol9jP[oOgmoogmoO`0KogmoO`03o`000?oooooooooo013ooooo002Vooooo`03o`000?moOgooOgmo
02OoOgmo00Go0000ogmoOomoOgooOgmoo`WZ2P04ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00Go2NX:
ogmoOol9jP[oOgmoo`WZ2P04ogmoO`03o`WZ2_moOgooOgmo00?oOgmo00?o2NX:ogmoOomoOgl06omo
Ogl00ol0003oooooooooo`0@ooooo`00Y_ooool00ol0003oOgmoogmoO`0XogmoO`05o`000?moOgoo
OgmoogmoOol9jPX00_moOgl00ol9jP[oOgmoogmoO`05ogmoO`03o`WZ2_moOgoo2NX:00;oOgmo00Co
2NX:ogmoOomoOgoo2NX:1omoOgl00ol9jP[oOgmoogmoO`0KogmoO`03o`000?oooooooooo00oooooo
002Vooooo`03o`000?moOgooOgmo02WoOgmo00Co0000ogmoOomoOgoo2NX:0_moOgl00ol9jP[oOgmo
ogmoO`05ogmoO`;o2NX:0omoOgl00ol9jP[oOgmoo`WZ2P08ogmoO`03o`WZ2_moOgooOgmo01coOgmo
00?o0000ooooooooool03_ooool00:Kooooo00?o0000ogmoOomoOgl0:_moOgl01Ol0003oOgmoo`WZ
2_moOgoo2NX:00SoOgmo00?o2NX:ogmoOomoOgl00_moOgl00ol9jP[oOgmoo`WZ2P08ogmoO`03o`WZ
2_moOgooOgmo01coOgmo00?o0000ooooooooool03_ooool00:Kooooo00?o0000ogmoOomoOgl0:_mo
Ogl01Ol0003oOgmoo`WZ2_moOgoo2NX:00SoOgmo0_l9jPX3ogmoO`;o2NX:2OmoOgl00ol9jP[oOgmo
ogmoO`0MogmoO`03o`000?oooooooooo00gooooo002Vooooo`03o`000?moOgooOgmo02_oOgmo00?o
0000o`WZ2_l9jPX02?moOgl00ol9jP[oOgmoo`WZ2P03ogmoO`03o`WZ2_moOgooOgmo00SoOgmo00?o
2NX:ogmoOomoOgl07_moOgl00ol0003oooooooooo`0<ooooo`00Y_ooool00ol0003oOgmoogmoO`0/
ogmoO`;o2NX:2?moOgl00ol9jP[oOgmoo`WZ2P03ogmoO`;o2NX:2_moOgl00ol9jP[oOgmoogmoO`0M
ogmoO`03o`000?oooooooooo00cooooo002Vooooo`03o`000?moOgooOgmo02coOgmo0_l9jPX7ogmo
O`04o`WZ2_moOgooOgmoo`WZ2P;oOgmo00?o2NX:ogmoOol9jPX02_moOgl00ol9jP[oOgmoogmoO`0N
ogmoO`03o`000?oooooooooo00_ooooo002Vooooo`03o`000?moOgooOgmo02_oOgmo00?o2NX:ogmo
Ool9jPX01_moOgl00ol9jP[oOgmoogmoO`02ogmoO`05o`WZ2_moOgoo2NX:ogmoOol9jPX02_moOgl0
0ol9jP[oOgmoogmoO`0OogmoO`03o`000?oooooooooo00[ooooo002Vooooo`03o`000?moOgooOgmo
02_oOgmo00?o2NX:ogmoOol9jPX01_l000000ol9jP[oOgmoogmoO`02ogmoO`;o2NX:0_moOgl00ol9
jP[oOgmoogmoO`08ogmoO`03o`WZ2_moOgooOgmo01ooOgmo00?o0000ooooooooool02_ooool00:Go
oooo0_l0000/ogmoO`05o`WZ2_moOgooOgmoogmoOol9jPX01?moOgl00ol9jP[oOgmoo`000003o`00
0005o`WZ2_l0003o0000o`000?l9jPX01?l00006ogmoO`03o`000?l9jP[oOgmo023oOgmo00?o0000
ooooooooool02Oooool00:Gooooo00?o0000ogmoOomoOgl0:_moOgl01_l9jP[oOgmoogmoOomoOgoo
0000o`WZ2P?oOgmo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oOgmoogmoO`02ogmoO`04o`WZ2_mo
OgooOgmoogmoO`Oo000000?o2NX:o`000?l000000ol0000MogmoO`03o`000?oooooooooo00Sooooo
002Uooooo`03o`000?moOgooOgmo02[oOgmo00Ko2NX:ogmoOomoOgoo0000ogmoOol9jPX3ogmoO`03
o`WZ2_moOgooOgmo00?oOgmo00?o2NX:ogmoOol9jPX00omoOgl00ol9jP[oOgmoogmoO`07ogmoO`;o
2NX:1OmoOgl=o`00013oOgmo00?o0000ooooooooool02?ooool00:Gooooo00?o0000ogmoOomoOgl0
:OmoOgl01?l9jP[oOgmoogmoOol00002ogmoO`04o`WZ2_moOgooOgmoo`WZ2PGoOgmo00Co2NX:ogmo
OomoOgoo2NX:0omoOgl00ol9jP[oOgmoogmoO`06ogmoO`;o2NX:4omoOgl=o`0000CoOgmo00?o0000
ooooooooool01oooool00:Gooooo00?o0000ogmoOomoOgl0:OmoOgl00ol9jP[oOgmoo`000003ogmo
O`04o`WZ2_moOgooOgmoo`WZ2PGoOgmo00Co2NX:ogmoOomoOgoo2NX:0omoOgl00ol9jP[oOgmoogmo
O`05ogmoO`?o2NX:8?moOgl6o`0000Sooooo002Uooooo`03o`000?moOgooOgmo02SoOgmo00?o2NX:
ogmoOol000001OmoOgl2o`WZ2PGoOgmo00Go2NX:ogmoOomoOgooOgmoo`WZ2P04ogmoO`03o`WZ2_mo
OgooOgmo00?oOgmo1?l9jPXUogmoO`03o`000?oooooooooo00Kooooo002Uooooo`03o`000?moOgoo
Ogmo02OoOgmo00?o2NX:ogmoOol000001_moOgl00ol9jP[oOgmoogmoO`04ogmoO`05o`WZ2_moOgoo
OgmoogmoOol9jPX01?moOgl00ol9jP[oOgmoogmoO`02ogmoO`Co2NX:9OmoOgl00ol0003ooooooooo
o`07ooooo`00YOooool00ol0003oOgmoogmoO`0WogmoO`03o`WZ2_l0003oOgmo00KoOgmo00?o2NX:
ogmoOomoOgl00omoOgl00ol9jP[oOgmoogmoO`03ogmoO`05o`WZ2_moOgooOgmoogmoOol9jPX00omo
Ogl2o`WZ2P03ogmoOol9jP[o2NX:02CoOgmo00?o0000ooooooooool02?ooool00:Gooooo00?o0000
ogmoOomoOgl09_moOgl00ol9jP[o0000ogmoO`06ogmoO`;o2NX:1?moOgl00ol9jP[oOgmoogmoO`04
ogmoO`05o`WZ2_moOgooOgmoogmoOol9jPX01OmoOgl3o`WZ2R?oOgmo00?o0000ooooooooool02Ooo
ool00:Gooooo00?o0000ogmoOomoOgl09_moOgl00ol9jP[oOgmoogmoO`05ogmoO`04o`WZ2_moOgoo
Ogmoo`WZ2P?oOgmo00?o2NX:ogmoOomoOgl01?moOgl01Ol9jP[oOgmoogmoOomoOgoo2NX:00CoOgmo
00?o2NX:ogmoOol9jPX08omoOgl00ol0003oooooooooo`0:ooooo`00Y?ooool2o`0002OoOgmo00?o
2NX:ogmoOomoOgl01_moOgl01?l9jP[oOgmoogmoOol9jPX2ogmoO`03o`WZ2_moOgooOgmo00GoOgmo
00?o2NX:ogmoOomoOgl00_moOgl01Ol9jP[oOgmoogmoOomoOgoo2NX:02CoOgmo00?o0000oooooooo
ool02oooool00:Cooooo0_l0000VogmoO`03o`WZ2_moOgooOgmo00KoOgmo00Go2NX:ogmoOomoOgoo
Ogmoo`WZ2P02ogmoO`03o`WZ2_moOgooOgmo00KoOgmo00Go2NX:ogmoOomoOgooOgmoo`WZ2P02ogmo
O`03o`WZ2_moOgooOgmo02;oOgmo00?o0000ooooooooool03?ooool00:Cooooo0_l0000UogmoO`03
o`000?l9jP[oOgmo00OoOgmo00Oo2NX:ogmoOomoOgooOgmoo`WZ2_moOgoo2NX:00WoOgmo00Go2NX:
ogmoOomoOgooOgmoo`WZ2P02ogmoO`03o`WZ2_moOgooOgmo027oOgmo00?o0000ooooooooool03Ooo
ool00:Cooooo00?o0000ogmoOomoOgl08omoOgl00ol0003o2NX:ogmoO`07ogmoO`03o`WZ2_moOgoo
Ogmo00?oOgmo00?o2NX:ogmoOomoOgl02?moOgl01ol9jP[oOgmoo`WZ2_moOgoo2NX:ogmoOol9jPX0
8omoOgl00ol0003oooooooooo`0>ooooo`00Y?ooool00ol0003oOgmoogmoO`0RogmoO`03o`000?l9
jP[oOgmo00OoOgmo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oOgmoogmoO`06ogmoO`05o`WZ2_mo
Ogoo2NX:ogmoOol9jPX00_moOgl00ol9jP[oOgmoogmoO`0QogmoO`03o`000?oooooooooo00oooooo
002Tooooo`03o`000?moOgooOgmo027oOgmo00?o0000ogmoOol9jPX02?moOgl00ol9jP[oOgmoogmo
O`03ogmoO`;o2NX:2?moOgl2o`WZ2P03ogmoOol9jP[o2NX:00;oOgmo00?o2NX:ogmoOomoOgl08?mo
Ogl00ol0003oooooooooo`0@ooooo`00Y?ooool2o`00027oOgmo00?o0000ogmoOol9jPX02?moOgl0
0ol9jP[oOgmoogmoO`03ogmoO`03o`WZ2_moOgoo2NX:00WoOgmo1?l9jPX00omoOgoo2NX:o`WZ2P0Q
ogmoO`03o`000?oooooooooo017ooooo002Tooooo`03o`000?oooooo000001ooOgmo00Co0000ogmo
OomoOgoo2NX:2?moOgl00ol9jP[oOgmoogmoO`03ogmoO`03o`WZ2_moOgoo2NX:00WoOgmo1?l9jPX0
0omoOgoo2NX:o`WZ2P0PogmoO`03o`000?oooooooooo01;ooooo002Tooooo`03o`000?oooooo0000
01koOgmo00Co0000ogmoOomoOgoo2NX:2?moOgl00ol9jP[oOgmoogmoO`03ogmoO`05o`WZ2_moOgoo
OgmoogmoOol9jPX02OmoOgl4o`WZ2P03ogmoOol9jP[oOgmo01koOgmo00?o0000ooooooooool04ooo
ool00:Cooooo00Co0000oooooooooooo00007?moOgl01?l0003oOgmoogmoOol9jPX6ogmoO`03o`WZ
2_moOgoo2NX:00KoOgmo00Go2NX:ogmoOomoOgooOgmoo`WZ2P0:ogmoO`;o2NX:0omoOgl00ol9jP[o
OgmoogmoO`0KogmoO`03o`000?oooooooooo01Cooooo002Tooooo`05o`000?ooooooooooooooool0
00006_moOgl01Ol0003oOgmoogmoOomoOgoo2NX:00KoOgmo00?o2NX:ogmoOol9jPX01OmoOgl00ol9
jP[oOgmoogmoO`02ogmoO`03o`WZ2_moOgooOgmo00SoOgmo0_l9jPX3ogmoO`03o`WZ2_moOgooOgmo
01[oOgmo00?o0000ooooooooool05Oooool00:Cooooo00Go0000ooooooooooooooooo`00000Iogmo
O`05o`000?moOgooOgmoogmoOol9jPX01_moOgl5o`WZ2P?oOgmo00?o2NX:ogmoOomoOgl00omoOgl0
0ol9jP[oOgmoogmoO`06ogmoO`Co2NX:0omoOgl00ol9jP[oOgmoogmoO`0IogmoO`03o`000?oooooo
oooo01Kooooo002Tooooo`03o`000?oooooooooo00;ooooo00?o0000ogmoOomoOgl05OmoOgl00ol0
003oOgmoogmoO`02ogmoO`03o`WZ2_moOgooOgmo00CoOgmo1?l9jPX4ogmoO`03o`WZ2_moOgooOgmo
00CoOgmo00?o2NX:ogmoOomoOgl01Ol9jPX01?moOgoo2NX:o`000?l00003ogmoO`03o`WZ2_moOgoo
Ogmo01SoOgmo00?o0000ooooooooool05oooool00:?ooooo00?oOgmoo`000?ooool01?ooool00ol0
003oOgmoogmoO`0CogmoO`03o`000?moOgooOgmo00;oOgmo00?o2NX:ogmoOomoOgl01OmoOgl4o`WZ
2P?oOgmo00?o2NX:ogmoOomoOgl00omoOgl5o`WZ2PKoOgmo00?o2NX:ogmoOomoOgl00omoOgl00ol9
jP[oOgmoogmoO`0GogmoO`03o`000?oooooooooo01Sooooo002Sooooo`;o00001_ooool00ol0003o
OgmoogmoO`0AogmoO`03o`000?moOgooOgmo00;oOgmo00?o2NX:ogmoOomoOgl01OmoOgl5o`WZ2P;o
Ogmo00?o2NX:ogmoOol9jPX01?l9jPX2ogmoO`03o`WZ2_moOgooOgmo00GoOgmo00?o2NX:ogmoOomo
Ogl01OmoOgl00ol9jP[oOgmoogmoO`0EogmoO`03o`000?oooooooooo01Wooooo000=ooooo`?o2NX:
Toooool00ol0003oooooooooo`03ooooo`?o2NX:4_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`WZ
2_moOgooOgmo00CoOgmo2_l9jPX7ogmoO`03o`WZ2_moOgooOgmo00GoOgmo2Ol9jPX00ol0003oOgmo
ogmoO`0CogmoO`03o`000?oooooooooo01[ooooo0006ooooo`;o000000?oooooo`WZ2_l9jPX01?l9
jPZDooooo`;o00001_l9jPX00ooooooo0000ogmoO`0?ogmoO`03o`000?moOgooOgmo00?oOgmo00?o
2NX:ogmoOomoOgl00_moOgl2o`000003o`WZ2_l0003o000000?o2NX:0_moOgl00ol9jP[oOgmoogmo
O`07ogmoO`03o`WZ2_moOgooOgmo00CoOgmo2?l9jPX00omoOgoo0000o`00000DogmoO`03o`000?oo
oooooooo01_ooooo0006ooooo`;o0000W?l9jPX00ol0003o2NX:o`WZ2P0Uo`WZ2P03o`000?l9jP[o
2NX:00Co2NX:2_moOgl00ol9jP[oOgmoo`WZ2P04o`WZ2P;oOgmo0ol9jPXHogmoO`03o`000?oooooo
oooo01cooooo000:ooooo`Go2NX:SOooool6o`WZ2P04ooooool0003oooooooooo`Go2NX:0_ooool0
0ol0003oOgmoogmoO`0;ogmoO`03o`000?moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl01?moOgl6
o`WZ2P03ogmoOol9jP[o2NX:00Co2NX:1?moOgl5o`WZ2P?oOgmo00?o2NX:ogmoOomoOgl00ol9jPXH
ogmoO`03o`000?oooooooooo01gooooo0007oooooi_o2NX:00?o0000o`WZ2_l9jPX0=Ol9jPX3ogmo
O`05o`WZ2_moOgooOgmoogmoOol9jPX00omoOgl00ol9jP[oOgmoogmoO`0GogmoO`03o`000?oooooo
oooo01kooooo002Looooo`Go2NX:00?oooooo`000?l000002oooool00ol0003oOgmoogmoO`07ogmo
O`03o`000?moOgooOgmo00GoOgmo00?o2NX:ogmoOomoOgl01OmoOgl5o`WZ2P;oOgmo1Ol9jPX2ogmo
O`;o00001?moOgl01Ol9jP[oOgmoogmoOomoOgoo2NX:01goOgmo00?o0000ooooooooool07_ooool0
09_ooooo0_l9jPX6ooooo`03o`000?oooooooooo00Wooooo00?o0000ogmoOomoOgl01_moOgl00ol0
003oOgmoogmoO`05ogmoO`03o`WZ2_moOgooOgmo00GoOgmo0_l9jPX5ogmoO`;o2NX:3OmoOgl00ol9
jP[oOgmoo`WZ2P0MogmoO`03o`000?oooooooooo01oooooo002Sooooo`03o`000?oooooooooo00[o
oooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`06ogmoO`03o`WZ2_moOgooOgmo01_o
Ogmo0_l9jPXMogmoO`03o`000?oooooooooo023ooooo002Rooooo`03ogmoOol0003ooooo00cooooo
00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`06ogmoO`03o`WZ2_moOgooOgmo01coOgmo
0ol9jPXKogmoO`03o`000?oooooooooo027ooooo002Rooooo`03ogmoOol0003ooooo00cooooo00Go
0000ogmoOomoOgooOgmoo`000008ogmoO`03o`WZ2_moOgooOgmo01_oOgmo0ol9jPX00omoOgoo2NX:
ogmoO`0IogmoO`03o`000?oooooooooo02;ooooo002Rooooo`;o00003_ooool00ol0003oOgmoo`00
0009ogmoO`03o`WZ2_moOgooOgmo01_oOgmo1Ol9jPXIogmoO`03o`000?oooooooooo02?ooooo002R
ooooo`;o00003oooool00ol0003oOgmoogmoO`07ogmoO`03o`WZ2_moOgooOgmo01goOgmo1?l9jPXH
ogmoO`03o`000?oooooooooo02Cooooo002Rooooo`;o00003_ooool00ol0003oOgmoogmoO`08ogmo
O`03o`WZ2_moOgooOgmo01coOgmo1Ol9jPXGogmoO`03o`000?oooooooooo02Gooooo002Rooooo`;o
00003Oooool00ol0003oOgmoogmoO`08ogmoO`03o`WZ2_moOgooOgmo01goOgmo00?o2NX:ogmoOol9
jPX00_l9jPXFogmoO`03o`000?oooooooooo02Kooooo002Rooooo`03o`000?oooooooooo00_ooooo
00?o0000ogmoOomoOgl02?moOgl00ol9jP[oOgmoogmoO`0MogmoO`04o`WZ2_moOgooOgmoogmoO`;o
2NX:5OmoOgl00ol0003oooooooooo`0Wooooo`00X_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?moOgooOgmo00WoOgmo00?o2NX:ogmoOomoOgl07?moOgl00ol9jP[oOgmoogmoO`02ogmoO`;o2NX:
5?moOgl00ol0003oooooooooo`0Xooooo`00X_ooool00ol0003oooooooooo`09ooooo`03o`000?mo
OgooOgmo00WoOgmo00?o2NX:ogmoOomoOgl07OmoOgl00ol9jP[oOgmoogmoO`03ogmoO`03o`WZ2_l0
003oOgmo017oOgmo00?o0000ooooooooool0:Oooool00:;ooooo00?o0000ooooooooool02?ooool0
0ol0003oOgmoogmoO`0:ogmoO`03o`WZ2_moOgooOgmo01coOgmo00?o2NX:ogmoOomoOgl01?moOgl0
0ol9jP[o0000ogmoO`0@ogmoO`03o`000?oooooooooo02[ooooo002Rooooo`03o`000?oooooooooo
00Oooooo00?o0000ogmoOomoOgl02_moOgl00ol9jP[oOgmoogmoO`0MogmoO`03o`WZ2_moOgooOgmo
00?oOgmo00?o2NX:ogmoOomoOgl04?moOgl00ol0003oooooooooo`0[ooooo`00X_ooool00ol0003o
ooooooooo`06ooooo`03o`000?moOgooOgmo00[oOgmo00?o2NX:ogmoOomoOgl07OmoOgl00ol9jP[o
OgmoogmoO`03ogmoO`03o`WZ2_moOgooOgmo013oOgmo00?o0000ooooooooool0;?ooool00:;ooooo
00?o0000ooooooooool01Oooool00ol0003oOgmoogmoO`0;ogmoO`03o`WZ2_moOgooOgmo01coOgmo
00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oOgmoogmoO`0?ogmoO`03o`000?oooooooooo02gooooo
002Qooooo`;o00001_ooool00ol0003oOgmoogmoO`0;ogmoO`03o`WZ2_moOgooOgmo01goOgmo00?o
2NX:ogmoOomoOgl00omoOgl00ol9jP[oOgmoogmoO`0?ogmoO`03o`000?oooooooooo02kooooo002Q
ooooo`03o`000?oooooooooo00Cooooo00?o0000ogmoOomoOgl03?moOgl00ol9jP[oOgmoogmoO`0L
ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl03_moOgl00ol0003oooooooooo`0_
ooooo`00VOooool3o`WZ2PGooooo00?o0000ooooooooool00oooool00ol0003oOgmoogmoO`0<ogmo
O`03o`WZ2_moOgooOgmo01?oOgmo0ol9jPX7ogmoO`03o`WZ2_moOgooOgmo00?oOgmo00?o2NX:ogmo
OomoOgl03_moOgl00ol0003oooooooooo`0`ooooo`00V_ooool6o`WZ2P03ooooool0003ooooo00?o
oooo00?o0000ogmoOomoOgl03?moOgl00ol9jP[oOgmoogmoO`0EogmoO`Ko2NX:0_moOgl00ol9jP[o
OgmoogmoO`03ogmoO`03o`WZ2_moOgooOgmo00koOgmo00?o0000ooooooooool0<Oooool000Oooooo
c_l9jPX00ol0003oOgmoogmoO`03ogmoO`03o`WZ2_moOgooOgmo00goOgmo00?o0000ooooooooool0
<_ooool009[ooooo1Ol9jPX2ooooo`;o000000?oooooo`000?moOgl03_moOgl00ol9jP[oOgmoogmo
O`0FogmoO`Go2NX:0_moOgl2o`0000CoOgmo00?o2NX:ogmoOomoOgl03OmoOgl00ol0003ooooooooo
o`0cooooo`00VOooool2o`WZ2PKooooo00?o0000ooooool000004?moOgl00ol9jP[oOgmoogmoO`0E
ogmoO`;o2NX:3?moOgl00ol9jP[oOgmoogmoO`0<ogmoO`03o`000?oooooooooo03Cooooo002Qoooo
o`;o00004?moOgl00ol9jP[oOgmoogmoO`0SogmoO`03o`WZ2_moOgooOgmo00coOgmo00?o0000oooo
ooooool0=Oooool00:7ooooo00?o0000ogmoOomoOgl03_moOgl00ol9jP[oOgmoogmoO`0SogmoO`03
o`WZ2_moOgooOgmo00goOgmo00?o0000ooooooooool0=Oooool00:3ooooo0_l0000@ogmoO`03o`WZ
2_moOgooOgmo02?oOgmo00?o2NX:ogmoOomoOgl03?moOgl00ol0003oooooooooo`0fooooo`00X?oo
ool2o`0000ooOgmo00?o2NX:ogmoOomoOgl08OmoOgl00ol9jP[oOgmoo`WZ2P0>ogmoO`03o`000?oo
oooooooo03Oooooo002Pooooo`;o00003?moOgl01?l9jP[oOgmoogmoOol9jPXSogmoO`03o`WZ2_mo
Ogoo2NX:00goOgmo00?o0000ooooooooool0>?ooool00:3ooooo0_l0000<ogmoO`03o`WZ2_moOgoo
2NX:02?oOgmo0ol9jPX=ogmoO`03o`000?oooooooooo03Wooooo002Pooooo`;o00003?moOgl5o`WZ
2R7oOgmo1Ol9jPX:ogmoO`03o`000?oooooooooo03[ooooo002Pooooo`03o`000?moOgooOgmo00[o
Ogmo1?l9jPXSogmoO`?o2NX:2omoOgl00ol0003oooooooooo`0kooooo`00X?ooool00ol0003oOgmo
ogmoO`0:ogmoO`?o2NX:8omoOgl3o`WZ2P_oOgmo00?o0000ooooooooool0??ooool000gooooo0ol9
jPZ@ooooo`03o`000?moOgooOgmo00?oOgmo0ol9jPX4ogmoO`;o2NX:9?moOgl2o`WZ2P_oOgmo00?o
0000ooooooooool0?Oooool000Wooooo1_l9jPZAooooo`03o`000?moOgoo2NX:00Go2NX:1?moOgl2
o`WZ2RGoOgmo00?o2NX:ogmoOomoOgl02OmoOgl00ol0003oooooooooo`0nooooo`001_ooool2o`00
0<_o2NX:00?o0000ogmoOomoOgl02?moOgl00ol0003oooooooooo`0oooooo`001_ooool2o`0000;o
oooo1Ol9jPZ@ooooo`;o00000_moOgl5o`WZ2P?oOgmo0_l0000UogmoO`;o00002OmoOgl00ol0003o
ooooooooo`10ooooo`003_ooool2o`WZ2Y3ooooo00?o0000ogmoOomoOgl01?moOgl2o`WZ2S?oOgmo
00?o0000ooooooooool0@Oooool009oooooo0_l0000jogmoO`03o`000?oooooooooo04;ooooo002O
ooooo`;o0000>OmoOgl00ol0003oooooooooo`13ooooo`00Woooool2o`0003SoOgmo00?o0000oooo
ooooool0A?ooool009oooooo00?o0000ogmoOomoOgl0=_moOgl00ol0003oooooooooo`15ooooo`00
Woooool00ol0003oOgmoogmoO`0eogmoO`03o`000?oooooooooo04Kooooo002Oooooo`03o`000?mo
OgooOgmo03CoOgmo00?o0000ooooooooool0Aoooool009oooooo00?o0000ogmoOomoOgl0<omoOgl0
0ol0003oooooooooo`18ooooo`00Woooool7o`0002koOgmo00?o0000ooooooooool0BOooool009oo
oooo00?o0000ooooooooool01?ooool<o`00027oOgmo00?o0000ooooooooool0B_ooool009oooooo
00?o0000ooooooooool04?ooool=o`0001?oOgmo00?o0000ooooooooool0Boooool009oooooo00?o
0000ooooooooool07Oooool<o`0000KoOgmo00?o0000ooooooooool0C?ooool009oooooo00?o0000
ooooooooool0:Oooool6o`0004oooooo002Nooooo`03o`000?oooooooooo07oooooo002Nooooo`03
o`000?oooooooooo07oooooo002Nooooo`03o`000?oooooooooo07oooooo002Nooooo`03o`000?oo
oooooooo07oooooo002Nooooo`03o`000?oooooooooo07oooooo002Nooooo`03o`000?oooooooooo
07oooooo002Nooooo`03o`000?oooooooooo07oooooo002Nooooo`03o`000?oooooooooo07oooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {192.5, 0}} -> {-2.22639, -30.1958, 0.313723, \
0.313723}},
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%,PlotType->FrontView];", "Input",
  CellTags->"Prism Examples"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00382 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0165587 0.50191 0.0165587 [
[ 0 0 0 0 ]
[ 1 1.00382 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
.5 g
.51915 .239 m
.93449 .26291 L
.55155 .50191 L
.51915 .239 L
F
.51915 .239 m
.55155 .50191 L
.1097 .26291 L
.51915 .239 L
F
.51915 .239 m
.1097 .26291 L
.3969 .08365 L
.51915 .239 L
F
.51915 .239 m
.3969 .08365 L
.6031 .08365 L
.51915 .239 L
F
.51915 .239 m
.6031 .08365 L
.93449 .26291 L
.51915 .239 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.55155 .50191 m
.1097 .26291 L
.3969 .08365 L
.6031 .08365 L
.93449 .26291 L
.55155 .50191 L
s
.5 g
.29233 .63336 m
.1097 .26291 L
.55155 .50191 L
.29233 .63336 L
F
.29233 .63336 m
.55155 .50191 L
.52209 .97992 L
.29233 .63336 L
F
.29233 .63336 m
.52209 .97992 L
.19071 .80067 L
.29233 .63336 L
F
.29233 .63336 m
.19071 .80067 L
.08761 .62141 L
.29233 .63336 L
F
.29233 .63336 m
.08761 .62141 L
.1097 .26291 L
.29233 .63336 L
F
0 g
.55155 .50191 m
.52209 .97992 L
.19071 .80067 L
.08761 .62141 L
.1097 .26291 L
.55155 .50191 L
s
.5 g
.74596 .63336 m
.52209 .97992 L
.55155 .50191 L
.74596 .63336 L
F
.74596 .63336 m
.55155 .50191 L
.93449 .26291 L
.74596 .63336 L
F
.74596 .63336 m
.93449 .26291 L
.91239 .62141 L
.74596 .63336 L
F
.74596 .63336 m
.91239 .62141 L
.80929 .80067 L
.74596 .63336 L
F
.74596 .63336 m
.80929 .80067 L
.52209 .97992 L
.74596 .63336 L
F
0 g
.55155 .50191 m
.93449 .26291 L
.91239 .62141 L
.80929 .80067 L
.52209 .97992 L
.55155 .50191 L
s
.5 g
.91239 .50191 m
.93366 .50191 L
.91888 .61458 L
.89834 .60905 L
.91239 .50191 L
F
.89834 .60905 m
.91888 .61458 L
.87556 .71957 L
.85714 .70889 L
.89834 .60905 L
F
.85714 .70889 m
.87556 .71957 L
.80664 .80972 L
.79161 .79463 L
.85714 .70889 L
F
.79161 .79463 m
.80664 .80972 L
.71683 .8789 L
.7062 .86042 L
.79161 .79463 L
F
.7062 .86042 m
.71683 .8789 L
.61224 .92239 L
.60674 .90177 L
.7062 .86042 L
F
.60674 .90177 m
.61224 .92239 L
.5 .93723 L
.5 .91588 L
.60674 .90177 L
F
.5 .91588 m
.5 .93723 L
.38776 .92239 L
.39326 .90177 L
.5 .91588 L
F
.39326 .90177 m
.38776 .92239 L
.28317 .8789 L
.2938 .86042 L
.39326 .90177 L
F
.2938 .86042 m
.28317 .8789 L
.19336 .80972 L
.20839 .79463 L
.2938 .86042 L
F
.20839 .79463 m
.19336 .80972 L
.12444 .71957 L
.14286 .70889 L
.20839 .79463 L
F
.14286 .70889 m
.12444 .71957 L
.08112 .61458 L
.10166 .60905 L
.14286 .70889 L
F
.10166 .60905 m
.08112 .61458 L
.06634 .50191 L
.08761 .50191 L
.10166 .60905 L
F
.08761 .50191 m
.06634 .50191 L
.08112 .38924 L
.10166 .39477 L
.08761 .50191 L
F
.10166 .39477 m
.08112 .38924 L
.12444 .28425 L
.14286 .29493 L
.10166 .39477 L
F
.14286 .29493 m
.12444 .28425 L
.19336 .1941 L
.20839 .20919 L
.14286 .29493 L
F
.20839 .20919 m
.19336 .1941 L
.28317 .12492 L
.2938 .1434 L
.20839 .20919 L
F
.2938 .1434 m
.28317 .12492 L
.38776 .08143 L
.39326 .10205 L
.2938 .1434 L
F
.39326 .10205 m
.38776 .08143 L
.5 .06659 L
.5 .08794 L
.39326 .10205 L
F
.5 .08794 m
.5 .06659 L
.61224 .08143 L
.60674 .10205 L
.5 .08794 L
F
.60674 .10205 m
.61224 .08143 L
.71683 .12492 L
.7062 .1434 L
.60674 .10205 L
F
.7062 .1434 m
.71683 .12492 L
.80664 .1941 L
.79161 .20919 L
.7062 .1434 L
F
.79161 .20919 m
.80664 .1941 L
.87556 .28425 L
.85714 .29493 L
.79161 .20919 L
F
.85714 .29493 m
.87556 .28425 L
.91888 .38924 L
.89834 .39477 L
.85714 .29493 L
F
.89834 .39477 m
.91888 .38924 L
.93366 .50191 L
.91239 .50191 L
.89834 .39477 L
F
.93366 .50191 m
.95492 .50191 L
.93942 .6201 L
.91888 .61458 L
.93366 .50191 L
F
.91888 .61458 m
.93942 .6201 L
.89398 .73024 L
.87556 .71957 L
.91888 .61458 L
F
.87556 .71957 m
.89398 .73024 L
.82168 .82482 L
.80664 .80972 L
.87556 .71957 L
F
.80664 .80972 m
.82168 .82482 L
.72746 .89739 L
.71683 .8789 L
.80664 .80972 L
F
.71683 .8789 m
.72746 .89739 L
.61774 .94301 L
.61224 .92239 L
.71683 .8789 L
F
.61224 .92239 m
.61774 .94301 L
.5 .95857 L
.5 .93723 L
.61224 .92239 L
F
.5 .93723 m
.5 .95857 L
.38226 .94301 L
.38776 .92239 L
.5 .93723 L
F
.38776 .92239 m
.38226 .94301 L
.27254 .89739 L
.28317 .8789 L
.38776 .92239 L
F
.28317 .8789 m
.27254 .89739 L
.17832 .82482 L
.19336 .80972 L
.28317 .8789 L
F
.19336 .80972 m
.17832 .82482 L
.10602 .73024 L
.12444 .71957 L
.19336 .80972 L
F
.12444 .71957 m
.10602 .73024 L
.06058 .6201 L
.08112 .61458 L
.12444 .71957 L
F
.08112 .61458 m
.06058 .6201 L
.04508 .50191 L
.06634 .50191 L
.08112 .61458 L
F
.06634 .50191 m
.04508 .50191 L
.06058 .38372 L
.08112 .38924 L
.06634 .50191 L
F
.08112 .38924 m
.06058 .38372 L
.10602 .27358 L
.12444 .28425 L
.08112 .38924 L
F
.12444 .28425 m
.10602 .27358 L
.17832 .179 L
.19336 .1941 L
.12444 .28425 L
F
.19336 .1941 m
.17832 .179 L
.27254 .10643 L
.28317 .12492 L
.19336 .1941 L
F
.28317 .12492 m
.27254 .10643 L
.38226 .06081 L
.38776 .08143 L
.28317 .12492 L
F
.38776 .08143 m
.38226 .06081 L
.5 .04525 L
.5 .06659 L
.38776 .08143 L
F
.5 .06659 m
.5 .04525 L
.61774 .06081 L
.61224 .08143 L
.5 .06659 L
F
.61224 .08143 m
.61774 .06081 L
.72746 .10643 L
.71683 .12492 L
.61224 .08143 L
F
.71683 .12492 m
.72746 .10643 L
.82168 .179 L
.80664 .1941 L
.71683 .12492 L
F
.80664 .1941 m
.82168 .179 L
.89398 .27358 L
.87556 .28425 L
.80664 .1941 L
F
.87556 .28425 m
.89398 .27358 L
.93942 .38372 L
.91888 .38924 L
.87556 .28425 L
F
.91888 .38924 m
.93942 .38372 L
.95492 .50191 L
.93366 .50191 L
.91888 .38924 L
F
.95492 .50191 m
.97619 .50191 L
.95996 .62563 L
.93942 .6201 L
.95492 .50191 L
F
.93942 .6201 m
.95996 .62563 L
.91239 .74091 L
.89398 .73024 L
.93942 .6201 L
F
.89398 .73024 m
.91239 .74091 L
.83672 .83991 L
.82168 .82482 L
.89398 .73024 L
F
.82168 .82482 m
.83672 .83991 L
.7381 .91588 L
.72746 .89739 L
.82168 .82482 L
F
.72746 .89739 m
.7381 .91588 L
.62325 .96363 L
.61774 .94301 L
.72746 .89739 L
F
.61774 .94301 m
.62325 .96363 L
.5 .97992 L
.5 .95857 L
.61774 .94301 L
F
.5 .95857 m
.5 .97992 L
.37675 .96363 L
.38226 .94301 L
.5 .95857 L
F
.38226 .94301 m
.37675 .96363 L
.2619 .91588 L
.27254 .89739 L
.38226 .94301 L
F
.27254 .89739 m
.2619 .91588 L
.16328 .83991 L
.17832 .82482 L
.27254 .89739 L
F
.17832 .82482 m
.16328 .83991 L
.08761 .74091 L
.10602 .73024 L
.17832 .82482 L
F
.10602 .73024 m
.08761 .74091 L
.04004 .62563 L
.06058 .6201 L
.10602 .73024 L
F
.06058 .6201 m
.04004 .62563 L
.02381 .50191 L
.04508 .50191 L
.06058 .6201 L
F
.04508 .50191 m
.02381 .50191 L
.04004 .37819 L
.06058 .38372 L
.04508 .50191 L
F
.06058 .38372 m
.04004 .37819 L
.08761 .26291 L
.10602 .27358 L
.06058 .38372 L
F
.10602 .27358 m
.08761 .26291 L
.16328 .16391 L
.17832 .179 L
.10602 .27358 L
F
.17832 .179 m
.16328 .16391 L
.2619 .08794 L
.27254 .10643 L
.17832 .179 L
F
.27254 .10643 m
.2619 .08794 L
.37675 .04019 L
.38226 .06081 L
.27254 .10643 L
F
.38226 .06081 m
.37675 .04019 L
.5 .0239 L
.5 .04525 L
.38226 .06081 L
F
.5 .04525 m
.5 .0239 L
.62325 .04019 L
.61774 .06081 L
.5 .04525 L
F
.61774 .06081 m
.62325 .04019 L
.7381 .08794 L
.72746 .10643 L
.61774 .06081 L
F
.72746 .10643 m
.7381 .08794 L
.83672 .16391 L
.82168 .179 L
.72746 .10643 L
F
.82168 .179 m
.83672 .16391 L
.91239 .26291 L
.89398 .27358 L
.82168 .179 L
F
.89398 .27358 m
.91239 .26291 L
.95996 .37819 L
.93942 .38372 L
.89398 .27358 L
F
.93942 .38372 m
.95996 .37819 L
.97619 .50191 L
.95492 .50191 L
.93942 .38372 L
F
0 g
.91239 .50191 m
.89834 .60905 L
.85714 .70889 L
.79161 .79463 L
.7062 .86042 L
.60674 .90177 L
.5 .91588 L
.39326 .90177 L
.2938 .86042 L
.20839 .79463 L
.14286 .70889 L
.10166 .60905 L
.08761 .50191 L
.10166 .39477 L
.14286 .29493 L
.20839 .20919 L
.2938 .1434 L
.39326 .10205 L
.5 .08794 L
.60674 .10205 L
.7062 .1434 L
.79161 .20919 L
.85714 .29493 L
.89834 .39477 L
.91239 .50191 L
s
.97619 .50191 m
.95996 .62563 L
.91239 .74091 L
.83672 .83991 L
.7381 .91588 L
.62325 .96363 L
.5 .97992 L
.37675 .96363 L
.2619 .91588 L
.16328 .83991 L
.08761 .74091 L
.04004 .62563 L
.02381 .50191 L
.04004 .37819 L
.08761 .26291 L
.16328 .16391 L
.2619 .08794 L
.37675 .04019 L
.5 .0239 L
.62325 .04019 L
.7381 .08794 L
.83672 .16391 L
.91239 .26291 L
.95996 .37819 L
.97619 .50191 L
s
.039 .916 .04 r
.78978 .50191 m
.78978 .50191 L
s
% Start of user PostScript
17.5 0 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.78978 .50191 Mdot
.039 .916 .04 r
.5 Mabswid
.68067 .72847 m
.68067 .72847 L
s
% Start of user PostScript
10.9111 13.6821 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.68067 .72847 Mdot
.039 .916 .04 r
.5 Mabswid
.43552 .78442 m
.43552 .78442 L
s
% Start of user PostScript
-3.89412 17.0612 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.43552 .78442 Mdot
.039 .916 .04 r
.5 Mabswid
.23892 .62764 m
.23892 .62764 L
s
% Start of user PostScript
-15.767 7.59297 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.23892 .62764 Mdot
.039 .916 .04 r
.5 Mabswid
.23892 .37618 m
.23892 .37618 L
s
% Start of user PostScript
-15.767 -7.59297 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.23892 .37618 Mdot
.039 .916 .04 r
.5 Mabswid
.43552 .2194 m
.43552 .2194 L
s
% Start of user PostScript
-3.89412 -17.0612 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.43552 .2194 Mdot
.039 .916 .04 r
.5 Mabswid
.68067 .27535 m
.68067 .27535 L
s
% Start of user PostScript
10.9111 -13.6821 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.68067 .27535 Mdot
.039 .916 .04 r
.5 Mabswid
.78978 .50191 m
.78978 .50191 L
s
% Start of user PostScript
17.5 0 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.78978 .50191 Mdot
.039 .916 .04 r
.5 Mabswid
.68067 .72847 m
.68067 .72847 L
s
% Start of user PostScript
10.9111 13.6821 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.68067 .72847 Mdot
.039 .916 .04 r
.5 Mabswid
.43552 .78442 m
.43552 .78442 L
s
% Start of user PostScript
-3.89412 17.0612 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.43552 .78442 Mdot
.039 .916 .04 r
.5 Mabswid
.23892 .62764 m
.23892 .62764 L
s
% Start of user PostScript
-15.767 7.59297 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.23892 .62764 Mdot
.039 .916 .04 r
.5 Mabswid
.23892 .37618 m
.23892 .37618 L
s
% Start of user PostScript
-15.767 -7.59297 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.23892 .37618 Mdot
.039 .916 .04 r
.5 Mabswid
.43552 .2194 m
.43552 .2194 L
s
% Start of user PostScript
-3.89412 -17.0612 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.43552 .2194 Mdot
.039 .916 .04 r
.5 Mabswid
.68067 .27535 m
.68067 .27535 L
s
% Start of user PostScript
10.9111 -13.6821 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.68067 .27535 Mdot
.039 .916 .04 r
.5 Mabswid
.78978 .50191 m
.53454 .36385 L
s
% Start of user PostScript
17.5 0 2.08568 -8.33785 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.53454 .36385 Mdot
.039 .916 .04 r
.5 Mabswid
.68067 .72847 m
.40374 .57867 L
s
% Start of user PostScript
10.9111 13.6821 -5.81323 4.63561 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40374 .57867 Mdot
.039 .916 .04 r
.5 Mabswid
.43552 .78442 m
.64066 .65639 L
s
% Start of user PostScript
-3.89412 17.0612 8.49445 9.32903 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.64066 .65639 Mdot
.039 .916 .04 r
.5 Mabswid
.23892 .62764 m
.74506 .31174 L
s
% Start of user PostScript
-15.767 7.59297 14.7991 -11.4846 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.74506 .31174 Mdot
.039 .916 .04 r
.5 Mabswid
.23892 .37618 m
.31339 .3297 L
s
% Start of user PostScript
-15.767 -7.59297 -11.2699 -10.3998 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.31339 .3297 Mdot
.039 .916 .04 r
.5 Mabswid
.43552 .2194 m
.40931 .64471 L
s
% Start of user PostScript
-3.89412 -17.0612 -5.47706 8.6241 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40931 .64471 Mdot
.039 .916 .04 r
.5 Mabswid
.68067 .27535 m
.66196 .57897 L
s
% Start of user PostScript
10.9111 -13.6821 9.78107 4.65362 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.66196 .57897 Mdot
.039 .916 .04 r
.5 Mabswid
.53454 .36385 m
.31333 .50191 L
s
% Start of user PostScript
2.08568 -8.33785 -11.2733 0.00002 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.31333 .50191 Mdot
.039 .916 .04 r
.5 Mabswid
.40374 .57867 m
.42243 .27535 L
s
% Start of user PostScript
-5.81323 4.63561 -4.68434 -13.682 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.42243 .27535 Mdot
.039 .916 .04 r
.5 Mabswid
.64066 .65639 m
.66759 .2194 L
s
% Start of user PostScript
8.49445 9.32903 10.1208 -17.0612 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.66759 .2194 Mdot
.039 .916 .04 r
.5 Mabswid
.74506 .31174 m
.86419 .37618 L
s
% Start of user PostScript
14.7991 -11.4846 21.9937 -7.59295 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.86419 .37618 Mdot
.039 .916 .04 r
.5 Mabswid
.31339 .3297 m
.86419 .62764 L
s
% Start of user PostScript
-11.2699 -10.3998 21.9937 7.59299 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.86419 .62764 Mdot
.039 .916 .04 r
.5 Mabswid
.40931 .64471 m
.66759 .78442 L
s
% Start of user PostScript
-5.47706 8.6241 10.1208 17.0613 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.66759 .78442 Mdot
.039 .916 .04 r
.5 Mabswid
.66196 .57897 m
.42243 .72847 L
s
% Start of user PostScript
9.78107 4.65362 -4.68434 13.6821 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.42243 .72847 Mdot
.039 .916 .04 r
.5 Mabswid
.31333 .50191 m
.31333 .50191 L
s
% Start of user PostScript
-11.2733 0.00002 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.31333 .50191 Mdot
.039 .916 .04 r
.5 Mabswid
.42243 .27535 m
.42243 .27535 L
s
% Start of user PostScript
-4.68434 -13.682 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.42243 .27535 Mdot
.039 .916 .04 r
.5 Mabswid
.66759 .2194 m
.66759 .2194 L
s
% Start of user PostScript
10.1208 -17.0612 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.66759 .2194 Mdot
.039 .916 .04 r
.5 Mabswid
.86419 .37618 m
.86419 .37618 L
s
% Start of user PostScript
21.9937 -7.59295 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.86419 .37618 Mdot
.039 .916 .04 r
.5 Mabswid
.86419 .62764 m
.86419 .62764 L
s
0 0 0 r
2 Mabswid
.86419 .62764 Mdot
.039 .916 .04 r
.5 Mabswid
.66759 .78442 m
.66759 .78442 L
s
% Start of user PostScript
10.1208 17.0613 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.66759 .78442 Mdot
.039 .916 .04 r
.5 Mabswid
.42243 .72847 m
.42243 .72847 L
s
% Start of user PostScript
-4.68434 13.6821 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.42243 .72847 Mdot
.039 .916 .04 r
.5 Mabswid
.31333 .50191 m
.31333 .50191 L
s
% Start of user PostScript
-11.2733 0.00002 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.31333 .50191 Mdot
.039 .916 .04 r
.5 Mabswid
.42243 .27535 m
.42243 .27535 L
s
% Start of user PostScript
-4.68434 -13.682 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.42243 .27535 Mdot
.039 .916 .04 r
.5 Mabswid
.66759 .2194 m
.66759 .2194 L
s
% Start of user PostScript
10.1208 -17.0612 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.66759 .2194 Mdot
.039 .916 .04 r
.5 Mabswid
.86419 .37618 m
.86419 .37618 L
s
% Start of user PostScript
21.9937 -7.59295 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.86419 .37618 Mdot
.039 .916 .04 r
.5 Mabswid
.86419 .62764 m
.86419 .62764 L
s
% Start of user PostScript
21.9937 7.59299 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.86419 .62764 Mdot
.039 .916 .04 r
.5 Mabswid
.66759 .78442 m
.66759 .78442 L
s
% Start of user PostScript
10.1208 17.0613 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.66759 .78442 Mdot
.039 .916 .04 r
.5 Mabswid
.42243 .72847 m
.42243 .72847 L
s
% Start of user PostScript
-4.68434 13.6821 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.42243 .72847 Mdot
0 0 m
1 0 L
1 1.00382 L
0 1.00382 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{286.875, 287.938},
  ImageMargins->{{137, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004N00017b000`400?l00000o`00003ooooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00Roooool8o`0008_ooooo0024ooooo`Oo00002?moOgl7o`0008Cooooo001mooooo`Oo0000
5_moOgl7o`0007gooooo001fooooo`Oo00009?moOgl7o`0007Kooooo001_ooooo`Oo0000<_moOgl7
o`0006oooooo001Zooooo`Go0000@?moOgl5o`0006[ooooo001Wooooo`?o0000B_moOgl2o`0006So
oooo001Uooooo`;o0000ComoOgl3o`0006Gooooo001Sooooo`;o0000E?moOgl2o`0006?ooooo001P
ooooo`?o0000F?moOgl2o`00067ooooo001Nooooo`;o0000GOmoOgl3o`0005kooooo001Looooo`;o
0000H_moOgl2o`0005cooooo001Iooooo`?o0000I_moOgl2o`0005[ooooo001Gooooo`;o0000Jomo
Ogl2o`0005Sooooo001Eooooo`;o0000KomoOgl3o`0005Gooooo001Booooo`?o0000M?moOgl2o`00
05?ooooo001@ooooo`;o0000NOmoOgl2o`00057ooooo001>ooooo`;o0000OOmoOgl3o`0004kooooo
001;ooooo`?o0000P_moOgl2o`0004cooooo0019ooooo`;o0000?omoOgl9o`0003ooOgmo0_l0001:
ooooo`00B?ooool00ol0003oOgmoogmoO`0hogmoO`Oo00002OmoOgl8o`0003WoOgmo00?o0000oooo
ooooool0Aoooool004Oooooo00?o0000ogmoOomoOgl0<OmoOgl8o`0001SoOgmo1ol0000cogmoO`03
o`000?oooooooooo04Kooooo0015ooooo`;o0000;OmoOgl7o`0002OoOgmo2?l0000/ogmoO`;o0000
A_ooool004Cooooo00?o0000ogmoOomoOgl0:?moOgl5o`0003KoOgmo1Ol0000YogmoO`03o`000?oo
oooooooo04?ooooo0013ooooo`03o`000?moOgooOgmo02KoOgmo0ol00010ogmoO`?o00009omoOgl2
o`0004?ooooo0011ooooo`;o00009omoOgl2o`0004KoOgmo0_l0000WogmoO`03o`000?oooooooooo
043ooooo0010ooooo`03o`000?moOgooOgmo02GoOgmo0_l0001:ogmoO`;o00009_moOgl00ol0003o
ooooooooo`0oooooo`00?oooool00ol0003oOgmoogmoO`0SogmoO`?o0000C_moOgl3o`0002CoOgmo
0_l0000oooooo`00?Oooool2o`0002CoOgmo0_l0001DogmoO`;o00009?moOgl00ol0003ooooooooo
o`0looooo`00??ooool00ol0003oOgmoogmoO`0QogmoO`?o0000F?moOgl2o`0002?oOgmo0_l0000l
ooooo`00>oooool00ol0003oOgmoogmoO`0PogmoO`;o0000GOmoOgl3o`0002;oOgmo00?o0000oooo
ooooool0>Oooool003Wooooo0_l0000PogmoO`?o0000H_moOgl2o`00027oOgmo00?o0000oooooooo
ool0>?ooool003Sooooo00?o0000ogmoOomoOgl07_moOgl2o`0006OoOgmo0_l0000PogmoO`;o0000
>?ooool003Oooooo00?o0000ogmoOomoOgl07OmoOgl2o`0006_oOgmo0ol0000OogmoO`03o`000?oo
oooooooo03Gooooo000eooooo`;o00007OmoOgl3o`00073oOgmo0_l0000NogmoO`03o`000?oooooo
oooo03Cooooo000dooooo`03o`000?moOgooOgmo01_oOgmo0ol0001dogmoO`;o00007OmoOgl2o`00
03Cooooo000cooooo`03o`000?moOgooOgmo01_oOgmo0ol0001gogmoO`03o`000?moOgooOgmo01co
Ogmo00?o0000ooooooooool0<Oooool0037ooooo0_l0000MogmoO`;o0000N_moOgl00ol0003oOgmo
ogmoO`0LogmoO`;o0000<Oooool0033ooooo00?o0000ogmoOomoOgl06omoOgl3o`0007coOgmo0_l0
000NogmoO`03o`000?oooooooooo02kooooo000_ooooo`03o`000?moOgooOgmo01_oOgmo0_l00020
ogmoO`03o`000?moOgooOgmo01coOgmo00?o0000ooooooooool0;Oooool002kooooo00?o0000ogmo
OomoOgl06omoOgl2o`0008;oOgmo0_l0000MogmoO`03o`000?oooooooooo02cooooo000^ooooo`03
o`000?moOgooOgmo01WoOgmo0_l00026ogmoO`03o`000?moOgooOgmo01[oOgmo00?o0000oooooooo
ool0;?ooool002gooooo00?o0000ogmoOomoOgl06OmoOgl00ol0003oOgmoogmoO`27ogmoO`03o`00
0?moOgooOgmo01[oOgmo00?o0000ooooooooool0:oooool002cooooo00?o0000ogmoOomoOgl06Omo
Ogl00ol0003oOgmoogmoO`29ogmoO`;o00006omoOgl00ol0003oooooooooo`0Zooooo`00:oooool0
0ol0003oOgmoogmoO`0HogmoO`;o0000S_moOgl00ol0003oOgmoogmoO`0IogmoO`03o`000?oooooo
oooo02Wooooo000[ooooo`03o`000?moOgooOgmo01OoOgmo00?o0000ogmoOomoOgl0SomoOgl2o`00
01WoOgmo00?o0000ooooooooool0:Oooool002[ooooo00?o0000ogmoOomoOgl05omoOgl00ol0003o
OgmoogmoO`2BogmoO`03o`000?moOgooOgmo01OoOgmo00?o0000ooooooooool0:?ooool002Wooooo
00?o0000ogmoOomoOgl05_moOgl2o`0009KoOgmo00?o0000ogmoOomoOgl05omoOgl00ol0003ooooo
ooooo`0Wooooo`00:Oooool00ol0003oOgmoogmoO`0EogmoO`03o`000?moOgooOgmo09OoOgmo0_l0
000GogmoO`03o`000?oooooooooo02Oooooo000Xooooo`03o`000?moOgooOgmo01GoOgmo00?o0000
ogmoOomoOgl0V_moOgl00ol0003oOgmoogmoO`0EogmoO`03o`000?oooooooooo02Kooooo000Woooo
o`03o`000?moOgooOgmo01CoOgmo0_l0002NogmoO`;o00005_moOgl00ol0003oooooooooo`0Uoooo
o`009_ooool00ol0003oOgmoogmoO`0DogmoO`03o`000?moOgooOgmo0:3oOgmo00?o0000ogmoOomo
Ogl05?moOgl00ol0003oooooooooo`0Tooooo`009_ooool00ol0003oOgmoogmoO`0CogmoO`03o`00
0?moOgooOgmo0:;oOgmo00?o0000ogmoOomoOgl04omoOgl00ol0003oooooooooo`0Tooooo`009Ooo
ool00ol0003oOgmoogmoO`0CogmoO`03o`000?moOgooOgmo0:CoOgmo00?o0000ogmoOomoOgl04omo
Ogl00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oOgmoogmoO`0DogmoO`03o`000?moOgoo
Ogmo0:CoOgmo00?o0000ogmoOomoOgl05?moOgl00ol0003oooooooooo`0Rooooo`008oooool00ol0
003oOgmoogmoO`0DogmoO`03o`000?moOgooOgmo0:KoOgmo00?o0000ogmoOomoOgl05?moOgl00ol0
003oooooooooo`0Qooooo`008oooool00ol0003oOgmoogmoO`0CogmoO`03o`000?moOgooOgmo043o
Ogmo00?o2NX:o`000?moOgl0?omoOgl2o`0002CoOgmo00?o0000ogmoOomoOgl04omoOgl00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oOgmoogmoO`0CogmoO`03o`000?moOgooOgmo047oOgmo
00?o2NX:o`000?moOgl0?omoOgl2o`0002GoOgmo00?o0000ogmoOomoOgl04omoOgl00ol0003ooooo
ooooo`0Pooooo`008Oooool00ol0003oOgmoogmoO`0DogmoO`03o`000?moOgooOgmo047oOgmo00?o
2NX:ogmoOomoOgl0?omoOgl00ol9jP[oOgmoogmoO`0TogmoO`03o`000?moOgooOgmo01CoOgmo00?o
0000ooooooooool07oooool0027ooooo00?o0000ogmoOomoOgl04omoOgl00ol0003oOgmoogmoO`12
ogmoO`03o`WZ2_moOgooOgmo03koOgmo0ol9jPXVogmoO`03o`000?moOgooOgmo01?oOgmo00?o0000
ooooooooool07oooool0023ooooo00?o0000ogmoOomoOgl04omoOgl00ol0003oOgmoogmoO`13ogmo
O`03o`WZ2_moOgooOgmo03koOgmo0ol9jPXWogmoO`03o`000?moOgooOgmo01?oOgmo00?o0000oooo
ooooool07_ooool001oooooo00?o0000ogmoOomoOgl04omoOgl00ol0003oOgmoogmoO`14ogmoO`03
o`WZ2_moOgooOgmo03koOgmo0ol9jPXXogmoO`03o`000?moOgooOgmo01?oOgmo00?o0000oooooooo
ool07Oooool001kooooo00?o0000ogmoOomoOgl05?moOgl00ol0003oOgmoogmoO`14ogmoO`03o`WZ
2_moOgooOgmo03koOgmo0ol9jPXXogmoO`03o`000?moOgooOgmo01CoOgmo00?o0000ooooooooool0
7?ooool001kooooo00?o0000ogmoOomoOgl04omoOgl00ol0003oOgmoogmoO`15ogmoO`03o`WZ2_mo
OgooOgmo03goOgmo1Ol9jPXXogmoO`03o`000?moOgooOgmo01?oOgmo0ol0000Looooo`007Oooool0
0ol0003oOgmoogmoO`0CogmoO`03o`000?moOgooOgmo04KoOgmo00?o2NX:ogmoOomoOgl0?OmoOgl0
1Ol9jP[oOgmoo`WZ2_moOgoo2NX:02WoOgmo00?o0000ogmoOomoOgl04omoOgl01?l0003oOgmoo`00
0?l0000Jooooo`007?ooool00ol0003oOgmoogmoO`0CogmoO`03o`000?moOgooOgmo04OoOgmo00?o
2NX:ogmoOomoOgl0?omoOgl00ol9jP[oOgmoogmoO`0ZogmoO`03o`000?moOgooOgmo01?oOgmo00?o
0000ogmoOomoOgl00_l0000Hooooo`007?ooool00ol0003oOgmoogmoO`0BogmoO`03o`000?moOgoo
Ogmo04OoOgmo00?o2NX:ogmoOomoOgl0?omoOgl00ol9jP[oOgmoogmoO`0/ogmoO`03o`000?moOgoo
Ogmo01;oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`0Eooooo`006oooool00ol0
003oOgmoogmoO`0CogmoO`03o`000?moOgooOgmo04OoOgmo00?o2NX:ogmoOomoOgl0?omoOgl00ol9
jP[oOgmoogmoO`0/ogmoO`03o`000?moOgooOgmo01?oOgmo00?o0000ogmoOomoOgl00_moOgl2o`00
01Gooooo000Jooooo`03o`000?moOgooOgmo01?oOgmo00?o0000ogmoOomoOgl0B?moOgl00ol9jP[o
OgmoogmoO`0oogmoO`03o`WZ2_moOgooOgmo02goOgmo00?o0000ogmoOomoOgl04omoOgl00ol0003o
OgmoogmoO`03ogmoO`;o00004oooool001Wooooo00?o0000ogmoOomoOgl04omoOgl00ol0003oOgmo
ogmoO`19ogmoO`03o`WZ2_moOgooOgmo03ooOgmo00?o2NX:ogmoOomoOgl0;_moOgl00ol0003oOgmo
ogmoO`0CogmoO`03o`000?moOgooOgmo00?oOgmo0_l0000Booooo`006Oooool00ol0003oOgmoogmo
O`0BogmoO`03o`000?moOgooOgmo04[oOgmo00?o2NX:ogmoOomoOgl0?omoOgl00ol9jP[oOgmoogmo
O`0_ogmoO`03o`000?moOgooOgmo01;oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoo`00
000Booooo`006?ooool00ol0003oOgmoogmoO`0CogmoO`03o`000?moOgooOgmo04[oOgmo00?o2NX:
ogmoOomoOgl0?omoOgl00ol9jP[oOgmoogmoO`0_ogmoO`03o`000?moOgooOgmo01?oOgmo00Co0000
ogmoOol0003o00000_moOgl00ol0003oooooooooo`0@ooooo`006?ooool00ol0003oOgmoogmoO`0B
ogmoO`03o`000?moOgooOgmo04SoOgmo0_l000000omoOgoo2NX:ogmoO`10ogmoO`03o`WZ2_moOgoo
Ogmo00;oOgmo00?o2NX:o`000?moOgl0:omoOgl00ol0003oOgmoogmoO`0BogmoO`;o00001?moOgl0
0ol0003oooooooooo`0@ooooo`006?ooool00ol0003oOgmoogmoO`0AogmoO`03o`000?moOgooOgmo
04WoOgmo0_l000000omoOgoo2NX:ogmoO`10ogmoO`03o`WZ2_moOgooOgmo00;oOgmo00?o2NX:o`00
0?moOgl0;?moOgl00ol0003oOgmoogmoO`0AogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000oooo
ooooool04?ooool001Oooooo00?o0000ogmoOomoOgl04OmoOgl00ol0003oOgmoogmoO`1:ogmoO`04
o`WZ2_moOgooOgmoo`WZ2T7oOgmo00?o2NX:ogmoOomoOgl00_moOgl00ol9jP[oOgmoogmoO`0]ogmo
O`03o`000?moOgooOgmo017oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`0@oooo
o`005oooool00ol0003oOgmoogmoO`0AogmoO`03o`000?moOgooOgmo04WoOgmo0ol9jPX00omoOgoo
2NX:ogmoO`10ogmoO`03o`WZ2_moOgooOgmo00;oOgmo00?o2NX:ogmoOomoOgl0;OmoOgl00ol0003o
OgmoogmoO`0AogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool04?ooool001Kooooo
00?o0000ogmoOomoOgl04OmoOgl01?l0003oOgmoo`000?l00019ogmoO`?o2NX:00?oOgmoo`WZ2_mo
Ogl0@?moOgl00ol9jP[oOgmoogmoO`02ogmoO`03o`WZ2_moOgooOgmo02koOgmo00?o0000ogmoOomo
Ogl04OmoOgl01Ol0003oOgmoogmoOomoOgoo000001;ooooo000Fooooo`03o`000?moOgooOgmo013o
Ogmo00?o0000ogmoOomoOgl00_moOgl2o`0004OoOgmo0ol9jPX00omoOgoo2NX:ogmoO`10ogmoO`03
o`WZ2_moOgooOgmo00;oOgmo00?o2NX:ogmoOomoOgl0;omoOgl00ol0003oOgmoogmoO`0@ogmoO`04
o`000?moOgooOgmoo`0001?ooooo000Eooooo`03o`000?moOgooOgmo013oOgmo00?o0000ogmoOomo
Ogl01OmoOgl2o`0004GoOgmo0ol9jPX00omoOgoo2NX:ogmoO`10ogmoO`03o`WZ2_moOgooOgmo00;o
Ogmo00?o2NX:ogmoOomoOgl0<?moOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?moOgoo000001?o
oooo000Eooooo`03o`000?moOgooOgmo013oOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmo
ogmoO`11ogmoO`Ko2NX:@OmoOgl00ol9jP[oOgmoogmoO`02ogmoO`03o`WZ2_moOgooOgmo033oOgmo
00?o0000ogmoOomoOgl04?moOgl00ol0003oOgmoo`00000Cooooo`005Oooool00ol0003oOgmoogmo
O`0?ogmoO`03o`000?moOgooOgmo00WoOgmo0_l00011ogmoO`04o`WZ2_moOgoo2NX:ogmoO`;o2NX:
@OmoOgl00ol9jP[oOgmoogmoO`02ogmoO`03o`WZ2_moOgooOgmo037oOgmo00?o0000ogmoOomoOgl0
3omoOgl00ol0003oOgmoo`00000Cooooo`005?ooool00ol0003oOgmoogmoO`0@ogmoO`03o`000?mo
OgooOgmo00_oOgmo0_l00011ogmoO`04o`WZ2_moOgooOgmoo`WZ2T7oOgmo00?o2NX:ogmoOomoOgl0
0_moOgl00ol9jP[oOgmoogmoO`0aogmoO`03o`000?moOgooOgmo013oOgmo0_l0000Cooooo`005?oo
ool00ol0003oOgmoogmoO`0@ogmoO`03o`000?moOgooOgmo00goOgmo0_l0000nogmoO`05o`WZ2_mo
OgooOgmoogmoOol9jPX0@OmoOgl01Ol9jP[oOgmoogmoOomoOgoo2NX:01;oOgmo0_l0000OogmoO`;o
00004_moOgl2o`0001?ooooo000Cooooo`03o`000?moOgooOgmo013oOgmo00?o0000ogmoOomoOgl0
4?moOgl2o`0003coOgmo00Co2NX:ogmoOomoOgoo2NX:@_moOgl01Ol9jP[oOgmoogmoOomoOgoo2NX:
013oOgmo1?l9jPXNogmoO`04o`000?moOgooOgmoo`0001;oOgmo00?o0000ooooooooool04Oooool0
01?ooooo00?o0000ogmoOomoOgl04?moOgl00ol0003oOgmoogmoO`0BogmoO`;o0000>_moOgl01?l9
jP[oOgmoogmoOol9jPY1ogmoO`03o`WZ2_moOgooOgmo00;oOgmo00?o2NX:ogmoOomoOgl02omoOgl6
o`WZ2P03ogmoOol9jP[o2NX:01[oOgmo0_l00003ogmoO`03o`000?moOgooOgmo013oOgmo00?o0000
ooooooooool04Oooool001;ooooo00?o0000ogmoOomoOgl04?moOgl00ol0003oOgmoogmoO`0Eogmo
O`;o0000>?moOgl01?l9jP[oOgmoogmoOol9jPY1ogmoO`03o`WZ2_moOgooOgmo00;oOgmo00?o2NX:
ogmoOomoOgl02OmoOgl7o`WZ2PCoOgmo0_l9jPXFogmoO`;o00001_moOgl00ol0003oOgmoogmoO`0@
ogmoO`03o`000?oooooooooo013ooooo000Booooo`03o`000?moOgooOgmo013oOgmo00?o0000ogmo
OomoOgl05omoOgl00ol0003oOgmoogmoO`0eogmoO`04o`WZ2_moOgooOgmoo`WZ2T7oOgmo00?o2NX:
ogmoOomoOgl00_moOgl00ol9jP[oOgmoogmoO`0:ogmoO`Go2NX:1omoOgl2o`WZ2Q?oOgmo00?o0000
ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo013ooooo000Boooo
o`03o`000?moOgooOgmo013oOgmo00?o0000ogmoOomoOgl06?moOgl2o`0001OoOgmo0_l0000Logmo
O`04o`WZ2_moOgooOgmoo`WZ2T7oOgmo00?o2NX:ogmoOomoOgl00_moOgl00ol9jP[oOgmoogmoO`09
ogmoO`03o`WZ2_moOgoo2NX:00;o2NX:2_moOgl2o`WZ2PooOgmo0_l00009ogmoO`03o`000?moOgoo
Ogmo013oOgmo00?o0000ooooooooool04?ooool0017ooooo00?o0000ogmoOomoOgl04?moOgl00ol0
003oOgmoogmoO`0KogmoO`;o00004omoOgl4o`WZ2QcoOgmo00Co2NX:ogmoOomoOgoo2NX:@OmoOgl0
0ol9jP[oOgmoogmoO`02ogmoO`03o`WZ2_moOgooOgmo00OoOgmo0_l9jPX2ogmoO`;o2NX:3OmoOgl2
o`WZ2P_oOgmo0_l0000<ogmoO`03o`000?moOgooOgmo013oOgmo00?o0000ooooooooool03oooool0
017ooooo00?o0000ogmoOomoOgl04?moOgl00ol0003oOgmoogmoO`0MogmoO`;o00003OmoOgl6o`WZ
2P;oOgmo0_l9jPXJogmoO`04o`WZ2_moOgooOgmoo`WZ2T7oOgmo00?o2NX:ogmoOomoOgl00_moOgl0
0ol9jP[oOgmoogmoO`06ogmoO`03o`WZ2_moOgooOgmo00;oOgmo00?o2NX:ogmoOomoOgl03_moOgl2
o`WZ2PSoOgmo00?o0000ogmoOomoOgl03?moOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooo
oooo00oooooo000@ooooo`03o`000?moOgooOgmo013oOgmo00?o0000ogmoOomoOgl08?moOgl2o`00
00WoOgmo1ol9jPX5ogmoO`;o2NX:6?moOgl01?l9jP[oOgmoogmoOol9jPY1ogmoO`03o`WZ2_moOgoo
Ogmo00;oOgmo00?o2NX:ogmoOomoOgl01?moOgl2o`WZ2QSoOgmo0_l9jPX4ogmoO`;o00004?moOgl0
0ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo00kooooo000@ooooo`03o`000?moOgooOgmo
013oOgmo00?o0000ogmoOomoOgl08_moOgl2o`0000WoOgmo1?l9jPX8ogmoO`;o2NX:5_moOgl01?l9
jP[oOgmoogmoOol9jPY1ogmoO`03o`WZ2_moOgooOgmo00;oOgmo00?o2NX:ogmoOomoOgl00_moOgl2
o`WZ2QcoOgmo0_l9jPX00omoOgoo0000ogmoO`0AogmoO`03o`000?moOgooOgmo013oOgmo00?o0000
ooooooooool03_ooool000oooooo00?o0000ogmoOomoOgl04OmoOgl00ol0003oOgmoogmoO`0Togmo
O`;o00001_moOgl01?l9jP[oOgmoo`WZ2_l9jPX;ogmoO`03o`WZ2_moOgooOgmo01?oOgmo00Co2NX:
ogmoOomoOgoo2NX:@OmoOgl00ol9jP[oOgmoogmoO`02ogmoO`05o`WZ2_moOgooOgmoogmoOol9jPX0
7omoOgl00ol0003o2NX:ogmoO`0BogmoO`03o`000?moOgooOgmo017oOgmo00?o0000ooooooooool0
3Oooool000oooooo00?o0000ogmoOomoOgl04?moOgl00ol0003oOgmoogmoO`0WogmoO`04o`000?mo
OgooOgmoogmoO`;o2NX:00?oOgmoo`WZ2_l9jPX03OmoOgl2o`WZ2Q?oOgmo00Co2NX:ogmoOomoOgoo
2NX:@OmoOgl00ol9jP[oOgmoogmoO`02ogmoO`04o`WZ2_moOgoo2NX:o`WZ2QkoOgmo0_l00002ogmo
O`;o2NX:4_moOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo00gooooo000?ooooo`03
o`000?moOgooOgmo013oOgmo00?o0000ogmoOomoOgl0:?moOgl00ol0003o2NX:o`WZ2P03ogmoO`03
o`WZ2_moOgooOgmo00koOgmo0_l9jPXAogmoO`04o`WZ2_moOgooOgmoo`WZ2T7oOgmo00?o2NX:ogmo
OomoOgl00_moOgl2o`WZ2QooOgmo00?o0000ogmoOomoOgl01?moOgl2o`WZ2Q3oOgmo00?o0000ogmo
OomoOgl04?moOgl00ol0003oooooooooo`0=ooooo`003_ooool00ol0003oOgmoogmoO`0AogmoO`03
o`000?moOgooOgmo02SoOgmo00Co2NX:ogmoOol0003o00005OmoOgl2o`WZ2PooOgmo00Co2NX:ogmo
OomoOgoo2NX:@OmoOgl01?l9jP[oOgmoogmoOomoOgl2o`WZ2QkoOgmo0_l00009ogmoO`;o2NX:3_mo
Ogl00ol0003oOgmoogmoO`0AogmoO`03o`000?oooooooooo00cooooo000>ooooo`03o`000?moOgoo
Ogmo013oOgmo00?o0000ogmoOomoOgl09omoOgl2o`WZ2PCoOgmo0_l0000EogmoO`;o2NX:3OmoOgl0
1?l9jP[oOgmoogmoOol9jPY1ogmoO`06o`WZ2_moOgoo2NX:o`WZ2_moOgoo2NX:7OmoOgl00ol0003o
OgmoogmoO`0;ogmoO`;o2NX:00?oOgmoo`WZ2_l9jPX02_moOgl00ol0003oOgmoogmoO`0@ogmoO`03
o`000?oooooooooo00cooooo000=ooooo`03o`000?moOgooOgmo017oOgmo00?o0000ogmoOomoOgl0
9_moOgl00ol9jP[oOgmoogmoO`06ogmoO`;o00005OmoOgl2o`WZ2P_oOgmo00Co2NX:ogmoOomoOgoo
2NX:7OmoOgl2o`0002;oOgmo0_l9jPX3ogmoO`03o`WZ2_moOgooOgmo01WoOgmo0_l0000@ogmoO`Co
2NX:2OmoOgl00ol0003oOgmoogmoO`0AogmoO`03o`000?oooooooooo00_ooooo000=ooooo`03o`00
0?moOgooOgmo013oOgmo00?o0000ogmoOomoOgl09OmoOgl2o`WZ2P_oOgmo0_l0000EogmoO`;o2NX:
2OmoOgl01?l9jP[oOgmoogmoOol9jPXLogmoO`;o2NX:00?o0000o`WZ2_moOgl07omoOgl2o`WZ2PCo
Ogmo00?o2NX:ogmoOomoOgl05omoOgl2o`0001?oOgmo1Ol9jPX8ogmoO`03o`000?moOgooOgmo013o
Ogmo00?o0000ooooooooool02oooool000cooooo00?o0000ogmoOomoOgl04OmoOgl00ol0003oOgmo
ogmoO`0SogmoO`;o2NX:3omoOgl2o`0001GoOgmo00?o2NX:ogmoOomoOgl01OmoOgl01Ol9jP[oOgmo
ogmoOomoOgoo2NX:01_oOgmo00Co2NX:ogmoOomoOgooOgmo1Ol9jPXKogmoO`03o`WZ2_moOgoo2NX:
00?oOgmo00?o2NX:ogmoOomoOgl05omoOgl00ol0003oOgmoogmoO`0BogmoO`Oo2NX:1omoOgl00ol0
003oOgmoogmoO`0AogmoO`03o`000?oooooooooo00[ooooo000<ooooo`03o`000?moOgooOgmo017o
Ogmo00?o0000ogmoOomoOgl08_moOgl00ol9jP[oOgmoogmoO`0AogmoO`03o`000?moOgooOgmo01?o
Ogmo0_l9jPX5ogmoO`05o`WZ2_moOgooOgmoogmoOol9jPX06OmoOgl2o`WZ2PGoOgmo1_l9jPXGogmo
O`;o2NX:0_moOgl01Ol9jP[oOgmoogmoOomoOgoo2NX:01OoOgmo0_l0000HogmoO`Go2NX:1_moOgl0
0ol0003oOgmoogmoO`0AogmoO`03o`000?oooooooooo00[ooooo000<ooooo`03o`000?moOgooOgmo
013oOgmo00?o0000ogmoOomoOgl08OmoOgl00ol0003o2NX:ogmoO`0DogmoO`;o00005OmoOgl2o`WZ
2P?oOgmo00Co2NX:ogmoOomoOgoo2NX:6?moOgl2o`WZ2PSoOgmo1?l9jPXFogmoO`;o2NX:1?moOgl0
1Ol9jP[oOgmoogmoOomoOgoo2NX:01GoOgmo0_l0000NogmoO`;o00001_moOgl00ol0003oOgmoogmo
O`0@ogmoO`03o`000?oooooooooo00[ooooo000;ooooo`03o`000?moOgooOgmo017oOgmo00?o0000
ogmoOomoOgl08OmoOgl2o`0001OoOgmo0_l0000EogmoO`;o2NX:00GoOgmoo`WZ2_moOgooOgmoo`WZ
2P0GogmoO`03o`WZ2_moOgooOgmo00WoOgmo0_l9jPX00omoOgoo2NX:ogmoO`0CogmoO`03o`WZ2_mo
OgooOgmo00?oOgmo00?o2NX:ogmoOomoOgl00_moOgl00ol9jP[oOgmoogmoO`0BogmoO`03o`000?mo
OgooOgmo01koOgmo0_l00006ogmoO`03o`000?moOgooOgmo017oOgmo00?o0000ooooooooool02Ooo
ool000_ooooo00?o0000ogmoOomoOgl04?moOgl00ol0003oOgmoogmoO`0mogmoO`;o00005OmoOgl2
o`WZ2P;oOgmo00?o2NX:ogmoOomoOgl04omoOgl2o`WZ2PgoOgmo00?o2NX:ogmoOomoOgl00_l9jPX@
ogmoO`;o2NX:1_moOgl00ol9jP[oOgmoogmoO`02ogmoO`03o`WZ2_moOgooOgmo013oOgmo0_l0000Z
ogmoO`03o`000?moOgooOgmo013oOgmo00?o0000ooooooooool02Oooool000_ooooo00?o0000ogmo
OomoOgl04?moOgl00ol0003oOgmoogmoO`0oogmoO`;o00005?moOgl4o`WZ2Q?oOgmo0_l9jPXDogmo
O`;o2NX:3OmoOgl00ol9jP[oOgmoogmoO`06ogmoO`03o`WZ2_moOgooOgmo00;oOgmo00?o2NX:ogmo
OomoOgl03omoOgl00ol0003oOgmoogmoO`0ZogmoO`03o`000?moOgooOgmo013oOgmo00?o0000oooo
ooooool02Oooool000_ooooo00?o0000ogmoOomoOgl04?moOgl00ol0003oOgmoogmoO`11ogmoO`;o
00004_moOgl00ol9jP[oOgmoogmoO`02o`WZ2Q7oOgmo00?o2NX:ogmoOomoOgl05_moOgl2o`WZ2PWo
Ogmo0_l9jPX9ogmoO`03o`WZ2_moOgooOgmo00;oOgmo00?o2NX:ogmoOomoOgl03OmoOgl2o`0002go
Ogmo00?o0000ogmoOomoOgl04?moOgl00ol0003oooooooooo`09ooooo`002_ooool00ol0003oOgmo
ogmoO`0@ogmoO`03o`000?moOgooOgmo04CoOgmo00?o0000ogmoOomoOgl03omoOgl01_l9jP[oOgmo
ogmoOol9jP[oOgmoo`WZ2PkoOgmo0_l9jPXKogmoO`;o2NX:1OmoOgl2o`WZ2P_oOgmo00?o2NX:ogmo
OomoOgl00_moOgl00ol9jP[oOgmoogmoO`0;ogmoO`;o0000<?moOgl00ol0003oOgmoogmoO`0@ogmo
O`03o`000?oooooooooo00Sooooo000:ooooo`03o`000?moOgooOgmo013oOgmo00?o0000ogmoOomo
Ogl0AOmoOgl2o`0000ooOgmo00Co2NX:ogmoOomoOgoo2NX:0_moOgl2o`WZ2P_oOgmo00?o2NX:ogmo
OomoOgl07OmoOgl2o`WZ2P;oOgmo00?o2NX:ogmoOomoOgl02omoOgl00ol9jP[oOgmoogmoO`02ogmo
O`03o`WZ2_moOgooOgmo00[oOgmo00?o0000ogmoOomoOgl0<?moOgl00ol0003oOgmoogmoO`0@ogmo
O`03o`000?oooooooooo00Sooooo000:ooooo`03o`000?moOgooOgmo013oOgmo00?o0000ogmoOomo
Ogl0AomoOgl2o`0000goOgmo00Co2NX:ogmoOomoOgoo2NX:1?moOgl2o`WZ2POoOgmo0_l9jPXRogmo
O`;o2NX:3_moOgl00ol9jP[oOgmoogmoO`02ogmoO`03o`WZ2_moOgooOgmo00SoOgmo0_l0000cogmo
O`03o`000?moOgooOgmo013oOgmo00?o0000ooooooooool02?ooool000[ooooo00?o0000ogmoOomo
Ogl04?moOgl00ol0003oOgmoogmoO`19ogmoO`;o00002omoOgl01?l9jP[oOgmoogmoOol9jPX6ogmo
O`;o2NX:0omoOgl2o`WZ2R?oOgmo00?o2NX:ogmoOomoOgl00_l9jPX<ogmoO`03o`WZ2_moOgooOgmo
00;oOgmo00?o2NX:ogmoOomoOgl01_moOgl2o`0003GoOgmo00?o0000ogmoOomoOgl04?moOgl00ol0
003oooooooooo`08ooooo`002_ooool00ol0003oOgmoogmoO`0@ogmoO`03o`000?moOgooOgmo04_o
Ogmo0_l00009ogmoO`04o`WZ2_moOgooOgmoo`WZ2PSoOgmo0ol9jPXSogmoO`;o2NX:1OmoOgl00ol9
jP[oOgmoogmoO`09ogmoO`03o`WZ2_moOgooOgmo00;oOgmo00?o2NX:ogmoOomoOgl01OmoOgl00ol0
003oOgmoogmoO`0eogmoO`03o`000?moOgooOgmo013oOgmo00?o0000ooooooooool02?ooool000[o
oooo00?o0000ogmoOomoOgl03omoOgl2o`0004ooOgmo0_l00007ogmoO`04o`WZ2_moOgooOgmoo`WZ
2PSoOgmo1?l9jPXPogmoO`;o2NX:2?moOgl2o`WZ2PWoOgmo00?o2NX:ogmoOomoOgl00_moOgl00ol9
jP[oOgmoogmoO`03ogmoO`;o0000>OmoOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?oooooooooo
00Sooooo000:ooooo`03o`000?moOgooOgmo00ooOgmo00?o0000ogmoOomoOgl0D?moOgl2o`0000Go
Ogmo00Co2NX:ogmoOomoOgoo2NX:1omoOgl00ol9jP[oOgmoogmoO`02ogmoO`;o2NX:7OmoOgl00ol9
jP[oOgmoogmoO`0:ogmoO`;o2NX:1omoOgl00ol9jP[oOgmoogmoO`02ogmoO`03o`WZ2_moOgooOgmo
00;oOgmo00?o0000ogmoOomoOgl0>OmoOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?moOgooOgmo013oOgmo00?o0000ogmoOomoOgl0D_moOgl00ol0003o
OgmoogmoO`02ogmoO`04o`WZ2_moOgooOgmoo`WZ2PGoOgmo0_l9jPX7ogmoO`03o`WZ2_moOgooOgmo
01SoOgmo0_l9jPX?ogmoO`;o2NX:1OmoOgl00ol9jP[oOgmoogmoO`02ogmoO`03o`WZ2_moOgooOgmo
00;o0000??moOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo00Oooooo0009ooooo`03
o`000?moOgooOgmo013oOgmo00?o0000ogmoOomoOgl0DomoOgl2o`0000;oOgmo00Co2NX:ogmoOomo
Ogoo2NX:0omoOgl2o`WZ2P[oOgmo0_l9jPXGogmoO`03o`WZ2_moOgooOgmo017oOgmo0_l9jPX3ogmo
O`03o`WZ2_moOgooOgmo00;oOgmo00?o2NX:o`000?l00000?_moOgl00ol0003oOgmoogmoO`0@ogmo
O`03o`000?oooooooooo00Oooooo0009ooooo`03o`000?moOgooOgmo013oOgmo00?o0000ogmoOomo
Ogl0EOmoOgl2o`000004o`WZ2_moOgooOgmoo`WZ2P;oOgmo00?o2NX:ogmoOomoOgl03?moOgl2o`WZ
2Q?oOgmo0_l9jPXFogmoO`;o2NX:00?oOgmoo`WZ2_moOgl00omoOgl00ol9jP[oOgmoogmoO`0nogmo
O`03o`000?moOgooOgmo013oOgmo00?o0000ooooooooool01oooool000Wooooo00?o0000ogmoOomo
Ogl04?moOgl00ol0003oOgmoogmoO`1FogmoO`04o`WZ2_l0003o0000ogmoO`?o2NX:4OmoOgl2o`WZ
2PooOgmo0_l9jPXJogmoO`;o2NX:0_moOgl00ol0003o2NX:ogmoO`10ogmoO`03o`000?moOgooOgmo
013oOgmo00?o0000ooooooooool01oooool000Wooooo00?o0000ogmoOomoOgl04?moOgl00ol0003o
OgmoogmoO`1FogmoO`03o`WZ2_moOgooOgmo00;o2NX:5OmoOgl2o`WZ2PcoOgmo00?o2NX:ogmoOomo
Ogl06omoOgl3o`WZ2P03ogmoOol9jP[oOgmo043oOgmo00?o0000ogmoOomoOgl04?moOgl00ol0003o
ooooooooo`07ooooo`002Oooool00ol0003oOgmoogmoO`0@ogmoO`03o`000?moOgooOgmo05KoOgmo
00Go2NX:ogmoOol9jP[o2NX:ogmoO`02o`0001GoOgmo0_l9jPX8ogmoO`;o2NX:7_moOgl00ol9jP[o
0000ogmoO`02o`WZ2T7oOgmo00?o0000ogmoOomoOgl04?moOgl00ol0003oooooooooo`07ooooo`00
2Oooool00ol0003oOgmoogmoO`0?ogmoO`;o0000F?moOgl2o`WZ2P03ogmoOol9jP[oOgmo00;oOgmo
0_l0000EogmoO`;o2NX:1OmoOgl00ol9jP[oOgmoogmoO`0LogmoO`03o`000?l9jP[oOgmo00?oOgmo
0_l9jPY1ogmoO`03o`000?moOgooOgmo00ooOgmo00?o0000ooooooooool01oooool000Sooooo00?o
0000ogmoOomoOgl04?moOgl2o`0005OoOgmo0_l9jPX2ogmoO`03o`WZ2_moOgooOgmo00?oOgmo00?o
0000ogmoOomoOgl05?moOgl00ol9jP[oOgmoogmoO`02o`WZ2QkoOgmo00?o0000ogmoOol9jPX01?mo
Ogl01?l9jP[oOgmoo`WZ2_l9jPXoogmoO`03o`000?moOgooOgmo013oOgmo00?o0000ooooooooool0
1_ooool000Sooooo00?o0000ogmoOomoOgl04?moOgl2o`0005GoOgmo0_l9jPX01OmoOgoo2NX:ogmo
OomoOgoo2NX:00KoOgmo0_l0000EogmoO`;o2NX:7_moOgl2o`0000;oOgmo00?o2NX:ogmoOomoOgl0
0_moOgl01?l9jP[oOgmoogmoOomoOgl2o`WZ2SgoOgmo00?o0000ogmoOomoOgl04?moOgl00ol0003o
ooooooooo`06ooooo`002?ooool00ol0003oOgmoogmoO`0@ogmoO`;o0000DomoOgl2o`WZ2P?oOgmo
00Co2NX:ogmoOomoOgoo2NX:2?moOgl2o`0001;oOgmo00?o2NX:ogmoOomoOgl00_l9jPXJogmoO`;o
00001?moOgl00ol9jP[oOgmoogmoO`02ogmoO`03o`WZ2_moOgooOgmo00?oOgmo0_l9jPXkogmoO`03
o`000?moOgooOgmo013oOgmo00?o0000ooooooooool01_ooool000Sooooo00?o0000ogmoOomoOgl0
4?moOgl2o`0005;oOgmo00?o2NX:ogmoOomoOgl00omoOgl01?l9jP[oOgmoogmoOol9jPX:ogmoO`;o
00003_moOgl2o`WZ2PGoOgmo0_l9jPXGogmoO`03o`000?moOgooOgmo00CoOgmo00?o2NX:ogmoOomo
Ogl00_moOgl00ol9jP[oOgmoogmoO`05ogmoO`;o2NX:>OmoOgl00ol0003oOgmoogmoO`0@ogmoO`03
o`000?oooooooooo00Kooooo0008ooooo`03o`000?moOgooOgmo013oOgmo0_l0001@ogmoO`;o2NX:
1_moOgl01?l9jP[oOgmoogmoOol9jPX<ogmoO`;o00002omoOgl00ol9jP[oOgmoogmoO`07ogmoO`;o
2NX:4omoOgl2o`0000OoOgmo00?o2NX:ogmoOomoOgl00_moOgl00ol9jP[oOgmoogmoO`07ogmoO`;o
2NX:=omoOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo00Kooooo0008ooooo`03o`00
0?moOgooOgmo013oOgmo0_l0001?ogmoO`03o`WZ2_moOgooOgmo00KoOgmo00Co2NX:ogmoOomoOgoo
2NX:3_moOgl2o`0000OoOgmo0_l9jPX<ogmoO`;o2NX:4?moOgl00ol0003oOgmoogmoO`07ogmoO`03
o`WZ2_moOgooOgmo00;oOgmo00?o2NX:ogmoOomoOgl02OmoOgl00ol9jP[oOgmoogmoO`0dogmoO`03
o`000?moOgooOgmo013oOgmo00?o0000ooooooooool01_ooool000Sooooo00?o0000ogmoOomoOgl0
3omoOgl00ol0003oooooo`00001=ogmoO`;o2NX:2OmoOgl01?l9jP[oOgmoogmoOol9jPX@ogmoO`;o
00000omoOgl2o`WZ2Q3oOgmo0_l9jPX<ogmoO`;o00002_moOgl00ol9jP[oOgmoogmoO`02ogmoO`03
o`WZ2_moOgooOgmo00[oOgmo0_l9jPXeogmoO`03o`000?moOgooOgmo00ooOgmo00?o0000oooooooo
ool01_ooool000Oooooo00?o0000ogmoOomoOgl04?moOgl00ol0003oooooo`00001;ogmoO`;o2NX:
2omoOgl01?l9jP[oOgmoogmoOol9jPXBogmoO`03o`000?moOgoo2NX:01CoOgmo00?o2NX:ogmoOomo
Ogl01omoOgl2o`0000coOgmo00?o2NX:ogmoOomoOgl00_moOgl00ol9jP[oOgmoogmoO`0<ogmoO`;o
2NX:<omoOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo00Gooooo0007ooooo`03o`00
0?moOgooOgmo013oOgmo00?o0000ooooool00000B_moOgl00ol9jP[oOgmoogmoO`0;ogmoO`04o`WZ
2_moOgooOgmoo`WZ2Q;oOgmo0_l9jPX00ol0003oOgmoogmoO`0CogmoO`;o2NX:1_moOgl00ol0003o
OgmoogmoO`0<ogmoO`03o`WZ2_moOgooOgmo00;oOgmo00?o2NX:ogmoOomoOgl03_moOgl2o`WZ2S7o
Ogmo00?o0000ogmoOomoOgl04?moOgl00ol0003oooooooooo`05ooooo`001oooool00ol0003oOgmo
ogmoO`0@ogmoO`;o0000BOmoOgl2o`WZ2PkoOgmo00Co2NX:ogmoOomoOgoo2NX:4OmoOgl01?l9jP[o
OgmoogmoOomoOgl2o`0001GoOgmo0_l9jPX2ogmoO`;o00003omoOgl00ol9jP[oOgmoogmoO`02ogmo
O`03o`WZ2_moOgooOgmo013oOgmo0_l9jPX_ogmoO`03o`000?moOgooOgmo013oOgmo00?o0000oooo
ooooool01Oooool000Oooooo00?o0000ogmoOomoOgl04?moOgl2o`0004OoOgmo0_l9jPX@ogmoO`04
o`WZ2_moOgooOgmoo`WZ2PooOgmo0_l9jPX6ogmoO`;o00005OmoOgl2o`WZ2Q7oOgmo00?o2NX:ogmo
OomoOgl00_moOgl00ol9jP[oOgmoogmoO`0BogmoO`;o2NX:;OmoOgl00ol0003oOgmoogmoO`0@ogmo
O`03o`000?oooooooooo00Gooooo0007ooooo`03o`000?moOgooOgmo013oOgmo0_l00013ogmoO`04
o`WZ2_moOgooOgmoo`WZ2Q;oOgmo00Co2NX:ogmoOomoOgoo2NX:3OmoOgl2o`WZ2P[oOgmo0_l0000B
ogmoO`;o000000?oOgmoo`WZ2_l9jPX03omoOgl00ol9jP[oOgmoogmoO`02ogmoO`03o`WZ2_moOgoo
Ogmo01CoOgmo0_l9jPX[ogmoO`03o`000?moOgooOgmo013oOgmo00?o0000ooooooooool01Oooool0
00Oooooo00?o0000ogmoOomoOgl04?moOgl2o`0004;oOgmo1?l9jPXCogmoO`04o`WZ2_moOgooOgmo
o`WZ2PcoOgmo00?o2NX:ogmoOomoOgl03?moOgl2o`0000koOgmo0_l00005ogmoO`;o2NX:3OmoOgl0
0ol9jP[oOgmoogmoO`02ogmoO`03o`WZ2_moOgooOgmo01KoOgmo0_l9jPXYogmoO`03o`000?moOgoo
Ogmo013oOgmo00?o0000ooooooooool01Oooool000Oooooo00?o0000ogmoOomoOgl04?moOgl2o`00
047oOgmo0ol9jPXEogmoO`04o`WZ2_moOgooOgmoo`WZ2P[oOgmo0_l9jPXAogmoO`;o00002omoOgl0
0ol0003oOgmoogmoO`07ogmoO`;o2NX:2omoOgl00ol9jP[oOgmoogmoO`02ogmoO`03o`WZ2_moOgoo
Ogmo01SoOgmo00?o2NX:ogmoOomoOgl09_moOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooo
oooo00Gooooo0006ooooo`03o`000?moOgooOgmo013oOgmo00?o0000ooooool00000@?moOgl5o`WZ
2Q?oOgmo00Go2NX:ogmoOomoOgooOgmoo`WZ2P09ogmoO`03o`WZ2_moOgooOgmo01?oOgmo00?o0000
ogmoOomoOgl01_moOgl2o`0000coOgmo00?o2NX:ogmoOomoOgl02?moOgl01Ol9jP[oOgmoogmoOomo
Ogoo2NX:01coOgmo0_l9jPXWogmoO`03o`000?moOgooOgmo013oOgmo00?o0000ooooooooool01?oo
ool000Kooooo00?o0000ogmoOomoOgl04?moOgl00ol0003oooooo`00000oogmoO`Oo2NX:4_moOgl0
1?l9jP[oOgmoogmoOol9jPX8ogmoO`;o2NX:5omoOgl2o`0000CoOgmo0_l0000?ogmoO`;o2NX:2?mo
Ogl01Ol9jP[oOgmoogmoOomoOgoo2NX:01koOgmo0_l9jPXUogmoO`03o`000?moOgooOgmo013oOgmo
00?o0000ooooooooool01?ooool000Kooooo00?o0000ogmoOomoOgl04?moOgl00ol0003oooooo`00
000nogmoO`Go2NX:5OmoOgl01?l9jP[oOgmoogmoOol9jPX6ogmoO`;o2NX:6omoOgl2o`000003ogmo
Ool0003oOgmo01;oOgmo0_l9jPX6ogmoO`05o`WZ2_moOgooOgmoogmoOol9jPX08?moOgl2o`WZ2R?o
Ogmo00?o0000ogmoOomoOgl04?moOgl00ol0003oooooooooo`04ooooo`001_ooool00ol0003oOgmo
ogmoO`0@ogmoO`03o`000?oooooo000003goOgmo0_l0000IogmoO`04o`WZ2_moOgooOgmoo`WZ2PGo
Ogmo00?o2NX:ogmoOomoOgl07OmoOgl00ol0003oOgmoogmoO`0DogmoO`;o2NX:0omoOgl00ol9jP[o
OgmoogmoO`02ogmoO`03o`WZ2_moOgooOgmo023oOgmo00?o2NX:o`000?moOgl08?moOgl00ol0003o
OgmoogmoO`0@ogmoO`03o`000?oooooooooo00Cooooo0006ooooo`03o`000?moOgooOgmo013oOgmo
00?o0000ooooool00000?OmoOgl2o`0001WoOgmo00Co2NX:ogmoOomoOgoo2NX:0omoOgl2o`WZ2R3o
Ogmo00?o0000ogmoOomoOgl05_moOgl2o`WZ2P03ogmoOol9jP[oOgmo00?oOgmo00?o2NX:ogmoOomo
Ogl08?moOgl2o`00027oOgmo00?o0000ogmoOomoOgl04?moOgl00ol0003oooooooooo`04ooooo`00
1_ooool00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooo000005SoOgmo00Co2NX:ogmoOomoOgoo
2NX:0_moOgl00ol9jP[oOgmoogmoO`0PogmoO`03o`000?moOgooOgmo01SoOgmo0_l9jPX4ogmoO`03
o`WZ2_moOgooOgmo04?oOgmo00?o0000ogmoOomoOgl04?moOgl00ol0003oooooooooo`04ooooo`00
1_ooool00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooo000005SoOgmo00?o2NX:ogmoOomoOgl0
0ol9jPXSogmoO`03o`000?moOgooOgmo01WoOgmo0ol9jPX2ogmoO`03o`WZ2_moOgooOgmo04?oOgmo
00?o0000ogmoOomoOgl04?moOgl00ol0003oooooooooo`04ooooo`001oooool00ol0003oOgmoogmo
O`0?ogmoO`03o`000?oooooo000005SoOgmo00Co2NX:ogmoOol9jP[o2NX:9OmoOgl00ol0003oOgmo
ogmoO`0IogmoO`06o`WZ2_moOgooOgmoo`WZ2_moOgoo2NX:AOmoOgl00ol0003oOgmoogmoO`0?ogmo
O`03o`000?oooooooooo00Gooooo0007ooooo`03o`000?moOgooOgmo013oOgmo0_l0001HogmoO`;o
2NX:00?oOgmoo`WZ2_moOgl09?moOgl00ol0003oOgmoogmoO`0IogmoO`04o`WZ2_moOgooOgmoogmo
O`;o2NX:A?moOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo00Gooooo0007ooooo`03
o`000?moOgooOgmo013oOgmo0_l0001GogmoO`;o2NX:0_moOgl00ol9jP[oOgmoogmoO`0SogmoO`03
o`000?moOgooOgmo01WoOgmo00?o2NX:ogmoOomoOgl00_moOgl3o`WZ2T;oOgmo00?o0000ogmoOomo
Ogl04?moOgl00ol0003oooooooooo`05ooooo`001oooool00ol0003oOgmoogmoO`0@ogmoO`;o0000
E_moOgl00ol9jP[oOgmoo`WZ2P02ogmoO`03o`WZ2_moOgooOgmo02?oOgmo00?o0000ogmoOomoOgl0
6OmoOgl00ol9jP[oOgmoogmoO`02ogmoO`03o`WZ2_moOgooOgmo00;o2NX:@?moOgl00ol0003oOgmo
ogmoO`0@ogmoO`03o`000?oooooooooo00Gooooo0007ooooo`03o`000?moOgooOgmo013oOgmo0_l0
001DogmoO`;o2NX:0_moOgl01?l9jP[oOgmoogmoOol9jPXUogmoO`03o`000?moOgooOgmo01WoOgmo
00?o2NX:ogmoOomoOgl00_moOgl00ol9jP[oOgmoogmoO`02ogmoO`;o2NX:?_moOgl00ol0003oOgmo
ogmoO`0@ogmoO`03o`000?oooooooooo00Gooooo0007ooooo`03o`000?moOgooOgmo013oOgmo00?o
0000ogmoOomoOgl0DOmoOgl2o`WZ2PCoOgmo00Co2NX:ogmoOomoOgoo2NX:9OmoOgl00ol0003oOgmo
ogmoO`0IogmoO`03o`WZ2_moOgooOgmo00;oOgmo00?o2NX:ogmoOomoOgl01?moOgl2o`WZ2ScoOgmo
00?o0000ogmoOomoOgl04?moOgl00ol0003oooooooooo`05ooooo`001oooool00ol0003oOgmoogmo
O`0@ogmoO`03o`000?moOgooOgmo053oOgmo00?o2NX:ogmoOomoOgl01?moOgl01?l9jP[oOgmoogmo
Ool9jPXTogmoO`03o`000?moOgooOgmo01[oOgmo00?o2NX:ogmoOomoOgl00_moOgl00ol9jP[oOgmo
ogmoO`06ogmoO`;o2NX:>_moOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo00Gooooo
0008ooooo`03o`000?moOgooOgmo00ooOgmo00?o0000ogmoOomoOgl0C_moOgl2o`WZ2POoOgmo00Co
2NX:ogmoOomoOgoo2NX:9?moOgl00ol0003oOgmoogmoO`0JogmoO`03o`WZ2_moOgooOgmo00;oOgmo
00?o2NX:ogmoOomoOgl02?moOgl00ol9jP[oOgmoogmoO`0gogmoO`03o`000?moOgooOgmo00ooOgmo
00?o0000ooooooooool01_ooool000Sooooo00?o0000ogmoOomoOgl03omoOgl00ol0003oOgmoogmo
O`1=ogmoO`03o`WZ2_moOgooOgmo00OoOgmo00Co2NX:ogmoOomoOgoo2NX:9?moOgl00ol0003oOgmo
ogmoO`0JogmoO`03o`WZ2_moOgooOgmo00;oOgmo00?o2NX:ogmoOomoOgl02OmoOgl2o`WZ2SOoOgmo
00?o0000ogmoOomoOgl03omoOgl00ol0003oooooooooo`06ooooo`002?ooool00ol0003oOgmoogmo
O`0@ogmoO`03o`000?moOgooOgmo04[oOgmo0_l9jPX:ogmoO`04o`WZ2_moOgooOgmoo`WZ2RCoOgmo
00?o0000ogmoOomoOgl06_moOgl00ol9jP[oOgmoogmoO`02ogmoO`03o`WZ2_moOgooOgmo00_oOgmo
0_l9jPXdogmoO`03o`000?moOgooOgmo013oOgmo00?o0000ooooooooool01_ooool000Sooooo00?o
0000ogmoOomoOgl04?moOgl00ol0003oOgmoogmoO`18ogmoO`;o2NX:2omoOgl01Ol9jP[oOgmoogmo
OomoOgoo2NX:02CoOgmo00?o0000ogmoOomoOgl06_moOgl01ol9jP[oOgmoo`WZ2_moOgoo2NX:ogmo
Ool9jPX03_moOgl2o`WZ2S;oOgmo00?o0000ogmoOomoOgl04?moOgl00ol0003oooooooooo`06oooo
o`002?ooool00ol0003oOgmoogmoO`0@ogmoO`03o`000?moOgooOgmo04OoOgmo00?o2NX:ogmoOomo
Ogl02omoOgl01Ol9jP[oOgmoogmoOomoOgoo2NX:02CoOgmo00?o0000ogmoOomoOgl06_moOgl00ol9
jP[oOgmoo`WZ2P04o`WZ2Q3oOgmo0_l9jPX`ogmoO`03o`000?moOgooOgmo013oOgmo00?o0000oooo
ooooool01_ooool000Sooooo00?o0000ogmoOomoOgl04?moOgl00ol0003oOgmoogmoO`15ogmoO`;o
2NX:3_moOgl01?l9jP[oOgmoogmoOol9jPXUogmoO`03o`000?moOgooOgmo01[oOgmo00?o2NX:ogmo
Ool9jPX01?l9jPXBogmoO`;o2NX:;_moOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo
00Kooooo0008ooooo`03o`000?moOgooOgmo013oOgmo00?o0000ogmoOomoOgl0A?moOgl00ol9jP[o
OgmoogmoO`0>ogmoO`04o`WZ2_moOgooOgmoo`WZ2RGoOgmo00?o0000ogmoOomoOgl06_moOgl00ol9
jP[oOgmoogmoO`03o`WZ2QGoOgmo0_l9jPX/ogmoO`03o`000?moOgooOgmo013oOgmo00?o0000oooo
ooooool01_ooool000Wooooo00?o0000ogmoOomoOgl03omoOgl00ol0003oOgmoogmoO`12ogmoO`;o
2NX:4OmoOgl01?l9jP[oOgmoogmoOol9jPXUogmoO`03o`000?moOgooOgmo01WoOgmo00Co2NX:ogmo
OomoOgooOgmo0ol9jPXGogmoO`03o`WZ2_moOgooOgmo02WoOgmo00?o0000ogmoOomoOgl03omoOgl0
0ol0003oooooooooo`07ooooo`002Oooool00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgooOgmo
043oOgmo0_l9jPXCogmoO`04o`WZ2_moOgooOgmoo`WZ2RGoOgmo00?o0000ogmoOomoOgl06OmoOgl0
1?l9jP[oOgmoogmoOomoOgl3o`WZ2QSoOgmo0_l9jPXYogmoO`03o`000?moOgooOgmo00ooOgmo00?o
0000ooooooooool01oooool000Wooooo00?o0000ogmoOomoOgl04?moOgl00ol0003oOgmoogmoO`0n
ogmoO`03o`WZ2_moOgooOgmo01?oOgmo00Co2NX:ogmoOomoOgoo2NX:9OmoOgl00ol0003oOgmoogmo
O`0IogmoO`04o`WZ2_moOgooOgmoogmoO`?o2NX:6_moOgl2o`WZ2RKoOgmo00?o0000ogmoOomoOgl0
4?moOgl00ol0003oooooooooo`07ooooo`002Oooool00ol0003oOgmoogmoO`0@ogmoO`03o`000?mo
OgooOgmo03coOgmo0_l9jPXEogmoO`05o`000?l9jP[oOgmoogmoOol9jPX09OmoOgl00ol0003oOgmo
ogmoO`0IogmoO`03o`WZ2_moOgooOgmo00;oOgmo00?o2NX:ogmoOomoOgl06omoOgl2o`WZ2RCoOgmo
00?o0000ogmoOomoOgl04?moOgl00ol0003oooooooooo`07ooooo`002Oooool00ol0003oOgmoogmo
O`0@ogmoO`03o`000?moOgooOgmo03_oOgmo00?o2NX:ogmoOomoOgl05OmoOgl00ol0003o2NX:o`WZ
2P02o`WZ2RGoOgmo00?o0000ogmoOomoOgl06OmoOgl01?l9jP[oOgmoogmoOomoOgl2o`WZ2QooOgmo
0_l9jPXRogmoO`03o`000?moOgooOgmo013oOgmo00?o0000ooooooooool01oooool000Wooooo00?o
0000ogmoOomoOgl04?moOgl00ol0003oOgmoogmoO`0iogmoO`;o2NX:6_moOgl6o`WZ2R;oOgmo00?o
0000ogmoOomoOgl06OmoOgl01?l9jP[oOgmoogmoOol9jPX2o`00027oOgmo0_l9jPXPogmoO`03o`00
0?moOgooOgmo013oOgmo00?o0000ooooooooool01oooool000Wooooo00?o0000ogmoOomoOgl04?mo
Ogl00ol0003oOgmoogmoO`0gogmoO`;o2NX:7OmoOgl7o`WZ2R3oOgmo00?o0000ogmoOomoOgl06Omo
Ogl3o`WZ2RKoOgmo0_l9jPXNogmoO`03o`000?moOgooOgmo013oOgmo00?o0000ooooooooool01ooo
ool000[ooooo00?o0000ogmoOomoOgl03omoOgl00ol0003oOgmoogmoO`0fogmoO`03o`WZ2_moOgoo
Ogmo01koOgmo1?l9jPXRogmoO`03o`000?moOgooOgmo01SoOgmo0_l9jPXZogmoO`03o`WZ2_moOgoo
Ogmo01_oOgmo00?o0000ogmoOomoOgl03omoOgl00ol0003oooooooooo`08ooooo`002_ooool00ol0
003oOgmoogmoO`0?ogmoO`03o`000?moOgooOgmo03CoOgmo0_l9jPXQogmoO`?o2NX:00?oOgmoo`WZ
2_l9jPX08?moOgl00ol0003oOgmoogmoO`0GogmoO`03o`WZ2_moOgoo2NX:02_oOgmo0_l9jPXKogmo
O`03o`000?moOgooOgmo00ooOgmo00?o0000ooooooooool02?ooool000[ooooo00?o0000ogmoOomo
Ogl03omoOgl00ol0003oOgmoogmoO`0cogmoO`03o`WZ2_moOgooOgmo027oOgmo00Co2NX:ogmoOol9
jP[o2NX:0_moOgl2o`WZ2QgoOgmo00?o0000ogmoOomoOgl05_moOgl2o`WZ2P;oOgmo00?o2NX:ogmo
OomoOgl0:omoOgl2o`WZ2QWoOgmo00?o0000ogmoOomoOgl03omoOgl00ol0003oooooooooo`08oooo
o`002_ooool00ol0003oOgmoogmoO`0@ogmoO`03o`000?moOgooOgmo033oOgmo0_l9jPXTogmoO`04
o`WZ2_moOgooOgmoo`WZ2PCoOgmo0_l9jPXKogmoO`03o`000?moOgooOgmo01GoOgmo00?o2NX:ogmo
OomoOgl00_moOgl00ol9jP[oOgmoogmoO`0]ogmoO`;o2NX:5_moOgl00ol0003oOgmoogmoO`0@ogmo
O`03o`000?oooooooooo00Sooooo000:ooooo`03o`000?moOgooOgmo013oOgmo00?o0000ogmoOomo
Ogl0;_moOgl2o`WZ2RKoOgmo00?o2NX:ogmoOomoOgl01omoOgl2o`WZ2QWoOgmo00?o0000ogmoOomo
Ogl04omoOgl2o`WZ2PGoOgmo00?o2NX:ogmoOomoOgl0;omoOgl2o`WZ2QCoOgmo00?o0000ogmoOomo
Ogl04?moOgl00ol0003oooooooooo`08ooooo`002_ooool00ol0003oOgmoogmoO`0@ogmoO`03o`00
0?moOgooOgmo02goOgmo00?o2NX:ogmoOomoOgl09_moOgl00ol9jP[oOgmoogmoO`09ogmoO`;o2NX:
5omoOgl00ol0003oOgmoogmoO`0AogmoO`;o2NX:1omoOgl00ol9jP[oOgmoogmoO`0aogmoO`;o2NX:
0_moOgl2o`WZ2PkoOgmo00?o0000ogmoOomoOgl04?moOgl00ol0003oooooooooo`08ooooo`002_oo
ool00ol0003oOgmoogmoO`0@ogmoO`03o`000?moOgooOgmo02_oOgmo0_l9jPXYogmoO`03o`WZ2_mo
OgooOgmo00_oOgmo00?o2NX:ogmoOomoOgl05?moOgl00ol0003oOgmoogmoO`0@ogmoO`03o`WZ2_mo
OgooOgmo00OoOgmo00?o2NX:ogmoOomoOgl0<omoOgl5o`WZ2PgoOgmo00?o0000ogmoOomoOgl04?mo
Ogl00ol0003oooooooooo`08ooooo`002oooool00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo
Ogmo02[oOgmo00?o2NX:ogmoOomoOgl0:OmoOgl00ol9jP[oOgmoogmoO`0<ogmoO`;o2NX:5?moOgl0
0ol0003oOgmoogmoO`0>ogmoO`;o2NX:2_moOgl00ol9jP[oOgmoogmoO`0eogmoO`Co2NX:3?moOgl0
0ol0003oOgmoogmoO`0?ogmoO`03o`000?oooooooooo00Wooooo000;ooooo`03o`000?moOgooOgmo
013oOgmo00?o0000ogmoOomoOgl09omoOgl2o`WZ2RWoOgmo00Go2NX:ogmoOol9jP[oOgmoo`WZ2P0?
ogmoO`;o2NX:4_moOgl00ol0003oOgmoogmoO`0=ogmoO`03o`WZ2_moOgooOgmo00[oOgmo00?o2NX:
ogmoOomoOgl0=OmoOgl5o`WZ2P[oOgmo00?o0000ogmoOomoOgl04?moOgl00ol0003oooooooooo`09
ooooo`002oooool00ol0003oOgmoogmoO`0@ogmoO`03o`000?moOgooOgmo02GoOgmo0_l9jPX[ogmo
O`Go2NX:4OmoOgl2o`WZ2Q3oOgmo00?o0000ogmoOomoOgl02omoOgl2o`WZ2PgoOgmo00?o2NX:ogmo
OomoOgl0=?moOgl7o`WZ2PWoOgmo00?o0000ogmoOomoOgl04?moOgl00ol0003oooooooooo`09oooo
o`002oooool00ol0003oOgmoogmoO`0@ogmoO`03o`000?moOgooOgmo02;oOgmo0_l000000ol9jP[o
OgmoogmoO`0[ogmoO`Go2NX:4omoOgl2o`WZ2PkoOgmo00?o0000ogmoOomoOgl02OmoOgl2o`WZ2Poo
Ogmo00?o2NX:ogmoOomoOgl0=omoOgl4o`WZ2P;o00001omoOgl00ol0003oOgmoogmoO`0@ogmoO`03
o`000?oooooooooo00Wooooo000;ooooo`03o`000?moOgooOgmo017oOgmo00?o0000ogmoOomoOgl0
8OmoOgl00ol0003o2NX:ogmoO`0^ogmoO`?o2NX:5_moOgl2o`WZ2PcoOgmo00?o0000ogmoOomoOgl0
2?moOgl00ol9jP[oOgmoogmoO`0>ogmoO`03o`WZ2_moOgooOgmo03coOgmo0_l00006ogmoO`03o`00
0?moOgooOgmo017oOgmo00?o0000ooooooooool02Oooool000cooooo00?o0000ogmoOomoOgl04?mo
Ogl00ol0003oOgmoogmoO`1BogmoO`?o2NX:6?moOgl00ol9jP[oOgmoogmoO`09ogmoO`03o`000?mo
OgooOgmo00KoOgmo0_l9jPXAogmoO`03o`WZ2_moOgooOgmo04CoOgmo00?o0000ogmoOomoOgl04?mo
Ogl00ol0003oooooooooo`0:ooooo`003?ooool00ol0003oOgmoogmoO`0AogmoO`03o`000?moOgoo
Ogmo057oOgmo0ol9jPXIogmoO`;o2NX:2OmoOgl00ol0003oOgmoogmoO`05ogmoO`03o`WZ2_moOgoo
Ogmo017oOgmo00?o2NX:ogmoOomoOgl0@omoOgl00ol0003oOgmoogmoO`0AogmoO`03o`000?oooooo
oooo00[ooooo000<ooooo`03o`000?moOgooOgmo017oOgmo00?o0000ogmoOomoOgl0DOmoOgl3o`WZ
2Q_oOgmo0_l9jPX7ogmoO`03o`000?moOgooOgmo00?oOgmo0_l9jPXDogmoO`03o`WZ2_moOgooOgmo
04?oOgmo00?o0000ogmoOomoOgl04OmoOgl00ol0003oooooooooo`0:ooooo`003Oooool00ol0003o
OgmoogmoO`0@ogmoO`03o`000?moOgooOgmo057oOgmo0_l0000NogmoO`;o2NX:1OmoOgl01?l0003o
OgmoogmoOomoOgl2o`WZ2QKoOgmo00?o2NX:ogmoOomoOgl0@omoOgl00ol0003oOgmoogmoO`0@ogmo
O`03o`000?oooooooooo00_ooooo000=ooooo`03o`000?moOgooOgmo017oOgmo00?o0000ogmoOomo
Ogl0D?moOgl00ol0003o2NX:o`WZ2P0OogmoO`;o2NX:0omoOgl01?l0003oOgmoogmoOol9jPXHogmo
O`03o`WZ2_moOgooOgmo04;oOgmo00?o0000ogmoOomoOgl04OmoOgl00ol0003oooooooooo`0;oooo
o`003_ooool00ol0003oOgmoogmoO`0@ogmoO`03o`000?moOgooOgmo05?oOgmo0_l9jPXOogmoO`;o
2NX:00CoOgmoo`000?l9jP[o2NX:6OmoOgl00ol9jP[oOgmoogmoO`12ogmoO`03o`000?moOgooOgmo
013oOgmo00?o0000ooooooooool03?ooool000kooooo00?o0000ogmoOomoOgl04OmoOgl00ol0003o
OgmoogmoO`1DogmoO`;o2NX:7omoOgl2o`WZ2Q_oOgmo00?o2NX:ogmoOomoOgl0@OmoOgl00ol0003o
OgmoogmoO`0AogmoO`03o`000?oooooooooo00cooooo000?ooooo`03o`000?moOgooOgmo013oOgmo
00?o0000ogmoOomoOgl0E_moOgl00ol9jP[oOgmoogmoO`0KogmoO`04o`WZ2_l0003oOgmoo`WZ2QWo
Ogmo00?o0000o`WZ2_moOgl0@_moOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo00go
oooo000?ooooo`03o`000?moOgooOgmo013oOgmo00?o0000ogmoOomoOgl0EomoOgl2o`WZ2QWoOgmo
0_l9jPX01?moOgoo0000ogmoOomoOgl2o`WZ2QCoOgmo0ol9jPX2o`0004?oOgmo00?o0000ogmoOomo
Ogl04?moOgl00ol0003oooooooooo`0=ooooo`003oooool00ol0003oOgmoogmoO`0AogmoO`03o`00
0?moOgooOgmo05SoOgmo0_l9jPXFogmoO`05o`WZ2_moOgooOgmoogmoOol000001?moOgl2o`WZ2Poo
Ogmo1_l9jPY4ogmoO`03o`000?moOgooOgmo017oOgmo00?o0000ooooooooool03Oooool0013ooooo
00?o0000ogmoOomoOgl04?moOgl00ol0003oOgmoogmoO`1JogmoO`;o2NX:4_moOgl2o`WZ2PCoOgmo
00?o0000ogmoOomoOgl01?moOgl2o`WZ2PcoOgmo1_l9jPY5ogmoO`03o`000?moOgooOgmo013oOgmo
00?o0000ooooooooool03_ooool0013ooooo00?o0000ogmoOomoOgl04?moOgl00ol0003oOgmoogmo
O`1LogmoO`;o2NX:3_moOgl2o`WZ2PKoOgmo00?o0000ogmoOomoOgl01_moOgl2o`WZ2P_oOgmo00Co
2NX:ogmoOol9jP[o2NX:A_moOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo00kooooo
000Aooooo`03o`000?moOgooOgmo013oOgmo00?o0000ogmoOomoOgl0GOmoOgl2o`WZ2P_oOgmo00?o
2NX:ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`08ogmoO`;o2NX:1omoOgl2o`WZ2P03ogmoOol9
jP[o2NX:04KoOgmo00?o0000ogmoOomoOgl04?moOgl00ol0003oooooooooo`0?ooooo`004Oooool0
0ol0003oOgmoogmoO`0@ogmoO`03o`000?moOgooOgmo05ooOgmo00?o2NX:ogmoOomoOgl01_moOgl2
o`WZ2PWoOgmo00?o0000ogmoOomoOgl02_moOgl00ol9jP[oOgmoogmoO`03ogmoO`05o`WZ2_moOgoo
OgmoogmoOol9jPX0AomoOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo00oooooo000B
ooooo`03o`000?moOgooOgmo013oOgmo00?o0000ogmoOomoOgl0GomoOgl2o`WZ2PGoOgmo00?o2NX:
ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0;ogmoO`;o2NX:00?oOgmoo`WZ2_l9jPX0BomoOgl0
0ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo013ooooo000Booooo`03o`000?moOgooOgmo
013oOgmo00?o0000ogmoOomoOgl0HOmoOgl2o`WZ2P03ogmoOol9jP[o2NX:00coOgmo00?o0000ogmo
OomoOgl03?moOgl3o`WZ2TcoOgmo00?o0000ogmoOomoOgl04?moOgl00ol0003oooooooooo`0@oooo
o`004_ooool00ol0003oOgmoogmoO`0@ogmoO`03o`000?moOgooOgmo06;oOgmo0ol9jPX=ogmoO`03
o`000?moOgooOgmo00_oOgmo00Co2NX:ogmoOomoOgooOgmo0_l9jPY:ogmoO`03o`000?moOgooOgmo
013oOgmo00?o0000ooooooooool04?ooool001?ooooo00?o0000ogmoOomoOgl04?moOgl00ol0003o
OgmoogmoO`1PogmoO`04o`WZ2_moOgooOgmoogmoO`;o2NX:2omoOgl00ol0003oOgmoogmoO`09ogmo
O`;o2NX:1_moOgl2o`WZ2TOoOgmo00?o0000ogmoOomoOgl04?moOgl00ol0003oooooooooo`0Aoooo
o`004oooool00ol0003oOgmoogmoO`0@ogmoO`03o`000?moOgooOgmo05koOgmo0_l9jPX6ogmoO`03
o`WZ2_moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl02?moOgl00ol9jP[oOgmoogmoO`08ogmoO`;o
2NX:AOmoOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo017ooooo000Dooooo`03o`00
0?moOgooOgmo013oOgmo00?o0000ogmoOomoOgl0G?moOgl00ol9jP[oOgmoogmoO`07ogmoO`;o2NX:
2?moOgl00ol0003oOgmoogmoO`06ogmoO`;o2NX:3OmoOgl00ol9jP[oOgmoogmoO`11ogmoO`03o`00
0?moOgooOgmo013oOgmo00?o0000ooooooooool04_ooool001Cooooo00?o0000ogmoOomoOgl04?mo
Ogl00ol0003oOgmoogmoO`1JogmoO`;o2NX:3?moOgl2o`WZ2PKoOgmo00?o0000ogmoOomoOgl01?mo
Ogl2o`WZ2Q3oOgmo0_l9jPY1ogmoO`03o`000?moOgooOgmo013oOgmo00?o0000ooooooooool04_oo
ool001Gooooo00?o0000ogmoOomoOgl03omoOgl00ol0003oOgmoogmoO`1HogmoO`;o2NX:4?moOgl2
o`WZ2PCoOgmo00?o0000ogmoOomoOgl00omoOgl00ol9jP[oOgmoogmoO`0BogmoO`;o2NX:?omoOgl0
0ol0003oOgmoogmoO`0?ogmoO`03o`000?oooooooooo01?ooooo000Eooooo`03o`000?moOgooOgmo
013oOgmo00?o0000ogmoOomoOgl0DomoOgl01?l9jP[oOgmoogmoOol9jPXDogmoO`;o2NX:0_moOgl0
1?l0003oOgmoogmoOomoOgl2o`WZ2QOoOgmo0_l9jPXlogmoO`03o`000?moOgooOgmo013oOgmo00?o
0000ooooooooool04oooool001Gooooo00?o0000ogmoOomoOgl04?moOgl00ol0003oOgmoogmoO`1B
ogmoO`Co2NX:5omoOgl2o`WZ2P04o`000?moOgooOgmoo`WZ2Q_oOgmo0_l9jPXjogmoO`03o`000?mo
OgooOgmo013oOgmo00?o0000ooooooooool04oooool001Kooooo00?o0000ogmoOomoOgl04?moOgl0
0ol0003oOgmoogmoO`1@ogmoO`?o2NX:6_moOgl01?l0003o2NX:o`WZ2_l9jPXNogmoO`;o2NX:=omo
Ogl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo01Cooooo000Fooooo`03o`000?moOgoo
Ogmo017oOgmo00?o0000ogmoOomoOgl0C_moOgl6o`WZ2QSoOgmo1?l9jPXPogmoO`03o`WZ2_moOgoo
Ogmo03?oOgmo00?o0000ogmoOomoOgl04OmoOgl00ol0003oooooooooo`0Dooooo`005oooool00ol0
003oOgmoogmoO`0AogmoO`03o`000?moOgooOgmo04coOgmo1Ol9jPXIogmoO`03o`WZ2_l0003oOgmo
00;oOgmo0_l9jPXOogmoO`;o2NX:<_moOgl00ol0003oOgmoogmoO`0AogmoO`03o`000?oooooooooo
01Gooooo000Gooooo`03o`000?moOgooOgmo017oOgmo00?o0000ogmoOomoOgl0B_moOgl2o`0000;o
2NX:6_moOgl2o`WZ2P03ogmoOol0003oOgmo00CoOgmo0_l9jPXOogmoO`;o2NX:0_l0000^ogmoO`03
o`000?moOgooOgmo017oOgmo00?o0000ooooooooool05Oooool001Sooooo00?o0000ogmoOomoOgl0
4OmoOgl00ol0003oOgmoogmoO`19ogmoO`;o00006omoOgl01Ol9jP[oOgmoogmoOomoOgoo000000Oo
Ogmo0_l9jPXOogmoO`03o`WZ2_l0003oOgmo02coOgmo00?o0000ogmoOomoOgl04OmoOgl00ol0003o
ooooooooo`0Fooooo`006?ooool00ol0003oOgmoogmoO`0BogmoO`03o`000?moOgooOgmo06?oOgmo
0_l9jPX4ogmoO`03o`000?moOgooOgmo00OoOgmo0_l9jPY;ogmoO`03o`000?moOgooOgmo01;oOgmo
00?o0000ooooooooool05_ooool001Sooooo00?o0000ogmoOomoOgl04omoOgl00ol0003oOgmoogmo
O`1QogmoO`03o`WZ2_moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl02OmoOgl00ol9jP[oOgmoogmo
O`17ogmoO`03o`000?moOgooOgmo01?oOgmo00?o0000ooooooooool05_ooool001Wooooo00?o0000
ogmoOomoOgl04_moOgl00ol0003oOgmoogmoO`1OogmoO`;o2NX:1omoOgl00ol0003oOgmoogmoO`0:
ogmoO`;o2NX:AomoOgl00ol0003oOgmoogmoO`0BogmoO`03o`000?oooooooooo01Oooooo000Ioooo
o`03o`000?moOgooOgmo01?oOgmo00?o0000ogmoOomoOgl0G?moOgl2o`WZ2PWoOgmo00?o0000ogmo
OomoOgl03?moOgl2o`WZ2TCoOgmo00?o0000ogmoOomoOgl04omoOgl00ol0003oooooooooo`0Goooo
o`006_ooool00ol0003oOgmoogmoO`0CogmoO`03o`000?moOgooOgmo05[oOgmo00?o2NX:ogmoOomo
Ogl02OmoOgl00ol0003oOgmoogmoO`0>ogmoO`;o2NX:@OmoOgl00ol0003oOgmoogmoO`0CogmoO`03
o`000?oooooooooo01Sooooo000Kooooo`03o`000?moOgooOgmo01?oOgmo00?o0000ogmoOomoOgl0
EomoOgl2o`WZ2PcoOgmo00?o0000ogmoOomoOgl04?moOgl2o`WZ2SkoOgmo00?o0000ogmoOomoOgl0
4omoOgl00ol0003oooooooooo`0Iooooo`007?ooool00ol0003oOgmoogmoO`0CogmoO`03o`000?mo
OgooOgmo05GoOgmo00?o2NX:ogmoOomoOgl03?moOgl00ol0003oOgmoogmoO`0BogmoO`03o`WZ2_mo
OgooOgmo03[oOgmo00?o0000ogmoOomoOgl04omoOgl00ol0003oooooooooo`0Jooooo`007?ooool0
0ol0003oOgmoogmoO`0CogmoO`03o`000?moOgooOgmo05?oOgmo0_l9jPX?ogmoO`03o`000?moOgoo
Ogmo01?oOgmo0_l9jPXjogmoO`03o`000?moOgooOgmo01?oOgmo00?o0000ooooooooool06_ooool0
01gooooo00?o0000ogmoOomoOgl04omoOgl00ol0003oOgmoogmoO`1@ogmoO`;o2NX:4OmoOgl00ol0
003oOgmoogmoO`0EogmoO`;o2NX:=omoOgl00ol0003oOgmoogmoO`0CogmoO`03o`000?oooooooooo
01_ooooo000Nooooo`03o`000?moOgooOgmo01?oOgmo00?o0000ogmoOomoOgl0C_moOgl00ol9jP[o
OgmoogmoO`0AogmoO`03o`000?moOgooOgmo01OoOgmo0_l9jPX3ogmoO`03o`WZ2_moOgooOgmo02ko
Ogmo00?o0000ogmoOomoOgl04omoOgl00ol0003oooooooooo`0Looooo`007_ooool00ol0003oOgmo
ogmoO`0DogmoO`03o`000?moOgooOgmo04_oOgmo0_l9jPXDogmoO`03o`000?moOgooOgmo01WoOgmo
0_l9jPX00omoOgoo2NX:o`WZ2P0^ogmoO`03o`000?moOgooOgmo01CoOgmo00?o0000ooooooooool0
7?ooool001oooooo00?o0000ogmoOomoOgl04omoOgl00ol0003oOgmoogmoO`1:ogmoO`03o`WZ2_mo
OgooOgmo01CoOgmo00?o0000ogmoOomoOgl06omoOgl4o`WZ2RgoOgmo00?o0000ogmoOomoOgl04omo
Ogl00ol0003oooooooooo`0Mooooo`008?ooool00ol0003oOgmoogmoO`0CogmoO`03o`000?moOgoo
Ogmo04OoOgmo0_l9jPXFogmoO`03o`000?moOgooOgmo01goOgmo1?l9jPX[ogmoO`03o`000?moOgoo
Ogmo01?oOgmo00?o0000ooooooooool07_ooool0027ooooo00?o0000ogmoOomoOgl04omoOgl00ol0
003oOgmoogmoO`14ogmoO`;o2NX:6?moOgl00ol0003oOgmoogmoO`0KogmoO`Oo2NX::OmoOgl00ol0
003oOgmoogmoO`0CogmoO`03o`000?oooooooooo01oooooo000Qooooo`03o`000?moOgooOgmo01Co
Ogmo00?o0000ogmoOomoOgl0@OmoOgl00ol0003o2NX:ogmoO`0IogmoO`03o`000?moOgooOgmo01ko
Ogmo1Ol9jPX2o`0002GoOgmo00?o0000ogmoOomoOgl05?moOgl00ol0003oooooooooo`0Oooooo`00
8_ooool00ol0003oOgmoogmoO`0CogmoO`03o`000?moOgooOgmo047oOgmo00?o2NX:o`000?moOgl0
6OmoOgl00ol0003oOgmoogmoO`0RogmoO`03o`WZ2_l0003o000002GoOgmo00?o0000ogmoOomoOgl0
4omoOgl00ol0003oooooooooo`0Pooooo`008oooool00ol0003oOgmoogmoO`0CogmoO`03o`000?mo
OgooOgmo05coOgmo00?o0000ogmoOomoOgl0BOmoOgl00ol0003oOgmoogmoO`0CogmoO`03o`000?oo
oooooooo027ooooo000Tooooo`03o`000?moOgooOgmo01?oOgmo00?o0000ogmoOomoOgl0FomoOgl0
0ol0003oOgmoogmoO`18ogmoO`03o`000?moOgooOgmo01?oOgmo00?o0000ooooooooool08_ooool0
02Cooooo00?o0000ogmoOomoOgl05?moOgl2o`0005_oOgmo00?o0000ogmoOomoOgl0A_moOgl2o`00
01KoOgmo00?o0000ooooooooool08_ooool002Gooooo00?o0000ogmoOomoOgl05OmoOgl00ol0003o
OgmoogmoO`1HogmoO`03o`000?moOgooOgmo04GoOgmo00?o0000ogmoOomoOgl05OmoOgl00ol0003o
ooooooooo`0Sooooo`009_ooool00ol0003oOgmoogmoO`0EogmoO`03o`000?moOgooOgmo05OoOgmo
00?o0000ogmoOomoOgl0A?moOgl00ol0003oOgmoogmoO`0EogmoO`03o`000?oooooooooo02Cooooo
000Vooooo`03o`000?moOgooOgmo01KoOgmo00?o0000ogmoOomoOgl0E_moOgl00ol0003oOgmoogmo
O`12ogmoO`;o00006?moOgl00ol0003oooooooooo`0Tooooo`009oooool00ol0003oOgmoogmoO`0F
ogmoO`;o0000E_moOgl00ol0003oOgmoogmoO`11ogmoO`03o`000?moOgooOgmo01OoOgmo00?o0000
ooooooooool09Oooool002Sooooo00?o0000ogmoOomoOgl05omoOgl00ol0003oOgmoogmoO`1Cogmo
O`03o`000?moOgooOgmo043oOgmo00?o0000ogmoOomoOgl05omoOgl00ol0003oooooooooo`0Voooo
o`00:Oooool00ol0003oOgmoogmoO`0GogmoO`03o`000?moOgooOgmo05;oOgmo00?o0000ogmoOomo
Ogl0?_moOgl2o`0001WoOgmo00?o0000ooooooooool09oooool002Wooooo00?o0000ogmoOomoOgl0
6?moOgl00ol0003oOgmoogmoO`1AogmoO`03o`000?moOgooOgmo03goOgmo00?o0000ogmoOomoOgl0
6OmoOgl00ol0003oooooooooo`0Wooooo`00:_ooool00ol0003oOgmoogmoO`0HogmoO`;o0000DOmo
Ogl00ol0003oOgmoogmoO`0logmoO`03o`000?moOgooOgmo01WoOgmo00?o0000ooooooooool0:?oo
ool002_ooooo00?o0000ogmoOomoOgl06OmoOgl00ol0003oOgmoogmoO`1>ogmoO`03o`000?moOgoo
Ogmo03[oOgmo0_l0000KogmoO`03o`000?oooooooooo02Wooooo000[ooooo`03o`000?moOgooOgmo
01[oOgmo00?o0000ogmoOomoOgl0COmoOgl00ol0003oOgmoogmoO`0iogmoO`03o`000?moOgooOgmo
01_oOgmo00?o0000ooooooooool0:Oooool002cooooo00?o0000ogmoOomoOgl06_moOgl2o`0004co
Ogmo00?o0000ogmoOomoOgl0>OmoOgl00ol0003oOgmoogmoO`0KogmoO`03o`000?oooooooooo02[o
oooo000]ooooo`03o`000?moOgooOgmo01_oOgmo00?o0000ogmoOomoOgl0BOmoOgl00ol0003oOgmo
ogmoO`0hogmoO`03o`000?moOgooOgmo01_oOgmo00?o0000ooooooooool0:oooool002kooooo0_l0
000LogmoO`;o0000BOmoOgl00ol0003oOgmoogmoO`0fogmoO`;o00007?moOgl2o`0002kooooo000`
ooooo`03o`000?moOgooOgmo01[oOgmo0ol00017ogmoO`03o`000?moOgooOgmo03GoOgmo00?o0000
ogmoOomoOgl06omoOgl00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oOgmoogmoO`0Jogmo
O`?o0000A_moOgl00ol0003oOgmoogmoO`0dogmoO`03o`000?moOgooOgmo01_oOgmo00?o0000oooo
ooooool0;oooool003;ooooo0_l0000LogmoO`?o0000A?moOgl00ol0003oOgmoogmoO`0bogmoO`;o
00007?moOgl2o`0003;ooooo000dooooo`03o`000?moOgooOgmo01[oOgmo00Co0000ooooool0003o
0000@_moOgl00ol0003oOgmoogmoO`0aogmoO`03o`000?moOgooOgmo01_oOgmo00?o0000oooooooo
ool0<_ooool003Gooooo00?o0000ogmoOomoOgl06_moOgl00ol0003oooooooooo`02o`00043oOgmo
00?o0000ogmoOomoOgl0<?moOgl00ol0003oOgmoogmoO`0JogmoO`;o0000=Oooool003Kooooo0_l0
000KogmoO`;o00000_ooool2o`0003koOgmo00?o0000ogmoOomoOgl0;_moOgl2o`0001coOgmo00?o
0000ooooooooool0=Oooool003Sooooo00?o0000ogmoOomoOgl06_moOgl3o`000003ooooool0003o
000003coOgmo00?o0000ogmoOomoOgl0:omoOgl3o`0001goOgmo00?o0000ooooooooool0=_ooool0
03Wooooo00?o0000ogmoOomoOgl07?moOgl4o`0003_oOgmo00?o0000ogmoOomoOgl0:OmoOgl2o`00
01koOgmo0_l0000iooooo`00>_ooool2o`0001ooOgmo0ol0000iogmoO`03o`000?moOgooOgmo02Ko
Ogmo0ol0000OogmoO`03o`000?oooooooooo03Wooooo000looooo`03o`000?moOgooOgmo01koOgmo
0ol0000gogmoO`03o`000?moOgooOgmo02CoOgmo0_l0000PogmoO`;o0000??ooool003gooooo00?o
0000ogmoOomoOgl08?moOgl3o`0003CoOgmo00?o0000ogmoOomoOgl08OmoOgl3o`00027oOgmo00?o
0000ooooooooool0??ooool003kooooo0_l0000SogmoO`;o0000<_moOgl00ol0003oOgmoogmoO`0N
ogmoO`?o00008omoOgl00ol0003oooooooooo`0mooooo`00@?ooool00ol0003oOgmoogmoO`0Rogmo
O`?o0000;omoOgl00ol0003oOgmoogmoO`0LogmoO`;o00009?moOgl2o`00043ooooo0011ooooo`03
o`000?moOgooOgmo02CoOgmo0_l0000]ogmoO`03o`000?moOgooOgmo01WoOgmo0ol0000UogmoO`03
o`000?oooooooooo043ooooo0012ooooo`;o00009_moOgl3o`0002WoOgmo00?o0000ogmoOomoOgl0
6?moOgl2o`0002OoOgmo00?o0000ooooooooool0@Oooool004Cooooo00?o0000ogmoOomoOgl09_mo
Ogl3o`0002KoOgmo00?o0000ogmoOomoOgl05OmoOgl3o`0002OoOgmo0_l00014ooooo`00AOooool0
0ol0003oOgmoogmoO`0XogmoO`Go00008OmoOgl00ol0003oOgmoogmoO`0@ogmoO`Go0000:OmoOgl0
0ol0003oooooooooo`14ooooo`00A_ooool2o`0002goOgmo1ol0000JogmoO`03o`000?moOgooOgmo
00SoOgmo2?l0000/ogmoO`;o0000Aoooool004Sooooo00?o0000ogmoOomoOgl0<OmoOgl8o`0001;o
Ogmo00Co0000ogmoOomoOgooOgmo1ol0000cogmoO`03o`000?oooooooooo04Oooooo0019ooooo`03
o`000?moOgooOgmo03SoOgmo1ol00007ogmoO`So0000>OmoOgl00ol0003oooooooooo`18ooooo`00
B_ooool2o`0003ooOgmo1ol0000oogmoO`;o0000Boooool004cooooo0ol00020ogmoO`;o0000COoo
ool004oooooo0_l0001kogmoO`?o0000Coooool0057ooooo0_l0001gogmoO`;o0000D_ooool005?o
oooo0ol0001bogmoO`;o0000E?ooool005Kooooo0_l0001]ogmoO`?o0000E_ooool005Sooooo0_l0
001YogmoO`;o0000FOooool005[ooooo0ol0001TogmoO`;o0000Foooool005gooooo0_l0001Pogmo
O`;o0000GOooool005oooooo0_l0001KogmoO`?o0000Goooool0067ooooo0ol0001FogmoO`;o0000
H_ooool006Cooooo0_l0001BogmoO`;o0000I?ooool006Kooooo0_l0001=ogmoO`?o0000I_ooool0
06Sooooo0ol00018ogmoO`;o0000JOooool006_ooooo1Ol0000nogmoO`Go0000Joooool0073ooooo
1ol0000`ogmoO`Oo0000L?ooool007Oooooo1ol0000RogmoO`Oo0000Moooool007kooooo1ol0000D
ogmoO`Oo0000O_ooool008Gooooo1ol00006ogmoO`Oo0000QOooool008cooooo1_l00003ooooo`03
o`000?oooooooooo08Kooooo003ooooooaoooooo003ooooooaoooooo003ooooooaoooooo003ooooo
oaoooooo003ooooooaoooooo003ooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 285.875}, {286.938, 0}} -> {-30.199, -30.3113, \
0.211274, 0.211274}},
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[SolidCornerCube[50,0,Baffled->False,Mirrored->True, \
FullForm->True]];\
\>", "Input",
  CellTags->"Prism Examples"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.283 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.141726 1.33891 -1.11022e-16 1.33891 [
[ 0 0 0 0 ]
[ 1 1.283 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.283 L
0 1.283 L
closepath
clip
newpath
.29555 .44249 m .79858 .58274 L .68095 .6868 L .278 .555 .928 r
F
.44685 1.07646 m .68095 .6868 L .79858 .58274 L 0 0 0 r
F
0 g
.5 Mabswid
[ ] 0 setdash
.45251 .75776 m
.68095 .6868 L
s
.29544 .44253 m
.45251 .75776 L
s
.29544 .44253 m
.45251 .75776 L
s
.44673 1.07649 m
.45251 .75776 L
s
.44673 1.07649 m
.45251 .75776 L
s
.09158 .39357 m
.29544 .44253 L
s
.09158 .39357 m
.29544 .44253 L
s
.29555 .44249 m .34691 .29519 L .79858 .58274 L .278 .555 .928 r
F
0 g
.29544 .44253 m
.29555 .44249 L
s
.29555 .44249 m
.68095 .6868 L
s
.25498 1.11054 m
.44673 1.07649 L
s
.44673 1.07649 m
.25498 1.11054 L
s
.44685 1.07646 m .79858 .58274 L .5278 1.03796 L 0 0 0 r
F
0 g
.44673 1.07649 m
.44685 1.07646 L
s
.44685 1.07646 m
.68095 .6868 L
s
.05185 .73951 m .79858 .58274 L .34691 .29519 L .744 .57 .658 r
F
0 g
.09158 .39357 m
.34691 .29519 L
s
.05185 .73951 m .5278 1.03796 L .79858 .58274 L .744 .57 .658 r
F
0 g
.05172 .73956 m
.09158 .39357 L
s
.05172 .73956 m
.09158 .39357 L
s
.34691 .29519 m
.79858 .58274 L
s
.5278 1.03796 m
.79858 .58274 L
s
.44685 1.07646 m
.5278 1.03796 L
s
.05185 .73951 m
.34691 .29519 L
s
.05172 .73956 m
.25498 1.11054 L
s
.25498 1.11054 m
.5278 1.03796 L
s
.05172 .73956 m
.25498 1.11054 L
s
.05185 .73951 m
.5278 1.03796 L
s
.05172 .73956 m
.05185 .73951 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{236.438, 303.312},
  ImageMargins->{{169, 0}, {0, 0}},
  ImageRegion->{{0, 1.19104}, {-0.289688, 1.15}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003/0001;b000`400?l00000o`00003ok?ooool0
0>cooooo003/ooooo`00k?ooool00>cooooo003/ooooo`00k?ooool00>cooooo003/ooooo`00k?oo
ool00>cooooo003/ooooo`00k?ooool00>cooooo003/ooooo`00k?ooool00>cooooo003/ooooo`00
k?ooool00>cooooo003/ooooo`00k?ooool00>cooooo003/ooooo`00k?ooool00>cooooo003/oooo
o`00k?ooool00>cooooo003/ooooo`00k?ooool00>cooooo003/ooooo`00H?ooool3o`0008Wooooo
001Mooooo`?o000000Coooooo`000?nnTJSo0000R?ooool005_ooooo0_l00003ooooo`04o`000?nn
TJSo_Y6XokjAZ0;o0000Q_ooool005Sooooo0ol00004ooooo`03o`000?nnTJSo_Y6X00Co_Y6X00?o
0000ooooooooool0Poooool005Gooooo0ol00007ooooo`03o`000?nnTJSo_Y6X00Go_Y6X0_l00023
ooooo`00Doooool2o`0000Wooooo00?o0000okjAZ?nnTJP02?nnTJP2o`00087ooooo001@ooooo`?o
00002_ooool00ol0003o_Y6XokjAZ00;okjAZ003o`000?oooooooooo07kooooo001>ooooo`;o0000
3Oooool00ol0003o_Y6XokjAZ00<okjAZ0;o0000O_ooool004_ooooo0ol0000>ooooo`03o`000?nn
TJSo_Y6X00oo_Y6X00?o0000ooooooooool0Noooool004Wooooo0_l0000@ooooo`03o`000?nnTJSo
_Y6X017o_Y6X0_l0001kooooo`00A_ooool3o`0001;ooooo00?o0000okjAZ?nnTJP04onnTJP00ol0
003oooooooooo`1hooooo`00@oooool3o`0001Cooooo00?o0000okjAZ?nnTJP05OnnTJP2o`0007So
oooo0011ooooo`;o00005_ooool00ol0003o_Y6XokjAZ00HokjAZ0;o0000M_ooool003kooooo0ol0
000Hooooo`03o`000?nnTJSo_Y6X01[o_Y6X00?o0000ooooooooool0Loooool003cooooo0_l0000J
ooooo`03o`000?nnTJSo_Y6X01co_Y6X0_l0001cooooo`00>Oooool3o`0001_ooooo00?o0000okjA
Z?nnTJP07onnTJP00ol0003oooooooooo`1`ooooo`00=oooool2o`0001kooooo00?o0000okjAZ?nn
TJP08?nnTJP2o`00073ooooo000dooooo`?o00007oooool00ol0003o_Y6XokjAZ00SokjAZ003o`00
0?oooooooooo06gooooo000aooooo`?o00008Oooool00ol0003o_Y6XokjAZ00UokjAZ0;o0000KOoo
ool002oooooo0_l0000Tooooo`03o`000?nnTJSo_Y6X02Oo_Y6X0_l0001[ooooo`00;?ooool3o`00
02Gooooo00?o0000okjAZ?nnTJP0:_nnTJP00ol0003oooooooooo`1Xooooo`00:_ooool2o`0002Oo
oooo00?o0000okjAZ?nnTJP0;?nnTJP2o`0006Sooooo000Wooooo`?o0000:Oooool00ol0003o_Y6X
okjAZ00^okjAZ003o`000?oooooooooo06Gooooo000Uooooo`;o0000:oooool00ol0003o_Y6XokjA
Z00`okjAZ0;o0000IOooool002;ooooo0ol0000/ooooo`03o`000?nnTJSo_Y6X03?o_Y6X00?o0000
ooooooooool0H_ooool001oooooo0ol0000_ooooo`03o`000?nnTJSo_Y6X03Co_Y6X0_l0001Roooo
o`007Oooool2o`00037ooooo00?o0000okjAZ?nnTJP0=onnTJP2o`00063ooooo000Jooooo`?o0000
<_ooool00ol0003o_Y6XokjAZ00jokjAZ003o`000?oooooooooo05gooooo000Iooooo`?o0000<ooo
ool00ol0003o_Y6XokjAZ00kokjAZ0;o0000GOooool001Wooooo00?o0000ooooooooool01Ol0000]
ooooo`03o`000?nnTJSo_Y6X03ko_Y6X00?o0000ooooooooool0F_ooool001Wooooo00?o0000oooo
ooooool01Oooool4o`0002Sooooo00?o0000okjAZ?nnTJP0@?nnTJP2o`0005[ooooo000Iooooo`03
o`000?oooooooooo00Wooooo1?l0000Tooooo`03o`000?nnTJSo_Y6X04;o_Y6X00?o0000oooooooo
ool0Eoooool001Wooooo00?o0000ooooooooool03Oooool5o`0001kooooo00?o0000okjAZ?nnTJP0
A?nnTJP2o`0005Oooooo000Hooooo`03o`000?oooooooooo01?ooooo1?l0000Iooooo`03o`000?nn
TJSo_Y6X04Oo_Y6X0_l0001Eooooo`006?ooool00ol0003oooooooooo`0Gooooo`Go00005?ooool0
0ol0003o_Y6XokjAZ019okjAZ003o`000?oooooooooo05;ooooo000Hooooo`03o`000?oooooooooo
01cooooo1?l0000?ooooo`03o`000?nnTJSo_Y6X04_o_Y6X0_l0001Booooo`006?ooool00ol0003o
ooooooooo`0Pooooo`Co00002_ooool00ol0003o_Y6XokjAZ01>okjAZ003o`000?oooooooooo04oo
oooo000Hooooo`03o`000?oooooooooo02Cooooo1Ol00005ooooo`03o`000?nnTJSo_Y6X04oo_Y6X
0_l0001?ooooo`006?ooool00ol0003oooooooooo`0Yooooo`Go0000E?nnTJP00ol0003ooooooooo
o`1<ooooo`006?ooool00ol0003oooooooooo`0/ooooo`03o`000?nnTJSo_Y6X05Co_Y6X0_l0001<
ooooo`006?ooool00ol0003oooooooooo`0/ooooo`03o`000?nnTJSo_Y6X05Ko_Y6X0_l0001:oooo
o`006?ooool00ol0003oooooooooo`0[ooooo`03o`000?nnTJSo_Y6X05Wo_Y6X00?o0000oooooooo
ool0Aoooool001Oooooo00?o0000ooooooooool0:oooool00ol0003o_Y6XokjAZ01KokjAZ0;o0000
Aoooool001Oooooo00?o0000ooooooooool0:oooool00ol0003o_Y6XokjAZ01MokjAZ003o`000?oo
oooooooo04Cooooo000Gooooo`03o`000?oooooooooo02[ooooo00?o0000okjAZ?nnTJP0GonnTJP2
o`0004Cooooo000Gooooo`03o`000?oooooooooo02Wooooo00?o0000okjAZ?nnTJP0H_nnTJP00ol0
003oooooooooo`11ooooo`005oooool00ol0003oooooooooo`0Yooooo`03o`000?nnTJSo_Y6X06?o
_Y6X0_l00011ooooo`005oooool00ol0003oooooooooo`0Xooooo`03o`000?nnTJSo_Y6X06Ko_Y6X
00?o0000ooooooooool0?_ooool001Oooooo00?o0000ooooooooool09oooool00ol0003o_Y6XokjA
Z01XokjAZ0;o0000?_ooool001Oooooo00?o0000ooooooooool09oooool00ol0003o_Y6XokjAZ01Z
okjAZ0;o0000??ooool001Oooooo00?o0000ooooooooool09_ooool00ol0003o_Y6XokjAZ01]okjA
Z003o`000?oooooooooo03Wooooo000Fooooo`03o`000?oooooooooo02Kooooo00?o0000okjAZ?nn
TJP0KonnTJP2o`0003Wooooo000Fooooo`03o`000?oooooooooo02Kooooo00?o0000okjAZ?nnTJP0
LOnnTJP00ol0003oooooooooo`0fooooo`005_ooool00ol0003oooooooooo`0Uooooo`03o`000?nn
TJSo_Y6X07?o_Y6X0_l0000fooooo`005_ooool00ol0003oooooooooo`0Tooooo`03o`000?nnTJSo
_Y6X07Ko_Y6X00?o0000ooooooooool0<oooool001Kooooo00?o0000ooooooooool09?ooool00ol0
003o_Y6XokjAZ01gokjAZ0;o0000<oooool001Kooooo00?o0000ooooooooool08oooool00ol0003o
_Y6XokjAZ01jokjAZ0;o0000<Oooool001Kooooo00?o0000ooooooooool08_ooool00ol0003o_Y6X
okjAZ01mokjAZ003o`000?oooooooooo02kooooo000Fooooo`03o`000?oooooooooo02;ooooo00?o
0000okjAZ?nnTJP0O_nnTJP2o`0002kooooo000Fooooo`03o`000?oooooooooo027ooooo00?o0000
okjAZ?nnTJP0POnnTJP00ol0003oooooooooo`0[ooooo`005Oooool00ol0003oooooooooo`0Qoooo
o`03o`000?nnTJSo_Y6X08?o_Y6X0_l0000[ooooo`005Oooool00ol0003oooooooooo`0Qooooo`03
o`000?nnTJSo_Y6X08Go_Y6X00?o0000ooooooooool0:?ooool001Gooooo00?o0000ooooooooool0
8?ooool00ol0003o_Y6XokjAZ027okjAZ0;o0000:?ooool001Gooooo00?o0000ooooooooool07ooo
ool00ol0003o_Y6XokjAZ02:okjAZ0;o00009_ooool001Gooooo00?o0000ooooooooool07oooool0
0ol0003o_Y6XokjAZ02<okjAZ003o`000?oooooooooo02?ooooo000Eooooo`03o`000?oooooooooo
01kooooo00?o0000okjAZ?nnTJP0S_nnTJP2o`0002?ooooo000Eooooo`03o`000?oooooooooo01ko
oooo00?o0000okjAZ?nnTJP0T?nnTJP00ol0003oooooooooo`0Pooooo`005Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?nnTJSo_Y6X09;o_Y6X0_l0000Pooooo`005Oooool00ol0003ooooooooo
o`0Looooo`03o`000?nnTJSo_Y6X09Go_Y6X00?o0000ooooooooool07Oooool001Cooooo00?o0000
ooooooooool07Oooool00ol0003o_Y6XokjAZ02FokjAZ0;o00007Oooool001Cooooo00?o0000oooo
ooooool07?ooool00ol0003o_Y6XokjAZ02IokjAZ0;o00006oooool001Cooooo00?o0000oooooooo
ool06oooool00ol0003o_Y6XokjAZ02LokjAZ003o`000?oooooooooo01Sooooo000Dooooo`03o`00
0?oooooooooo01_ooooo00?o0000okjAZ?nnTJP0WOnnTJP2o`0001Sooooo000Dooooo`03o`000?oo
oooooooo01[ooooo00?o0000okjAZ?nnTJP0X?nnTJP00ol0003oooooooooo`0Eooooo`005?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?nnTJSo_Y6X0:;o_Y6X0_l0000Eooooo`005?ooool00ol0
003oooooooooo`0Iooooo`03o`000?nnTJSo_Y6X0:Co_Y6X00?o0000ooooooooool04_ooool001Co
oooo00?o0000ooooooooool06?ooool00ol0003o_Y6XokjAZ02VokjAZ0;o00004_ooool001?ooooo
00?o0000ooooooooool06?ooool00ol0003o_Y6XokjAZ02YokjAZ0;o00004?ooool001?ooooo00?o
0000ooooooooool06?ooool00ol0003o_Y6XokjAZ02[okjAZ003o`000?oooooooooo00gooooo000C
ooooo`03o`000?oooooooooo01Oooooo00?o0000okjAZ?nnTJP0[OnnTJP2o`0000gooooo000Coooo
o`03o`000?oooooooooo01Kooooo00?o0000okjAZ?nnTJP0/?nnTJP00ol0003oooooooooo`0:oooo
o`004oooool00ol0003oooooooooo`0Fooooo`03o`000?nnTJSo_Y6X0;7o_Y6X00?o0000oooooooo
ool02Oooool001?ooooo00?o0000ooooooooool05Oooool00ol0003o_Y6XokjAZ02bokjAZ003o`00
0?oooooooooo00Wooooo000Cooooo`03o`000?oooooooooo01Cooooo00?o0000okjAZ?nnTJP0/_nn
TJP00ol0003oooooooooo`0:ooooo`004oooool00ol0003oooooooooo`0Dooooo`03o`000?nnTJSo
_Y6X0;;o_Y6X00?o0000ooooooooool02_ooool001?ooooo00?o0000ooooooooool04oooool00ol0
003o_Y6XokjAZ02bokjAZ003o`000?oooooooooo00_ooooo000Booooo`03o`000?oooooooooo01?o
oooo00?o0000okjAZ?nnTJP0/_nnTJP00ol0003oooooooooo`0<ooooo`004_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?nnTJSo_Y6X0;;o_Y6X00?o0000ooooooooool03?ooool001;ooooo00?o
0000ooooooooool04_ooool00ol0003o_Y6XokjAZ02bokjAZ003o`000?oooooooooo00gooooo000B
ooooo`03o`000?oooooooooo017ooooo00?o0000okjAZ?nnTJP0/onnTJP00ol0003oooooooooo`0=
ooooo`004_ooool00ol0003oooooooooo`0Aooooo`03o`000?nnTJSo_Y6X0;;o_Y6X00?o0000oooo
ooooool03_ooool001;ooooo00?o0000ooooooooool04?ooool00ol0003o_Y6XokjAZ02bokjAZ003
o`000?oooooooooo00oooooo000Booooo`03o`000?oooooooooo00oooooo00?o0000okjAZ?nnTJP0
/onnTJP00ol0003oooooooooo`0?ooooo`004_ooool00ol0003oooooooooo`0?ooooo`03o`000?nn
TJSo_Y6X0;;o_Y6X00?o0000ooooooooool04?ooool001;ooooo00?o0000ooooooooool03_ooool0
0ol0003o_Y6XokjAZ02cokjAZ003o`000?oooooooooo013ooooo000Aooooo`03o`000?oooooooooo
00kooooo00?o0000okjAZ?nnTJP0/onnTJP00ol0003oooooooooo`0Aooooo`004Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?nnTJSo_Y6X0;;o_Y6X00?o0000ooooooooool04_ooool0017ooooo
00?o0000ooooooooool03Oooool00ol0003o_Y6XokjAZ02cokjAZ003o`000?oooooooooo01;ooooo
000Aooooo`03o`000?oooooooooo00cooooo00?o0000okjAZ?nnTJP0/onnTJP00ol0003ooooooooo
o`0Cooooo`004Oooool00ol0003oooooooooo`0<ooooo`03o`000?nnTJSo_Y6X0;?o_Y6X00?o0000
ooooooooool04oooool0017ooooo00?o0000ooooooooool02oooool00ol0003o_Y6XokjAZ02cokjA
Z003o`000?oooooooooo01Cooooo000Aooooo`03o`000?oooooooooo00[ooooo00?o0000okjAZ?nn
TJP0/onnTJP00ol0003oooooooooo`0Eooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?nnTJSo_Y6X0;?o_Y6X00?o0000ooooooooool05Oooool0017ooooo00?o0000ooooooooool02Ooo
ool00ol0003o_Y6XokjAZ02cokjAZ003o`000?oooooooooo01Kooooo000@ooooo`03o`000?oooooo
oooo00Wooooo00?o0000okjAZ?nnTJP0]?nnTJP00ol0003oooooooooo`0Fooooo`004?ooool00ol0
003oooooooooo`09ooooo`03o`000?nnTJSo_Y6X0;?o_Y6X00?o0000ooooooooool05oooool0013o
oooo00?o0000ooooooooool02?ooool00ol0003o_Y6XokjAZ02cokjAZ003o`000?oooooooooo01So
oooo000@ooooo`03o`000?oooooooooo00Oooooo00?o0000okjAZ?nnTJP0]?nnTJP00ol0003ooooo
ooooo`0Hooooo`004?ooool00ol0003oooooooooo`07ooooo`03o`000?nnTJSo_Y6X0;?o_Y6X00?o
0000ooooooooool06Oooool0013ooooo00?o0000ooooooooool01_ooool00ol0003o_Y6XokjAZ02d
okjAZ003o`000?oooooooooo01Wooooo000@ooooo`03o`000?oooooooooo00Gooooo00?o0000okjA
Z?nnTJP0]?nnTJP00ol0003oooooooooo`0Jooooo`004?ooool00ol0003oooooooooo`05ooooo`03
o`000?nnTJSo_Y6X0;?o_Y6X00?o0000ooooooooool06oooool0013ooooo00?o0000ooooooooool0
1?ooool00ol0003o_Y6XokjAZ02dokjAZ003o`000?oooooooooo01_ooooo000?ooooo`03o`000?oo
oooooooo00Cooooo00?o0000okjAZ?nnTJP0]?nnTJP00ol0003oooooooooo`0Looooo`003oooool0
0ol0003oooooooooo`04ooooo`03o`000?nnTJSo_Y6X0;Co_Y6X00?o0000ooooooooool07?ooool0
00oooooo00?o0000ooooooooool00oooool00ol0003o_Y6XokjAZ02dokjAZ003o`000?oooooooooo
01gooooo000?ooooo`03o`000?oooooooooo00;ooooo00?o0000okjAZ?nnTJP0]?nnTJP00ol0003o
ooooooooo`0Nooooo`003oooool00ol0003oooooooooo`02ooooo`03o`000?nnTJSo_Y6X0;Co_Y6X
00?o0000ooooooooool07_ooool000oooooo00Go0000ooooooooooooooooo`00002fokjAZ003o`00
0?oooooooooo01oooooo000?ooooo`04o`000?ooooooooooo`000;Oo_Y6X00?o0000ooooooooool0
7oooool000oooooo00Co0000oooooooooooo0000]_nnTJP00ol0003oooooooooo`0Pooooo`003ooo
ool00ol0003oooooo`00002fokjAZ003o`000?oooooooooo027ooooo000>ooooo`03o`000?oooooo
00000;Oo_Y6X00?o0000ooooooooool08Oooool000kooooo00?o0000ooooool00000]_nnTJP00ol0
003oooooooooo`0Rooooo`003_ooool2o`000;Oo_Y6X00?o0000ooooooooool08_ooool000kooooo
0_l0002fokjAZ003o`000?oooooooooo02?ooooo000>ooooo`03o`000?oooooo00000;Co_Y6X00?o
0000ooooooooool09?ooool000oooooo00Co0000ooooool0003o0000/_nnTJP00ol0003ooooooooo
o`0Tooooo`003oooool01?l0003oooooooooooooool2o`000:oo_Y6X00?o0000ooooooooool09Ooo
ool0013ooooo00?o0000ooooooooool00_ooool00ol0003o_Y6XokjAZ02/okjAZ003o`000?oooooo
oooo02Gooooo000@ooooo`03o`000?oooooooooo00?ooooo0_l0002[okjAZ003o`000?oooooooooo
02Kooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o0000okjAZ?nnTJP0YonnTJP00ol0003o
ooooooooo`0Wooooo`004_ooool00ol0003oooooooooo`04ooooo`;o0000YonnTJP00ol0003ooooo
ooooo`0Wooooo`004_ooool00ol0003oooooooooo`06ooooo`;o0000Y?nnTJP00ol0003ooooooooo
o`0Xooooo`004oooool00ol0003oooooooooo`07ooooo`03o`000?nnTJSo_Y6X0:7o_Y6X00?o0000
ooooooooool0:?ooool001?ooooo00?o0000ooooooooool02?ooool2o`000:3o_Y6X00?o0000oooo
ooooool0:Oooool001Cooooo00?o0000ooooooooool02Oooool2o`0009go_Y6X00?o0000oooooooo
ool0:_ooool001Cooooo00?o0000ooooooooool02oooool00ol0003o_Y6XokjAZ02JokjAZ003o`00
0?oooooooooo02[ooooo000Eooooo`03o`000?oooooooooo00_ooooo0_l0002IokjAZ003o`000?oo
oooooooo02_ooooo000Eooooo`03o`000?oooooooooo00gooooo00?o0000okjAZ?nnTJP0U_nnTJP0
0ol0003oooooooooo`0[ooooo`005_ooool00ol0003oooooooooo`0=ooooo`;o0000UOnnTJP00ol0
003oooooooooo`0/ooooo`005_ooool00ol0003oooooooooo`0?ooooo`;o0000T_nnTJP00ol0003o
ooooooooo`0]ooooo`005oooool00ol0003oooooooooo`0@ooooo`03o`000?nnTJSo_Y6X08oo_Y6X
00?o0000ooooooooool0;Oooool001Sooooo00?o0000ooooooooool04?ooool2o`0008ko_Y6X00?o
0000ooooooooool0;_ooool001Sooooo00?o0000ooooooooool04_ooool00ol0003o_Y6XokjAZ02;
okjAZ003o`000?oooooooooo02kooooo000Iooooo`03o`000?oooooooooo01;ooooo0_l0002:okjA
Z003o`000?oooooooooo02oooooo000Iooooo`03o`000?oooooooooo01Cooooo0_l00027okjAZ003
o`000?oooooooooo033ooooo000Jooooo`03o`000?oooooooooo01Gooooo00?o0000okjAZ?nnTJP0
Q?nnTJP00ol0003oooooooooo`0`ooooo`006_ooool00ol0003oooooooooo`0Fooooo`;o0000Ponn
TJP00ol0003oooooooooo`0aooooo`006oooool00ol0003oooooooooo`0Gooooo`;o0000POnnTJP0
0ol0003oooooooooo`0aooooo`006oooool00ol0003oooooooooo`0Iooooo`03o`000?nnTJSo_Y6X
07go_Y6X00?o0000ooooooooool0<_ooool001cooooo00?o0000ooooooooool06Oooool2o`0007co
_Y6X00?o0000ooooooooool0<oooool001gooooo00?o0000ooooooooool06_ooool00ol0003o_Y6X
okjAZ01iokjAZ003o`000?oooooooooo03?ooooo000Mooooo`03o`000?oooooooooo01_ooooo0_l0
001hokjAZ003o`000?oooooooooo03Cooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0001f
okjAZ003o`000?oooooooooo03Cooooo000Nooooo`03o`000?oooooooooo01kooooo00?o0000okjA
Z?nnTJP0L_nnTJP00ol0003oooooooooo`0eooooo`007oooool00ol0003oooooooooo`0Nooooo`;o
0000LOnnTJP00ol0003oooooooooo`0fooooo`007oooool00ol0003oooooooooo`0Pooooo`03o`00
0?nnTJSo_Y6X06ko_Y6X00?o0000ooooooooool0=_ooool0023ooooo00?o0000ooooooooool08?oo
ool2o`0006go_Y6X00?o0000ooooooooool0=oooool0023ooooo00?o0000ooooooooool08_ooool2
o`0006_o_Y6X00?o0000ooooooooool0=oooool0027ooooo00?o0000ooooooooool08oooool00ol0
003o_Y6XokjAZ01WokjAZ003o`000?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo02Co
oooo0_l0001VokjAZ003o`000?oooooooooo03Wooooo000Rooooo`03o`000?oooooooooo02Gooooo
0_l0001TokjAZ003o`000?oooooooooo03Wooooo000Sooooo`03o`000?oooooooooo02Kooooo00?o
0000okjAZ?nnTJP0H?nnTJP00ol0003oooooooooo`0jooooo`008oooool00ol0003oooooooooo`0W
ooooo`;o0000H?nnTJP00ol0003oooooooooo`0jooooo`009?ooool00ol0003oooooooooo`0Xoooo
o`03o`000?nnTJSo_Y6X05co_Y6X00?o0000ooooooooool0>oooool002Cooooo00?o0000oooooooo
ool0:Oooool2o`0005_o_Y6X00?o0000ooooooooool0??ooool002Gooooo00?o0000ooooooooool0
:_ooool2o`0005Wo_Y6X00?o0000ooooooooool0??ooool002Gooooo00?o0000ooooooooool0;?oo
ool00ol0003o_Y6XokjAZ01EokjAZ003o`000?oooooooooo03gooooo000Vooooo`03o`000?oooooo
oooo02cooooo0_l0001EokjAZ003o`000?oooooooooo03gooooo000Vooooo`03o`000?oooooooooo
02kooooo00?o0000okjAZ?nnTJP0DOnnTJP00ol0003oooooooooo`0nooooo`009oooool00ol0003o
ooooooooo`0^ooooo`;o0000D?nnTJP00ol0003oooooooooo`0oooooo`009oooool00ol0003ooooo
ooooo`0`ooooo`;o0000C_nnTJP00ol0003oooooooooo`0oooooo`00:?ooool00ol0003ooooooooo
o`0aooooo`03o`000?nnTJSo_Y6X04[o_Y6X00?o0000ooooooooool0@?ooool002Wooooo00?o0000
ooooooooool0<Oooool2o`0004[o_Y6X00?o0000ooooooooool0@?ooool002Wooooo00?o0000oooo
ooooool0<oooool2o`0004Oo_Y6X00?o0000ooooooooool0@Oooool002[ooooo00?o0000oooooooo
ool0=?ooool00ol0003o_Y6XokjAZ013okjAZ003o`000?oooooooooo04;ooooo000Zooooo`03o`00
0?oooooooooo03Gooooo0_l00013okjAZ003o`000?oooooooooo04;ooooo000[ooooo`03o`000?oo
oooooooo03Kooooo00?o0000okjAZ?nnTJP0?onnTJP00ol0003oooooooooo`13ooooo`00:oooool0
0ol0003oooooooooo`0gooooo`;o0000?onnTJP00ol0003oooooooooo`13ooooo`00;?ooool00ol0
003oooooooooo`0hooooo`;o0000??nnTJP00ol0003oooooooooo`14ooooo`00;?ooool00ol0003o
ooooooooo`0jooooo`03o`000?nnTJSo_Y6X03So_Y6X00?o0000ooooooooool0AOooool002gooooo
00?o0000ooooooooool0>_ooool2o`0003So_Y6X00?o0000ooooooooool0AOooool002kooooo00?o
0000ooooooooool0>oooool00ol0003o_Y6XokjAZ00dokjAZ003o`000?oooooooooo04Kooooo000^
ooooo`03o`000?oooooooooo03cooooo0_l0000dokjAZ003o`000?oooooooooo04Kooooo000_oooo
o`03o`000?oooooooooo03gooooo0_l0000aokjAZ003o`000?oooooooooo04Oooooo000_ooooo`03
o`000?oooooooooo03oooooo00?o0000okjAZ?nnTJP0;OnnTJP00ol0003oooooooooo`18ooooo`00
<?ooool00ol0003oooooooooo`0oooooo`;o0000;OnnTJP00ol0003oooooooooo`18ooooo`00<?oo
ool00ol0003oooooooooo`11ooooo`;o0000:_nnTJP00ol0003oooooooooo`19ooooo`00<Oooool0
0ol0003oooooooooo`12ooooo`03o`000?nnTJSo_Y6X02Oo_Y6X00?o0000ooooooooool0BOooool0
037ooooo00?o0000ooooooooool0@oooool2o`0002Ko_Y6X00?o0000ooooooooool0B_ooool003;o
oooo00?o0000ooooooooool0A?ooool00ol0003o_Y6XokjAZ00RokjAZ003o`000?oooooooooo04_o
oooo000booooo`03o`000?oooooooooo04Gooooo0_l0000RokjAZ003o`000?oooooooooo04_ooooo
000cooooo`03o`000?oooooooooo04Kooooo0_l0000OokjAZ003o`000?oooooooooo04cooooo000d
ooooo`03o`000?oooooooooo04Kooooo0_l0000NokjAZ003o`000?oooooooooo04cooooo000doooo
o`03o`000?oooooooooo04Kooooo00Co0000ooooool0003o00006onnTJP00ol0003oooooooooo`1=
ooooo`00=Oooool00ol0003oooooooooo`15ooooo`05o`000?ooooooooooooooool000006OnnTJP0
0ol0003oooooooooo`1>ooooo`00=Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
00;ooooo0_l0000GokjAZ003o`000?oooooooooo04kooooo000fooooo`03o`000?oooooooooo04Co
oooo00?o0000ooooooooool01?ooool2o`0001Co_Y6X00?o0000ooooooooool0Coooool003Kooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`06ooooo`03o`000?nnTJSo_Y6X017o_Y6X
00?o0000ooooooooool0Coooool003Oooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`07ooooo`;o00004?nnTJP00ol0003oooooooooo`1@ooooo`00=oooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo00Sooooo0ol0000=okjAZ003o`000?oooooooooo057ooooo000hoooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02?ooool4o`0000co_Y6X00?o0000oooo
ooooool0DOooool003Sooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`07ooooo`Oo
00002OnnTJP00ol0003oooooooooo`1Booooo`00>Oooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo00Kooooo2Ol00008okjAZ003o`000?oooooooooo05;ooooo000jooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool01_ooool;o`0000Go_Y6X00?o0000ooooooooool0Dooo
ool003[ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`05ooooo`ko00000_nnTJP0
0ol0003oooooooooo`1Dooooo`00>oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00Gooooo3ol000000onnTJSo0000ooooo`1Eooooo`00>oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00Cooooo4Ol0001Gooooo`00??ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo00?ooooo4?l0001Iooooo`00??ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo00?ooooo3_l0001Kooooo`00?Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo3Ol0001Mooooo`00?Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
00;ooooo2ol0001Oooooo`00?_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00_o
0000HOooool003oooooo00?o0000ooooooooool0>_ooool<o`0006Cooooo000oooooo`03o`000?oo
oooooooo03Kooooo1?l000001?oooooo0000ooooooooool6o`0006Kooooo0010ooooo`03o`000?oo
oooooooo03;ooooo0ol00005ooooo`03o`000?oooooo000000Co0000J?ooool0043ooooo00?o0000
ooooooooool0;_ooool4o`0000Sooooo00?o0000ooooool000000_l0001Zooooo`00@Oooool00ol0
003oooooooooo`0Yooooo`Co00003?ooool3o`0006cooooo0011ooooo`03o`000?oooooooooo02Ko
oooo0ol0000=ooooo`Co0000K_ooool004;ooooo00?o0000ooooooooool08Oooool4o`0000_ooooo
1Ol0001booooo`00@_ooool00ol0003oooooooooo`0Mooooo`Co00002Oooool6o`0007Oooooo0013
ooooo`03o`000?oooooooooo01Wooooo0ol00008ooooo`Go0000OOooool004?ooooo00?o0000oooo
ooooool05Oooool4o`0000Kooooo1Ol00022ooooo`00A?ooool00ol0003oooooooooo`0@ooooo`Co
00001?ooool6o`0008Oooooo0015ooooo`03o`000?oooooooooo00cooooo0ol00003ooooo`Go0000
SOooool004Gooooo00?o0000ooooooooool02?ooool:o`0009;ooooo0016ooooo`03o`000?oooooo
oooo00?ooooo2?l0002Hooooo`00A_ooool00ol0003oooooooooo`06o`0009gooooo0017ooooo`?o
0000X_ooool00>cooooo003/ooooo`00k?ooool00>cooooo003/ooooo`00k?ooool00>cooooo003/
ooooo`00k?ooool00>cooooo003/ooooo`00k?ooool00>cooooo003/ooooo`00k?ooool00>cooooo
003/ooooo`00k?ooool00>cooooo003/ooooo`00k?ooool00>cooooo003/ooooo`00k?ooool00>co
oooo003/ooooo`00k?ooool00>cooooo003/ooooo`00k?ooool00>cooooo003/ooooo`00k?ooool0
0>cooooo003/ooooo`00k?ooool00>cooooo003/ooooo`00k?ooool00>cooooo0000\
\>"],
  ImageRangeCache->{{{0, 280.562}, {390.125, -45.4375}} -> {0.105848, \
-0.221592, 0.00266209, 0.00266209}},
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AnalyzeSystem[SolidCornerCube[50,37.5]];", "Input",
  CellTags->"Prism Examples"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.23418 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.120053 1.30829 -1.11022e-16 1.30829 [
[ 0 0 0 0 ]
[ 1 1.23418 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.23418 L
0 1.23418 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.43907 .68631 m
.44419 .7031 L
s
.43367 .66998 m
.43907 .68631 L
s
.42803 .65405 m
.43367 .66998 L
s
.44419 .7031 m
.44904 .72037 L
s
.42904 .65683 m
.45359 .7382 L
s
.39605 .57958 m
.42904 .65683 L
s
.42213 .63849 m
.42803 .65405 L
s
.44904 .72037 m
.45359 .7382 L
s
.42146 .63679 m
.42213 .63849 L
s
.42078 .63509 m
.42146 .63679 L
s
.4201 .63339 m
.42078 .63509 L
s
.41943 .63169 m
.4201 .63339 L
s
.4912 .72652 m
.45359 .7382 L
s
.45359 .7382 m
.45768 .75605 L
s
.45359 .7382 m
.46853 .81996 L
s
.41874 .63001 m
.41943 .63169 L
s
.41806 .62832 m
.41874 .63001 L
s
.41756 .62712 m
.41806 .62832 L
s
.41707 .62592 m
.41756 .62712 L
s
.41658 .62472 m
.41707 .62592 L
s
.41608 .62353 m
.41658 .62472 L
s
.41558 .62234 m
.41608 .62353 L
s
.41508 .62115 m
.41558 .62234 L
s
.41471 .62025 m
.41508 .62115 L
s
.41433 .61936 m
.41471 .62025 L
s
.41395 .61847 m
.41433 .61936 L
s
.41357 .61759 m
.41395 .61847 L
s
.41319 .6167 m
.41357 .61759 L
s
.41281 .61581 m
.41319 .6167 L
s
.41252 .61512 m
.41281 .61581 L
s
.45768 .75605 m
.46122 .77338 L
s
.41222 .61444 m
.41252 .61512 L
s
.41192 .61375 m
.41222 .61444 L
s
.41163 .61306 m
.41192 .61375 L
s
.41133 .61238 m
.41163 .61306 L
s
.41103 .61169 m
.41133 .61238 L
s
.40862 .60624 m
.41103 .61169 L
s
.40617 .60082 m
.40862 .60624 L
s
.40369 .59545 m
.40617 .60082 L
s
.46122 .77338 m
.46424 .79025 L
s
.40118 .59012 m
.40369 .59545 L
s
.39863 .58483 m
.40118 .59012 L
s
.39605 .57958 m
.39863 .58483 L
s
.46424 .79025 m
.46678 .8067 L
s
.38398 .55643 m
.39605 .57958 L
s
.356 .51016 m
.39605 .57958 L
s
.52927 .71469 m
.4912 .72652 L
s
.46678 .8067 m
.46886 .82277 L
s
.46853 .81996 m
.47291 .89824 L
s
.37115 .53404 m
.38398 .55643 L
s
.46886 .82277 m
.47051 .83849 L
s
.47051 .83849 m
.47066 .84022 L
s
.47066 .84022 m
.47082 .84194 L
s
.56782 .70272 m
.52927 .71469 L
s
.47082 .84194 m
.47096 .84366 L
s
.47096 .84366 m
.4711 .84537 L
s
.4711 .84537 m
.47124 .84708 L
s
.35749 .5124 m
.37115 .53404 L
s
.47124 .84708 m
.47137 .84878 L
s
.47137 .84878 m
.47146 .85 L
s
.47146 .85 m
.47155 .85121 L
s
.47155 .85121 m
.47163 .85243 L
s
.47163 .85243 m
.47171 .85364 L
s
.47171 .85364 m
.47179 .85485 L
s
.47179 .85485 m
.47187 .85605 L
s
.47187 .85605 m
.47192 .85696 L
s
.47192 .85696 m
.47198 .85786 L
s
.47198 .85786 m
.47203 .85876 L
s
.47203 .85876 m
.47208 .85966 L
s
.47208 .85966 m
.47213 .86056 L
s
.47213 .86056 m
.47218 .86146 L
s
.47218 .86146 m
.47222 .86215 L
s
.47222 .86215 m
.47225 .86285 L
s
.47225 .86285 m
.47229 .86355 L
s
.47229 .86355 m
.47232 .86424 L
s
.47232 .86424 m
.47236 .86494 L
s
.47236 .86494 m
.47239 .86563 L
s
.47239 .86563 m
.47262 .87117 L
s
.48929 .56193 m
.48562 .55965 L
s
.49294 .56422 m
.48929 .56193 L
s
.48562 .55965 m
.48195 .55738 L
s
.47969 .55612 m
.50136 .56942 L
s
.45829 .54239 m
.47969 .55612 L
s
.49658 .56653 m
.49294 .56422 L
s
.48195 .55738 m
.47827 .55513 L
s
.50045 .56878 m
.49658 .56653 L
s
.47827 .55513 m
.47458 .5529 L
s
.47262 .87117 m
.47279 .87666 L
s
.47458 .5529 m
.47112 .5506 L
s
.50431 .57104 m
.50045 .56878 L
s
.50136 .56942 m
.52331 .58236 L
s
.47112 .5506 m
.46764 .54831 L
s
.50816 .57332 m
.50431 .57104 L
s
.34293 .49153 m
.35749 .5124 L
s
.46764 .54831 m
.46415 .54604 L
s
.512 .57561 m
.50816 .57332 L
s
.46415 .54604 m
.46065 .54378 L
s
.51584 .57792 m
.512 .57561 L
s
.60686 .69059 m
.56782 .70272 L
s
.46065 .54378 m
.45714 .54154 L
s
.51967 .58025 m
.51584 .57792 L
s
.43713 .52815 m
.45829 .54239 L
s
.45714 .54154 m
.45362 .53931 L
s
.52372 .58251 m
.51967 .58025 L
s
.45362 .53931 m
.45032 .53701 L
s
.52331 .58236 m
.54555 .59498 L
s
.52777 .58478 m
.52372 .58251 L
s
.31057 .4523 m
.356 .51016 L
s
.45032 .53701 m
.44701 .53473 L
s
.53181 .58708 m
.52777 .58478 L
s
.44701 .53473 m
.44369 .53246 L
s
.53585 .58939 m
.53181 .58708 L
s
.47279 .87666 m
.4729 .88211 L
s
.44369 .53246 m
.44036 .53021 L
s
.53988 .59172 m
.53585 .58939 L
s
.44036 .53021 m
.43702 .52797 L
s
.5439 .59406 m
.53988 .59172 L
s
.41622 .51329 m
.43713 .52815 L
s
.43702 .52797 m
.43366 .52574 L
s
.54816 .59634 m
.5439 .59406 L
s
.54555 .59498 m
.5681 .60732 L
s
.43366 .52574 m
.43053 .52344 L
s
.55241 .59864 m
.54816 .59634 L
s
.43053 .52344 m
.42738 .52116 L
s
.4729 .88211 m
.47296 .88753 L
s
.55666 .60095 m
.55241 .59864 L
s
.42738 .52116 m
.42423 .51889 L
s
.5609 .60328 m
.55666 .60095 L
s
.42423 .51889 m
.42106 .51664 L
s
.56514 .60564 m
.5609 .60328 L
s
.42106 .51664 m
.41788 .51439 L
s
.56937 .60801 m
.56514 .60564 L
s
.41788 .51439 m
.41469 .51216 L
s
.5681 .60732 m
.59099 .61943 L
s
.47296 .88753 m
.47296 .8929 L
s
.57385 .61031 m
.56937 .60801 L
s
.39555 .49767 m
.41622 .51329 L
s
.41469 .51216 m
.41172 .50986 L
s
.57833 .61263 m
.57385 .61031 L
s
.41172 .50986 m
.40874 .50758 L
s
.5828 .61497 m
.57833 .61263 L
s
.40874 .50758 m
.40575 .5053 L
s
.47296 .8929 m
.47291 .89824 L
s
.58727 .61734 m
.5828 .61497 L
s
.40575 .5053 m
.40275 .50304 L
s
.59173 .61972 m
.58727 .61734 L
s
.40275 .50304 m
.39973 .5008 L
s
.59099 .61943 m
.61424 .63131 L
s
.59619 .62212 m
.59173 .61972 L
s
.32735 .47147 m
.34293 .49153 L
s
.39973 .5008 m
.3967 .49856 L
s
.47291 .89824 m
.47196 .9218 L
s
.47291 .89824 m
.466 .96894 L
s
.60092 .62445 m
.59619 .62212 L
s
.64638 .67831 m
.60686 .69059 L
s
.3967 .49856 m
.3939 .49625 L
s
.37515 .48106 m
.39555 .49767 L
s
.60564 .6268 m
.60092 .62445 L
s
.3939 .49625 m
.3911 .49395 L
s
.61036 .62918 m
.60564 .6268 L
s
.3911 .49395 m
.38827 .49167 L
s
.61508 .63158 m
.61036 .62918 L
s
.38827 .49167 m
.38544 .4894 L
s
.61424 .63131 m
.63787 .643 L
s
.61979 .634 m
.61508 .63158 L
s
.38544 .4894 m
.38258 .48714 L
s
.6245 .63644 m
.61979 .634 L
s
.38258 .48714 m
.37972 .4849 L
s
.62951 .6388 m
.6245 .63644 L
s
.37972 .4849 m
.3771 .48257 L
s
.63451 .6412 m
.62951 .6388 L
s
.3771 .48257 m
.37447 .48026 L
s
.35504 .46313 m
.37515 .48106 L
s
.63951 .64361 m
.63451 .6412 L
s
.37447 .48026 m
.37182 .47796 L
s
.63787 .643 m
.66191 .65452 L
s
.64451 .64605 m
.63951 .64361 L
s
.37182 .47796 m
.36915 .47568 L
s
.6495 .64852 m
.64451 .64605 L
s
.47196 .9218 m
.46982 .9446 L
s
.36915 .47568 m
.36647 .47341 L
s
.64638 .67831 m
.68641 .66588 L
s
.31057 .4523 m
.32735 .47147 L
s
.6545 .65101 m
.6495 .64852 L
s
.36647 .47341 m
.36377 .47115 L
s
.65982 .65342 m
.6545 .65101 L
s
.61264 .78021 m
.61549 .77584 L
s
.61004 .78447 m
.61264 .78021 L
s
.61185 .78146 m
.59778 .80386 L
s
.62619 .75885 m
.61185 .78146 L
s
.61549 .77584 m
.61832 .77146 L
s
.61832 .77146 m
.62113 .76706 L
s
.60742 .78871 m
.61004 .78447 L
s
.36377 .47115 m
.36135 .4688 L
s
.62113 .76706 m
.62392 .76264 L
s
.62392 .76264 m
.6267 .7582 L
s
.60478 .79294 m
.60742 .78871 L
s
.6408 .73602 m
.62619 .75885 L
s
.6267 .7582 m
.62945 .75373 L
s
.60213 .79715 m
.60478 .79294 L
s
.62945 .75373 m
.63247 .74916 L
s
.59945 .80134 m
.60213 .79715 L
s
.63247 .74916 m
.63546 .74457 L
s
.59676 .80551 m
.59945 .80134 L
s
.59778 .80386 m
.58397 .82608 L
s
.5943 .80959 m
.59676 .80551 L
s
.63546 .74457 m
.63844 .73996 L
s
.59182 .81365 m
.5943 .80959 L
s
.63844 .73996 m
.6414 .73532 L
s
.65569 .71293 m
.6408 .73602 L
s
.58932 .8177 m
.59182 .81365 L
s
.66514 .65585 m
.65982 .65342 L
s
.6414 .73532 m
.64434 .73066 L
s
.36135 .4688 m
.3589 .46647 L
s
.5868 .82173 m
.58932 .8177 L
s
.64434 .73066 m
.64726 .72597 L
s
.66191 .65452 m
.68641 .66588 L
s
.58427 .82574 m
.5868 .82173 L
s
.64726 .72597 m
.65047 .72117 L
s
.58397 .82608 m
.57042 .84814 L
s
.58172 .82974 m
.58427 .82574 L
s
.65047 .72117 m
.65365 .71634 L
s
.57939 .83365 m
.58172 .82974 L
s
.67046 .65832 m
.66514 .65585 L
s
.65365 .71634 m
.65682 .71148 L
s
.3589 .46647 m
.35644 .46415 L
s
.57705 .83754 m
.57939 .83365 L
s
.67089 .68956 m
.65569 .71293 L
s
.65682 .71148 m
.65997 .7066 L
s
.57468 .84142 m
.57705 .83754 L
s
.65997 .7066 m
.66309 .70169 L
s
.5723 .84528 m
.57468 .84142 L
s
.66309 .70169 m
.6662 .69675 L
s
.67578 .66081 m
.67046 .65832 L
s
.35644 .46415 m
.35396 .46184 L
s
.5699 .84913 m
.5723 .84528 L
s
.6662 .69675 m
.66962 .69169 L
s
.57042 .84814 m
.55712 .87006 L
s
.56748 .85297 m
.5699 .84913 L
s
.33532 .44325 m
.35504 .46313 L
s
.66962 .69169 m
.67302 .68659 L
s
.56528 .85672 m
.56748 .85297 L
s
.68641 .66588 m
.67089 .68956 L
s
.68109 .66333 m
.67578 .66081 L
s
.35396 .46184 m
.35146 .45955 L
s
.56306 .86045 m
.56528 .85672 L
s
.67302 .68659 m
.6764 .68146 L
s
.56083 .86417 m
.56306 .86045 L
s
.6764 .68146 m
.67976 .6763 L
s
.55857 .86788 m
.56083 .86417 L
s
.35146 .45955 m
.34894 .45728 L
s
.68641 .66588 m
.68109 .66333 L
s
.67976 .6763 m
.68309 .67111 L
s
.5563 .87157 m
.55857 .86788 L
s
.68309 .67111 m
.68641 .66588 L
s
.55712 .87006 m
.5441 .89185 L
s
.554 .87525 m
.5563 .87157 L
s
.34894 .45728 m
.34672 .4549 L
s
.68641 .66588 m
.79588 .57033 L
s
.55193 .87884 m
.554 .87525 L
s
.46982 .9446 m
.46643 .96665 L
s
.54984 .88243 m
.55193 .87884 L
s
.34672 .4549 m
.34448 .45254 L
s
.54773 .886 m
.54984 .88243 L
s
.54559 .88955 m
.54773 .886 L
s
.31468 .4508 m
.31057 .4523 L
s
.29336 .43511 m
.31057 .4523 L
s
.26184 .4098 m
.31057 .4523 L
s
.34448 .45254 m
.34222 .45019 L
s
.54344 .89309 m
.54559 .88955 L
s
.5441 .89185 m
.53135 .91354 L
s
.3188 .44929 m
.31468 .4508 L
s
.54127 .89662 m
.54344 .89309 L
s
.34222 .45019 m
.33994 .44786 L
s
.53932 .90007 m
.54127 .89662 L
s
.32292 .44779 m
.3188 .44929 L
s
.53735 .9035 m
.53932 .90007 L
s
.32704 .44628 m
.32292 .44779 L
s
.33994 .44786 m
.33764 .44555 L
s
.53536 .90693 m
.53735 .9035 L
s
.33118 .44476 m
.32704 .44628 L
s
.53335 .91033 m
.53536 .90693 L
s
.33764 .44555 m
.33532 .44325 L
s
.53132 .91373 m
.53335 .91033 L
s
.33532 .44325 m
.33118 .44476 L
s
.53135 .91354 m
.5189 .93514 L
s
.52927 .91711 m
.53132 .91373 L
s
.31921 .42411 m
.33532 .44325 L
s
.33532 .44325 m
.33333 .44086 L
s
.52744 .92041 m
.52927 .91711 L
s
.33333 .44086 m
.33135 .43851 L
s
.52559 .9237 m
.52744 .92041 L
s
.52373 .92698 m
.52559 .9237 L
s
.33135 .43851 m
.32938 .43621 L
s
.46643 .96665 m
.46169 .9879 L
s
.52184 .93024 m
.52373 .92698 L
s
.51993 .93349 m
.52184 .93024 L
s
.466 .96894 m
.44742 1.0277 L
s
.32938 .43621 m
.32741 .43396 L
s
.51799 .93673 m
.51993 .93349 L
s
.5189 .93514 m
.5068 .95666 L
s
.32741 .43396 m
.32546 .43175 L
s
.51629 .93988 m
.51799 .93673 L
s
.27657 .42064 m
.29336 .43511 L
s
.51457 .94302 m
.51629 .93988 L
s
.32546 .43175 m
.32351 .42959 L
s
.51283 .94615 m
.51457 .94302 L
s
.32351 .42959 m
.32189 .42735 L
s
.51106 .94927 m
.51283 .94615 L
s
.50928 .95237 m
.51106 .94927 L
s
.32189 .42735 m
.32027 .42516 L
s
.50747 .95546 m
.50928 .95237 L
s
.32027 .42516 m
.31867 .423 L
s
.5059 .95847 m
.50747 .95546 L
s
.5068 .95666 m
.49512 .97811 L
s
.30822 .40804 m
.31921 .42411 L
s
.50431 .96146 m
.5059 .95847 L
s
.31867 .423 m
.31707 .42089 L
s
.50269 .96444 m
.50431 .96146 L
s
.46169 .9879 m
.45542 1.00829 L
s
.31707 .42089 m
.31547 .41882 L
s
.50105 .9674 m
.50269 .96444 L
s
.49939 .97035 m
.50105 .9674 L
s
.31547 .41882 m
.31389 .41679 L
s
.49771 .97329 m
.49939 .97035 L
s
.26012 .40864 m
.27657 .42064 L
s
.31389 .41679 m
.3126 .41468 L
s
.49628 .97614 m
.49771 .97329 L
s
.3126 .41468 m
.31133 .41262 L
s
.49483 .97898 m
.49628 .97614 L
s
.49512 .97811 m
.48398 .9995 L
s
.49335 .9818 m
.49483 .97898 L
s
.31133 .41262 m
.31006 .4106 L
s
.49185 .9846 m
.49335 .9818 L
s
.31006 .4106 m
.30879 .40861 L
s
.49032 .9874 m
.49185 .9846 L
s
.30879 .40861 m
.30754 .40666 L
s
.3009 .39413 m
.30822 .40804 L
s
.48877 .99017 m
.49032 .9874 L
s
.30754 .40666 m
.30629 .40475 L
s
.45542 1.00829 m
.44742 1.0277 L
s
.48749 .99286 m
.48877 .99017 L
s
.30629 .40475 m
.30532 .40277 L
s
.48619 .99552 m
.48749 .99286 L
s
.21238 .38631 m
.26184 .4098 L
s
.48486 .99818 m
.48619 .99552 L
s
.24395 .39896 m
.26012 .40864 L
s
.30532 .40277 m
.30436 .40082 L
s
.4835 1.00081 m
.48486 .99818 L
s
.30436 .40082 m
.3034 .39892 L
s
.48398 .9995 m
.47363 1.02079 L
s
.48212 1.00344 m
.4835 1.00081 L
s
.3034 .39892 m
.30246 .39704 L
s
.48071 1.00604 m
.48212 1.00344 L
s
.30246 .39704 m
.30152 .39521 L
s
.4796 1.00854 m
.48071 1.00604 L
s
.30152 .39521 m
.30058 .3934 L
s
.47847 1.01103 m
.4796 1.00854 L
s
.29647 .38186 m
.3009 .39413 L
s
.30058 .3934 m
.29992 .39154 L
s
.4773 1.01349 m
.47847 1.01103 L
s
.44742 1.0277 m
.45177 1.02655 L
s
.44742 1.0277 m
.43792 1.04499 L
s
.44742 1.0277 m
.4173 1.07001 L
s
.29992 .39154 m
.29926 .38971 L
s
.47611 1.01594 m
.4773 1.01349 L
s
.45177 1.02655 m
.45613 1.0254 L
s
.45613 1.0254 m
.4605 1.02425 L
s
.22804 .39152 m
.24395 .39896 L
s
.47489 1.01838 m
.47611 1.01594 L
s
.29926 .38971 m
.29861 .38791 L
s
.4605 1.02425 m
.46487 1.0231 L
s
.46487 1.0231 m
.46925 1.02194 L
s
.47363 1.02079 m
.47489 1.01838 L
s
.29861 .38791 m
.29797 .38614 L
s
.46925 1.02194 m
.47363 1.02079 L
s
.47363 1.02079 m
.46592 1.03853 L
s
.47271 1.02307 m
.47363 1.02079 L
s
.29797 .38614 m
.29733 .38441 L
s
.47178 1.02531 m
.47271 1.02307 L
s
.29733 .38441 m
.29671 .38272 L
s
.47083 1.02749 m
.47178 1.02531 L
s
.29671 .38272 m
.29634 .38096 L
s
.29443 .37093 m
.29647 .38186 L
s
.46986 1.02963 m
.47083 1.02749 L
s
.29634 .38096 m
.29598 .37923 L
s
.46888 1.03171 m
.46986 1.02963 L
s
.29598 .37923 m
.29563 .37754 L
s
.43792 1.04499 m
.42745 1.05939 L
s
.46788 1.03375 m
.46888 1.03171 L
s
.21238 .38631 m
.22804 .39152 L
s
.29563 .37754 m
.29528 .37588 L
s
.46721 1.03566 m
.46788 1.03375 L
s
.29528 .37588 m
.29495 .37425 L
s
.46652 1.03752 m
.46721 1.03566 L
s
.29495 .37425 m
.29462 .37265 L
s
.46582 1.03933 m
.46652 1.03752 L
s
.46592 1.03853 m
.46146 1.05098 L
s
.29462 .37265 m
.29454 .371 L
s
.46511 1.0411 m
.46582 1.03933 L
s
.29454 .371 m
.29448 .36937 L
s
.29448 .36113 m
.29443 .37093 L
s
.46438 1.04283 m
.46511 1.0411 L
s
.29448 .36937 m
.29442 .36778 L
s
.46364 1.04451 m
.46438 1.04283 L
s
.29442 .36778 m
.29437 .36622 L
s
.20893 .38546 m
.21238 .38631 L
s
.16526 .38509 m
.21238 .38631 L
s
.4632 1.04607 m
.46364 1.04451 L
s
.42745 1.05939 m
.41605 1.07114 L
s
.29437 .36622 m
.29433 .36469 L
s
.46274 1.04758 m
.4632 1.04607 L
s
.20549 .38472 m
.20893 .38546 L
s
.29433 .36469 m
.2943 .36319 L
s
.46227 1.04905 m
.46274 1.04758 L
s
.2943 .36319 m
.29453 .36164 L
s
.46179 1.05048 m
.46227 1.04905 L
s
.20206 .38409 m
.20549 .38472 L
s
.4613 1.05187 m
.46179 1.05048 L
s
.29453 .36164 m
.29476 .36011 L
s
.46146 1.05098 m
.45935 1.05961 L
s
.2964 .35233 m
.29448 .36113 L
s
.19865 .38358 m
.20206 .38409 L
s
.4608 1.05322 m
.4613 1.05187 L
s
.29476 .36011 m
.295 .35862 L
s
.46057 1.05445 m
.4608 1.05322 L
s
.19524 .38318 m
.19865 .38358 L
s
.295 .35862 m
.29525 .35716 L
s
.4173 1.07001 m
.37652 1.09154 L
s
.46034 1.05564 m
.46057 1.05445 L
s
.29525 .35716 m
.29551 .35573 L
s
.41605 1.07114 m
.40375 1.08038 L
s
.19185 .38291 m
.19524 .38318 L
s
.46009 1.05679 m
.46034 1.05564 L
s
.29551 .35573 m
.29579 .35434 L
s
.45983 1.0579 m
.46009 1.05679 L
s
.19143 .38288 m
.19185 .38291 L
s
.19101 .38286 m
.19143 .38288 L
s
.29579 .35434 m
.29631 .35288 L
s
.19058 .38283 m
.19101 .38286 L
s
.19016 .38281 m
.19058 .38283 L
s
.18974 .38279 m
.19016 .38281 L
s
.45957 1.05897 m
.45983 1.0579 L
s
.18932 .38278 m
.18974 .38279 L
s
.18878 .38276 m
.18932 .38278 L
s
.18823 .38274 m
.18878 .38276 L
s
.29631 .35288 m
.29685 .35145 L
s
.18769 .38273 m
.18823 .38274 L
s
.18715 .38272 m
.18769 .38273 L
s
.30005 .34442 m
.2964 .35233 L
s
.45929 1.05999 m
.45957 1.05897 L
s
.18661 .38271 m
.18715 .38272 L
s
.18607 .38271 m
.18661 .38271 L
s
.45935 1.05961 m
.45911 1.06522 L
s
.29685 .35145 m
.2974 .35006 L
s
.18535 .38271 m
.18607 .38271 L
s
.45928 1.06091 m
.45929 1.05999 L
s
.18463 .38271 m
.18535 .38271 L
s
.18391 .38272 m
.18463 .38271 L
s
.18319 .38274 m
.18391 .38272 L
s
.2974 .35006 m
.29796 .3487 L
s
.18247 .38276 m
.18319 .38274 L
s
.45925 1.06179 m
.45928 1.06091 L
s
.18175 .38279 m
.18247 .38276 L
s
.18075 .38284 m
.18175 .38279 L
s
.29796 .3487 m
.29852 .34738 L
s
.45922 1.06262 m
.45925 1.06179 L
s
.17975 .3829 m
.18075 .38284 L
s
.40375 1.08038 m
.39058 1.08718 L
s
.17875 .38297 m
.17975 .3829 L
s
.29852 .34738 m
.29911 .34608 L
s
.17775 .38305 m
.17875 .38297 L
s
.45918 1.06342 m
.45922 1.06262 L
s
.17675 .38315 m
.17775 .38305 L
s
.17575 .38325 m
.17675 .38315 L
s
.29911 .34608 m
.29995 .34473 L
s
.45913 1.06418 m
.45918 1.06342 L
s
.16682 .38473 m
.17575 .38325 L
s
.45907 1.0649 m
.45913 1.06418 L
s
.29995 .34473 m
.3008 .3434 L
s
.30531 .33733 m
.30005 .34442 L
s
.45926 1.06551 m
.45907 1.0649 L
s
.3008 .3434 m
.30167 .34211 L
s
.45911 1.06522 m
.46043 1.06833 L
s
.45945 1.06608 m
.45926 1.06551 L
s
.30167 .34211 m
.30254 .34086 L
s
.45963 1.06661 m
.45945 1.06608 L
s
.158 .3872 m
.16682 .38473 L
s
.30254 .34086 m
.30343 .33963 L
s
.39058 1.08718 m
.37652 1.09154 L
s
.4598 1.06711 m
.45963 1.06661 L
s
.12405 .40846 m
.16526 .38509 L
s
.30343 .33963 m
.30433 .33845 L
s
.45996 1.06756 m
.4598 1.06711 L
s
.30433 .33845 m
.30551 .33719 L
s
.46012 1.06797 m
.45996 1.06756 L
s
.31213 .33101 m
.30531 .33733 L
s
.30551 .33719 m
.30669 .33598 L
s
.46052 1.06828 m
.46012 1.06797 L
s
.1493 .39071 m
.158 .3872 L
s
.30669 .33598 m
.30789 .33479 L
s
.46092 1.06855 m
.46052 1.06828 L
s
.46043 1.06833 m
.46314 1.06925 L
s
.30789 .33479 m
.30911 .33364 L
s
.46131 1.06878 m
.46092 1.06855 L
s
.4617 1.06896 m
.46131 1.06878 L
s
.30911 .33364 m
.31033 .33253 L
s
.37652 1.09154 m
.37327 1.09217 L
s
.37652 1.09154 m
.32697 1.08862 L
s
.46207 1.06911 m
.4617 1.06896 L
s
.31033 .33253 m
.31157 .33146 L
s
.14073 .39536 m
.1493 .39071 L
s
.37327 1.09217 m
.36998 1.09268 L
s
.46244 1.06922 m
.46207 1.06911 L
s
.31157 .33146 m
.3131 .33031 L
s
.32045 .32544 m
.31213 .33101 L
s
.46306 1.06922 m
.46244 1.06922 L
s
.36998 1.09268 m
.36665 1.09307 L
s
.3131 .33031 m
.31464 .3292 L
s
.46367 1.06918 m
.46306 1.06922 L
s
.46314 1.06925 m
.46709 1.0682 L
s
.36665 1.09307 m
.36327 1.09332 L
s
.31464 .3292 m
.31619 .32813 L
s
.46427 1.0691 m
.46367 1.06918 L
s
.1323 .40124 m
.14073 .39536 L
s
.31619 .32813 m
.31777 .3271 L
s
.36327 1.09332 m
.35984 1.09345 L
s
.46487 1.06898 m
.46427 1.0691 L
s
.31777 .3271 m
.31935 .32611 L
s
.46546 1.06882 m
.46487 1.06898 L
s
.35984 1.09345 m
.35637 1.09346 L
s
.31935 .32611 m
.32096 .32515 L
s
.46604 1.06862 m
.46546 1.06882 L
s
.35637 1.09346 m
.35593 1.09345 L
s
.35593 1.09345 m
.35549 1.09344 L
s
.33025 .32058 m
.32045 .32544 L
s
.35549 1.09344 m
.35506 1.09342 L
s
.46688 1.06831 m
.46604 1.06862 L
s
.35506 1.09342 m
.35462 1.09341 L
s
.32096 .32515 m
.32286 .32412 L
s
.35462 1.09341 m
.35418 1.09339 L
s
.35418 1.09339 m
.35374 1.09337 L
s
.12405 .40846 m
.1323 .40124 L
s
.35374 1.09337 m
.35317 1.09334 L
s
.35317 1.09334 m
.3526 1.09331 L
s
.3526 1.09331 m
.35203 1.09328 L
s
.46771 1.06795 m
.46688 1.06831 L
s
.35203 1.09328 m
.35146 1.09324 L
s
.32286 .32412 m
.32479 .32313 L
s
.35146 1.09324 m
.35088 1.0932 L
s
.46709 1.0682 m
.47218 1.06535 L
s
.35088 1.0932 m
.35031 1.09315 L
s
.35031 1.09315 m
.34954 1.09309 L
s
.46854 1.06756 m
.46771 1.06795 L
s
.34954 1.09309 m
.34877 1.09302 L
s
.32479 .32313 m
.32673 .32218 L
s
.34877 1.09302 m
.348 1.09294 L
s
.348 1.09294 m
.34723 1.09285 L
s
.34723 1.09285 m
.34645 1.09276 L
s
.46935 1.06712 m
.46854 1.06756 L
s
.34645 1.09276 m
.34567 1.09267 L
s
.32673 .32218 m
.32869 .32127 L
s
.34567 1.09267 m
.34458 1.09252 L
s
.34458 1.09252 m
.34348 1.09236 L
s
.47017 1.06664 m
.46935 1.06712 L
s
.34348 1.09236 m
.34238 1.09219 L
s
.16585 .39235 m
.12405 .40846 L
s
.11625 .41689 m
.12405 .40846 L
s
.09253 .45708 m
.12405 .40846 L
s
.32869 .32127 m
.33066 .32041 L
s
.34238 1.09219 m
.34128 1.09201 L
s
.47097 1.06612 m
.47017 1.06664 L
s
.34128 1.09201 m
.34017 1.09182 L
s
.34017 1.09182 m
.33905 1.09161 L
s
.34152 .31642 m
.33025 .32058 L
s
.33066 .32041 m
.33266 .31958 L
s
.33905 1.09161 m
.32882 1.08916 L
s
.47203 1.06549 m
.47097 1.06612 L
s
.33266 .31958 m
.33498 .31868 L
s
.47309 1.06481 m
.47203 1.06549 L
s
.47218 1.06535 m
.47836 1.06079 L
s
.47415 1.06409 m
.47309 1.06481 L
s
.33498 .31868 m
.33732 .31782 L
s
.10915 .42622 m
.11625 .41689 L
s
.20827 .37601 m
.16585 .39235 L
s
.47519 1.06332 m
.47415 1.06409 L
s
.33732 .31782 m
.33969 .31701 L
s
.32882 1.08916 m
.31821 1.08563 L
s
.32697 1.08862 m
.27173 1.05905 L
s
.47624 1.06251 m
.47519 1.06332 L
s
.33969 .31701 m
.34207 .31623 L
s
.47727 1.06166 m
.47624 1.06251 L
s
.35427 .31297 m
.34152 .31642 L
s
.34207 .31623 m
.34448 .31551 L
s
.47858 1.06068 m
.47727 1.06166 L
s
.1027 .43641 m
.10915 .42622 L
s
.25131 .35943 m
.20827 .37601 L
s
.34448 .31551 m
.34691 .31483 L
s
.31821 1.08563 m
.30723 1.08094 L
s
.47836 1.06079 m
.48559 1.05461 L
s
.47988 1.05967 m
.47858 1.06068 L
s
.34691 .31483 m
.34969 .31406 L
s
.48117 1.0586 m
.47988 1.05967 L
s
.48246 1.05749 m
.48117 1.0586 L
s
.34969 .31406 m
.3525 .31335 L
s
.09687 .44742 m
.1027 .43641 L
s
.48374 1.05633 m
.48246 1.05749 L
s
.30723 1.08094 m
.29583 1.07502 L
s
.3525 .31335 m
.35533 .31268 L
s
.29498 .3426 m
.25131 .35943 L
s
.48502 1.05512 m
.48374 1.05633 L
s
.36852 .31022 m
.35427 .31297 L
s
.35533 .31268 m
.35819 .31207 L
s
.48658 1.05379 m
.48502 1.05512 L
s
.48559 1.05461 m
.49382 1.04686 L
s
.35819 .31207 m
.36108 .3115 L
s
.09165 .45921 m
.09687 .44742 L
s
.48813 1.05241 m
.48658 1.05379 L
s
.29583 1.07502 m
.28401 1.06777 L
s
.36108 .3115 m
.36399 .31098 L
s
.48968 1.05098 m
.48813 1.05241 L
s
.3393 .32552 m
.29498 .3426 L
s
.36399 .31098 m
.3673 .31038 L
s
.49123 1.0495 m
.48968 1.05098 L
s
.07426 .52921 m
.09253 .45708 L
s
.08702 .47176 m
.09165 .45921 L
s
.49277 1.04797 m
.49123 1.0495 L
s
.3673 .31038 m
.37064 .30983 L
s
.28401 1.06777 m
.27173 1.05905 L
s
.38429 .30819 m
.36852 .31022 L
s
.4943 1.04638 m
.49277 1.04797 L
s
.37064 .30983 m
.374 .30933 L
s
.49382 1.04686 m
.50304 1.03756 L
s
.49614 1.04466 m
.4943 1.04638 L
s
.38429 .30819 m
.3393 .32552 L
s
.374 .30933 m
.3774 .30889 L
s
.79588 .57033 m
.38429 .30819 L
s
.5498 .98506 m
.79588 .57033 L
s
.08654 .4732 m
.08702 .47176 L
s
.08607 .47465 m
.08654 .4732 L
s
.49797 1.04289 m
.49614 1.04466 L
s
.0856 .47611 m
.08607 .47465 L
s
.08515 .47758 m
.0856 .47611 L
s
.31633 1.04718 m
.27173 1.05905 L
s
.27173 1.05905 m
.25938 1.04907 L
s
.27173 1.05905 m
.21502 1.00298 L
s
.3774 .30889 m
.38083 .30851 L
s
.08469 .47905 m
.08515 .47758 L
s
.4998 1.04107 m
.49797 1.04289 L
s
.08425 .48054 m
.08469 .47905 L
s
.08394 .48161 m
.08425 .48054 L
s
.08363 .48268 m
.08394 .48161 L
s
.08333 .48375 m
.08363 .48268 L
s
.38083 .30851 m
.38429 .30819 L
s
.50162 1.03919 m
.4998 1.04107 L
s
.08302 .48483 m
.08333 .48375 L
s
.08273 .48592 m
.08302 .48483 L
s
.08243 .48701 m
.08273 .48592 L
s
.08221 .48783 m
.08243 .48701 L
s
.082 .48865 m
.08221 .48783 L
s
.50344 1.03725 m
.50162 1.03919 L
s
.08178 .48947 m
.082 .48865 L
s
.38429 .30819 m
.37808 .31166 L
s
.35588 .32448 m
.38429 .30819 L
s
.08157 .4903 m
.08178 .48947 L
s
.08136 .49113 m
.08157 .4903 L
s
.08115 .49197 m
.08136 .49113 L
s
.37808 .31166 m
.37189 .31517 L
s
.08099 .49261 m
.08115 .49197 L
s
.25938 1.04907 m
.24735 1.03818 L
s
.08083 .49327 m
.08099 .49261 L
s
.50304 1.03756 m
.51324 1.02674 L
s
.08068 .49392 m
.08083 .49327 L
s
.37189 .31517 m
.36572 .31873 L
s
.08052 .49457 m
.08068 .49392 L
s
.50525 1.03526 m
.50344 1.03725 L
s
.08036 .49523 m
.08052 .49457 L
s
.08021 .49589 m
.08036 .49523 L
s
.36572 .31873 m
.35958 .32233 L
s
.07902 .5012 m
.08021 .49589 L
s
.36161 1.03513 m
.31633 1.04718 L
s
.35958 .32233 m
.35347 .32597 L
s
.32852 .34166 m
.35588 .32448 L
s
.35347 .32597 m
.34738 .32965 L
s
.50739 1.03313 m
.50525 1.03526 L
s
.34738 .32965 m
.34169 .33324 L
s
.07791 .50661 m
.07902 .5012 L
s
.34169 .33324 m
.33602 .33686 L
s
.33602 .33686 m
.33037 .34052 L
s
.50952 1.03093 m
.50739 1.03313 L
s
.07688 .51211 m
.07791 .50661 L
s
.33037 .34052 m
.32475 .34422 L
s
.30224 .35974 m
.32852 .34166 L
s
.24735 1.03818 m
.23563 1.02643 L
s
.32475 .34422 m
.31915 .34796 L
s
.31915 .34796 m
.31357 .35174 L
s
.51165 1.02868 m
.50952 1.03093 L
s
.07592 .51772 m
.07688 .51211 L
s
.31357 .35174 m
.30836 .35542 L
s
.30836 .35542 m
.30317 .35915 L
s
.30317 .35915 m
.29801 .3629 L
s
.07505 .52341 m
.07592 .51772 L
s
.27707 .37876 m
.30224 .35974 L
s
.51377 1.02636 m
.51165 1.02868 L
s
.29801 .3629 m
.29286 .3667 L
s
.40758 1.0229 m
.36161 1.03513 L
s
.29286 .3667 m
.28774 .37053 L
s
.07426 .52921 m
.07505 .52341 L
s
.28774 .37053 m
.28263 .3744 L
s
.51324 1.02674 m
.52443 1.0144 L
s
.23563 1.02643 m
.22421 1.01389 L
s
.51589 1.02398 m
.51377 1.02636 L
s
.28263 .3744 m
.27787 .37818 L
s
.27787 .37818 m
.27313 .38199 L
s
.25308 .39873 m
.27707 .37876 L
s
.07169 .55647 m
.07426 .52921 L
s
.07192 .62025 m
.07426 .52921 L
s
.27313 .38199 m
.26841 .38584 L
s
.51801 1.02154 m
.51589 1.02398 L
s
.26841 .38584 m
.26371 .38972 L
s
.26371 .38972 m
.25904 .39364 L
s
.25904 .39364 m
.25438 .39759 L
s
.25438 .39759 m
.25005 .40146 L
s
.23033 .41971 m
.25308 .39873 L
s
.52048 1.01894 m
.51801 1.02154 L
s
.22421 1.01389 m
.21308 1.00058 L
s
.25005 .40146 m
.24574 .40536 L
s
.24574 .40536 m
.24145 .4093 L
s
.24145 .4093 m
.23718 .41327 L
s
.52294 1.01628 m
.52048 1.01894 L
s
.45426 1.01048 m
.40758 1.0229 L
s
.23718 .41327 m
.23293 .41727 L
s
.23293 .41727 m
.2287 .4213 L
s
.20891 .44175 m
.23033 .41971 L
s
.2287 .4213 m
.22478 .42525 L
s
.21502 1.00298 m
.16192 .92358 L
s
.22478 .42525 m
.22088 .42924 L
s
.07082 .58568 m
.07169 .55647 L
s
.52541 1.01354 m
.52294 1.01628 L
s
.22088 .42924 m
.21701 .43326 L
s
.21308 1.00058 m
.20225 .98654 L
s
.21701 .43326 m
.21315 .43731 L
s
.52443 1.0144 m
.53661 1.00051 L
s
.21315 .43731 m
.20932 .44139 L
s
.20932 .44139 m
.2055 .4455 L
s
.18893 .46493 m
.20891 .44175 L
s
.52787 1.01074 m
.52541 1.01354 L
s
.2055 .4455 m
.20199 .44954 L
s
.20199 .44954 m
.1985 .45361 L
s
.1985 .45361 m
.19503 .4577 L
s
.53032 1.00787 m
.52787 1.01074 L
s
.19503 .4577 m
.19158 .46183 L
s
.20225 .98654 m
.20106 .98493 L
s
.19158 .46183 m
.18816 .46599 L
s
.20106 .98493 m
.19988 .98332 L
s
.17055 .48933 m
.18893 .46493 L
s
.19988 .98332 m
.1987 .9817 L
s
.18816 .46599 m
.18475 .47018 L
s
.1987 .9817 m
.19753 .98007 L
s
.50166 .99787 m
.45426 1.01048 L
s
.18475 .47018 m
.18164 .4743 L
s
.19753 .98007 m
.19636 .97843 L
s
.53277 1.00493 m
.53032 1.00787 L
s
.07172 .61684 m
.07082 .58568 L
s
.18164 .4743 m
.17856 .47844 L
s
.19636 .97843 m
.19519 .97679 L
s
.19519 .97679 m
.19436 .97561 L
s
.17856 .47844 m
.17549 .48262 L
s
.19436 .97561 m
.19353 .97442 L
s
.19353 .97442 m
.1927 .97323 L
s
.17549 .48262 m
.17245 .48683 L
s
.1927 .97323 m
.19188 .97204 L
s
.17245 .48683 m
.16943 .49106 L
s
.19188 .97204 m
.19105 .97084 L
s
.15394 .51508 m
.17055 .48933 L
s
.19105 .97084 m
.19023 .96964 L
s
.53562 1.00181 m
.53277 1.00493 L
s
.16943 .49106 m
.16643 .49533 L
s
.19023 .96964 m
.18962 .96873 L
s
.18962 .96873 m
.189 .96782 L
s
.189 .96782 m
.18839 .96691 L
s
.16643 .49533 m
.16373 .49952 L
s
.18839 .96691 m
.18778 .966 L
s
.18778 .966 m
.18717 .96509 L
s
.16373 .49952 m
.16105 .50374 L
s
.18717 .96509 m
.18656 .96417 L
s
.18656 .96417 m
.18608 .96346 L
s
.18608 .96346 m
.18561 .96274 L
s
.16105 .50374 m
.15839 .508 L
s
.18561 .96274 m
.18514 .96202 L
s
.18514 .96202 m
.18466 .9613 L
s
.18466 .9613 m
.18419 .96058 L
s
.18419 .96058 m
.18372 .95986 L
s
.15839 .508 m
.15576 .51228 L
s
.53846 .99862 m
.53562 1.00181 L
s
.18372 .95986 m
.17998 .95404 L
s
.15576 .51228 m
.15315 .51659 L
s
.13937 .54233 m
.15394 .51508 L
s
.53661 1.00051 m
.5498 .98506 L
s
.15315 .51659 m
.15056 .52093 L
s
.17998 .95404 m
.17628 .94812 L
s
.07453 .65001 m
.07172 .61684 L
s
.15056 .52093 m
.14827 .5252 L
s
.14827 .5252 m
.146 .5295 L
s
.08667 .72275 m
.07192 .62025 L
s
.5413 .99535 m
.53846 .99862 L
s
.17628 .94812 m
.17263 .94212 L
s
.146 .5295 m
.14376 .53383 L
s
.14376 .53383 m
.14154 .53818 L
s
.50166 .99787 m
.5498 .98506 L
s
.14154 .53818 m
.13935 .54257 L
s
.17263 .94212 m
.16902 .93603 L
s
.12715 .57128 m
.13937 .54233 L
s
.13935 .54257 m
.13718 .54699 L
s
.13718 .54699 m
.13531 .55133 L
s
.54414 .992 m
.5413 .99535 L
s
.16902 .93603 m
.16545 .92985 L
s
.13531 .55133 m
.13347 .5557 L
s
.13347 .5557 m
.13165 .56011 L
s
.16545 .92985 m
.16192 .92358 L
s
.13165 .56011 m
.12986 .56454 L
s
.12986 .56454 m
.1281 .569 L
s
.07943 .68527 m
.07453 .65001 L
s
.16192 .92358 m
.14661 .89433 L
s
.16192 .92358 m
.11764 .82721 L
s
.54697 .98857 m
.54414 .992 L
s
.1281 .569 m
.12636 .57349 L
s
.11777 .60223 m
.12715 .57128 L
s
.12636 .57349 m
.12493 .57791 L
s
.12493 .57791 m
.12353 .58236 L
s
.12353 .58236 m
.12216 .58684 L
s
.12216 .58684 m
.12082 .59134 L
s
.5498 .98506 m
.54697 .98857 L
s
.12082 .59134 m
.1195 .59588 L
s
.1195 .59588 m
.11821 .60045 L
s
.11821 .60045 m
.11725 .60494 L
s
.11192 .63562 m
.11777 .60223 L
s
.14661 .89433 m
.13227 .86338 L
s
.11725 .60494 m
.11632 .60947 L
s
.08667 .72275 m
.07943 .68527 L
s
.11632 .60947 m
.11541 .61402 L
s
.11541 .61402 m
.11454 .6186 L
s
.54225 .98426 m
.5498 .98506 L
s
.5498 .98506 m
.51513 .98113 L
s
.11454 .6186 m
.11369 .62322 L
s
.5347 .98341 m
.54225 .98426 L
s
.11369 .62322 m
.11288 .62787 L
s
.52717 .98253 m
.5347 .98341 L
s
.11288 .62787 m
.11241 .63243 L
s
.51964 .98161 m
.52717 .98253 L
s
.11241 .63243 m
.11198 .63703 L
s
.51213 .98066 m
.51964 .98161 L
s
.11068 .67213 m
.11192 .63562 L
s
.13227 .86338 m
.11898 .83076 L
s
.11198 .63703 m
.11157 .64166 L
s
.51513 .98113 m
.4811 .9759 L
s
.50463 .97967 m
.51213 .98066 L
s
.09155 .72113 m
.08667 .72275 L
s
.09602 .76049 m
.08667 .72275 L
s
.11764 .82721 m
.08667 .72275 L
s
.11157 .64166 m
.1112 .64632 L
s
.49753 .97854 m
.50463 .97967 L
s
.1112 .64632 m
.11086 .65102 L
s
.49045 .97737 m
.49753 .97854 L
s
.11086 .65102 m
.11056 .65575 L
s
.09643 .7195 m
.09155 .72113 L
s
.48337 .97617 m
.49045 .97737 L
s
.11056 .65575 m
.11063 .66039 L
s
.11898 .83076 m
.10685 .79647 L
s
.47631 .97494 m
.48337 .97617 L
s
.4811 .9759 m
.44774 .96935 L
s
.11063 .66039 m
.11073 .66506 L
s
.10685 .79647 m
.09602 .76049 L
s
.10132 .71787 m
.09643 .7195 L
s
.46926 .97367 m
.47631 .97494 L
s
.11073 .66506 m
.11087 .66977 L
s
.46222 .97238 m
.46926 .97367 L
s
.11087 .66977 m
.11104 .67452 L
s
.11603 .71297 m
.11068 .67213 L
s
.45555 .97095 m
.46222 .97238 L
s
.10621 .71624 m
.10132 .71787 L
s
.11104 .67452 m
.11125 .6793 L
s
.44889 .96949 m
.45555 .97095 L
s
.11125 .6793 m
.11149 .68411 L
s
.44224 .968 m
.44889 .96949 L
s
.44774 .96935 m
.41508 .96144 L
s
.11149 .68411 m
.11215 .68883 L
s
.11112 .71461 m
.10621 .71624 L
s
.43561 .96647 m
.44224 .968 L
s
.11215 .68883 m
.11285 .69358 L
s
.42898 .96492 m
.43561 .96647 L
s
.11285 .69358 m
.11359 .69837 L
s
.42236 .96334 m
.42898 .96492 L
s
.11359 .69837 m
.11436 .7032 L
s
.11603 .71297 m
.11112 .71461 L
s
.4161 .96164 m
.42236 .96334 L
s
.11436 .7032 m
.11518 .70807 L
s
.40984 .95991 m
.4161 .96164 L
s
.41508 .96144 m
.38317 .95213 L
s
.11518 .70807 m
.11603 .71297 L
s
.4036 .95814 m
.40984 .95991 L
s
.12857 .75251 m
.11603 .71297 L
s
.11603 .71297 m
.11733 .71774 L
s
.39736 .95635 m
.4036 .95814 L
s
.11733 .71774 m
.11865 .72248 L
s
.39114 .95454 m
.39736 .95635 L
s
.38493 .95269 m
.39114 .95454 L
s
.11865 .72248 m
.12 .7272 L
s
.37905 .95073 m
.38493 .95269 L
s
.38317 .95213 m
.35207 .94136 L
s
.12 .7272 m
.12137 .73188 L
s
.37317 .94874 m
.37905 .95073 L
s
.12137 .73188 m
.12277 .73654 L
s
.36732 .94672 m
.37317 .94874 L
s
.12277 .73654 m
.12419 .74117 L
s
.36147 .94468 m
.36732 .94672 L
s
.12419 .74117 m
.12601 .74565 L
s
.35563 .94261 m
.36147 .94468 L
s
.12601 .74565 m
.12786 .75011 L
s
.34981 .94051 m
.35563 .94261 L
s
.35207 .94136 m
.32183 .92905 L
s
.12786 .75011 m
.12974 .75453 L
s
.3443 .9383 m
.34981 .94051 L
s
.14541 .78573 m
.12857 .75251 L
s
.12974 .75453 m
.13163 .75893 L
s
.3388 .93606 m
.3443 .9383 L
s
.13163 .75893 m
.13355 .76331 L
s
.33331 .9338 m
.3388 .93606 L
s
.13355 .76331 m
.13549 .76765 L
s
.32784 .93151 m
.33331 .9338 L
s
.13549 .76765 m
.13779 .77186 L
s
.32238 .9292 m
.32784 .93151 L
s
.13779 .77186 m
.14012 .77605 L
s
.32183 .92905 m
.29256 .9151 L
s
.31693 .92686 m
.32238 .9292 L
s
.31179 .92442 m
.31693 .92686 L
s
.14012 .77605 m
.14247 .78021 L
s
.30666 .92194 m
.31179 .92442 L
s
.14247 .78021 m
.14484 .78434 L
s
.30154 .91945 m
.30666 .92194 L
s
.14484 .78434 m
.14724 .78845 L
s
.16529 .81443 m
.14541 .78573 L
s
.29643 .91692 m
.30154 .91945 L
s
.14724 .78845 m
.14965 .79254 L
s
.14965 .79254 m
.1524 .79649 L
s
.29134 .91438 m
.29643 .91692 L
s
.29256 .9151 m
.26433 .89938 L
s
.28626 .9118 m
.29134 .91438 L
s
.1524 .79649 m
.15518 .80043 L
s
.28149 .90913 m
.28626 .9118 L
s
.15518 .80043 m
.15797 .80434 L
s
.27672 .90642 m
.28149 .90913 L
s
.15797 .80434 m
.16079 .80822 L
s
.27197 .90369 m
.27672 .90642 L
s
.16079 .80822 m
.16362 .81208 L
s
.26723 .90094 m
.27197 .90369 L
s
.16362 .81208 m
.16647 .81591 L
s
.18751 .8396 m
.16529 .81443 L
s
.26251 .89816 m
.26723 .90094 L
s
.16647 .81591 m
.16965 .81963 L
s
.26433 .89938 m
.2373 .88172 L
s
.2578 .89536 m
.26251 .89816 L
s
.16965 .81963 m
.17284 .82332 L
s
.25338 .89246 m
.2578 .89536 L
s
.17284 .82332 m
.17606 .82699 L
s
.24898 .88952 m
.25338 .89246 L
s
.17606 .82699 m
.17929 .83063 L
s
.2446 .88657 m
.24898 .88952 L
s
.17929 .83063 m
.18254 .83425 L
s
.24023 .88359 m
.2446 .88657 L
s
.18254 .83425 m
.1858 .83785 L
s
.1858 .83785 m
.18938 .84133 L
s
.2373 .88172 m
.21161 .86189 L
s
.23587 .88058 m
.24023 .88359 L
s
.21161 .86189 m
.18751 .8396 L
s
.23154 .87756 m
.23587 .88058 L
s
.22749 .87442 m
.23154 .87756 L
s
.18938 .84133 m
.19297 .84479 L
s
.22347 .87126 m
.22749 .87442 L
s
.19297 .84479 m
.19658 .84823 L
s
.19658 .84823 m
.20021 .85164 L
s
.21946 .86808 m
.22347 .87126 L
s
.20752 .85839 m
.21148 .86164 L
s
.20386 .85503 m
.20752 .85839 L
s
.20021 .85164 m
.20386 .85503 L
s
.21546 .86487 m
.21946 .86808 L
s
.21148 .86164 m
.21546 .86487 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{307.312, 333.5},
  ImageMargins->{{117, 0}, {0, 0}},
  ImageRegion->{{-0.222903, 1.37894}, {-0.316303, 1.11091}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004c0001CB000`400?l00000o`00003ooooooold
ooooo`00ooooooldooooo`00ooooooldooooo`00ooooooldooooo`00ooooooldooooo`00oooooold
ooooo`00ooooooldooooo`00ooooooldooooo`00ooooooldooooo`00ooooooldooooo`00oooooold
ooooo`00ooooooldooooo`00ooooooldooooo`00POooool5o`000:gooooo001kooooo`So00000ooo
ool00ol0003oooooooooo`2Zooooo`00Moooool5o`0000;ooooo0ol00006ooooo`;o0000Z_ooool0
07?ooooo1?l00004ooooo`Go00002Oooool00ol0003oooooooooo`2Wooooo`00L?ooool4o`0000Go
oooo0_l000000ooooooo0000o`00000<ooooo`;o0000Yoooool006kooooo0ol00006ooooo`;o0000
00Coooooo`000?l0003o00003oooool2o`000:Gooooo001/ooooo`?o00001Oooool3o`000003oooo
ool0003o000000;o00004_ooool00ol0003oooooooooo`2Rooooo`00Joooool2o`0000Gooooo0_l0
0003ooooo`?o00005Oooool2o`000:;ooooo001Yooooo`;o00001?ooool3o`0000?ooooo0_l0000J
ooooo`03o`000?oooooooooo09oooooo001Xooooo`;o00000_ooool3o`0000Gooooo0_l0000Loooo
o`;o0000Woooool006Oooooo1Ol00007ooooo`;o00007oooool00ol0003oooooooooo`2Looooo`00
I_ooool3o`0000Sooooo0_l0000Rooooo`;o0000W?ooool006?ooooo1?l00009ooooo`03o`000?oo
oooooooo02Cooooo0_l0002Jooooo`00HOooool2o`000003ooooool0003o000000Sooooo0_l0000Y
ooooo`03o`000?oooooooooo09Oooooo001Nooooo`?o00000oooool00ol0003oooooooooo`05oooo
o`;o0000;?ooool2o`0009Oooooo001Looooo`;o00001Oooool2o`0000Kooooo0_l0000_ooooo`03
o`000?oooooooooo09Cooooo001Iooooo`?o00001oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo033ooooo0_l0002Dooooo`00Eoooool2o`0000Wooooo00?o0000ooooooooool00ooo
ool2o`0003Gooooo00?o0000ooooooooool0TOooool005Gooooo0_l0000;ooooo`03o`000?oooooo
oooo00;ooooo0_l0000gooooo`;o0000TOooool005;ooooo0ol0000=ooooo`05o`000?oooooooooo
ooooool00000>oooool2o`0008oooooo001@ooooo`;o00004?ooool01?l0003oooooo`000?l0000n
ooooo`03o`000?oooooooooo08cooooo001=ooooo`?o00004Oooool3o`00047ooooo0_l0002<oooo
o`00B_ooool3o`0001Cooooo0_l00014ooooo`03o`000?oooooooooo08Wooooo0017ooooo`?o0000
5_ooool3o`0004Gooooo0_l00029ooooo`00A?ooool3o`0001Sooooo00Co0000oooooooooooo0000
Aoooool00ol0003oooooooooo`26ooooo`00@Oooool3o`0001Wooooo0_l00003ooooo`03o`000?oo
oooooooo04Kooooo0_l00026ooooo`00?oooool2o`0001_ooooo0_l00004ooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool0Poooool003gooooo0_l0000Kooooo`;o00001_ooool00ol0
003oooooooooo`19ooooo`;o0000Poooool003[ooooo0ol0000Looooo`;o00001oooool00ol0003o
ooooooooo`1;ooooo`;o0000POooool003;ooooo3Ol0000Iooooo`;o00002?ooool2o`0004kooooo
00?o0000ooooooooool0O_ooool002oooooo5_l0000Booooo`;o00002_ooool00ol0003ooooooooo
o`1=ooooo`;o0000O_ooool002cooooo0ol00004ooooo`?o00003_ooool4o`0000kooooo0_l0000;
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0Noooool002Wooooo1?l00004oooo
o`;o00004oooool4o`0000_ooooo0_l0000<ooooo`;o0000DOooool2o`0007_ooooo000Wooooo`;o
000000?oooooo`000?l000000oooool2o`0001Oooooo1?l00008ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1hooooo`009Oooool2o`000003oooo
ool0003o000000;ooooo0ol0000Kooooo`Co00001Oooool00ol0003oooooooooo`0>ooooo`;o0000
Doooool2o`0007Sooooo000Tooooo`05o`000?oooooo0000o`000?ooool00ol0000Qooooo`?o0000
00?oooooo`000?l000004_ooool00ol0003oooooooooo`1Cooooo`;o0000M_ooool002?ooooo0ol0
00000ooooooo0000o`00000Vooooo`;o00005?ooool00ol0003oooooooooo`1Eooooo`03o`000?oo
oooooooo07?ooooo000Rooooo`Go0000:?ooool4o`0001?ooooo00?o0000ooooooooool0EOooool2
o`0007?ooooo000Qooooo`?o0000:_ooool2o`0000?ooooo0_l0000Aooooo`;o0000F?ooool00ol0
003oooooooooo`1`ooooo`008?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Co
oooo0ol0000@ooooo`03o`000?oooooooooo05Oooooo0_l0001`ooooo`007oooool2o`0002_ooooo
0_l00008ooooo`;o00003oooool2o`0005[ooooo00?o0000ooooooooool0KOooool001kooooo0_l0
000[ooooo`;o00002oooool00ol0003oooooooooo`0=ooooo`;o0000F_ooool2o`0006gooooo000M
ooooo`;o0000:oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo06[ooooo000Mooooo`;o0000:_ooool00ol0003oooooooooo`0>oooo
o`;o00003Oooool2o`0005cooooo0_l0001Zooooo`007?ooool2o`0002[ooooo0_l0000Aooooo`;o
00003Oooool2o`0005gooooo0_l0001Xooooo`006oooool2o`0002[ooooo0_l0000Cooooo`;o0000
3Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo06Gooooo000Jooooo`03o`000?oo
oooo000002Wooooo0_l0000Eooooo`;o00003?ooool2o`0005oooooo0_l0001Uooooo`006_ooool2
o`0002Wooooo0_l0000Gooooo`;o00003?ooool2o`00063ooooo00?o0000ooooooooool0H_ooool0
01Wooooo0_l0000Yooooo`;o00006_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
05oooooo0_l0001Rooooo`006?ooool00ol0003oooooo`00000Xooooo`;o00007?ooool00ol0003o
ooooooooo`0:ooooo`;o0000HOooool00ol0003oooooooooo`1Oooooo`006?ooool2o`0002Sooooo
0_l0000Nooooo`03o`000?oooooooooo00[ooooo0_l0001Qooooo`;o0000Goooool001Oooooo0_l0
000Xooooo`;o00008?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo067ooooo0_l0
001Mooooo`005oooool2o`0002Oooooo0_l0000Rooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0H_ooool00ol0003oooooooooo`1Jooooo`005oooool00ol0003oooooooooo`0Uoooo
o`;o00009?ooool00ol0003oooooooooo`05ooooo`Co000000?oooooo`000?ooool0Hoooool2o`00
05[ooooo000Fooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09?ooool01?l0003o
ooooooooooooool3o`0000Kooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1Goooo
o`005_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Kooooo00?o0000ooooool0
00002_ooool00ol0003oooooooooo`1Sooooo`;o0000Eoooool001Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`1Dooooo`005?ooool2o`0002Kooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06Cooooo0_l0001Dooooo`005?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1Uooooo`;o0000D_ooool001Cooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0I_ooool00ol0
003oooooooooo`1?ooooo`004oooool00ol0003oooooooooo`0Sooooo`;o0000<?ooool00ol0003o
ooooooooo`0;ooooo`;o0000Ioooool2o`0004oooooo000Cooooo`03o`000?oooooooooo02;ooooo
0_l0000aooooo`;o00003Oooool2o`0006Sooooo00?o0000ooooooooool0C?ooool001?ooooo00?o
0000ooooooooool08Oooool2o`0003?ooooo0_l0000=ooooo`;o0000J?ooool2o`0004cooooo000B
ooooo`;o00008oooool00ol0003oooooooooo`0cooooo`;o00003Oooool2o`0006Wooooo00?o0000
ooooooooool0BOooool0017ooooo0_l0000Sooooo`;o0000=_ooool00ol0003oooooooooo`0<oooo
o`;o0000JOooool2o`0004Wooooo000Aooooo`;o00008oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00cooooo0_l0001Zooooo`03o`000?oooooooooo04Kooooo000Aooooo`;o0000
8_ooool00ol0003oooooooooo`0gooooo`;o00003oooool00ol0003oooooooooo`1Xooooo`;o0000
A_ooool0013ooooo0ol0000Qooooo`03o`000?oooooooooo03Wooooo0_l0000?ooooo`;o0000J_oo
ool2o`0004Cooooo000@ooooo`;o00008_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo00kooooo0_l0001[ooooo`03o`000?oooooooooo047ooooo000@ooooo`;o00008Oooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo00kooooo0_l0001[ooooo`;o0000@Oooool0013o
oooo0_l0000Pooooo`03o`000?oooooooooo03gooooo0_l0000Aooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool0?_ooool000oooooo0ol0000Oooooo`;o0000@?ooool2o`00017ooooo
00?o0000ooooooooool0J_ooool2o`0003kooooo000?ooooo`;o00007oooool2o`0004;ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo03_ooooo000?
ooooo`;o00007oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo013ooooo0_l0001/
ooooo`;o0000>oooool000oooooo0_l0000Nooooo`;o0000AOooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo06_ooooo0_l0000iooooo`003oooool2o`0001gooooo0_l00016ooooo`;o
00004oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo03Kooooo000>ooooo`;o0000
7_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo0_l0001]ooooo`;o0000
=_ooool000kooooo0_l0000Mooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo03?ooooo000>ooooo`;o00007Oooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0K?ooool2
o`0003?ooooo000>ooooo`;o00007?ooool00ol0003oooooooooo`1:ooooo`;o00005Oooool2o`00
06kooooo00?o0000ooooooooool0<?ooool000kooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0K?ooool2o`00033o
oooo000=ooooo`;o00007?ooool00ol0003oooooooooo`1<ooooo`;o00005oooool2o`0006kooooo
00?o0000ooooooooool0;Oooool000gooooo0_l0000Kooooo`03o`000?oooooooooo04kooooo0_l0
000Gooooo`;o0000K_ooool2o`0002gooooo000=ooooo`;o00006oooool00ol0003oooooooooo`1?
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0KOooool2o`0002_ooooo000=oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0D?ooool2o`0001Wooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`0Xooooo`003Oooool00ol0003oooooooooo`0Hooooo`;o
0000Doooool00ol0003oooooooooo`0Hooooo`;o0000Koooool2o`0002Sooooo000=ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0D_ooool2o`0001_ooooo0_l0001_ooooo`03o`00
0?oooooooooo02Gooooo000=ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Dooo
ool2o`0001cooooo0_l0001^ooooo`;o00009Oooool000gooooo00?o0000ooooooooool05oooool2
o`0005Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02;ooooo000=ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0EOooool2o`00
01kooooo0_l0001^ooooo`;o00008_ooool000gooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`1Gooooo`03o`000?oooooooooo01gooooo0ol0001^ooooo`;o00008?ooool000cooooo
0_l0000Hooooo`03o`000?oooooooooo05Oooooo0_l0000Oooooo`?o0000Koooool00ol0003ooooo
ooooo`0Mooooo`003?ooool2o`0001Oooooo00?o0000ooooooooool0FOooool2o`00023ooooo0_l0
001_ooooo`;o00007Oooool000cooooo0_l0000Gooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool07oooool3o`0006oooooo00?o0000ooooooooool06_ooool000cooooo0_l0000Foooo
o`03o`000?oooooooooo05_ooooo0_l0000Sooooo`03o`000?oooooooooo06gooooo0_l0000Joooo
o`003?ooool2o`0001Kooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Rooooo`;o
0000Koooool00ol0003oooooooooo`0Gooooo`003?ooool2o`0001Gooooo0_l0001Nooooo`;o0000
9?ooool2o`0006oooooo0_l0000Gooooo`003?ooool2o`0001Gooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`0Tooooo`;o0000Koooool2o`0001Gooooo000<ooooo`;o00005Oooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo02Cooooo0_l0001`ooooo`03o`000?oooooo
oooo01;ooooo000<ooooo`;o00005?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
02Kooooo0_l0001_ooooo`;o00004_ooool000cooooo0_l0000Dooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool09_ooool3o`0006oooooo00?o0000ooooooooool03oooool000cooooo
0_l0000Cooooo`;o0000Hoooool2o`0002Wooooo0ol0001]ooooo`;o00004?ooool000_ooooo00?o
0000ooooool000004oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02Wooooo0_l0
001[ooooo`03o`000?oooooo0000013ooooo000;ooooo`;o00005?ooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo02[ooooo0_l0001Xooooo`03o`000?oooooo0000017ooooo000;oooo
o`;o00004oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0I?ooool01?l0003oooooooooool0000Aooooo`002oooool2o`0001?ooooo00?o0000oooo
ooooool0I_ooool00ol0003oooooooooo`0/ooooo`;o0000Hoooool01?l0003oooooooooool0000B
ooooo`002oooool2o`0001?ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0^oooo
o`;o0000H?ooool01?l0003oooooooooool0000Cooooo`002oooool2o`0001;ooooo0_l0001Yoooo
o`03o`000?oooooooooo02kooooo0ol0001Mooooo`05o`000?ooooooooooooooool000004oooool0
00_ooooo0_l0000Booooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0<Oooool2o`00
05Wooooo0_l00003ooooo`03o`000?oooooooooo01;ooooo000;ooooo`;o00004_ooool00ol0003o
ooooooooo`1Xooooo`;o0000=?ooool2o`0005Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Booooo`002oooool2o`0001;ooooo00?o0000ooooooooool0JOooool00ol0003ooooo
ooooo`0dooooo`;o0000Doooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo
000;ooooo`;o00004Oooool2o`0006_ooooo0_l0000fooooo`?o0000D?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01Cooooo000;ooooo`;o00004Oooool00ol0003oooooooooo`1[
ooooo`03o`000?oooooooooo03Kooooo0ol0001=ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool05?ooool000_ooooo0_l0000Aooooo`03o`000?oooooooooo06_ooooo0_l0000hoooo
o`?o0000Boooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo000<ooooo`03
o`000?oooooooooo00kooooo0_l0001^ooooo`03o`000?oooooooooo03Sooooo0ol00018ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool000cooooo00?o0000ooooooooool0
3_ooool2o`0006kooooo00?o0000ooooooooool0>_ooool3o`0004Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Fooooo`003?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool0>oooool4o`00047ooooo0_l00007ooooo`03o`000?oo
oooooooo01Oooooo000<ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0K_ooool2
o`0003oooooo0_l0000nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool0
00cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1^ooooo`;o0000@?ooool2o`00
03cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hooooo`003?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0@?ooool2o`0003Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`003?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo073ooooo0_l00013ooooo`;o0000=_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01Wooooo000<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0L?ooool2o`0004Gooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool06Oooool000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1a
ooooo`;o0000AOooool4o`0002oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0J
ooooo`003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo077ooooo0_l00017oooo
o`Co0000:oooool2o`0000_ooooo00?o0000ooooooooool06oooool000cooooo0_l0000>ooooo`03
o`000?oooooooooo07;ooooo00?o0000ooooooooool0Aoooool4o`0002Sooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Kooooo`003?ooool2o`0000gooooo00?o0000ooooooooool0
Loooool2o`0004[ooooo1?l0000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
7?ooool000gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1cooooo`;o0000C?oo
ool4o`0002;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`003Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07Cooooo0_l0001>ooooo`;o00008?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01gooooo000=ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0M?ooool2o`00053ooooo0_l0000Mooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool07_ooool000gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`1eooooo`;o0000DOooool2o`0001[ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Nooooo`003Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07Gooooo
0_l0001Cooooo`;o00005oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01oooooo
000=ooooo`;o00003?ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo05?ooooo0ol0
000Booooo`;o00004?ooool00ol0003oooooooooo`0Oooooo`003Oooool2o`0000cooooo00?o0000
ooooooooool0M_ooool2o`0005Kooooo0ol0000?ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool08?ooool000gooooo0_l0000<ooooo`03o`000?oooooooooo07Kooooo0_l0001Hoooo
o`?o00003?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo000=ooooo`;o
00003?ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo05Sooooo0ol00009ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool08Oooool000gooooo0_l0000<ooooo`03o`00
0?oooooooooo07Oooooo0_l0001Kooooo`?o00001_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo02;ooooo000>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Mooo
ool2o`0005gooooo0_l00004ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08_oo
ool000kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1hooooo`03o`000?oooooo
oooo05gooooo0_l000000ooooooo0000ooooo`0Booooo`03o`000?oooooooooo02?ooooo000>oooo
o`;o00002oooool00ol0003oooooooooo`1hooooo`;o0000Goooool2o`0001Cooooo00?o0000oooo
ooooool08oooool000kooooo0_l0000;ooooo`03o`000?oooooooooo07Sooooo0_l0001Looooo`?o
000000?oooooo`000?ooool04_ooool00ol0003oooooooooo`0Tooooo`003_ooool2o`0000_ooooo
00?o0000ooooooooool0NOooool00ol0003oooooooooo`1Gooooo`?o00000oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo02Gooooo000>ooooo`;o00002oooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo05Cooooo0ol00005ooooo`;o00004oooool00ol0003ooooooooo
o`0Uooooo`003_ooool2o`0000_ooooo00?o0000ooooooooool0NOooool2o`0005;ooooo0ol00008
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09_ooool000oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo04cooooo1?l0000:oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09_ooool000oooooo0_l0000:ooooo`03
o`000?oooooooooo07[ooooo00?o0000ooooooooool0B?ooool4o`0000gooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Wooooo`003oooool2o`0000[ooooo0_l0001kooooo`;o0000
A_ooool3o`00017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Xooooo`003ooo
ool2o`0000[ooooo0_l0001looooo`03o`000?oooooooooo043ooooo1?l0000Cooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0:?ooool000oooooo0_l0000:ooooo`;o0000O?ooool0
0ol0003oooooooooo`0mooooo`?o00005_ooool2o`0001?ooooo00?o0000ooooooooool0:Oooool0
013ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1jooooo`;o0000>oooool3o`00
01Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Yooooo`004?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0=_ooool3o`0001_o
oooo0_l0000Cooooo`03o`000?oooooooooo02[ooooo000@ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`?o00007_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo02[ooooo000@ooooo`;o00002_ooool00ol0003ooooooooo
o`1kooooo`;o0000<Oooool3o`00023ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0[ooooo`004?ooool2o`0000[ooooo00?o0000ooooooooool0Noooool2o`0002kooooo0ol0000R
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;?ooool0017ooooo00?o0000oooo
ooooool02?ooool2o`0007gooooo00?o0000ooooooooool0:Oooool3o`0002Cooooo0_l0000Doooo
o`03o`000?oooooooooo02cooooo000Aooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0Noooool00ol0003oooooooooo`0Vooooo`?o00009oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo02gooooo000Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
Noooool2o`0002Cooooo0ol0000Yooooo`;o00005?ooool00ol0003oooooooooo`0]ooooo`004Ooo
ool00ol0003oooooooooo`08ooooo`;o0000O_ooool00ol0003oooooooooo`0Oooooo`?o0000;?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02kooooo000Aooooo`03o`000?oooooo
oooo00Cooooo1?l000000ooooooo0000ooooo`1mooooo`03o`000?oooooooooo01_ooooo1?l0000^
ooooo`;o00004oooool00ol0003oooooooooo`0_ooooo`004_ooool00ol0003oooooo`000003o`00
00Gooooo0_l0001mooooo`;o00006?ooool4o`0003;ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0_ooooo`004_ooool2o`0000Wooooo0_l0001nooooo`03o`000?oooooooooo01?o
oooo0ol0000eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool001;ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00oooooo
1?l0000gooooo`;o00005?ooool00ol0003oooooooooo`0`ooooo`004_ooool00ol0003ooooooooo
o`09ooooo`;o0000OOooool00ol0003oooooooooo`0<ooooo`?o0000>_ooool2o`0001Cooooo00?o
0000ooooooooool0<Oooool001;ooooo00?o0000ooooooooool02Oooool2o`0007kooooo00?o0000
ooooooooool02?ooool3o`0003gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0b
ooooo`004oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07cooooo00?o0000oooo
ooooool01Oooool3o`0003oooooo0_l0000Dooooo`03o`000?oooooooooo03;ooooo000Cooooo`03
o`000?oooooooooo00Wooooo0_l0001mooooo`03o`000?oooooooooo00;ooooo0ol00011ooooo`;o
00005?ooool00ol0003oooooooooo`0cooooo`004oooool00ol0003oooooooooo`09ooooo`;o0000
O_ooool4o`0004Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0cooooo`004ooo
ool2o`0000[ooooo0_l0001nooooo`03o`000?oooooooooo04Cooooo0_l0000Dooooo`03o`000?oo
oooooooo03Cooooo000Cooooo`;o00002oooool2o`0007gooooo00?o0000ooooooooool0A?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Cooooo000Dooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0=Oooool001Cooooo0_l0000;ooooo`03o`000?oooooooooo07_o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Ko
oooo000Dooooo`;o00002oooool2o`0007gooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo03Kooooo000Dooooo`;o00002oooool2o`0007gooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Oooooo000D
ooooo`;o00003?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03oooooo0_l0000E
ooooo`03o`000?oooooooooo03Oooooo000Eooooo`;o00002oooool2o`0007cooooo00?o0000oooo
ooooool0?_ooool2o`0001Gooooo00?o0000ooooooooool0>?ooool001Gooooo0_l0000<ooooo`03
o`000?oooooooooo07[ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo03Wooooo000Eooooo`;o00003Oooool00ol0003oooooooooo`1jooooo`03o`00
0?oooooooooo03cooooo0_l0000Eooooo`03o`000?oooooooooo03Wooooo000Eooooo`03o`000?oo
oooo000000cooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0>_ooool001Kooooo0_l0000<ooooo`;o0000Noooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0>_ooool0
01Kooooo0_l0000<ooooo`;o0000Noooool2o`0003_ooooo0_l0000Eooooo`03o`000?oooooooooo
03_ooooo000Fooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool0NOooool2o`0003_o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0looooo`005oooool2o`0000gooooo
00?o0000ooooooooool0NOooool00ol0003oooooooooo`0hooooo`;o00005Oooool00ol0003ooooo
ooooo`0looooo`005oooool2o`0000gooooo00?o0000ooooooooool0NOooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?Oooool001Oooooo0_l0000>
ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo03gooooo000Gooooo`03o`000?oooooo000000gooooo0_l0001ioooo
o`;o0000=oooool2o`0001Gooooo00?o0000ooooooooool0?_ooool001Sooooo0_l0000>ooooo`03
o`000?oooooooooo07Oooooo0_l0000gooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0?_ooool001Sooooo0_l0000>ooooo`;o0000NOooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0?oooool001Sooooo00?o0000ooooool000003_oo
ool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`10ooooo`006Oooool2o`0000oooooo00?o0000ooooooooool0M_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0@?ooool0
01Wooooo0_l0000@ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo047ooooo000Iooooo`03o`000?oooooo000000oo
oooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0@Oooool001[ooooo0_l0000@ooooo`03o`000?oooooooooo07Gooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04;ooooo
000Jooooo`;o00004Oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`13ooooo`006_ooool2o`00017ooooo00?o0000
ooooooooool0M?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0@oooool001_ooooo0_l0000Aooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Cooooo000Kooooo`;o
00004_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo02gooooo0_l0000Fooooo`03
o`000?oooooooooo04Cooooo000Looooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
LOooool2o`0002kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`15ooooo`007?oo
ool2o`0001;ooooo0_l0001cooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`16ooooo`007?ooool2o`0001?ooooo0_l0001booooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`16ooooo`007Oooool00ol0
003oooooooooo`0Booooo`;o0000LOooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0Aoooool001gooooo0_l0000Dooooo`03o`000?oooooooooo06oo
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Oo
oooo000Mooooo`;o00005Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`18ooooo`007_ooool00ol0003ooooooooo
o`0Cooooo`;o0000Koooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0B?ooool001kooooo0_l0000Eooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09oooool2o`0001Kooooo00?o0000ooooooooool0BOooool001oooooo00?o0000oooo
ooooool05?ooool2o`0006gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04[ooooo000Oooooo`;o00005_ooool2o`0006cooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04[ooooo000Oooooo`;o0000
5oooool2o`0006_ooooo00?o0000ooooooooool09Oooool2o`0001Kooooo00?o0000ooooooooool0
Boooool0023ooooo0_l0000Gooooo`;o0000J_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0Boooool0023ooooo0_l0000Hooooo`;o0000JOooool2
o`0002Gooooo0_l0000Fooooo`03o`000?oooooooooo04cooooo000Qooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0I_ooool2o`0002Gooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1=ooooo`008Oooool2o`0001[ooooo0_l0001Vooooo`;o00009Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo04gooooo000Qooooo`;o00006oooool2o`0006Gooooo
0_l0000Tooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0C_ooool002;ooooo0_l0
000Kooooo`;o0000I?ooool2o`0002?ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`1>ooooo`008_ooool2o`0001cooooo0_l0001Sooooo`;o00008oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo04oooooo000Rooooo`03o`000?oooooo000001gooooo0_l0001Roooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1@oooo
o`008oooool2o`0001kooooo0_l0001Qooooo`03o`000?oooooooooo01oooooo0_l0000Fooooo`03
o`000?oooooooooo053ooooo000Sooooo`03o`000?oooooo000001kooooo0_l0001Pooooo`03o`00
0?oooooooooo01kooooo0_l0000Fooooo`03o`000?oooooooooo057ooooo000Tooooo`;o00007ooo
ool2o`0005oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo057ooooo000Tooooo`03o`000?oooooo000001oooooo0ol0001Mooooo`03o`000?oooooo
oooo01gooooo0_l0000Fooooo`03o`000?oooooooooo05;ooooo000Uooooo`;o00008Oooool2o`00
05cooooo00?o0000ooooooooool07?ooool2o`0001Oooooo00?o0000ooooooooool0D_ooool002Go
oooo00?o0000ooooool000008Oooool2o`0005_ooooo00?o0000ooooooooool07?ooool2o`0001Ko
oooo00?o0000ooooooooool0Doooool002Kooooo0_l0000Sooooo`03o`000?oooooooooo05Sooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Cooooo
000Vooooo`;o00009?ooool2o`0005Sooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo05Cooooo000Wooooo`;o00009?ooool2o`0005Oooooo00?o0000
ooooooooool06_ooool2o`0001Kooooo00?o0000ooooooooool0EOooool002Oooooo0_l0000Uoooo
o`?o0000EOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0EOooool002Sooooo0_l0000Vooooo`;o0000E?ooool00ol0003oooooooooo`0Iooooo`;o
00005_ooool00ol0003oooooooooo`1Fooooo`00:?ooool2o`0002Sooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`0Hooooo`;o00005_ooool00ol0003oooooooooo`1Gooooo`00:Ooo
ool2o`0002Sooooo0_l0001Aooooo`03o`000?oooooooooo01Sooooo0_l0000Fooooo`03o`000?oo
oooooooo05Oooooo000Yooooo`;o0000:_ooool2o`0004oooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Sooooo000Zooooo`;o0000:_ooool3o`00
04gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
05Sooooo000Zooooo`;o0000;?ooool3o`0004_ooooo00?o0000ooooooooool05_ooool2o`0001Ko
oooo00?o0000ooooooooool0FOooool002_ooooo0_l0000]ooooo`?o0000BOooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0FOooool002_ooooo0_l0
000_ooooo`;o0000B?ooool00ol0003oooooooooo`0Eooooo`;o00005_ooool00ol0003ooooooooo
o`1Jooooo`00;?ooool00ol0003oooooooooo`0^ooooo`?o0000A_ooool00ol0003oooooooooo`0D
ooooo`;o00005_ooool00ol0003oooooooooo`1Kooooo`00;Oooool00ol0003oooooooooo`0_oooo
o`?o0000A?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Foooool002gooooo00?o0000ooooooooool0<Oooool3o`0004;ooooo00?o0000oooooooo
ool04oooool2o`0001Kooooo00?o0000ooooooooool0G?ooool002kooooo00?o0000ooooooooool0
<_ooool3o`0003oooooo0_l0000Eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
G?ooool002kooooo00?o0000ooooooooool0=?ooool3o`0003gooooo0_l0000Dooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0GOooool002oooooo00?o0000ooooooooool0=_ooool2
o`0003_ooooo0_l0000Cooooo`;o00005_ooool00ol0003oooooooooo`1Nooooo`00;oooool00ol0
003oooooooooo`0hooooo`;o0000>Oooool2o`0001?ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`1Nooooo`00<?ooool00ol0003oooooooooo`0iooooo`;o0000=oooool2o`0001;o
oooo0_l0000Fooooo`03o`000?oooooooooo05oooooo000`ooooo`;o0000??ooool3o`0003Cooooo
0_l0000Booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Goooool0037ooooo00?o
0000ooooooooool0??ooool3o`0003;ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo063ooooo000aooooo`;o0000@?ooool2o`00033ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo067ooooo000boooo
o`;o0000@Oooool4o`0002cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo067ooooo000cooooo`03o`000?oooooooooo04;ooooo0ol0000Zooooo`03
o`000?oooooooooo00kooooo0_l0000Fooooo`03o`000?oooooooooo06;ooooo000cooooo`;o0000
A_ooool3o`0002Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo06;ooooo000dooooo`;o0000B?ooool3o`0002Cooooo00?o0000ooooooooool03Ooo
ool2o`0001Kooooo00?o0000ooooooooool0Hoooool003Cooooo0_l0001:ooooo`Co00008Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Hoooool0
03Gooooo0_l0001=ooooo`?o00007Oooool2o`0000kooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`1Tooooo`00=Oooool00ol0003oooooo`00001?ooooo`Co00006Oooool2o`0000ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Uooooo`00=_ooool2o`00057ooooo
1_l0000Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`1Uooooo`00=oooool2o`0005Gooooo1Ol0000Aooooo`03o`000?oooooooooo00_ooooo0_l0
000Fooooo`03o`000?oooooooooo06Kooooo000gooooo`?o0000E_ooool6o`0000kooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Kooooo000hoooo
o`;o0000Foooool5o`0000[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo06Oooooo000iooooo`;o0000G_ooool4o`0000Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Sooooo000iooooo`?o0000
H?ooool6o`0000;ooooo00?o0000ooooooooool02Oooool2o`0001Kooooo00?o0000ooooooooool0
J?ooool003[ooooo0_l0001Uooooo`Oo00002?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo06Wooooo000kooooo`;o0000I_ooool01?l0003oooooooooooooool6o`0000;ooooo0_l0
000Fooooo`03o`000?oooooooooo06Wooooo000looooo`;o0000IOooool00ol0003oooooooooo`07
ooooo`Oo00004_ooool00ol0003oooooooooo`1Zooooo`00??ooool2o`0006Cooooo0_l0000:oooo
o`;o00000_ooool9o`0000[ooooo00?o0000ooooooooool0Joooool003gooooo0_l0001Sooooo`;o
00002Oooool2o`0000cooooo2Ol000000ooooooo0000ooooo`1/ooooo`00?_ooool2o`0006;ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`?o0000K_ooool003kooooo0_l0
001Qooooo`;o00002_ooool00ol0003oooooooooo`0>ooooo`Co000000?oooooo`000?l00000K_oo
ool003oooooo0_l0001Pooooo`;o00002Oooool00ol0003oooooooooo`0;ooooo`Co00001?ooool2
o`0006oooooo0010ooooo`;o0000Goooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo0ol00008ooooo`03o`000?oooooooooo06kooooo0010ooooo`;o0000G_ooool2o`0000Wo
oooo00?o0000ooooooooool01Oooool4o`0000Wooooo0_l0001aooooo`00@Oooool2o`0005gooooo
0_l00008ooooo`;o00000oooool4o`0000cooooo0_l0001booooo`00@_ooool2o`0005cooooo00?o
0000ooooooooool01oooool5o`0000oooooo0_l0001cooooo`00@oooool2o`0005[ooooo0_l00005
ooooo`Go00004_ooool2o`0007Cooooo0014ooooo`;o0000FOooool7o`0000?ooooo00?o0000oooo
ooooool04?ooool2o`0007Gooooo0015ooooo`;o0000E_ooool4o`0000Oooooo0_l0000Aooooo`;o
0000M_ooool004Kooooo0_l0001Booooo`?o000000?oooooo`000?l000002?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo07Gooooo0017ooooo`;o0000COooool4o`0000Cooooo00?o
0000ooooooooool01_ooool2o`00017ooooo00?o0000ooooooooool0M_ooool004Sooooo0_l00018
ooooo`Co00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo0_l0001h
ooooo`00BOooool2o`0004Cooooo0ol0000;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1gooooo`00B_ooool2o`0003oooooo1?l0000>ooooo`03
o`000?oooooooooo00;ooooo1Ol0000Aooooo`03o`000?oooooooooo07Sooooo001;ooooo`;o0000
>oooool3o`0001;ooooo00?o0000ooooool000000_l00004ooooo`03o`000?oooooooooo00gooooo
0_l0001kooooo`00Boooool00ol0003oooooo`00000fooooo`Co00005?ooool3o`0000Kooooo00?o
0000ooooooooool03Oooool2o`0007cooooo001<ooooo`03o`000?oooooo0000037ooooo1?l0000H
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool2o`0007gooooo001=oooo
o`03o`000?oooooo000002gooooo0ol0000Kooooo`03o`000?oooooooooo00Kooooo0_l0000=oooo
o`;o0000O_ooool004kooooo00?o0000ooooool00000:?ooool4o`0001gooooo0_l00008ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0OOooool004oooooo0ol0000Sooooo`Co0000
8Oooool00ol0003oooooooooo`06ooooo`;o00003?ooool2o`00083ooooo001Aooooo`;o00007Ooo
ool5o`0002Cooooo0_l00008ooooo`;o00002oooool2o`00087ooooo001Booooo`;o00006?ooool4
o`0002Sooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`09ooooo`;o0000P_ooool0
05?ooooo0_l0000Cooooo`Co0000;?ooool2o`0000Sooooo0_l0000:ooooo`;o0000Poooool005Co
oooo0_l0000?ooooo`?o0000;oooool00ol0003oooooo`000008ooooo`;o00002Oooool2o`0008Co
oooo001Fooooo`03o`000?oooooooooo00Sooooo1?l0000aooooo`03o`000?oooooo000000Wooooo
00?o0000ooooooooool01oooool2o`0008Gooooo001Gooooo`03o`000?oooooooooo00Cooooo0ol0
000dooooo`03o`000?oooooo000000Wooooo0_l00008ooooo`03o`000?oooooooooo08Gooooo001H
ooooo`03o`000?oooooooooo00?o0000=oooool2o`0000[ooooo00?o0000ooooooooool01_ooool2
o`0008Oooooo001Iooooo`;o0000>Oooool2o`0000_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`27ooooo`00Foooool2o`0003Kooooo0_l0000<ooooo`03o`000?oooooooooo00?o
oooo0_l0002:ooooo`00GOooool2o`0003Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`02ooooo`;o0000Roooool005kooooo0ol0000aooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool00ol0002<ooooo`00H?ooool3o`0002gooooo0_l0000?ooooo`Co0000S_ooool0
067ooooo00Co0000ooooool0003o0000:Oooool3o`000:;ooooo001Rooooo`;o000000?oooooo`00
0?ooool09_ooool2o`000:Cooooo001Tooooo`Co00008oooool3o`000:Gooooo001Vooooo`Co0000
7oooool4o`000:Kooooo001Xooooo`Co00006oooool4o`000:Sooooo001[ooooo`?o00005oooool2
o`000003ooooool0003ooooo0:Wooooo001]ooooo`Oo00004?ooool01?l0003oooooo`000?l0002[
ooooo`00Koooool3o`0000;ooooo2Ol00005ooooo`Co0000[Oooool007;ooooo4Ol0002`ooooo`00
ooooooldooooo`00ooooooldooooo`00ooooooldooooo`00ooooooldooooo`00ooooooldooooo`00
ooooooldooooo`00ooooooldooooo`00ooooooldooooo`00ooooooldooooo`00ooooooldooooo`00
ooooooldooooo`00ooooooldooooo`00ooooooldooooo`00ooooooldooooo`00ooooooldooooo`00
ooooooldooooo`00ooooooldooooo`00\
\>"],
  ImageRangeCache->{{{-68.5, 422.75}, {437.938, -36.9375}} -> {0.122074, \
-0.0733829, 0.00198655, 0.00198655}},
  CellTags->"Prism Examples"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Polarizing Elements", "Section",
  CellTags->"Polarizing Elements"],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{
\tMove[SingleRay[Polarization->{1,1,0}],{0,5}],
\tMove[PolarizingPrism[30, 0, 50, 50],50],
\tBoundary[150,GraphicDesign->Off]},PlotType->TopView];\
\>", "Input",
  CellTags->"Polarizing Elements"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .36 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00634921 0.192698 0.00634921 [
[.5 .00857 -45 -4.5 ]
[.5 .00857 45 4.5 ]
[ 0 0 0 0 ]
[ 1 .36 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .03397 m
.34127 .35143 L
.34127 .35143 L
.34127 .03397 L
.34127 .03397 L
s
.40804 .03397 m
.59133 .35143 L
.59133 .35143 L
.40804 .03397 L
.40804 .03397 L
s
.59133 .35143 m
.34127 .35143 L
.34127 .35143 L
.59133 .35143 L
.59133 .35143 L
s
.40804 .03397 m
.34127 .03397 L
.34127 .03397 L
.40804 .03397 L
.40804 .03397 L
s
.34127 .03397 m
.34127 .35143 L
.59133 .35143 L
.40804 .03397 L
.34127 .03397 L
s
.34127 .03397 m
.34127 .35143 L
.59133 .35143 L
.40804 .03397 L
.34127 .03397 L
s
.40867 .03397 m
.59196 .35143 L
.59196 .35143 L
.40867 .03397 L
.40867 .03397 L
s
.65873 .03397 m
.65873 .35143 L
.65873 .35143 L
.65873 .03397 L
.65873 .03397 L
s
.65873 .35143 m
.59196 .35143 L
.59196 .35143 L
.65873 .35143 L
.65873 .35143 L
s
.65873 .03397 m
.40867 .03397 L
.40867 .03397 L
.65873 .03397 L
.65873 .03397 L
s
.40867 .03397 m
.59196 .35143 L
.65873 .35143 L
.65873 .03397 L
.40867 .03397 L
s
.40867 .03397 m
.59196 .35143 L
.65873 .35143 L
.65873 .03397 L
.40867 .03397 L
s
.039 .916 .04 r
.02381 .22444 m
.34127 .22444 L
s
0 0 0 r
2 Mabswid
.34127 .22444 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .22444 m
.51801 .22444 L
s
0 0 0 r
2 Mabswid
.51801 .22444 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .22444 m
.51801 .22444 L
s
0 0 0 r
2 Mabswid
.51801 .22444 Mdot
.039 .916 .04 r
.5 Mabswid
.51801 .22444 m
.5189 .22488 L
s
0 0 0 r
2 Mabswid
.5189 .22488 Mdot
.039 .916 .04 r
.5 Mabswid
.51801 .22444 m
.51879 .2247 L
s
0 0 0 r
2 Mabswid
.51879 .2247 Mdot
.039 .916 .04 r
.5 Mabswid
.5189 .22488 m
.65873 .23456 L
s
0 0 0 r
2 Mabswid
.65873 .23456 Mdot
.039 .916 .04 r
.5 Mabswid
.51879 .2247 m
.65873 .21635 L
s
0 0 0 r
2 Mabswid
.65873 .21635 Mdot
.039 .916 .04 r
.5 Mabswid
.65873 .23456 m
.97619 .26735 L
s
0 0 0 r
2 Mabswid
.97619 .26735 Mdot
.039 .916 .04 r
.5 Mabswid
.65873 .21635 m
.97619 .18477 L
s
0 0 0 r
2 Mabswid
.97619 .18477 Mdot
[(PolarizingPrism)] .5 .00857 0 0 Mshowa
0 0 m
1 0 L
1 .36 L
0 .36 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{761.438, 274.062},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;i00014R000`400?l00000o`00003oo`3ooooo
0?oooo/0oooo003o0?ooool0oooon`3oool00?l0ooooP@3oool200000?l0ooooN03oool00?l0oooo
P03oool010000000oooo0?ooo`00003o0?ooogL0oooo003o0?oooe`0oooo0`0000040?ooo`800000
0P3oool5000000030?ooo`00000000000080oooo1P0000000`3oool000000000000900000080oooo
0`0000030?ooo`030000003oool0oooo00D000000P3oool700000?l0ooooG`3oool00?l0ooooG@3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool01P000000oooo0?ooo`000000
oooo00000080oooo0P0000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000030?ooo`080000003oool0oooo0000003oool000000?ooo`00003o0?ooof00oooo003o0?oo
oed0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0080000000<0oooo0000003oool00P3oool010000000oooo0?ooo`0000030?ooo`080000003o
ool0oooo0000003oool000000?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0?l0ooooH03oool00?l0ooooG@3oool300000080oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0000003oool000000?ooo`8000000P3oool01@000000oooo0?ooo`3oool000000080oooo
00P000000?ooo`3oool000000?ooo`000000oooo00000080oooo00<000000?ooo`3oool00`000002
0?ooo`8000000P3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`000000o`3o
oomP0?ooo`00o`3ooomM0?ooo`040000003oool0oooo00000080oooo0P0000030?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`0000000P0000001@3oool00000000000000000oooo0080
000000@0oooo00000000000000000`3oool4000000080?ooo`000000oooo0?ooo`000000oooo0000
003oool300000080oooo0P0000000`3oool000000000000300000?l0ooooH@3oool00?l0ooooG@3o
ool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo01/0oooo00@000000?ooo`3oool0
0000o`3oooma0?ooo`00o`3ooomL0?ooo`@000001`3oool2000000T0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`090?ooo`@000001P3oool00`000000oooo0?ooo`3o0?ooofT0oooo
003o0?ooool0oooon`3oool00?l0ooooo`3ooook0?ooo`00o`3ooooo0?oooo/0oooo003o0?ooool0
oooon`3oool00?l0ooooo`3ooook0?ooo`00o`3ooooo0?oooo/0oooo003o0?ooool0oooon`3oool0
0?l0ooooo`3ooook0?ooo`00o`3ooooo0?oooo/0oooo003o0?ooool0oooon`3oool00?l0ooooo`3o
oook0?ooo`00o`3ooooo0?oooo/0oooo003o0?ooool0oooon`3oool00?l0ooooo`3ooook0?ooo`00
o`3ooooo0?oooo/0oooo003o0?ooo`@0oooolP00003o0?ooo`D0oooo003o0?ooo`@0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo0?l0oooo0`3oool0
0?l0oooo103oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0;X0oooo00<000000?oo
o`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0^P3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`00o`3oool40?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0^03oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`2g0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
o`3oool40?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0]P3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`2f0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`3o0?oo
o`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2d0?ooo`03
0000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0;<0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o
0?ooo`@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0
oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
0;40oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo0?l0oooo
0`3oool00?l0oooo103oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0[`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0
oooo103oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
[@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`00o`3oool40?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0[03oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`2[0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3o
ool40?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?oo
o`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`2Y
0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`3o0?ooo`<0
oooo003o0?ooo`@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2X0?ooo`030000
003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo0:L0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?oo
o`@0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo
0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0:D0
oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo0?l0oooo0`3o
ool00?l0oooo103oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0:@0oooo00<00000
0?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0X`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo
103oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0
o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0X@3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0o`3oool30?oo
o`00o`3oool40?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0X03oool00`000000
oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0C03oool00`000000oooo
0?ooo`2O0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool4
0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`2M0?oo
o`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo09d0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`3o0?ooo`<0oooo
003o0?ooo`@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`2L0?ooo`030000003o
ool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo09/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo
0540oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0?l0
oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo09T0oooo
00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool0V@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0?l0oooo0`3oool0
0?l0oooo103oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool0U`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103o
ool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`00o`3oool40?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0U@3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`2E0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
o`3oool40?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`2C0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`3o0?oo
o`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo0940oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o
0?ooo`@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo05d0
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo
00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?l0oooo
0`3oool00?l0oooo103oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo05h0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?oo
o`3oool0G`3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0
oooo103oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0
R`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0H@3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool0
0`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`00o`3oool40?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0R@3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0HP3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3o
ool40?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?oo
o`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`27
0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`03
0000003oool0oooo06D0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo003o0?ooo`@0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`250?ooo`030000
003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`1W0?ooo`030000003o
ool0oooo08@0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?oo
o`@0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo
0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo08<0
oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo06T0oooo
00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<0
00000?ooo`3oool0J@3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0?l0oooo0`3o
ool00?l0oooo103oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0840oooo00<00000
0?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0P03oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo
103oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0
o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0O`3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0K@3oool0
0`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`00
0000oooo0?ooo`1]0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3oool30?oo
o`00o`3oool40?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0O@3oool00`000000
oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0K`3oool00`000000oooo
0?ooo`1l0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?oo
o`1_0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool4
0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1k0?oo
o`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`1a0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000
003oool0oooo0740oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`3]0?ooo`800000
4`3oool00?l0oooo103oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool0j@3oool400WZ2P8000004`3oool00?l0oooo103oool00`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0g`3oool:00WZ2QT0oooo003o0?oo
o`@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
0=D0oooo2P09jPXS0?ooo`00o`3oool40?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`3;0?ooo`X02NX:;@3oool00?l0oooo103oool00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0`@3oool:00WZ2SL0oooo
003o0?ooo`@0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1f0?ooo`030000003o
ool0oooo0;L0oooo2P09jPY10?ooo`00o`3oool40?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool0M@3oool00`000000oooo0?ooo`2]0?ooo`X02NX:B`3oool00?l0oooo103oool00`00
0000oooo0?ooo`1f0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0X`3oool:00WZ
2UD0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo09T0oooo2P09jPYO0?ooo`00o`3oool40?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`2?0?ooo`X02NX:J@3oool00?l0oooo103o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0Q@3o
ool:00WZ2W<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo07/0oooo2P09jPYm0?ooo`00o`3oool40?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1`0?ooo`/02NX:Q`3oool00?l0
oooo103oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3o
ool0IP3oool:00WZ2Y80oooo003o0?ooo`@0oooo00<000000?ooo`3oool0NP3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo05`0oooo2P09jPZL0?ooo`00o`3oool40?ooo`030000003o
ool0oooo07/0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1B0?ooo`X02NX:YP3o
ool00?l0oooo103oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0700oooo00<00000
0?ooo`3oool0B03oool:00WZ2[00oooo003o0?ooo`@0oooo00<000000?ooo`3oool0O03oool00`00
0000oooo0?ooo`1_0?ooo`030000003oool0oooo03h0oooo2P09jPZj0?ooo`00o`3oool40?ooo`03
0000003oool0oooo07`0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0d0?ooo`X0
2NX:a03oool00?l0oooo103oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo06h0oooo
00<000000?ooo`3oool0:P3oool:00WZ2/h0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0OP3o
ool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0200oooo2P09jP[H0?ooo`00o`3oool4
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0F
0?ooo`X02NX:hP3oool00?l0oooo103oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo
06`0oooo00<000000?ooo`3oool0303oool:00WZ2^`0oooo003o0?ooo`@0oooo00<000000?ooo`3o
ool0O`3oool00`000000oooo0?ooo`1/0?ooo`8000000`3oool:00WZ2_H0oooo003o0?ooo`@0oooo
00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`1R0?ooo`h02NX:o`3oool10?ooo`00o`3o
ool40?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0D03ooolB00WZ2PT0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo0840oooo00<00000
0?ooo`3oool0?P3ooolA00WZ2Q/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?oo
o`030000003oool0oooo0880oooo00<000000?ooo`3oool0:`3ooolB00WZ2R`0oooo00<000000?oo
o`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo0880oooo00<000000?ooo`3o
ool06@3ooolB00WZ2Sh0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`800000
Q03oool2000000P0oooo4@09jPY@0?ooo`030000003oool0oooo0?l0oooo0`3oool001<0ooooo`09
jPYg00WZ2P0300000009jPX02NX:00L02NX:H@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o
0?ooo`@0oooo00<000000?ooo`3oool0Q03oool2000000L0oooo3`09jPYB0?ooo`030000003oool0
oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo
01D0oooo3`09jPY30?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000
oooo0?ooo`250?ooo`030000003oool0oooo02<0oooo3`09jPXd0?ooo`030000003oool0oooo0?l0
oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0340oooo
3`09jPXU0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo0400oooo3`09jPXF0?ooo`030000003oool0oooo0?l0oooo0`3o
ool00?l0oooo103oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo04h0oooo3`09jPX7
0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`270?oo
o`030000003oool0oooo05d0oooo3@09jP[o0?ooo`00o`3oool40?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool0H`3oool2000000@0oooo2@09jP[f0?ooo`00o`3oool40?ooo`030000
003oool0oooo08T0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0<0?ooo`X02NX:
k03oool00?l0oooo103oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool05P3oool:00WZ2^80oooo003o0?ooo`@0oooo00<000000?ooo`3oool0RP3oool0
0`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0200oooo2@09jP[I0?ooo`00o`3oool40?oo
o`030000003oool0oooo08X0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0Y0?oo
o`X02NX:c`3oool00?l0oooo103oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo0600
oooo00<000000?ooo`3oool0<`3oool:00WZ2/D0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0
R`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo03d0oooo2@09jPZl0?ooo`00o`3o
ool40?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?oo
o`160?ooo`X02NX:/P3oool00?l0oooo103oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo05h0oooo00<000000?ooo`3oool0D03oool:00WZ2ZP0oooo003o0?ooo`@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo05X0oooo2@09jPZO0?oo
o`00o`3oool40?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0G@3oool00`000000
oooo0?ooo`1S0?ooo`X02NX:U@3oool00?l0oooo103oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo05d0oooo00<000000?ooo`3oool0K@3oool:00WZ2X/0oooo003o0?ooo`@0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo07L0oooo2@09
jPZ20?ooo`00o`3oool40?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`200?ooo`X02NX:N03oool00?l0oooo103oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo05/0oooo00<000000?ooo`3oool0RP3oool900WZ2Vl0oooo003o0?ooo`@0
oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo09<0
oooo2P09jPYU0?ooo`00o`3oool40?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`2M0?ooo`X02NX:F`3oool00?l0oooo103oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0Y`3oool900WZ2U80oooo003o
0?ooo`@0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0
oooo0;00oooo2P09jPY80?ooo`00o`3oool40?ooo`030000003oool0oooo09<0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`2j0?ooo`X02NX:?P3oool00?l0oooo103oool00`000000
oooo0?ooo`2C0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0a03oool900WZ2SD0
oooo003o0?ooo`@0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo0<d0oooo2P09jPX[0?ooo`00o`3oool40?ooo`030000003oool0oooo09D0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`3G0?ooo`X02NX:8@3oool00?l0oooo103oool0
0`000000oooo0?ooo`2E0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0h@3oool9
00WZ2QP0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0>X0oooo0`09jPX2000001<0oooo003o0?ooo`@0oooo00<000000?ooo`3o
ool0UP3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0>d0oooo0P00000C0?ooo`00
o`3oool40?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`2H
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?oo
o`030000003oool0oooo09T0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?oo
o`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`2J0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003o
ool0oooo09X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o
0?ooo`@0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo09`0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo
00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0?l0oooo
0`3oool00?l0oooo103oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo09h0oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?oo
o`3oool0WP3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0
oooo103oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0X03o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool0
0`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`00o`3oool40?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0XP3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3o
ool40?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?oo
o`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`2T0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`03
0000003oool0oooo0:D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo003o0?ooo`@0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0
oooo0:L0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?oo
o`@0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo0:P0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<0
00000?ooo`3oool0Z@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0?l0oooo0`3o
ool00?l0oooo103oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo0:X0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3o
ool0Z`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo
103oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0[03oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`00
0000oooo0?ooo`2]0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0o`3oool30?oo
o`00o`3oool40?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0[P3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?oo
o`2_0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool4
0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3o
0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`2`0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000
003oool0oooo0;40oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
003o0?ooo`@0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`2b0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo
0;<0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0
oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0?l0
oooo0`3oool00?l0oooo103oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo0;@0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<00000
0?ooo`3oool0]@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0?l0oooo0`3oool0
0?l0oooo103oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool0o`3oool30?ooo`00o`3oool40?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0
]`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103o
ool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`00o`3oool40?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0^03oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oool00`000000
oooo0?ooo`2i0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0o`3oool30?ooo`00
o`3oool40?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo003o0?ooo`@0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo103oooob00000?l0oooo1@3oool0
0?l0ooooo`3ooook0?ooo`00o`3ooooo0?oooo/0oooo003o0?ooool0oooon`3oool00?l0ooooo`3o
oook0?ooo`00o`3ooooo0?oooo/0oooo003o0?ooool0oooon`3oool00001\
\>"],
  ImageRangeCache->{{{0, 760.438}, {273.062, 0}} -> {-3.95122, -30.3502, \
0.207647, 0.207647}},
  CellTags->"Polarizing Elements"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
 DrawSystem[{
\tSingleRay[Polarization->{1,1,0}],
\tMove[PolarizingPrism[70, {0,0}, 50, 50, \
ComponentMedium->{{1.5442,1.5533},1.455}, BeamSplitter->True],20],
\tBoundary[175,GraphicDesign->Off]},PlotType->TopView];\
\>", "Input",
  CellTags->"Polarizing Elements"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .58785 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00544218 0.179703 0.00544218 [
[.50673 .014 -45 -4.5 ]
[.50673 .014 45 4.5 ]
[ 0 0 0 0 ]
[ 1 .58785 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.13265 .04365 m
.13265 .31576 L
.13265 .31576 L
.13265 .04365 L
.13265 .04365 L
s
.88027 .31576 m
.70536 .5242 L
.70536 .5242 L
.88027 .31576 L
.88027 .31576 L
s
.13265 .04365 m
.88027 .31576 L
.88027 .31576 L
.13265 .04365 L
.13265 .04365 L
s
.13265 .31576 m
.70536 .5242 L
.70536 .5242 L
.13265 .31576 L
.13265 .31576 L
s
.13265 .04365 m
.13265 .31576 L
.70536 .5242 L
.88027 .31576 L
.13265 .04365 L
s
.13265 .04365 m
.13265 .31576 L
.70536 .5242 L
.88027 .31576 L
.13265 .04365 L
s
.1332 .04365 m
.88081 .31576 L
.88081 .31576 L
.1332 .04365 L
.1332 .04365 L
s
.88081 .04365 m
.88081 .31576 L
.88081 .31576 L
.88081 .04365 L
.88081 .04365 L
s
.88081 .04365 m
.1332 .04365 L
.1332 .04365 L
.88081 .04365 L
.88081 .04365 L
s
.1332 .04365 m
.88081 .31576 L
.88081 .04365 L
.1332 .04365 L
s
.1332 .04365 m
.88081 .31576 L
.88081 .04365 L
.1332 .04365 L
s
.039 .916 .04 r
.02381 .1797 m
.13265 .1797 L
s
0 0 0 r
2 Mabswid
.13265 .1797 Mdot
.039 .916 .04 r
.5 Mabswid
.13265 .1797 m
.50646 .1797 L
s
0 0 0 r
2 Mabswid
.50646 .1797 Mdot
.039 .916 .04 r
.5 Mabswid
.13265 .1797 m
.50646 .1797 L
s
0 0 0 r
2 Mabswid
.50646 .1797 Mdot
.039 .916 .04 r
.5 Mabswid
.50646 .1797 m
.5089 .18039 L
s
0 0 0 r
2 Mabswid
.5089 .18039 Mdot
.039 .916 .04 r
.5 Mabswid
.50646 .1797 m
.79281 .41998 L
s
0 0 0 r
2 Mabswid
.79281 .41998 Mdot
.039 .916 .04 r
.5 Mabswid
.5089 .18039 m
.88081 .18039 L
s
0 0 0 r
2 Mabswid
.88081 .18039 Mdot
.039 .916 .04 r
.5 Mabswid
.79281 .41998 m
.97619 .57385 L
s
0 0 0 r
2 Mabswid
.97619 .57385 Mdot
.039 .916 .04 r
.5 Mabswid
.88081 .18039 m
.97619 .18039 L
s
0 0 0 r
2 Mabswid
.97619 .18039 Mdot
[(PolarizingPrism)] .50673 .014 0 0 Mshowa
0 0 m
1 0 L
1 .58785 L
0 .58785 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{308.625, 181.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004d0000]B000`400?l00000o`00003oX03oool2
00000980oooo002O0?ooo`040000003oool0oooo00000940oooo001k0?ooo`<00000103oool20000
0080oooo1@0000000`3oool00000000000020?ooo`H0000000<0oooo0000000000002@0000020?oo
o`<000000`3oool00`000000oooo0?ooo`0500000080oooo1`00001i0?ooo`00O03oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`000000103oool01P000000oooo0?ooo`000000oooo00000080
oooo0P0000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?oo
o`080000003oool0oooo0000003oool000000?ooo`00001j0?ooo`00O03oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P0000000`3oool00000
0?ooo`020?ooo`040000003oool0oooo000000<0oooo00P000000?ooo`3oool000000?ooo`000000
oooo00000080oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool000000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000NP3oool007`0oooo0`000002
0?ooo`040000003oool0oooo00000080oooo00H000000?ooo`000000oooo0000003oool200000080
oooo00D000000?ooo`3oool0oooo000000020?ooo`080000003oool0oooo0000003oool000000?oo
o`0000020?ooo`030000003oool0oooo00<000000P3oool200000080oooo00<000000?ooo`000000
103oool01@000000oooo0000003oool0000007X0oooo001l0?ooo`040000003oool0oooo00000080
oooo0P0000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000P0000001@3o
ool00000000000000000oooo0080000000@0oooo00000000000000000`3oool4000000080?ooo`00
0000oooo0?ooo`000000oooo0000003oool300000080oooo0P0000000`3oool00000000000030000
07/0oooo001l0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool06`3oool01000
0000oooo0?ooo`00002;0?ooo`00N`3oool4000000L0oooo0P0000090?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02@3oool4000000H0oooo00<000000?ooo`3oool0P`3oool00?l0
oooo=@3oool00?l0oooo=@3oool00?l0oooo=@3oool00?l0oooo=@3oool002T0oooo00<000000?oo
o`3oool0hP3oool00`000000oooo0?ooo`0S0?ooo`00:@3ooooV000002D0oooo000Y0?ooo`030000
003oool0000000800000h03oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?oo
o`020?ooo`<00000g@3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`05
0?ooo`<00000fP3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`080?oo
o`800000f03oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`0:0?ooo`<0
0000e@3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`0=0?ooo`<00000
dP3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`0@0?ooo`<00000c`3o
ool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`0C0?ooo`800000c@3oool0
0`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`00
0000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`0H0?ooo`<00000a`3oool00`000000
oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`0K0?ooo`<00000a03oool00`000000oooo
0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`0N0?ooo`800000`P3oool00`000000oooo0?oo
o`0S0?ooo`00:@3oool00`000000oooo0?ooo`0P0?ooo`<00000_`3oool00`000000oooo0?ooo`0S
0?ooo`00:@3oool00`000000oooo0?ooo`0S0?ooo`<00000_03oool00`000000oooo0?ooo`0S0?oo
o`00:@3oool00`000000oooo0?ooo`0V0?ooo`<00000^@3oool00`000000oooo0?ooo`0S0?ooo`00
:@3oool00`000000oooo0?ooo`0Y0?ooo`<00000]P3oool00`000000oooo0?ooo`0S0?ooo`00:@3o
ool00`000000oooo0?ooo`0/0?ooo`800000]03oool00`000000oooo0?ooo`0S0?ooo`00:@3oool0
0`000000oooo0?ooo`0^0?ooo`<00000/@3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`00
0000oooo0?ooo`0a0?ooo`<00000[P3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000
oooo0?ooo`0d0?ooo`<00000Z`3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo
0?ooo`0g0?ooo`800000Z@3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?oo
o`0i0?ooo`<00000YP3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`0l
0?ooo`<00000X`3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`0o0?oo
o`<00000X03oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`120?ooo`80
0000WP3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`140?ooo`<00000
V`3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`170?ooo`<00000V03o
ool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`1:0?ooo`<00000U@3oool0
0`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`1=0?ooo`800000T`3oool00`00
0000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`1?0?ooo`<00000T03oool00`000000
oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`1B0?ooo`<00000S@3oool00`000000oooo
0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`1E0?ooo`<00000RP3oool00`000000oooo0?oo
o`0S0?ooo`00:@3oool00`000000oooo0?ooo`1H0?ooo`800000R03oool00`000000oooo0?ooo`0S
0?ooo`00:@3oool00`000000oooo0?ooo`1J0?ooo`<00000Q@3oool00`000000oooo0?ooo`0S0?oo
o`00:@3oool00`000000oooo0?ooo`1M0?ooo`<00000PP3oool00`000000oooo0?ooo`0S0?ooo`00
:@3oool00`000000oooo0?ooo`1P0?ooo`<00000O`3oool00`000000oooo0?ooo`0S0?ooo`00:@3o
ool00`000000oooo0?ooo`1S0?ooo`800000O@3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool0
0`000000oooo0?ooo`1U0?ooo`<00000NP3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`00
0000oooo0?ooo`1X0?ooo`<00000M`3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000
oooo0?ooo`1[0?ooo`<00000M03oool00`000000oooo0?ooo`0S0?ooo`001`3ooolQ00WZ2P030000
0009jPX02NX:07802NX:00<000000?ooo`3oool0KP3oool2000001/0oooo0P0000070?ooo`00:03o
ool200000740oooo00<0000000WZ2P09jPX0S@09jPX2000000L0oooo000Y0?ooo`030000003oool0
oooo0780oooo00@02NX:0000000000000000K03oool00`000000oooo0?ooo`0S0?ooo`00:@3oool0
0`000000oooo0?ooo`1c0?ooo`0300WZ2P3oool0oooo00<00000J@3oool00`000000oooo0?ooo`0S
0?ooo`00:@3oool00`000000oooo0?ooo`1d0?ooo`0300WZ2P3oool0oooo0080oooo0`00001V0?oo
o`030000003oool0oooo02<0oooo000Y0?ooo`030000003oool0oooo07D0oooo0P09jPX50?ooo`80
0000I03oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`1g0?ooo`0300WZ
2P3oool0oooo00@0oooo0`00001Q0?ooo`030000003oool0oooo02<0oooo000Y0?ooo`030000003o
ool0oooo07P0oooo00<02NX:0?ooo`3oool01P3oool3000005h0oooo00<000000?ooo`3oool08`3o
ool002T0oooo00<000000?ooo`3oool0N@3oool00`09jPX0oooo0?ooo`080?ooo`<00000F`3oool0
0`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`1j0?ooo`0300WZ2P3oool0oooo
00X0oooo0P00001I0?ooo`030000003oool0oooo02<0oooo000Y0?ooo`030000003oool0oooo07/0
oooo00<02NX:0?ooo`3oool02`3oool3000005H0oooo00<000000?ooo`3oool08`3oool002T0oooo
00<000000?ooo`3oool0O03oool200WZ2Ph0oooo0`00001C0?ooo`030000003oool0oooo02<0oooo
000Y0?ooo`030000003oool0oooo07h0oooo00<02NX:0?ooo`3oool03P3oool300000500oooo00<0
00000?ooo`3oool08`3oool002T0oooo00<000000?ooo`3oool0O`3oool00`09jPX0oooo0?ooo`0@
0?ooo`800000CP3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`200?oo
o`0300WZ2P3oool0oooo0140oooo0`00001;0?ooo`030000003oool0oooo02<0oooo000Y0?ooo`03
0000003oool0oooo0840oooo00<02NX:0?ooo`3oool04`3oool3000004P0oooo00<000000?ooo`3o
ool08`3oool002T0oooo00<000000?ooo`3oool0PP3oool200WZ2QH0oooo0`0000150?ooo`030000
003oool0oooo02<0oooo000Y0?ooo`030000003oool0oooo08@0oooo00<02NX:0?ooo`3oool05P3o
ool2000004<0oooo00<000000?ooo`3oool08`3oool002T0oooo00<000000?ooo`3oool0Q@3oool0
0`09jPX0oooo0?ooo`0G0?ooo`<00000@03oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`00
0000oooo0?ooo`260?ooo`0300WZ2P3oool0oooo01T0oooo0`00000m0?ooo`030000003oool0oooo
02<0oooo000Y0?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool06`3oool3000003X0
oooo00<000000?ooo`3oool08`3oool002T0oooo00<000000?ooo`3oool0R03oool200WZ2Qh0oooo
0P00000h0?ooo`030000003oool0oooo02<0oooo000Y0?ooo`030000003oool0oooo08X0oooo00<0
2NX:0?ooo`3oool07@3oool3000003D0oooo00<000000?ooo`3oool08`3oool002T0oooo00<00000
0?ooo`3oool0R`3oool00`09jPX0oooo0?ooo`0O0?ooo`<00000<P3oool00`000000oooo0?ooo`0S
0?ooo`00:@3oool00`000000oooo0?ooo`2<0?ooo`0300WZ2P3oool0oooo0240oooo0`00000_0?oo
o`030000003oool0oooo02<0oooo000Y0?ooo`030000003oool0oooo08d0oooo00<02NX:0?ooo`3o
ool08`3oool2000002d0oooo00<000000?ooo`3oool08`3oool002T0oooo00<000000?ooo`3oool0
SP3oool200WZ2RD0oooo0`00000Z0?ooo`030000003oool0oooo02<0oooo000Y0?ooo`030000003o
ool0oooo0900oooo00<02NX:0?ooo`3oool09@3oool3000002L0oooo00<000000?ooo`3oool08`3o
ool002T0oooo00<000000?ooo`3oool0T@3oool00`09jPX0oooo0?ooo`0W0?ooo`<00000903oool0
0`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`2B0?ooo`0300WZ2P3oool0oooo
02T0oooo0`00000Q0?ooo`030000003oool0oooo02<0oooo000Y0?ooo`030000003oool0oooo09<0
oooo00<02NX:0?ooo`3oool0:`3oool2000001l0oooo00<000000?ooo`3oool08`3oool002T0oooo
00<000000?ooo`3oool0U03oool00`09jPX0oooo0?ooo`0/0?ooo`<00000703oool00`000000oooo
0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`2E0?ooo`802NX:;`3oool3000001T0oooo00<0
00000?ooo`3oool08`3oool002T0oooo00<000000?ooo`3oool0U`3oool00`09jPX0oooo0?ooo`0_
0?ooo`<000005P3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`2H0?oo
o`0300WZ2P3oool0oooo0340oooo0P00000D0?ooo`030000003oool0oooo02<0oooo000Y0?ooo`03
0000003oool0oooo09T0oooo00<02NX:0?ooo`3oool0<P3oool300000140oooo00<000000?ooo`3o
ool08`3oool002T0oooo00<000000?ooo`3oool0VP3oool00`09jPX0oooo0?ooo`0d0?ooo`<00000
3P3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`000000oooo0?ooo`2K0?ooo`802NX:=`3o
ool3000000/0oooo00<000000?ooo`3oool08`3oool002T0oooo00<000000?ooo`3oool0W@3oool0
0`09jPX0oooo0?ooo`0g0?ooo`8000002@3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool00`00
0000oooo0?ooo`2N0?ooo`0300WZ2P3oool0oooo03P0oooo0`0000060?ooo`030000003oool0oooo
02<0oooo000Y0?ooo`030000003oool0oooo09l0oooo00<02NX:0?ooo`3oool0>P3oool3000000<0
oooo00<000000?ooo`3oool08`3oool002T0oooo00<000000?ooo`3oool0X03oool00`09jPX0oooo
0?ooo`0l0?ooo`@000009@3oool002T0oooo0P00002R0?ooo`802NX:?`3oool00`000000oooo0?oo
o`0S0?ooo`00:`3oool300000:40oooo00<02NX:0?ooo`3oool0?03oool00`000000oooo0?ooo`0S
0?ooo`00;P3oool3000009l0oooo00<02NX:0?ooo`3oool0>P3oool00`000000oooo0?ooo`0T0?oo
o`00<@3oool3000009d0oooo00<02NX:0?ooo`3oool0>03oool00`000000oooo0?ooo`0U0?ooo`00
=03oool2000009`0oooo00<02NX:0?ooo`3oool0=P3oool00`000000oooo0?ooo`0V0?ooo`00=P3o
ool3000009X0oooo00<02NX:0?ooo`3oool0=03oool00`000000oooo0?ooo`0W0?ooo`00>@3oool3
000009P0oooo0P09jPXc0?ooo`030000003oool0oooo02P0oooo000l0?ooo`<00000U`3oool00`09
jPX0oooo0?ooo`0`0?ooo`030000003oool0oooo02P0oooo000o0?ooo`800000UP3oool00`09jPX0
oooo0?ooo`0^0?ooo`030000003oool0oooo02T0oooo00110?ooo`<00000U03oool00`09jPX0oooo
0?ooo`0/0?ooo`030000003oool0oooo02X0oooo00140?ooo`<00000TP3oool00`09jPX0oooo0?oo
o`0Z0?ooo`030000003oool0oooo02/0oooo00170?ooo`800000T@3oool200WZ2RT0oooo00<00000
0?ooo`3oool0;03oool004T0oooo0`00002@0?ooo`0300WZ2P3oool0oooo02D0oooo00<000000?oo
o`3oool0;@3oool004`0oooo0`00002>0?ooo`0300WZ2P3oool0oooo02<0oooo00<000000?ooo`3o
ool0;P3oool004l0oooo0`00002<0?ooo`0300WZ2P3oool0oooo0280oooo00<000000?ooo`3oool0
;P3oool00580oooo0P00002;0?ooo`0300WZ2P3oool0oooo0200oooo00<000000?ooo`3oool0;`3o
ool005@0oooo0`0000290?ooo`802NX:7`3oool00`000000oooo0?ooo`0`0?ooo`00E`3oool30000
08P0oooo00<02NX:0?ooo`3oool06`3oool00`000000oooo0?ooo`0a0?ooo`00FP3oool3000008H0
oooo00<02NX:0?ooo`3oool06@3oool00`000000oooo0?ooo`0b0?ooo`00G@3oool2000008D0oooo
00<02NX:0?ooo`3oool05`3oool00`000000oooo0?ooo`0c0?ooo`00G`3oool3000008<0oooo00<0
2NX:0?ooo`3oool05P3oool00`000000oooo0?ooo`0c0?ooo`00HP3oool300000840oooo0P09jPXE
0?ooo`030000003oool0oooo03@0oooo001U0?ooo`<00000P03oool00`09jPX0oooo0?ooo`0A0?oo
o`030000003oool0oooo03D0oooo001X0?ooo`800000O`3oool00`09jPX0oooo0?ooo`0?0?ooo`03
0000003oool0oooo03H0oooo001Z0?ooo`<00000O@3oool00`09jPX0oooo0?ooo`0=0?ooo`030000
003oool0oooo03L0oooo001]0?ooo`<00000N`3oool00`09jPX0oooo0?ooo`0;0?ooo`030000003o
ool0oooo03P0oooo001`0?ooo`800000NP3oool00`09jPX0oooo0?ooo`090?ooo`030000003oool0
oooo03T0oooo001b0?ooo`<00000N03oool200WZ2PT0oooo00<000000?ooo`3oool0>@3oool007D0
oooo0`00001g0?ooo`0300WZ2P3oool0oooo00D0oooo00<000000?ooo`3oool0>P3oool007P0oooo
0`00001e0?ooo`0300WZ2P3oool0oooo00<0oooo00<000000?ooo`3oool0>`3oool007/0oooo0P00
001d0?ooo`0500WZ2P3oool0oooo0?ooo`000000?P3oool007d0oooo0`00001b0?ooo`0300WZ2P3o
ool0000003l0oooo00200?ooo`<00000L03oool200WZ2Sl0oooo00230?ooo`<00000K@3oool20000
000300WZ2P3oool0oooo03`0oooo00260?ooo`800000JP3oool01@000000oooo0?ooo`3oool02NX:
03d0oooo00280?ooo`<00000IP3oool00`000000oooo0?ooo`030?ooo`0300WZ2P3oool0oooo03X0
oooo002;0?ooo`<00000HP3oool00`000000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo03T0oooo
002>0?ooo`<00000GP3oool00`000000oooo0?ooo`070?ooo`802NX:>@3oool00940oooo0P00001K
0?ooo`030000003oool0oooo00X0oooo00<02NX:0?ooo`3oool0=P3oool009<0oooo0`00001H0?oo
o`030000003oool0oooo00/0oooo00<02NX:0?ooo`3oool0=@3oool009H0oooo0`00001D0?ooo`03
0000003oool0oooo00d0oooo00<02NX:0?ooo`3oool0=03oool009T0oooo0P00001A0?ooo`030000
003oool0oooo00l0oooo00<02NX:0?ooo`3oool0<`3oool009/0oooo0`00001=0?ooo`030000003o
ool0oooo0140oooo0P09jPXc0?ooo`00WP3oool3000004T0oooo00<000000?ooo`3oool0503oool0
0`09jPX0oooo0?ooo`0`0?ooo`00X@3oool3000004D0oooo00<000000?ooo`3oool05P3oool00`09
jPX0oooo0?ooo`0_0?ooo`00Y03oool200000480oooo00<000000?ooo`3oool0603oool00`09jPX0
oooo0?ooo`0^0?ooo`00YP3oool3000003l0oooo00<000000?ooo`3oool06@3oool00`09jPX0oooo
0?ooo`0]0?ooo`00Z@3oool3000003/0oooo00<000000?ooo`3oool06`3oool00`09jPX0oooo0?oo
o`0/0?ooo`00[03oool3000003L0oooo00<000000?ooo`3oool07@3oool200WZ2R`0oooo002_0?oo
o`800000=03oool00`000000oooo0?ooo`0P0?ooo`0300WZ2P3oool0oooo02T0oooo002a0?ooo`<0
0000<03oool00`000000oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo02P0oooo002d0?ooo`<00000
;03oool00`000000oooo0?ooo`0T0?ooo`0300WZ2P3oool0oooo02L0oooo002g0?ooo`<00000:@3o
ool00`000000oooo0?ooo`0U0?ooo`0300WZ2P3oool0oooo02H0oooo002j0?ooo`8000009P3oool0
0`000000oooo0?ooo`0W0?ooo`802NX:9P3oool00;`0oooo0`00000R0?ooo`030000003oool0oooo
02X0oooo00<02NX:0?ooo`3oool08`3oool00;l0oooo0`00000N0?ooo`030000003oool0oooo02`0
oooo00<02NX:0?ooo`3oool08P3oool00<80oooo0P00000K0?ooo`030000003oool0oooo02h0oooo
00<02NX:0?ooo`3oool08@3oool00<@0oooo0`00000G0?ooo`030000003oool0oooo0300oooo00<0
2NX:0?ooo`3oool0803oool00<L0oooo0`00000C0?ooo`030000003oool0oooo0380oooo0P09jPXP
0?ooo`00bP3oool300000100oooo00<000000?ooo`3oool0=03oool00`09jPX0oooo0?ooo`0M0?oo
o`00c@3oool2000000d0oooo00<000000?ooo`3oool0=P3oool00`09jPX0oooo0?ooo`0L0?ooo`00
c`3oool3000000T0oooo00<000000?ooo`3oool0>03oool00`09jPX0oooo0?ooo`0K0?ooo`00dP3o
ool3000000D0oooo00<000000?ooo`3oool0>P3oool00`09jPX0oooo0?ooo`0J0?ooo`00e@3oool3
000000030?ooo`000000oooo03d0oooo0P09jPXJ0?ooo`00f03oool200000400oooo00<02NX:0?oo
o`3oool05`3oool00?l0oooo703oool00`09jPX0oooo0?ooo`0F0?ooo`00o`3ooolM0?ooo`0300WZ
2P3oool0oooo01D0oooo003o0?oooah0oooo00<02NX:0?ooo`3oool0503oool00?l0oooo7`3oool0
0`09jPX0oooo0?ooo`0C0?ooo`00o`3ooolP0?ooo`802NX:4`3oool00?l0oooo8P3oool00`09jPX0
oooo0?ooo`0@0?ooo`00o`3ooolS0?ooo`0300WZ2P3oool0oooo00l0oooo003o0?ooob@0oooo00<0
2NX:0?ooo`3oool03P3oool00?l0oooo9@3oool00`09jPX0oooo0?ooo`0=0?ooo`00o`3ooolV0?oo
o`802NX:3@3oool00?l0oooo:03oool00`09jPX0oooo0?ooo`0:0?ooo`00o`3ooolY0?ooo`0300WZ
2P3oool0oooo00T0oooo003o0?ooobX0oooo00<02NX:0?ooo`3oool0203oool00?l0oooo:`3oool0
0`09jPX0oooo0?ooo`070?ooo`00o`3oool/0?ooo`8000001`3oool00?l0oooo;03oool2000000L0
oooo003o0?ooocD0oooo003o0?ooocD0oooo003o0?ooocD0oooo0000\
\>"],
  ImageRangeCache->{{{0, 307.625}, {180.375, 0}} -> {-4.7184, -33.1464, \
0.59955, 0.59955}},
  CellTags->"Polarizing Elements"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[
\t{RainbowOfRays[{.35,.85},NumberOfRays->50,Polarization->{1,1,0}],
\tMove[FresnelRhomb[10,{DesignWaveLength->.5876}],10],
\tBoundary[50]},
\tPlotType->TopView, ThresholdIntensity->10];
pol = ReadRays[sys,{WaveLength,Polarization[[3]]},IntersectionNumber->5];
ListPlot[pol,PlotJoined->True];\
\>", "Input",
  CellTags->"Polarizing Elements"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.5 0.0190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.21429 .61596 m
.21429 .38404 L
.21429 .38404 L
.21429 .61596 L
.21429 .61596 L
s
.66478 .92884 m
.66478 .69693 L
.66478 .69693 L
.66478 .92884 L
.66478 .92884 L
s
.66478 .92884 m
.21429 .61596 L
.21429 .61596 L
.66478 .92884 L
.66478 .92884 L
s
.66478 .69693 m
.21429 .38404 L
.21429 .38404 L
.66478 .69693 L
.66478 .69693 L
s
.21429 .61596 m
.21429 .38404 L
.66478 .69693 L
.66478 .92884 L
.21429 .61596 L
s
.21429 .61596 m
.21429 .38404 L
.66478 .69693 L
.66478 .92884 L
.21429 .61596 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.002 .018 .48 r
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.002 .02 .834 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.002 .022 .9 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.002 .025 .923 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.002 .028 .933 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.001 .032 .937 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.001 .038 .937 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.001 .045 .935 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
0 .055 .928 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
0 .072 .917 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.001 .099 .896 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.002 .152 .851 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.003 .282 .728 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.005 .569 .386 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.007 .775 .166 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.01 .853 .096 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.016 .889 .065 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.025 .907 .049 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.043 .917 .038 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.093 .922 .031 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.41 .923 .026 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.851 .918 .023 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.915 .905 .02 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.936 .869 .017 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.945 .726 .016 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.949 .221 .014 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.951 .077 .013 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.952 .04 .012 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.951 .024 .011 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.948 .015 .01 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.945 .01 .009 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.939 .007 .009 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.931 .005 .008 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.918 .003 .008 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.898 .002 .007 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.86 .001 .007 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.779 0 .006 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.569 0 .006 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.283 .001 .006 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.155 .001 .006 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.102 .001 .005 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.075 .002 .005 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.059 .002 .005 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.048 .002 .005 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.041 .002 .004 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.046 .002 .005 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.056 .002 .005 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.071 .002 .005 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.096 .001 .005 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.141 .001 .005 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.002 .018 .48 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.002 .02 .834 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.002 .022 .9 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.002 .025 .923 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.002 .028 .933 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.001 .032 .937 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.001 .038 .937 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.001 .045 .935 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
0 .055 .928 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
0 .072 .917 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.001 .099 .896 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.002 .152 .851 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.003 .282 .728 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.005 .569 .386 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.007 .775 .166 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.01 .853 .096 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.016 .889 .065 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.025 .907 .049 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.043 .917 .038 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.093 .922 .031 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.41 .923 .026 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.851 .918 .023 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.915 .905 .02 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.936 .869 .017 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.945 .726 .016 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.949 .221 .014 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.951 .077 .013 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.952 .04 .012 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.951 .024 .011 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.948 .015 .01 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.945 .01 .009 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.939 .007 .009 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.931 .005 .008 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.918 .003 .008 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.898 .002 .007 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.86 .001 .007 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.779 0 .006 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.569 0 .006 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.283 .001 .006 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.155 .001 .006 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.102 .001 .005 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.075 .002 .005 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.059 .002 .005 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.048 .002 .005 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.041 .002 .004 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.046 .002 .005 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.056 .002 .005 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.071 .002 .005 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.096 .001 .005 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.141 .001 .005 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.002 .018 .48 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.002 .02 .834 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.002 .022 .9 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.002 .025 .923 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.002 .028 .933 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.001 .032 .937 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.001 .038 .937 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.001 .045 .935 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
0 .055 .928 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
0 .072 .917 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.001 .099 .896 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.002 .152 .851 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.003 .282 .728 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.005 .569 .386 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.007 .775 .166 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.01 .853 .096 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.016 .889 .065 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.025 .907 .049 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.043 .917 .038 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.093 .922 .031 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.41 .923 .026 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.851 .918 .023 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.915 .905 .02 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.936 .869 .017 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.945 .726 .016 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.949 .221 .014 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.951 .077 .013 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.952 .04 .012 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.951 .024 .011 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.948 .015 .01 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.945 .01 .009 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.939 .007 .009 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.931 .005 .008 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.918 .003 .008 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.898 .002 .007 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.86 .001 .007 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.779 0 .006 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.569 0 .006 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.283 .001 .006 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.155 .001 .006 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.102 .001 .005 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.075 .002 .005 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.059 .002 .005 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.048 .002 .005 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.041 .002 .004 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.046 .002 .005 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.056 .002 .005 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.071 .002 .005 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.096 .001 .005 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.141 .001 .005 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.002 .018 .48 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.002 .02 .834 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.002 .022 .9 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.002 .025 .923 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.002 .028 .933 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.001 .032 .937 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.001 .038 .937 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.001 .045 .935 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
0 .055 .928 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
0 .072 .917 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.001 .099 .896 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.002 .152 .851 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.003 .282 .728 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.005 .569 .386 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.007 .775 .166 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.01 .853 .096 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.016 .889 .065 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.025 .907 .049 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.043 .917 .038 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.093 .922 .031 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.41 .923 .026 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.851 .918 .023 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.915 .905 .02 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.936 .869 .017 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.945 .726 .016 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.949 .221 .014 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.951 .077 .013 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.952 .04 .012 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.951 .024 .011 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.948 .015 .01 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.945 .01 .009 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.939 .007 .009 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.931 .005 .008 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.918 .003 .008 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.898 .002 .007 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.86 .001 .007 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.779 0 .006 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.569 0 .006 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.283 .001 .006 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.155 .001 .006 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.102 .001 .005 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.075 .002 .005 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.059 .002 .005 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.048 .002 .005 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.041 .002 .004 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.046 .002 .005 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.056 .002 .005 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.071 .002 .005 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.096 .001 .005 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.141 .001 .005 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.002 .018 .48 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.002 .02 .834 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.002 .022 .9 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.002 .025 .923 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.002 .028 .933 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.001 .032 .937 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.001 .038 .937 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.001 .045 .935 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
0 .055 .928 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
0 .072 .917 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.001 .099 .896 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.002 .152 .851 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.003 .282 .728 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.005 .569 .386 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.007 .775 .166 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.01 .853 .096 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.016 .889 .065 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.025 .907 .049 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.043 .917 .038 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.093 .922 .031 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.41 .923 .026 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.851 .918 .023 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.915 .905 .02 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.936 .869 .017 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.945 .726 .016 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.949 .221 .014 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.951 .077 .013 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.952 .04 .012 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.951 .024 .011 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.948 .015 .01 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.945 .01 .009 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.939 .007 .009 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.931 .005 .008 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.918 .003 .008 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.898 .002 .007 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.86 .001 .007 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.779 0 .006 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.569 0 .006 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.283 .001 .006 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.155 .001 .006 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.102 .001 .005 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.075 .002 .005 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.059 .002 .005 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.048 .002 .005 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.041 .002 .004 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.046 .002 .005 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.056 .002 .005 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.071 .002 .005 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.096 .001 .005 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.141 .001 .005 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.25026, -26.2503, 0.182929, \
0.182929}},
  CellTags->"Polarizing Elements"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.642857 1.90476 -19.0072 0.212967 [
[.30952 .1473 -9 -9 ]
[.30952 .1473 9 0 ]
[.5 .1473 -9 -9 ]
[.5 .1473 9 0 ]
[.69048 .1473 -9 -9 ]
[.69048 .1473 9 0 ]
[.88095 .1473 -9 -9 ]
[.88095 .1473 9 0 ]
[.10655 .05332 -24 -4.5 ]
[.10655 .05332 0 4.5 ]
[.10655 .26629 -24 -4.5 ]
[.10655 .26629 0 4.5 ]
[.10655 .37277 -12 -4.5 ]
[.10655 .37277 0 4.5 ]
[.10655 .47925 -24 -4.5 ]
[.10655 .47925 0 4.5 ]
[.10655 .58574 -12 -4.5 ]
[.10655 .58574 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.30952 .1598 m
.30952 .16605 L
s
[(0.5)] .30952 .1473 0 1 Mshowa
.5 .1598 m
.5 .16605 L
s
[(0.6)] .5 .1473 0 1 Mshowa
.69048 .1598 m
.69048 .16605 L
s
[(0.7)] .69048 .1473 0 1 Mshowa
.88095 .1598 m
.88095 .16605 L
s
[(0.8)] .88095 .1473 0 1 Mshowa
.125 Mabswid
.15714 .1598 m
.15714 .16355 L
s
.19524 .1598 m
.19524 .16355 L
s
.23333 .1598 m
.23333 .16355 L
s
.27143 .1598 m
.27143 .16355 L
s
.34762 .1598 m
.34762 .16355 L
s
.38571 .1598 m
.38571 .16355 L
s
.42381 .1598 m
.42381 .16355 L
s
.4619 .1598 m
.4619 .16355 L
s
.5381 .1598 m
.5381 .16355 L
s
.57619 .1598 m
.57619 .16355 L
s
.61429 .1598 m
.61429 .16355 L
s
.65238 .1598 m
.65238 .16355 L
s
.72857 .1598 m
.72857 .16355 L
s
.76667 .1598 m
.76667 .16355 L
s
.80476 .1598 m
.80476 .16355 L
s
.84286 .1598 m
.84286 .16355 L
s
.08095 .1598 m
.08095 .16355 L
s
.04286 .1598 m
.04286 .16355 L
s
.00476 .1598 m
.00476 .16355 L
s
.91905 .1598 m
.91905 .16355 L
s
.95714 .1598 m
.95714 .16355 L
s
.99524 .1598 m
.99524 .16355 L
s
.25 Mabswid
0 .1598 m
1 .1598 L
s
.11905 .05332 m
.1253 .05332 L
s
[(89.5)] .10655 .05332 1 0 Mshowa
.11905 .26629 m
.1253 .26629 L
s
[(90.5)] .10655 .26629 1 0 Mshowa
.11905 .37277 m
.1253 .37277 L
s
[(91)] .10655 .37277 1 0 Mshowa
.11905 .47925 m
.1253 .47925 L
s
[(91.5)] .10655 .47925 1 0 Mshowa
.11905 .58574 m
.1253 .58574 L
s
[(92)] .10655 .58574 1 0 Mshowa
.125 Mabswid
.11905 .07462 m
.1228 .07462 L
s
.11905 .09591 m
.1228 .09591 L
s
.11905 .11721 m
.1228 .11721 L
s
.11905 .13851 m
.1228 .13851 L
s
.11905 .1811 m
.1228 .1811 L
s
.11905 .2024 m
.1228 .2024 L
s
.11905 .22369 m
.1228 .22369 L
s
.11905 .24499 m
.1228 .24499 L
s
.11905 .28758 m
.1228 .28758 L
s
.11905 .30888 m
.1228 .30888 L
s
.11905 .33018 m
.1228 .33018 L
s
.11905 .35147 m
.1228 .35147 L
s
.11905 .39407 m
.1228 .39407 L
s
.11905 .41536 m
.1228 .41536 L
s
.11905 .43666 m
.1228 .43666 L
s
.11905 .45796 m
.1228 .45796 L
s
.11905 .50055 m
.1228 .50055 L
s
.11905 .52185 m
.1228 .52185 L
s
.11905 .54314 m
.1228 .54314 L
s
.11905 .56444 m
.1228 .56444 L
s
.11905 .03202 m
.1228 .03202 L
s
.11905 .01073 m
.1228 .01073 L
s
.11905 .60703 m
.1228 .60703 L
s
.25 Mabswid
.11905 0 m
.11905 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.04325 .56473 L
.06268 .52944 L
.08212 .49705 L
.10155 .46724 L
.12099 .43973 L
.14043 .41427 L
.15986 .39066 L
.1793 .3687 L
.19874 .34824 L
.21817 .32914 L
.23761 .31128 L
.25705 .29453 L
.27648 .27881 L
.29592 .26402 L
.31535 .2501 L
.33479 .23695 L
.35423 .22453 L
.37366 .21278 L
.3931 .20164 L
.41254 .19106 L
.43197 .18101 L
.45141 .17144 L
.47085 .16232 L
.49028 .15362 L
.50972 .14531 L
.52915 .13735 L
.54859 .12973 L
.56803 .12242 L
.58746 .11541 L
.6069 .10867 L
.62634 .10218 L
.64577 .09593 L
.66521 .0899 L
.68465 .08408 L
.70408 .07845 L
.72352 .07301 L
.74295 .06774 L
.76239 .06263 L
.78183 .05768 L
.80126 .05286 L
.8207 .04818 L
.84014 .04363 L
.85957 .03919 L
.87901 .03487 L
.89845 .03065 L
.91788 .02653 L
.93732 .02251 L
.95675 .01857 L
.97619 .01472 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.336849, 89.2495, \
0.00183381, 0.0164014}},
  CellTags->"Polarizing Elements"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[
\t{RainbowOfRays[{.35,.85},NumberOfRays->50,Polarization->{1,1,0}],
\tMove[FresnelRhomb[10,{DesignWaveLength->.5876,FullForm->True}],10],
\tBoundary[75]},
\tPlotType->TopView, ThresholdIntensity->10];
pol = ReadRays[sys,{WaveLength,Polarization[[3]]},IntersectionNumber->6];
ListPlot[pol,PlotJoined->True,AxesOrigin->{.4,180}];\
\>", "Input",
  CellTags->"Polarizing Elements"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0126984 0.5 0.0126984 [
[.45112 .3846 -36 -4.5 ]
[.45112 .3846 36 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.15079 .5773 m
.15079 .4227 L
.15079 .4227 L
.15079 .5773 L
.15079 .5773 L
s
.45112 .7859 m
.15079 .5773 L
.15079 .5773 L
.45112 .7859 L
.45112 .7859 L
s
.45112 .63129 m
.15079 .4227 L
.15079 .4227 L
.45112 .63129 L
.45112 .63129 L
s
.15079 .5773 m
.15079 .4227 L
.45112 .63129 L
.45112 .7859 L
.15079 .5773 L
s
.15079 .5773 m
.15079 .4227 L
.45112 .63129 L
.45112 .7859 L
.15079 .5773 L
s
.75145 .5773 m
.45112 .7859 L
.45112 .7859 L
.75145 .5773 L
.75145 .5773 L
s
.75145 .4227 m
.45112 .63129 L
.45112 .63129 L
.75145 .4227 L
.75145 .4227 L
s
.75145 .4227 m
.75145 .5773 L
.75145 .5773 L
.75145 .4227 L
.75145 .4227 L
s
.45112 .63129 m
.45112 .7859 L
.75145 .5773 L
.75145 .4227 L
.45112 .63129 L
s
.45112 .63129 m
.45112 .7859 L
.75145 .5773 L
.75145 .4227 L
.45112 .63129 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.002 .018 .48 r
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.002 .02 .834 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.002 .022 .9 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.002 .025 .923 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.002 .028 .933 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.001 .032 .937 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.001 .038 .937 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.001 .045 .935 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
0 .055 .928 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
0 .072 .917 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.001 .099 .896 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.002 .152 .851 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.003 .282 .728 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.005 .569 .386 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.007 .775 .166 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.01 .853 .096 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.016 .889 .065 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.025 .907 .049 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.043 .917 .038 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.093 .922 .031 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.41 .923 .026 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.851 .918 .023 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.915 .905 .02 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.936 .869 .017 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.945 .726 .016 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.949 .221 .014 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.951 .077 .013 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.952 .04 .012 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.951 .024 .011 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.948 .015 .01 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.945 .01 .009 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.939 .007 .009 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.931 .005 .008 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.918 .003 .008 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.898 .002 .007 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.86 .001 .007 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.779 0 .006 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.569 0 .006 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.283 .001 .006 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.155 .001 .006 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.102 .001 .005 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.075 .002 .005 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.059 .002 .005 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.048 .002 .005 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.041 .002 .004 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.046 .002 .005 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.056 .002 .005 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.071 .002 .005 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.096 .001 .005 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.141 .001 .005 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.002 .018 .48 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.002 .02 .834 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.002 .022 .9 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.002 .025 .923 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.002 .028 .933 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.001 .032 .937 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.001 .038 .937 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.001 .045 .935 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
0 .055 .928 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
0 .072 .917 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.001 .099 .896 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.002 .152 .851 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.003 .282 .728 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.005 .569 .386 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.007 .775 .166 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.01 .853 .096 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.016 .889 .065 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.025 .907 .049 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.043 .917 .038 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.093 .922 .031 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.41 .923 .026 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.851 .918 .023 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.915 .905 .02 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.936 .869 .017 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.945 .726 .016 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.949 .221 .014 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.951 .077 .013 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.952 .04 .012 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.951 .024 .011 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.948 .015 .01 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.945 .01 .009 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.939 .007 .009 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.931 .005 .008 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.918 .003 .008 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.898 .002 .007 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.86 .001 .007 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.779 0 .006 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.569 0 .006 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.283 .001 .006 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.155 .001 .006 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.102 .001 .005 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.075 .002 .005 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.059 .002 .005 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.048 .002 .005 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.041 .002 .004 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.046 .002 .005 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.056 .002 .005 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.071 .002 .005 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.096 .001 .005 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.141 .001 .005 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.002 .018 .48 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.002 .02 .834 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.002 .022 .9 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.002 .025 .923 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.002 .028 .933 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.001 .032 .937 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.001 .038 .937 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.001 .045 .935 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
0 .055 .928 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
0 .072 .917 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.001 .099 .896 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.002 .152 .851 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.003 .282 .728 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.005 .569 .386 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.007 .775 .166 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.01 .853 .096 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.016 .889 .065 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.025 .907 .049 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.043 .917 .038 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.093 .922 .031 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.41 .923 .026 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.851 .918 .023 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.915 .905 .02 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.936 .869 .017 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.945 .726 .016 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.949 .221 .014 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.951 .077 .013 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.952 .04 .012 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.951 .024 .011 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.948 .015 .01 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.945 .01 .009 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.939 .007 .009 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.931 .005 .008 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.918 .003 .008 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.898 .002 .007 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.86 .001 .007 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.779 0 .006 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.569 0 .006 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.283 .001 .006 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.155 .001 .006 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.102 .001 .005 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.075 .002 .005 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.059 .002 .005 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.048 .002 .005 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.041 .002 .004 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.046 .002 .005 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.056 .002 .005 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.071 .002 .005 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.096 .001 .005 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.141 .001 .005 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.002 .018 .48 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.002 .02 .834 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.002 .022 .9 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.002 .025 .923 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.002 .028 .933 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.001 .032 .937 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.001 .038 .937 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.001 .045 .935 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
0 .055 .928 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
0 .072 .917 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.001 .099 .896 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.002 .152 .851 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.003 .282 .728 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.005 .569 .386 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.007 .775 .166 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.01 .853 .096 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.016 .889 .065 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.025 .907 .049 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.043 .917 .038 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.093 .922 .031 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.41 .923 .026 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.851 .918 .023 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.915 .905 .02 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.936 .869 .017 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.945 .726 .016 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.949 .221 .014 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.951 .077 .013 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.952 .04 .012 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.951 .024 .011 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.948 .015 .01 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.945 .01 .009 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.939 .007 .009 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.931 .005 .008 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.918 .003 .008 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.898 .002 .007 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.86 .001 .007 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.779 0 .006 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.569 0 .006 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.283 .001 .006 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.155 .001 .006 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.102 .001 .005 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.075 .002 .005 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.059 .002 .005 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.048 .002 .005 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.041 .002 .004 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.046 .002 .005 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.056 .002 .005 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.071 .002 .005 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.096 .001 .005 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.141 .001 .005 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.002 .018 .48 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.002 .02 .834 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.002 .022 .9 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.002 .025 .923 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.002 .028 .933 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.001 .032 .937 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.001 .038 .937 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.001 .045 .935 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
0 .055 .928 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
0 .072 .917 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.001 .099 .896 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.002 .152 .851 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.003 .282 .728 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.005 .569 .386 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.007 .775 .166 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.01 .853 .096 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.016 .889 .065 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.025 .907 .049 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.043 .917 .038 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.093 .922 .031 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.41 .923 .026 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.851 .918 .023 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.915 .905 .02 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.936 .869 .017 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.945 .726 .016 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.949 .221 .014 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.951 .077 .013 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.952 .04 .012 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.951 .024 .011 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.948 .015 .01 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.945 .01 .009 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.939 .007 .009 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.931 .005 .008 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.918 .003 .008 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.898 .002 .007 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.86 .001 .007 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.779 0 .006 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.569 0 .006 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.283 .001 .006 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.155 .001 .006 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.102 .001 .005 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.075 .002 .005 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.059 .002 .005 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.048 .002 .005 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.041 .002 .004 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.046 .002 .005 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.056 .002 .005 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.071 .002 .005 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.096 .001 .005 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.141 .001 .005 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.002 .018 .48 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.002 .02 .834 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.002 .022 .9 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.002 .025 .923 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.002 .028 .933 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.001 .032 .937 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.001 .038 .937 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.001 .045 .935 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
0 .055 .928 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
0 .072 .917 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.001 .099 .896 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.002 .152 .851 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.003 .282 .728 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.005 .569 .386 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.007 .775 .166 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.01 .853 .096 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.016 .889 .065 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.025 .907 .049 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.043 .917 .038 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.093 .922 .031 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.41 .923 .026 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.851 .918 .023 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.915 .905 .02 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.936 .869 .017 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.945 .726 .016 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.949 .221 .014 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.951 .077 .013 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.952 .04 .012 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.951 .024 .011 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.948 .015 .01 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.945 .01 .009 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.939 .007 .009 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.931 .005 .008 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.918 .003 .008 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.898 .002 .007 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.86 .001 .007 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.779 0 .006 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.569 0 .006 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.283 .001 .006 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.155 .001 .006 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.102 .001 .005 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.075 .002 .005 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.059 .002 .005 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.048 .002 .005 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.041 .002 .004 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.046 .002 .005 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.056 .002 .005 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.071 .002 .005 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.096 .001 .005 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.141 .001 .005 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.002 .018 .48 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.002 .02 .834 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.002 .022 .9 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.002 .025 .923 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.002 .028 .933 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.001 .032 .937 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.001 .038 .937 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.001 .045 .935 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
0 .055 .928 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
0 .072 .917 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.001 .099 .896 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.002 .152 .851 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.003 .282 .728 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.005 .569 .386 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.007 .775 .166 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.01 .853 .096 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.016 .889 .065 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.025 .907 .049 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.043 .917 .038 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.093 .922 .031 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.41 .923 .026 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.851 .918 .023 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.915 .905 .02 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.936 .869 .017 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.945 .726 .016 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.949 .221 .014 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.951 .077 .013 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.952 .04 .012 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.951 .024 .011 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.948 .015 .01 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.945 .01 .009 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.939 .007 .009 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.931 .005 .008 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.918 .003 .008 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.898 .002 .007 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.86 .001 .007 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.779 0 .006 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.569 0 .006 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.283 .001 .006 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.155 .001 .006 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.102 .001 .005 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.075 .002 .005 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.059 .002 .005 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.048 .002 .005 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.041 .002 .004 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.046 .002 .005 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.056 .002 .005 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.071 .002 .005 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.096 .001 .005 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.141 .001 .005 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(FresnelRhomb)] .45112 .3846 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.87539, -39.3754, 0.274393, \
0.274393}},
  CellTags->"Polarizing Elements"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.642857 1.90476 -19.0072 0.106484 [
[.30952 .1473 -9 -9 ]
[.30952 .1473 9 0 ]
[.5 .1473 -9 -9 ]
[.5 .1473 9 0 ]
[.69048 .1473 -9 -9 ]
[.69048 .1473 9 0 ]
[.88095 .1473 -9 -9 ]
[.88095 .1473 9 0 ]
[.10655 .05332 -18 -4.5 ]
[.10655 .05332 0 4.5 ]
[.10655 .26629 -18 -4.5 ]
[.10655 .26629 0 4.5 ]
[.10655 .37277 -18 -4.5 ]
[.10655 .37277 0 4.5 ]
[.10655 .47925 -18 -4.5 ]
[.10655 .47925 0 4.5 ]
[.10655 .58574 -18 -4.5 ]
[.10655 .58574 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.30952 .1598 m
.30952 .16605 L
s
[(0.5)] .30952 .1473 0 1 Mshowa
.5 .1598 m
.5 .16605 L
s
[(0.6)] .5 .1473 0 1 Mshowa
.69048 .1598 m
.69048 .16605 L
s
[(0.7)] .69048 .1473 0 1 Mshowa
.88095 .1598 m
.88095 .16605 L
s
[(0.8)] .88095 .1473 0 1 Mshowa
.125 Mabswid
.15714 .1598 m
.15714 .16355 L
s
.19524 .1598 m
.19524 .16355 L
s
.23333 .1598 m
.23333 .16355 L
s
.27143 .1598 m
.27143 .16355 L
s
.34762 .1598 m
.34762 .16355 L
s
.38571 .1598 m
.38571 .16355 L
s
.42381 .1598 m
.42381 .16355 L
s
.4619 .1598 m
.4619 .16355 L
s
.5381 .1598 m
.5381 .16355 L
s
.57619 .1598 m
.57619 .16355 L
s
.61429 .1598 m
.61429 .16355 L
s
.65238 .1598 m
.65238 .16355 L
s
.72857 .1598 m
.72857 .16355 L
s
.76667 .1598 m
.76667 .16355 L
s
.80476 .1598 m
.80476 .16355 L
s
.84286 .1598 m
.84286 .16355 L
s
.08095 .1598 m
.08095 .16355 L
s
.04286 .1598 m
.04286 .16355 L
s
.00476 .1598 m
.00476 .16355 L
s
.91905 .1598 m
.91905 .16355 L
s
.95714 .1598 m
.95714 .16355 L
s
.99524 .1598 m
.99524 .16355 L
s
.25 Mabswid
0 .1598 m
1 .1598 L
s
.11905 .05332 m
.1253 .05332 L
s
[(179)] .10655 .05332 1 0 Mshowa
.11905 .26629 m
.1253 .26629 L
s
[(181)] .10655 .26629 1 0 Mshowa
.11905 .37277 m
.1253 .37277 L
s
[(182)] .10655 .37277 1 0 Mshowa
.11905 .47925 m
.1253 .47925 L
s
[(183)] .10655 .47925 1 0 Mshowa
.11905 .58574 m
.1253 .58574 L
s
[(184)] .10655 .58574 1 0 Mshowa
.125 Mabswid
.11905 .07462 m
.1228 .07462 L
s
.11905 .09591 m
.1228 .09591 L
s
.11905 .11721 m
.1228 .11721 L
s
.11905 .13851 m
.1228 .13851 L
s
.11905 .1811 m
.1228 .1811 L
s
.11905 .2024 m
.1228 .2024 L
s
.11905 .22369 m
.1228 .22369 L
s
.11905 .24499 m
.1228 .24499 L
s
.11905 .28758 m
.1228 .28758 L
s
.11905 .30888 m
.1228 .30888 L
s
.11905 .33018 m
.1228 .33018 L
s
.11905 .35147 m
.1228 .35147 L
s
.11905 .39407 m
.1228 .39407 L
s
.11905 .41536 m
.1228 .41536 L
s
.11905 .43666 m
.1228 .43666 L
s
.11905 .45796 m
.1228 .45796 L
s
.11905 .50055 m
.1228 .50055 L
s
.11905 .52185 m
.1228 .52185 L
s
.11905 .54314 m
.1228 .54314 L
s
.11905 .56444 m
.1228 .56444 L
s
.11905 .03202 m
.1228 .03202 L
s
.11905 .01073 m
.1228 .01073 L
s
.11905 .60703 m
.1228 .60703 L
s
.25 Mabswid
.11905 0 m
.11905 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.04325 .56473 L
.06268 .52944 L
.08212 .49705 L
.10155 .46724 L
.12099 .43973 L
.14043 .41427 L
.15986 .39066 L
.1793 .3687 L
.19874 .34824 L
.21817 .32914 L
.23761 .31128 L
.25705 .29453 L
.27648 .27881 L
.29592 .26402 L
.31535 .2501 L
.33479 .23695 L
.35423 .22453 L
.37366 .21278 L
.3931 .20164 L
.41254 .19106 L
.43197 .18101 L
.45141 .17144 L
.47085 .16232 L
.49028 .15362 L
.50972 .14531 L
.52915 .13735 L
.54859 .12973 L
.56803 .12242 L
.58746 .11541 L
.6069 .10867 L
.62634 .10218 L
.64577 .09593 L
.66521 .0899 L
.68465 .08408 L
.70408 .07845 L
.72352 .07301 L
.74295 .06774 L
.76239 .06263 L
.78183 .05768 L
.80126 .05286 L
.8207 .04818 L
.84014 .04363 L
.85957 .03919 L
.87901 .03487 L
.89845 .03065 L
.91788 .02653 L
.93732 .02251 L
.95675 .01857 L
.97619 .01472 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{366.312, 226.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 365.312}, {225.375, 0}} -> {0.337033, 178.498, \
0.00143969, 0.0257528}},
  CellTags->"Polarizing Elements"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Solitaire Diamond Example", "Section",
  CellTags->"Solitaire Diamond Example"],

Cell[CellGroupData[{

Cell["DataToRayica[OpticalMedium->Diamond]", "Input",
  CellTags->"Solitaire Diamond Example"],

Cell[BoxData[
    \("Loading database ..."\)], "Print",
  CellTags->"Solitaire Diamond Example"],

Cell[BoxData[
    \({"Diamond is an optical material from nature with a refractive index of \
2.41748 at the 0.5876 micron wavelength, a corresponding V-number of 55.2781, \
a partial dispersion ratio of 0.295516, and a mean dispersion value of \
0.0256427. The refractive index model for this crystalline material is valid \
from 0.225 to 1000. microns of wavelength."}\)], "Output",
  CellTags->"Solitaire Diamond Example"]
}, Open  ]],

Cell[CellGroupData[{

Cell["?Solitaire", "Input",
  CellTags->"Solitaire Diamond Example"],

Cell[BoxData[
    \("Solitaire[diameter, label, options] creates the 58-faceted round prism \
commonly found in solitaire diamond engagement rings.\n \nYou can use the \
option: ComponentMedium -> Diamond to specify a diamond refractive index \
function. The user-named label parameter is optional and can be omitted. When \
it is present, its text content is used to identify the object in both the \
rendered graphics and the output cell expression. When it is omitted, Optica \
uses the default setting of the Labels option with the rendered graphics.\n \n\
Solitaire uses special options for controlling its overall geometric shape \
that include: TableDiameter, GirdleThickness, CrownAngle, PavilionAngle, \
StarDiameter, BackFacetDiameter, CrownHeight, PavilionDepth, CuletAngle, and \
CuletDiameter."\)], "Print",
  CellTags->{"Info3252053805-1502543", "Solitaire Diamond Example"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Timing[diamond = \
Solitaire[100,ComponentMedium->Diamond]][[1]]\
\>", "Input",
  CellTags->"Solitaire Diamond Example"],

Cell[BoxData[
    \("Loading database ..."\)], "Print",
  CellTags->"Solitaire Diamond Example"],

Cell[BoxData[
    \(55.28333333333285`\ Second\)], "Output",
  CellTags->"Solitaire Diamond Example"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
\t{Move[diamond,-100],
\tMove[diamond,{0,0,0},{0,0,1},0]},
\tPlotType->TopView];\
\>", "Input",
  CellTags->"Solitaire Diamond Example"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .50485 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.702874 0.00452709 0.266477 0.00452709 [
[.25016 .01202 -30 -4.5 ]
[.25016 .01202 30 4.5 ]
[.78505 .01202 -30 -4.5 ]
[.78505 .01202 30 4.5 ]
[ 0 0 0 0 ]
[ 1 .50485 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.41314 .26648 m
.47652 .26648 L
.45929 .3531 L
.41314 .26648 L
s
.36541 .38172 m
.41022 .42653 L
.33679 .4756 L
.36541 .38172 L
s
.25016 .42945 m
.25016 .49283 L
.16354 .4756 L
.25016 .42945 L
s
.13492 .38172 m
.09011 .42653 L
.04104 .3531 L
.13492 .38172 L
s
.08719 .26648 m
.02381 .26648 L
.04104 .17985 L
.08719 .26648 L
s
.13492 .15124 m
.09011 .10642 L
.16354 .05735 L
.13492 .15124 L
s
.25016 .1035 m
.25016 .04012 L
.33679 .05735 L
.25016 .1035 L
s
.36541 .15124 m
.41022 .10642 L
.45929 .17985 L
.36541 .15124 L
s
.361 .22057 m
.361 .31239 L
.41314 .26648 L
.361 .22057 L
s
.361 .31239 m
.29607 .37731 L
.36541 .38172 L
.361 .31239 L
s
.29607 .37731 m
.20425 .37731 L
.25016 .42945 L
.29607 .37731 L
s
.20425 .37731 m
.13933 .31239 L
.13492 .38172 L
.20425 .37731 L
s
.13933 .31239 m
.13933 .22057 L
.08719 .26648 L
.13933 .31239 L
s
.13933 .22057 m
.20425 .15564 L
.13492 .15124 L
.13933 .22057 L
s
.20425 .15564 m
.29607 .15564 L
.25016 .1035 L
.20425 .15564 L
s
.29607 .15564 m
.361 .22057 L
.36541 .15124 L
.29607 .15564 L
s
.41314 .26648 m
.45929 .17985 L
.47652 .26648 L
.41314 .26648 L
s
.36541 .38172 m
.45929 .3531 L
.41022 .42653 L
.36541 .38172 L
s
.25016 .42945 m
.33679 .4756 L
.25016 .49283 L
.25016 .42945 L
s
.13492 .38172 m
.16354 .4756 L
.09011 .42653 L
.13492 .38172 L
s
.08719 .26648 m
.04104 .3531 L
.02381 .26648 L
.08719 .26648 L
s
.13492 .15124 m
.04104 .17985 L
.09011 .10642 L
.13492 .15124 L
s
.25016 .1035 m
.16354 .05735 L
.25016 .04012 L
.25016 .1035 L
s
.36541 .15124 m
.33679 .05735 L
.41022 .10642 L
.36541 .15124 L
s
.31807 .26648 m
.47652 .26648 L
.45929 .3531 L
.31807 .26648 L
s
.29818 .31449 m
.41022 .42653 L
.33679 .4756 L
.29818 .31449 L
s
.25016 .33438 m
.25016 .49283 L
.16354 .4756 L
.25016 .33438 L
s
.20215 .31449 m
.09011 .42653 L
.04104 .3531 L
.20215 .31449 L
s
.18226 .26648 m
.02381 .26648 L
.04104 .17985 L
.18226 .26648 L
s
.20215 .21846 m
.09011 .10642 L
.16354 .05735 L
.20215 .21846 L
s
.25016 .19857 m
.25016 .04012 L
.33679 .05735 L
.25016 .19857 L
s
.29818 .21846 m
.41022 .10642 L
.45929 .17985 L
.29818 .21846 L
s
.31807 .26648 m
.45929 .17985 L
.47652 .26648 L
.31807 .26648 L
s
.29818 .31449 m
.45929 .3531 L
.41022 .42653 L
.29818 .31449 L
s
.25016 .33438 m
.33679 .4756 L
.25016 .49283 L
.25016 .33438 L
s
.20215 .31449 m
.16354 .4756 L
.09011 .42653 L
.20215 .31449 L
s
.18226 .26648 m
.04104 .3531 L
.02381 .26648 L
.18226 .26648 L
s
.20215 .21846 m
.04104 .17985 L
.09011 .10642 L
.20215 .21846 L
s
.25016 .19857 m
.16354 .05735 L
.25016 .04012 L
.25016 .19857 L
s
.29818 .21846 m
.33679 .05735 L
.41022 .10642 L
.29818 .21846 L
s
.361 .31239 m
.36541 .38172 L
.45929 .3531 L
.41303 .26643 L
.361 .31239 L
s
.29607 .37731 m
.25016 .42945 L
.33679 .4756 L
.36536 .3816 L
.29607 .37731 L
s
.20425 .37731 m
.13492 .38172 L
.16354 .4756 L
.25021 .42934 L
.20425 .37731 L
s
.13933 .31239 m
.08719 .26648 L
.04104 .3531 L
.13504 .38167 L
.13933 .31239 L
s
.13933 .22057 m
.13492 .15124 L
.04104 .17985 L
.0873 .26652 L
.13933 .22057 L
s
.20425 .15564 m
.25016 .1035 L
.16354 .05735 L
.13497 .15135 L
.20425 .15564 L
s
.29607 .15564 m
.36541 .15124 L
.33679 .05735 L
.25012 .10361 L
.29607 .15564 L
s
.361 .22057 m
.41314 .26648 L
.45929 .17985 L
.36529 .15128 L
.361 .22057 L
s
.47652 .26648 m
.45929 .3531 L
.45929 .3531 L
.47652 .26648 L
.47652 .26648 L
s
.45929 .3531 m
.41022 .42653 L
.41022 .42653 L
.45929 .3531 L
.45929 .3531 L
s
.41022 .42653 m
.33679 .4756 L
.33679 .4756 L
.41022 .42653 L
.41022 .42653 L
s
.33679 .4756 m
.25016 .49283 L
.25016 .49283 L
.33679 .4756 L
.33679 .4756 L
s
.25016 .49283 m
.16354 .4756 L
.16354 .4756 L
.25016 .49283 L
.25016 .49283 L
s
.16354 .4756 m
.09011 .42653 L
.09011 .42653 L
.16354 .4756 L
.16354 .4756 L
s
.09011 .42653 m
.04104 .3531 L
.04104 .3531 L
.09011 .42653 L
.09011 .42653 L
s
.04104 .3531 m
.02381 .26648 L
.02381 .26648 L
.04104 .3531 L
.04104 .3531 L
s
.02381 .26648 m
.04104 .17985 L
.04104 .17985 L
.02381 .26648 L
.02381 .26648 L
s
.04104 .17985 m
.09011 .10642 L
.09011 .10642 L
.04104 .17985 L
.04104 .17985 L
s
.09011 .10642 m
.16354 .05735 L
.16354 .05735 L
.09011 .10642 L
.09011 .10642 L
s
.16354 .05735 m
.25016 .04012 L
.25016 .04012 L
.16354 .05735 L
.16354 .05735 L
s
.25016 .04012 m
.33679 .05735 L
.33679 .05735 L
.25016 .04012 L
.25016 .04012 L
s
.33679 .05735 m
.41022 .10642 L
.41022 .10642 L
.33679 .05735 L
.33679 .05735 L
s
.41022 .10642 m
.45929 .17985 L
.45929 .17985 L
.41022 .10642 L
.41022 .10642 L
s
.45929 .17985 m
.47652 .26648 L
.47652 .26648 L
.45929 .17985 L
.45929 .17985 L
s
.25337 .26968 m
.29818 .31449 L
.45929 .3531 L
.31815 .26651 L
.2547 .26648 L
.25337 .26968 L
s
.25016 .271 m
.25016 .33438 L
.33679 .4756 L
.29821 .31457 L
.25337 .26968 L
.25016 .271 L
s
.24696 .26968 m
.20215 .31449 L
.16354 .4756 L
.25013 .33446 L
.25016 .27101 L
.24696 .26968 L
s
.24564 .26648 m
.18226 .26648 L
.04104 .3531 L
.20207 .31452 L
.24696 .26968 L
.24564 .26648 L
s
.24696 .26328 m
.20215 .21846 L
.04104 .17985 L
.18218 .26645 L
.24563 .26647 L
.24696 .26328 L
s
.25016 .26195 m
.25016 .19857 L
.16354 .05735 L
.20212 .21838 L
.24696 .26327 L
.25016 .26195 L
s
.25337 .26328 m
.29818 .21846 L
.33679 .05735 L
.2502 .1985 L
.25017 .26194 L
.25337 .26328 L
s
.25469 .26648 m
.31807 .26648 L
.45929 .17985 L
.29826 .21843 L
.25337 .26327 L
.25469 .26648 L
s
.25469 .26648 m
.25337 .26968 L
.25016 .271 L
.24696 .26968 L
.24564 .26648 L
.24696 .26328 L
.25016 .26195 L
.25337 .26328 L
.25469 .26648 L
s
.361 .31239 m
.29607 .37731 L
.20425 .37731 L
.13933 .31239 L
.13933 .22057 L
.20425 .15564 L
.29607 .15564 L
.361 .22057 L
.361 .31239 L
.361 .31239 L
s
.72377 .26648 m
.77599 .26648 L
.77599 .3531 L
.72377 .26648 L
s
.72377 .38172 m
.77599 .42653 L
.77599 .4756 L
.72377 .38172 L
s
.72377 .42945 m
.77599 .49283 L
.77599 .4756 L
.72377 .42945 L
s
.72377 .38172 m
.77599 .42653 L
.77599 .3531 L
.72377 .38172 L
s
.72377 .26648 m
.77599 .26648 L
.77599 .17985 L
.72377 .26648 L
s
.72377 .15124 m
.77599 .10642 L
.77599 .05735 L
.72377 .15124 L
s
.72377 .1035 m
.77599 .04012 L
.77599 .05735 L
.72377 .1035 L
s
.72377 .15124 m
.77599 .10642 L
.77599 .17985 L
.72377 .15124 L
s
.70287 .22057 m
.70287 .31239 L
.72377 .26648 L
.70287 .22057 L
s
.70287 .31239 m
.70287 .37731 L
.72377 .38172 L
.70287 .31239 L
s
.70287 .37731 m
.70287 .37731 L
.72377 .42945 L
.70287 .37731 L
s
.70287 .37731 m
.70287 .31239 L
.72377 .38172 L
.70287 .37731 L
s
.70287 .31239 m
.70287 .22057 L
.72377 .26648 L
.70287 .31239 L
s
.70287 .22057 m
.70287 .15564 L
.72377 .15124 L
.70287 .22057 L
s
.70287 .15564 m
.70287 .15564 L
.72377 .1035 L
.70287 .15564 L
s
.70287 .15564 m
.70287 .22057 L
.72377 .15124 L
.70287 .15564 L
s
.72377 .26648 m
.77599 .17985 L
.77599 .26648 L
.72377 .26648 L
s
.72377 .38172 m
.77599 .3531 L
.77599 .42653 L
.72377 .38172 L
s
.72377 .42945 m
.77599 .4756 L
.77599 .49283 L
.72377 .42945 L
s
.72377 .38172 m
.77599 .4756 L
.77599 .42653 L
.72377 .38172 L
s
.72377 .26648 m
.77599 .3531 L
.77599 .26648 L
.72377 .26648 L
s
.72377 .15124 m
.77599 .17985 L
.77599 .10642 L
.72377 .15124 L
s
.72377 .1035 m
.77599 .05735 L
.77599 .04012 L
.72377 .1035 L
s
.72377 .15124 m
.77599 .05735 L
.77599 .10642 L
.72377 .15124 L
s
.92573 .26648 m
.78505 .26648 L
.78505 .3531 L
.92573 .26648 L
s
.92573 .31449 m
.78505 .42653 L
.78505 .4756 L
.92573 .31449 L
s
.92573 .33438 m
.78505 .49283 L
.78505 .4756 L
.92573 .33438 L
s
.92573 .31449 m
.78505 .42653 L
.78505 .3531 L
.92573 .31449 L
s
.92573 .26648 m
.78505 .26648 L
.78505 .17985 L
.92573 .26648 L
s
.92573 .21846 m
.78505 .10642 L
.78505 .05735 L
.92573 .21846 L
s
.92573 .19857 m
.78505 .04012 L
.78505 .05735 L
.92573 .19857 L
s
.92573 .21846 m
.78505 .10642 L
.78505 .17985 L
.92573 .21846 L
s
.92573 .26648 m
.78505 .17985 L
.78505 .26648 L
.92573 .26648 L
s
.92573 .31449 m
.78505 .3531 L
.78505 .42653 L
.92573 .31449 L
s
.92573 .33438 m
.78505 .4756 L
.78505 .49283 L
.92573 .33438 L
s
.92573 .31449 m
.78505 .4756 L
.78505 .42653 L
.92573 .31449 L
s
.92573 .26648 m
.78505 .3531 L
.78505 .26648 L
.92573 .26648 L
s
.92573 .21846 m
.78505 .17985 L
.78505 .10642 L
.92573 .21846 L
s
.92573 .19857 m
.78505 .05735 L
.78505 .04012 L
.92573 .19857 L
s
.92573 .21846 m
.78505 .05735 L
.78505 .10642 L
.92573 .21846 L
s
.70287 .31239 m
.72377 .38172 L
.77599 .3531 L
.72395 .26643 L
.70287 .31239 L
s
.70287 .37731 m
.72377 .42945 L
.77599 .4756 L
.72395 .3816 L
.70287 .37731 L
s
.70287 .37731 m
.72377 .38172 L
.77599 .4756 L
.72395 .42934 L
.70287 .37731 L
s
.70287 .31239 m
.72377 .26648 L
.77599 .3531 L
.72395 .38167 L
.70287 .31239 L
s
.70287 .22057 m
.72377 .15124 L
.77599 .17985 L
.72395 .26652 L
.70287 .22057 L
s
.70287 .15564 m
.72377 .1035 L
.77599 .05735 L
.72395 .15135 L
.70287 .15564 L
s
.70287 .15564 m
.72377 .15124 L
.77599 .05735 L
.72395 .10361 L
.70287 .15564 L
s
.70287 .22057 m
.72377 .26648 L
.77599 .17985 L
.72395 .15128 L
.70287 .22057 L
s
.77599 .26648 m
.77599 .3531 L
.78505 .3531 L
.78505 .26648 L
.77599 .26648 L
s
.77599 .3531 m
.77599 .42653 L
.78505 .42653 L
.78505 .3531 L
.77599 .3531 L
s
.77599 .42653 m
.77599 .4756 L
.78505 .4756 L
.78505 .42653 L
.77599 .42653 L
s
.77599 .4756 m
.77599 .49283 L
.78505 .49283 L
.78505 .4756 L
.77599 .4756 L
s
.77599 .49283 m
.77599 .4756 L
.78505 .4756 L
.78505 .49283 L
.77599 .49283 L
s
.77599 .4756 m
.77599 .42653 L
.78505 .42653 L
.78505 .4756 L
.77599 .4756 L
s
.77599 .42653 m
.77599 .3531 L
.78505 .3531 L
.78505 .42653 L
.77599 .42653 L
s
.77599 .3531 m
.77599 .26648 L
.78505 .26648 L
.78505 .3531 L
.77599 .3531 L
s
.77599 .26648 m
.77599 .17985 L
.78505 .17985 L
.78505 .26648 L
.77599 .26648 L
s
.77599 .17985 m
.77599 .10642 L
.78505 .10642 L
.78505 .17985 L
.77599 .17985 L
s
.77599 .10642 m
.77599 .05735 L
.78505 .05735 L
.78505 .10642 L
.77599 .10642 L
s
.77599 .05735 m
.77599 .04012 L
.78505 .04012 L
.78505 .05735 L
.77599 .05735 L
s
.77599 .04012 m
.77599 .05735 L
.78505 .05735 L
.78505 .04012 L
.77599 .04012 L
s
.77599 .05735 m
.77599 .10642 L
.78505 .10642 L
.78505 .05735 L
.77599 .05735 L
s
.77599 .10642 m
.77599 .17985 L
.78505 .17985 L
.78505 .10642 L
.77599 .10642 L
s
.77599 .17985 m
.77599 .26648 L
.78505 .26648 L
.78505 .17985 L
.77599 .17985 L
s
.97618 .26968 m
.92573 .31449 L
.78505 .3531 L
.92582 .26651 L
.97619 .26648 L
.97618 .26968 L
s
.97618 .271 m
.92573 .33438 L
.78505 .4756 L
.92582 .31457 L
.97619 .26968 L
.97618 .271 L
s
.97618 .26968 m
.92573 .31449 L
.78505 .4756 L
.92582 .33446 L
.97619 .27101 L
.97618 .26968 L
s
.97618 .26648 m
.92573 .26648 L
.78505 .3531 L
.92582 .31452 L
.97619 .26968 L
.97618 .26648 L
s
.97618 .26328 m
.92573 .21846 L
.78505 .17985 L
.92582 .26645 L
.97619 .26647 L
.97618 .26328 L
s
.97618 .26195 m
.92573 .19857 L
.78505 .05735 L
.92582 .21838 L
.97619 .26327 L
.97618 .26195 L
s
.97618 .26328 m
.92573 .21846 L
.78505 .05735 L
.92582 .1985 L
.97619 .26194 L
.97618 .26328 L
s
.97618 .26648 m
.92573 .26648 L
.78505 .17985 L
.92582 .21843 L
.97619 .26327 L
.97618 .26648 L
s
.97618 .26648 m
.97618 .26968 L
.97618 .271 L
.97618 .26968 L
.97618 .26648 L
.97618 .26328 L
.97618 .26195 L
.97618 .26328 L
.97618 .26648 L
s
.70287 .31239 m
.70287 .37731 L
.70287 .37731 L
.70287 .31239 L
.70287 .22057 L
.70287 .15564 L
.70287 .15564 L
.70287 .22057 L
.70287 .31239 L
.70287 .31239 L
s
0 0 0 r
[(Solitaire1)] .25016 .01202 0 0 Mshowa
[(Solitaire2)] .78505 .01202 0 0 Mshowa
0 0 m
1 0 L
1 .50485 L
0 .50485 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 145.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000TB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00=@3oool010000000oooo0000000000030?ooo`8000000P3oool60000
00030?ooo`000000oooo0080000000<0oooo0000000000000`0000030?ooo`8000000P3oool30000
0740oooo00@000000?ooo`00000000000`3oool200000080oooo1P0000000`3oool000000?ooo`02
000000030?ooo`000000000000<000000`3oool2000000030?ooo`000000000000800000;P3oool0
03D0oooo0P0000020?ooo`030000003oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo000000020?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0700oooo0P0000020?ooo`030000003oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000020?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0;03oool003D0oooo00<000000?ooo`3oool00P0000001@3oool000000?oo
o`3oool000000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`8000000P3oool00`00
0000oooo000000020?ooo`<000000`3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo
0080000000D0oooo0000003oool0oooo000000020?ooo`060000003oool0oooo0000003oool00000
0`3oool200000080oooo00<000000?ooo`0000000P3oool300000080oooo00<000000?ooo`3oool0
;P3oool003H0oooo0`0000020?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool0
00000?ooo`0000020?ooo`030000003oool000000080oooo00P000000?ooo`00000000000?ooo`00
0000oooo000000<0oooo00<000000?ooo`3oool0L@3oool300000080oooo00@000000?ooo`3oool0
00000P3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`0000000P3oool0
20000000oooo000000000000oooo0000003oool000000`3oool00`000000oooo0?ooo`0]0?ooo`00
=@3oool200000080oooo00<000000?ooo`3oool00P0000030?ooo`050000003oool000000000003o
ool00P0000020?ooo`030000003oool0oooo0080000000H0oooo0000003oool000000?ooo`000004
0?ooo`030000003oool0oooo0700oooo0P0000020?ooo`030000003oool0oooo008000000`3oool0
1@000000oooo000000000000oooo008000000P3oool00`000000oooo0?ooo`02000000060?ooo`00
0000oooo0000003oool000001@3oool00`000000oooo0?ooo`0/0?ooo`00=@3oool00`000000oooo
0?ooo`02000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`800000
LP3oool00`000000oooo0?ooo`02000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0>0?ooo`040000003oool0oooo000002h0oooo000f0?ooo`80000000<0oooo0000003oool0
1@3oool200000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0740oooo0P0000000`3oool000000?ooo`050?ooo`8000000P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo0P00000_0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00B03oool00`000000oooo0?ooo`3E0?ooo`00A@3oool700000940oooo
1000000o0?ooo`00?`3oool6000000<0oooo00@000000?ooo`3oool0oooo1P00002;0?ooo`040000
003oool0oooo000003l0oooo000i0?ooo`H000002@3oool00`000000oooo0?ooo`070?ooo`L00000
P`3oool200000080oooo0P00000n0?ooo`00<`3oool6000000l0oooo00<000000?ooo`3oool03P3o
ool6000007`0oooo00<000000?ooo`0000000P3oool00`000000oooo0000000m0?ooo`00;`3oool4
000001D0oooo00<000000?ooo`3oool0503oool4000007L0oooo00<000000?ooo`3oool010000002
0?ooo`030000003oool0oooo03X0oooo000^0?ooo`040000003oool000000?ooo`800000503oool0
0`000000oooo0?ooo`0C0?ooo`80000000@0oooo0000003oool00000M@3oool00`000000oooo0?oo
o`0200000080oooo00D000000?ooo`3oool0oooo0000000k0?ooo`00;03oool2000000040?ooo`00
0000000000000080oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo008000000P3oool2000007<0oooo00<000000?ooo`0000000P0000020?ooo`800000
0`3oool00`000000oooo0?ooo`0h0?ooo`00:`3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000`3oool200000140oooo00<000000?ooo`3oool0403oool200000080oooo0P0000000`3oool0
00000?ooo`020?ooo`030000003oool0oooo06l0oooo00@000000?ooo`000000oooo0P0000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool0=`3oool002T0oooo0P0000040?ooo`04
0000003oool00000000000@0oooo0P00000?0?ooo`030000003oool0oooo00h0oooo0P0000040?oo
o`80000000<0oooo0000003oool00`3oool2000006h0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0f0?ooo`00:03o
ool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool000001@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo0P0000050?ooo`050000003oool000000?oo
o`0000001P3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool000000080oooo00<000000?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0=@3oool0
02H0oooo0P0000060?ooo`060000003oool0oooo0000003oool000001P3oool2000000`0oooo00<0
00000?ooo`3oool02P3oool2000000L0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`040?ooo`800000JP3oool200000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000003L0oooo000U0?ooo`030000003oool0oooo00H0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`8000002P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo06H0oooo0P0000030?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000f0?ooo`008`3oool20000
00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000090?ooo`800000203oool00`00
0000oooo0?ooo`070?ooo`800000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00L0oooo0P00001U0?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`00000e0?ooo`008P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo0P00000:0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1Q0?ooo`800000103oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool200000080oooo00<000000?oo
o`3oool0<P3oool00200oooo0P00000;0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000000:0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`8000002`3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool02@3oool200000600oooo0P000004
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001`3oool200000080oooo00<0
00000?ooo`3oool0<@3oool001l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`000000303oool2000000<0oooo00@000000?ooo`3oool0oooo
0P00000=0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`1M0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000080?ooo`8000000P3oool00`000000oooo0?ooo`0`0?ooo`007@3oool2000000d0
oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000d0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`0000001@3o
ool00`000000oooo0?ooo`0<0?ooo`800000G03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000002@3oool200000080oooo00<000000?ooo`3oool0
;`3oool001`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`0000003P3oool5000000h0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000002P3oool200000080
oooo00<000000?ooo`3oool0;P3oool001/0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`H000002P3oool200000080oooo00<000000?ooo`3oool0;@3oool001/0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`800000F03oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0000
000:0?ooo`80000000<0oooo0000003oool0;P3oool001X0oooo00<000000?ooo`0000003P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool3
000000h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00/0oooo00@000000?ooo`3oool00000EP3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`05
0000003oool000000?ooo`000000;P3oool001T0oooo00D000000?ooo`3oool0oooo0000000<0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?oo
o`050000003oool000000?ooo`000000303oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000T0oooo00D000000?ooo`000000
oooo0000000]0?ooo`006@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`000000103oool010000000oooo0?ooo`0000040?ooo`800000203oool01@000000oooo0000003o
ool0000002`0oooo000H0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool0000000D0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`060?ooo`05
0000003oool000000?ooo`000000:`3oool001L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000H0oooo00@000000?ooo`3oool000001`3oool0
0`000000oooo0?ooo`060?ooo`050000003oool000000?ooo`000000:P3oool001L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000L0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`060?ooo`050000003oool000000?ooo`00
0000:@3oool001H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000P0
oooo00@000000?ooo`3oool000002@3oool2000000L0oooo00D000000?ooo`000000oooo0000000X
0?ooo`005@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000L0oooo00<00000
0?ooo`3oool01@3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000090?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool01@3oool01@000000oooo0000003oool0000002L0oooo000E0?ooo`030000
003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00H0
oooo0P0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001`3oool00`000000
oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo00<0oooo0P00000:0?ooo`040000003oool0oooo000000`0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`02000002L0oooo000D0?ooo`030000003oool0oooo
00h0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00X0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo00<0oooo0P00000;0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`02000002H0oooo000C0?ooo`030000003oool0oooo0100oooo0P00
000>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000203oool00`000000oooo0?oo
o`060?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool02`3oool200000180oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00@0
00000?ooo`3oool000003P3oool2000000D0oooo00<000000?ooo`3oool00P00000U0?ooo`004`3o
ool00`000000oooo0?ooo`0?0?ooo`d00000103oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000H0
oooo00@000000?ooo`3oool0oooo3@00000B0?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`0000001000000<0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`02000002@0oooo000B0?ooo`030000003oool0oooo00d0oooo0`0000020?oo
o`8000002@3oool]000000T0oooo0P0000020?ooo`<000003`3oool00`000000oooo0?ooo`180?oo
o`<000000`3oool010000000oooo00000000000:0?ooo`040000003oool0oooo00000140oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`02000002<0oooo000A0?ooo`030000003oool0
oooo00/0oooo0`0000050?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0000
00050?ooo`<000003@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00<0oooo00D0
00000?ooo`3oool0oooo000000090?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0200000280oooo000A0?ooo`030000003oool0oooo00P0oooo
0`0000080?ooo`040000003oool0oooo000000/0oooo00D000000?ooo`3oool0oooo000000060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`040000003oool0oooo000000/0oooo00@000000?ooo`3oool00000203oool3000000/0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P00
00070?ooo`040000003oool0oooo000001<0oooo0P0000040?ooo`030000003oool0oooo00800000
8@3oool00100oooo00<000000?ooo`3oool01@3oool4000000/0oooo00D000000?ooo`3oool0oooo
0000000;0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000002P3oool01@000000oooo
0?ooo`3oool0000000/0oooo100000070?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`8000001@3oool010000000oooo0?ooo`00000E0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P00000P0?ooo`003`3oool00`000000
oooo0?ooo`030?ooo`<000003`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo0P0000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0=0?ooo`<000001@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01`3oool2000000<0oooo00@000000?ooo`3oool000005P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo0P00000O0?ooo`003`3oool00`000000oooo0?ooo`030000
01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00T0oooo0P0000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool30000
0080oooo00<000000?ooo`3oool0A@3oool01@000000oooo0?ooo`3oool0000000`0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`0M0?ooo`003P3oool4000001H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`050?ooo`800000303oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo000000060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool04`3oool4000004H0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`<0
00000P3oool00`000000oooo0?ooo`0F0?ooo`8000000P3oool01@000000oooo0?ooo`3oool00000
01h0oooo000=0?ooo`<00000603oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000002`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool02P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool05@3oool4000004@0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`H00000
603oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01/0oooo000=0?ooo`030000
003oool0000000@00000503oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool02`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0A0?ooo`D0000000<0oooo0000003oool0A03oool010000000oooo0?ooo`00
000@0?ooo`050000003oool0oooo0000003oool01000000F0?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool06P3oool000d0oooo0P0000000`3oool00000000000020?ooo`@00000
403oool00`000000oooo0?ooo`060?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0
2P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00`3oool2000000T0oooo00<000000?ooo`3oool03@3oool400000080oooo0P0000000`3oool0
0000000000150?ooo`040000003oool0oooo000000l0oooo0P0000020?ooo`030000003oool0oooo
0080000000<0oooo0000000000000P00000C0?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool06@3oool000`0oooo00<000000?ooo`0000000`3oool2000000@0oooo1000000<0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?oo
o`050000003oool000000?ooo`0000003@3oool00`000000oooo0?ooo`030?ooo`800000203oool0
0`000000oooo0?ooo`0:0?ooo`@00000103oool2000000<0oooo00<000000?ooo`000000A03oool0
10000000oooo0?ooo`00000?0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`8000000`3o
ool400000100oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo01P0oooo000<
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool4000000P0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo000000040?ooo`030000003oool0oooo00`0oooo0P00
00000`3oool000000?ooo`0<0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
1`3oool00`000000oooo0?ooo`060?ooo`@000001`3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000004@0oooo00@000000?ooo`3oool000003P3oool00`000000oooo000000020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool3000000l0oooo0P0000040?oo
o`030000003oool0oooo01L0oooo000<0?ooo`040000003oool0oooo000000D0oooo0P0000090?oo
o`D000000`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`0;0?ooo`<000003P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`3oool5000000T0oooo0P0000050?ooo`040000
003oool0oooo000004@0oooo00<000000?ooo`0000003P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00D0oooo0P0000070?ooo`@00000303oool2000000@0oooo00<000000?oo
o`3oool05P3oool000`0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo
00/0oooo100000060?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000>
0?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0oooo00<0oooo1000000=0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo
000000140?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo100000090?ooo`800000103oool00`000000
oooo0?ooo`0E0?ooo`00303oool01@000000oooo0?ooo`3oool0000000L0oooo0P00000>0?ooo`D0
000000<0oooo0000003oool01P3oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo
00`0oooo00@000000?ooo`3oool00000203oool6000000h0oooo0P0000070?ooo`050000003oool0
oooo0?ooo`000000A03oool00`000000oooo0000000=0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`080?ooo`800000303oool3000000L0oooo0P0000030?ooo`030000
003oool0oooo01D0oooo000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool2000000d0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0000000h0oooo
00<000000?ooo`3oool0303oool00`000000oooo000000060?ooo`D000000`3oool00`000000oooo
0?ooo`0:0?ooo`800000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0440oooo
0P00000>0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`80
00003@3oool4000000D0oooo00D000000?ooo`3oool0oooo0000000F0?ooo`002`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool010000000
oooo0?ooo`0000040?ooo`@000000`3oool2000000h0oooo00<000000?ooo`3oool0303oool20000
00<0oooo100000050?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0440oooo0P00000=0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0>0?ooo`@000000P3o
ool01@000000oooo0?ooo`3oool0000001D0oooo000;0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0203oool2000000X0oooo00<000000?ooo`0000002@3oool6000000d0oooo00<0
00000?ooo`3oool02`3oool6000000X0oooo00<000000?ooo`0000002@3oool2000000X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`110?ooo`8000003@3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000l0oooo0P00000B0?ooo`@000000`3oool00`000000oooo
0?ooo`0B0?ooo`002`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01`3oool2000000h0oooo0P00000=0?ooo`030000003oool0oooo00/0oooo0P00
000?0?ooo`800000203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000004@3oool00`000000oooo0?ooo`0B0?ooo`<000000P3oool00`000000oooo
0?ooo`0A0?ooo`002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo0P00
00060?ooo`8000004@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0403oool2000000D0oooo0P00000<0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000004P3oool2000001D0oooo00<000000?ooo`0000004`3oool000X0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`8000000`3oool00`000000oooo0000
000B0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool000000080oooo0P00000=0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00@0
00000?ooo`3oool00000503oool2000001@0oooo00<000000?ooo`0000004P3oool000X0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`02000000l0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`100?ooo`8000002P3oool00`000000oooo0?ooo`050?ooo`040000003o
ool0oooo000001H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000000A0?ooo`002P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo0P0000020?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`0000000P00000>0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0@03oool2000000X0oooo00<000000?ooo`3oool01@3oool010000000oooo0?oo
o`00000G0?ooo`8000004`3oool00`000000oooo0000000@0?ooo`002P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00`0oooo00H000000?ooo`3oool000000?ooo`00000E0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0D0?ooo`80
00000`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo000000080?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3o
ool000006@3oool00`000000oooo0?ooo`0A0?ooo`800000403oool000X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo0P00000F0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`80
00001@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo000000080?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3o
ool000006P3oool200000180oooo0P00000?0?ooo`002@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00P0oooo0P0000060?ooo`<000005@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool2000000030?ooo`000000oooo00D0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03l0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo
000001`0oooo0P00000A0?ooo`8000003P3oool000T0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000005@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo03l0oooo00@000000?ooo`3oool000001P3oool00`000000oooo
0?ooo`070?ooo`040000003oool0oooo000001h0oooo00<000000?ooo`3oool03`3oool2000000d0
oooo00090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`070?ooo`040000003oool0oooo0?ooo`800000503oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool2000000@0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0?`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00P0oooo00@000000?oo
o`3oool000007`3oool200000100oooo0P00000<0?ooo`002@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0o0?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo00000240oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`002@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`040?ooo`8000004`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0140oooo
0P0000070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo03l0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo00T0oooo00@000000?ooo`3oool000008P3oool2000000l0oooo00<000000?oo
o`3oool02@3oool000P0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000<0?oo
o`030000003oool0oooo00H0oooo0P00000B0?ooo`050000003oool000000?ooo`0000004P3oool2
000000T0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00000@0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000<0?ooo`040000003o
ool0oooo000002@0oooo0P00000>0?ooo`030000003oool0oooo00P0oooo00080?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0100oooo0`00000B0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0000000@0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0000000<0?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`070?ooo`00203ooom0000000030?ooo`000000000003l00000?`3o
ool00`000000oooo0?ooo`030?ooodP000002@3oool000P0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0000000<0?ooo`030000003oool0oooo00H0oooo0P00000B0?ooo`D000004P3oool2
000000T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000A0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0
oooo000002@0oooo0P00000>0?ooo`8000002@3oool000P0oooo00<000000?ooo`3oool03P3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0A0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000<0?ooo`04
0000003oool0oooo000002<0oooo00<000000?ooo`3oool03@3oool00`000000oooo000000090?oo
o`002@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`030?ooo`8000004`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool04@3oool2000000H0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000`0oooo00@000000?ooo`3oool000008@3oool2
000000l0oooo00<000000?ooo`0000002P3oool000T0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0oooo0P00000D
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B
0?ooo`800000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0o0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000001l0oooo0P00000@0?ooo`030000
003oool0000000/0oooo00090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0
oooo000000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0o0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`080?oo
o`040000003oool0oooo000001h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0000000<
0?ooo`002@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo0P0000060?oo
o`<000005@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool04`3oool2000000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo03l0oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`080?ooo`040000003oool0oooo000001`0oooo0P00000A0?ooo`030000003o
ool0000000d0oooo00090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`8000005P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0503oool2000000D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03l0oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000001X0oooo0P00000A0?ooo`800000
0P3oool00`000000oooo0?ooo`0;0?ooo`002P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00/0oooo00H000000?ooo`3oool000000?ooo`00000E0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0D0?ooo`8000000`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@03oool010000000
oooo0?ooo`0000060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000006@3oool0
0`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000003P3oool000X0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`8000000P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool00000008000003P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0400oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`060?ooo`040000003oool0
oooo000001L0oooo0P00000B0?ooo`050000003oool0oooo0?ooo`0000003`3oool000X0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`80000000D0oooo0000003oool0oooo
0000000C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00<000003@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0400oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`040000
003oool0oooo000001D0oooo0P00000C0?ooo`050000003oool0oooo0?ooo`000000403oool000X0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool04@3oool00`000000oooo000000030?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`100?ooo`8000002P3oool00`000000
oooo0?ooo`050?ooo`040000003oool0oooo000001@0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo000:0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool02@3oool2000000H0oooo0P00000A0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`8000001@3oool2000000/0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`100?ooo`8000002`3oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo00000180oooo0P00000D0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03`3oool000/0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`080?ooo`8000002@3oool00`000000oooo0?ooo`0<0?ooo`<000003@3oool00`000000
oooo0?ooo`0;0?ooo`<000003P3oool2000000P0oooo0P00000:0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`3oool00000403oool2000001<0oooo0`0000040?ooo`030000003oool0oooo
0100oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`090?ooo`8000002@3oool400000080oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`80000000<0oooo0000000000000P0000090?ooo`030000003oool0000000X0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00l0oooo00<000000?ooo`3oool0403oool4000000030?ooo`000000oooo0080oooo00<000000?oo
o`3oool04@3oool000/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`80
0000303oool00`000000oooo000000040?ooo`@000001@3oool2000000d0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo000000040?ooo`@00000103oool010000000oooo0?ooo`00000;0?oo
o`800000203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000d0oooo0P00000?
0?ooo`@000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo0180oooo000;0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool2000000h0oooo00<000000?oo
o`3oool0100000080?ooo`8000003P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool00000
00L0oooo100000030?ooo`030000003oool0oooo00/0oooo0P0000060?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0@@3oool2000000d0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`00000;0?ooo`8000003@3oool4000000D0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`0B0?ooo`002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool03@3oool4000000030?ooo`000000oooo00P0oooo00<000000?oo
o`0000003P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`0000000`00000?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`110?ooo`8000003P3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`<000001`3oool2000000030?ooo`00
0000oooo00<0oooo00<000000?ooo`3oool04`3oool000`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`8000002`3oool5000000030?ooo`000000oooo00<0oooo00<00000
0?ooo`3oool01@3oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo00`0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00<0oooo1P00000;0?ooo`800000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0480oooo0P00000>0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`8000002@3oool4000000T0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0D0?ooo`00303oool01@000000
oooo0?ooo`3oool0000000<0oooo0P0000090?ooo`@000001@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool4000000T0oooo0P0000030?ooo`050000003oool0
oooo0?ooo`000000A03oool00`000000oooo0000000>0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0103oool2000000L0oooo1000000<0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool05@3oool000`0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`050?ooo`@000002@3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo00L0oooo10000007
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0000000h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo0`00000?0?ooo`040000003oool0oooo000000@0oooo0P00000G0?ooo`00
303oool01@000000oooo0?ooo`000000oooo00800000103oool4000000d0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo000000040?ooo`030000003oool0oooo00`0oooo0`00000>0?ooo`03
0000003oool0oooo00<0oooo0P0000080?ooo`030000003oool0oooo00/0oooo100000040?ooo`80
000000D0oooo0000003oool0oooo000000140?ooo`030000003oool0000000l0oooo00<000000?oo
o`0000000P3oool010000000oooo0?ooo`3oool2000000<0oooo1000000@0?ooo`8000000P3oool0
0`000000oooo0?ooo`020?ooo`800000603oool000`0oooo00<000000?ooo`0000000P0000020?oo
o`@000004@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool02`3oool01@000000oooo0000003oool0000000d0oooo00<000000?ooo`3oool00`3oool2
000000P0oooo00<000000?ooo`3oool03`3oool400000080oooo0`0000000`3oool000000?ooo`13
0?ooo`040000003oool0oooo000000l0oooo0P0000020?ooo`050000003oool000000000003oool0
1000000C0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P00000I0?ooo`00
3@3oool6000001D0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000040?ooo`030000
003oool0oooo00/0oooo00D000000?ooo`000000oooo0000000=0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`0C0?ooo`H00000A@3oool01000
0000oooo0?ooo`00000?0?ooo`8000000P3oool5000001H0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`3oool2000001X0oooo000=0?ooo`8000006@3oool00`000000oooo0?ooo`05
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool05P3oool3000004@0oooo00@000000?ooo`3o
ool000003`3oool6000001P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2
000001/0oooo000=0?ooo`030000003oool00000008000005P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000003@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01<0oooo0`0000000`3oool000000?ooo`140?ooo`040000003oool0
oooo000000h0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`800000103o
ool010000000oooo0?ooo`3oool2000001`0oooo000>0?ooo`040000003oool0oooo0?ooo`<00000
4`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P00000<0?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`800000203oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0100oooo0`0000030?ooo`030000003oool0oooo04@0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`8000000P3oool010000000oooo0?ooo`00000F
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P00000M0?ooo`003`3oool0
0`000000oooo0?ooo`030?ooo`<00000403oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03@3oool3000000D0oooo00<000000?ooo`3oool0A@3oool0
1@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00000E0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P00000N0?ooo`00
3`3oool00`000000oooo0?ooo`060?ooo`<000003@3oool01@000000oooo0?ooo`3oool0000000X0
oooo0P00000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`080?ooo`8000002`3oool01@000000oooo0?ooo`3oool0000000`0oooo0`0000080?oo
o`030000003oool0oooo04D0oooo00D000000?ooo`3oool0oooo000000080?ooo`8000001@3oool0
10000000oooo0?ooo`00000D0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo
0P00000O0?ooo`00403oool00`000000oooo0?ooo`080?ooo`<000002@3oool01@000000oooo0?oo
o`3oool0000000/0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00000;0?ooo`04
0000003oool0oooo000000T0oooo0`00000:0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001`3oool010000000oooo0?ooo`00000B
0?ooo`8000001P3oool01P000000oooo0?ooo`000000oooo000001l0oooo000A0?ooo`030000003o
ool0oooo00X0oooo0`0000060?ooo`040000003oool0oooo000000/0oooo00D000000?ooo`3oool0
oooo000000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo000000060?oo
o`<000003@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo00000140oooo00<00000
0?ooo`3oool01@3oool01P000000oooo0?ooo`000000oooo00000200oooo000A0?ooo`030000003o
ool0oooo00d0oooo0`0000030?ooo`030000003oool0000000`0oooo9@00000=0?ooo`8000000`3o
ool3000000l0oooo00<000000?ooo`3oool0A`3oool300000080oooo00<000000?ooo`3oool00P00
000:0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool01@3oool01P000000oooo
0?ooo`000000oooo00000240oooo000B0?ooo`030000003oool0oooo00l0oooo1@0000030?ooo`/0
0000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo2`0000040?ooo`@0
00004@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00D00000303oool010000000
oooo0?ooo`00000?0?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`00
000R0?ooo`004`3oool00`000000oooo0?ooo`0A0?ooo`D000002P3oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`070?ooo`H000004`3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo0080oooo0P00000<0?ooo`040000003oool0oooo000000d0
oooo0P0000070?ooo`060000003oool0oooo0000003oool000008`3oool001<0oooo00<000000?oo
o`3oool0403oool2000000h0oooo00<000000?ooo`3oool0103oool00`000000oooo000000080?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool000000140oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000/0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`06
0?ooo`060000003oool0oooo0000003oool00000903oool001@0oooo00<000000?ooo`3oool03P3o
ool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo00H0oooo0P0000080?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`040000
003oool0oooo000000l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000000X0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`060?oo
o`060000003oool0oooo0000003oool000009@3oool001D0oooo00<000000?ooo`3oool0303oool0
1@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01P3oool2000000P0oooo00<0
00000?ooo`3oool01P3oool2000000P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000T0oooo00@000000?ooo`3oool000002P3oool00`000000
oooo0?ooo`060?ooo`060000003oool0oooo0000003oool000009P3oool001D0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool01@3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo00D0oooo00@00000
0?ooo`3oool00000203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000080?ooo`8000002@3oool01@000000
oooo0000003oool0000002L0oooo000F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?oo
o`080?ooo`030000003oool000000080oooo00<000000?ooo`3oool09@3oool001L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`8000001@3o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`0V0?ooo`005`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo000000020?ooo`030000
003oool0oooo02L0oooo000H0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`3oool2000000X0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0X0?ooo`00
6@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0Y0?ooo`006@3oool01@000000oooo0?ooo`3oool0000000`0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`000000
E@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000
0P3oool00`000000oooo0000000;0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
:P3oool001X0oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02P3oool01@000000oooo0000003oool0000000`0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`000000EP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
0P0000020?ooo`8000002`3oool00`000000oooo000000020?ooo`030000003oool0oooo02/0oooo
000K0?ooo`8000003P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02`3oool3000000h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00d0oooo0P00001G0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool4000000`0oooo0P0000020?ooo`030000003oool0oooo02`0oooo000M
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00`0oooo0`00000?0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05P0oooo0P000005
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000002`3oool200000080oooo00<0
00000?ooo`3oool0;@3oool001h0oooo0P00000<0?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo0000000=0?ooo`80000000<0oooo0000003oool00P00000=0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`800000F`3o
ool00`000000oooo000000040?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000
2P3oool2000000<0oooo00<000000?ooo`3oool0;@3oool00200oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool2000000<0oooo00@000000?ooo`3oool0oooo0P00000<0?ooo`050000003oool0oooo0?ooo`00
00001P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05`0oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000T0oooo0P0000030?oo
o`030000003oool0oooo02h0oooo000Q0?ooo`8000002@3oool00`000000oooo0?ooo`030?ooo`05
0000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo0P00000:0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`08
0?ooo`800000H03oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool00000203oool2000000<0oooo00<000000?ooo`3oool0;`3oool002<0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002@3o
ool2000000H0oooo00<000000?ooo`3oool01@3oool2000000T0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001`3oool2000000<0
oooo00<000000?ooo`3oool0<03oool002@0oooo0P0000070?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000203oool2000000P0oooo00<000000?ooo`3oool01`3oool2000000P0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`800000I@3oool00`00
0000oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001P3oool2
000000<0oooo00<000000?ooo`3oool0<@3oool002H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000L0oooo0P00000:0?ooo`030000003oool0oooo
00T0oooo0P0000060?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1U0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000d0?ooo`00
9`3oool2000000D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`80
0000303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`030?ooo`800000J@3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool0000003D0oooo000Y0?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?oo
o`0000040?ooo`8000003P3oool00`000000oooo0?ooo`0<0?ooo`8000001@3oool00`000000oooo
000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0JP3oool01P000000oooo
0?ooo`000000oooo00000080oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3o
ool0000003H0oooo000Z0?ooo`8000000P3oool01P000000oooo0?ooo`000000oooo00000080oooo
0P00000@0?ooo`030000003oool0oooo00h0oooo0P0000030?ooo`050000003oool000000?ooo`00
00000`3oool2000006h0oooo00P000000?ooo`3oool000000?ooo`000000oooo00000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo03D0oooo000/0?ooo`050000003o
ool0oooo0000003oool00P0000020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
403oool200000080oooo0P0000001@3oool000000?ooo`3oool000000700oooo00@000000?ooo`3o
ool0oooo0P0000001@3oool000000?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0e0?ooo`00;@3oool3000000030?ooo`000000oooo008000004`3oool00`00
0000oooo0?ooo`0B0?ooo`@0000000@0oooo0000000000000000LP3oool010000000oooo0?ooo`3o
ool300000080oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0f0?ooo`00;`3oool4
000001D0oooo00<000000?ooo`3oool0503oool4000007D0oooo00@000000?ooo`3oool0oooo0P00
00020?ooo`800000103oool00`000000oooo0?ooo`0g0?ooo`00<03oool3000001D0oooo00<00000
0?ooo`3oool0503oool3000007L0oooo00@000000?ooo`3oool0oooo100000040?ooo`030000003o
ool0oooo03P0oooo000c0?ooo`D00000403oool00`000000oooo0?ooo`0?0?ooo`D00000N`3oool0
10000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000>`3oool003P0oooo1@00
000;0?ooo`030000003oool0oooo00X0oooo1@0000200?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000?03oool003d0oooo1@0000060?ooo`030000003oool0oooo00D0oooo
1@0000260?ooo`030000003oool000000080oooo00<000000?ooo`000000?@3oool00480oooo1@00
0000103oool000000?ooo`3oool5000008`0oooo0P0000020?ooo`800000?P3oool004L0oooo1000
002B0?ooo`@00000?`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {144.375, 0}} -> {-156.498, -59.7105, \
0.778291, 0.778291}},
  CellTags->"Solitaire Diamond Example"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Timing[sol = TurboPlot[
\t{Move[WedgeOfRays[10,NumberOfRays->51,Polarization->{1,0,0}],{-500,10},-1],
\tMove[diamond,{0,0,0},{0,0,1},0],
\tBoundary[{-70,-70,-70},{17,70,70}],
\tBoundary[{17,-70,-70},{70,70,70}]},
\tScoutRays->False,
\tReportedSurfaces->All,
\tColorView->Log[Intensity],
\tFresnelReflections->True,
\tThresholdIntensity->.1,
\tPlotType->TopView,
\tPlotRange->Automatic]][[1]]\
\>", "Input",
  CellTags->"Solitaire Diamond Example"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.10713 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.448985 0.00753151 0.553566 0.00753151 [
[ 0 0 0 0 ]
[ 1 1.10713 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.10713 L
0 1.10713 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.48373 .55354 m
.57064 .55354 L
.57064 .69772 L
.48373 .55354 L
s
.48373 .74525 m
.57064 .81984 L
.57064 .90152 L
.48373 .74525 L
s
.48373 .82467 m
.57064 .93016 L
.57064 .90148 L
.48373 .82467 L
s
.48373 .74528 m
.57064 .81988 L
.57064 .69765 L
.48373 .74528 L
s
.48373 .55359 m
.57064 .55359 L
.57064 .40941 L
.48373 .55359 L
s
.48373 .36188 m
.57064 .28729 L
.57064 .20562 L
.48373 .36188 L
s
.48373 .28246 m
.57064 .17697 L
.57064 .20565 L
.48373 .28246 L
s
.48373 .36185 m
.57064 .28725 L
.57064 .40949 L
.48373 .36185 L
s
.44898 .47715 m
.44898 .62998 L
.48377 .55357 L
.44898 .47715 L
s
.44898 .62991 m
.44898 .73798 L
.48377 .74531 L
.44898 .62991 L
s
.44898 .73794 m
.44898 .73794 L
.48377 .82473 L
.44898 .73794 L
s
.44898 .73798 m
.44898 .62991 L
.48377 .74531 L
.44898 .73798 L
s
.44898 .62998 m
.44898 .47715 L
.48377 .55357 L
.44898 .62998 L
s
.44898 .47723 m
.44898 .36916 L
.48377 .36182 L
.44898 .47723 L
s
.44898 .36919 m
.44898 .36919 L
.48377 .2824 L
.44898 .36919 L
s
.44898 .36916 m
.44898 .47723 L
.48377 .36182 L
.44898 .36916 L
s
.48373 .55359 m
.57064 .40941 L
.57064 .55359 L
.48373 .55359 L
s
.48373 .74528 m
.57064 .69765 L
.57064 .81988 L
.48373 .74528 L
s
.48373 .82467 m
.57064 .90148 L
.57064 .93016 L
.48373 .82467 L
s
.48373 .74525 m
.57064 .90152 L
.57064 .81984 L
.48373 .74525 L
s
.48373 .55354 m
.57064 .69772 L
.57064 .55354 L
.48373 .55354 L
s
.48373 .36185 m
.57064 .40949 L
.57064 .28725 L
.48373 .36185 L
s
.48373 .28246 m
.57064 .20565 L
.57064 .17697 L
.48373 .28246 L
s
.48373 .36188 m
.57064 .20562 L
.57064 .28729 L
.48373 .36188 L
s
.8163 .55354 m
.58189 .55354 L
.58189 .69772 L
.8163 .55354 L
s
.8163 .63337 m
.58189 .81986 L
.58189 .90153 L
.8163 .63337 L
s
.8163 .66646 m
.58189 .93019 L
.58189 .90151 L
.8163 .66646 L
s
.8163 .63341 m
.58189 .8199 L
.58189 .69767 L
.8163 .63341 L
s
.8163 .55359 m
.58189 .55359 L
.58189 .40941 L
.8163 .55359 L
s
.8163 .47376 m
.58189 .28727 L
.58189 .2056 L
.8163 .47376 L
s
.8163 .44068 m
.58189 .17694 L
.58189 .20562 L
.8163 .44068 L
s
.8163 .47372 m
.58189 .28724 L
.58189 .40947 L
.8163 .47372 L
s
.8163 .55359 m
.58189 .40941 L
.58189 .55359 L
.8163 .55359 L
s
.8163 .63341 m
.58189 .69767 L
.58189 .8199 L
.8163 .63341 L
s
.8163 .66646 m
.58189 .90151 L
.58189 .93019 L
.8163 .66646 L
s
.8163 .63337 m
.58189 .90153 L
.58189 .81986 L
.8163 .63337 L
s
.8163 .55354 m
.58189 .69772 L
.58189 .55354 L
.8163 .55354 L
s
.8163 .47372 m
.58189 .40947 L
.58189 .28724 L
.8163 .47372 L
s
.8163 .44068 m
.58189 .20562 L
.58189 .17694 L
.8163 .44068 L
s
.8163 .47376 m
.58189 .2056 L
.58189 .28727 L
.8163 .47376 L
s
.44896 .62993 m
.48375 .74533 L
.57066 .6977 L
.48405 .55344 L
.44896 .62993 L
s
.44896 .73793 m
.48375 .82471 L
.57066 .90153 L
.48405 .74507 L
.44896 .73793 L
s
.44896 .73793 m
.48375 .74526 L
.57066 .90153 L
.48405 .82452 L
.44896 .73793 L
s
.44896 .62993 m
.48375 .55351 L
.57066 .6977 L
.48405 .74525 L
.44896 .62993 L
s
.44896 .4772 m
.48375 .3618 L
.57066 .40944 L
.48405 .5537 L
.44896 .4772 L
s
.44896 .36921 m
.48375 .28242 L
.57066 .20561 L
.48405 .36206 L
.44896 .36921 L
s
.44896 .36921 m
.48375 .36187 L
.57066 .20561 L
.48405 .28261 L
.44896 .36921 L
s
.44896 .4772 m
.48375 .55362 L
.57066 .40944 L
.48405 .36188 L
.44896 .4772 L
s
.57062 .55353 m
.57062 .69771 L
.58193 .69771 L
.58193 .55353 L
.57062 .55353 L
s
.57062 .69764 m
.57062 .81988 L
.58193 .81988 L
.58193 .69764 L
.57062 .69764 L
s
.57062 .81982 m
.57062 .9015 L
.58193 .9015 L
.58193 .81982 L
.57062 .81982 L
s
.57062 .90147 m
.57062 .93015 L
.58193 .93015 L
.58193 .90147 L
.57062 .90147 L
s
.57062 .93015 m
.57062 .90147 L
.58193 .90147 L
.58193 .93015 L
.57062 .93015 L
s
.57062 .9015 m
.57062 .81982 L
.58193 .81982 L
.58193 .9015 L
.57062 .9015 L
s
.57062 .81988 m
.57062 .69764 L
.58193 .69764 L
.58193 .81988 L
.57062 .81988 L
s
.57062 .69771 m
.57062 .55353 L
.58193 .55353 L
.58193 .69771 L
.57062 .69771 L
s
.57062 .5536 m
.57062 .40942 L
.58193 .40942 L
.58193 .5536 L
.57062 .5536 L
s
.57062 .40949 m
.57062 .28726 L
.58193 .28726 L
.58193 .40949 L
.57062 .40949 L
s
.57062 .28731 m
.57062 .20564 L
.58193 .20564 L
.58193 .28731 L
.57062 .28731 L
s
.57062 .20566 m
.57062 .17698 L
.58193 .17698 L
.58193 .20566 L
.57062 .20566 L
s
.57062 .17698 m
.57062 .20566 L
.58193 .20566 L
.58193 .17698 L
.57062 .17698 L
s
.57062 .20564 m
.57062 .28731 L
.58193 .28731 L
.58193 .20564 L
.57062 .20564 L
s
.57062 .28726 m
.57062 .40949 L
.58193 .40949 L
.58193 .28726 L
.57062 .28726 L
s
.57062 .40942 m
.57062 .5536 L
.58193 .5536 L
.58193 .40942 L
.57062 .40942 L
s
.90321 .55621 m
.81623 .63347 L
.58181 .69772 L
.81631 .55357 L
.90321 .55354 L
.90321 .55621 L
s
.90321 .55728 m
.81623 .66654 L
.58181 .9016 L
.81631 .6335 L
.90321 .55618 L
.90321 .55728 L
s
.90321 .55618 m
.81623 .63344 L
.58181 .9016 L
.81631 .6666 L
.90321 .55728 L
.90321 .55618 L
s
.90321 .55354 m
.81623 .55354 L
.58181 .69772 L
.81631 .63349 L
.90321 .55621 L
.90321 .55354 L
s
.90321 .55092 m
.81623 .47367 L
.58181 .40941 L
.81631 .55356 L
.90321 .55359 L
.90321 .55092 L
s
.90321 .54985 m
.81623 .44059 L
.58181 .20554 L
.81631 .47363 L
.90321 .55095 L
.90321 .54985 L
s
.90321 .55096 m
.81623 .4737 L
.58181 .20554 L
.81631 .44053 L
.90321 .54985 L
.90321 .55096 L
s
.90321 .55359 m
.81623 .55359 L
.58181 .40941 L
.81631 .47364 L
.90321 .55092 L
.90321 .55359 L
s
.90316 .55357 m
.90316 .55623 L
.90316 .55733 L
.90316 .55623 L
.90316 .55357 L
.90316 .5509 L
.90316 .5498 L
.90316 .5509 L
.90316 .55357 L
s
.44898 .62998 m
.44898 .73805 L
.44898 .73805 L
.44898 .62998 L
.44898 .47715 L
.44898 .36908 L
.44898 .36908 L
.44898 .47715 L
.44898 .62998 L
.44898 .62998 L
s
.57702 1.08077 m
.57702 .02636 L
.57702 .02636 L
.57702 1.08077 L
.57702 1.08077 L
s
.57702 .02636 m
0 0 rlineto s
.57702 .02636 m
0 .02636 L
s
0 .02636 m
.57702 .02636 L
.57702 .02636 L
s
0 1.08077 m
.57702 1.08077 L
.57702 1.08077 L
s
.57702 1.08077 m
0 1.08077 L
s
.57702 .02636 m
.57702 1.08077 L
s
.57702 1.08077 m
0 1.08077 L
s
0 .02636 m
.57702 .02636 L
s
.57702 1.08077 m
.57702 .02636 L
s
.57702 .02636 m
0 .02636 L
s
0 1.08077 m
.57702 1.08077 L
s
.97619 1.08077 m
.97619 .02636 L
.97619 .02636 L
.97619 1.08077 L
.97619 1.08077 L
s
.97619 .02636 m
.57702 .02636 L
.57702 .02636 L
.97619 .02636 L
.97619 .02636 L
s
.57702 .02636 m
.57702 1.08077 L
.57702 1.08077 L
.57702 .02636 L
.57702 .02636 L
s
.57702 1.08077 m
.97619 1.08077 L
.97619 1.08077 L
.57702 1.08077 L
.57702 1.08077 L
s
.97619 .02636 m
.97619 1.08077 L
.57702 1.08077 L
.57702 .02636 L
.97619 .02636 L
s
.97619 1.08077 m
.97619 .02636 L
.57702 .02636 L
.57702 1.08077 L
.97619 1.08077 L
s
1 0 0 r
0 .86081 m
.5449 .89892 L
s
0 0 0 r
2.5 Mabswid
.5449 .89892 Mdot
1 0 0 r
.5 Mabswid
0 .84918 m
.5331 .88459 L
s
0 0 0 r
2.5 Mabswid
.5331 .88459 Mdot
1 0 0 r
.5 Mabswid
0 .83755 m
.52137 .87036 L
s
0 0 0 r
2.5 Mabswid
.52137 .87036 Mdot
1 0 0 r
.5 Mabswid
0 .82593 m
.50972 .85622 L
s
0 0 0 r
2.5 Mabswid
.50972 .85622 Mdot
1 0 0 r
.5 Mabswid
0 .81432 m
.49815 .84217 L
s
0 0 0 r
2.5 Mabswid
.49815 .84217 Mdot
1 0 0 r
.5 Mabswid
0 .80271 m
.48665 .82821 L
s
0 0 0 r
2.5 Mabswid
.48665 .82821 Mdot
1 0 0 r
.5 Mabswid
0 .7911 m
.47969 .81456 L
s
0 0 0 r
2.5 Mabswid
.47969 .81456 Mdot
1 0 0 r
.5 Mabswid
0 .77949 m
.47427 .80103 L
s
0 0 0 r
2.5 Mabswid
.47427 .80103 Mdot
1 0 0 r
.5 Mabswid
0 .76789 m
.46886 .78755 L
s
0 0 0 r
2.5 Mabswid
.46886 .78755 Mdot
1 0 0 r
.5 Mabswid
0 .7563 m
.46347 .7741 L
s
0 0 0 r
2.5 Mabswid
.46347 .7741 Mdot
1 0 0 r
.5 Mabswid
0 .74471 m
.4581 .7607 L
s
0 0 0 r
2.5 Mabswid
.4581 .7607 Mdot
1 0 0 r
.5 Mabswid
0 .73311 m
.45275 .74734 L
s
0 0 0 r
2.5 Mabswid
.45275 .74734 Mdot
1 0 0 r
.5 Mabswid
0 .72153 m
.44898 .73407 L
s
0 0 0 r
2.5 Mabswid
.44898 .73407 Mdot
1 0 0 r
.5 Mabswid
0 .70994 m
.44898 .72091 L
s
0 0 0 r
2.5 Mabswid
.44898 .72091 Mdot
1 0 0 r
.5 Mabswid
0 .69836 m
.44898 .70776 L
s
0 0 0 r
2.5 Mabswid
.44898 .70776 Mdot
1 0 0 r
.5 Mabswid
0 .68678 m
.44898 .69461 L
s
0 0 0 r
2.5 Mabswid
.44898 .69461 Mdot
1 0 0 r
.5 Mabswid
0 .67519 m
.44898 .68146 L
s
0 0 0 r
2.5 Mabswid
.44898 .68146 Mdot
1 0 0 r
.5 Mabswid
0 .66362 m
.44898 .66832 L
s
0 0 0 r
2.5 Mabswid
.44898 .66832 Mdot
1 0 0 r
.5 Mabswid
0 .65204 m
.44898 .65517 L
s
0 0 0 r
2.5 Mabswid
.44898 .65517 Mdot
1 0 0 r
.5 Mabswid
0 .64046 m
.44898 .64203 L
s
0 0 0 r
2.5 Mabswid
.44898 .64203 Mdot
1 0 0 r
.5 Mabswid
0 .62888 m
.44898 .62888 L
s
0 0 0 r
2.5 Mabswid
.44898 .62888 Mdot
1 0 0 r
.5 Mabswid
0 .6173 m
.44898 .61574 L
s
0 0 0 r
2.5 Mabswid
.44898 .61574 Mdot
1 0 0 r
.5 Mabswid
0 .60573 m
.44898 .60259 L
s
0 0 0 r
2.5 Mabswid
.44898 .60259 Mdot
1 0 0 r
.5 Mabswid
0 .59415 m
.44898 .58944 L
s
0 0 0 r
2.5 Mabswid
.44898 .58944 Mdot
1 0 0 r
.5 Mabswid
0 .58257 m
.44898 .5763 L
s
0 0 0 r
2.5 Mabswid
.44898 .5763 Mdot
1 0 0 r
.5 Mabswid
0 .57099 m
.44898 .56315 L
s
0 0 0 r
2.5 Mabswid
.44898 .56315 Mdot
1 0 0 r
.5 Mabswid
0 .5594 m
.44898 .55 L
s
0 0 0 r
2.5 Mabswid
.44898 .55 Mdot
1 0 0 r
.5 Mabswid
0 .54782 m
.44898 .53685 L
s
0 0 0 r
2.5 Mabswid
.44898 .53685 Mdot
1 0 0 r
.5 Mabswid
0 .53624 m
.44898 .52369 L
s
0 0 0 r
2.5 Mabswid
.44898 .52369 Mdot
1 0 0 r
.5 Mabswid
0 .52465 m
.44898 .51054 L
s
0 0 0 r
2.5 Mabswid
.44898 .51054 Mdot
1 0 0 r
.5 Mabswid
0 .51306 m
.44898 .49738 L
s
0 0 0 r
2.5 Mabswid
.44898 .49738 Mdot
1 0 0 r
.5 Mabswid
0 .50146 m
.44898 .48422 L
s
0 0 0 r
2.5 Mabswid
.44898 .48422 Mdot
1 0 0 r
.5 Mabswid
0 .48987 m
.44898 .47105 L
s
0 0 0 r
2.5 Mabswid
.44898 .47105 Mdot
1 0 0 r
.5 Mabswid
0 .47827 m
.44898 .45788 L
s
0 0 0 r
2.5 Mabswid
.44898 .45788 Mdot
1 0 0 r
.5 Mabswid
0 .46666 m
.44898 .4447 L
s
0 0 0 r
2.5 Mabswid
.44898 .4447 Mdot
1 0 0 r
.5 Mabswid
0 .45506 m
.44898 .43153 L
s
0 0 0 r
2.5 Mabswid
.44898 .43153 Mdot
1 0 0 r
.5 Mabswid
0 .44344 m
.44898 .41834 L
s
0 0 0 r
2.5 Mabswid
.44898 .41834 Mdot
1 0 0 r
.5 Mabswid
0 .43183 m
.44898 .40515 L
s
0 0 0 r
2.5 Mabswid
.44898 .40515 Mdot
1 0 0 r
.5 Mabswid
0 .42021 m
.44898 .39196 L
s
0 0 0 r
2.5 Mabswid
.44898 .39196 Mdot
1 0 0 r
.5 Mabswid
0 .40858 m
.44898 .37876 L
s
0 0 0 r
2.5 Mabswid
.44898 .37876 Mdot
1 0 0 r
.5 Mabswid
0 .39695 m
.45048 .36545 L
s
0 0 0 r
2.5 Mabswid
.45048 .36545 Mdot
1 0 0 r
.5 Mabswid
0 .38531 m
.45594 .35183 L
s
0 0 0 r
2.5 Mabswid
.45594 .35183 Mdot
1 0 0 r
.5 Mabswid
0 .37367 m
.46141 .33817 L
s
0 0 0 r
2.5 Mabswid
.46141 .33817 Mdot
1 0 0 r
.5 Mabswid
0 .36202 m
.46691 .32445 L
s
0 0 0 r
2.5 Mabswid
.46691 .32445 Mdot
1 0 0 r
.5 Mabswid
0 .35036 m
.47243 .31069 L
s
0 0 0 r
2.5 Mabswid
.47243 .31069 Mdot
1 0 0 r
.5 Mabswid
0 .3387 m
.47796 .29688 L
s
0 0 0 r
2.5 Mabswid
.47796 .29688 Mdot
1 0 0 r
.5 Mabswid
0 .32703 m
.48352 .28303 L
s
0 0 0 r
2.5 Mabswid
.48352 .28303 Mdot
1 0 0 r
.5 Mabswid
0 .31535 m
.4952 .26854 L
s
0 0 0 r
2.5 Mabswid
.4952 .26854 Mdot
1 0 0 r
.5 Mabswid
0 .30367 m
.50723 .25393 L
s
0 0 0 r
2.5 Mabswid
.50723 .25393 Mdot
1 0 0 r
.5 Mabswid
0 .29198 m
.51936 .23922 L
s
0 0 0 r
2.5 Mabswid
.51936 .23922 Mdot
1 0 0 r
.5 Mabswid
0 .28027 m
.53156 .2244 L
s
0 0 0 r
2.5 Mabswid
.53156 .2244 Mdot
1 .058 0 r
.5 Mabswid
.5449 .89892 m
.5449 .89892 L
s
0 0 0 r
2.5 Mabswid
.5449 .89892 Mdot
1 .059 0 r
.5 Mabswid
.5331 .88459 m
.5331 .88459 L
s
0 0 0 r
2.5 Mabswid
.5331 .88459 Mdot
1 .059 0 r
.5 Mabswid
.52137 .87036 m
.52137 .87036 L
s
0 0 0 r
2.5 Mabswid
.52137 .87036 Mdot
1 .06 0 r
.5 Mabswid
.50972 .85622 m
.50972 .85622 L
s
0 0 0 r
2.5 Mabswid
.50972 .85622 Mdot
1 .06 0 r
.5 Mabswid
.49815 .84217 m
.49815 .84217 L
s
0 0 0 r
2.5 Mabswid
.49815 .84217 Mdot
1 .061 0 r
.5 Mabswid
.48665 .82821 m
.48665 .82821 L
s
0 0 0 r
2.5 Mabswid
.48665 .82821 Mdot
1 .096 0 r
.5 Mabswid
.47969 .81456 m
.73213 .76114 L
s
0 0 0 r
2.5 Mabswid
.73213 .76114 Mdot
1 .096 0 r
.5 Mabswid
.47427 .80103 m
.74862 .7426 L
s
0 0 0 r
2.5 Mabswid
.74862 .7426 Mdot
1 .097 0 r
.5 Mabswid
.46886 .78755 m
.76511 .72404 L
s
0 0 0 r
2.5 Mabswid
.76511 .72404 Mdot
1 .097 0 r
.5 Mabswid
.46347 .7741 m
.78163 .70546 L
s
0 0 0 r
2.5 Mabswid
.78163 .70546 Mdot
1 .097 0 r
.5 Mabswid
.4581 .7607 m
.79816 .68685 L
s
0 0 0 r
2.5 Mabswid
.79816 .68685 Mdot
1 .098 0 r
.5 Mabswid
.45275 .74734 m
.81472 .66823 L
s
0 0 0 r
2.5 Mabswid
.81472 .66823 Mdot
1 .116 0 r
.5 Mabswid
.44898 .73407 m
.75309 .73757 L
s
0 0 0 r
2.5 Mabswid
.75309 .73757 Mdot
1 .116 0 r
.5 Mabswid
.44898 .72091 m
.76506 .7241 L
s
0 0 0 r
2.5 Mabswid
.76506 .7241 Mdot
1 .116 0 r
.5 Mabswid
.44898 .70776 m
.77706 .71059 L
s
0 0 0 r
2.5 Mabswid
.77706 .71059 Mdot
1 .116 0 r
.5 Mabswid
.44898 .69461 m
.78909 .69706 L
s
0 0 0 r
2.5 Mabswid
.78909 .69706 Mdot
1 .116 0 r
.5 Mabswid
.44898 .68146 m
.80115 .68349 L
s
0 0 0 r
2.5 Mabswid
.80115 .68349 Mdot
1 .116 0 r
.5 Mabswid
.44898 .66832 m
.81324 .66989 L
s
0 0 0 r
2.5 Mabswid
.81324 .66989 Mdot
1 .116 0 r
.5 Mabswid
.44898 .65517 m
.82441 .65625 L
s
0 0 0 r
2.5 Mabswid
.82441 .65625 Mdot
1 .116 0 r
.5 Mabswid
.44898 .64203 m
.83529 .64258 L
s
0 0 0 r
2.5 Mabswid
.83529 .64258 Mdot
1 .116 0 r
.5 Mabswid
.44898 .62888 m
.8462 .62888 L
s
0 0 0 r
2.5 Mabswid
.8462 .62888 Mdot
1 .116 0 r
.5 Mabswid
.44898 .61574 m
.85713 .61515 L
s
0 0 0 r
2.5 Mabswid
.85713 .61515 Mdot
1 .116 0 r
.5 Mabswid
.44898 .60259 m
.86809 .60138 L
s
0 0 0 r
2.5 Mabswid
.86809 .60138 Mdot
1 .116 0 r
.5 Mabswid
.44898 .58944 m
.87907 .58759 L
s
0 0 0 r
2.5 Mabswid
.87907 .58759 Mdot
1 .116 0 r
.5 Mabswid
.44898 .5763 m
.89008 .57376 L
s
0 0 0 r
2.5 Mabswid
.89008 .57376 Mdot
1 .116 0 r
.5 Mabswid
.44898 .56315 m
.90112 .5599 L
s
0 0 0 r
2.5 Mabswid
.90112 .5599 Mdot
1 .116 0 r
.5 Mabswid
.44898 .55 m
.90022 .5461 L
s
0 0 0 r
2.5 Mabswid
.90022 .5461 Mdot
1 .116 0 r
.5 Mabswid
.44898 .53685 m
.88932 .53241 L
s
0 0 0 r
2.5 Mabswid
.88932 .53241 Mdot
1 .116 0 r
.5 Mabswid
.44898 .52369 m
.87844 .51875 L
s
0 0 0 r
2.5 Mabswid
.87844 .51875 Mdot
1 .116 0 r
.5 Mabswid
.44898 .51054 m
.86759 .50512 L
s
0 0 0 r
2.5 Mabswid
.86759 .50512 Mdot
1 .116 0 r
.5 Mabswid
.44898 .49738 m
.85676 .49151 L
s
0 0 0 r
2.5 Mabswid
.85676 .49151 Mdot
1 .116 0 r
.5 Mabswid
.44898 .48422 m
.84595 .47793 L
s
0 0 0 r
2.5 Mabswid
.84595 .47793 Mdot
1 .116 0 r
.5 Mabswid
.44898 .47105 m
.83516 .46438 L
s
0 0 0 r
2.5 Mabswid
.83516 .46438 Mdot
1 .115 0 r
.5 Mabswid
.44898 .45788 m
.82439 .45086 L
s
0 0 0 r
2.5 Mabswid
.82439 .45086 Mdot
1 .115 0 r
.5 Mabswid
.44898 .4447 m
.81335 .43737 L
s
0 0 0 r
2.5 Mabswid
.81335 .43737 Mdot
1 .115 0 r
.5 Mabswid
.44898 .43153 m
.8014 .42392 L
s
0 0 0 r
2.5 Mabswid
.8014 .42392 Mdot
1 .115 0 r
.5 Mabswid
.44898 .41834 m
.78948 .41051 L
s
0 0 0 r
2.5 Mabswid
.78948 .41051 Mdot
1 .115 0 r
.5 Mabswid
.44898 .40515 m
.77758 .39712 L
s
0 0 0 r
2.5 Mabswid
.77758 .39712 Mdot
1 .115 0 r
.5 Mabswid
.44898 .39196 m
.76571 .38376 L
s
0 0 0 r
2.5 Mabswid
.76571 .38376 Mdot
1 .115 0 r
.5 Mabswid
.44898 .37876 m
.75386 .37043 L
s
0 0 0 r
2.5 Mabswid
.75386 .37043 Mdot
1 .094 0 r
.5 Mabswid
.45048 .36545 m
.81537 .43964 L
s
0 0 0 r
2.5 Mabswid
.81537 .43964 Mdot
1 .094 0 r
.5 Mabswid
.45594 .35183 m
.79888 .42109 L
s
0 0 0 r
2.5 Mabswid
.79888 .42109 Mdot
1 .094 0 r
.5 Mabswid
.46141 .33817 m
.78241 .40255 L
s
0 0 0 r
2.5 Mabswid
.78241 .40255 Mdot
1 .093 0 r
.5 Mabswid
.46691 .32445 m
.76594 .38403 L
s
0 0 0 r
2.5 Mabswid
.76594 .38403 Mdot
1 .093 0 r
.5 Mabswid
.47243 .31069 m
.74949 .36551 L
s
0 0 0 r
2.5 Mabswid
.74949 .36551 Mdot
1 .092 0 r
.5 Mabswid
.47796 .29688 m
.73304 .34701 L
s
0 0 0 r
2.5 Mabswid
.73304 .34701 Mdot
1 .092 0 r
.5 Mabswid
.48352 .28303 m
.7166 .32851 L
s
0 0 0 r
2.5 Mabswid
.7166 .32851 Mdot
1 .056 0 r
.5 Mabswid
.4952 .26854 m
.4952 .26854 L
s
0 0 0 r
2.5 Mabswid
.4952 .26854 Mdot
1 .054 0 r
.5 Mabswid
.50723 .25393 m
.50723 .25393 L
s
0 0 0 r
2.5 Mabswid
.50723 .25393 Mdot
1 .053 0 r
.5 Mabswid
.51936 .23922 m
.51936 .23922 L
s
0 0 0 r
2.5 Mabswid
.51936 .23922 Mdot
1 .053 0 r
.5 Mabswid
.53156 .2244 m
.53156 .2244 L
s
0 0 0 r
2.5 Mabswid
.53156 .2244 Mdot
1 .866 0 r
.5 Mabswid
.5449 .89892 m
.59728 .90798 L
s
0 0 0 r
2.5 Mabswid
.59728 .90798 Mdot
.8 1 0 r
.5 Mabswid
.5449 .89892 m
.5449 .89892 L
s
0 0 0 r
2.5 Mabswid
.5449 .89892 Mdot
1 .878 0 r
.5 Mabswid
.5331 .88459 m
.60557 .89679 L
s
0 0 0 r
2.5 Mabswid
.60557 .89679 Mdot
.765 1 0 r
.5 Mabswid
.5331 .88459 m
.5331 .88459 L
s
0 0 0 r
2.5 Mabswid
.5331 .88459 Mdot
1 .871 0 r
.5 Mabswid
.52137 .87036 m
.61395 .8855 L
s
0 0 0 r
2.5 Mabswid
.61395 .8855 Mdot
.766 1 0 r
.5 Mabswid
.52137 .87036 m
.52137 .87036 L
s
0 0 0 r
2.5 Mabswid
.52137 .87036 Mdot
1 .864 0 r
.5 Mabswid
.50972 .85622 m
.62242 .87413 L
s
0 0 0 r
2.5 Mabswid
.62242 .87413 Mdot
.767 1 0 r
.5 Mabswid
.50972 .85622 m
.50972 .85622 L
s
0 0 0 r
2.5 Mabswid
.50972 .85622 Mdot
1 .857 0 r
.5 Mabswid
.49815 .84217 m
.63098 .86266 L
s
0 0 0 r
2.5 Mabswid
.63098 .86266 Mdot
.768 1 0 r
.5 Mabswid
.49815 .84217 m
.49815 .84217 L
s
0 0 0 r
2.5 Mabswid
.49815 .84217 Mdot
1 .85 0 r
.5 Mabswid
.48665 .82821 m
.63963 .8511 L
s
0 0 0 r
2.5 Mabswid
.63963 .8511 Mdot
.77 1 0 r
.5 Mabswid
.48665 .82821 m
.48665 .82821 L
s
0 0 0 r
2.5 Mabswid
.48665 .82821 Mdot
1 .096 0 r
.5 Mabswid
.73213 .76114 m
.77046 .40606 L
s
0 0 0 r
2.5 Mabswid
.77046 .40606 Mdot
1 .096 0 r
.5 Mabswid
.74862 .7426 m
.7838 .42064 L
s
0 0 0 r
2.5 Mabswid
.7838 .42064 Mdot
1 .097 0 r
.5 Mabswid
.76511 .72404 m
.79707 .43515 L
s
0 0 0 r
2.5 Mabswid
.79707 .43515 Mdot
1 .097 0 r
.5 Mabswid
.78163 .70546 m
.81027 .44958 L
s
0 0 0 r
2.5 Mabswid
.81027 .44958 Mdot
1 .097 0 r
.5 Mabswid
.79816 .68685 m
.82342 .46394 L
s
0 0 0 r
2.5 Mabswid
.82342 .46394 Mdot
1 .098 0 r
.5 Mabswid
.81472 .66823 m
.83649 .47824 L
s
0 0 0 r
2.5 Mabswid
.83649 .47824 Mdot
1 .116 0 r
.5 Mabswid
.75309 .73757 m
.70825 .33807 L
s
0 0 0 r
2.5 Mabswid
.70825 .33807 Mdot
1 .116 0 r
.5 Mabswid
.76506 .7241 m
.72424 .35554 L
s
0 0 0 r
2.5 Mabswid
.72424 .35554 Mdot
1 .116 0 r
.5 Mabswid
.77706 .71059 m
.74016 .37294 L
s
0 0 0 r
2.5 Mabswid
.74016 .37294 Mdot
1 .116 0 r
.5 Mabswid
.78909 .69706 m
.75601 .39027 L
s
0 0 0 r
2.5 Mabswid
.75601 .39027 Mdot
1 .116 0 r
.5 Mabswid
.80115 .68349 m
.7718 .40752 L
s
0 0 0 r
2.5 Mabswid
.7718 .40752 Mdot
1 .116 0 r
.5 Mabswid
.81324 .66989 m
.78752 .42471 L
s
0 0 0 r
2.5 Mabswid
.78752 .42471 Mdot
1 .116 0 r
.5 Mabswid
.82441 .65625 m
.78916 .44322 L
s
0 0 0 r
2.5 Mabswid
.78916 .44322 Mdot
1 .116 0 r
.5 Mabswid
.83529 .64258 m
.80501 .45792 L
s
0 0 0 r
2.5 Mabswid
.80501 .45792 Mdot
1 .116 0 r
.5 Mabswid
.8462 .62888 m
.82086 .4729 L
s
0 0 0 r
2.5 Mabswid
.82086 .4729 Mdot
1 .116 0 r
.5 Mabswid
.85713 .61515 m
.83664 .48782 L
s
0 0 0 r
2.5 Mabswid
.83664 .48782 Mdot
1 .116 0 r
.5 Mabswid
.86809 .60138 m
.85235 .50268 L
s
0 0 0 r
2.5 Mabswid
.85235 .50268 Mdot
1 .116 0 r
.5 Mabswid
.87907 .58759 m
.868 .51748 L
s
0 0 0 r
2.5 Mabswid
.868 .51748 Mdot
1 .116 0 r
.5 Mabswid
.89008 .57376 m
.88358 .53222 L
s
0 0 0 r
2.5 Mabswid
.88358 .53222 Mdot
1 .116 0 r
.5 Mabswid
.90112 .5599 m
.8991 .5469 L
s
0 0 0 r
2.5 Mabswid
.8991 .5469 Mdot
1 .116 0 r
.5 Mabswid
.90022 .5461 m
.89754 .56172 L
s
0 0 0 r
2.5 Mabswid
.89754 .56172 Mdot
1 .116 0 r
.5 Mabswid
.88932 .53241 m
.88164 .57675 L
s
0 0 0 r
2.5 Mabswid
.88164 .57675 Mdot
1 .116 0 r
.5 Mabswid
.87844 .51875 m
.86568 .59184 L
s
0 0 0 r
2.5 Mabswid
.86568 .59184 Mdot
1 .116 0 r
.5 Mabswid
.86759 .50512 m
.84964 .60701 L
s
0 0 0 r
2.5 Mabswid
.84964 .60701 Mdot
1 .116 0 r
.5 Mabswid
.85676 .49151 m
.83354 .62224 L
s
0 0 0 r
2.5 Mabswid
.83354 .62224 Mdot
1 .116 0 r
.5 Mabswid
.84595 .47793 m
.81735 .63754 L
s
0 0 0 r
2.5 Mabswid
.81735 .63754 Mdot
1 .116 0 r
.5 Mabswid
.83516 .46438 m
.8011 .65292 L
s
0 0 0 r
2.5 Mabswid
.8011 .65292 Mdot
1 .115 0 r
.5 Mabswid
.82439 .45086 m
.78493 .66749 L
s
0 0 0 r
2.5 Mabswid
.78493 .66749 Mdot
1 .115 0 r
.5 Mabswid
.81335 .43737 m
.78312 .68722 L
s
0 0 0 r
2.5 Mabswid
.78312 .68722 Mdot
1 .115 0 r
.5 Mabswid
.8014 .42392 m
.767 .70484 L
s
0 0 0 r
2.5 Mabswid
.767 .70484 Mdot
1 .115 0 r
.5 Mabswid
.78948 .41051 m
.75081 .72253 L
s
0 0 0 r
2.5 Mabswid
.75081 .72253 Mdot
1 .115 0 r
.5 Mabswid
.77758 .39712 m
.73454 .74031 L
s
0 0 0 r
2.5 Mabswid
.73454 .74031 Mdot
1 .115 0 r
.5 Mabswid
.76571 .38376 m
.7182 .75816 L
s
0 0 0 r
2.5 Mabswid
.7182 .75816 Mdot
1 .115 0 r
.5 Mabswid
.75386 .37043 m
.70179 .7761 L
s
0 0 0 r
2.5 Mabswid
.70179 .7761 Mdot
1 .094 0 r
.5 Mabswid
.81537 .43964 m
.83452 .63105 L
s
0 0 0 r
2.5 Mabswid
.83452 .63105 Mdot
1 .094 0 r
.5 Mabswid
.79888 .42109 m
.82106 .64576 L
s
0 0 0 r
2.5 Mabswid
.82106 .64576 Mdot
1 .094 0 r
.5 Mabswid
.78241 .40255 m
.80753 .66054 L
s
0 0 0 r
2.5 Mabswid
.80753 .66054 Mdot
1 .093 0 r
.5 Mabswid
.76594 .38403 m
.79394 .6754 L
s
0 0 0 r
2.5 Mabswid
.79394 .6754 Mdot
1 .093 0 r
.5 Mabswid
.74949 .36551 m
.78027 .69033 L
s
0 0 0 r
2.5 Mabswid
.78027 .69033 Mdot
1 .092 0 r
.5 Mabswid
.73304 .34701 m
.76653 .70535 L
s
0 0 0 r
2.5 Mabswid
.76653 .70535 Mdot
1 .092 0 r
.5 Mabswid
.7166 .32851 m
.75272 .72044 L
s
0 0 0 r
2.5 Mabswid
.75272 .72044 Mdot
1 .992 0 r
.5 Mabswid
.4952 .26854 m
.62775 .24114 L
s
0 0 0 r
2.5 Mabswid
.62775 .24114 Mdot
.782 1 0 r
.5 Mabswid
.4952 .26854 m
.4952 .26854 L
s
0 0 0 r
2.5 Mabswid
.4952 .26854 Mdot
1 .946 0 r
.5 Mabswid
.50723 .25393 m
.61965 .23014 L
s
0 0 0 r
2.5 Mabswid
.61965 .23014 Mdot
.757 1 0 r
.5 Mabswid
.50723 .25393 m
.50723 .25393 L
s
0 0 0 r
2.5 Mabswid
.50723 .25393 Mdot
1 .954 0 r
.5 Mabswid
.51936 .23922 m
.61164 .21923 L
s
0 0 0 r
2.5 Mabswid
.61164 .21923 Mdot
.757 1 0 r
.5 Mabswid
.51936 .23922 m
.51936 .23922 L
s
0 0 0 r
2.5 Mabswid
.51936 .23922 Mdot
1 .962 0 r
.5 Mabswid
.53156 .2244 m
.60372 .20841 L
s
0 0 0 r
2.5 Mabswid
.60372 .20841 Mdot
.756 1 0 r
.5 Mabswid
.53156 .2244 m
.53156 .2244 L
s
0 0 0 r
2.5 Mabswid
.53156 .2244 Mdot
.045 1 0 r
.5 Mabswid
.59728 .90798 m
.44898 .47975 L
s
0 0 0 r
2.5 Mabswid
.44898 .47975 Mdot
.8 1 0 r
.5 Mabswid
.5449 .89892 m
.5449 .89892 L
s
0 0 0 r
2.5 Mabswid
.5449 .89892 Mdot
.022 1 0 r
.5 Mabswid
.60557 .89679 m
.44898 .43825 L
s
0 0 0 r
2.5 Mabswid
.44898 .43825 Mdot
.765 1 0 r
.5 Mabswid
.5331 .88459 m
.5331 .88459 L
s
0 0 0 r
2.5 Mabswid
.5331 .88459 Mdot
.031 1 0 r
.5 Mabswid
.61395 .8855 m
.45579 .41579 L
s
0 0 0 r
2.5 Mabswid
.45579 .41579 Mdot
.766 1 0 r
.5 Mabswid
.52137 .87036 m
.52137 .87036 L
s
0 0 0 r
2.5 Mabswid
.52137 .87036 Mdot
.039 1 0 r
.5 Mabswid
.62242 .87413 m
.4641 .39721 L
s
0 0 0 r
2.5 Mabswid
.4641 .39721 Mdot
.767 1 0 r
.5 Mabswid
.50972 .85622 m
.50972 .85622 L
s
0 0 0 r
2.5 Mabswid
.50972 .85622 Mdot
.047 1 0 r
.5 Mabswid
.63098 .86266 m
.47249 .37836 L
s
0 0 0 r
2.5 Mabswid
.47249 .37836 Mdot
.768 1 0 r
.5 Mabswid
.49815 .84217 m
.49815 .84217 L
s
0 0 0 r
2.5 Mabswid
.49815 .84217 Mdot
.056 1 0 r
.5 Mabswid
.63963 .8511 m
.48146 .36079 L
s
0 0 0 r
2.5 Mabswid
.48146 .36079 Mdot
.77 1 0 r
.5 Mabswid
.48665 .82821 m
.48665 .82821 L
s
0 0 0 r
2.5 Mabswid
.48665 .82821 Mdot
1 .096 0 r
.5 Mabswid
.77046 .40606 m
.45083 .36456 L
s
0 0 0 r
2.5 Mabswid
.45083 .36456 Mdot
1 .096 0 r
.5 Mabswid
.7838 .42064 m
.44898 .37755 L
s
0 0 0 r
2.5 Mabswid
.44898 .37755 Mdot
1 .097 0 r
.5 Mabswid
.79707 .43515 m
.44898 .39076 L
s
0 0 0 r
2.5 Mabswid
.44898 .39076 Mdot
1 .097 0 r
.5 Mabswid
.81027 .44958 m
.44898 .40393 L
s
0 0 0 r
2.5 Mabswid
.44898 .40393 Mdot
1 .097 0 r
.5 Mabswid
.82342 .46394 m
.44898 .41706 L
s
0 0 0 r
2.5 Mabswid
.44898 .41706 Mdot
1 .098 0 r
.5 Mabswid
.83649 .47824 m
.44898 .43017 L
s
0 0 0 r
2.5 Mabswid
.44898 .43017 Mdot
1 .116 0 r
.5 Mabswid
.70825 .33807 m
.50689 .27265 L
s
0 0 0 r
2.5 Mabswid
.50689 .27265 Mdot
1 .116 0 r
.5 Mabswid
.72424 .35554 m
.49839 .28247 L
s
0 0 0 r
2.5 Mabswid
.49839 .28247 Mdot
1 .116 0 r
.5 Mabswid
.74016 .37294 m
.48989 .2923 L
s
0 0 0 r
2.5 Mabswid
.48989 .2923 Mdot
1 .116 0 r
.5 Mabswid
.75601 .39027 m
.48138 .30214 L
s
0 0 0 r
2.5 Mabswid
.48138 .30214 Mdot
1 .116 0 r
.5 Mabswid
.7718 .40752 m
.47286 .31198 L
s
0 0 0 r
2.5 Mabswid
.47286 .31198 Mdot
1 .116 0 r
.5 Mabswid
.78752 .42471 m
.46755 .32287 L
s
0 0 0 r
2.5 Mabswid
.46755 .32287 Mdot
1 .116 0 r
.5 Mabswid
.78916 .44322 m
.46947 .33831 L
s
0 0 0 r
2.5 Mabswid
.46947 .33831 Mdot
1 .116 0 r
.5 Mabswid
.80501 .45792 m
.46486 .36086 L
s
0 0 0 r
2.5 Mabswid
.46486 .36086 Mdot
1 .116 0 r
.5 Mabswid
.82086 .4729 m
.45748 .36963 L
s
0 0 0 r
2.5 Mabswid
.45748 .36963 Mdot
1 .116 0 r
.5 Mabswid
.83664 .48782 m
.45206 .37896 L
s
0 0 0 r
2.5 Mabswid
.45206 .37896 Mdot
1 .116 0 r
.5 Mabswid
.85235 .50268 m
.44898 .38896 L
s
0 0 0 r
2.5 Mabswid
.44898 .38896 Mdot
1 .116 0 r
.5 Mabswid
.868 .51748 m
.44898 .39982 L
s
0 0 0 r
2.5 Mabswid
.44898 .39982 Mdot
1 .116 0 r
.5 Mabswid
.88358 .53222 m
.44898 .41067 L
s
0 0 0 r
2.5 Mabswid
.44898 .41067 Mdot
1 .116 0 r
.5 Mabswid
.8991 .5469 m
.44898 .42151 L
s
0 0 0 r
2.5 Mabswid
.44898 .42151 Mdot
1 .116 0 r
.5 Mabswid
.89754 .56172 m
.44898 .69223 L
s
0 0 0 r
2.5 Mabswid
.44898 .69223 Mdot
1 .116 0 r
.5 Mabswid
.88164 .57675 m
.44898 .70313 L
s
0 0 0 r
2.5 Mabswid
.44898 .70313 Mdot
1 .116 0 r
.5 Mabswid
.86568 .59184 m
.44898 .71404 L
s
0 0 0 r
2.5 Mabswid
.44898 .71404 Mdot
1 .116 0 r
.5 Mabswid
.84964 .60701 m
.45001 .72465 L
s
0 0 0 r
2.5 Mabswid
.45001 .72465 Mdot
1 .116 0 r
.5 Mabswid
.83354 .62224 m
.45543 .73398 L
s
0 0 0 r
2.5 Mabswid
.45543 .73398 Mdot
1 .116 0 r
.5 Mabswid
.81735 .63754 m
.46184 .74301 L
s
0 0 0 r
2.5 Mabswid
.46184 .74301 Mdot
1 .116 0 r
.5 Mabswid
.8011 .65292 m
.46979 .75158 L
s
0 0 0 r
2.5 Mabswid
.46979 .75158 Mdot
1 .115 0 r
.5 Mabswid
.78493 .66749 m
.47386 .77258 L
s
0 0 0 r
2.5 Mabswid
.47386 .77258 Mdot
1 .115 0 r
.5 Mabswid
.78312 .68722 m
.47016 .79077 L
s
0 0 0 r
2.5 Mabswid
.47016 .79077 Mdot
1 .115 0 r
.5 Mabswid
.767 .70484 m
.47784 .8009 L
s
0 0 0 r
2.5 Mabswid
.47784 .8009 Mdot
1 .115 0 r
.5 Mabswid
.75081 .72253 m
.48635 .81074 L
s
0 0 0 r
2.5 Mabswid
.48635 .81074 Mdot
1 .115 0 r
.5 Mabswid
.73454 .74031 m
.49485 .82057 L
s
0 0 0 r
2.5 Mabswid
.49485 .82057 Mdot
1 .115 0 r
.5 Mabswid
.7182 .75816 m
.50334 .83039 L
s
0 0 0 r
2.5 Mabswid
.50334 .83039 Mdot
1 .115 0 r
.5 Mabswid
.70179 .7761 m
.51183 .84021 L
s
0 0 0 r
2.5 Mabswid
.51183 .84021 Mdot
1 .094 0 r
.5 Mabswid
.83452 .63105 m
.44898 .68295 L
s
0 0 0 r
2.5 Mabswid
.44898 .68295 Mdot
1 .094 0 r
.5 Mabswid
.82106 .64576 m
.44898 .69627 L
s
0 0 0 r
2.5 Mabswid
.44898 .69627 Mdot
1 .094 0 r
.5 Mabswid
.80753 .66054 m
.44898 .70963 L
s
0 0 0 r
2.5 Mabswid
.44898 .70963 Mdot
1 .093 0 r
.5 Mabswid
.79394 .6754 m
.44898 .72302 L
s
0 0 0 r
2.5 Mabswid
.44898 .72302 Mdot
1 .093 0 r
.5 Mabswid
.78027 .69033 m
.44898 .73645 L
s
0 0 0 r
2.5 Mabswid
.44898 .73645 Mdot
1 .092 0 r
.5 Mabswid
.76653 .70535 m
.45352 .74928 L
s
0 0 0 r
2.5 Mabswid
.45352 .74928 Mdot
1 .092 0 r
.5 Mabswid
.75272 .72044 m
.45864 .76205 L
s
0 0 0 r
2.5 Mabswid
.45864 .76205 Mdot
0 1 .598 r
.5 Mabswid
.62775 .24114 m
.45859 .68539 L
s
0 0 0 r
2.5 Mabswid
.45859 .68539 Mdot
.782 1 0 r
.5 Mabswid
.4952 .26854 m
.4952 .26854 L
s
0 0 0 r
2.5 Mabswid
.4952 .26854 Mdot
0 1 .056 r
.5 Mabswid
.61965 .23014 m
.45066 .66811 L
s
0 0 0 r
2.5 Mabswid
.45066 .66811 Mdot
.757 1 0 r
.5 Mabswid
.50723 .25393 m
.50723 .25393 L
s
0 0 0 r
2.5 Mabswid
.50723 .25393 Mdot
0 1 .066 r
.5 Mabswid
.61164 .21923 m
.44898 .63529 L
s
0 0 0 r
2.5 Mabswid
.44898 .63529 Mdot
.757 1 0 r
.5 Mabswid
.51936 .23922 m
.51936 .23922 L
s
0 0 0 r
2.5 Mabswid
.51936 .23922 Mdot
0 1 .075 r
.5 Mabswid
.60372 .20841 m
.44898 .59908 L
s
0 0 0 r
2.5 Mabswid
.44898 .59908 Mdot
.756 1 0 r
.5 Mabswid
.53156 .2244 m
.53156 .2244 L
s
0 0 0 r
2.5 Mabswid
.53156 .2244 Mdot
0 1 .403 r
.5 Mabswid
.44898 .47975 m
.50765 .31033 L
s
0 0 0 r
2.5 Mabswid
.50765 .31033 Mdot
.8 1 0 r
.5 Mabswid
.5449 .89892 m
.5449 .89892 L
s
0 0 0 r
2.5 Mabswid
.5449 .89892 Mdot
0 1 .517 r
.5 Mabswid
.44898 .43825 m
.47638 .35803 L
s
0 0 0 r
2.5 Mabswid
.47638 .35803 Mdot
.765 1 0 r
.5 Mabswid
.5331 .88459 m
.5331 .88459 L
s
0 0 0 r
2.5 Mabswid
.5331 .88459 Mdot
0 1 .665 r
.5 Mabswid
.45579 .41579 m
.63998 .26961 L
s
0 0 0 r
2.5 Mabswid
.63998 .26961 Mdot
.766 1 0 r
.5 Mabswid
.52137 .87036 m
.52137 .87036 L
s
0 0 0 r
2.5 Mabswid
.52137 .87036 Mdot
0 1 .653 r
.5 Mabswid
.4641 .39721 m
.6303 .26428 L
s
0 0 0 r
2.5 Mabswid
.6303 .26428 Mdot
.767 1 0 r
.5 Mabswid
.50972 .85622 m
.50972 .85622 L
s
0 0 0 r
2.5 Mabswid
.50972 .85622 Mdot
0 1 .64 r
.5 Mabswid
.47249 .37836 m
.61991 .25952 L
s
0 0 0 r
2.5 Mabswid
.61991 .25952 Mdot
.768 1 0 r
.5 Mabswid
.49815 .84217 m
.49815 .84217 L
s
0 0 0 r
2.5 Mabswid
.49815 .84217 Mdot
0 1 .65 r
.5 Mabswid
.48146 .36079 m
.67732 .33749 L
s
0 0 0 r
2.5 Mabswid
.67732 .33749 Mdot
.77 1 0 r
.5 Mabswid
.48665 .82821 m
.48665 .82821 L
s
0 0 0 r
2.5 Mabswid
.48665 .82821 Mdot
1 .728 0 r
.5 Mabswid
.45083 .36456 m
.8029 .62309 L
s
0 0 0 r
2.5 Mabswid
.8029 .62309 Mdot
.778 1 0 r
.5 Mabswid
.44898 .37755 m
.71427 .34342 L
s
0 0 0 r
2.5 Mabswid
.71427 .34342 Mdot
.789 1 0 r
.5 Mabswid
.44898 .39076 m
.72108 .35606 L
s
0 0 0 r
2.5 Mabswid
.72108 .35606 Mdot
.793 1 0 r
.5 Mabswid
.44898 .40393 m
.72789 .36868 L
s
0 0 0 r
2.5 Mabswid
.72789 .36868 Mdot
.797 1 0 r
.5 Mabswid
.44898 .41706 m
.73422 .38135 L
s
0 0 0 r
2.5 Mabswid
.73422 .38135 Mdot
.801 1 0 r
.5 Mabswid
.44898 .43017 m
.73912 .39419 L
s
0 0 0 r
2.5 Mabswid
.73912 .39419 Mdot
1 .886 0 r
.5 Mabswid
.50689 .27265 m
.77239 .57713 L
s
0 0 0 r
2.5 Mabswid
.77239 .57713 Mdot
.857 1 0 r
.5 Mabswid
.49839 .28247 m
.76298 .58678 L
s
0 0 0 r
2.5 Mabswid
.76298 .58678 Mdot
.866 1 0 r
.5 Mabswid
.48989 .2923 m
.75327 .59612 L
s
0 0 0 r
2.5 Mabswid
.75327 .59612 Mdot
.874 1 0 r
.5 Mabswid
.48138 .30214 m
.74356 .60546 L
s
0 0 0 r
2.5 Mabswid
.74356 .60546 Mdot
.884 1 0 r
.5 Mabswid
.47286 .31198 m
.73384 .61481 L
s
0 0 0 r
2.5 Mabswid
.73384 .61481 Mdot
.806 1 0 r
.5 Mabswid
.46755 .32287 m
.87469 .52174 L
s
0 0 0 r
2.5 Mabswid
.87469 .52174 Mdot
1 .99 0 r
.5 Mabswid
.46947 .33831 m
.76133 .66474 L
s
0 0 0 r
2.5 Mabswid
.76133 .66474 Mdot
.303 1 0 r
.5 Mabswid
.46486 .36086 m
.76687 .71529 L
s
0 0 0 r
2.5 Mabswid
.76687 .71529 Mdot
.89 1 0 r
.5 Mabswid
.45748 .36963 m
.82111 .47241 L
s
0 0 0 r
2.5 Mabswid
.82111 .47241 Mdot
.865 1 0 r
.5 Mabswid
.45206 .37896 m
.82307 .48428 L
s
0 0 0 r
2.5 Mabswid
.82307 .48428 Mdot
.364 1 0 r
.5 Mabswid
.44898 .38896 m
.68479 .32247 L
s
0 0 0 r
2.5 Mabswid
.68479 .32247 Mdot
.37 1 0 r
.5 Mabswid
.44898 .39982 m
.6946 .33084 L
s
0 0 0 r
2.5 Mabswid
.6946 .33084 Mdot
.378 1 0 r
.5 Mabswid
.44898 .41067 m
.70442 .33922 L
s
0 0 0 r
2.5 Mabswid
.70442 .33922 Mdot
.385 1 0 r
.5 Mabswid
.44898 .42151 m
.71425 .34761 L
s
0 0 0 r
2.5 Mabswid
.71425 .34761 Mdot
.298 1 0 r
.5 Mabswid
.44898 .69223 m
.7056 .7669 L
s
0 0 0 r
2.5 Mabswid
.7056 .7669 Mdot
.284 1 0 r
.5 Mabswid
.44898 .70313 m
.69583 .77524 L
s
0 0 0 r
2.5 Mabswid
.69583 .77524 Mdot
.274 1 0 r
.5 Mabswid
.44898 .71404 m
.68608 .78356 L
s
0 0 0 r
2.5 Mabswid
.68608 .78356 Mdot
.88 1 0 r
.5 Mabswid
.45001 .72465 m
.82327 .62324 L
s
0 0 0 r
2.5 Mabswid
.82327 .62324 Mdot
.865 1 0 r
.5 Mabswid
.45543 .73398 m
.82096 .63511 L
s
0 0 0 r
2.5 Mabswid
.82096 .63511 Mdot
.4 1 0 r
.5 Mabswid
.46184 .74301 m
.76779 .39262 L
s
0 0 0 r
2.5 Mabswid
.76779 .39262 Mdot
.406 1 0 r
.5 Mabswid
.46979 .75158 m
.77692 .40068 L
s
0 0 0 r
2.5 Mabswid
.77692 .40068 Mdot
.282 1 0 r
.5 Mabswid
.47386 .77258 m
.77233 .4462 L
s
0 0 0 r
2.5 Mabswid
.77233 .4462 Mdot
.813 1 0 r
.5 Mabswid
.47016 .79077 m
.86403 .60391 L
s
0 0 0 r
2.5 Mabswid
.86403 .60391 Mdot
.819 1 0 r
.5 Mabswid
.47784 .8009 m
.74347 .50236 L
s
0 0 0 r
2.5 Mabswid
.74347 .50236 Mdot
.814 1 0 r
.5 Mabswid
.48635 .81074 m
.75316 .51174 L
s
0 0 0 r
2.5 Mabswid
.75316 .51174 Mdot
.81 1 0 r
.5 Mabswid
.49485 .82057 m
.76274 .52123 L
s
0 0 0 r
2.5 Mabswid
.76274 .52123 Mdot
.806 1 0 r
.5 Mabswid
.50334 .83039 m
.77208 .531 L
s
0 0 0 r
2.5 Mabswid
.77208 .531 Mdot
.803 1 0 r
.5 Mabswid
.51183 .84021 m
.7814 .54075 L
s
0 0 0 r
2.5 Mabswid
.7814 .54075 Mdot
.8 1 0 r
.5 Mabswid
.44898 .68295 m
.73709 .72173 L
s
0 0 0 r
2.5 Mabswid
.73709 .72173 Mdot
.746 1 0 r
.5 Mabswid
.44898 .69627 m
.73082 .73453 L
s
0 0 0 r
2.5 Mabswid
.73082 .73453 Mdot
.741 1 0 r
.5 Mabswid
.44898 .70963 m
.72396 .74728 L
s
0 0 0 r
2.5 Mabswid
.72396 .74728 Mdot
.737 1 0 r
.5 Mabswid
.44898 .72302 m
.7171 .76004 L
s
0 0 0 r
2.5 Mabswid
.7171 .76004 Mdot
.732 1 0 r
.5 Mabswid
.44898 .73645 m
.71022 .77281 L
s
0 0 0 r
2.5 Mabswid
.71022 .77281 Mdot
.514 1 0 r
.5 Mabswid
.45352 .74928 m
.81312 .49089 L
s
0 0 0 r
2.5 Mabswid
.81312 .49089 Mdot
.514 1 0 r
.5 Mabswid
.45864 .76205 m
.82322 .5007 L
s
0 0 0 r
2.5 Mabswid
.82322 .5007 Mdot
0 .282 1 r
.5 Mabswid
.45859 .68539 m
.64551 .82335 L
s
0 0 0 r
2.5 Mabswid
.64551 .82335 Mdot
.782 1 0 r
.5 Mabswid
.4952 .26854 m
.4952 .26854 L
s
0 0 0 r
2.5 Mabswid
.4952 .26854 Mdot
0 1 .797 r
.5 Mabswid
.45066 .66811 m
.65576 .81823 L
s
0 0 0 r
2.5 Mabswid
.65576 .81823 Mdot
.757 1 0 r
.5 Mabswid
.50723 .25393 m
.50723 .25393 L
s
0 0 0 r
2.5 Mabswid
.50723 .25393 Mdot
0 1 .676 r
.5 Mabswid
.44898 .63529 m
.51236 .7974 L
s
0 0 0 r
2.5 Mabswid
.51236 .7974 Mdot
.757 1 0 r
.5 Mabswid
.51936 .23922 m
.51936 .23922 L
s
0 0 0 r
2.5 Mabswid
.51936 .23922 Mdot
0 1 .693 r
.5 Mabswid
.44898 .59908 m
.54568 .84322 L
s
0 0 0 r
2.5 Mabswid
.54568 .84322 Mdot
.756 1 0 r
.5 Mabswid
.53156 .2244 m
.53156 .2244 L
s
0 0 0 r
2.5 Mabswid
.53156 .2244 Mdot
0 1 .975 r
.5 Mabswid
.50765 .31033 m
.5936 .23654 L
s
0 0 0 r
2.5 Mabswid
.5936 .23654 Mdot
.8 1 0 r
.5 Mabswid
.5449 .89892 m
.5449 .89892 L
s
0 0 0 r
2.5 Mabswid
.5449 .89892 Mdot
0 1 .935 r
.5 Mabswid
.47638 .35803 m
.60333 .24989 L
s
0 0 0 r
2.5 Mabswid
.60333 .24989 Mdot
.765 1 0 r
.5 Mabswid
.5331 .88459 m
.5331 .88459 L
s
0 0 0 r
2.5 Mabswid
.5331 .88459 Mdot
.03 0 1 r
.5 Mabswid
.63998 .26961 m
.44898 .42221 L
s
0 0 0 r
2.5 Mabswid
.44898 .42221 Mdot
.766 1 0 r
.5 Mabswid
.52137 .87036 m
.52137 .87036 L
s
0 0 0 r
2.5 Mabswid
.52137 .87036 Mdot
.089 0 1 r
.5 Mabswid
.6303 .26428 m
.45541 .38426 L
s
0 0 0 r
2.5 Mabswid
.45541 .38426 Mdot
.767 1 0 r
.5 Mabswid
.50972 .85622 m
.50972 .85622 L
s
0 0 0 r
2.5 Mabswid
.50972 .85622 Mdot
.069 0 1 r
.5 Mabswid
.61991 .25952 m
.45145 .37369 L
s
0 0 0 r
2.5 Mabswid
.45145 .37369 Mdot
.768 1 0 r
.5 Mabswid
.49815 .84217 m
.49815 .84217 L
s
0 0 0 r
2.5 Mabswid
.49815 .84217 Mdot
0 .38 1 r
.5 Mabswid
.67732 .33749 m
.60523 .77137 L
s
0 0 0 r
2.5 Mabswid
.60523 .77137 Mdot
.77 1 0 r
.5 Mabswid
.48665 .82821 m
.48665 .82821 L
s
0 0 0 r
2.5 Mabswid
.48665 .82821 Mdot
1 .728 0 r
.5 Mabswid
.8029 .62309 m
.5473 .6967 L
s
0 0 0 r
2.5 Mabswid
.5473 .6967 Mdot
.778 1 0 r
.5 Mabswid
.71427 .34342 m
.524 .86299 L
s
0 0 0 r
2.5 Mabswid
.524 .86299 Mdot
.789 1 0 r
.5 Mabswid
.72108 .35606 m
.53175 .87454 L
s
0 0 0 r
2.5 Mabswid
.53175 .87454 Mdot
.793 1 0 r
.5 Mabswid
.72789 .36868 m
.53949 .88608 L
s
0 0 0 r
2.5 Mabswid
.53949 .88608 Mdot
.797 1 0 r
.5 Mabswid
.73422 .38135 m
.55411 .87238 L
s
0 0 0 r
2.5 Mabswid
.55411 .87238 Mdot
.801 1 0 r
.5 Mabswid
.73912 .39419 m
.55949 .88517 L
s
0 0 0 r
2.5 Mabswid
.55949 .88517 Mdot
1 .886 0 r
.5 Mabswid
.77239 .57713 m
.48231 .77437 L
s
0 0 0 r
2.5 Mabswid
.48231 .77437 Mdot
.857 1 0 r
.5 Mabswid
.76298 .58678 m
.44898 .67579 L
s
0 0 0 r
2.5 Mabswid
.44898 .67579 Mdot
.866 1 0 r
.5 Mabswid
.75327 .59612 m
.44898 .68262 L
s
0 0 0 r
2.5 Mabswid
.44898 .68262 Mdot
.874 1 0 r
.5 Mabswid
.74356 .60546 m
.44898 .68944 L
s
0 0 0 r
2.5 Mabswid
.44898 .68944 Mdot
.884 1 0 r
.5 Mabswid
.73384 .61481 m
.44898 .69625 L
s
0 0 0 r
2.5 Mabswid
.44898 .69625 Mdot
.806 1 0 r
.5 Mabswid
.87469 .52174 m
.8871 .57266 L
s
0 0 0 r
2.5 Mabswid
.8871 .57266 Mdot
0 1 .145 r
.5 Mabswid
.76133 .66474 m
.44898 .65338 L
s
0 0 0 r
2.5 Mabswid
.44898 .65338 Mdot
0 1 .871 r
.5 Mabswid
.76687 .71529 m
.44898 .54754 L
s
0 0 0 r
2.5 Mabswid
.44898 .54754 Mdot
.89 1 0 r
.5 Mabswid
.82111 .47241 m
.81114 .64053 L
s
0 0 0 r
2.5 Mabswid
.81114 .64053 Mdot
.865 1 0 r
.5 Mabswid
.82307 .48428 m
.63722 .78848 L
s
0 0 0 r
2.5 Mabswid
.63722 .78848 Mdot
0 1 .928 r
.5 Mabswid
.68479 .32247 m
.45972 .75901 L
s
0 0 0 r
2.5 Mabswid
.45972 .75901 Mdot
0 1 .754 r
.5 Mabswid
.6946 .33084 m
.46918 .76944 L
s
0 0 0 r
2.5 Mabswid
.46918 .76944 Mdot
0 1 .653 r
.5 Mabswid
.70442 .33922 m
.47865 .77989 L
s
0 0 0 r
2.5 Mabswid
.47865 .77989 Mdot
0 1 .542 r
.5 Mabswid
.71425 .34761 m
.48815 .79035 L
s
0 0 0 r
2.5 Mabswid
.48815 .79035 Mdot
0 .111 1 r
.5 Mabswid
.7056 .7669 m
.47517 .33109 L
s
0 0 0 r
2.5 Mabswid
.47517 .33109 Mdot
0 .498 1 r
.5 Mabswid
.69583 .77524 m
.46576 .34146 L
s
0 0 0 r
2.5 Mabswid
.46576 .34146 Mdot
0 .449 1 r
.5 Mabswid
.68608 .78356 m
.45637 .35181 L
s
0 0 0 r
2.5 Mabswid
.45637 .35181 Mdot
.88 1 0 r
.5 Mabswid
.82327 .62324 m
.64099 .32553 L
s
0 0 0 r
2.5 Mabswid
.64099 .32553 Mdot
.865 1 0 r
.5 Mabswid
.82096 .63511 m
.80985 .46396 L
s
0 0 0 r
2.5 Mabswid
.80985 .46396 Mdot
0 1 .699 r
.5 Mabswid
.76779 .39262 m
.44898 .56533 L
s
0 0 0 r
2.5 Mabswid
.44898 .56533 Mdot
0 1 .592 r
.5 Mabswid
.77692 .40068 m
.44898 .62839 L
s
0 0 0 r
2.5 Mabswid
.44898 .62839 Mdot
0 1 .595 r
.5 Mabswid
.77233 .4462 m
.44898 .45961 L
s
0 0 0 r
2.5 Mabswid
.44898 .45961 Mdot
.813 1 0 r
.5 Mabswid
.86403 .60391 m
.88248 .52612 L
s
0 0 0 r
2.5 Mabswid
.88248 .52612 Mdot
.819 1 0 r
.5 Mabswid
.74347 .50236 m
.44898 .42358 L
s
0 0 0 r
2.5 Mabswid
.44898 .42358 Mdot
.814 1 0 r
.5 Mabswid
.75316 .51174 m
.44898 .43063 L
s
0 0 0 r
2.5 Mabswid
.44898 .43063 Mdot
.81 1 0 r
.5 Mabswid
.76274 .52123 m
.47984 .33175 L
s
0 0 0 r
2.5 Mabswid
.47984 .33175 Mdot
.806 1 0 r
.5 Mabswid
.77208 .531 m
.48129 .33638 L
s
0 0 0 r
2.5 Mabswid
.48129 .33638 Mdot
.803 1 0 r
.5 Mabswid
.7814 .54075 m
.48274 .34102 L
s
0 0 0 r
2.5 Mabswid
.48274 .34102 Mdot
.8 1 0 r
.5 Mabswid
.73709 .72173 m
.55594 .2355 L
s
0 0 0 r
2.5 Mabswid
.55594 .2355 Mdot
.746 1 0 r
.5 Mabswid
.73082 .73453 m
.54 .22205 L
s
0 0 0 r
2.5 Mabswid
.54 .22205 Mdot
.741 1 0 r
.5 Mabswid
.72396 .74728 m
.53219 .23367 L
s
0 0 0 r
2.5 Mabswid
.53219 .23367 Mdot
.737 1 0 r
.5 Mabswid
.7171 .76004 m
.52437 .24531 L
s
0 0 0 r
2.5 Mabswid
.52437 .24531 Mdot
.732 1 0 r
.5 Mabswid
.71022 .77281 m
.51746 .25942 L
s
0 0 0 r
2.5 Mabswid
.51746 .25942 Mdot
.514 1 0 r
.5 Mabswid
.81312 .49089 m
.55784 .42108 L
s
0 0 0 r
2.5 Mabswid
.55784 .42108 Mdot
.514 1 0 r
.5 Mabswid
.82322 .5007 m
.56564 .43055 L
s
0 0 0 r
2.5 Mabswid
.56564 .43055 Mdot
.782 1 0 r
.5 Mabswid
.4952 .26854 m
.4952 .26854 L
s
0 0 0 r
2.5 Mabswid
.4952 .26854 Mdot
.757 1 0 r
.5 Mabswid
.50723 .25393 m
.50723 .25393 L
s
0 0 0 r
2.5 Mabswid
.50723 .25393 Mdot
0 .931 1 r
.5 Mabswid
.51236 .7974 m
.58754 .86645 L
s
0 0 0 r
2.5 Mabswid
.58754 .86645 Mdot
.757 1 0 r
.5 Mabswid
.51936 .23922 m
.51936 .23922 L
s
0 0 0 r
2.5 Mabswid
.51936 .23922 Mdot
0 .686 1 r
.5 Mabswid
.54568 .84322 m
.58576 .87377 L
s
0 0 0 r
2.5 Mabswid
.58576 .87377 Mdot
.756 1 0 r
.5 Mabswid
.53156 .2244 m
.53156 .2244 L
s
0 0 0 r
2.5 Mabswid
.53156 .2244 Mdot
0 .029 1 r
.5 Mabswid
.5936 .23654 m
.48892 .30284 L
s
0 0 0 r
2.5 Mabswid
.48892 .30284 Mdot
.8 1 0 r
.5 Mabswid
.5449 .89892 m
.5449 .89892 L
s
0 0 0 r
2.5 Mabswid
.5449 .89892 Mdot
.136 0 1 r
.5 Mabswid
.60333 .24989 m
.46004 .3416 L
s
0 0 0 r
2.5 Mabswid
.46004 .3416 Mdot
.765 1 0 r
.5 Mabswid
.5331 .88459 m
.5331 .88459 L
s
0 0 0 r
2.5 Mabswid
.5331 .88459 Mdot
.766 1 0 r
.5 Mabswid
.52137 .87036 m
.52137 .87036 L
s
0 0 0 r
2.5 Mabswid
.52137 .87036 Mdot
.767 1 0 r
.5 Mabswid
.50972 .85622 m
.50972 .85622 L
s
0 0 0 r
2.5 Mabswid
.50972 .85622 Mdot
.768 1 0 r
.5 Mabswid
.49815 .84217 m
.49815 .84217 L
s
0 0 0 r
2.5 Mabswid
.49815 .84217 Mdot
.77 1 0 r
.5 Mabswid
.48665 .82821 m
.48665 .82821 L
s
0 0 0 r
2.5 Mabswid
.48665 .82821 Mdot
1 .728 0 r
.5 Mabswid
.5473 .6967 m
.62392 .67781 L
s
0 0 0 r
2.5 Mabswid
.62392 .67781 Mdot
.778 1 0 r
.5 Mabswid
.524 .86299 m
.65195 .84056 L
s
0 0 0 r
2.5 Mabswid
.65195 .84056 Mdot
.789 1 0 r
.5 Mabswid
.53175 .87454 m
.64055 .85558 L
s
0 0 0 r
2.5 Mabswid
.64055 .85558 Mdot
.793 1 0 r
.5 Mabswid
.53949 .88608 m
.62921 .87054 L
s
0 0 0 r
2.5 Mabswid
.62921 .87054 Mdot
.797 1 0 r
.5 Mabswid
.55411 .87238 m
.59759 .87307 L
s
0 0 0 r
2.5 Mabswid
.59759 .87307 Mdot
.801 1 0 r
.5 Mabswid
.55949 .88517 m
.59368 .88575 L
s
0 0 0 r
2.5 Mabswid
.59368 .88575 Mdot
1 .886 0 r
.5 Mabswid
.48231 .77437 m
.73922 .62063 L
s
0 0 0 r
2.5 Mabswid
.73922 .62063 Mdot
.857 1 0 r
.5 Mabswid
.44898 .67579 m
.65211 .73338 L
s
0 0 0 r
2.5 Mabswid
.65211 .73338 Mdot
.866 1 0 r
.5 Mabswid
.44898 .68262 m
.65742 .74188 L
s
0 0 0 r
2.5 Mabswid
.65742 .74188 Mdot
.874 1 0 r
.5 Mabswid
.44898 .68944 m
.66272 .75038 L
s
0 0 0 r
2.5 Mabswid
.66272 .75038 Mdot
.884 1 0 r
.5 Mabswid
.44898 .69625 m
.66606 .75831 L
s
0 0 0 r
2.5 Mabswid
.66606 .75831 Mdot
.806 1 0 r
.5 Mabswid
.8871 .57266 m
.47179 .61576 L
s
0 0 0 r
2.5 Mabswid
.47179 .61576 Mdot
0 1 .145 r
.5 Mabswid
.44898 .65338 m
.65821 .64578 L
s
0 0 0 r
2.5 Mabswid
.65821 .64578 Mdot
0 1 .871 r
.5 Mabswid
.44898 .54754 m
.74496 .39134 L
s
0 0 0 r
2.5 Mabswid
.74496 .39134 Mdot
.89 1 0 r
.5 Mabswid
.81114 .64053 m
.4549 .75272 L
s
0 0 0 r
2.5 Mabswid
.4549 .75272 Mdot
.865 1 0 r
.5 Mabswid
.63722 .78848 m
.55798 .81953 L
s
0 0 0 r
2.5 Mabswid
.55798 .81953 Mdot
0 1 .928 r
.5 Mabswid
.45972 .75901 m
.73967 .73914 L
s
0 0 0 r
2.5 Mabswid
.73967 .73914 Mdot
0 1 .754 r
.5 Mabswid
.46918 .76944 m
.72598 .75148 L
s
0 0 0 r
2.5 Mabswid
.72598 .75148 Mdot
0 1 .653 r
.5 Mabswid
.47865 .77989 m
.71233 .76378 L
s
0 0 0 r
2.5 Mabswid
.71233 .76378 Mdot
0 1 .542 r
.5 Mabswid
.48815 .79035 m
.69872 .77606 L
s
0 0 0 r
2.5 Mabswid
.69872 .77606 Mdot
0 .111 1 r
.5 Mabswid
.47517 .33109 m
.72026 .35049 L
s
0 0 0 r
2.5 Mabswid
.72026 .35049 Mdot
0 .498 1 r
.5 Mabswid
.46576 .34146 m
.73411 .36298 L
s
0 0 0 r
2.5 Mabswid
.73411 .36298 Mdot
0 .449 1 r
.5 Mabswid
.45637 .35181 m
.748 .3755 L
s
0 0 0 r
2.5 Mabswid
.748 .3755 Mdot
.88 1 0 r
.5 Mabswid
.64099 .32553 m
.55664 .29356 L
s
0 0 0 r
2.5 Mabswid
.55664 .29356 Mdot
.865 1 0 r
.5 Mabswid
.80985 .46396 m
.45717 .34876 L
s
0 0 0 r
2.5 Mabswid
.45717 .34876 Mdot
0 1 .699 r
.5 Mabswid
.44898 .56533 m
.73729 .72151 L
s
0 0 0 r
2.5 Mabswid
.73729 .72151 Mdot
0 1 .592 r
.5 Mabswid
.44898 .62839 m
.69175 .79695 L
s
0 0 0 r
2.5 Mabswid
.69175 .79695 Mdot
0 1 .595 r
.5 Mabswid
.44898 .45961 m
.64126 .46759 L
s
0 0 0 r
2.5 Mabswid
.64126 .46759 Mdot
.813 1 0 r
.5 Mabswid
.88248 .52612 m
.44898 .52123 L
s
0 0 0 r
2.5 Mabswid
.44898 .52123 Mdot
.819 1 0 r
.5 Mabswid
.44898 .42358 m
.66326 .36626 L
s
0 0 0 r
2.5 Mabswid
.66326 .36626 Mdot
.814 1 0 r
.5 Mabswid
.44898 .43063 m
.65801 .37489 L
s
0 0 0 r
2.5 Mabswid
.65801 .37489 Mdot
.81 1 0 r
.5 Mabswid
.47984 .33175 m
.74434 .49285 L
s
0 0 0 r
2.5 Mabswid
.74434 .49285 Mdot
.806 1 0 r
.5 Mabswid
.48129 .33638 m
.73248 .48948 L
s
0 0 0 r
2.5 Mabswid
.73248 .48948 Mdot
.803 1 0 r
.5 Mabswid
.48274 .34102 m
.72063 .48611 L
s
0 0 0 r
2.5 Mabswid
.72063 .48611 Mdot
.8 1 0 r
.5 Mabswid
.55594 .2355 m
.60414 .2389 L
s
0 0 0 r
2.5 Mabswid
.60414 .2389 Mdot
.746 1 0 r
.5 Mabswid
.54 .22205 m
.62905 .2383 L
s
0 0 0 r
2.5 Mabswid
.62905 .2383 Mdot
.741 1 0 r
.5 Mabswid
.53219 .23367 m
.64062 .25357 L
s
0 0 0 r
2.5 Mabswid
.64062 .25357 Mdot
.737 1 0 r
.5 Mabswid
.52437 .24531 m
.65224 .26891 L
s
0 0 0 r
2.5 Mabswid
.65224 .26891 Mdot
.732 1 0 r
.5 Mabswid
.51746 .25942 m
.6383 .25205 L
s
0 0 0 r
2.5 Mabswid
.6383 .25205 Mdot
.514 1 0 r
.5 Mabswid
.55784 .42108 m
.60334 .43293 L
s
0 0 0 r
2.5 Mabswid
.60334 .43293 Mdot
0 .938 1 r
.5 Mabswid
.56564 .43055 m
.59864 .434 L
s
0 0 0 r
2.5 Mabswid
.59864 .434 Mdot
.782 1 0 r
.5 Mabswid
.4952 .26854 m
.4952 .26854 L
s
0 0 0 r
2.5 Mabswid
.4952 .26854 Mdot
.757 1 0 r
.5 Mabswid
.50723 .25393 m
.50723 .25393 L
s
0 0 0 r
2.5 Mabswid
.50723 .25393 Mdot
.757 1 0 r
.5 Mabswid
.51936 .23922 m
.51936 .23922 L
s
0 0 0 r
2.5 Mabswid
.51936 .23922 Mdot
.756 1 0 r
.5 Mabswid
.53156 .2244 m
.53156 .2244 L
s
0 0 0 r
2.5 Mabswid
.53156 .2244 Mdot
1 .728 0 r
.5 Mabswid
.62392 .67781 m
.65 .34288 L
s
0 0 0 r
2.5 Mabswid
.65 .34288 Mdot
.778 1 0 r
.5 Mabswid
.65195 .84056 m
.69007 .30437 L
s
0 0 0 r
2.5 Mabswid
.69007 .30437 Mdot
.789 1 0 r
.5 Mabswid
.64055 .85558 m
.67987 .29595 L
s
0 0 0 r
2.5 Mabswid
.67987 .29595 Mdot
.793 1 0 r
.5 Mabswid
.62921 .87054 m
.66969 .28753 L
s
0 0 0 r
2.5 Mabswid
.66969 .28753 Mdot
.797 1 0 r
.5 Mabswid
.59759 .87307 m
.49449 .33007 L
s
0 0 0 r
2.5 Mabswid
.49449 .33007 Mdot
.801 1 0 r
.5 Mabswid
.59368 .88575 m
.49014 .34214 L
s
0 0 0 r
2.5 Mabswid
.49014 .34214 Mdot
1 .886 0 r
.5 Mabswid
.73922 .62063 m
.68748 .30213 L
s
0 0 0 r
2.5 Mabswid
.68748 .30213 Mdot
0 1 .495 r
.5 Mabswid
.65211 .73338 m
.44898 .58091 L
s
0 0 0 r
2.5 Mabswid
.44898 .58091 Mdot
0 1 .253 r
.5 Mabswid
.65742 .74188 m
.44898 .58555 L
s
0 0 0 r
2.5 Mabswid
.44898 .58555 Mdot
0 1 .243 r
.5 Mabswid
.66272 .75038 m
.44898 .5902 L
s
0 0 0 r
2.5 Mabswid
.44898 .5902 Mdot
0 .538 1 r
.5 Mabswid
.66606 .75831 m
.44898 .46049 L
s
0 0 0 r
2.5 Mabswid
.44898 .46049 Mdot
0 1 .599 r
.5 Mabswid
.47179 .61576 m
.8249 .46116 L
s
0 0 0 r
2.5 Mabswid
.8249 .46116 Mdot
0 .711 1 r
.5 Mabswid
.65821 .64578 m
.44898 .55617 L
s
0 0 0 r
2.5 Mabswid
.44898 .55617 Mdot
0 .13 1 r
.5 Mabswid
.74496 .39134 m
.44918 .73846 L
s
0 0 0 r
2.5 Mabswid
.44918 .73846 Mdot
0 1 .284 r
.5 Mabswid
.4549 .75272 m
.84185 .56225 L
s
0 0 0 r
2.5 Mabswid
.84185 .56225 Mdot
0 1 .394 r
.5 Mabswid
.55798 .81953 m
.80694 .54307 L
s
0 0 0 r
2.5 Mabswid
.80694 .54307 Mdot
0 1 .928 r
.5 Mabswid
.73967 .73914 m
.70969 .34999 L
s
0 0 0 r
2.5 Mabswid
.70969 .34999 Mdot
0 1 .754 r
.5 Mabswid
.72598 .75148 m
.69288 .32953 L
s
0 0 0 r
2.5 Mabswid
.69288 .32953 Mdot
0 1 .653 r
.5 Mabswid
.71233 .76378 m
.67601 .30899 L
s
0 0 0 r
2.5 Mabswid
.67601 .30899 Mdot
0 1 .542 r
.5 Mabswid
.69872 .77606 m
.65907 .28839 L
s
0 0 0 r
2.5 Mabswid
.65907 .28839 Mdot
0 .111 1 r
.5 Mabswid
.72026 .35049 m
.6922 .77843 L
s
0 0 0 r
2.5 Mabswid
.6922 .77843 Mdot
0 .498 1 r
.5 Mabswid
.73411 .36298 m
.70875 .75829 L
s
0 0 0 r
2.5 Mabswid
.70875 .75829 Mdot
0 .449 1 r
.5 Mabswid
.748 .3755 m
.72525 .73821 L
s
0 0 0 r
2.5 Mabswid
.72525 .73821 Mdot
.06 1 0 r
.5 Mabswid
.55664 .29356 m
.79491 .56293 L
s
0 0 0 r
2.5 Mabswid
.79491 .56293 Mdot
0 1 .063 r
.5 Mabswid
.45717 .34876 m
.83084 .52779 L
s
0 0 0 r
2.5 Mabswid
.83084 .52779 Mdot
0 .364 1 r
.5 Mabswid
.73729 .72151 m
.45624 .42096 L
s
0 0 0 r
2.5 Mabswid
.45624 .42096 Mdot
0 .418 1 r
.5 Mabswid
.69175 .79695 m
.44898 .52103 L
s
0 0 0 r
2.5 Mabswid
.44898 .52103 Mdot
0 .298 1 r
.5 Mabswid
.64126 .46759 m
.44898 .54976 L
s
0 0 0 r
2.5 Mabswid
.44898 .54976 Mdot
0 1 .532 r
.5 Mabswid
.44898 .52123 m
.74867 .51785 L
s
0 0 0 r
2.5 Mabswid
.74867 .51785 Mdot
0 1 .247 r
.5 Mabswid
.66326 .36626 m
.44898 .53112 L
s
0 0 0 r
2.5 Mabswid
.44898 .53112 Mdot
0 1 .326 r
.5 Mabswid
.65801 .37489 m
.44898 .53583 L
s
0 0 0 r
2.5 Mabswid
.44898 .53583 Mdot
.81 1 0 r
.5 Mabswid
.74434 .49285 m
.68865 .80473 L
s
0 0 0 r
2.5 Mabswid
.68865 .80473 Mdot
.806 1 0 r
.5 Mabswid
.73248 .48948 m
.67251 .82284 L
s
0 0 0 r
2.5 Mabswid
.67251 .82284 Mdot
.803 1 0 r
.5 Mabswid
.72063 .48611 m
.65631 .84102 L
s
0 0 0 r
2.5 Mabswid
.65631 .84102 Mdot
.8 1 0 r
.5 Mabswid
.60414 .2389 m
.63379 .73746 L
s
0 0 0 r
2.5 Mabswid
.63379 .73746 Mdot
.746 1 0 r
.5 Mabswid
.62905 .2383 m
.67281 .81998 L
s
0 0 0 r
2.5 Mabswid
.67281 .81998 Mdot
.741 1 0 r
.5 Mabswid
.64062 .25357 m
.68305 .8115 L
s
0 0 0 r
2.5 Mabswid
.68305 .8115 Mdot
.737 1 0 r
.5 Mabswid
.65224 .26891 m
.69329 .80301 L
s
0 0 0 r
2.5 Mabswid
.69329 .80301 Mdot
.732 1 0 r
.5 Mabswid
.6383 .25205 m
.54935 .86907 L
s
0 0 0 r
2.5 Mabswid
.54935 .86907 Mdot
.514 1 0 r
.5 Mabswid
.60334 .43293 m
.62963 .70901 L
s
0 0 0 r
2.5 Mabswid
.62963 .70901 Mdot
0 .938 1 r
.5 Mabswid
.59864 .434 m
.74477 .55553 L
s
0 0 0 r
2.5 Mabswid
.74477 .55553 Mdot
1 .728 0 r
.5 Mabswid
.65 .34288 m
.51393 .3402 L
s
0 0 0 r
2.5 Mabswid
.51393 .3402 Mdot
.778 1 0 r
.5 Mabswid
.69007 .30437 m
.4802 .29684 L
s
0 0 0 r
2.5 Mabswid
.4802 .29684 Mdot
.789 1 0 r
.5 Mabswid
.67987 .29595 m
.48948 .289 L
s
0 0 0 r
2.5 Mabswid
.48948 .289 Mdot
.793 1 0 r
.5 Mabswid
.66969 .28753 m
.49872 .28118 L
s
0 0 0 r
2.5 Mabswid
.49872 .28118 Mdot
.797 1 0 r
.5 Mabswid
.49449 .33007 m
.64065 .30948 L
s
0 0 0 r
2.5 Mabswid
.64065 .30948 Mdot
.801 1 0 r
.5 Mabswid
.49014 .34214 m
.64227 .32085 L
s
0 0 0 r
2.5 Mabswid
.64227 .32085 Mdot
1 .886 0 r
.5 Mabswid
.68748 .30213 m
.51794 .27493 L
s
0 0 0 r
2.5 Mabswid
.51794 .27493 Mdot
0 1 .495 r
.5 Mabswid
.44898 .58091 m
.72216 .37586 L
s
0 0 0 r
2.5 Mabswid
.72216 .37586 Mdot
0 1 .253 r
.5 Mabswid
.44898 .58555 m
.71944 .38271 L
s
0 0 0 r
2.5 Mabswid
.71944 .38271 Mdot
0 1 .243 r
.5 Mabswid
.44898 .5902 m
.71671 .38956 L
s
0 0 0 r
2.5 Mabswid
.71671 .38956 Mdot
0 .538 1 r
.5 Mabswid
.44898 .46049 m
.61171 .23723 L
s
0 0 0 r
2.5 Mabswid
.61171 .23723 Mdot
0 .711 1 r
.5 Mabswid
.44898 .55617 m
.70704 .44564 L
s
0 0 0 r
2.5 Mabswid
.70704 .44564 Mdot
0 .13 1 r
.5 Mabswid
.44918 .73846 m
.6946 .76372 L
s
0 0 0 r
2.5 Mabswid
.6946 .76372 Mdot
0 1 .284 r
.5 Mabswid
.84185 .56225 m
.82163 .45224 L
s
0 0 0 r
2.5 Mabswid
.82163 .45224 Mdot
0 1 .394 r
.5 Mabswid
.80694 .54307 m
.78769 .43714 L
s
0 0 0 r
2.5 Mabswid
.78769 .43714 Mdot
0 1 .928 r
.5 Mabswid
.70969 .34999 m
.50082 .30709 L
s
0 0 0 r
2.5 Mabswid
.50082 .30709 Mdot
0 1 .754 r
.5 Mabswid
.69288 .32953 m
.51034 .29176 L
s
0 0 0 r
2.5 Mabswid
.51034 .29176 Mdot
0 1 .653 r
.5 Mabswid
.67601 .30899 m
.51986 .27645 L
s
0 0 0 r
2.5 Mabswid
.51986 .27645 Mdot
0 1 .542 r
.5 Mabswid
.65907 .28839 m
.52936 .26116 L
s
0 0 0 r
2.5 Mabswid
.52936 .26116 Mdot
0 .111 1 r
.5 Mabswid
.6922 .77843 m
.50936 .81379 L
s
0 0 0 r
2.5 Mabswid
.50936 .81379 Mdot
0 .498 1 r
.5 Mabswid
.70875 .75829 m
.49979 .79838 L
s
0 0 0 r
2.5 Mabswid
.49979 .79838 Mdot
0 .449 1 r
.5 Mabswid
.72525 .73821 m
.4902 .78296 L
s
0 0 0 r
2.5 Mabswid
.4902 .78296 Mdot
.06 1 0 r
.5 Mabswid
.79491 .56293 m
.81013 .67272 L
s
0 0 0 r
2.5 Mabswid
.81013 .67272 Mdot
0 1 .063 r
.5 Mabswid
.83084 .52779 m
.80192 .67082 L
s
0 0 0 r
2.5 Mabswid
.80192 .67082 Mdot
0 .364 1 r
.5 Mabswid
.45624 .42096 m
.69564 .3778 L
s
0 0 0 r
2.5 Mabswid
.69564 .3778 Mdot
0 .418 1 r
.5 Mabswid
.44898 .52103 m
.65717 .28441 L
s
0 0 0 r
2.5 Mabswid
.65717 .28441 Mdot
0 .298 1 r
.5 Mabswid
.44898 .54976 m
.7276 .66885 L
s
0 0 0 r
2.5 Mabswid
.7276 .66885 Mdot
0 1 .532 r
.5 Mabswid
.74867 .51785 m
.55523 .64354 L
s
0 0 0 r
2.5 Mabswid
.55523 .64354 Mdot
0 1 .247 r
.5 Mabswid
.44898 .53112 m
.7121 .73355 L
s
0 0 0 r
2.5 Mabswid
.7121 .73355 Mdot
0 1 .326 r
.5 Mabswid
.44898 .53583 m
.71476 .74046 L
s
0 0 0 r
2.5 Mabswid
.71476 .74046 Mdot
.81 1 0 r
.5 Mabswid
.68865 .80473 m
.51816 .83506 L
s
0 0 0 r
2.5 Mabswid
.51816 .83506 Mdot
.806 1 0 r
.5 Mabswid
.67251 .82284 m
.5246 .84937 L
s
0 0 0 r
2.5 Mabswid
.5246 .84937 Mdot
.803 1 0 r
.5 Mabswid
.65631 .84102 m
.53102 .86367 L
s
0 0 0 r
2.5 Mabswid
.53102 .86367 Mdot
.8 1 0 r
.5 Mabswid
.63379 .73746 m
.52703 .76816 L
s
0 0 0 r
2.5 Mabswid
.52703 .76816 Mdot
.746 1 0 r
.5 Mabswid
.67281 .81998 m
.49309 .82619 L
s
0 0 0 r
2.5 Mabswid
.49309 .82619 Mdot
.741 1 0 r
.5 Mabswid
.68305 .8115 m
.48375 .81826 L
s
0 0 0 r
2.5 Mabswid
.48375 .81826 Mdot
.737 1 0 r
.5 Mabswid
.69329 .80301 m
.47794 .81019 L
s
0 0 0 r
2.5 Mabswid
.47794 .81019 Mdot
.732 1 0 r
.5 Mabswid
.54935 .86907 m
.59817 .88107 L
s
0 0 0 r
2.5 Mabswid
.59817 .88107 Mdot
.514 1 0 r
.5 Mabswid
.62963 .70901 m
.53447 .69922 L
s
0 0 0 r
2.5 Mabswid
.53447 .69922 Mdot
0 .938 1 r
.5 Mabswid
.74477 .55553 m
.44898 .55449 L
s
0 0 0 r
2.5 Mabswid
.44898 .55449 Mdot
1 .728 0 r
.5 Mabswid
.51393 .3402 m
.65241 .6766 L
s
0 0 0 r
2.5 Mabswid
.65241 .6766 Mdot
.778 1 0 r
.5 Mabswid
.4802 .29684 m
.67914 .73939 L
s
0 0 0 r
2.5 Mabswid
.67914 .73939 Mdot
.789 1 0 r
.5 Mabswid
.48948 .289 m
.69075 .7356 L
s
0 0 0 r
2.5 Mabswid
.69075 .7356 Mdot
.793 1 0 r
.5 Mabswid
.49872 .28118 m
.70191 .73092 L
s
0 0 0 r
2.5 Mabswid
.70191 .73092 Mdot
.797 1 0 r
.5 Mabswid
.64065 .30948 m
.46753 .7695 L
s
0 0 0 r
2.5 Mabswid
.46753 .7695 Mdot
.801 1 0 r
.5 Mabswid
.64227 .32085 m
.46987 .7796 L
s
0 0 0 r
2.5 Mabswid
.46987 .7796 Mdot
1 .886 0 r
.5 Mabswid
.51794 .27493 m
.78369 .63296 L
s
0 0 0 r
2.5 Mabswid
.78369 .63296 Mdot
0 .692 1 r
.5 Mabswid
.72216 .37586 m
.44898 .58241 L
s
0 0 0 r
2.5 Mabswid
.44898 .58241 Mdot
0 .685 1 r
.5 Mabswid
.71944 .38271 m
.44898 .58734 L
s
0 0 0 r
2.5 Mabswid
.44898 .58734 Mdot
0 .695 1 r
.5 Mabswid
.71671 .38956 m
.44898 .59226 L
s
0 0 0 r
2.5 Mabswid
.44898 .59226 Mdot
0 .538 1 r
.5 Mabswid
.61171 .23723 m
.50108 .27751 L
s
0 0 0 r
2.5 Mabswid
.50108 .27751 Mdot
0 .13 1 r
.5 Mabswid
.6946 .76372 m
.5044 .27731 L
s
0 0 0 r
2.5 Mabswid
.5044 .27731 Mdot
0 1 .284 r
.5 Mabswid
.82163 .45224 m
.46435 .39327 L
s
0 0 0 r
2.5 Mabswid
.46435 .39327 Mdot
0 1 .394 r
.5 Mabswid
.78769 .43714 m
.53047 .45752 L
s
0 0 0 r
2.5 Mabswid
.53047 .45752 Mdot
0 .595 1 r
.5 Mabswid
.50082 .30709 m
.78052 .69589 L
s
0 0 0 r
2.5 Mabswid
.78052 .69589 Mdot
0 .042 1 r
.5 Mabswid
.49979 .79838 m
.77527 .40437 L
s
0 0 0 r
2.5 Mabswid
.77527 .40437 Mdot
0 .046 1 r
.5 Mabswid
.4902 .78296 m
.76418 .38985 L
s
0 0 0 r
2.5 Mabswid
.76418 .38985 Mdot
.06 1 0 r
.5 Mabswid
.81013 .67272 m
.49527 .6165 L
s
0 0 0 r
2.5 Mabswid
.49527 .6165 Mdot
0 1 .063 r
.5 Mabswid
.80192 .67082 m
.47267 .729 L
s
0 0 0 r
2.5 Mabswid
.47267 .729 Mdot
0 .364 1 r
.5 Mabswid
.69564 .3778 m
.53885 .64159 L
s
0 0 0 r
2.5 Mabswid
.53885 .64159 Mdot
0 1 .532 r
.5 Mabswid
.55523 .64354 m
.60666 .64372 L
s
0 0 0 r
2.5 Mabswid
.60666 .64372 Mdot
0 .877 1 r
.5 Mabswid
.7121 .73355 m
.44898 .53895 L
s
0 0 0 r
2.5 Mabswid
.44898 .53895 Mdot
0 .601 1 r
.5 Mabswid
.71476 .74046 m
.44898 .54404 L
s
0 0 0 r
2.5 Mabswid
.44898 .54404 Mdot
.699 1 0 r
.5 Mabswid
.51816 .83506 m
.79072 .47671 L
s
0 0 0 r
2.5 Mabswid
.79072 .47671 Mdot
.435 1 0 r
.5 Mabswid
.5246 .84937 m
.80198 .48556 L
s
0 0 0 r
2.5 Mabswid
.80198 .48556 Mdot
.371 1 0 r
.5 Mabswid
.53102 .86367 m
.81323 .49443 L
s
0 0 0 r
2.5 Mabswid
.81323 .49443 Mdot
.8 1 0 r
.5 Mabswid
.52703 .76816 m
.64629 .61613 L
s
0 0 0 r
2.5 Mabswid
.64629 .61613 Mdot
.746 1 0 r
.5 Mabswid
.49309 .82619 m
.68951 .38206 L
s
0 0 0 r
2.5 Mabswid
.68951 .38206 Mdot
.741 1 0 r
.5 Mabswid
.48375 .81826 m
.67734 .37941 L
s
0 0 0 r
2.5 Mabswid
.67734 .37941 Mdot
0 .627 1 r
.5 Mabswid
.47794 .81019 m
.84205 .48487 L
s
0 0 0 r
2.5 Mabswid
.84205 .48487 Mdot
.732 1 0 r
.5 Mabswid
.59817 .88107 m
.44898 .52523 L
s
0 0 0 r
2.5 Mabswid
.44898 .52523 Mdot
.514 1 0 r
.5 Mabswid
.53447 .69922 m
.76879 .44166 L
s
0 0 0 r
2.5 Mabswid
.76879 .44166 Mdot
.018 0 1 r
.5 Mabswid
.44898 .55449 m
.84618 .55309 L
s
0 0 0 r
2.5 Mabswid
.84618 .55309 Mdot
1 .728 0 r
.5 Mabswid
.65241 .6766 m
.50561 .69978 L
s
0 0 0 r
2.5 Mabswid
.50561 .69978 Mdot
.778 1 0 r
.5 Mabswid
.67914 .73939 m
.48269 .79346 L
s
0 0 0 r
2.5 Mabswid
.48269 .79346 Mdot
.789 1 0 r
.5 Mabswid
.69075 .7356 m
.44898 .69397 L
s
0 0 0 r
2.5 Mabswid
.44898 .69397 Mdot
.793 1 0 r
.5 Mabswid
.70191 .73092 m
.44898 .68724 L
s
0 0 0 r
2.5 Mabswid
.44898 .68724 Mdot
.797 1 0 r
.5 Mabswid
.46753 .7695 m
.70174 .77021 L
s
0 0 0 r
2.5 Mabswid
.70174 .77021 Mdot
.801 1 0 r
.5 Mabswid
.46987 .7796 m
.69888 .78046 L
s
0 0 0 r
2.5 Mabswid
.69888 .78046 Mdot
1 .886 0 r
.5 Mabswid
.78369 .63296 m
.61982 .82103 L
s
0 0 0 r
2.5 Mabswid
.61982 .82103 Mdot
0 .692 1 r
.5 Mabswid
.44898 .58241 m
.70937 .77929 L
s
0 0 0 r
2.5 Mabswid
.70937 .77929 Mdot
0 .685 1 r
.5 Mabswid
.44898 .58734 m
.70854 .78372 L
s
0 0 0 r
2.5 Mabswid
.70854 .78372 Mdot
0 .695 1 r
.5 Mabswid
.44898 .59226 m
.70772 .78816 L
s
0 0 0 r
2.5 Mabswid
.70772 .78816 Mdot
0 .538 1 r
.5 Mabswid
.50108 .27751 m
.44898 .50002 L
s
0 0 0 r
2.5 Mabswid
.44898 .50002 Mdot
0 .13 1 r
.5 Mabswid
.5044 .27731 m
.6566 .27376 L
s
0 0 0 r
2.5 Mabswid
.6566 .27376 Mdot
0 .588 1 r
.5 Mabswid
.46435 .39327 m
.82645 .53883 L
s
0 0 0 r
2.5 Mabswid
.82645 .53883 Mdot
0 .884 1 r
.5 Mabswid
.53047 .45752 m
.70934 .56151 L
s
0 0 0 r
2.5 Mabswid
.70934 .56151 Mdot
0 .038 1 r
.5 Mabswid
.49527 .6165 m
.74496 .4401 L
s
0 0 0 r
2.5 Mabswid
.74496 .4401 Mdot
0 .932 1 r
.5 Mabswid
.47267 .729 m
.79565 .60332 L
s
0 0 0 r
2.5 Mabswid
.79565 .60332 Mdot
0 .364 1 r
.5 Mabswid
.53885 .64159 m
.62481 .66423 L
s
0 0 0 r
2.5 Mabswid
.62481 .66423 Mdot
0 1 .532 r
.5 Mabswid
.60666 .64372 m
.65377 .5438 L
s
0 0 0 r
2.5 Mabswid
.65377 .5438 Mdot
0 .877 1 r
.5 Mabswid
.44898 .53895 m
.7205 .33814 L
s
0 0 0 r
2.5 Mabswid
.7205 .33814 Mdot
0 .601 1 r
.5 Mabswid
.44898 .54404 m
.72142 .34269 L
s
0 0 0 r
2.5 Mabswid
.72142 .34269 Mdot
.699 1 0 r
.5 Mabswid
.79072 .47671 m
.63756 .30457 L
s
0 0 0 r
2.5 Mabswid
.63756 .30457 Mdot
.435 1 0 r
.5 Mabswid
.80198 .48556 m
.66153 .32761 L
s
0 0 0 r
2.5 Mabswid
.66153 .32761 Mdot
.371 1 0 r
.5 Mabswid
.81323 .49443 m
.68538 .35055 L
s
0 0 0 r
2.5 Mabswid
.68538 .35055 Mdot
.8 1 0 r
.5 Mabswid
.64629 .61613 m
.49828 .53867 L
s
0 0 0 r
2.5 Mabswid
.49828 .53867 Mdot
.746 1 0 r
.5 Mabswid
.68951 .38206 m
.47342 .32306 L
s
0 0 0 r
2.5 Mabswid
.47342 .32306 Mdot
.741 1 0 r
.5 Mabswid
.67734 .37941 m
.47864 .32517 L
s
0 0 0 r
2.5 Mabswid
.47864 .32517 Mdot
.732 1 0 r
.5 Mabswid
.44898 .52523 m
.47486 .46351 L
s
0 0 0 r
2.5 Mabswid
.47486 .46351 Mdot
0 1 .124 r
.5 Mabswid
.76879 .44166 m
.44898 .51447 L
s
0 0 0 r
2.5 Mabswid
.44898 .51447 Mdot
.018 0 1 r
.5 Mabswid
.84618 .55309 m
.84689 .59766 L
s
0 0 0 r
2.5 Mabswid
.84689 .59766 Mdot
1 .728 0 r
.5 Mabswid
.50561 .69978 m
.65649 .60434 L
s
0 0 0 r
2.5 Mabswid
.65649 .60434 Mdot
.778 1 0 r
.5 Mabswid
.48269 .79346 m
.63256 .55502 L
s
0 0 0 r
2.5 Mabswid
.63256 .55502 Mdot
0 1 .003 r
.5 Mabswid
.44898 .69397 m
.84759 .62534 L
s
0 0 0 r
2.5 Mabswid
.84759 .62534 Mdot
0 1 .128 r
.5 Mabswid
.44898 .68724 m
.8467 .61856 L
s
0 0 0 r
2.5 Mabswid
.8467 .61856 Mdot
.797 1 0 r
.5 Mabswid
.70174 .77021 m
.58358 .1932 L
s
0 0 0 r
2.5 Mabswid
.58358 .1932 Mdot
.801 1 0 r
.5 Mabswid
.69888 .78046 m
.57882 .19521 L
s
0 0 0 r
2.5 Mabswid
.57882 .19521 Mdot
1 .886 0 r
.5 Mabswid
.61982 .82103 m
.56462 .83471 L
s
0 0 0 r
2.5 Mabswid
.56462 .83471 Mdot
0 .538 1 r
.5 Mabswid
.44898 .50002 m
.45171 .51167 L
s
0 0 0 r
2.5 Mabswid
.45171 .51167 Mdot
0 .13 1 r
.5 Mabswid
.6566 .27376 m
.57798 .91556 L
s
0 0 0 r
2.5 Mabswid
.57798 .91556 Mdot
0 .588 1 r
.5 Mabswid
.82645 .53883 m
.84609 .6243 L
s
0 0 0 r
2.5 Mabswid
.84609 .6243 Mdot
0 .884 1 r
.5 Mabswid
.70934 .56151 m
.76419 .68961 L
s
0 0 0 r
2.5 Mabswid
.76419 .68961 Mdot
0 .038 1 r
.5 Mabswid
.74496 .4401 m
.71491 .40479 L
s
0 0 0 r
2.5 Mabswid
.71491 .40479 Mdot
0 .932 1 r
.5 Mabswid
.79565 .60332 m
.8237 .47006 L
s
0 0 0 r
2.5 Mabswid
.8237 .47006 Mdot
0 .364 1 r
.5 Mabswid
.62481 .66423 m
.63133 .71337 L
s
0 0 0 r
2.5 Mabswid
.63133 .71337 Mdot
0 1 .532 r
.5 Mabswid
.65377 .5438 m
.50698 .54854 L
s
0 0 0 r
2.5 Mabswid
.50698 .54854 Mdot
.052 0 1 r
.5 Mabswid
.7205 .33814 m
.44898 .62555 L
s
0 0 0 r
2.5 Mabswid
.44898 .62555 Mdot
.699 1 0 r
.5 Mabswid
.63756 .30457 m
.56 .28622 L
s
0 0 0 r
2.5 Mabswid
.56 .28622 Mdot
.435 1 0 r
.5 Mabswid
.66153 .32761 m
.55384 .30232 L
s
0 0 0 r
2.5 Mabswid
.55384 .30232 Mdot
.371 1 0 r
.5 Mabswid
.68538 .35055 m
.55123 .31928 L
s
0 0 0 r
2.5 Mabswid
.55123 .31928 Mdot
.8 1 0 r
.5 Mabswid
.49828 .53867 m
.62143 .37014 L
s
0 0 0 r
2.5 Mabswid
.62143 .37014 Mdot
.746 1 0 r
.5 Mabswid
.47342 .32306 m
.62592 .56477 L
s
0 0 0 r
2.5 Mabswid
.62592 .56477 Mdot
.741 1 0 r
.5 Mabswid
.47864 .32517 m
.63626 .57479 L
s
0 0 0 r
2.5 Mabswid
.63626 .57479 Mdot
.732 1 0 r
.5 Mabswid
.47486 .46351 m
.59867 .35245 L
s
0 0 0 r
2.5 Mabswid
.59867 .35245 Mdot
0 1 .943 r
.5 Mabswid
.44898 .51447 m
.82695 .60052 L
s
0 0 0 r
2.5 Mabswid
.82695 .60052 Mdot
.018 0 1 r
.5 Mabswid
.84689 .59766 m
.44898 .5947 L
s
0 0 0 r
2.5 Mabswid
.44898 .5947 Mdot
1 .728 0 r
.5 Mabswid
.65649 .60434 m
.48386 .53257 L
s
0 0 0 r
2.5 Mabswid
.48386 .53257 Mdot
.778 1 0 r
.5 Mabswid
.63256 .55502 m
.52957 .45866 L
s
0 0 0 r
2.5 Mabswid
.52957 .45866 Mdot
0 1 .003 r
.5 Mabswid
.84759 .62534 m
.83237 .46405 L
s
0 0 0 r
2.5 Mabswid
.83237 .46405 Mdot
0 1 .128 r
.5 Mabswid
.8467 .61856 m
.83226 .46563 L
s
0 0 0 r
2.5 Mabswid
.83226 .46563 Mdot
.797 1 0 r
.5 Mabswid
.58358 .1932 m
.57752 .19152 L
s
0 0 0 r
2.5 Mabswid
.57752 .19152 Mdot
0 1 .522 r
.5 Mabswid
.57882 .19521 m
.46401 .77545 L
s
0 0 0 r
2.5 Mabswid
.46401 .77545 Mdot
.388 1 0 r
.5 Mabswid
.56462 .83471 m
.69041 .67518 L
s
0 0 0 r
2.5 Mabswid
.69041 .67518 Mdot
0 .538 1 r
.5 Mabswid
.45171 .51167 m
.50719 .61252 L
s
0 0 0 r
2.5 Mabswid
.50719 .61252 Mdot
0 .588 1 r
.5 Mabswid
.84609 .6243 m
.45601 .53924 L
s
0 0 0 r
2.5 Mabswid
.45601 .53924 Mdot
0 .884 1 r
.5 Mabswid
.76419 .68961 m
.47574 .55731 L
s
0 0 0 r
2.5 Mabswid
.47574 .55731 Mdot
0 .038 1 r
.5 Mabswid
.71491 .40479 m
.5023 .47376 L
s
0 0 0 r
2.5 Mabswid
.5023 .47376 Mdot
0 .932 1 r
.5 Mabswid
.8237 .47006 m
.46643 .54459 L
s
0 0 0 r
2.5 Mabswid
.46643 .54459 Mdot
0 .364 1 r
.5 Mabswid
.63133 .71337 m
.53868 .67512 L
s
0 0 0 r
2.5 Mabswid
.53868 .67512 Mdot
0 1 .532 r
.5 Mabswid
.50698 .54854 m
.62823 .68965 L
s
0 0 0 r
2.5 Mabswid
.62823 .68965 Mdot
.052 0 1 r
.5 Mabswid
.44898 .62555 m
.6559 .84458 L
s
0 0 0 r
2.5 Mabswid
.6559 .84458 Mdot
.699 1 0 r
.5 Mabswid
.56 .28622 m
.68661 .44851 L
s
0 0 0 r
2.5 Mabswid
.68661 .44851 Mdot
0 1 .832 r
.5 Mabswid
.55384 .30232 m
.80302 .48021 L
s
0 0 0 r
2.5 Mabswid
.80302 .48021 Mdot
0 1 .67 r
.5 Mabswid
.55123 .31928 m
.80819 .50323 L
s
0 0 0 r
2.5 Mabswid
.80819 .50323 Mdot
.8 1 0 r
.5 Mabswid
.62143 .37014 m
.52702 .39985 L
s
0 0 0 r
2.5 Mabswid
.52702 .39985 Mdot
.746 1 0 r
.5 Mabswid
.62592 .56477 m
.50646 .6026 L
s
0 0 0 r
2.5 Mabswid
.50646 .6026 Mdot
.741 1 0 r
.5 Mabswid
.63626 .57479 m
.49817 .61864 L
s
0 0 0 r
2.5 Mabswid
.49817 .61864 Mdot
0 1 .453 r
.5 Mabswid
.59867 .35245 m
.47628 .36817 L
s
0 0 0 r
2.5 Mabswid
.47628 .36817 Mdot
0 .149 1 r
.5 Mabswid
.82695 .60052 m
.5871 .47355 L
s
0 0 0 r
2.5 Mabswid
.5871 .47355 Mdot
1 .728 0 r
.5 Mabswid
.48386 .53257 m
.68734 .50753 L
s
0 0 0 r
2.5 Mabswid
.68734 .50753 Mdot
.778 1 0 r
.5 Mabswid
.52957 .45866 m
.6912 .30545 L
s
0 0 0 r
2.5 Mabswid
.6912 .30545 Mdot
0 1 .003 r
.5 Mabswid
.83237 .46405 m
.47031 .33262 L
s
0 0 0 r
2.5 Mabswid
.47031 .33262 Mdot
0 1 .128 r
.5 Mabswid
.83226 .46563 m
.49277 .31707 L
s
0 0 0 r
2.5 Mabswid
.49277 .31707 Mdot
.797 1 0 r
.5 Mabswid
.57752 .19152 m
.56829 .19442 L
s
0 0 0 r
2.5 Mabswid
.56829 .19442 Mdot
0 1 .522 r
.5 Mabswid
.46401 .77545 m
.62005 .8852 L
s
0 0 0 r
2.5 Mabswid
.62005 .8852 Mdot
.388 1 0 r
.5 Mabswid
.69041 .67518 m
.74252 .5663 L
s
0 0 0 r
2.5 Mabswid
.74252 .5663 Mdot
0 .538 1 r
.5 Mabswid
.50719 .61252 m
.58964 .69003 L
s
0 0 0 r
2.5 Mabswid
.58964 .69003 Mdot
0 .327 1 r
.5 Mabswid
.47574 .55731 m
.72984 .45009 L
s
0 0 0 r
2.5 Mabswid
.72984 .45009 Mdot
0 .038 1 r
.5 Mabswid
.5023 .47376 m
.73286 .74663 L
s
0 0 0 r
2.5 Mabswid
.73286 .74663 Mdot
0 .364 1 r
.5 Mabswid
.53868 .67512 m
.73486 .37512 L
s
0 0 0 r
2.5 Mabswid
.73486 .37512 Mdot
0 1 .532 r
.5 Mabswid
.62823 .68965 m
.53033 .65392 L
s
0 0 0 r
2.5 Mabswid
.53033 .65392 Mdot
.699 1 0 r
.5 Mabswid
.68661 .44851 m
.74584 .66602 L
s
0 0 0 r
2.5 Mabswid
.74584 .66602 Mdot
0 1 .832 r
.5 Mabswid
.80302 .48021 m
.88483 .57841 L
s
0 0 0 r
2.5 Mabswid
.88483 .57841 Mdot
0 1 .67 r
.5 Mabswid
.80819 .50323 m
.87599 .5848 L
s
0 0 0 r
2.5 Mabswid
.87599 .5848 Mdot
.8 1 0 r
.5 Mabswid
.52702 .39985 m
.69234 .75709 L
s
0 0 0 r
2.5 Mabswid
.69234 .75709 Mdot
.746 1 0 r
.5 Mabswid
.50646 .6026 m
.61748 .60253 L
s
0 0 0 r
2.5 Mabswid
.61748 .60253 Mdot
.741 1 0 r
.5 Mabswid
.49817 .61864 m
.60672 .61923 L
s
0 0 0 r
2.5 Mabswid
.60672 .61923 Mdot
0 1 .453 r
.5 Mabswid
.47628 .36817 m
.55792 .56137 L
s
0 0 0 r
2.5 Mabswid
.55792 .56137 Mdot
0 .149 1 r
.5 Mabswid
.5871 .47355 m
.57851 .47165 L
s
0 0 0 r
2.5 Mabswid
.57851 .47165 Mdot
1 .728 0 r
.5 Mabswid
.68734 .50753 m
.45025 .55441 L
s
0 0 0 r
2.5 Mabswid
.45025 .55441 Mdot
.778 1 0 r
.5 Mabswid
.6912 .30545 m
.49371 .47277 L
s
0 0 0 r
2.5 Mabswid
.49371 .47277 Mdot
0 1 .766 r
.5 Mabswid
.47031 .33262 m
.80374 .66495 L
s
0 0 0 r
2.5 Mabswid
.80374 .66495 Mdot
0 .739 1 r
.5 Mabswid
.49277 .31707 m
.82854 .60693 L
s
0 0 0 r
2.5 Mabswid
.82854 .60693 Mdot
.797 1 0 r
.5 Mabswid
.56829 .19442 m
.49138 .83314 L
s
0 0 0 r
2.5 Mabswid
.49138 .83314 Mdot
0 .348 1 r
.5 Mabswid
.62005 .8852 m
.44898 .6914 L
s
0 0 0 r
2.5 Mabswid
.44898 .6914 Mdot
.388 1 0 r
.5 Mabswid
.74252 .5663 m
.74887 .54915 L
s
0 0 0 r
2.5 Mabswid
.74887 .54915 Mdot
0 .538 1 r
.5 Mabswid
.58964 .69003 m
.53729 .72245 L
s
0 0 0 r
2.5 Mabswid
.53729 .72245 Mdot
0 .327 1 r
.5 Mabswid
.72984 .45009 m
.71403 .42584 L
s
0 0 0 r
2.5 Mabswid
.71403 .42584 Mdot
0 .038 1 r
.5 Mabswid
.73286 .74663 m
.52737 .67231 L
s
0 0 0 r
2.5 Mabswid
.52737 .67231 Mdot
0 .364 1 r
.5 Mabswid
.73486 .37512 m
.51624 .40713 L
s
0 0 0 r
2.5 Mabswid
.51624 .40713 Mdot
0 1 .532 r
.5 Mabswid
.53033 .65392 m
.68801 .30724 L
s
0 0 0 r
2.5 Mabswid
.68801 .30724 Mdot
.699 1 0 r
.5 Mabswid
.74584 .66602 m
.69503 .80184 L
s
0 0 0 r
2.5 Mabswid
.69503 .80184 Mdot
0 1 .832 r
.5 Mabswid
.88483 .57841 m
.4687 .34533 L
s
0 0 0 r
2.5 Mabswid
.4687 .34533 Mdot
0 1 .67 r
.5 Mabswid
.87599 .5848 m
.83635 .57421 L
s
0 0 0 r
2.5 Mabswid
.83635 .57421 Mdot
.8 1 0 r
.5 Mabswid
.69234 .75709 m
.45856 .68129 L
s
0 0 0 r
2.5 Mabswid
.45856 .68129 Mdot
.746 1 0 r
.5 Mabswid
.61748 .60253 m
.53157 .58456 L
s
0 0 0 r
2.5 Mabswid
.53157 .58456 Mdot
.741 1 0 r
.5 Mabswid
.60672 .61923 m
.54318 .60602 L
s
0 0 0 r
2.5 Mabswid
.54318 .60602 Mdot
0 1 .453 r
.5 Mabswid
.55792 .56137 m
.58696 .5678 L
s
0 0 0 r
2.5 Mabswid
.58696 .5678 Mdot
0 .149 1 r
.5 Mabswid
.57851 .47165 m
.56066 .47233 L
s
0 0 0 r
2.5 Mabswid
.56066 .47233 Mdot
1 .728 0 r
.5 Mabswid
.45025 .55441 m
.7021 .64584 L
s
0 0 0 r
2.5 Mabswid
.7021 .64584 Mdot
.778 1 0 r
.5 Mabswid
.49371 .47277 m
.66816 .70622 L
s
0 0 0 r
2.5 Mabswid
.66816 .70622 Mdot
0 .739 1 r
.5 Mabswid
.82854 .60693 m
.7724 .67063 L
s
0 0 0 r
2.5 Mabswid
.7724 .67063 Mdot
.797 1 0 r
.5 Mabswid
.49138 .83314 m
.64585 .84992 L
s
0 0 0 r
2.5 Mabswid
.64585 .84992 Mdot
0 .348 1 r
.5 Mabswid
.44898 .6914 m
.68363 .42557 L
s
0 0 0 r
2.5 Mabswid
.68363 .42557 Mdot
.388 1 0 r
.5 Mabswid
.74887 .54915 m
.76013 .41836 L
s
0 0 0 r
2.5 Mabswid
.76013 .41836 Mdot
0 .538 1 r
.5 Mabswid
.53729 .72245 m
.46712 .7832 L
s
0 0 0 r
2.5 Mabswid
.46712 .7832 Mdot
0 .327 1 r
.5 Mabswid
.71403 .42584 m
.50005 .51147 L
s
0 0 0 r
2.5 Mabswid
.50005 .51147 Mdot
0 .038 1 r
.5 Mabswid
.52737 .67231 m
.65199 .59323 L
s
0 0 0 r
2.5 Mabswid
.65199 .59323 Mdot
0 .364 1 r
.5 Mabswid
.51624 .40713 m
.68239 .49168 L
s
0 0 0 r
2.5 Mabswid
.68239 .49168 Mdot
0 1 .532 r
.5 Mabswid
.68801 .30724 m
.47266 .39356 L
s
0 0 0 r
2.5 Mabswid
.47266 .39356 Mdot
.699 1 0 r
.5 Mabswid
.69503 .80184 m
.67779 .81798 L
s
0 0 0 r
2.5 Mabswid
.67779 .81798 Mdot
0 .092 1 r
.5 Mabswid
.4687 .34533 m
.84736 .616 L
s
0 0 0 r
2.5 Mabswid
.84736 .616 Mdot
0 1 .67 r
.5 Mabswid
.83635 .57421 m
.5418 .48675 L
s
0 0 0 r
2.5 Mabswid
.5418 .48675 Mdot
.8 1 0 r
.5 Mabswid
.45856 .68129 m
.72624 .34262 L
s
0 0 0 r
2.5 Mabswid
.72624 .34262 Mdot
.746 1 0 r
.5 Mabswid
.53157 .58456 m
.58948 .33349 L
s
0 0 0 r
2.5 Mabswid
.58948 .33349 Mdot
.741 1 0 r
.5 Mabswid
.54318 .60602 m
.6022 .35318 L
s
0 0 0 r
2.5 Mabswid
.6022 .35318 Mdot
0 1 .453 r
.5 Mabswid
.58696 .5678 m
.44898 .55782 L
s
0 0 0 r
2.5 Mabswid
.44898 .55782 Mdot
0 .149 1 r
.5 Mabswid
.56066 .47233 m
.44898 .50085 L
s
0 0 0 r
2.5 Mabswid
.44898 .50085 Mdot
.142 1 0 r
.5 Mabswid
.7021 .64584 m
.44898 .56785 L
s
0 0 0 r
2.5 Mabswid
.44898 .56785 Mdot
.778 1 0 r
.5 Mabswid
.66816 .70622 m
.50407 .81438 L
s
0 0 0 r
2.5 Mabswid
.50407 .81438 Mdot
0 .739 1 r
.5 Mabswid
.7724 .67063 m
.54432 .65949 L
s
0 0 0 r
2.5 Mabswid
.54432 .65949 Mdot
.797 1 0 r
.5 Mabswid
.64585 .84992 m
.50108 .28966 L
s
0 0 0 r
2.5 Mabswid
.50108 .28966 Mdot
.388 1 0 r
.5 Mabswid
.76013 .41836 m
.61418 .25555 L
s
0 0 0 r
2.5 Mabswid
.61418 .25555 Mdot
0 .538 1 r
.5 Mabswid
.46712 .7832 m
.56164 .77858 L
s
0 0 0 r
2.5 Mabswid
.56164 .77858 Mdot
0 .327 1 r
.5 Mabswid
.50005 .51147 m
.69517 .77959 L
s
0 0 0 r
2.5 Mabswid
.69517 .77959 Mdot
0 .038 1 r
.5 Mabswid
.65199 .59323 m
.66312 .27809 L
s
0 0 0 r
2.5 Mabswid
.66312 .27809 Mdot
0 .364 1 r
.5 Mabswid
.68239 .49168 m
.70597 .76114 L
s
0 0 0 r
2.5 Mabswid
.70597 .76114 Mdot
0 1 .532 r
.5 Mabswid
.47266 .39356 m
.70679 .65503 L
s
0 0 0 r
2.5 Mabswid
.70679 .65503 Mdot
.699 1 0 r
.5 Mabswid
.67779 .81798 m
.57838 .89181 L
s
0 0 0 r
2.5 Mabswid
.57838 .89181 Mdot
0 .272 1 r
.5 Mabswid
.5418 .48675 m
.7744 .49531 L
s
0 0 0 r
2.5 Mabswid
.7744 .49531 Mdot
.8 1 0 r
.5 Mabswid
.72624 .34262 m
.45375 .50102 L
s
0 0 0 r
2.5 Mabswid
.45375 .50102 Mdot
.746 1 0 r
.5 Mabswid
.58948 .33349 m
.56382 .33764 L
s
0 0 0 r
2.5 Mabswid
.56382 .33764 Mdot
.741 1 0 r
.5 Mabswid
.6022 .35318 m
.55218 .36133 L
s
0 0 0 r
2.5 Mabswid
.55218 .36133 Mdot
0 1 .453 r
.5 Mabswid
.44898 .55782 m
.618 .54559 L
s
0 0 0 r
2.5 Mabswid
.618 .54559 Mdot
0 .149 1 r
.5 Mabswid
.44898 .50085 m
.63114 .54737 L
s
0 0 0 r
2.5 Mabswid
.63114 .54737 Mdot
.142 1 0 r
.5 Mabswid
.44898 .56785 m
.82261 .45272 L
s
0 0 0 r
2.5 Mabswid
.82261 .45272 Mdot
.778 1 0 r
.5 Mabswid
.50407 .81438 m
.66265 .71583 L
s
0 0 0 r
2.5 Mabswid
.66265 .71583 Mdot
.797 1 0 r
.5 Mabswid
.50108 .28966 m
.6463 .25839 L
s
0 0 0 r
2.5 Mabswid
.6463 .25839 Mdot
.388 1 0 r
.5 Mabswid
.61418 .25555 m
.56667 .24262 L
s
0 0 0 r
2.5 Mabswid
.56667 .24262 Mdot
0 .538 1 r
.5 Mabswid
.56164 .77858 m
.57883 .77372 L
s
0 0 0 r
2.5 Mabswid
.57883 .77372 Mdot
0 .327 1 r
.5 Mabswid
.69517 .77959 m
.49475 .73053 L
s
0 0 0 r
2.5 Mabswid
.49475 .73053 Mdot
0 .038 1 r
.5 Mabswid
.66312 .27809 m
.52005 .28864 L
s
0 0 0 r
2.5 Mabswid
.52005 .28864 Mdot
0 .364 1 r
.5 Mabswid
.70597 .76114 m
.50128 .73159 L
s
0 0 0 r
2.5 Mabswid
.50128 .73159 Mdot
0 1 .532 r
.5 Mabswid
.70679 .65503 m
.51687 .81824 L
s
0 0 0 r
2.5 Mabswid
.51687 .81824 Mdot
.699 1 0 r
.5 Mabswid
.57838 .89181 m
.45674 .70248 L
s
0 0 0 r
2.5 Mabswid
.45674 .70248 Mdot
0 .272 1 r
.5 Mabswid
.7744 .49531 m
.86829 .52192 L
s
0 0 0 r
2.5 Mabswid
.86829 .52192 Mdot
.8 1 0 r
.5 Mabswid
.45375 .50102 m
.74626 .63573 L
s
0 0 0 r
2.5 Mabswid
.74626 .63573 Mdot
.746 1 0 r
.5 Mabswid
.56382 .33764 m
.67555 .77678 L
s
0 0 0 r
2.5 Mabswid
.67555 .77678 Mdot
.741 1 0 r
.5 Mabswid
.55218 .36133 m
.66231 .79679 L
s
0 0 0 r
2.5 Mabswid
.66231 .79679 Mdot
0 1 .453 r
.5 Mabswid
.618 .54559 m
.51314 .5688 L
s
0 0 0 r
2.5 Mabswid
.51314 .5688 Mdot
0 .149 1 r
.5 Mabswid
.63114 .54737 m
.50295 .59445 L
s
0 0 0 r
2.5 Mabswid
.50295 .59445 Mdot
.142 1 0 r
.5 Mabswid
.82261 .45272 m
.75226 .62126 L
s
0 0 0 r
2.5 Mabswid
.75226 .62126 Mdot
.778 1 0 r
.5 Mabswid
.66265 .71583 m
.52485 .27662 L
s
0 0 0 r
2.5 Mabswid
.52485 .27662 Mdot
.797 1 0 r
.5 Mabswid
.6463 .25839 m
.50474 .75283 L
s
0 0 0 r
2.5 Mabswid
.50474 .75283 Mdot
0 .542 1 r
.5 Mabswid
.56667 .24262 m
.72792 .43977 L
s
0 0 0 r
2.5 Mabswid
.72792 .43977 Mdot
0 .538 1 r
.5 Mabswid
.57883 .77372 m
.58593 .76681 L
s
0 0 0 r
2.5 Mabswid
.58593 .76681 Mdot
0 .327 1 r
.5 Mabswid
.49475 .73053 m
.73326 .59132 L
s
0 0 0 r
2.5 Mabswid
.73326 .59132 Mdot
0 .038 1 r
.5 Mabswid
.52005 .28864 m
.68624 .60826 L
s
0 0 0 r
2.5 Mabswid
.68624 .60826 Mdot
0 1 .532 r
.5 Mabswid
.51687 .81824 m
.64869 .75151 L
s
0 0 0 r
2.5 Mabswid
.64869 .75151 Mdot
.699 1 0 r
.5 Mabswid
.45674 .70248 m
.44898 .58052 L
s
0 0 0 r
2.5 Mabswid
.44898 .58052 Mdot
0 .272 1 r
.5 Mabswid
.86829 .52192 m
.47191 .78998 L
s
0 0 0 r
2.5 Mabswid
.47191 .78998 Mdot
.8 1 0 r
.5 Mabswid
.74626 .63573 m
.6516 .65909 L
s
0 0 0 r
2.5 Mabswid
.6516 .65909 Mdot
.746 1 0 r
.5 Mabswid
.67555 .77678 m
.47577 .74158 L
s
0 0 0 r
2.5 Mabswid
.47577 .74158 Mdot
.741 1 0 r
.5 Mabswid
.66231 .79679 m
.48941 .76656 L
s
0 0 0 r
2.5 Mabswid
.48941 .76656 Mdot
0 1 .453 r
.5 Mabswid
.51314 .5688 m
.47859 .60402 L
s
0 0 0 r
2.5 Mabswid
.47859 .60402 Mdot
0 .149 1 r
.5 Mabswid
.50295 .59445 m
.63975 .61398 L
s
0 0 0 r
2.5 Mabswid
.63975 .61398 Mdot
.142 1 0 r
.5 Mabswid
.75226 .62126 m
.51695 .75456 L
s
0 0 0 r
2.5 Mabswid
.51695 .75456 Mdot
.778 1 0 r
.5 Mabswid
.52485 .27662 m
.63227 .24936 L
s
0 0 0 r
2.5 Mabswid
.63227 .24936 Mdot
.797 1 0 r
.5 Mabswid
.50474 .75283 m
.6446 .80515 L
s
0 0 0 r
2.5 Mabswid
.6446 .80515 Mdot
0 .542 1 r
.5 Mabswid
.72792 .43977 m
.78818 .56637 L
s
0 0 0 r
2.5 Mabswid
.78818 .56637 Mdot
0 .538 1 r
.5 Mabswid
.58593 .76681 m
.728 .43554 L
s
0 0 0 r
2.5 Mabswid
.728 .43554 Mdot
0 .327 1 r
.5 Mabswid
.73326 .59132 m
.75541 .38359 L
s
0 0 0 r
2.5 Mabswid
.75541 .38359 Mdot
0 .038 1 r
.5 Mabswid
.68624 .60826 m
.52033 .85897 L
s
0 0 0 r
2.5 Mabswid
.52033 .85897 Mdot
0 1 .532 r
.5 Mabswid
.64869 .75151 m
.51035 .26926 L
s
0 0 0 r
2.5 Mabswid
.51035 .26926 Mdot
.699 1 0 r
.5 Mabswid
.44898 .58052 m
.46451 .33622 L
s
0 0 0 r
2.5 Mabswid
.46451 .33622 Mdot
.8 1 0 r
.5 Mabswid
.6516 .65909 m
.5458 .63856 L
s
0 0 0 r
2.5 Mabswid
.5458 .63856 Mdot
.746 1 0 r
.5 Mabswid
.47577 .74158 m
.805 .42957 L
s
0 0 0 r
2.5 Mabswid
.805 .42957 Mdot
.741 1 0 r
.5 Mabswid
.48941 .76656 m
.626 .23457 L
s
0 0 0 r
2.5 Mabswid
.626 .23457 Mdot
0 1 .453 r
.5 Mabswid
.47859 .60402 m
.63849 .57007 L
s
0 0 0 r
2.5 Mabswid
.63849 .57007 Mdot
0 .149 1 r
.5 Mabswid
.63975 .61398 m
.50253 .58863 L
s
0 0 0 r
2.5 Mabswid
.50253 .58863 Mdot
.778 1 0 r
.5 Mabswid
.63227 .24936 m
.52269 .64465 L
s
0 0 0 r
2.5 Mabswid
.52269 .64465 Mdot
.797 1 0 r
.5 Mabswid
.6446 .80515 m
.54296 .53423 L
s
0 0 0 r
2.5 Mabswid
.54296 .53423 Mdot
0 .542 1 r
.5 Mabswid
.78818 .56637 m
.78927 .67441 L
s
0 0 0 r
2.5 Mabswid
.78927 .67441 Mdot
0 .538 1 r
.5 Mabswid
.728 .43554 m
.65612 .27252 L
s
0 0 0 r
2.5 Mabswid
.65612 .27252 Mdot
0 .327 1 r
.5 Mabswid
.75541 .38359 m
.46831 .42124 L
s
0 0 0 r
2.5 Mabswid
.46831 .42124 Mdot
0 .038 1 r
.5 Mabswid
.52033 .85897 m
.66467 .81072 L
s
0 0 0 r
2.5 Mabswid
.66467 .81072 Mdot
0 1 .532 r
.5 Mabswid
.51035 .26926 m
.62732 .23141 L
s
0 0 0 r
2.5 Mabswid
.62732 .23141 Mdot
.699 1 0 r
.5 Mabswid
.46451 .33622 m
.61782 .22276 L
s
0 0 0 r
2.5 Mabswid
.61782 .22276 Mdot
.142 1 0 r
.5 Mabswid
.5458 .63856 m
.81005 .443 L
s
0 0 0 r
2.5 Mabswid
.81005 .443 Mdot
0 1 .749 r
.5 Mabswid
.805 .42957 m
.44898 .66855 L
s
0 0 0 r
2.5 Mabswid
.44898 .66855 Mdot
.741 1 0 r
.5 Mabswid
.626 .23457 m
.5174 .24355 L
s
0 0 0 r
2.5 Mabswid
.5174 .24355 Mdot
0 1 .453 r
.5 Mabswid
.63849 .57007 m
.44898 .37983 L
s
0 0 0 r
2.5 Mabswid
.44898 .37983 Mdot
0 .149 1 r
.5 Mabswid
.50253 .58863 m
.62028 .3021 L
s
0 0 0 r
2.5 Mabswid
.62028 .3021 Mdot
.778 1 0 r
.5 Mabswid
.52269 .64465 m
.62681 .69354 L
s
0 0 0 r
2.5 Mabswid
.62681 .69354 Mdot
.797 1 0 r
.5 Mabswid
.54296 .53423 m
.61244 .51382 L
s
0 0 0 r
2.5 Mabswid
.61244 .51382 Mdot
0 .542 1 r
.5 Mabswid
.78927 .67441 m
.58124 .83334 L
s
0 0 0 r
2.5 Mabswid
.58124 .83334 Mdot
0 .538 1 r
.5 Mabswid
.65612 .27252 m
.55425 .2458 L
s
0 0 0 r
2.5 Mabswid
.55425 .2458 Mdot
0 .038 1 r
.5 Mabswid
.66467 .81072 m
.57924 .38861 L
s
0 0 0 r
2.5 Mabswid
.57924 .38861 Mdot
0 1 .532 r
.5 Mabswid
.62732 .23141 m
.44898 .57154 L
s
0 0 0 r
2.5 Mabswid
.44898 .57154 Mdot
0 1 .711 r
.5 Mabswid
.61782 .22276 m
.44898 .39994 L
s
0 0 0 r
2.5 Mabswid
.44898 .39994 Mdot
.142 1 0 r
.5 Mabswid
.81005 .443 m
.47238 .72603 L
s
0 0 0 r
2.5 Mabswid
.47238 .72603 Mdot
0 1 .749 r
.5 Mabswid
.44898 .66855 m
.66842 .81584 L
s
0 0 0 r
2.5 Mabswid
.66842 .81584 Mdot
.741 1 0 r
.5 Mabswid
.5174 .24355 m
.61981 .84018 L
s
0 0 0 r
2.5 Mabswid
.61981 .84018 Mdot
0 1 .453 r
.5 Mabswid
.44898 .37983 m
.52821 .3003 L
s
0 0 0 r
2.5 Mabswid
.52821 .3003 Mdot
0 .149 1 r
.5 Mabswid
.62028 .3021 m
.53112 .33562 L
s
0 0 0 r
2.5 Mabswid
.53112 .33562 Mdot
.778 1 0 r
.5 Mabswid
.62681 .69354 m
.4629 .59428 L
s
0 0 0 r
2.5 Mabswid
.4629 .59428 Mdot
.797 1 0 r
.5 Mabswid
.61244 .51382 m
.55562 .44796 L
s
0 0 0 r
2.5 Mabswid
.55562 .44796 Mdot
0 .542 1 r
.5 Mabswid
.58124 .83334 m
.4977 .69427 L
s
0 0 0 r
2.5 Mabswid
.4977 .69427 Mdot
0 .538 1 r
.5 Mabswid
.55425 .2458 m
.70377 .41744 L
s
0 0 0 r
2.5 Mabswid
.70377 .41744 Mdot
0 .038 1 r
.5 Mabswid
.57924 .38861 m
.48004 .43912 L
s
0 0 0 r
2.5 Mabswid
.48004 .43912 Mdot
0 1 .532 r
.5 Mabswid
.44898 .57154 m
.57839 .81835 L
s
0 0 0 r
2.5 Mabswid
.57839 .81835 Mdot
0 1 .711 r
.5 Mabswid
.44898 .39994 m
.73903 .70433 L
s
0 0 0 r
2.5 Mabswid
.73903 .70433 Mdot
0 1 .381 r
.5 Mabswid
.47238 .72603 m
.69824 .75523 L
s
0 0 0 r
2.5 Mabswid
.69824 .75523 Mdot
0 .005 1 r
.5 Mabswid
.66842 .81584 m
.44898 .55996 L
s
0 0 0 r
2.5 Mabswid
.44898 .55996 Mdot
.741 1 0 r
.5 Mabswid
.61981 .84018 m
.53563 .85123 L
s
0 0 0 r
2.5 Mabswid
.53563 .85123 Mdot
0 1 .453 r
.5 Mabswid
.52821 .3003 m
.58647 .28185 L
s
0 0 0 r
2.5 Mabswid
.58647 .28185 Mdot
0 .149 1 r
.5 Mabswid
.53112 .33562 m
.65738 .83768 L
s
0 0 0 r
2.5 Mabswid
.65738 .83768 Mdot
.778 1 0 r
.5 Mabswid
.4629 .59428 m
.6371 .55756 L
s
0 0 0 r
2.5 Mabswid
.6371 .55756 Mdot
.797 1 0 r
.5 Mabswid
.55562 .44796 m
.59493 .45109 L
s
0 0 0 r
2.5 Mabswid
.59493 .45109 Mdot
0 .542 1 r
.5 Mabswid
.4977 .69427 m
.45059 .44781 L
s
0 0 0 r
2.5 Mabswid
.45059 .44781 Mdot
0 .538 1 r
.5 Mabswid
.70377 .41744 m
.76349 .62651 L
s
0 0 0 r
2.5 Mabswid
.76349 .62651 Mdot
0 .038 1 r
.5 Mabswid
.48004 .43912 m
.65939 .51462 L
s
0 0 0 r
2.5 Mabswid
.65939 .51462 Mdot
0 1 .532 r
.5 Mabswid
.57839 .81835 m
.66902 .81636 L
s
0 0 0 r
2.5 Mabswid
.66902 .81636 Mdot
0 1 .381 r
.5 Mabswid
.69824 .75523 m
.64039 .38315 L
s
0 0 0 r
2.5 Mabswid
.64039 .38315 Mdot
0 .005 1 r
.5 Mabswid
.44898 .55996 m
.68113 .28926 L
s
0 0 0 r
2.5 Mabswid
.68113 .28926 Mdot
.741 1 0 r
.5 Mabswid
.53563 .85123 m
.71335 .48434 L
s
0 0 0 r
2.5 Mabswid
.71335 .48434 Mdot
0 1 .453 r
.5 Mabswid
.58647 .28185 m
.52402 .36009 L
s
0 0 0 r
2.5 Mabswid
.52402 .36009 Mdot
0 .149 1 r
.5 Mabswid
.65738 .83768 m
.49494 .80703 L
s
0 0 0 r
2.5 Mabswid
.49494 .80703 Mdot
.333 1 0 r
.5 Mabswid
.6371 .55756 m
.44898 .40014 L
s
0 0 0 r
2.5 Mabswid
.44898 .40014 Mdot
.797 1 0 r
.5 Mabswid
.59493 .45109 m
.48105 .62741 L
s
0 0 0 r
2.5 Mabswid
.48105 .62741 Mdot
0 .542 1 r
.5 Mabswid
.45059 .44781 m
.59881 .19785 L
s
0 0 0 r
2.5 Mabswid
.59881 .19785 Mdot
0 .538 1 r
.5 Mabswid
.76349 .62651 m
.72678 .75674 L
s
0 0 0 r
2.5 Mabswid
.72678 .75674 Mdot
0 .038 1 r
.5 Mabswid
.65939 .51462 m
.49796 .80691 L
s
0 0 0 r
2.5 Mabswid
.49796 .80691 Mdot
0 1 .532 r
.5 Mabswid
.66902 .81636 m
.69936 .75853 L
s
0 0 0 r
2.5 Mabswid
.69936 .75853 Mdot
0 1 .381 r
.5 Mabswid
.64039 .38315 m
.53507 .35466 L
s
0 0 0 r
2.5 Mabswid
.53507 .35466 Mdot
.741 1 0 r
.5 Mabswid
.71335 .48434 m
.451 .40211 L
s
0 0 0 r
2.5 Mabswid
.451 .40211 Mdot
0 1 .453 r
.5 Mabswid
.52402 .36009 m
.45677 .54895 L
s
0 0 0 r
2.5 Mabswid
.45677 .54895 Mdot
0 .149 1 r
.5 Mabswid
.49494 .80703 m
.65386 .26858 L
s
0 0 0 r
2.5 Mabswid
.65386 .26858 Mdot
.333 1 0 r
.5 Mabswid
.44898 .40014 m
.60481 .26974 L
s
0 0 0 r
2.5 Mabswid
.60481 .26974 Mdot
.797 1 0 r
.5 Mabswid
.48105 .62741 m
.66185 .62423 L
s
0 0 0 r
2.5 Mabswid
.66185 .62423 Mdot
0 .542 1 r
.5 Mabswid
.59881 .19785 m
.54355 .21846 L
s
0 0 0 r
2.5 Mabswid
.54355 .21846 Mdot
0 .538 1 r
.5 Mabswid
.72678 .75674 m
.55006 .87447 L
s
0 0 0 r
2.5 Mabswid
.55006 .87447 Mdot
0 .038 1 r
.5 Mabswid
.49796 .80691 m
.66232 .77259 L
s
0 0 0 r
2.5 Mabswid
.66232 .77259 Mdot
0 1 .532 r
.5 Mabswid
.69936 .75853 m
.59602 .55802 L
s
0 0 0 r
2.5 Mabswid
.59602 .55802 Mdot
0 1 .381 r
.5 Mabswid
.53507 .35466 m
.73364 .5498 L
s
0 0 0 r
2.5 Mabswid
.73364 .5498 Mdot
.741 1 0 r
.5 Mabswid
.451 .40211 m
.71374 .46526 L
s
0 0 0 r
2.5 Mabswid
.71374 .46526 Mdot
0 1 .453 r
.5 Mabswid
.45677 .54895 m
.47761 .7679 L
s
0 0 0 r
2.5 Mabswid
.47761 .7679 Mdot
0 .149 1 r
.5 Mabswid
.65386 .26858 m
.47903 .29421 L
s
0 0 0 r
2.5 Mabswid
.47903 .29421 Mdot
.333 1 0 r
.5 Mabswid
.60481 .26974 m
.5055 .33942 L
s
0 0 0 r
2.5 Mabswid
.5055 .33942 Mdot
.797 1 0 r
.5 Mabswid
.66185 .62423 m
.49628 .48512 L
s
0 0 0 r
2.5 Mabswid
.49628 .48512 Mdot
0 .542 1 r
.5 Mabswid
.54355 .21846 m
.54184 .64296 L
s
0 0 0 r
2.5 Mabswid
.54184 .64296 Mdot
0 .538 1 r
.5 Mabswid
.55006 .87447 m
.63334 .8237 L
s
0 0 0 r
2.5 Mabswid
.63334 .8237 Mdot
0 .038 1 r
.5 Mabswid
.66232 .77259 m
.56211 .21164 L
s
0 0 0 r
2.5 Mabswid
.56211 .21164 Mdot
0 1 .532 r
.5 Mabswid
.59602 .55802 m
.58082 .53998 L
s
0 0 0 r
2.5 Mabswid
.58082 .53998 Mdot
0 1 .381 r
.5 Mabswid
.73364 .5498 m
.46819 .73692 L
s
0 0 0 r
2.5 Mabswid
.46819 .73692 Mdot
.741 1 0 r
.5 Mabswid
.71374 .46526 m
.44898 .68159 L
s
0 0 0 r
2.5 Mabswid
.44898 .68159 Mdot
0 1 .453 r
.5 Mabswid
.47761 .7679 m
.61347 .89434 L
s
0 0 0 r
2.5 Mabswid
.61347 .89434 Mdot
0 .149 1 r
.5 Mabswid
.47903 .29421 m
.76543 .66117 L
s
0 0 0 r
2.5 Mabswid
.76543 .66117 Mdot
.333 1 0 r
.5 Mabswid
.5055 .33942 m
.44898 .52867 L
s
0 0 0 r
2.5 Mabswid
.44898 .52867 Mdot
.797 1 0 r
.5 Mabswid
.49628 .48512 m
.6575 .50011 L
s
0 0 0 r
2.5 Mabswid
.6575 .50011 Mdot
0 .542 1 r
.5 Mabswid
.54184 .64296 m
.59909 .70239 L
s
0 0 0 r
2.5 Mabswid
.59909 .70239 Mdot
0 .538 1 r
.5 Mabswid
.63334 .8237 m
.71726 .3792 L
s
0 0 0 r
2.5 Mabswid
.71726 .3792 Mdot
0 .038 1 r
.5 Mabswid
.56211 .21164 m
.59138 .21023 L
s
0 0 0 r
2.5 Mabswid
.59138 .21023 Mdot
0 1 .532 r
.5 Mabswid
.58082 .53998 m
.50379 .48271 L
s
0 0 0 r
2.5 Mabswid
.50379 .48271 Mdot
0 1 .381 r
.5 Mabswid
.46819 .73692 m
.71058 .77495 L
s
0 0 0 r
2.5 Mabswid
.71058 .77495 Mdot
.741 1 0 r
.5 Mabswid
.44898 .68159 m
.65357 .84877 L
s
0 0 0 r
2.5 Mabswid
.65357 .84877 Mdot
0 1 .643 r
.5 Mabswid
.61347 .89434 m
.46234 .7654 L
s
0 0 0 r
2.5 Mabswid
.46234 .7654 Mdot
0 .149 1 r
.5 Mabswid
.76543 .66117 m
.46652 .7063 L
s
0 0 0 r
2.5 Mabswid
.46652 .7063 Mdot
.333 1 0 r
.5 Mabswid
.44898 .52867 m
.55783 .89315 L
s
0 0 0 r
2.5 Mabswid
.55783 .89315 Mdot
.797 1 0 r
.5 Mabswid
.6575 .50011 m
.53787 .68735 L
s
0 0 0 r
2.5 Mabswid
.53787 .68735 Mdot
0 .542 1 r
.5 Mabswid
.59909 .70239 m
.45369 .7497 L
s
0 0 0 r
2.5 Mabswid
.45369 .7497 Mdot
0 .538 1 r
.5 Mabswid
.71726 .3792 m
.47578 .30762 L
s
0 0 0 r
2.5 Mabswid
.47578 .30762 Mdot
0 .038 1 r
.5 Mabswid
.59138 .21023 m
.53403 .80936 L
s
0 0 0 r
2.5 Mabswid
.53403 .80936 Mdot
0 1 .532 r
.5 Mabswid
.50379 .48271 m
.44898 .41582 L
s
0 0 0 r
2.5 Mabswid
.44898 .41582 Mdot
0 1 .381 r
.5 Mabswid
.71058 .77495 m
.54979 .34475 L
s
0 0 0 r
2.5 Mabswid
.54979 .34475 Mdot
.741 1 0 r
.5 Mabswid
.65357 .84877 m
.45459 .65435 L
s
0 0 0 r
2.5 Mabswid
.45459 .65435 Mdot
0 1 .643 r
.5 Mabswid
.46234 .7654 m
.44898 .69091 L
s
0 0 0 r
2.5 Mabswid
.44898 .69091 Mdot
0 .149 1 r
.5 Mabswid
.46652 .7063 m
.69814 .61676 L
s
0 0 0 r
2.5 Mabswid
.69814 .61676 Mdot
.333 1 0 r
.5 Mabswid
.55783 .89315 m
.5836 .90837 L
s
0 0 0 r
2.5 Mabswid
.5836 .90837 Mdot
.797 1 0 r
.5 Mabswid
.53787 .68735 m
.61185 .68691 L
s
0 0 0 r
2.5 Mabswid
.61185 .68691 Mdot
0 .542 1 r
.5 Mabswid
.45369 .7497 m
.61987 .66986 L
s
0 0 0 r
2.5 Mabswid
.61987 .66986 Mdot
0 .538 1 r
.5 Mabswid
.47578 .30762 m
.79748 .63797 L
s
0 0 0 r
2.5 Mabswid
.79748 .63797 Mdot
0 .038 1 r
.5 Mabswid
.53403 .80936 m
.61489 .81994 L
s
0 0 0 r
2.5 Mabswid
.61489 .81994 Mdot
0 1 .532 r
.5 Mabswid
.44898 .41582 m
.54914 .29357 L
s
0 0 0 r
2.5 Mabswid
.54914 .29357 Mdot
0 1 .381 r
.5 Mabswid
.54979 .34475 m
.61587 .32288 L
s
0 0 0 r
2.5 Mabswid
.61587 .32288 Mdot
.741 1 0 r
.5 Mabswid
.45459 .65435 m
.60363 .34241 L
s
0 0 0 r
2.5 Mabswid
.60363 .34241 Mdot
0 1 .643 r
.5 Mabswid
.44898 .69091 m
.52363 .27451 L
s
0 0 0 r
2.5 Mabswid
.52363 .27451 Mdot
0 .149 1 r
.5 Mabswid
.69814 .61676 m
.54605 .29454 L
s
0 0 0 r
2.5 Mabswid
.54605 .29454 Mdot
.333 1 0 r
.5 Mabswid
.5836 .90837 m
.44898 .72344 L
s
0 0 0 r
2.5 Mabswid
.44898 .72344 Mdot
.797 1 0 r
.5 Mabswid
.61185 .68691 m
.44898 .46184 L
s
0 0 0 r
2.5 Mabswid
.44898 .46184 Mdot
0 .542 1 r
.5 Mabswid
.61987 .66986 m
.50148 .61072 L
s
0 0 0 r
2.5 Mabswid
.50148 .61072 Mdot
0 .538 1 r
.5 Mabswid
.79748 .63797 m
.55915 .78522 L
s
0 0 0 r
2.5 Mabswid
.55915 .78522 Mdot
0 .038 1 r
.5 Mabswid
.61489 .81994 m
.49835 .34312 L
s
0 0 0 r
2.5 Mabswid
.49835 .34312 Mdot
0 1 .532 r
.5 Mabswid
.54914 .29357 m
.58561 .29215 L
s
0 0 0 r
2.5 Mabswid
.58561 .29215 Mdot
0 1 .381 r
.5 Mabswid
.61587 .32288 m
.65442 .37548 L
s
0 0 0 r
2.5 Mabswid
.65442 .37548 Mdot
.741 1 0 r
.5 Mabswid
.60363 .34241 m
.52742 .31274 L
s
0 0 0 r
2.5 Mabswid
.52742 .31274 Mdot
0 1 .643 r
.5 Mabswid
.52363 .27451 m
.59993 .22282 L
s
0 0 0 r
2.5 Mabswid
.59993 .22282 Mdot
0 .149 1 r
.5 Mabswid
.54605 .29454 m
.61456 .31502 L
s
0 0 0 r
2.5 Mabswid
.61456 .31502 Mdot
.333 1 0 r
.5 Mabswid
.44898 .72344 m
.66854 .42182 L
s
0 0 0 r
2.5 Mabswid
.66854 .42182 Mdot
.797 1 0 r
.5 Mabswid
.44898 .46184 m
.48273 .4152 L
s
0 0 0 r
2.5 Mabswid
.48273 .4152 Mdot
0 .542 1 r
.5 Mabswid
.50148 .61072 m
.47079 .32922 L
s
0 0 0 r
2.5 Mabswid
.47079 .32922 Mdot
0 .038 1 r
.5 Mabswid
.49835 .34312 m
.65988 .35409 L
s
0 0 0 r
2.5 Mabswid
.65988 .35409 Mdot
0 .829 1 r
.5 Mabswid
.58561 .29215 m
.49234 .38655 L
s
0 0 0 r
2.5 Mabswid
.49234 .38655 Mdot
0 1 .381 r
.5 Mabswid
.65442 .37548 m
.51872 .47044 L
s
0 0 0 r
2.5 Mabswid
.51872 .47044 Mdot
.741 1 0 r
.5 Mabswid
.52742 .31274 m
.54488 .45182 L
s
0 0 0 r
2.5 Mabswid
.54488 .45182 Mdot
0 .439 1 r
.5 Mabswid
.59993 .22282 m
.44898 .39943 L
s
0 0 0 r
2.5 Mabswid
.44898 .39943 Mdot
0 .149 1 r
.5 Mabswid
.61456 .31502 m
.53039 .84457 L
s
0 0 0 r
2.5 Mabswid
.53039 .84457 Mdot
.045 1 0 r
.5 Mabswid
.66854 .42182 m
.44898 .4169 L
s
0 0 0 r
2.5 Mabswid
.44898 .4169 Mdot
.797 1 0 r
.5 Mabswid
.48273 .4152 m
.59963 .36718 L
s
0 0 0 r
2.5 Mabswid
.59963 .36718 Mdot
0 .542 1 r
.5 Mabswid
.47079 .32922 m
.65128 .31759 L
s
0 0 0 r
2.5 Mabswid
.65128 .31759 Mdot
0 .038 1 r
.5 Mabswid
.65988 .35409 m
.57792 .77108 L
s
0 0 0 r
2.5 Mabswid
.57792 .77108 Mdot
0 .829 1 r
.5 Mabswid
.49234 .38655 m
.44898 .49607 L
s
0 0 0 r
2.5 Mabswid
.44898 .49607 Mdot
0 1 .381 r
.5 Mabswid
.51872 .47044 m
.66609 .78835 L
s
0 0 0 r
2.5 Mabswid
.66609 .78835 Mdot
.741 1 0 r
.5 Mabswid
.54488 .45182 m
.58757 .47704 L
s
0 0 0 r
2.5 Mabswid
.58757 .47704 Mdot
0 .439 1 r
.5 Mabswid
.44898 .39943 m
.7365 .73582 L
s
0 0 0 r
2.5 Mabswid
.7365 .73582 Mdot
0 .149 1 r
.5 Mabswid
.53039 .84457 m
.6122 .85558 L
s
0 0 0 r
2.5 Mabswid
.6122 .85558 Mdot
.045 1 0 r
.5 Mabswid
.44898 .4169 m
.76144 .40989 L
s
0 0 0 r
2.5 Mabswid
.76144 .40989 Mdot
0 1 .522 r
.5 Mabswid
.59963 .36718 m
.45449 .45486 L
s
0 0 0 r
2.5 Mabswid
.45449 .45486 Mdot
0 .542 1 r
.5 Mabswid
.65128 .31759 m
.45957 .7311 L
s
0 0 0 r
2.5 Mabswid
.45957 .7311 Mdot
0 .829 1 r
.5 Mabswid
.44898 .49607 m
.59837 .8735 L
s
0 0 0 r
2.5 Mabswid
.59837 .8735 Mdot
0 1 .381 r
.5 Mabswid
.66609 .78835 m
.5149 .83292 L
s
0 0 0 r
2.5 Mabswid
.5149 .83292 Mdot
.741 1 0 r
.5 Mabswid
.58757 .47704 m
.47212 .62903 L
s
0 0 0 r
2.5 Mabswid
.47212 .62903 Mdot
0 .149 1 r
.5 Mabswid
.6122 .85558 m
.44898 .46191 L
s
0 0 0 r
2.5 Mabswid
.44898 .46191 Mdot
.045 1 0 r
.5 Mabswid
.76144 .40989 m
.58457 .88594 L
s
0 0 0 r
2.5 Mabswid
.58457 .88594 Mdot
0 1 .522 r
.5 Mabswid
.45449 .45486 m
.46734 .72933 L
s
0 0 0 r
2.5 Mabswid
.46734 .72933 Mdot
0 .542 1 r
.5 Mabswid
.45957 .7311 m
.62779 .8755 L
s
0 0 0 r
2.5 Mabswid
.62779 .8755 Mdot
0 .829 1 r
.5 Mabswid
.59837 .8735 m
.54774 .863 L
s
0 0 0 r
2.5 Mabswid
.54774 .863 Mdot
0 1 .381 r
.5 Mabswid
.5149 .83292 m
.67232 .68834 L
s
0 0 0 r
2.5 Mabswid
.67232 .68834 Mdot
.741 1 0 r
.5 Mabswid
.47212 .62903 m
.45381 .75 L
s
0 0 0 r
2.5 Mabswid
.45381 .75 Mdot
0 .149 1 r
.5 Mabswid
.44898 .46191 m
.53997 .24245 L
s
0 0 0 r
2.5 Mabswid
.53997 .24245 Mdot
.045 1 0 r
.5 Mabswid
.58457 .88594 m
.57903 .88989 L
s
0 0 0 r
2.5 Mabswid
.57903 .88989 Mdot
0 1 .522 r
.5 Mabswid
.46734 .72933 m
.59031 .81383 L
s
0 0 0 r
2.5 Mabswid
.59031 .81383 Mdot
0 .542 1 r
.5 Mabswid
.62779 .8755 m
.47237 .73154 L
s
0 0 0 r
2.5 Mabswid
.47237 .73154 Mdot
0 .829 1 r
.5 Mabswid
.54774 .863 m
.64597 .26663 L
s
0 0 0 r
2.5 Mabswid
.64597 .26663 Mdot
0 1 .381 r
.5 Mabswid
.67232 .68834 m
.58713 .25072 L
s
0 0 0 r
2.5 Mabswid
.58713 .25072 Mdot
.741 1 0 r
.5 Mabswid
.45381 .75 m
.58406 .85069 L
s
0 0 0 r
2.5 Mabswid
.58406 .85069 Mdot
0 .149 1 r
.5 Mabswid
.53997 .24245 m
.58441 .20618 L
s
0 0 0 r
2.5 Mabswid
.58441 .20618 Mdot
.045 1 0 r
.5 Mabswid
.57903 .88989 m
.56396 .88745 L
s
0 0 0 r
2.5 Mabswid
.56396 .88745 Mdot
0 .2 1 r
.5 Mabswid
.59031 .81383 m
.53467 .76871 L
s
0 0 0 r
2.5 Mabswid
.53467 .76871 Mdot
0 .542 1 r
.5 Mabswid
.47237 .73154 m
.63803 .44552 L
s
0 0 0 r
2.5 Mabswid
.63803 .44552 Mdot
0 .829 1 r
.5 Mabswid
.64597 .26663 m
.51553 .27849 L
s
0 0 0 r
2.5 Mabswid
.51553 .27849 Mdot
0 1 .381 r
.5 Mabswid
.58713 .25072 m
.57089 .23867 L
s
0 0 0 r
2.5 Mabswid
.57089 .23867 Mdot
.741 1 0 r
.5 Mabswid
.58406 .85069 m
.55898 .83206 L
s
0 0 0 r
2.5 Mabswid
.55898 .83206 Mdot
.045 1 0 r
.5 Mabswid
.56396 .88745 m
.46028 .70222 L
s
0 0 0 r
2.5 Mabswid
.46028 .70222 Mdot
0 .2 1 r
.5 Mabswid
.53467 .76871 m
.44898 .54369 L
s
0 0 0 r
2.5 Mabswid
.44898 .54369 Mdot
0 .542 1 r
.5 Mabswid
.63803 .44552 m
.51413 .30466 L
s
0 0 0 r
2.5 Mabswid
.51413 .30466 Mdot
0 .829 1 r
.5 Mabswid
.51553 .27849 m
.70201 .79329 L
s
0 0 0 r
2.5 Mabswid
.70201 .79329 Mdot
0 1 .381 r
.5 Mabswid
.57089 .23867 m
.57052 .23861 L
s
0 0 0 r
2.5 Mabswid
.57052 .23861 Mdot
.741 1 0 r
.5 Mabswid
.55898 .83206 m
.47208 .44465 L
s
0 0 0 r
2.5 Mabswid
.47208 .44465 Mdot
.045 1 0 r
.5 Mabswid
.46028 .70222 m
.57793 .47815 L
s
0 0 0 r
2.5 Mabswid
.57793 .47815 Mdot
0 .2 1 r
.5 Mabswid
.44898 .54369 m
.58335 .19086 L
s
0 0 0 r
2.5 Mabswid
.58335 .19086 Mdot
0 .542 1 r
.5 Mabswid
.51413 .30466 m
.69212 .32751 L
s
0 0 0 r
2.5 Mabswid
.69212 .32751 Mdot
0 .829 1 r
.5 Mabswid
.70201 .79329 m
.4606 .74689 L
s
0 0 0 r
2.5 Mabswid
.4606 .74689 Mdot
0 1 .381 r
.5 Mabswid
.57052 .23861 m
.50942 .38515 L
s
0 0 0 r
2.5 Mabswid
.50942 .38515 Mdot
.741 1 0 r
.5 Mabswid
.47208 .44465 m
.5901 .20191 L
s
0 0 0 r
2.5 Mabswid
.5901 .20191 Mdot
.045 1 0 r
.5 Mabswid
.57793 .47815 m
.71299 .33257 L
s
0 0 0 r
2.5 Mabswid
.71299 .33257 Mdot
0 .2 1 r
.5 Mabswid
.58335 .19086 m
.56569 .1961 L
s
0 0 0 r
2.5 Mabswid
.56569 .1961 Mdot
0 .542 1 r
.5 Mabswid
.69212 .32751 m
.55225 .65139 L
s
0 0 0 r
2.5 Mabswid
.55225 .65139 Mdot
0 .829 1 r
.5 Mabswid
.4606 .74689 m
.62463 .2591 L
s
0 0 0 r
2.5 Mabswid
.62463 .2591 Mdot
0 1 .381 r
.5 Mabswid
.50942 .38515 m
.63222 .47497 L
s
0 0 0 r
2.5 Mabswid
.63222 .47497 Mdot
.741 1 0 r
.5 Mabswid
.5901 .20191 m
.54766 .21347 L
s
0 0 0 r
2.5 Mabswid
.54766 .21347 Mdot
.045 1 0 r
.5 Mabswid
.71299 .33257 m
.63673 .37944 L
s
0 0 0 r
2.5 Mabswid
.63673 .37944 Mdot
0 .2 1 r
.5 Mabswid
.56569 .1961 m
.52496 .83915 L
s
0 0 0 r
2.5 Mabswid
.52496 .83915 Mdot
0 .542 1 r
.5 Mabswid
.55225 .65139 m
.61109 .69897 L
s
0 0 0 r
2.5 Mabswid
.61109 .69897 Mdot
0 .829 1 r
.5 Mabswid
.62463 .2591 m
.52417 .25203 L
s
0 0 0 r
2.5 Mabswid
.52417 .25203 Mdot
0 1 .381 r
.5 Mabswid
.63222 .47497 m
.48177 .80225 L
s
0 0 0 r
2.5 Mabswid
.48177 .80225 Mdot
.741 1 0 r
.5 Mabswid
.54766 .21347 m
.47818 .4577 L
s
0 0 0 r
2.5 Mabswid
.47818 .4577 Mdot
.045 1 0 r
.5 Mabswid
.63673 .37944 m
.55537 .42366 L
s
0 0 0 r
2.5 Mabswid
.55537 .42366 Mdot
0 .2 1 r
.5 Mabswid
.52496 .83915 m
.61234 .87508 L
s
0 0 0 r
2.5 Mabswid
.61234 .87508 Mdot
0 .542 1 r
.5 Mabswid
.61109 .69897 m
.5397 .78907 L
s
0 0 0 r
2.5 Mabswid
.5397 .78907 Mdot
0 .829 1 r
.5 Mabswid
.52417 .25203 m
.61757 .56692 L
s
0 0 0 r
2.5 Mabswid
.61757 .56692 Mdot
0 1 .381 r
.5 Mabswid
.48177 .80225 m
.61836 .84469 L
s
0 0 0 r
2.5 Mabswid
.61836 .84469 Mdot
.741 1 0 r
.5 Mabswid
.47818 .4577 m
.60924 .69704 L
s
0 0 0 r
2.5 Mabswid
.60924 .69704 Mdot
.045 1 0 r
.5 Mabswid
.55537 .42366 m
.64503 .52347 L
s
0 0 0 r
2.5 Mabswid
.64503 .52347 Mdot
0 .2 1 r
.5 Mabswid
.61234 .87508 m
.44898 .56155 L
s
0 0 0 r
2.5 Mabswid
.44898 .56155 Mdot
0 .542 1 r
.5 Mabswid
.5397 .78907 m
.61304 .76297 L
s
0 0 0 r
2.5 Mabswid
.61304 .76297 Mdot
0 .829 1 r
.5 Mabswid
.61757 .56692 m
.53028 .60651 L
s
0 0 0 r
2.5 Mabswid
.53028 .60651 Mdot
0 1 .381 r
.5 Mabswid
.61836 .84469 m
.47509 .68268 L
s
0 0 0 r
2.5 Mabswid
.47509 .68268 Mdot
.741 1 0 r
.5 Mabswid
.60924 .69704 m
.50173 .72783 L
s
0 0 0 r
2.5 Mabswid
.50173 .72783 Mdot
.045 1 0 r
.5 Mabswid
.64503 .52347 m
.70812 .69449 L
s
0 0 0 r
2.5 Mabswid
.70812 .69449 Mdot
0 .2 1 r
.5 Mabswid
.44898 .56155 m
.60176 .26833 L
s
0 0 0 r
2.5 Mabswid
.60176 .26833 Mdot
0 .542 1 r
.5 Mabswid
.61304 .76297 m
.53726 .23084 L
s
0 0 0 r
2.5 Mabswid
.53726 .23084 Mdot
0 .829 1 r
.5 Mabswid
.53028 .60651 m
.57306 .76607 L
s
0 0 0 r
2.5 Mabswid
.57306 .76607 Mdot
0 1 .381 r
.5 Mabswid
.47509 .68268 m
.55371 .20819 L
s
0 0 0 r
2.5 Mabswid
.55371 .20819 Mdot
.741 1 0 r
.5 Mabswid
.50173 .72783 m
.45211 .74575 L
s
0 0 0 r
2.5 Mabswid
.45211 .74575 Mdot
.045 1 0 r
.5 Mabswid
.70812 .69449 m
.7061 .76519 L
s
0 0 0 r
2.5 Mabswid
.7061 .76519 Mdot
.2 0 1 r
.5 Mabswid
.60176 .26833 m
.53122 .28438 L
s
0 0 0 r
2.5 Mabswid
.53122 .28438 Mdot
0 .542 1 r
.5 Mabswid
.53726 .23084 m
.61477 .23305 L
s
0 0 0 r
2.5 Mabswid
.61477 .23305 Mdot
0 1 .381 r
.5 Mabswid
.55371 .20819 m
.58857 .19171 L
s
0 0 0 r
2.5 Mabswid
.58857 .19171 Mdot
.741 1 0 r
.5 Mabswid
.45211 .74575 m
.46082 .7419 L
s
0 0 0 r
2.5 Mabswid
.46082 .7419 Mdot
.045 1 0 r
.5 Mabswid
.7061 .76519 m
.65933 .83415 L
s
0 0 0 r
2.5 Mabswid
.65933 .83415 Mdot
.2 0 1 r
.5 Mabswid
.53122 .28438 m
.44898 .65764 L
s
0 0 0 r
2.5 Mabswid
.44898 .65764 Mdot
0 .542 1 r
.5 Mabswid
.61477 .23305 m
.53477 .8179 L
s
0 0 0 r
2.5 Mabswid
.53477 .8179 Mdot
0 1 .381 r
.5 Mabswid
.58857 .19171 m
.46145 .41889 L
s
0 0 0 r
2.5 Mabswid
.46145 .41889 Mdot
.741 1 0 r
.5 Mabswid
.46082 .7419 m
.47836 .73319 L
s
0 0 0 r
2.5 Mabswid
.47836 .73319 Mdot
.045 1 0 r
.5 Mabswid
.65933 .83415 m
.56482 .86608 L
s
0 0 0 r
2.5 Mabswid
.56482 .86608 Mdot
.2 0 1 r
.5 Mabswid
.44898 .65764 m
.45247 .67345 L
s
0 0 0 r
2.5 Mabswid
.45247 .67345 Mdot
0 .542 1 r
.5 Mabswid
.53477 .8179 m
.61861 .84064 L
s
0 0 0 r
2.5 Mabswid
.61861 .84064 Mdot
0 1 .381 r
.5 Mabswid
.46145 .41889 m
.53392 .67261 L
s
0 0 0 r
2.5 Mabswid
.53392 .67261 Mdot
.741 1 0 r
.5 Mabswid
.47836 .73319 m
.47999 .73241 L
s
0 0 0 r
2.5 Mabswid
.47999 .73241 Mdot
.045 1 0 r
.5 Mabswid
.56482 .86608 m
.61938 .81235 L
s
0 0 0 r
2.5 Mabswid
.61938 .81235 Mdot
.2 0 1 r
.5 Mabswid
.45247 .67345 m
.57603 .81483 L
s
0 0 0 r
2.5 Mabswid
.57603 .81483 Mdot
0 .542 1 r
.5 Mabswid
.61861 .84064 m
.55027 .52407 L
s
0 0 0 r
2.5 Mabswid
.55027 .52407 Mdot
0 1 .381 r
.5 Mabswid
.53392 .67261 m
.58436 .73672 L
s
0 0 0 r
2.5 Mabswid
.58436 .73672 Mdot
.741 1 0 r
.5 Mabswid
.47999 .73241 m
.60994 .68827 L
s
0 0 0 r
2.5 Mabswid
.60994 .68827 Mdot
.045 1 0 r
.5 Mabswid
.61938 .81235 m
.7175 .5643 L
s
0 0 0 r
2.5 Mabswid
.7175 .5643 Mdot
.2 0 1 r
.5 Mabswid
.57603 .81483 m
.74254 .74276 L
s
0 0 0 r
2.5 Mabswid
.74254 .74276 Mdot
0 .542 1 r
.5 Mabswid
.55027 .52407 m
.60147 .50473 L
s
0 0 0 r
2.5 Mabswid
.60147 .50473 Mdot
0 1 .381 r
.5 Mabswid
.58436 .73672 m
.53335 .7467 L
s
0 0 0 r
2.5 Mabswid
.53335 .7467 Mdot
.741 1 0 r
.5 Mabswid
.60994 .68827 m
.46739 .53501 L
s
0 0 0 r
2.5 Mabswid
.46739 .53501 Mdot
.045 1 0 r
.5 Mabswid
.7175 .5643 m
.72105 .51831 L
s
0 0 0 r
2.5 Mabswid
.72105 .51831 Mdot
.2 0 1 r
.5 Mabswid
.74254 .74276 m
.77385 .70158 L
s
0 0 0 r
2.5 Mabswid
.77385 .70158 Mdot
0 .542 1 r
.5 Mabswid
.60147 .50473 m
.51487 .40396 L
s
0 0 0 r
2.5 Mabswid
.51487 .40396 Mdot
0 1 .381 r
.5 Mabswid
.53335 .7467 m
.46702 .74924 L
s
0 0 0 r
2.5 Mabswid
.46702 .74924 Mdot
.741 1 0 r
.5 Mabswid
.46739 .53501 m
.55882 .21278 L
s
0 0 0 r
2.5 Mabswid
.55882 .21278 Mdot
.045 1 0 r
.5 Mabswid
.72105 .51831 m
.72046 .47572 L
s
0 0 0 r
2.5 Mabswid
.72046 .47572 Mdot
.2 0 1 r
.5 Mabswid
.77385 .70158 m
.77865 .62017 L
s
0 0 0 r
2.5 Mabswid
.77865 .62017 Mdot
0 .542 1 r
.5 Mabswid
.51487 .40396 m
.62881 .41854 L
s
0 0 0 r
2.5 Mabswid
.62881 .41854 Mdot
0 1 .381 r
.5 Mabswid
.46702 .74924 m
.44898 .73214 L
s
0 0 0 r
2.5 Mabswid
.44898 .73214 Mdot
.741 1 0 r
.5 Mabswid
.55882 .21278 m
.58457 .2056 L
s
0 0 0 r
2.5 Mabswid
.58457 .2056 Mdot
.045 1 0 r
.5 Mabswid
.72046 .47572 m
.7126 .41484 L
s
0 0 0 r
2.5 Mabswid
.7126 .41484 Mdot
.2 0 1 r
.5 Mabswid
.77865 .62017 m
.66948 .40497 L
s
0 0 0 r
2.5 Mabswid
.66948 .40497 Mdot
0 .542 1 r
.5 Mabswid
.62881 .41854 m
.48886 .81276 L
s
0 0 0 r
2.5 Mabswid
.48886 .81276 Mdot
0 1 .381 r
.5 Mabswid
.44898 .73214 m
.48436 .69861 L
s
0 0 0 r
2.5 Mabswid
.48436 .69861 Mdot
.741 1 0 r
.5 Mabswid
.58457 .2056 m
.49553 .38745 L
s
0 0 0 r
2.5 Mabswid
.49553 .38745 Mdot
.045 1 0 r
.5 Mabswid
.7126 .41484 m
.70414 .37922 L
s
0 0 0 r
2.5 Mabswid
.70414 .37922 Mdot
.2 0 1 r
.5 Mabswid
.66948 .40497 m
.55568 .2985 L
s
0 0 0 r
2.5 Mabswid
.55568 .2985 Mdot
0 .542 1 r
.5 Mabswid
.48886 .81276 m
.67015 .80596 L
s
0 0 0 r
2.5 Mabswid
.67015 .80596 Mdot
0 1 .381 r
.5 Mabswid
.48436 .69861 m
.61528 .64504 L
s
0 0 0 r
2.5 Mabswid
.61528 .64504 Mdot
.741 1 0 r
.5 Mabswid
.49553 .38745 m
.59092 .83079 L
s
0 0 0 r
2.5 Mabswid
.59092 .83079 Mdot
.045 1 0 r
.5 Mabswid
.70414 .37922 m
.56618 .18255 L
s
0 0 0 r
2.5 Mabswid
.56618 .18255 Mdot
0 .542 1 r
.5 Mabswid
.67015 .80596 m
.53669 .23051 L
s
0 0 0 r
2.5 Mabswid
.53669 .23051 Mdot
0 1 .381 r
.5 Mabswid
.61528 .64504 m
.44898 .49844 L
s
0 0 0 r
2.5 Mabswid
.44898 .49844 Mdot
.741 1 0 r
.5 Mabswid
.59092 .83079 m
.5581 .83794 L
s
0 0 0 r
2.5 Mabswid
.5581 .83794 Mdot
.045 1 0 r
.5 Mabswid
.56618 .18255 m
.58995 .19135 L
s
0 0 0 r
2.5 Mabswid
.58995 .19135 Mdot
0 .542 1 r
.5 Mabswid
.53669 .23051 m
.62343 .23118 L
s
0 0 0 r
2.5 Mabswid
.62343 .23118 Mdot
0 1 .381 r
.5 Mabswid
.44898 .49844 m
.67803 .29651 L
s
0 0 0 r
2.5 Mabswid
.67803 .29651 Mdot
.741 1 0 r
.5 Mabswid
.5581 .83794 m
.57054 .56769 L
s
0 0 0 r
2.5 Mabswid
.57054 .56769 Mdot
.045 1 0 r
.5 Mabswid
.58995 .19135 m
.60202 .587 L
s
0 0 0 r
2.5 Mabswid
.60202 .587 Mdot
0 .542 1 r
.5 Mabswid
.62343 .23118 m
.60111 .80559 L
s
0 0 0 r
2.5 Mabswid
.60111 .80559 Mdot
0 1 .381 r
.5 Mabswid
.67803 .29651 m
.44898 .50155 L
s
0 0 0 r
2.5 Mabswid
.44898 .50155 Mdot
.741 1 0 r
.5 Mabswid
.57054 .56769 m
.57105 .56734 L
s
0 0 0 r
2.5 Mabswid
.57105 .56734 Mdot
.045 1 0 r
.5 Mabswid
.60202 .587 m
.55468 .62629 L
s
0 0 0 r
2.5 Mabswid
.55468 .62629 Mdot
0 .542 1 r
.5 Mabswid
.60111 .80559 m
.55773 .81349 L
s
0 0 0 r
2.5 Mabswid
.55773 .81349 Mdot
0 1 .381 r
.5 Mabswid
.44898 .50155 m
.64756 .67931 L
s
0 0 0 r
2.5 Mabswid
.64756 .67931 Mdot
.741 1 0 r
.5 Mabswid
.57105 .56734 m
.58433 .55718 L
s
0 0 0 r
2.5 Mabswid
.58433 .55718 Mdot
.045 1 0 r
.5 Mabswid
.55468 .62629 m
.6408 .85206 L
s
0 0 0 r
2.5 Mabswid
.6408 .85206 Mdot
0 .542 1 r
.5 Mabswid
.55773 .81349 m
.73378 .39222 L
s
0 0 0 r
2.5 Mabswid
.73378 .39222 Mdot
0 1 .381 r
.5 Mabswid
.64756 .67931 m
.44898 .73307 L
s
0 0 0 r
2.5 Mabswid
.44898 .73307 Mdot
.741 1 0 r
.5 Mabswid
.58433 .55718 m
.61951 .23443 L
s
0 0 0 r
2.5 Mabswid
.61951 .23443 Mdot
.045 1 0 r
.5 Mabswid
.6408 .85206 m
.5231 .80467 L
s
0 0 0 r
2.5 Mabswid
.5231 .80467 Mdot
0 .542 1 r
.5 Mabswid
.73378 .39222 m
.44898 .4627 L
s
0 0 0 r
2.5 Mabswid
.44898 .4627 Mdot
0 1 .381 r
.5 Mabswid
.44898 .73307 m
.65326 .78839 L
s
0 0 0 r
2.5 Mabswid
.65326 .78839 Mdot
.741 1 0 r
.5 Mabswid
.61951 .23443 m
.54231 .21677 L
s
0 0 0 r
2.5 Mabswid
.54231 .21677 Mdot
.045 1 0 r
.5 Mabswid
.5231 .80467 m
.63561 .44207 L
s
0 0 0 r
2.5 Mabswid
.63561 .44207 Mdot
0 1 .381 r
.5 Mabswid
.65326 .78839 m
.45504 .5364 L
s
0 0 0 r
2.5 Mabswid
.45504 .5364 Mdot
.741 1 0 r
.5 Mabswid
.54231 .21677 m
.67573 .44868 L
s
0 0 0 r
2.5 Mabswid
.67573 .44868 Mdot
.045 1 0 r
.5 Mabswid
.63561 .44207 m
.51532 .3266 L
s
0 0 0 r
2.5 Mabswid
.51532 .3266 Mdot
0 1 .381 r
.5 Mabswid
.45504 .5364 m
.63768 .25329 L
s
0 0 0 r
2.5 Mabswid
.63768 .25329 Mdot
.741 1 0 r
.5 Mabswid
.67573 .44868 m
.54148 .77463 L
s
0 0 0 r
2.5 Mabswid
.54148 .77463 Mdot
.045 1 0 r
.5 Mabswid
.51532 .3266 m
.67149 .36295 L
s
0 0 0 r
2.5 Mabswid
.67149 .36295 Mdot
0 1 .381 r
.5 Mabswid
.63768 .25329 m
.47247 .3259 L
s
0 0 0 r
2.5 Mabswid
.47247 .3259 Mdot
.741 1 0 r
.5 Mabswid
.54148 .77463 m
.61853 .83597 L
s
0 0 0 r
2.5 Mabswid
.61853 .83597 Mdot
.045 1 0 r
.5 Mabswid
.67149 .36295 m
.46407 .53965 L
s
0 0 0 r
2.5 Mabswid
.46407 .53965 Mdot
0 1 .381 r
.5 Mabswid
.47247 .3259 m
.57987 .83344 L
s
0 0 0 r
2.5 Mabswid
.57987 .83344 Mdot
.741 1 0 r
.5 Mabswid
.61853 .83597 m
.58103 .81873 L
s
0 0 0 r
2.5 Mabswid
.58103 .81873 Mdot
.045 1 0 r
.5 Mabswid
.46407 .53965 m
.69936 .78922 L
s
0 0 0 r
2.5 Mabswid
.69936 .78922 Mdot
0 .702 1 r
.5 Mabswid
.57987 .83344 m
.70032 .42445 L
s
0 0 0 r
2.5 Mabswid
.70032 .42445 Mdot
.741 1 0 r
.5 Mabswid
.58103 .81873 m
.52802 .23932 L
s
0 0 0 r
2.5 Mabswid
.52802 .23932 Mdot
.045 1 0 r
.5 Mabswid
.69936 .78922 m
.46734 .6234 L
s
0 0 0 r
2.5 Mabswid
.46734 .6234 Mdot
0 .702 1 r
.5 Mabswid
.70032 .42445 m
.46198 .40781 L
s
0 0 0 r
2.5 Mabswid
.46198 .40781 Mdot
.741 1 0 r
.5 Mabswid
.52802 .23932 m
.62129 .22151 L
s
0 0 0 r
2.5 Mabswid
.62129 .22151 Mdot
.045 1 0 r
.5 Mabswid
.46734 .6234 m
.68552 .36538 L
s
0 0 0 r
2.5 Mabswid
.68552 .36538 Mdot
0 .702 1 r
.5 Mabswid
.46198 .40781 m
.77927 .59811 L
s
0 0 0 r
2.5 Mabswid
.77927 .59811 Mdot
.741 1 0 r
.5 Mabswid
.62129 .22151 m
.45035 .67296 L
s
0 0 0 r
2.5 Mabswid
.45035 .67296 Mdot
.045 1 0 r
.5 Mabswid
.68552 .36538 m
.44898 .4399 L
s
0 0 0 r
2.5 Mabswid
.44898 .4399 Mdot
.741 1 0 r
.5 Mabswid
.45035 .67296 m
.65315 .81245 L
s
0 0 0 r
2.5 Mabswid
.65315 .81245 Mdot
.045 1 0 r
.5 Mabswid
.44898 .4399 m
.62466 .49524 L
s
0 0 0 r
2.5 Mabswid
.62466 .49524 Mdot
.741 1 0 r
.5 Mabswid
.65315 .81245 m
.44898 .63761 L
s
0 0 0 r
2.5 Mabswid
.44898 .63761 Mdot
0 1 .632 r
.5 Mabswid
.62466 .49524 m
.46053 .59112 L
s
0 0 0 r
2.5 Mabswid
.46053 .59112 Mdot
.741 1 0 r
.5 Mabswid
.44898 .63761 m
.59863 .50946 L
s
0 0 0 r
2.5 Mabswid
.59863 .50946 Mdot
0 1 .632 r
.5 Mabswid
.46053 .59112 m
.57705 .82855 L
s
0 0 0 r
2.5 Mabswid
.57705 .82855 Mdot
0 .989 1 r
.5 Mabswid
.59863 .50946 m
.52093 .49024 L
s
0 0 0 r
2.5 Mabswid
.52093 .49024 Mdot
0 1 .632 r
.5 Mabswid
.57705 .82855 m
.6731 .39847 L
s
0 0 0 r
2.5 Mabswid
.6731 .39847 Mdot
0 .989 1 r
.5 Mabswid
.52093 .49024 m
.4928 .49114 L
s
0 0 0 r
2.5 Mabswid
.4928 .49114 Mdot
0 1 .632 r
.5 Mabswid
.6731 .39847 m
.53602 .22894 L
s
0 0 0 r
2.5 Mabswid
.53602 .22894 Mdot
0 .989 1 r
.5 Mabswid
.4928 .49114 m
.62677 .52834 L
s
0 0 0 r
2.5 Mabswid
.62677 .52834 Mdot
0 1 .632 r
.5 Mabswid
.53602 .22894 m
.65295 .28254 L
s
0 0 0 r
2.5 Mabswid
.65295 .28254 Mdot
0 .989 1 r
.5 Mabswid
.62677 .52834 m
.44898 .72257 L
s
0 0 0 r
2.5 Mabswid
.44898 .72257 Mdot
0 1 .632 r
.5 Mabswid
.65295 .28254 m
.58932 .63551 L
s
0 0 0 r
2.5 Mabswid
.58932 .63551 Mdot
0 .989 1 r
.5 Mabswid
.44898 .72257 m
.57394 .85908 L
s
0 0 0 r
2.5 Mabswid
.57394 .85908 Mdot
0 1 .632 r
.5 Mabswid
.58932 .63551 m
.56913 .65692 L
s
0 0 0 r
2.5 Mabswid
.56913 .65692 Mdot
0 .989 1 r
.5 Mabswid
.57394 .85908 m
.7655 .46995 L
s
0 0 0 r
2.5 Mabswid
.7655 .46995 Mdot
0 1 .632 r
.5 Mabswid
.56913 .65692 m
.65091 .7951 L
s
0 0 0 r
2.5 Mabswid
.65091 .7951 Mdot
0 .989 1 r
.5 Mabswid
.7655 .46995 m
.70544 .31973 L
s
0 0 0 r
2.5 Mabswid
.70544 .31973 Mdot
0 1 .632 r
.5 Mabswid
.65091 .7951 m
.63219 .8586 L
s
0 0 0 r
2.5 Mabswid
.63219 .8586 Mdot
0 .989 1 r
.5 Mabswid
.70544 .31973 m
.53437 .26932 L
s
0 0 0 r
2.5 Mabswid
.53437 .26932 Mdot
0 1 .632 r
.5 Mabswid
.63219 .8586 m
.56671 .84941 L
s
0 0 0 r
2.5 Mabswid
.56671 .84941 Mdot
0 .989 1 r
.5 Mabswid
.53437 .26932 m
.69174 .42795 L
s
0 0 0 r
2.5 Mabswid
.69174 .42795 Mdot
0 1 .632 r
.5 Mabswid
.56671 .84941 m
.60794 .79211 L
s
0 0 0 r
2.5 Mabswid
.60794 .79211 Mdot
0 .989 1 r
.5 Mabswid
.69174 .42795 m
.72347 .69304 L
s
0 0 0 r
2.5 Mabswid
.72347 .69304 Mdot
0 1 .632 r
.5 Mabswid
.60794 .79211 m
.59174 .31484 L
s
0 0 0 r
2.5 Mabswid
.59174 .31484 Mdot
0 .989 1 r
.5 Mabswid
.72347 .69304 m
.61171 .89655 L
s
0 0 0 r
2.5 Mabswid
.61171 .89655 Mdot
0 1 .632 r
.5 Mabswid
.59174 .31484 m
.56754 .28506 L
s
0 0 0 r
2.5 Mabswid
.56754 .28506 Mdot
0 .989 1 r
.5 Mabswid
.61171 .89655 m
.61048 .89784 L
s
0 0 0 r
2.5 Mabswid
.61048 .89784 Mdot
0 1 .632 r
.5 Mabswid
.56754 .28506 m
.67083 .29129 L
s
0 0 0 r
2.5 Mabswid
.67083 .29129 Mdot
0 .989 1 r
.5 Mabswid
.61048 .89784 m
.57832 .92397 L
s
0 0 0 r
2.5 Mabswid
.57832 .92397 Mdot
0 1 .632 r
.5 Mabswid
.67083 .29129 m
.70497 .3663 L
s
0 0 0 r
2.5 Mabswid
.70497 .3663 Mdot
0 .989 1 r
.5 Mabswid
.57832 .92397 m
.53486 .87577 L
s
0 0 0 r
2.5 Mabswid
.53486 .87577 Mdot
0 1 .632 r
.5 Mabswid
.70497 .3663 m
.65476 .49066 L
s
0 0 0 r
2.5 Mabswid
.65476 .49066 Mdot
0 .989 1 r
.5 Mabswid
.53486 .87577 m
.5073 .83125 L
s
0 0 0 r
2.5 Mabswid
.5073 .83125 Mdot
0 1 .632 r
.5 Mabswid
.65476 .49066 m
.56281 .60389 L
s
0 0 0 r
2.5 Mabswid
.56281 .60389 Mdot
0 .989 1 r
.5 Mabswid
.5073 .83125 m
.45212 .71048 L
s
0 0 0 r
2.5 Mabswid
.45212 .71048 Mdot
0 1 .632 r
.5 Mabswid
.56281 .60389 m
.63345 .65532 L
s
0 0 0 r
2.5 Mabswid
.63345 .65532 Mdot
0 .989 1 r
.5 Mabswid
.45212 .71048 m
.45469 .43867 L
s
0 0 0 r
2.5 Mabswid
.45469 .43867 Mdot
0 1 .632 r
.5 Mabswid
.63345 .65532 m
.70446 .73635 L
s
0 0 0 r
2.5 Mabswid
.70446 .73635 Mdot
0 .989 1 r
.5 Mabswid
.45469 .43867 m
.59176 .23784 L
s
0 0 0 r
2.5 Mabswid
.59176 .23784 Mdot
0 1 .632 r
.5 Mabswid
.70446 .73635 m
.71416 .77268 L
s
0 0 0 r
2.5 Mabswid
.71416 .77268 Mdot
0 .989 1 r
.5 Mabswid
.59176 .23784 m
.53837 .24966 L
s
0 0 0 r
2.5 Mabswid
.53837 .24966 Mdot
0 1 .632 r
.5 Mabswid
.71416 .77268 m
.60685 .71771 L
s
0 0 0 r
2.5 Mabswid
.60685 .71771 Mdot
0 .989 1 r
.5 Mabswid
.53837 .24966 m
.48899 .53922 L
s
0 0 0 r
2.5 Mabswid
.48899 .53922 Mdot
0 1 .632 r
.5 Mabswid
.60685 .71771 m
.56996 .69893 L
s
0 0 0 r
2.5 Mabswid
.56996 .69893 Mdot
0 .989 1 r
.5 Mabswid
.48899 .53922 m
.58558 .6764 L
s
0 0 0 r
2.5 Mabswid
.58558 .6764 Mdot
0 1 .632 r
.5 Mabswid
.56996 .69893 m
.5916 .665 L
s
0 0 0 r
2.5 Mabswid
.5916 .665 Mdot
0 .989 1 r
.5 Mabswid
.58558 .6764 m
.55242 .70689 L
s
0 0 0 r
2.5 Mabswid
.55242 .70689 Mdot
0 1 .632 r
.5 Mabswid
.5916 .665 m
.65355 .34159 L
s
0 0 0 r
2.5 Mabswid
.65355 .34159 Mdot
0 .989 1 r
.5 Mabswid
.55242 .70689 m
.51708 .86105 L
s
0 0 0 r
2.5 Mabswid
.51708 .86105 Mdot
0 1 .632 r
.5 Mabswid
.65355 .34159 m
.51259 .25007 L
s
0 0 0 r
2.5 Mabswid
.51259 .25007 Mdot
0 .989 1 r
.5 Mabswid
.51708 .86105 m
.62331 .83403 L
s
0 0 0 r
2.5 Mabswid
.62331 .83403 Mdot
0 1 .632 r
.5 Mabswid
.51259 .25007 m
.60998 .3619 L
s
0 0 0 r
2.5 Mabswid
.60998 .3619 Mdot
0 .989 1 r
.5 Mabswid
.62331 .83403 m
.49186 .5241 L
s
0 0 0 r
2.5 Mabswid
.49186 .5241 Mdot
0 1 .632 r
.5 Mabswid
.60998 .3619 m
.53128 .46833 L
s
0 0 0 r
2.5 Mabswid
.53128 .46833 Mdot
0 .989 1 r
.5 Mabswid
.49186 .5241 m
.68829 .36198 L
s
0 0 0 r
2.5 Mabswid
.68829 .36198 Mdot
0 1 .632 r
.5 Mabswid
.53128 .46833 m
.58028 .84622 L
s
0 0 0 r
2.5 Mabswid
.58028 .84622 Mdot
0 .989 1 r
.5 Mabswid
.68829 .36198 m
.51655 .46602 L
s
0 0 0 r
2.5 Mabswid
.51655 .46602 Mdot
0 1 .632 r
.5 Mabswid
.58028 .84622 m
.63862 .76606 L
s
0 0 0 r
2.5 Mabswid
.63862 .76606 Mdot
0 .989 1 r
.5 Mabswid
.51655 .46602 m
.63948 .54213 L
s
0 0 0 r
2.5 Mabswid
.63948 .54213 Mdot
0 1 .632 r
.5 Mabswid
.63862 .76606 m
.52078 .66842 L
s
0 0 0 r
2.5 Mabswid
.52078 .66842 Mdot
0 .989 1 r
.5 Mabswid
.63948 .54213 m
.56602 .91106 L
s
0 0 0 r
2.5 Mabswid
.56602 .91106 Mdot
0 1 .632 r
.5 Mabswid
.52078 .66842 m
.6577 .30591 L
s
0 0 0 r
2.5 Mabswid
.6577 .30591 Mdot
0 .989 1 r
.5 Mabswid
.56602 .91106 m
.58677 .90846 L
s
0 0 0 r
2.5 Mabswid
.58677 .90846 Mdot
0 1 .632 r
.5 Mabswid
.6577 .30591 m
.51428 .25714 L
s
0 0 0 r
2.5 Mabswid
.51428 .25714 Mdot
0 .989 1 r
.5 Mabswid
.58677 .90846 m
.53907 .40289 L
s
0 0 0 r
2.5 Mabswid
.53907 .40289 Mdot
0 1 .632 r
.5 Mabswid
.51428 .25714 m
.70951 .43192 L
s
0 0 0 r
2.5 Mabswid
.70951 .43192 Mdot
0 .989 1 r
.5 Mabswid
.53907 .40289 m
.59569 .34507 L
s
0 0 0 r
2.5 Mabswid
.59569 .34507 Mdot
0 1 .632 r
.5 Mabswid
.70951 .43192 m
.66243 .79117 L
s
0 0 0 r
2.5 Mabswid
.66243 .79117 Mdot
0 .989 1 r
.5 Mabswid
.59569 .34507 m
.4802 .2913 L
s
0 0 0 r
2.5 Mabswid
.4802 .2913 Mdot
0 1 .632 r
.5 Mabswid
.66243 .79117 m
.54095 .87845 L
s
0 0 0 r
2.5 Mabswid
.54095 .87845 Mdot
0 .989 1 r
.5 Mabswid
.4802 .2913 m
.59824 .33131 L
s
0 0 0 r
2.5 Mabswid
.59824 .33131 Mdot
0 1 .632 r
.5 Mabswid
.54095 .87845 m
.73755 .68904 L
s
0 0 0 r
2.5 Mabswid
.73755 .68904 Mdot
0 .989 1 r
.5 Mabswid
.59824 .33131 m
.532 .39475 L
s
0 0 0 r
2.5 Mabswid
.532 .39475 Mdot
0 1 .632 r
.5 Mabswid
.73755 .68904 m
.60187 .23531 L
s
0 0 0 r
2.5 Mabswid
.60187 .23531 Mdot
0 .989 1 r
.5 Mabswid
.532 .39475 m
.57916 .92489 L
s
0 0 0 r
2.5 Mabswid
.57916 .92489 Mdot
0 1 .632 r
.5 Mabswid
.60187 .23531 m
.56734 .20846 L
s
0 0 0 r
2.5 Mabswid
.56734 .20846 Mdot
0 .989 1 r
.5 Mabswid
.57916 .92489 m
.61707 .60943 L
s
0 0 0 r
2.5 Mabswid
.61707 .60943 Mdot
0 .989 1 r
.5 Mabswid
.61707 .60943 m
.54743 .51878 L
s
0 0 0 r
2.5 Mabswid
.54743 .51878 Mdot
0 .989 1 r
.5 Mabswid
.54743 .51878 m
.67557 .3116 L
s
0 0 0 r
2.5 Mabswid
.67557 .3116 Mdot
0 .989 1 r
.5 Mabswid
.67557 .3116 m
.54064 .30265 L
s
0 0 0 r
2.5 Mabswid
.54064 .30265 Mdot
0 .989 1 r
.5 Mabswid
.54064 .30265 m
.61601 .38491 L
s
0 0 0 r
2.5 Mabswid
.61601 .38491 Mdot
0 .989 1 r
.5 Mabswid
.61601 .38491 m
.57313 .81555 L
s
0 0 0 r
2.5 Mabswid
.57313 .81555 Mdot
0 .989 1 r
.5 Mabswid
.57313 .81555 m
.55538 .89032 L
s
0 0 0 r
2.5 Mabswid
.55538 .89032 Mdot
0 .989 1 r
.5 Mabswid
.55538 .89032 m
.59271 .91039 L
s
0 0 0 r
2.5 Mabswid
.59271 .91039 Mdot
0 .989 1 r
.5 Mabswid
.59271 .91039 m
.54554 .85647 L
s
0 0 0 r
2.5 Mabswid
.54554 .85647 Mdot
0 .989 1 r
.5 Mabswid
.54554 .85647 m
.57042 .68302 L
s
0 0 0 r
2.5 Mabswid
.57042 .68302 Mdot
0 .989 1 r
.5 Mabswid
.57042 .68302 m
.57114 .68208 L
s
0 0 0 r
2.5 Mabswid
.57114 .68208 Mdot
0 .989 1 r
.5 Mabswid
.57114 .68208 m
.58682 .65961 L
s
0 0 0 r
2.5 Mabswid
.58682 .65961 Mdot
0 .989 1 r
.5 Mabswid
.58682 .65961 m
.64103 .31246 L
s
0 0 0 r
2.5 Mabswid
.64103 .31246 Mdot
0 .989 1 r
.5 Mabswid
.64103 .31246 m
.53209 .22953 L
s
0 0 0 r
2.5 Mabswid
.53209 .22953 Mdot
0 .989 1 r
.5 Mabswid
.53209 .22953 m
.62468 .31503 L
s
0 0 0 r
2.5 Mabswid
.62468 .31503 Mdot
0 .989 1 r
.5 Mabswid
.62468 .31503 m
.56347 .48362 L
s
0 0 0 r
2.5 Mabswid
.56347 .48362 Mdot
0 .989 1 r
.5 Mabswid
.56347 .48362 m
.60318 .55781 L
s
0 0 0 r
2.5 Mabswid
.60318 .55781 Mdot
0 .989 1 r
.5 Mabswid
.60318 .55781 m
.52996 .84845 L
s
0 0 0 r
2.5 Mabswid
.52996 .84845 Mdot
0 .989 1 r
.5 Mabswid
.52996 .84845 m
.60941 .89783 L
s
0 0 0 r
2.5 Mabswid
.60941 .89783 Mdot
0 .989 1 r
.5 Mabswid
.60941 .89783 m
.47739 .74553 L
s
0 0 0 r
2.5 Mabswid
.47739 .74553 Mdot
0 .989 1 r
.5 Mabswid
.47739 .74553 m
.47217 .7029 L
s
0 0 0 r
2.5 Mabswid
.47217 .7029 Mdot
0 .989 1 r
.5 Mabswid
.47217 .7029 m
.52109 .44318 L
s
0 0 0 r
2.5 Mabswid
.52109 .44318 Mdot
0 .989 1 r
.5 Mabswid
.52109 .44318 m
.58859 .34311 L
s
0 0 0 r
2.5 Mabswid
.58859 .34311 Mdot
0 .989 1 r
.5 Mabswid
.58859 .34311 m
.52475 .31576 L
s
0 0 0 r
2.5 Mabswid
.52475 .31576 Mdot
0 .989 1 r
.5 Mabswid
.52475 .31576 m
.48328 .34343 L
s
0 0 0 r
2.5 Mabswid
.48328 .34343 Mdot
0 .989 1 r
.5 Mabswid
.48328 .34343 m
.54745 .41329 L
s
0 0 0 r
2.5 Mabswid
.54745 .41329 Mdot
0 .989 1 r
.5 Mabswid
.54745 .41329 m
.57399 .43459 L
s
0 0 0 r
2.5 Mabswid
.57399 .43459 Mdot
0 .989 1 r
.5 Mabswid
.57399 .43459 m
.73194 .64257 L
s
0 0 0 r
2.5 Mabswid
.73194 .64257 Mdot
0 .989 1 r
.5 Mabswid
.73194 .64257 m
.7535 .71164 L
s
0 0 0 r
2.5 Mabswid
.7535 .71164 Mdot
0 .989 1 r
.5 Mabswid
.7535 .71164 m
.70922 .75847 L
s
0 0 0 r
2.5 Mabswid
.70922 .75847 Mdot
0 .989 1 r
.5 Mabswid
.70922 .75847 m
.57671 .75575 L
s
0 0 0 r
2.5 Mabswid
.57671 .75575 Mdot
0 .989 1 r
.5 Mabswid
.57671 .75575 m
.51599 .66807 L
s
0 0 0 r
2.5 Mabswid
.51599 .66807 Mdot
0 .989 1 r
.5 Mabswid
.51599 .66807 m
.45501 .52431 L
s
0 0 0 r
2.5 Mabswid
.45501 .52431 Mdot
0 .989 1 r
.5 Mabswid
.45501 .52431 m
.44961 .42081 L
s
0 0 0 r
2.5 Mabswid
.44961 .42081 Mdot
0 .989 1 r
.5 Mabswid
.44961 .42081 m
.46919 .32966 L
s
0 0 0 r
2.5 Mabswid
.46919 .32966 Mdot
0 .989 1 r
.5 Mabswid
.46919 .32966 m
.52386 .24112 L
s
0 0 0 r
2.5 Mabswid
.52386 .24112 Mdot
0 .989 1 r
.5 Mabswid
.52386 .24112 m
.58799 .20311 L
s
0 0 0 r
2.5 Mabswid
.58799 .20311 Mdot
0 .989 1 r
.5 Mabswid
.58799 .20311 m
.51828 .2891 L
s
0 0 0 r
2.5 Mabswid
.51828 .2891 Mdot
0 .989 1 r
.5 Mabswid
.51828 .2891 m
.46745 .46781 L
s
0 0 0 r
2.5 Mabswid
.46745 .46781 Mdot
0 .989 1 r
.5 Mabswid
.46745 .46781 m
.47494 .62067 L
s
0 0 0 r
2.5 Mabswid
.47494 .62067 Mdot
0 .989 1 r
.5 Mabswid
.47494 .62067 m
.59259 .85265 L
s
0 0 0 r
2.5 Mabswid
.59259 .85265 Mdot
0 .989 1 r
.5 Mabswid
.59259 .85265 m
.54007 .85373 L
s
0 0 0 r
2.5 Mabswid
.54007 .85373 Mdot
0 .989 1 r
.5 Mabswid
.54007 .85373 m
.54786 .61623 L
s
0 0 0 r
2.5 Mabswid
.54786 .61623 Mdot
0 .989 1 r
.5 Mabswid
.54786 .61623 m
.59771 .57979 L
s
0 0 0 r
2.5 Mabswid
.59771 .57979 Mdot
0 .989 1 r
.5 Mabswid
.59771 .57979 m
.50908 .28802 L
s
0 0 0 r
2.5 Mabswid
.50908 .28802 Mdot
0 .989 1 r
.5 Mabswid
.50908 .28802 m
.61604 .22818 L
s
0 0 0 r
2.5 Mabswid
.61604 .22818 Mdot
0 .989 1 r
.5 Mabswid
.61604 .22818 m
.49897 .37245 L
s
0 0 0 r
2.5 Mabswid
.49897 .37245 Mdot
0 .989 1 r
.5 Mabswid
.49897 .37245 m
.68499 .68085 L
s
0 0 0 r
2.5 Mabswid
.68499 .68085 Mdot
0 .989 1 r
.5 Mabswid
.68499 .68085 m
.48823 .80332 L
s
0 0 0 r
2.5 Mabswid
.48823 .80332 Mdot
0 .989 1 r
.5 Mabswid
.48823 .80332 m
.71282 .65906 L
s
0 0 0 r
2.5 Mabswid
.71282 .65906 Mdot
0 .989 1 r
.5 Mabswid
.71282 .65906 m
.54014 .21815 L
s
0 0 0 r
2.5 Mabswid
.54014 .21815 Mdot
0 .989 1 r
.5 Mabswid
.54014 .21815 m
.62906 .23809 L
s
0 0 0 r
2.5 Mabswid
.62906 .23809 Mdot
0 .989 1 r
.5 Mabswid
.62906 .23809 m
.67198 .81434 L
s
0 0 0 r
2.5 Mabswid
.67198 .81434 Mdot
0 .989 1 r
.5 Mabswid
.67198 .81434 m
.4961 .8232 L
s
0 0 0 r
2.5 Mabswid
.4961 .8232 Mdot
0 .989 1 r
.5 Mabswid
.4961 .8232 m
.68225 .3974 L
s
0 0 0 r
2.5 Mabswid
.68225 .3974 Mdot
0 .989 1 r
.5 Mabswid
.68225 .3974 m
.46541 .35189 L
s
0 0 0 r
2.5 Mabswid
.46541 .35189 Mdot
0 .989 1 r
.5 Mabswid
.46541 .35189 m
.63199 .65455 L
s
0 0 0 r
2.5 Mabswid
.63199 .65455 Mdot
0 .989 1 r
.5 Mabswid
.63199 .65455 m
.51583 .70257 L
s
0 0 0 r
2.5 Mabswid
.51583 .70257 Mdot
0 .989 1 r
.5 Mabswid
.51583 .70257 m
.61381 .7474 L
s
0 0 0 r
2.5 Mabswid
.61381 .7474 Mdot
0 .989 1 r
.5 Mabswid
.61381 .7474 m
.53564 .7073 L
s
0 0 0 r
2.5 Mabswid
.53564 .7073 Mdot
0 .989 1 r
.5 Mabswid
.53564 .7073 m
.69965 .31121 L
s
0 0 0 r
2.5 Mabswid
.69965 .31121 Mdot
0 .989 1 r
.5 Mabswid
.69965 .31121 m
.45062 .39719 L
s
0 0 0 r
2.5 Mabswid
.45062 .39719 Mdot
0 .989 1 r
.5 Mabswid
.45062 .39719 m
.74445 .72576 L
s
0 0 0 r
2.5 Mabswid
.74445 .72576 Mdot
.544 1 0 r
.5 Mabswid
.5449 .89892 m
.52542 1.08077 L
s
0 0 0 r
2.5 Mabswid
.52542 1.08077 Mdot
.549 1 0 r
.5 Mabswid
.5331 .88459 m
.51138 1.08077 L
s
0 0 0 r
2.5 Mabswid
.51138 1.08077 Mdot
.554 1 0 r
.5 Mabswid
.52137 .87036 m
.49734 1.08077 L
s
0 0 0 r
2.5 Mabswid
.49734 1.08077 Mdot
.559 1 0 r
.5 Mabswid
.50972 .85622 m
.48328 1.08077 L
s
0 0 0 r
2.5 Mabswid
.48328 1.08077 Mdot
.564 1 0 r
.5 Mabswid
.49815 .84217 m
.4692 1.08077 L
s
0 0 0 r
2.5 Mabswid
.4692 1.08077 Mdot
.569 1 0 r
.5 Mabswid
.48665 .82821 m
.45511 1.08077 L
s
0 0 0 r
2.5 Mabswid
.45511 1.08077 Mdot
.831 1 0 r
.5 Mabswid
.47969 .81456 m
.22696 1.08077 L
s
0 0 0 r
2.5 Mabswid
.22696 1.08077 Mdot
.833 1 0 r
.5 Mabswid
.47427 .80103 m
.20683 1.08077 L
s
0 0 0 r
2.5 Mabswid
.20683 1.08077 Mdot
.834 1 0 r
.5 Mabswid
.46886 .78755 m
.18657 1.08077 L
s
0 0 0 r
2.5 Mabswid
.18657 1.08077 Mdot
.836 1 0 r
.5 Mabswid
.46347 .7741 m
.16617 1.08077 L
s
0 0 0 r
2.5 Mabswid
.16617 1.08077 Mdot
.838 1 0 r
.5 Mabswid
.4581 .7607 m
.14563 1.08077 L
s
0 0 0 r
2.5 Mabswid
.14563 1.08077 Mdot
.84 1 0 r
.5 Mabswid
.45275 .74734 m
.12495 1.08077 L
s
0 0 0 r
2.5 Mabswid
.12495 1.08077 Mdot
.933 1 0 r
.5 Mabswid
.44898 .73407 m
0 0 rlineto s
.44898 .73407 m
0 .74661 L
s
.934 1 0 r
.44898 .72091 m
0 0 rlineto s
.44898 .72091 m
0 .73189 L
s
.44898 .70776 m
0 0 rlineto s
.44898 .70776 m
0 .71717 L
s
.44898 .69461 m
0 0 rlineto s
.44898 .69461 m
0 .70245 L
s
.44898 .68146 m
0 0 rlineto s
.44898 .68146 m
0 .68773 L
s
.44898 .66832 m
0 0 rlineto s
.44898 .66832 m
0 .67302 L
s
.44898 .65517 m
0 0 rlineto s
.44898 .65517 m
0 .65831 L
s
.44898 .64203 m
0 0 rlineto s
.44898 .64203 m
0 .64359 L
s
.44898 .62888 m
0 0 rlineto s
.44898 .62888 m
0 .62888 L
s
.44898 .61574 m
0 0 rlineto s
.44898 .61574 m
0 .61417 L
s
.44898 .60259 m
0 0 rlineto s
.44898 .60259 m
0 .59946 L
s
.44898 .58944 m
0 0 rlineto s
.44898 .58944 m
0 .58474 L
s
.44898 .5763 m
0 0 rlineto s
.44898 .5763 m
0 .57003 L
s
.44898 .56315 m
0 0 rlineto s
.44898 .56315 m
0 .55531 L
s
.44898 .55 m
0 0 rlineto s
.44898 .55 m
0 .54059 L
s
.44898 .53685 m
0 0 rlineto s
.44898 .53685 m
0 .52588 L
s
.933 1 0 r
.44898 .52369 m
0 0 rlineto s
.44898 .52369 m
0 .51115 L
s
.44898 .51054 m
0 0 rlineto s
.44898 .51054 m
0 .49643 L
s
.44898 .49738 m
0 0 rlineto s
.44898 .49738 m
0 .4817 L
s
.44898 .48422 m
0 0 rlineto s
.44898 .48422 m
0 .46697 L
s
.44898 .47105 m
0 0 rlineto s
.44898 .47105 m
0 .45223 L
s
.44898 .45788 m
0 0 rlineto s
.44898 .45788 m
0 .43749 L
s
.44898 .4447 m
0 0 rlineto s
.44898 .4447 m
0 .42275 L
s
.932 1 0 r
.44898 .43153 m
0 0 rlineto s
.44898 .43153 m
0 .408 L
s
.44898 .41834 m
0 0 rlineto s
.44898 .41834 m
0 .39324 L
s
.44898 .40515 m
0 0 rlineto s
.44898 .40515 m
0 .37848 L
s
.44898 .39196 m
0 0 rlineto s
.44898 .39196 m
0 .36371 L
s
.44898 .37876 m
0 0 rlineto s
.44898 .37876 m
0 .34894 L
s
.819 1 0 r
.45048 .36545 m
.1418 .02636 L
s
0 0 0 r
2.5 Mabswid
.1418 .02636 Mdot
.817 1 0 r
.5 Mabswid
.45594 .35183 m
.16173 .02636 L
s
0 0 0 r
2.5 Mabswid
.16173 .02636 Mdot
.815 1 0 r
.5 Mabswid
.46141 .33817 m
.18153 .02636 L
s
0 0 0 r
2.5 Mabswid
.18153 .02636 Mdot
.813 1 0 r
.5 Mabswid
.46691 .32445 m
.20121 .02636 L
s
0 0 0 r
2.5 Mabswid
.20121 .02636 Mdot
.811 1 0 r
.5 Mabswid
.47243 .31069 m
.22077 .02636 L
s
0 0 0 r
2.5 Mabswid
.22077 .02636 Mdot
.809 1 0 r
.5 Mabswid
.47796 .29688 m
.2402 .02636 L
s
0 0 0 r
2.5 Mabswid
.2402 .02636 Mdot
.807 1 0 r
.5 Mabswid
.48352 .28303 m
.25952 .02636 L
s
0 0 0 r
2.5 Mabswid
.25952 .02636 Mdot
.508 1 0 r
.5 Mabswid
.4952 .26854 m
.47522 .02636 L
s
0 0 0 r
2.5 Mabswid
.47522 .02636 Mdot
.5 1 0 r
.5 Mabswid
.50723 .25393 m
.48927 .02636 L
s
0 0 0 r
2.5 Mabswid
.48927 .02636 Mdot
.494 1 0 r
.5 Mabswid
.51936 .23922 m
.5033 .02636 L
s
0 0 0 r
2.5 Mabswid
.5033 .02636 Mdot
.488 1 0 r
.5 Mabswid
.53156 .2244 m
.51731 .02636 L
s
0 0 0 r
2.5 Mabswid
.51731 .02636 Mdot
0 1 .067 r
.5 Mabswid
.44898 .47975 m
0 0 rlineto s
.44898 .47975 m
0 .29382 L
s
0 .668 1 r
.44898 .43825 m
0 0 rlineto s
.44898 .43825 m
0 .252 L
s
0 .56 1 r
.45579 .41579 m
0 0 rlineto s
.45579 .41579 m
0 .0842 L
s
0 .58 1 r
.4641 .39721 m
0 0 rlineto s
.4641 .39721 m
0 .0588 L
s
0 .599 1 r
.47249 .37836 m
0 0 rlineto s
.47249 .37836 m
0 .03304 L
s
0 .939 1 r
.48146 .36079 m
.1775 .02636 L
s
0 0 0 r
2.5 Mabswid
.1775 .02636 Mdot
.261 1 0 r
.5 Mabswid
.45083 .36456 m
0 0 rlineto s
.45083 .36456 m
0 .53779 L
s
1 .397 0 r
.44898 .37755 m
0 0 rlineto s
.44898 .37755 m
0 .21069 L
s
1 .403 0 r
.44898 .39076 m
0 0 rlineto s
.44898 .39076 m
0 .22539 L
s
1 .401 0 r
.44898 .40393 m
0 0 rlineto s
.44898 .40393 m
0 .24006 L
s
1 .398 0 r
.44898 .41706 m
0 0 rlineto s
.44898 .41706 m
0 .2547 L
s
1 .396 0 r
.44898 .43017 m
0 0 rlineto s
.44898 .43017 m
0 .26931 L
s
1 .356 0 r
.50689 .27265 m
0 0 rlineto s
.50689 .27265 m
0 .42105 L
s
1 .24 0 r
.49839 .28247 m
0 0 rlineto s
.49839 .28247 m
0 .43313 L
s
1 .242 0 r
.48989 .2923 m
0 0 rlineto s
.48989 .2923 m
0 .44521 L
s
1 .244 0 r
.48138 .30214 m
0 0 rlineto s
.48138 .30214 m
0 .45727 L
s
1 .246 0 r
.47286 .31198 m
0 0 rlineto s
.47286 .31198 m
0 .46932 L
s
1 .228 0 r
.46755 .32287 m
0 0 rlineto s
.46755 .32287 m
0 .22821 L
s
1 .286 0 r
.46947 .33831 m
0 0 rlineto s
.46947 .33831 m
0 .41264 L
s
1 .16 0 r
.46486 .36086 m
0 0 rlineto s
.46486 .36086 m
0 .45007 L
s
1 .247 0 r
.45748 .36963 m
0 0 rlineto s
.45748 .36963 m
0 .23914 L
s
1 .242 0 r
.45206 .37896 m
0 0 rlineto s
.45206 .37896 m
0 .25125 L
s
1 .168 0 r
.44898 .38896 m
.05687 .02636 L
s
0 0 0 r
2.5 Mabswid
.05687 .02636 Mdot
1 .168 0 r
.5 Mabswid
.44898 .39982 m
.04192 .02636 L
s
0 0 0 r
2.5 Mabswid
.04192 .02636 Mdot
1 .169 0 r
.5 Mabswid
.44898 .41067 m
.02678 .02636 L
s
0 0 0 r
2.5 Mabswid
.02678 .02636 Mdot
1 .17 0 r
.5 Mabswid
.44898 .42151 m
.01145 .02636 L
s
0 0 0 r
2.5 Mabswid
.01145 .02636 Mdot
1 .163 0 r
.5 Mabswid
.44898 .69223 m
.05527 1.08077 L
s
0 0 0 r
2.5 Mabswid
.05527 1.08077 Mdot
1 .162 0 r
.5 Mabswid
.44898 .70313 m
.06949 1.08077 L
s
0 0 0 r
2.5 Mabswid
.06949 1.08077 Mdot
1 .161 0 r
.5 Mabswid
.44898 .71404 m
.08354 1.08077 L
s
0 0 0 r
2.5 Mabswid
.08354 1.08077 Mdot
1 .26 0 r
.5 Mabswid
.45001 .72465 m
0 0 rlineto s
.45001 .72465 m
0 .86415 L
s
1 .243 0 r
.45543 .73398 m
0 0 rlineto s
.45543 .73398 m
0 .87642 L
s
1 .173 0 r
.46184 .74301 m
0 0 rlineto s
.46184 .74301 m
0 .67129 L
s
.46979 .75158 m
0 0 rlineto s
.46979 .75158 m
0 .68028 L
s
1 .184 0 r
.47386 .77258 m
0 0 rlineto s
.47386 .77258 m
0 .71975 L
s
1 .245 0 r
.47016 .79077 m
0 0 rlineto s
.47016 .79077 m
0 .90034 L
s
1 .234 0 r
.47784 .8009 m
0 0 rlineto s
.47784 .8009 m
0 .68733 L
s
.48635 .81074 m
0 0 rlineto s
.48635 .81074 m
0 .69901 L
s
1 .233 0 r
.49485 .82057 m
0 0 rlineto s
.49485 .82057 m
0 .71073 L
s
.50334 .83039 m
0 0 rlineto s
.50334 .83039 m
0 .7225 L
s
1 .232 0 r
.51183 .84021 m
0 0 rlineto s
.51183 .84021 m
0 .73431 L
s
1 .421 0 r
.44898 .68295 m
0 0 rlineto s
.44898 .68295 m
0 .85643 L
s
1 .422 0 r
.44898 .69627 m
0 0 rlineto s
.44898 .69627 m
0 .87125 L
s
1 .424 0 r
.44898 .70963 m
0 0 rlineto s
.44898 .70963 m
0 .8861 L
s
1 .427 0 r
.44898 .72302 m
0 0 rlineto s
.44898 .72302 m
0 .90099 L
s
1 .429 0 r
.44898 .73645 m
0 0 rlineto s
.44898 .73645 m
0 .91591 L
s
1 .388 0 r
.45352 .74928 m
0 0 rlineto s
.45352 .74928 m
0 .5997 L
s
1 .392 0 r
.45864 .76205 m
0 0 rlineto s
.45864 .76205 m
0 .61308 L
s
0 1 .635 r
.45859 .68539 m
0 0 rlineto s
.45859 .68539 m
0 1.0118 L
s
0 .375 1 r
.45066 .66811 m
0 0 rlineto s
.45066 .66811 m
0 .98806 L
s
0 .43 1 r
.44898 .63529 m
0 0 rlineto s
.44898 .63529 m
0 .8181 L
s
0 .402 1 r
.44898 .59908 m
0 0 rlineto s
.44898 .59908 m
0 .78151 L
s
0 .645 1 r
.50765 .31033 m
.31886 .02636 L
s
0 0 0 r
2.5 Mabswid
.31886 .02636 Mdot
0 1 .72 r
.5 Mabswid
.47638 .35803 m
.25564 .02636 L
s
0 0 0 r
2.5 Mabswid
.25564 .02636 Mdot
0 1 .922 r
.5 Mabswid
.51236 .7974 m
.32594 1.08077 L
s
0 0 0 r
2.5 Mabswid
.32594 1.08077 Mdot
0 1 .827 r
.5 Mabswid
.54568 .84322 m
.4082 1.08077 L
s
0 0 0 r
2.5 Mabswid
.4082 1.08077 Mdot
.54 1 0 r
.5 Mabswid
.56564 .43055 m
.57642 .40775 L
s
0 0 0 r
2.5 Mabswid
.57642 .40775 Mdot
.8 1 0 r
.5 Mabswid
.5449 .89892 m
.57702 .9456 L
s
0 0 0 r
2.5 Mabswid
.57702 .9456 Mdot
.765 1 0 r
.5 Mabswid
.5331 .88459 m
.57702 .94842 L
s
0 0 0 r
2.5 Mabswid
.57702 .94842 Mdot
.766 1 0 r
.5 Mabswid
.52137 .87036 m
.57702 .95122 L
s
0 0 0 r
2.5 Mabswid
.57702 .95122 Mdot
.767 1 0 r
.5 Mabswid
.50972 .85622 m
.57702 .95399 L
s
0 0 0 r
2.5 Mabswid
.57702 .95399 Mdot
.768 1 0 r
.5 Mabswid
.49815 .84217 m
.57702 .95675 L
s
0 0 0 r
2.5 Mabswid
.57702 .95675 Mdot
.77 1 0 r
.5 Mabswid
.48665 .82821 m
.57365 .95459 L
s
0 0 0 r
2.5 Mabswid
.57365 .95459 Mdot
.93 1 0 r
.5 Mabswid
.47179 .61576 m
0 0 rlineto s
.47179 .61576 m
0 .56501 L
s
.774 1 0 r
.4549 .75272 m
0 0 rlineto s
.4549 .75272 m
0 .83341 L
s
.785 1 0 r
.55798 .81953 m
0 0 rlineto s
.55798 .81953 m
0 .82001 L
s
.194 1 0 r
.55664 .29356 m
0 0 rlineto s
.55664 .29356 m
0 .31338 L
s
.703 1 0 r
.45717 .34876 m
0 0 rlineto s
.45717 .34876 m
0 .25498 L
s
.761 1 0 r
.44898 .52123 m
0 0 rlineto s
.44898 .52123 m
0 .50633 L
s
.782 1 0 r
.4952 .26854 m
.57702 .14953 L
s
0 0 0 r
2.5 Mabswid
.57702 .14953 Mdot
.757 1 0 r
.5 Mabswid
.50723 .25393 m
.57702 .15242 L
s
0 0 0 r
2.5 Mabswid
.57702 .15242 Mdot
.757 1 0 r
.5 Mabswid
.51936 .23922 m
.57702 .15532 L
s
0 0 0 r
2.5 Mabswid
.57702 .15532 Mdot
.756 1 0 r
.5 Mabswid
.53156 .2244 m
.57702 .15826 L
s
0 0 0 r
2.5 Mabswid
.57702 .15826 Mdot
0 .77 1 r
.5 Mabswid
.50082 .30709 m
0 0 rlineto s
.50082 .30709 m
0 .57803 L
s
0 1 .774 r
.51034 .29176 m
0 0 rlineto s
.51034 .29176 m
0 .56317 L
s
0 1 .668 r
.51986 .27645 m
0 0 rlineto s
.51986 .27645 m
0 .54824 L
s
0 1 .553 r
.52936 .26116 m
0 0 rlineto s
.52936 .26116 m
0 .53325 L
s
0 .101 1 r
.50936 .81379 m
0 0 rlineto s
.50936 .81379 m
0 .49644 L
s
0 .108 1 r
.49979 .79838 m
0 0 rlineto s
.49979 .79838 m
0 .48122 L
s
0 .008 1 r
.4902 .78296 m
0 0 rlineto s
.4902 .78296 m
0 .46603 L
s
0 1 .37 r
.51816 .83506 m
.18422 .26711 L
s
0 0 0 r
2.5 Mabswid
.18422 .26711 Mdot
.327 1 0 r
.5 Mabswid
.5246 .84937 m
.16638 .28759 L
s
0 0 0 r
2.5 Mabswid
.16638 .28759 Mdot
.389 1 0 r
.5 Mabswid
.53102 .86367 m
.15145 .30446 L
s
0 0 0 r
2.5 Mabswid
.15145 .30446 Mdot
.761 1 0 r
.5 Mabswid
.47794 .81019 m
0 0 rlineto s
.47794 .81019 m
0 .4808 L
s
0 .565 1 r
.44898 .55449 m
0 0 rlineto s
.44898 .55449 m
0 .55035 L
s
0 1 .391 r
.46435 .39327 m
0 0 rlineto s
.46435 .39327 m
0 .40335 L
s
0 1 .62 r
.53047 .45752 m
.39315 .61084 L
s
0 0 0 r
2.5 Mabswid
.39315 .61084 Mdot
0 1 .017 r
.5 Mabswid
.49527 .6165 m
.33078 .2879 L
s
0 0 0 r
2.5 Mabswid
.33078 .2879 Mdot
0 1 .202 r
.5 Mabswid
.47267 .729 m
0 0 rlineto s
.47267 .729 m
0 .73169 L
s
.57 1 0 r
.44898 .69397 m
0 0 rlineto s
.44898 .69397 m
0 .41916 L
s
.493 1 0 r
.44898 .68724 m
0 0 rlineto s
.44898 .68724 m
0 .41023 L
s
0 1 .516 r
.44898 .51447 m
0 0 rlineto s
.44898 .51447 m
0 .94035 L
s
.659 1 0 r
.57882 .19521 m
.57702 .19215 L
s
0 0 0 r
2.5 Mabswid
.57702 .19215 Mdot
1 .984 0 r
.5 Mabswid
.56462 .83471 m
.42671 .57411 L
s
0 0 0 r
2.5 Mabswid
.42671 .57411 Mdot
.114 0 1 r
.5 Mabswid
.57798 .91556 m
.57702 .91864 L
s
0 0 0 r
2.5 Mabswid
.57702 .91864 Mdot
.486 1 0 r
.5 Mabswid
.55384 .30232 m
.24851 .33996 L
s
0 0 0 r
2.5 Mabswid
.24851 .33996 Mdot
.249 1 0 r
.5 Mabswid
.55123 .31928 m
.25489 .35735 L
s
0 0 0 r
2.5 Mabswid
.25489 .35735 Mdot
0 .502 1 r
.5 Mabswid
.45601 .53924 m
0 0 rlineto s
.45601 .53924 m
0 .25205 L
s
0 .585 1 r
.47574 .55731 m
.34393 .02636 L
s
0 0 0 r
2.5 Mabswid
.34393 .02636 Mdot
0 1 .969 r
.5 Mabswid
.46643 .54459 m
.03476 .80532 L
s
0 0 0 r
2.5 Mabswid
.03476 .80532 Mdot
0 .709 1 r
.5 Mabswid
.47031 .33262 m
0 0 rlineto s
.47031 .33262 m
0 .32269 L
s
0 1 .303 r
.49277 .31707 m
0 0 rlineto s
.49277 .31707 m
0 .23978 L
s
0 1 .953 r
.4687 .34533 m
0 0 rlineto s
.4687 .34533 m
0 .12834 L
s
0 1 .779 r
.5418 .48675 m
.31578 .37231 L
s
0 0 0 r
2.5 Mabswid
.31578 .37231 Mdot
0 .072 1 r
.5 Mabswid
.54432 .65949 m
.43387 .54359 L
s
0 0 0 r
2.5 Mabswid
.43387 .54359 Mdot
.479 1 0 r
.5 Mabswid
.56667 .24262 m
.38145 .47292 L
s
0 0 0 r
2.5 Mabswid
.38145 .47292 Mdot
0 .332 1 r
.5 Mabswid
.50128 .73159 m
0 0 rlineto s
.50128 .73159 m
0 .2265 L
s
0 .156 1 r
.47191 .78998 m
.07672 1.08077 L
s
0 0 0 r
2.5 Mabswid
.07672 1.08077 Mdot
.203 1 0 r
.5 Mabswid
.51695 .75456 m
.07179 1.08077 L
s
0 0 0 r
2.5 Mabswid
.07179 1.08077 Mdot
.321 1 0 r
.5 Mabswid
.5458 .63856 m
0 0 rlineto s
.5458 .63856 m
0 .18463 L
s
0 .267 1 r
.46831 .42124 m
0 0 rlineto s
.46831 .42124 m
0 .84419 L
s
0 1 .862 r
.47238 .72603 m
.48799 1.08077 L
s
0 0 0 r
2.5 Mabswid
.48799 1.08077 Mdot
0 .531 1 r
.5 Mabswid
.55915 .78522 m
.57702 .80086 L
s
0 0 0 r
2.5 Mabswid
.57702 .80086 Mdot
0 .137 1 r
.5 Mabswid
.57792 .77108 m
.57702 .7732 L
s
0 0 0 r
2.5 Mabswid
.57702 .7732 Mdot
0 .957 1 r
.5 Mabswid
.57306 .76607 m
.57702 .75765 L
s
0 0 0 r
2.5 Mabswid
.57702 .75765 Mdot
0 .414 1 r
.5 Mabswid
.44898 .4627 m
0 0 rlineto s
.44898 .4627 m
0 .78485 L
s
.608 1 0 r
.59863 .50946 m
.57702 .34075 L
s
0 0 0 r
2.5 Mabswid
.57702 .34075 Mdot
0 1 .795 r
.5 Mabswid
.56734 .20846 m
.28847 .02636 L
s
0 0 0 r
2.5 Mabswid
.28847 .02636 Mdot
.903 1 0 r
.5 Mabswid
.59728 .90798 m
.89829 1.08077 L
s
0 0 0 r
2.5 Mabswid
.89829 1.08077 Mdot
.983 1 0 r
.5 Mabswid
.60557 .89679 m
.92726 1.08077 L
s
0 0 0 r
2.5 Mabswid
.92726 1.08077 Mdot
.989 1 0 r
.5 Mabswid
.61395 .8855 m
.95662 1.08077 L
s
0 0 0 r
2.5 Mabswid
.95662 1.08077 Mdot
.996 1 0 r
.5 Mabswid
.62242 .87413 m
.97619 1.07499 L
s
0 0 0 r
2.5 Mabswid
.97619 1.07499 Mdot
1 .998 0 r
.5 Mabswid
.63098 .86266 m
.97619 1.05795 L
s
0 0 0 r
2.5 Mabswid
.97619 1.05795 Mdot
1 .991 0 r
.5 Mabswid
.63963 .8511 m
.97619 1.04081 L
s
0 0 0 r
2.5 Mabswid
.97619 1.04081 Mdot
1 .921 0 r
.5 Mabswid
.62775 .24114 m
.97619 .03582 L
s
0 0 0 r
2.5 Mabswid
.97619 .03582 Mdot
.92 1 0 r
.5 Mabswid
.61965 .23014 m
.96417 .02636 L
s
0 0 0 r
2.5 Mabswid
.96417 .02636 Mdot
.912 1 0 r
.5 Mabswid
.61164 .21923 m
.93648 .02636 L
s
0 0 0 r
2.5 Mabswid
.93648 .02636 Mdot
.905 1 0 r
.5 Mabswid
.60372 .20841 m
.90917 .02636 L
s
0 0 0 r
2.5 Mabswid
.90917 .02636 Mdot
0 1 .91 r
.5 Mabswid
.63998 .26961 m
.94592 .02636 L
s
0 0 0 r
2.5 Mabswid
.94592 .02636 Mdot
0 1 .874 r
.5 Mabswid
.6303 .26428 m
.93824 .02636 L
s
0 0 0 r
2.5 Mabswid
.93824 .02636 Mdot
0 1 .858 r
.5 Mabswid
.61991 .25952 m
.92072 .02636 L
s
0 0 0 r
2.5 Mabswid
.92072 .02636 Mdot
0 .547 1 r
.5 Mabswid
.67732 .33749 m
.97619 .19865 L
s
0 0 0 r
2.5 Mabswid
.97619 .19865 Mdot
.834 1 0 r
.5 Mabswid
.76133 .66474 m
.83378 1.08077 L
s
0 0 0 r
2.5 Mabswid
.83378 1.08077 Mdot
.201 1 0 r
.5 Mabswid
.76687 .71529 m
.92259 1.08077 L
s
0 0 0 r
2.5 Mabswid
.92259 1.08077 Mdot
.317 1 0 r
.5 Mabswid
.68479 .32247 m
.97619 .5285 L
s
0 0 0 r
2.5 Mabswid
.97619 .5285 Mdot
.266 1 0 r
.5 Mabswid
.6946 .33084 m
.97619 .53601 L
s
0 0 0 r
2.5 Mabswid
.97619 .53601 Mdot
.254 1 0 r
.5 Mabswid
.70442 .33922 m
.97619 .54376 L
s
0 0 0 r
2.5 Mabswid
.97619 .54376 Mdot
.235 1 0 r
.5 Mabswid
.71425 .34761 m
.97619 .55189 L
s
0 0 0 r
2.5 Mabswid
.97619 .55189 Mdot
.282 1 0 r
.5 Mabswid
.7056 .7669 m
.97619 .60931 L
s
0 0 0 r
2.5 Mabswid
.97619 .60931 Mdot
.251 1 0 r
.5 Mabswid
.69583 .77524 m
.97619 .61532 L
s
0 0 0 r
2.5 Mabswid
.97619 .61532 Mdot
.243 1 0 r
.5 Mabswid
.68608 .78356 m
.97619 .62142 L
s
0 0 0 r
2.5 Mabswid
.97619 .62142 Mdot
.235 1 0 r
.5 Mabswid
.76779 .39262 m
.93942 .02636 L
s
0 0 0 r
2.5 Mabswid
.93942 .02636 Mdot
.265 1 0 r
.5 Mabswid
.77692 .40068 m
.97619 .03507 L
s
0 0 0 r
2.5 Mabswid
.97619 .03507 Mdot
.103 1 0 r
.5 Mabswid
.77233 .4462 m
.85959 .02636 L
s
0 0 0 r
2.5 Mabswid
.85959 .02636 Mdot
0 .892 1 r
.5 Mabswid
.65576 .81823 m
.97619 1.06449 L
s
0 0 0 r
2.5 Mabswid
.97619 1.06449 Mdot
0 .42 1 r
.5 Mabswid
.5936 .23654 m
.85737 .02636 L
s
0 0 0 r
2.5 Mabswid
.85737 .02636 Mdot
0 .918 1 r
.5 Mabswid
.60333 .24989 m
.88479 .02636 L
s
0 0 0 r
2.5 Mabswid
.88479 .02636 Mdot
0 .175 1 r
.5 Mabswid
.60523 .77137 m
.78678 .98446 L
s
0 0 0 r
2.5 Mabswid
.78678 .98446 Mdot
0 .785 1 r
.5 Mabswid
.58754 .86645 m
.84879 1.08077 L
s
0 0 0 r
2.5 Mabswid
.84879 1.08077 Mdot
0 .475 1 r
.5 Mabswid
.58576 .87377 m
.85915 1.08077 L
s
0 0 0 r
2.5 Mabswid
.85915 1.08077 Mdot
.918 1 0 r
.5 Mabswid
.65211 .73338 m
.97619 .72613 L
s
0 0 0 r
2.5 Mabswid
.97619 .72613 Mdot
.76 1 0 r
.5 Mabswid
.65742 .74188 m
.97619 .73562 L
s
0 0 0 r
2.5 Mabswid
.97619 .73562 Mdot
.769 1 0 r
.5 Mabswid
.66272 .75038 m
.97619 .74508 L
s
0 0 0 r
2.5 Mabswid
.97619 .74508 Mdot
.871 1 0 r
.5 Mabswid
.66606 .75831 m
.87665 .50126 L
s
0 0 0 r
2.5 Mabswid
.87665 .50126 Mdot
0 1 .255 r
.5 Mabswid
.65821 .64578 m
.97619 .54334 L
s
0 0 0 r
2.5 Mabswid
.97619 .54334 Mdot
0 1 .989 r
.5 Mabswid
.74496 .39134 m
.97619 .3415 L
s
0 0 0 r
2.5 Mabswid
.97619 .3415 Mdot
0 1 .846 r
.5 Mabswid
.73729 .72151 m
.97619 .7907 L
s
0 0 0 r
2.5 Mabswid
.97619 .7907 Mdot
0 1 .735 r
.5 Mabswid
.69175 .79695 m
.97619 .92791 L
s
0 0 0 r
2.5 Mabswid
.97619 .92791 Mdot
0 1 .68 r
.5 Mabswid
.64126 .46759 m
.97619 .58215 L
s
0 0 0 r
2.5 Mabswid
.97619 .58215 Mdot
.664 1 0 r
.5 Mabswid
.66326 .36626 m
.97619 .38687 L
s
0 0 0 r
2.5 Mabswid
.97619 .38687 Mdot
.713 1 0 r
.5 Mabswid
.65801 .37489 m
.97619 .39679 L
s
0 0 0 r
2.5 Mabswid
.97619 .39679 Mdot
0 1 .497 r
.5 Mabswid
.8249 .46116 m
.97619 .58183 L
s
0 0 0 r
2.5 Mabswid
.97619 .58183 Mdot
0 .881 1 r
.5 Mabswid
.72216 .37586 m
.97619 .18657 L
s
0 0 0 r
2.5 Mabswid
.97619 .18657 Mdot
0 1 .37 r
.5 Mabswid
.71944 .38271 m
.97619 .19182 L
s
0 0 0 r
2.5 Mabswid
.97619 .19182 Mdot
0 1 .36 r
.5 Mabswid
.71671 .38956 m
.97619 .19708 L
s
0 0 0 r
2.5 Mabswid
.97619 .19708 Mdot
0 .502 1 r
.5 Mabswid
.70704 .44564 m
.92111 .30866 L
s
0 0 0 r
2.5 Mabswid
.92111 .30866 Mdot
0 .407 1 r
.5 Mabswid
.65717 .28441 m
.78552 .02636 L
s
0 0 0 r
2.5 Mabswid
.78552 .02636 Mdot
0 .123 1 r
.5 Mabswid
.7276 .66885 m
.97097 .73689 L
s
0 0 0 r
2.5 Mabswid
.97097 .73689 Mdot
0 1 .692 r
.5 Mabswid
.7121 .73355 m
.97619 .94452 L
s
0 0 0 r
2.5 Mabswid
.97619 .94452 Mdot
0 1 .44 r
.5 Mabswid
.71476 .74046 m
.97619 .94974 L
s
0 0 0 r
2.5 Mabswid
.97619 .94974 Mdot
0 .409 1 r
.5 Mabswid
.78052 .69589 m
.84178 1.08077 L
s
0 0 0 r
2.5 Mabswid
.84178 1.08077 Mdot
.152 0 1 r
.5 Mabswid
.77527 .40437 m
.8196 .02636 L
s
0 0 0 r
2.5 Mabswid
.8196 .02636 Mdot
.149 0 1 r
.5 Mabswid
.76418 .38985 m
.8051 .02636 L
s
0 0 0 r
2.5 Mabswid
.8051 .02636 Mdot
0 1 .049 r
.5 Mabswid
.76879 .44166 m
.61717 .2093 L
s
0 0 0 r
2.5 Mabswid
.61717 .2093 Mdot
0 .581 1 r
.5 Mabswid
.70937 .77929 m
.97619 .93362 L
s
0 0 0 r
2.5 Mabswid
.97619 .93362 Mdot
0 .559 1 r
.5 Mabswid
.70854 .78372 m
.97619 .93891 L
s
0 0 0 r
2.5 Mabswid
.97619 .93891 Mdot
0 .57 1 r
.5 Mabswid
.70772 .78816 m
.97619 .94421 L
s
0 0 0 r
2.5 Mabswid
.97619 .94421 Mdot
0 .521 1 r
.5 Mabswid
.7205 .33814 m
.97619 .19998 L
s
0 0 0 r
2.5 Mabswid
.97619 .19998 Mdot
0 .473 1 r
.5 Mabswid
.72142 .34269 m
.97619 .20541 L
s
0 0 0 r
2.5 Mabswid
.97619 .20541 Mdot
.364 1 0 r
.5 Mabswid
.59867 .35245 m
.76696 .02636 L
s
0 0 0 r
2.5 Mabswid
.76696 .02636 Mdot
0 .31 1 r
.5 Mabswid
.82695 .60052 m
.97619 .61134 L
s
0 0 0 r
2.5 Mabswid
.97619 .61134 Mdot
.16 0 1 r
.5 Mabswid
.6559 .84458 m
.82612 1.08077 L
s
0 0 0 r
2.5 Mabswid
.82612 1.08077 Mdot
0 1 .846 r
.5 Mabswid
.62005 .8852 m
.97619 1.04175 L
s
0 0 0 r
2.5 Mabswid
.97619 1.04175 Mdot
0 1 .772 r
.5 Mabswid
.80374 .66495 m
.97619 .90279 L
s
0 0 0 r
2.5 Mabswid
.97619 .90279 Mdot
1 .992 0 r
.5 Mabswid
.7021 .64584 m
.69217 .65618 L
s
0 0 0 r
2.5 Mabswid
.69217 .65618 Mdot
0 .313 1 r
.5 Mabswid
.68363 .42557 m
.70755 .02636 L
s
0 0 0 r
2.5 Mabswid
.70755 .02636 Mdot
.019 0 1 r
.5 Mabswid
.84736 .616 m
.97619 .69434 L
s
0 0 0 r
2.5 Mabswid
.97619 .69434 Mdot
.595 1 0 r
.5 Mabswid
.805 .42957 m
.97619 .21355 L
s
0 0 0 r
2.5 Mabswid
.97619 .21355 Mdot
.599 1 0 r
.5 Mabswid
.61782 .22276 m
.97619 .06418 L
s
0 0 0 r
2.5 Mabswid
.97619 .06418 Mdot
0 1 .968 r
.5 Mabswid
.66842 .81584 m
.97619 .94343 L
s
0 0 0 r
2.5 Mabswid
.97619 .94343 Mdot
0 1 .704 r
.5 Mabswid
.73903 .70433 m
.95016 1.08077 L
s
0 0 0 r
2.5 Mabswid
.95016 1.08077 Mdot
.417 1 0 r
.5 Mabswid
.6371 .55756 m
.97619 .2373 L
s
0 0 0 r
2.5 Mabswid
.97619 .2373 Mdot
0 1 .8 r
.5 Mabswid
.61347 .89434 m
.59523 .91138 L
s
0 0 0 r
2.5 Mabswid
.59523 .91138 Mdot
0 .305 1 r
.5 Mabswid
.58561 .29215 m
.74926 .52414 L
s
0 0 0 r
2.5 Mabswid
.74926 .52414 Mdot
0 .852 1 r
.5 Mabswid
.59993 .22282 m
.97619 .06803 L
s
0 0 0 r
2.5 Mabswid
.97619 .06803 Mdot
0 1 .2 r
.5 Mabswid
.66854 .42182 m
.57982 .02636 L
s
0 0 0 r
2.5 Mabswid
.57982 .02636 Mdot
.852 1 0 r
.5 Mabswid
.59963 .36718 m
.94175 .26841 L
s
0 0 0 r
2.5 Mabswid
.94175 .26841 Mdot
0 .339 1 r
.5 Mabswid
.7365 .73582 m
.8872 1.08077 L
s
0 0 0 r
2.5 Mabswid
.8872 1.08077 Mdot
0 1 .727 r
.5 Mabswid
.59031 .81383 m
.73722 .89068 L
s
0 0 0 r
2.5 Mabswid
.73722 .89068 Mdot
0 .016 1 r
.5 Mabswid
.58441 .20618 m
.83893 .02636 L
s
0 0 0 r
2.5 Mabswid
.83893 .02636 Mdot
0 1 .96 r
.5 Mabswid
.57987 .83344 m
.71352 1.08077 L
s
0 0 0 r
2.5 Mabswid
.71352 1.08077 Mdot
0 .244 1 r
.5 Mabswid
.77927 .59811 m
.97619 .84008 L
s
0 0 0 r
2.5 Mabswid
.97619 .84008 Mdot
0 1 .347 r
.5 Mabswid
.62466 .49524 m
.69403 .71859 L
s
0 0 0 r
2.5 Mabswid
.69403 .71859 Mdot
0 .968 1 r
.5 Mabswid
.74445 .72576 m
.86915 1.08077 L
s
0 0 0 r
2.5 Mabswid
.86915 1.08077 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{415.125, 459.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"Solitaire Diamond Example"],

Cell[BoxData[
    \(387.73333333333335`\ Second\)], "Output",
  CellTags->"Solitaire Diamond Example"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
 TurboPlot[sol,ColorView->Log[Intensity],PlotType->FrontView, \
PlotRange->Automatic];\
\>", "Input",
  CellTags->"Solitaire Diamond Example"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00680272 0.5 0.00680272 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.49998 .74487 m
.49998 .84016 L
.63021 .81425 L
.49998 .74487 L
s
.67313 .67317 m
.74051 .74054 L
.81428 .63014 L
.67313 .67317 L
s
.74487 .50002 m
.84016 .50002 L
.81425 .36979 L
.74487 .50002 L
s
.67317 .32687 m
.74054 .25949 L
.63014 .18572 L
.67317 .32687 L
s
.50002 .25513 m
.50002 .15984 L
.36979 .18575 L
.50002 .25513 L
s
.32687 .32684 m
.25949 .25946 L
.18572 .36986 L
.32687 .32684 L
s
.25513 .49998 m
.15984 .49998 L
.18575 .63021 L
.25513 .49998 L
s
.32684 .67313 m
.25946 .74051 L
.36986 .81428 L
.32684 .67313 L
s
.43098 .66654 m
.56902 .66654 L
.5 .74492 L
.43098 .66654 L
s
.56895 .66656 m
.66657 .56895 L
.67319 .67319 L
.56895 .66656 L
s
.66654 .56902 m
.66654 .43098 L
.74492 .5 L
.66654 .56902 L
s
.66657 .43105 m
.56895 .33344 L
.67319 .32681 L
.66657 .43105 L
s
.56902 .33346 m
.43098 .33346 L
.5 .25508 L
.56902 .33346 L
s
.43105 .33344 m
.33344 .43105 L
.32681 .32681 L
.43105 .33344 L
s
.33346 .43098 m
.33346 .56902 L
.25508 .5 L
.33346 .43098 L
s
.33344 .56895 m
.43105 .66656 L
.32681 .67319 L
.33344 .56895 L
s
.50002 .74487 m
.36979 .81425 L
.50002 .84016 L
.50002 .74487 L
s
.67317 .67313 m
.63014 .81428 L
.74054 .74051 L
.67317 .67313 L
s
.74487 .49998 m
.81425 .63021 L
.84016 .49998 L
.74487 .49998 L
s
.67313 .32684 m
.81428 .36986 L
.74051 .25946 L
.67313 .32684 L
s
.49998 .25513 m
.63021 .18575 L
.49998 .15984 L
.49998 .25513 L
s
.32684 .32687 m
.36986 .18572 L
.25946 .25949 L
.32684 .32687 L
s
.25513 .50002 m
.18575 .36979 L
.15984 .50002 L
.25513 .50002 L
s
.32687 .67317 m
.18572 .63014 L
.25949 .74054 L
.32687 .67317 L
s
.49998 .60197 m
.49998 .84018 L
.63021 .81428 L
.49998 .60197 L
s
.57209 .57212 m
.74053 .74056 L
.8143 .63016 L
.57209 .57212 L
s
.60197 .50002 m
.84018 .50002 L
.81428 .36979 L
.60197 .50002 L
s
.57212 .42791 m
.74056 .25947 L
.63016 .1857 L
.57212 .42791 L
s
.50002 .39803 m
.50002 .15982 L
.36979 .18572 L
.50002 .39803 L
s
.42791 .42788 m
.25947 .25944 L
.1857 .36984 L
.42791 .42788 L
s
.39803 .49998 m
.15982 .49998 L
.18572 .63021 L
.39803 .49998 L
s
.42788 .57209 m
.25944 .74053 L
.36984 .8143 L
.42788 .57209 L
s
.50002 .60197 m
.36979 .81428 L
.50002 .84018 L
.50002 .60197 L
s
.57212 .57209 m
.63016 .8143 L
.74056 .74053 L
.57212 .57209 L
s
.60197 .49998 m
.81428 .63021 L
.84018 .49998 L
.60197 .49998 L
s
.57209 .42788 m
.8143 .36984 L
.74053 .25944 L
.57209 .42788 L
s
.49998 .39803 m
.63021 .18572 L
.49998 .15982 L
.49998 .39803 L
s
.42788 .42791 m
.36984 .1857 L
.25944 .25947 L
.42788 .42791 L
s
.39803 .50002 m
.18572 .36979 L
.15982 .50002 L
.39803 .50002 L
s
.42791 .57212 m
.1857 .63016 L
.25947 .74056 L
.42791 .57212 L
s
.56898 .66652 m
.67321 .67314 L
.63018 .81429 L
.49988 .74474 L
.56898 .66652 L
s
.66652 .56898 m
.74491 .49995 L
.81429 .63018 L
.67297 .67314 L
.66652 .56898 L
s
.66652 .43102 m
.67314 .32679 L
.81429 .36982 L
.74474 .50012 L
.66652 .43102 L
s
.56898 .33348 m
.49995 .25509 L
.63018 .18571 L
.67314 .32703 L
.56898 .33348 L
s
.43103 .33348 m
.32679 .32686 L
.36982 .18571 L
.50012 .25526 L
.43103 .33348 L
s
.33348 .43102 m
.25509 .50005 L
.18571 .36982 L
.32703 .32686 L
.33348 .43102 L
s
.33348 .56898 m
.32686 .67321 L
.18571 .63018 L
.25526 .49988 L
.33348 .56898 L
s
.43103 .66652 m
.50005 .74491 L
.36982 .81429 L
.32686 .67297 L
.43103 .66652 L
s
.49997 .84014 m
.6302 .81424 L
.6302 .81424 L
.49997 .84014 L
.49997 .84014 L
s
.63014 .81426 m
.74054 .74049 L
.74054 .74049 L
.63014 .81426 L
.63014 .81426 L
s
.74049 .74054 m
.81426 .63014 L
.81426 .63014 L
.74049 .74054 L
.74049 .74054 L
s
.81424 .6302 m
.84014 .49997 L
.84014 .49997 L
.81424 .6302 L
.81424 .6302 L
s
.84014 .50003 m
.81424 .3698 L
.81424 .3698 L
.84014 .50003 L
.84014 .50003 L
s
.81426 .36986 m
.74049 .25946 L
.74049 .25946 L
.81426 .36986 L
.81426 .36986 L
s
.74054 .25951 m
.63014 .18574 L
.63014 .18574 L
.74054 .25951 L
.74054 .25951 L
s
.6302 .18576 m
.49997 .15986 L
.49997 .15986 L
.6302 .18576 L
.6302 .18576 L
s
.50003 .15986 m
.3698 .18576 L
.3698 .18576 L
.50003 .15986 L
.50003 .15986 L
s
.36986 .18574 m
.25946 .25951 L
.25946 .25951 L
.36986 .18574 L
.36986 .18574 L
s
.25951 .25946 m
.18574 .36986 L
.18574 .36986 L
.25951 .25946 L
.25951 .25946 L
s
.18576 .3698 m
.15986 .50003 L
.15986 .50003 L
.18576 .3698 L
.18576 .3698 L
s
.15986 .49997 m
.18576 .6302 L
.18576 .6302 L
.15986 .49997 L
.15986 .49997 L
s
.18574 .63014 m
.25951 .74054 L
.25951 .74054 L
.18574 .63014 L
.18574 .63014 L
s
.25946 .74049 m
.36986 .81426 L
.36986 .81426 L
.25946 .74049 L
.25946 .74049 L
s
.3698 .81424 m
.50003 .84014 L
.50003 .84014 L
.3698 .81424 L
.3698 .81424 L
s
.50239 .50236 m
.57217 .57214 L
.63021 .81435 L
.5 .6021 L
.49998 .50336 L
.50239 .50236 L
s
.50335 .49998 m
.60204 .49998 L
.81435 .63021 L
.5722 .57219 L
.50236 .50239 L
.50335 .49998 L
s
.50236 .49761 m
.57214 .42783 L
.81435 .36979 L
.6021 .5 L
.50336 .50002 L
.50236 .49761 L
s
.49998 .49665 m
.49998 .39796 L
.63021 .18565 L
.57219 .4278 L
.50239 .49764 L
.49998 .49665 L
s
.49761 .49764 m
.42783 .42786 L
.36979 .18565 L
.5 .3979 L
.50002 .49664 L
.49761 .49764 L
s
.49665 .50002 m
.39796 .50002 L
.18565 .36979 L
.4278 .42781 L
.49764 .49761 L
.49665 .50002 L
s
.49764 .50239 m
.42786 .57217 L
.18565 .63021 L
.3979 .5 L
.49664 .49998 L
.49764 .50239 L
s
.50002 .50335 m
.50002 .60204 L
.36979 .81435 L
.42781 .5722 L
.49761 .50236 L
.50002 .50335 L
s
.5 .5034 m
.50241 .50241 L
.5034 .5 L
.50241 .49759 L
.5 .4966 L
.49759 .49759 L
.4966 .5 L
.49759 .50241 L
.5 .5034 L
s
.56902 .66662 m
.66663 .56901 L
.66663 .43097 L
.56902 .33336 L
.43097 .33336 L
.33336 .43097 L
.33336 .56901 L
.43097 .66662 L
.56902 .66662 L
.56902 .66662 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .02381 L
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
s
.02381 .02381 m
.97619 .02381 L
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
s
.97619 .02381 m
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
.97619 .02381 L
s
.02381 .02381 m
.97619 .02381 L
.97619 .02381 L
.02381 .02381 L
.02381 .02381 L
s
.97619 .97619 m
.02381 .97619 L
.02381 .97619 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .02381 L
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
s
.02381 .02381 m
.97619 .02381 L
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
s
.97619 .02381 m
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
.97619 .02381 L
s
.02381 .02381 m
.97619 .02381 L
.97619 .02381 L
.02381 .02381 L
.02381 .02381 L
s
.97619 .97619 m
.02381 .97619 L
.02381 .97619 L
.97619 .97619 L
.97619 .97619 L
s
1 0 0 r
.56803 .5 m
.81193 .5 L
s
0 0 0 r
2.5 Mabswid
.81193 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.79899 .5 L
s
0 0 0 r
2.5 Mabswid
.79899 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.78614 .5 L
s
0 0 0 r
2.5 Mabswid
.78614 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.77336 .5 L
s
0 0 0 r
2.5 Mabswid
.77336 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.76068 .5 L
s
0 0 0 r
2.5 Mabswid
.76068 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.74807 .5 L
s
0 0 0 r
2.5 Mabswid
.74807 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.73574 .5 L
s
0 0 0 r
2.5 Mabswid
.73574 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.72352 .5 L
s
0 0 0 r
2.5 Mabswid
.72352 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.71134 .5 L
s
0 0 0 r
2.5 Mabswid
.71134 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.6992 .5 L
s
0 0 0 r
2.5 Mabswid
.6992 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.68709 .5 L
s
0 0 0 r
2.5 Mabswid
.68709 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.67503 .5 L
s
0 0 0 r
2.5 Mabswid
.67503 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.66304 .5 L
s
0 0 0 r
2.5 Mabswid
.66304 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.65115 .5 L
s
0 0 0 r
2.5 Mabswid
.65115 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.63928 .5 L
s
0 0 0 r
2.5 Mabswid
.63928 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.6274 .5 L
s
0 0 0 r
2.5 Mabswid
.6274 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.61552 .5 L
s
0 0 0 r
2.5 Mabswid
.61552 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.60365 .5 L
s
0 0 0 r
2.5 Mabswid
.60365 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.59177 .5 L
s
0 0 0 r
2.5 Mabswid
.59177 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.5799 .5 L
s
0 0 0 r
2.5 Mabswid
.5799 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.56803 .5 L
s
0 0 0 r
2.5 Mabswid
.56803 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.55615 .5 L
s
0 0 0 r
2.5 Mabswid
.55615 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.54428 .5 L
s
0 0 0 r
2.5 Mabswid
.54428 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.53241 .5 L
s
0 0 0 r
2.5 Mabswid
.53241 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.52053 .5 L
s
0 0 0 r
2.5 Mabswid
.52053 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.50866 .5 L
s
0 0 0 r
2.5 Mabswid
.50866 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.49678 .5 L
s
0 0 0 r
2.5 Mabswid
.49678 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.4849 .5 L
s
0 0 0 r
2.5 Mabswid
.4849 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.47302 .5 L
s
0 0 0 r
2.5 Mabswid
.47302 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.46114 .5 L
s
0 0 0 r
2.5 Mabswid
.46114 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.44925 .5 L
s
0 0 0 r
2.5 Mabswid
.44925 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.43736 .5 L
s
0 0 0 r
2.5 Mabswid
.43736 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.42547 .5 L
s
0 0 0 r
2.5 Mabswid
.42547 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.41357 .5 L
s
0 0 0 r
2.5 Mabswid
.41357 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.40167 .5 L
s
0 0 0 r
2.5 Mabswid
.40167 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.38977 .5 L
s
0 0 0 r
2.5 Mabswid
.38977 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.37786 .5 L
s
0 0 0 r
2.5 Mabswid
.37786 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.36595 .5 L
s
0 0 0 r
2.5 Mabswid
.36595 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.35403 .5 L
s
0 0 0 r
2.5 Mabswid
.35403 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.34211 .5 L
s
0 0 0 r
2.5 Mabswid
.34211 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.33009 .5 L
s
0 0 0 r
2.5 Mabswid
.33009 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.31779 .5 L
s
0 0 0 r
2.5 Mabswid
.31779 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.30544 .5 L
s
0 0 0 r
2.5 Mabswid
.30544 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.29306 .5 L
s
0 0 0 r
2.5 Mabswid
.29306 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.28063 .5 L
s
0 0 0 r
2.5 Mabswid
.28063 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.26816 .5 L
s
0 0 0 r
2.5 Mabswid
.26816 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.25564 .5 L
s
0 0 0 r
2.5 Mabswid
.25564 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.24256 .5 L
s
0 0 0 r
2.5 Mabswid
.24256 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.22936 .5 L
s
0 0 0 r
2.5 Mabswid
.22936 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.21607 .5 L
s
0 0 0 r
2.5 Mabswid
.21607 .5 Mdot
1 0 0 r
.5 Mabswid
.56803 .5 m
.20269 .5 L
s
0 0 0 r
2.5 Mabswid
.20269 .5 Mdot
1 .058 0 r
.5 Mabswid
.81193 .5 m
.81193 .5 L
s
0 0 0 r
2.5 Mabswid
.81193 .5 Mdot
1 .059 0 r
.5 Mabswid
.79899 .5 m
.79899 .5 L
s
0 0 0 r
2.5 Mabswid
.79899 .5 Mdot
1 .059 0 r
.5 Mabswid
.78614 .5 m
.78614 .5 L
s
0 0 0 r
2.5 Mabswid
.78614 .5 Mdot
1 .06 0 r
.5 Mabswid
.77336 .5 m
.77336 .5 L
s
0 0 0 r
2.5 Mabswid
.77336 .5 Mdot
1 .06 0 r
.5 Mabswid
.76068 .5 m
.76068 .5 L
s
0 0 0 r
2.5 Mabswid
.76068 .5 Mdot
1 .061 0 r
.5 Mabswid
.74807 .5 m
.74807 .5 L
s
0 0 0 r
2.5 Mabswid
.74807 .5 Mdot
1 .096 0 r
.5 Mabswid
.73574 .5 m
.68749 .5 L
s
0 0 0 r
2.5 Mabswid
.68749 .5 Mdot
1 .096 0 r
.5 Mabswid
.72352 .5 m
.67074 .5 L
s
0 0 0 r
2.5 Mabswid
.67074 .5 Mdot
1 .097 0 r
.5 Mabswid
.71134 .5 m
.65398 .5 L
s
0 0 0 r
2.5 Mabswid
.65398 .5 Mdot
1 .097 0 r
.5 Mabswid
.6992 .5 m
.63719 .5 L
s
0 0 0 r
2.5 Mabswid
.63719 .5 Mdot
1 .097 0 r
.5 Mabswid
.68709 .5 m
.62039 .5 L
s
0 0 0 r
2.5 Mabswid
.62039 .5 Mdot
1 .098 0 r
.5 Mabswid
.67503 .5 m
.60357 .5 L
s
0 0 0 r
2.5 Mabswid
.60357 .5 Mdot
1 .116 0 r
.5 Mabswid
.66304 .5 m
.6662 .5 L
s
0 0 0 r
2.5 Mabswid
.6662 .5 Mdot
1 .116 0 r
.5 Mabswid
.65115 .5 m
.65403 .5 L
s
0 0 0 r
2.5 Mabswid
.65403 .5 Mdot
1 .116 0 r
.5 Mabswid
.63928 .5 m
.64183 .5 L
s
0 0 0 r
2.5 Mabswid
.64183 .5 Mdot
1 .116 0 r
.5 Mabswid
.6274 .5 m
.62961 .5 L
s
0 0 0 r
2.5 Mabswid
.62961 .5 Mdot
1 .116 0 r
.5 Mabswid
.61552 .5 m
.61735 .5 L
s
0 0 0 r
2.5 Mabswid
.61735 .5 Mdot
1 .116 0 r
.5 Mabswid
.60365 .5 m
.60507 .5 L
s
0 0 0 r
2.5 Mabswid
.60507 .5 Mdot
1 .116 0 r
.5 Mabswid
.59177 .5 m
.59275 .5 L
s
0 0 0 r
2.5 Mabswid
.59275 .5 Mdot
1 .116 0 r
.5 Mabswid
.5799 .5 m
.5804 .5 L
s
0 0 0 r
2.5 Mabswid
.5804 .5 Mdot
1 .116 0 r
.5 Mabswid
.56803 .5 m
.56803 .5 L
s
0 0 0 r
2.5 Mabswid
.56803 .5 Mdot
1 .116 0 r
.5 Mabswid
.55615 .5 m
.55562 .5 L
s
0 0 0 r
2.5 Mabswid
.55562 .5 Mdot
1 .116 0 r
.5 Mabswid
.54428 .5 m
.54319 .5 L
s
0 0 0 r
2.5 Mabswid
.54319 .5 Mdot
1 .116 0 r
.5 Mabswid
.53241 .5 m
.53073 .5 L
s
0 0 0 r
2.5 Mabswid
.53073 .5 Mdot
1 .116 0 r
.5 Mabswid
.52053 .5 m
.51824 .5 L
s
0 0 0 r
2.5 Mabswid
.51824 .5 Mdot
1 .116 0 r
.5 Mabswid
.50866 .5 m
.50572 .5 L
s
0 0 0 r
2.5 Mabswid
.50572 .5 Mdot
1 .116 0 r
.5 Mabswid
.49678 .5 m
.49326 .5 L
s
0 0 0 r
2.5 Mabswid
.49326 .5 Mdot
1 .116 0 r
.5 Mabswid
.4849 .5 m
.48089 .5 L
s
0 0 0 r
2.5 Mabswid
.48089 .5 Mdot
1 .116 0 r
.5 Mabswid
.47302 .5 m
.46855 .5 L
s
0 0 0 r
2.5 Mabswid
.46855 .5 Mdot
1 .116 0 r
.5 Mabswid
.46114 .5 m
.45624 .5 L
s
0 0 0 r
2.5 Mabswid
.45624 .5 Mdot
1 .116 0 r
.5 Mabswid
.44925 .5 m
.44395 .5 L
s
0 0 0 r
2.5 Mabswid
.44395 .5 Mdot
1 .116 0 r
.5 Mabswid
.43736 .5 m
.43169 .5 L
s
0 0 0 r
2.5 Mabswid
.43169 .5 Mdot
1 .116 0 r
.5 Mabswid
.42547 .5 m
.41945 .5 L
s
0 0 0 r
2.5 Mabswid
.41945 .5 Mdot
1 .115 0 r
.5 Mabswid
.41357 .5 m
.40723 .5 L
s
0 0 0 r
2.5 Mabswid
.40723 .5 Mdot
1 .115 0 r
.5 Mabswid
.40167 .5 m
.39504 .5 L
s
0 0 0 r
2.5 Mabswid
.39504 .5 Mdot
1 .115 0 r
.5 Mabswid
.38977 .5 m
.3829 .5 L
s
0 0 0 r
2.5 Mabswid
.3829 .5 Mdot
1 .115 0 r
.5 Mabswid
.37786 .5 m
.37078 .5 L
s
0 0 0 r
2.5 Mabswid
.37078 .5 Mdot
1 .115 0 r
.5 Mabswid
.36595 .5 m
.35869 .5 L
s
0 0 0 r
2.5 Mabswid
.35869 .5 Mdot
1 .115 0 r
.5 Mabswid
.35403 .5 m
.34663 .5 L
s
0 0 0 r
2.5 Mabswid
.34663 .5 Mdot
1 .115 0 r
.5 Mabswid
.34211 .5 m
.33458 .5 L
s
0 0 0 r
2.5 Mabswid
.33458 .5 Mdot
1 .094 0 r
.5 Mabswid
.33009 .5 m
.3971 .5 L
s
0 0 0 r
2.5 Mabswid
.3971 .5 Mdot
1 .094 0 r
.5 Mabswid
.31779 .5 m
.38034 .5 L
s
0 0 0 r
2.5 Mabswid
.38034 .5 Mdot
1 .094 0 r
.5 Mabswid
.30544 .5 m
.3636 .5 L
s
0 0 0 r
2.5 Mabswid
.3636 .5 Mdot
1 .093 0 r
.5 Mabswid
.29306 .5 m
.34686 .5 L
s
0 0 0 r
2.5 Mabswid
.34686 .5 Mdot
1 .093 0 r
.5 Mabswid
.28063 .5 m
.33014 .5 L
s
0 0 0 r
2.5 Mabswid
.33014 .5 Mdot
1 .092 0 r
.5 Mabswid
.26816 .5 m
.31343 .5 L
s
0 0 0 r
2.5 Mabswid
.31343 .5 Mdot
1 .092 0 r
.5 Mabswid
.25564 .5 m
.29672 .5 L
s
0 0 0 r
2.5 Mabswid
.29672 .5 Mdot
1 .056 0 r
.5 Mabswid
.24256 .5 m
.24256 .5 L
s
0 0 0 r
2.5 Mabswid
.24256 .5 Mdot
1 .054 0 r
.5 Mabswid
.22936 .5 m
.22936 .5 L
s
0 0 0 r
2.5 Mabswid
.22936 .5 Mdot
1 .053 0 r
.5 Mabswid
.21607 .5 m
.21607 .5 L
s
0 0 0 r
2.5 Mabswid
.21607 .5 Mdot
1 .053 0 r
.5 Mabswid
.20269 .5 m
.20269 .5 L
s
0 0 0 r
2.5 Mabswid
.20269 .5 Mdot
1 .866 0 r
.5 Mabswid
.81193 .5 m
.82012 .4778 L
s
0 0 0 r
2.5 Mabswid
.82012 .4778 Mdot
.8 1 0 r
.5 Mabswid
.81193 .5 m
.81193 .5 L
s
0 0 0 r
2.5 Mabswid
.81193 .5 Mdot
1 .878 0 r
.5 Mabswid
.79899 .5 m
.81001 .46936 L
s
0 0 0 r
2.5 Mabswid
.81001 .46936 Mdot
.765 1 0 r
.5 Mabswid
.79899 .5 m
.79899 .5 L
s
0 0 0 r
2.5 Mabswid
.79899 .5 Mdot
1 .871 0 r
.5 Mabswid
.78614 .5 m
.79982 .46094 L
s
0 0 0 r
2.5 Mabswid
.79982 .46094 Mdot
.766 1 0 r
.5 Mabswid
.78614 .5 m
.78614 .5 L
s
0 0 0 r
2.5 Mabswid
.78614 .5 Mdot
1 .864 0 r
.5 Mabswid
.77336 .5 m
.78954 .45256 L
s
0 0 0 r
2.5 Mabswid
.78954 .45256 Mdot
.767 1 0 r
.5 Mabswid
.77336 .5 m
.77336 .5 L
s
0 0 0 r
2.5 Mabswid
.77336 .5 Mdot
1 .857 0 r
.5 Mabswid
.76068 .5 m
.77919 .44421 L
s
0 0 0 r
2.5 Mabswid
.77919 .44421 Mdot
.768 1 0 r
.5 Mabswid
.76068 .5 m
.76068 .5 L
s
0 0 0 r
2.5 Mabswid
.76068 .5 Mdot
1 .85 0 r
.5 Mabswid
.74807 .5 m
.76875 .43589 L
s
0 0 0 r
2.5 Mabswid
.76875 .43589 Mdot
.77 1 0 r
.5 Mabswid
.74807 .5 m
.74807 .5 L
s
0 0 0 r
2.5 Mabswid
.74807 .5 Mdot
1 .096 0 r
.5 Mabswid
.68749 .5 m
.36677 .55035 L
s
0 0 0 r
2.5 Mabswid
.36677 .55035 Mdot
1 .096 0 r
.5 Mabswid
.67074 .5 m
.37994 .54558 L
s
0 0 0 r
2.5 Mabswid
.37994 .54558 Mdot
1 .097 0 r
.5 Mabswid
.65398 .5 m
.39304 .54083 L
s
0 0 0 r
2.5 Mabswid
.39304 .54083 Mdot
1 .097 0 r
.5 Mabswid
.63719 .5 m
.40608 .5361 L
s
0 0 0 r
2.5 Mabswid
.40608 .5361 Mdot
1 .097 0 r
.5 Mabswid
.62039 .5 m
.41905 .53139 L
s
0 0 0 r
2.5 Mabswid
.41905 .53139 Mdot
1 .098 0 r
.5 Mabswid
.60357 .5 m
.43196 .52671 L
s
0 0 0 r
2.5 Mabswid
.43196 .52671 Mdot
1 .116 0 r
.5 Mabswid
.6662 .5 m
.30535 .57262 L
s
0 0 0 r
2.5 Mabswid
.30535 .57262 Mdot
1 .116 0 r
.5 Mabswid
.65403 .5 m
.32113 .5669 L
s
0 0 0 r
2.5 Mabswid
.32113 .5669 Mdot
1 .116 0 r
.5 Mabswid
.64183 .5 m
.33685 .5612 L
s
0 0 0 r
2.5 Mabswid
.33685 .5612 Mdot
1 .116 0 r
.5 Mabswid
.62961 .5 m
.3525 .55553 L
s
0 0 0 r
2.5 Mabswid
.3525 .55553 Mdot
1 .116 0 r
.5 Mabswid
.61735 .5 m
.36809 .54987 L
s
0 0 0 r
2.5 Mabswid
.36809 .54987 Mdot
1 .116 0 r
.5 Mabswid
.60507 .5 m
.38361 .54425 L
s
0 0 0 r
2.5 Mabswid
.38361 .54425 Mdot
1 .116 0 r
.5 Mabswid
.59275 .5 m
.40034 .42046 L
s
0 0 0 r
2.5 Mabswid
.40034 .42046 Mdot
1 .116 0 r
.5 Mabswid
.5804 .5 m
.41361 .43116 L
s
0 0 0 r
2.5 Mabswid
.41361 .43116 Mdot
1 .116 0 r
.5 Mabswid
.56803 .5 m
.42714 .44195 L
s
0 0 0 r
2.5 Mabswid
.42714 .44195 Mdot
1 .116 0 r
.5 Mabswid
.55562 .5 m
.44062 .45269 L
s
0 0 0 r
2.5 Mabswid
.44062 .45269 Mdot
1 .116 0 r
.5 Mabswid
.54319 .5 m
.45404 .46338 L
s
0 0 0 r
2.5 Mabswid
.45404 .46338 Mdot
1 .116 0 r
.5 Mabswid
.53073 .5 m
.46741 .47403 L
s
0 0 0 r
2.5 Mabswid
.46741 .47403 Mdot
1 .116 0 r
.5 Mabswid
.51824 .5 m
.48072 .48464 L
s
0 0 0 r
2.5 Mabswid
.48072 .48464 Mdot
1 .116 0 r
.5 Mabswid
.50572 .5 m
.49397 .4952 L
s
0 0 0 r
2.5 Mabswid
.49397 .4952 Mdot
1 .116 0 r
.5 Mabswid
.49326 .5 m
.50736 .50587 L
s
0 0 0 r
2.5 Mabswid
.50736 .50587 Mdot
1 .116 0 r
.5 Mabswid
.48089 .5 m
.52094 .51668 L
s
0 0 0 r
2.5 Mabswid
.52094 .51668 Mdot
1 .116 0 r
.5 Mabswid
.46855 .5 m
.53457 .52755 L
s
0 0 0 r
2.5 Mabswid
.53457 .52755 Mdot
1 .116 0 r
.5 Mabswid
.45624 .5 m
.54827 .53846 L
s
0 0 0 r
2.5 Mabswid
.54827 .53846 Mdot
1 .116 0 r
.5 Mabswid
.44395 .5 m
.56203 .54943 L
s
0 0 0 r
2.5 Mabswid
.56203 .54943 Mdot
1 .116 0 r
.5 Mabswid
.43169 .5 m
.57585 .56044 L
s
0 0 0 r
2.5 Mabswid
.57585 .56044 Mdot
1 .116 0 r
.5 Mabswid
.41945 .5 m
.58974 .5715 L
s
0 0 0 r
2.5 Mabswid
.58974 .5715 Mdot
1 .115 0 r
.5 Mabswid
.40723 .5 m
.6029 .58229 L
s
0 0 0 r
2.5 Mabswid
.6029 .58229 Mdot
1 .115 0 r
.5 Mabswid
.39504 .5 m
.62072 .54582 L
s
0 0 0 r
2.5 Mabswid
.62072 .54582 Mdot
1 .115 0 r
.5 Mabswid
.3829 .5 m
.63663 .55159 L
s
0 0 0 r
2.5 Mabswid
.63663 .55159 Mdot
1 .115 0 r
.5 Mabswid
.37078 .5 m
.65262 .55739 L
s
0 0 0 r
2.5 Mabswid
.65262 .55739 Mdot
1 .115 0 r
.5 Mabswid
.35869 .5 m
.66867 .56321 L
s
0 0 0 r
2.5 Mabswid
.66867 .56321 Mdot
1 .115 0 r
.5 Mabswid
.34663 .5 m
.6848 .56906 L
s
0 0 0 r
2.5 Mabswid
.6848 .56906 Mdot
1 .115 0 r
.5 Mabswid
.33458 .5 m
.701 .57493 L
s
0 0 0 r
2.5 Mabswid
.701 .57493 Mdot
1 .094 0 r
.5 Mabswid
.3971 .5 m
.56998 .52742 L
s
0 0 0 r
2.5 Mabswid
.56998 .52742 Mdot
1 .094 0 r
.5 Mabswid
.38034 .5 m
.58327 .53224 L
s
0 0 0 r
2.5 Mabswid
.58327 .53224 Mdot
1 .094 0 r
.5 Mabswid
.3636 .5 m
.59662 .53708 L
s
0 0 0 r
2.5 Mabswid
.59662 .53708 Mdot
1 .093 0 r
.5 Mabswid
.34686 .5 m
.61004 .54195 L
s
0 0 0 r
2.5 Mabswid
.61004 .54195 Mdot
1 .093 0 r
.5 Mabswid
.33014 .5 m
.62353 .54684 L
s
0 0 0 r
2.5 Mabswid
.62353 .54684 Mdot
1 .092 0 r
.5 Mabswid
.31343 .5 m
.63709 .55176 L
s
0 0 0 r
2.5 Mabswid
.63709 .55176 Mdot
1 .092 0 r
.5 Mabswid
.29672 .5 m
.65073 .5567 L
s
0 0 0 r
2.5 Mabswid
.65073 .5567 Mdot
1 .992 0 r
.5 Mabswid
.24256 .5 m
.2178 .44285 L
s
0 0 0 r
2.5 Mabswid
.2178 .44285 Mdot
.782 1 0 r
.5 Mabswid
.24256 .5 m
.24256 .5 L
s
0 0 0 r
2.5 Mabswid
.24256 .5 Mdot
1 .946 0 r
.5 Mabswid
.22936 .5 m
.20787 .45141 L
s
0 0 0 r
2.5 Mabswid
.20787 .45141 Mdot
.757 1 0 r
.5 Mabswid
.22936 .5 m
.22936 .5 L
s
0 0 0 r
2.5 Mabswid
.22936 .5 Mdot
1 .954 0 r
.5 Mabswid
.21607 .5 m
.19802 .46001 L
s
0 0 0 r
2.5 Mabswid
.19802 .46001 Mdot
.757 1 0 r
.5 Mabswid
.21607 .5 m
.21607 .5 L
s
0 0 0 r
2.5 Mabswid
.21607 .5 Mdot
1 .962 0 r
.5 Mabswid
.20269 .5 m
.18825 .46865 L
s
0 0 0 r
2.5 Mabswid
.18825 .46865 Mdot
.756 1 0 r
.5 Mabswid
.20269 .5 m
.20269 .5 L
s
0 0 0 r
2.5 Mabswid
.20269 .5 Mdot
.045 1 0 r
.5 Mabswid
.82012 .4778 m
.43333 .39212 L
s
0 0 0 r
2.5 Mabswid
.43333 .39212 Mdot
.8 1 0 r
.5 Mabswid
.81193 .5 m
.81193 .5 L
s
0 0 0 r
2.5 Mabswid
.81193 .5 Mdot
.022 1 0 r
.5 Mabswid
.81001 .46936 m
.39584 .37774 L
s
0 0 0 r
2.5 Mabswid
.39584 .37774 Mdot
.765 1 0 r
.5 Mabswid
.79899 .5 m
.79899 .5 L
s
0 0 0 r
2.5 Mabswid
.79899 .5 Mdot
.031 1 0 r
.5 Mabswid
.79982 .46094 m
.37556 .36722 L
s
0 0 0 r
2.5 Mabswid
.37556 .36722 Mdot
.766 1 0 r
.5 Mabswid
.78614 .5 m
.78614 .5 L
s
0 0 0 r
2.5 Mabswid
.78614 .5 Mdot
.039 1 0 r
.5 Mabswid
.78954 .45256 m
.35878 .35753 L
s
0 0 0 r
2.5 Mabswid
.35878 .35753 Mdot
.767 1 0 r
.5 Mabswid
.77336 .5 m
.77336 .5 L
s
0 0 0 r
2.5 Mabswid
.77336 .5 Mdot
.047 1 0 r
.5 Mabswid
.77919 .44421 m
.34175 .34783 L
s
0 0 0 r
2.5 Mabswid
.34175 .34783 Mdot
.768 1 0 r
.5 Mabswid
.76068 .5 m
.76068 .5 L
s
0 0 0 r
2.5 Mabswid
.76068 .5 Mdot
.056 1 0 r
.5 Mabswid
.76875 .43589 m
.32588 .33843 L
s
0 0 0 r
2.5 Mabswid
.32588 .33843 Mdot
.77 1 0 r
.5 Mabswid
.74807 .5 m
.74807 .5 L
s
0 0 0 r
2.5 Mabswid
.74807 .5 Mdot
1 .096 0 r
.5 Mabswid
.36677 .55035 m
.32929 .49022 L
s
0 0 0 r
2.5 Mabswid
.32929 .49022 Mdot
1 .096 0 r
.5 Mabswid
.37994 .54558 m
.34102 .48237 L
s
0 0 0 r
2.5 Mabswid
.34102 .48237 Mdot
1 .097 0 r
.5 Mabswid
.39304 .54083 m
.35294 .47488 L
s
0 0 0 r
2.5 Mabswid
.35294 .47488 Mdot
1 .097 0 r
.5 Mabswid
.40608 .5361 m
.36484 .46741 L
s
0 0 0 r
2.5 Mabswid
.36484 .46741 Mdot
1 .097 0 r
.5 Mabswid
.41905 .53139 m
.37671 .45996 L
s
0 0 0 r
2.5 Mabswid
.37671 .45996 Mdot
1 .098 0 r
.5 Mabswid
.43196 .52671 m
.38855 .45253 L
s
0 0 0 r
2.5 Mabswid
.38855 .45253 Mdot
1 .116 0 r
.5 Mabswid
.30535 .57262 m
.24627 .55701 L
s
0 0 0 r
2.5 Mabswid
.24627 .55701 Mdot
1 .116 0 r
.5 Mabswid
.32113 .5669 m
.25514 .54921 L
s
0 0 0 r
2.5 Mabswid
.25514 .54921 Mdot
1 .116 0 r
.5 Mabswid
.33685 .5612 m
.26401 .54142 L
s
0 0 0 r
2.5 Mabswid
.26401 .54142 Mdot
1 .116 0 r
.5 Mabswid
.3525 .55553 m
.2729 .53361 L
s
0 0 0 r
2.5 Mabswid
.2729 .53361 Mdot
1 .116 0 r
.5 Mabswid
.36809 .54987 m
.2818 .5258 L
s
0 0 0 r
2.5 Mabswid
.2818 .5258 Mdot
1 .116 0 r
.5 Mabswid
.38361 .54425 m
.29163 .51823 L
s
0 0 0 r
2.5 Mabswid
.29163 .51823 Mdot
1 .116 0 r
.5 Mabswid
.40034 .42046 m
.30557 .42791 L
s
0 0 0 r
2.5 Mabswid
.30557 .42791 Mdot
1 .116 0 r
.5 Mabswid
.41361 .43116 m
.32594 .39485 L
s
0 0 0 r
2.5 Mabswid
.32594 .39485 Mdot
1 .116 0 r
.5 Mabswid
.42714 .44195 m
.33387 .40351 L
s
0 0 0 r
2.5 Mabswid
.33387 .40351 Mdot
1 .116 0 r
.5 Mabswid
.44062 .45269 m
.34229 .41238 L
s
0 0 0 r
2.5 Mabswid
.34229 .41238 Mdot
1 .116 0 r
.5 Mabswid
.45404 .46338 m
.35132 .4215 L
s
0 0 0 r
2.5 Mabswid
.35132 .4215 Mdot
1 .116 0 r
.5 Mabswid
.46741 .47403 m
.36113 .43094 L
s
0 0 0 r
2.5 Mabswid
.36113 .43094 Mdot
1 .116 0 r
.5 Mabswid
.48072 .48464 m
.37093 .44037 L
s
0 0 0 r
2.5 Mabswid
.37093 .44037 Mdot
1 .116 0 r
.5 Mabswid
.49397 .4952 m
.38072 .44979 L
s
0 0 0 r
2.5 Mabswid
.38072 .44979 Mdot
1 .116 0 r
.5 Mabswid
.50736 .50587 m
.62525 .55595 L
s
0 0 0 r
2.5 Mabswid
.62525 .55595 Mdot
1 .116 0 r
.5 Mabswid
.52094 .51668 m
.63509 .56542 L
s
0 0 0 r
2.5 Mabswid
.63509 .56542 Mdot
1 .116 0 r
.5 Mabswid
.53457 .52755 m
.64494 .5749 L
s
0 0 0 r
2.5 Mabswid
.64494 .5749 Mdot
1 .116 0 r
.5 Mabswid
.54827 .53846 m
.65453 .58427 L
s
0 0 0 r
2.5 Mabswid
.65453 .58427 Mdot
1 .116 0 r
.5 Mabswid
.56203 .54943 m
.66295 .59314 L
s
0 0 0 r
2.5 Mabswid
.66295 .59314 Mdot
1 .116 0 r
.5 Mabswid
.57585 .56044 m
.67111 .60189 L
s
0 0 0 r
2.5 Mabswid
.67111 .60189 Mdot
1 .116 0 r
.5 Mabswid
.58974 .5715 m
.67885 .61046 L
s
0 0 0 r
2.5 Mabswid
.67885 .61046 Mdot
1 .115 0 r
.5 Mabswid
.6029 .58229 m
.69782 .57894 L
s
0 0 0 r
2.5 Mabswid
.69782 .57894 Mdot
1 .115 0 r
.5 Mabswid
.62072 .54582 m
.71425 .52362 L
s
0 0 0 r
2.5 Mabswid
.71425 .52362 Mdot
1 .115 0 r
.5 Mabswid
.63663 .55159 m
.7234 .5313 L
s
0 0 0 r
2.5 Mabswid
.7234 .5313 Mdot
1 .115 0 r
.5 Mabswid
.65262 .55739 m
.73229 .53902 L
s
0 0 0 r
2.5 Mabswid
.73229 .53902 Mdot
1 .115 0 r
.5 Mabswid
.66867 .56321 m
.74117 .54674 L
s
0 0 0 r
2.5 Mabswid
.74117 .54674 Mdot
1 .115 0 r
.5 Mabswid
.6848 .56906 m
.75004 .55446 L
s
0 0 0 r
2.5 Mabswid
.75004 .55446 Mdot
1 .115 0 r
.5 Mabswid
.701 .57493 m
.75891 .56217 L
s
0 0 0 r
2.5 Mabswid
.75891 .56217 Mdot
1 .094 0 r
.5 Mabswid
.56998 .52742 m
.61686 .45748 L
s
0 0 0 r
2.5 Mabswid
.61686 .45748 Mdot
1 .094 0 r
.5 Mabswid
.58327 .53224 m
.6289 .46498 L
s
0 0 0 r
2.5 Mabswid
.6289 .46498 Mdot
1 .094 0 r
.5 Mabswid
.59662 .53708 m
.64096 .4725 L
s
0 0 0 r
2.5 Mabswid
.64096 .4725 Mdot
1 .093 0 r
.5 Mabswid
.61004 .54195 m
.65306 .48004 L
s
0 0 0 r
2.5 Mabswid
.65306 .48004 Mdot
1 .093 0 r
.5 Mabswid
.62353 .54684 m
.66519 .4876 L
s
0 0 0 r
2.5 Mabswid
.66519 .4876 Mdot
1 .092 0 r
.5 Mabswid
.63709 .55176 m
.67677 .49598 L
s
0 0 0 r
2.5 Mabswid
.67677 .49598 Mdot
1 .092 0 r
.5 Mabswid
.65073 .5567 m
.68831 .50449 L
s
0 0 0 r
2.5 Mabswid
.68831 .50449 Mdot
0 1 .598 r
.5 Mabswid
.2178 .44285 m
.61907 .35292 L
s
0 0 0 r
2.5 Mabswid
.61907 .35292 Mdot
.782 1 0 r
.5 Mabswid
.24256 .5 m
.24256 .5 L
s
0 0 0 r
2.5 Mabswid
.24256 .5 Mdot
0 1 .056 r
.5 Mabswid
.20787 .45141 m
.60346 .36257 L
s
0 0 0 r
2.5 Mabswid
.60346 .36257 Mdot
.757 1 0 r
.5 Mabswid
.22936 .5 m
.22936 .5 L
s
0 0 0 r
2.5 Mabswid
.22936 .5 Mdot
0 1 .066 r
.5 Mabswid
.19802 .46001 m
.57382 .37544 L
s
0 0 0 r
2.5 Mabswid
.57382 .37544 Mdot
.757 1 0 r
.5 Mabswid
.21607 .5 m
.21607 .5 L
s
0 0 0 r
2.5 Mabswid
.21607 .5 Mdot
0 1 .075 r
.5 Mabswid
.18825 .46865 m
.54111 .38908 L
s
0 0 0 r
2.5 Mabswid
.54111 .38908 Mdot
.756 1 0 r
.5 Mabswid
.20269 .5 m
.20269 .5 L
s
0 0 0 r
2.5 Mabswid
.20269 .5 Mdot
0 1 .403 r
.5 Mabswid
.43333 .39212 m
.2803 .35822 L
s
0 0 0 r
2.5 Mabswid
.2803 .35822 Mdot
.8 1 0 r
.5 Mabswid
.81193 .5 m
.81193 .5 L
s
0 0 0 r
2.5 Mabswid
.81193 .5 Mdot
0 1 .517 r
.5 Mabswid
.39584 .37774 m
.32339 .36171 L
s
0 0 0 r
2.5 Mabswid
.32339 .36171 Mdot
.765 1 0 r
.5 Mabswid
.79899 .5 m
.79899 .5 L
s
0 0 0 r
2.5 Mabswid
.79899 .5 Mdot
0 1 .665 r
.5 Mabswid
.37556 .36722 m
.24352 .38952 L
s
0 0 0 r
2.5 Mabswid
.24352 .38952 Mdot
.766 1 0 r
.5 Mabswid
.78614 .5 m
.78614 .5 L
s
0 0 0 r
2.5 Mabswid
.78614 .5 Mdot
0 1 .653 r
.5 Mabswid
.35878 .35753 m
.23871 .37737 L
s
0 0 0 r
2.5 Mabswid
.23871 .37737 Mdot
.767 1 0 r
.5 Mabswid
.77336 .5 m
.77336 .5 L
s
0 0 0 r
2.5 Mabswid
.77336 .5 Mdot
0 1 .64 r
.5 Mabswid
.34175 .34783 m
.23441 .36517 L
s
0 0 0 r
2.5 Mabswid
.23441 .36517 Mdot
.768 1 0 r
.5 Mabswid
.76068 .5 m
.76068 .5 L
s
0 0 0 r
2.5 Mabswid
.76068 .5 Mdot
0 1 .65 r
.5 Mabswid
.32588 .33843 m
.30484 .36275 L
s
0 0 0 r
2.5 Mabswid
.30484 .36275 Mdot
.77 1 0 r
.5 Mabswid
.74807 .5 m
.74807 .5 L
s
0 0 0 r
2.5 Mabswid
.74807 .5 Mdot
1 .728 0 r
.5 Mabswid
.32929 .49022 m
.5628 .40873 L
s
0 0 0 r
2.5 Mabswid
.5628 .40873 Mdot
.778 1 0 r
.5 Mabswid
.34102 .48237 m
.31019 .43228 L
s
0 0 0 r
2.5 Mabswid
.31019 .43228 Mdot
.789 1 0 r
.5 Mabswid
.35294 .47488 m
.3216 .42333 L
s
0 0 0 r
2.5 Mabswid
.3216 .42333 Mdot
.793 1 0 r
.5 Mabswid
.36484 .46741 m
.33301 .41439 L
s
0 0 0 r
2.5 Mabswid
.33301 .41439 Mdot
.797 1 0 r
.5 Mabswid
.37671 .45996 m
.34445 .40555 L
s
0 0 0 r
2.5 Mabswid
.34445 .40555 Mdot
.801 1 0 r
.5 Mabswid
.38855 .45253 m
.35604 .39699 L
s
0 0 0 r
2.5 Mabswid
.35604 .39699 Mdot
1 .886 0 r
.5 Mabswid
.24627 .55701 m
.52128 .35765 L
s
0 0 0 r
2.5 Mabswid
.52128 .35765 Mdot
.857 1 0 r
.5 Mabswid
.25514 .54921 m
.53 .34991 L
s
0 0 0 r
2.5 Mabswid
.53 .34991 Mdot
.866 1 0 r
.5 Mabswid
.26401 .54142 m
.53843 .34237 L
s
0 0 0 r
2.5 Mabswid
.53843 .34237 Mdot
.874 1 0 r
.5 Mabswid
.2729 .53361 m
.54687 .33483 L
s
0 0 0 r
2.5 Mabswid
.54687 .33483 Mdot
.884 1 0 r
.5 Mabswid
.2818 .5258 m
.55532 .32728 L
s
0 0 0 r
2.5 Mabswid
.55532 .32728 Mdot
.806 1 0 r
.5 Mabswid
.29163 .51823 m
.47125 .48313 L
s
0 0 0 r
2.5 Mabswid
.47125 .48313 Mdot
1 .99 0 r
.5 Mabswid
.30557 .42791 m
.60042 .61907 L
s
0 0 0 r
2.5 Mabswid
.60042 .61907 Mdot
.303 1 0 r
.5 Mabswid
.32594 .39485 m
.64608 .52903 L
s
0 0 0 r
2.5 Mabswid
.64608 .52903 Mdot
.89 1 0 r
.5 Mabswid
.33387 .40351 m
.4267 .55605 L
s
0 0 0 r
2.5 Mabswid
.4267 .55605 Mdot
.865 1 0 r
.5 Mabswid
.34229 .41238 m
.43742 .56849 L
s
0 0 0 r
2.5 Mabswid
.43742 .56849 Mdot
.364 1 0 r
.5 Mabswid
.35132 .4215 m
.29127 .39702 L
s
0 0 0 r
2.5 Mabswid
.29127 .39702 Mdot
.37 1 0 r
.5 Mabswid
.36113 .43094 m
.29883 .40568 L
s
0 0 0 r
2.5 Mabswid
.29883 .40568 Mdot
.378 1 0 r
.5 Mabswid
.37093 .44037 m
.3064 .41435 L
s
0 0 0 r
2.5 Mabswid
.3064 .41435 Mdot
.385 1 0 r
.5 Mabswid
.38072 .44979 m
.31398 .42303 L
s
0 0 0 r
2.5 Mabswid
.31398 .42303 Mdot
.298 1 0 r
.5 Mabswid
.62525 .55595 m
.69269 .58461 L
s
0 0 0 r
2.5 Mabswid
.69269 .58461 Mdot
.284 1 0 r
.5 Mabswid
.63509 .56542 m
.70022 .59323 L
s
0 0 0 r
2.5 Mabswid
.70022 .59323 Mdot
.274 1 0 r
.5 Mabswid
.64494 .5749 m
.70774 .60184 L
s
0 0 0 r
2.5 Mabswid
.70774 .60184 Mdot
.88 1 0 r
.5 Mabswid
.65453 .58427 m
.56293 .43189 L
s
0 0 0 r
2.5 Mabswid
.56293 .43189 Mdot
.865 1 0 r
.5 Mabswid
.66295 .59314 m
.57365 .44437 L
s
0 0 0 r
2.5 Mabswid
.57365 .44437 Mdot
.4 1 0 r
.5 Mabswid
.67111 .60189 m
.35462 .47182 L
s
0 0 0 r
2.5 Mabswid
.35462 .47182 Mdot
.406 1 0 r
.5 Mabswid
.67885 .61046 m
.36191 .48046 L
s
0 0 0 r
2.5 Mabswid
.36191 .48046 Mdot
.282 1 0 r
.5 Mabswid
.69782 .57894 m
.40303 .39181 L
s
0 0 0 r
2.5 Mabswid
.40303 .39181 Mdot
.813 1 0 r
.5 Mabswid
.71425 .52362 m
.54548 .49426 L
s
0 0 0 r
2.5 Mabswid
.54548 .49426 Mdot
.819 1 0 r
.5 Mabswid
.7234 .5313 m
.45374 .33439 L
s
0 0 0 r
2.5 Mabswid
.45374 .33439 Mdot
.814 1 0 r
.5 Mabswid
.73229 .53902 m
.46222 .34187 L
s
0 0 0 r
2.5 Mabswid
.46222 .34187 Mdot
.81 1 0 r
.5 Mabswid
.74117 .54674 m
.4708 .34942 L
s
0 0 0 r
2.5 Mabswid
.4708 .34942 Mdot
.806 1 0 r
.5 Mabswid
.75004 .55446 m
.47961 .35715 L
s
0 0 0 r
2.5 Mabswid
.47961 .35715 Mdot
.803 1 0 r
.5 Mabswid
.75891 .56217 m
.48843 .36488 L
s
0 0 0 r
2.5 Mabswid
.48843 .36488 Mdot
.8 1 0 r
.5 Mabswid
.61686 .45748 m
.65189 .40522 L
s
0 0 0 r
2.5 Mabswid
.65189 .40522 Mdot
.746 1 0 r
.5 Mabswid
.6289 .46498 m
.66346 .41404 L
s
0 0 0 r
2.5 Mabswid
.66346 .41404 Mdot
.741 1 0 r
.5 Mabswid
.64096 .4725 m
.67497 .42297 L
s
0 0 0 r
2.5 Mabswid
.67497 .42297 Mdot
.737 1 0 r
.5 Mabswid
.65306 .48004 m
.68649 .43192 L
s
0 0 0 r
2.5 Mabswid
.68649 .43192 Mdot
.732 1 0 r
.5 Mabswid
.66519 .4876 m
.69803 .44088 L
s
0 0 0 r
2.5 Mabswid
.69803 .44088 Mdot
.514 1 0 r
.5 Mabswid
.67677 .49598 m
.44339 .41785 L
s
0 0 0 r
2.5 Mabswid
.44339 .41785 Mdot
.514 1 0 r
.5 Mabswid
.68831 .50449 m
.45225 .42564 L
s
0 0 0 r
2.5 Mabswid
.45225 .42564 Mdot
0 .282 1 r
.5 Mabswid
.61907 .35292 m
.74368 .3783 L
s
0 0 0 r
2.5 Mabswid
.74368 .3783 Mdot
.782 1 0 r
.5 Mabswid
.24256 .5 m
.24256 .5 L
s
0 0 0 r
2.5 Mabswid
.24256 .5 Mdot
0 1 .797 r
.5 Mabswid
.60346 .36257 m
.73905 .39075 L
s
0 0 0 r
2.5 Mabswid
.73905 .39075 Mdot
.757 1 0 r
.5 Mabswid
.22936 .5 m
.22936 .5 L
s
0 0 0 r
2.5 Mabswid
.22936 .5 Mdot
0 1 .676 r
.5 Mabswid
.57382 .37544 m
.72024 .3425 L
s
0 0 0 r
2.5 Mabswid
.72024 .3425 Mdot
.757 1 0 r
.5 Mabswid
.21607 .5 m
.21607 .5 L
s
0 0 0 r
2.5 Mabswid
.21607 .5 Mdot
0 1 .693 r
.5 Mabswid
.54111 .38908 m
.76162 .33936 L
s
0 0 0 r
2.5 Mabswid
.76162 .33936 Mdot
.756 1 0 r
.5 Mabswid
.20269 .5 m
.20269 .5 L
s
0 0 0 r
2.5 Mabswid
.20269 .5 Mdot
0 1 .975 r
.5 Mabswid
.2803 .35822 m
.21366 .34902 L
s
0 0 0 r
2.5 Mabswid
.21366 .34902 Mdot
.8 1 0 r
.5 Mabswid
.81193 .5 m
.81193 .5 L
s
0 0 0 r
2.5 Mabswid
.81193 .5 Mdot
0 1 .935 r
.5 Mabswid
.32339 .36171 m
.22571 .34844 L
s
0 0 0 r
2.5 Mabswid
.22571 .34844 Mdot
.765 1 0 r
.5 Mabswid
.79899 .5 m
.79899 .5 L
s
0 0 0 r
2.5 Mabswid
.79899 .5 Mdot
.03 0 1 r
.5 Mabswid
.24352 .38952 m
.38136 .54289 L
s
0 0 0 r
2.5 Mabswid
.38136 .54289 Mdot
.766 1 0 r
.5 Mabswid
.78614 .5 m
.78614 .5 L
s
0 0 0 r
2.5 Mabswid
.78614 .5 Mdot
.089 0 1 r
.5 Mabswid
.23871 .37737 m
.34708 .60308 L
s
0 0 0 r
2.5 Mabswid
.34708 .60308 Mdot
.767 1 0 r
.5 Mabswid
.77336 .5 m
.77336 .5 L
s
0 0 0 r
2.5 Mabswid
.77336 .5 Mdot
.069 0 1 r
.5 Mabswid
.23441 .36517 m
.33753 .58091 L
s
0 0 0 r
2.5 Mabswid
.33753 .58091 Mdot
.768 1 0 r
.5 Mabswid
.76068 .5 m
.76068 .5 L
s
0 0 0 r
2.5 Mabswid
.76068 .5 Mdot
0 .38 1 r
.5 Mabswid
.30484 .36275 m
.69673 .74183 L
s
0 0 0 r
2.5 Mabswid
.69673 .74183 Mdot
.77 1 0 r
.5 Mabswid
.74807 .5 m
.74807 .5 L
s
0 0 0 r
2.5 Mabswid
.74807 .5 Mdot
1 .728 0 r
.5 Mabswid
.5628 .40873 m
.62929 .78147 L
s
0 0 0 r
2.5 Mabswid
.62929 .78147 Mdot
.778 1 0 r
.5 Mabswid
.31019 .43228 m
.77948 .54795 L
s
0 0 0 r
2.5 Mabswid
.77948 .54795 Mdot
.789 1 0 r
.5 Mabswid
.3216 .42333 m
.78992 .5382 L
s
0 0 0 r
2.5 Mabswid
.78992 .5382 Mdot
.793 1 0 r
.5 Mabswid
.33301 .41439 m
.80034 .52846 L
s
0 0 0 r
2.5 Mabswid
.80034 .52846 Mdot
.797 1 0 r
.5 Mabswid
.34445 .40555 m
.78797 .63675 L
s
0 0 0 r
2.5 Mabswid
.78797 .63675 Mdot
.801 1 0 r
.5 Mabswid
.35604 .39699 m
.79952 .62745 L
s
0 0 0 r
2.5 Mabswid
.79952 .62745 Mdot
1 .886 0 r
.5 Mabswid
.52128 .35765 m
.69944 .60386 L
s
0 0 0 r
2.5 Mabswid
.69944 .60386 Mdot
.857 1 0 r
.5 Mabswid
.53 .34991 m
.6104 .56768 L
s
0 0 0 r
2.5 Mabswid
.6104 .56768 Mdot
.866 1 0 r
.5 Mabswid
.53843 .34237 m
.61657 .55288 L
s
0 0 0 r
2.5 Mabswid
.61657 .55288 Mdot
.874 1 0 r
.5 Mabswid
.54687 .33483 m
.62273 .5381 L
s
0 0 0 r
2.5 Mabswid
.62273 .5381 Mdot
.884 1 0 r
.5 Mabswid
.55532 .32728 m
.62888 .52335 L
s
0 0 0 r
2.5 Mabswid
.62888 .52335 Mdot
.806 1 0 r
.5 Mabswid
.47125 .48313 m
.51724 .4894 L
s
0 0 0 r
2.5 Mabswid
.51724 .4894 Mdot
0 1 .145 r
.5 Mabswid
.60042 .61907 m
.59016 .40042 L
s
0 0 0 r
2.5 Mabswid
.59016 .40042 Mdot
0 1 .871 r
.5 Mabswid
.64608 .52903 m
.49455 .46829 L
s
0 0 0 r
2.5 Mabswid
.49455 .46829 Mdot
.89 1 0 r
.5 Mabswid
.4267 .55605 m
.57855 .571 L
s
0 0 0 r
2.5 Mabswid
.57855 .571 Mdot
.865 1 0 r
.5 Mabswid
.43742 .56849 m
.71219 .31629 L
s
0 0 0 r
2.5 Mabswid
.71219 .31629 Mdot
0 1 .928 r
.5 Mabswid
.29127 .39702 m
.68556 .56006 L
s
0 0 0 r
2.5 Mabswid
.68556 .56006 Mdot
0 1 .754 r
.5 Mabswid
.29883 .40568 m
.69499 .56977 L
s
0 0 0 r
2.5 Mabswid
.69499 .56977 Mdot
0 1 .653 r
.5 Mabswid
.3064 .41435 m
.70442 .57949 L
s
0 0 0 r
2.5 Mabswid
.70442 .57949 Mdot
0 1 .542 r
.5 Mabswid
.31398 .42303 m
.71387 .58923 L
s
0 0 0 r
2.5 Mabswid
.71387 .58923 Mdot
0 .111 1 r
.5 Mabswid
.69269 .58461 m
.29905 .42409 L
s
0 0 0 r
2.5 Mabswid
.29905 .42409 Mdot
0 .498 1 r
.5 Mabswid
.70022 .59323 m
.30842 .43374 L
s
0 0 0 r
2.5 Mabswid
.30842 .43374 Mdot
0 .449 1 r
.5 Mabswid
.70774 .60184 m
.31777 .44338 L
s
0 0 0 r
2.5 Mabswid
.31777 .44338 Mdot
.88 1 0 r
.5 Mabswid
.56293 .43189 m
.29403 .68624 L
s
0 0 0 r
2.5 Mabswid
.29403 .68624 Mdot
.865 1 0 r
.5 Mabswid
.57365 .44437 m
.41907 .43122 L
s
0 0 0 r
2.5 Mabswid
.41907 .43122 Mdot
0 1 .699 r
.5 Mabswid
.35462 .47182 m
.51062 .53636 L
s
0 0 0 r
2.5 Mabswid
.51062 .53636 Mdot
0 1 .592 r
.5 Mabswid
.36191 .48046 m
.56758 .46656 L
s
0 0 0 r
2.5 Mabswid
.56758 .46656 Mdot
0 1 .595 r
.5 Mabswid
.40303 .39181 m
.41514 .62546 L
s
0 0 0 r
2.5 Mabswid
.41514 .62546 Mdot
.813 1 0 r
.5 Mabswid
.54548 .49426 m
.47521 .5051 L
s
0 0 0 r
2.5 Mabswid
.47521 .5051 Mdot
.819 1 0 r
.5 Mabswid
.45374 .33439 m
.38259 .54062 L
s
0 0 0 r
2.5 Mabswid
.38259 .54062 Mdot
.814 1 0 r
.5 Mabswid
.46222 .34187 m
.38896 .55542 L
s
0 0 0 r
2.5 Mabswid
.38896 .55542 Mdot
.81 1 0 r
.5 Mabswid
.4708 .34942 m
.29965 .59342 L
s
0 0 0 r
2.5 Mabswid
.29965 .59342 Mdot
.806 1 0 r
.5 Mabswid
.47961 .35715 m
.30383 .60862 L
s
0 0 0 r
2.5 Mabswid
.30383 .60862 Mdot
.803 1 0 r
.5 Mabswid
.48843 .36488 m
.30802 .62384 L
s
0 0 0 r
2.5 Mabswid
.30802 .62384 Mdot
.8 1 0 r
.5 Mabswid
.65189 .40522 m
.21271 .64207 L
s
0 0 0 r
2.5 Mabswid
.21271 .64207 Mdot
.746 1 0 r
.5 Mabswid
.66346 .41404 m
.20056 .53577 L
s
0 0 0 r
2.5 Mabswid
.20056 .53577 Mdot
.741 1 0 r
.5 Mabswid
.67497 .42297 m
.21106 .54552 L
s
0 0 0 r
2.5 Mabswid
.21106 .54552 Mdot
.737 1 0 r
.5 Mabswid
.68649 .43192 m
.22157 .55529 L
s
0 0 0 r
2.5 Mabswid
.22157 .55529 Mdot
.732 1 0 r
.5 Mabswid
.69803 .44088 m
.23431 .56448 L
s
0 0 0 r
2.5 Mabswid
.23431 .56448 Mdot
.514 1 0 r
.5 Mabswid
.44339 .41785 m
.38034 .80042 L
s
0 0 0 r
2.5 Mabswid
.38034 .80042 Mdot
.514 1 0 r
.5 Mabswid
.45225 .42564 m
.38889 .81257 L
s
0 0 0 r
2.5 Mabswid
.38889 .81257 Mdot
.782 1 0 r
.5 Mabswid
.24256 .5 m
.24256 .5 L
s
0 0 0 r
2.5 Mabswid
.24256 .5 Mdot
.757 1 0 r
.5 Mabswid
.22936 .5 m
.22936 .5 L
s
0 0 0 r
2.5 Mabswid
.22936 .5 Mdot
0 .931 1 r
.5 Mabswid
.72024 .3425 m
.78261 .33258 L
s
0 0 0 r
2.5 Mabswid
.78261 .33258 Mdot
.757 1 0 r
.5 Mabswid
.21607 .5 m
.21607 .5 L
s
0 0 0 r
2.5 Mabswid
.21607 .5 Mdot
0 .686 1 r
.5 Mabswid
.76162 .33936 m
.78922 .33926 L
s
0 0 0 r
2.5 Mabswid
.78922 .33926 Mdot
.756 1 0 r
.5 Mabswid
.20269 .5 m
.20269 .5 L
s
0 0 0 r
2.5 Mabswid
.20269 .5 Mdot
0 .029 1 r
.5 Mabswid
.21366 .34902 m
.27354 .43828 L
s
0 0 0 r
2.5 Mabswid
.27354 .43828 Mdot
.8 1 0 r
.5 Mabswid
.81193 .5 m
.81193 .5 L
s
0 0 0 r
2.5 Mabswid
.81193 .5 Mdot
.136 0 1 r
.5 Mabswid
.22571 .34844 m
.30854 .47147 L
s
0 0 0 r
2.5 Mabswid
.30854 .47147 Mdot
.765 1 0 r
.5 Mabswid
.79899 .5 m
.79899 .5 L
s
0 0 0 r
2.5 Mabswid
.79899 .5 Mdot
.766 1 0 r
.5 Mabswid
.78614 .5 m
.78614 .5 L
s
0 0 0 r
2.5 Mabswid
.78614 .5 Mdot
.767 1 0 r
.5 Mabswid
.77336 .5 m
.77336 .5 L
s
0 0 0 r
2.5 Mabswid
.77336 .5 Mdot
.768 1 0 r
.5 Mabswid
.76068 .5 m
.76068 .5 L
s
0 0 0 r
2.5 Mabswid
.76068 .5 Mdot
.77 1 0 r
.5 Mabswid
.74807 .5 m
.74807 .5 L
s
0 0 0 r
2.5 Mabswid
.74807 .5 Mdot
1 .728 0 r
.5 Mabswid
.62929 .78147 m
.61222 .77399 L
s
0 0 0 r
2.5 Mabswid
.61222 .77399 Mdot
.778 1 0 r
.5 Mabswid
.77948 .54795 m
.75922 .54902 L
s
0 0 0 r
2.5 Mabswid
.75922 .54902 Mdot
.789 1 0 r
.5 Mabswid
.78992 .5382 m
.77279 .53903 L
s
0 0 0 r
2.5 Mabswid
.77279 .53903 Mdot
.793 1 0 r
.5 Mabswid
.80034 .52846 m
.7863 .52908 L
s
0 0 0 r
2.5 Mabswid
.7863 .52908 Mdot
.797 1 0 r
.5 Mabswid
.78797 .63675 m
.78859 .64045 L
s
0 0 0 r
2.5 Mabswid
.78859 .64045 Mdot
.801 1 0 r
.5 Mabswid
.79952 .62745 m
.80004 .63034 L
s
0 0 0 r
2.5 Mabswid
.80004 .63034 Mdot
1 .886 0 r
.5 Mabswid
.69944 .60386 m
.56057 .66448 L
s
0 0 0 r
2.5 Mabswid
.56057 .66448 Mdot
.857 1 0 r
.5 Mabswid
.6104 .56768 m
.66241 .70856 L
s
0 0 0 r
2.5 Mabswid
.66241 .70856 Mdot
.866 1 0 r
.5 Mabswid
.61657 .55288 m
.67009 .69708 L
s
0 0 0 r
2.5 Mabswid
.67009 .69708 Mdot
.874 1 0 r
.5 Mabswid
.62273 .5381 m
.67777 .68559 L
s
0 0 0 r
2.5 Mabswid
.67777 .68559 Mdot
.884 1 0 r
.5 Mabswid
.62888 .52335 m
.68493 .67276 L
s
0 0 0 r
2.5 Mabswid
.68493 .67276 Mdot
.806 1 0 r
.5 Mabswid
.51724 .4894 m
.55618 .70422 L
s
0 0 0 r
2.5 Mabswid
.55618 .70422 Mdot
0 1 .145 r
.5 Mabswid
.59016 .40042 m
.58329 .25395 L
s
0 0 0 r
2.5 Mabswid
.58329 .25395 Mdot
0 1 .871 r
.5 Mabswid
.49455 .46829 m
.35347 .41174 L
s
0 0 0 r
2.5 Mabswid
.35347 .41174 Mdot
.89 1 0 r
.5 Mabswid
.57855 .571 m
.67988 .50569 L
s
0 0 0 r
2.5 Mabswid
.67988 .50569 Mdot
.865 1 0 r
.5 Mabswid
.71219 .31629 m
.74023 .28354 L
s
0 0 0 r
2.5 Mabswid
.74023 .28354 Mdot
0 1 .928 r
.5 Mabswid
.68556 .56006 m
.66762 .55165 L
s
0 0 0 r
2.5 Mabswid
.66762 .55165 Mdot
0 1 .754 r
.5 Mabswid
.69499 .56977 m
.67876 .56229 L
s
0 0 0 r
2.5 Mabswid
.67876 .56229 Mdot
0 1 .653 r
.5 Mabswid
.70442 .57949 m
.68988 .5729 L
s
0 0 0 r
2.5 Mabswid
.68988 .5729 Mdot
0 1 .542 r
.5 Mabswid
.71387 .58923 m
.70096 .58349 L
s
0 0 0 r
2.5 Mabswid
.70096 .58349 Mdot
0 .111 1 r
.5 Mabswid
.29905 .42409 m
.31658 .43326 L
s
0 0 0 r
2.5 Mabswid
.31658 .43326 Mdot
0 .498 1 r
.5 Mabswid
.30842 .43374 m
.32785 .44403 L
s
0 0 0 r
2.5 Mabswid
.32785 .44403 Mdot
0 .449 1 r
.5 Mabswid
.31777 .44338 m
.33916 .45483 L
s
0 0 0 r
2.5 Mabswid
.33916 .45483 Mdot
.88 1 0 r
.5 Mabswid
.29403 .68624 m
.26516 .72193 L
s
0 0 0 r
2.5 Mabswid
.26516 .72193 Mdot
.865 1 0 r
.5 Mabswid
.41907 .43122 m
.31502 .49955 L
s
0 0 0 r
2.5 Mabswid
.31502 .49955 Mdot
0 1 .699 r
.5 Mabswid
.51062 .53636 m
.6517 .59472 L
s
0 0 0 r
2.5 Mabswid
.6517 .59472 Mdot
0 1 .592 r
.5 Mabswid
.56758 .46656 m
.71983 .45626 L
s
0 0 0 r
2.5 Mabswid
.71983 .45626 Mdot
0 1 .595 r
.5 Mabswid
.41514 .62546 m
.42234 .7644 L
s
0 0 0 r
2.5 Mabswid
.42234 .7644 Mdot
.813 1 0 r
.5 Mabswid
.47521 .5051 m
.4708 .40496 L
s
0 0 0 r
2.5 Mabswid
.4708 .40496 Mdot
.819 1 0 r
.5 Mabswid
.38259 .54062 m
.33082 .69068 L
s
0 0 0 r
2.5 Mabswid
.33082 .69068 Mdot
.814 1 0 r
.5 Mabswid
.38896 .55542 m
.33861 .70217 L
s
0 0 0 r
2.5 Mabswid
.33861 .70217 Mdot
.81 1 0 r
.5 Mabswid
.29965 .59342 m
.44516 .66101 L
s
0 0 0 r
2.5 Mabswid
.44516 .66101 Mdot
.806 1 0 r
.5 Mabswid
.30383 .60862 m
.44211 .67321 L
s
0 0 0 r
2.5 Mabswid
.44211 .67321 Mdot
.803 1 0 r
.5 Mabswid
.30802 .62384 m
.43907 .6854 L
s
0 0 0 r
2.5 Mabswid
.43907 .6854 Mdot
.8 1 0 r
.5 Mabswid
.21271 .64207 m
.21579 .63526 L
s
0 0 0 r
2.5 Mabswid
.21579 .63526 Mdot
.746 1 0 r
.5 Mabswid
.20056 .53577 m
.21524 .53762 L
s
0 0 0 r
2.5 Mabswid
.21524 .53762 Mdot
.741 1 0 r
.5 Mabswid
.21106 .54552 m
.22903 .54786 L
s
0 0 0 r
2.5 Mabswid
.22903 .54786 Mdot
.737 1 0 r
.5 Mabswid
.22157 .55529 m
.24289 .55815 L
s
0 0 0 r
2.5 Mabswid
.24289 .55815 Mdot
.732 1 0 r
.5 Mabswid
.23431 .56448 m
.22766 .55282 L
s
0 0 0 r
2.5 Mabswid
.22766 .55282 Mdot
.514 1 0 r
.5 Mabswid
.38034 .80042 m
.39104 .7967 L
s
0 0 0 r
2.5 Mabswid
.39104 .7967 Mdot
0 .938 1 r
.5 Mabswid
.38889 .81257 m
.392 .80167 L
s
0 0 0 r
2.5 Mabswid
.392 .80167 Mdot
.782 1 0 r
.5 Mabswid
.24256 .5 m
.24256 .5 L
s
0 0 0 r
2.5 Mabswid
.24256 .5 Mdot
.757 1 0 r
.5 Mabswid
.22936 .5 m
.22936 .5 L
s
0 0 0 r
2.5 Mabswid
.22936 .5 Mdot
.757 1 0 r
.5 Mabswid
.21607 .5 m
.21607 .5 L
s
0 0 0 r
2.5 Mabswid
.21607 .5 Mdot
.756 1 0 r
.5 Mabswid
.20269 .5 m
.20269 .5 L
s
0 0 0 r
2.5 Mabswid
.20269 .5 Mdot
1 .728 0 r
.5 Mabswid
.61222 .77399 m
.3097 .30753 L
s
0 0 0 r
2.5 Mabswid
.3097 .30753 Mdot
.778 1 0 r
.5 Mabswid
.75922 .54902 m
.27492 .47406 L
s
0 0 0 r
2.5 Mabswid
.27492 .47406 Mdot
.789 1 0 r
.5 Mabswid
.77279 .53903 m
.26731 .46024 L
s
0 0 0 r
2.5 Mabswid
.26731 .46024 Mdot
.793 1 0 r
.5 Mabswid
.7863 .52908 m
.2597 .44644 L
s
0 0 0 r
2.5 Mabswid
.2597 .44644 Mdot
.797 1 0 r
.5 Mabswid
.78859 .64045 m
.29813 .36042 L
s
0 0 0 r
2.5 Mabswid
.29813 .36042 Mdot
.801 1 0 r
.5 Mabswid
.80004 .63034 m
.30903 .34915 L
s
0 0 0 r
2.5 Mabswid
.30903 .34915 Mdot
1 .886 0 r
.5 Mabswid
.56057 .66448 m
.27289 .47104 L
s
0 0 0 r
2.5 Mabswid
.27289 .47104 Mdot
0 1 .495 r
.5 Mabswid
.66241 .70856 m
.5247 .57327 L
s
0 0 0 r
2.5 Mabswid
.5247 .57327 Mdot
0 1 .253 r
.5 Mabswid
.67009 .69708 m
.52889 .55785 L
s
0 0 0 r
2.5 Mabswid
.52889 .55785 Mdot
0 1 .243 r
.5 Mabswid
.67777 .68559 m
.53309 .54241 L
s
0 0 0 r
2.5 Mabswid
.53309 .54241 Mdot
0 .538 1 r
.5 Mabswid
.68493 .67276 m
.41593 .64111 L
s
0 0 0 r
2.5 Mabswid
.41593 .64111 Mdot
0 1 .599 r
.5 Mabswid
.55618 .70422 m
.41653 .47882 L
s
0 0 0 r
2.5 Mabswid
.41653 .47882 Mdot
0 .711 1 r
.5 Mabswid
.58329 .25395 m
.50235 .44728 L
s
0 0 0 r
2.5 Mabswid
.50235 .44728 Mdot
0 .13 1 r
.5 Mabswid
.35347 .41174 m
.667 .54315 L
s
0 0 0 r
2.5 Mabswid
.667 .54315 Mdot
0 1 .284 r
.5 Mabswid
.67988 .50569 m
.50784 .43027 L
s
0 0 0 r
2.5 Mabswid
.50784 .43027 Mdot
0 1 .394 r
.5 Mabswid
.74023 .28354 m
.49052 .3912 L
s
0 0 0 r
2.5 Mabswid
.49052 .3912 Mdot
0 1 .928 r
.5 Mabswid
.66762 .55165 m
.31612 .40528 L
s
0 0 0 r
2.5 Mabswid
.31612 .40528 Mdot
0 1 .754 r
.5 Mabswid
.67876 .56229 m
.29764 .40383 L
s
0 0 0 r
2.5 Mabswid
.29764 .40383 Mdot
0 1 .653 r
.5 Mabswid
.68988 .5729 m
.27909 .40238 L
s
0 0 0 r
2.5 Mabswid
.27909 .40238 Mdot
0 1 .542 r
.5 Mabswid
.70096 .58349 m
.26048 .40092 L
s
0 0 0 r
2.5 Mabswid
.26048 .40092 Mdot
0 .111 1 r
.5 Mabswid
.31658 .43326 m
.70311 .59623 L
s
0 0 0 r
2.5 Mabswid
.70311 .59623 Mdot
0 .498 1 r
.5 Mabswid
.32785 .44403 m
.68491 .5948 L
s
0 0 0 r
2.5 Mabswid
.68491 .5948 Mdot
0 .449 1 r
.5 Mabswid
.33916 .45483 m
.66678 .59338 L
s
0 0 0 r
2.5 Mabswid
.66678 .59338 Mdot
.06 1 0 r
.5 Mabswid
.26516 .72193 m
.50846 .62201 L
s
0 0 0 r
2.5 Mabswid
.50846 .62201 Mdot
0 1 .063 r
.5 Mabswid
.31502 .49955 m
.47672 .57586 L
s
0 0 0 r
2.5 Mabswid
.47672 .57586 Mdot
0 .364 1 r
.5 Mabswid
.6517 .59472 m
.38022 .36112 L
s
0 0 0 r
2.5 Mabswid
.38022 .36112 Mdot
0 .418 1 r
.5 Mabswid
.71983 .45626 m
.47061 .5313 L
s
0 0 0 r
2.5 Mabswid
.47061 .5313 Mdot
0 .298 1 r
.5 Mabswid
.42234 .7644 m
.49657 .59233 L
s
0 0 0 r
2.5 Mabswid
.49657 .59233 Mdot
0 1 .532 r
.5 Mabswid
.4708 .40496 m
.46774 .33573 L
s
0 0 0 r
2.5 Mabswid
.46774 .33573 Mdot
0 1 .247 r
.5 Mabswid
.33082 .69068 m
.47972 .5496 L
s
0 0 0 r
2.5 Mabswid
.47972 .5496 Mdot
0 1 .326 r
.5 Mabswid
.33861 .70217 m
.48398 .56496 L
s
0 0 0 r
2.5 Mabswid
.48398 .56496 Mdot
.81 1 0 r
.5 Mabswid
.44516 .66101 m
.72686 .47575 L
s
0 0 0 r
2.5 Mabswid
.72686 .47575 Mdot
.806 1 0 r
.5 Mabswid
.44211 .67321 m
.74322 .47554 L
s
0 0 0 r
2.5 Mabswid
.74322 .47554 Mdot
.803 1 0 r
.5 Mabswid
.43907 .6854 m
.75964 .47534 L
s
0 0 0 r
2.5 Mabswid
.75964 .47534 Mdot
.8 1 0 r
.5 Mabswid
.21579 .63526 m
.6661 .27194 L
s
0 0 0 r
2.5 Mabswid
.6661 .27194 Mdot
.746 1 0 r
.5 Mabswid
.21524 .53762 m
.74064 .46413 L
s
0 0 0 r
2.5 Mabswid
.74064 .46413 Mdot
.741 1 0 r
.5 Mabswid
.22903 .54786 m
.73298 .4779 L
s
0 0 0 r
2.5 Mabswid
.73298 .4779 Mdot
.737 1 0 r
.5 Mabswid
.24289 .55815 m
.72531 .49168 L
s
0 0 0 r
2.5 Mabswid
.72531 .49168 Mdot
.732 1 0 r
.5 Mabswid
.22766 .55282 m
.78497 .37214 L
s
0 0 0 r
2.5 Mabswid
.78497 .37214 Mdot
.514 1 0 r
.5 Mabswid
.39104 .7967 m
.64041 .24978 L
s
0 0 0 r
2.5 Mabswid
.64041 .24978 Mdot
0 .938 1 r
.5 Mabswid
.392 .80167 m
.50178 .32571 L
s
0 0 0 r
2.5 Mabswid
.50178 .32571 Mdot
1 .728 0 r
.5 Mabswid
.3097 .30753 m
.30728 .30087 L
s
0 0 0 r
2.5 Mabswid
.30728 .30087 Mdot
.778 1 0 r
.5 Mabswid
.27492 .47406 m
.26812 .48096 L
s
0 0 0 r
2.5 Mabswid
.26812 .48096 Mdot
.789 1 0 r
.5 Mabswid
.26731 .46024 m
.26103 .4663 L
s
0 0 0 r
2.5 Mabswid
.26103 .4663 Mdot
.793 1 0 r
.5 Mabswid
.2597 .44644 m
.25397 .45169 L
s
0 0 0 r
2.5 Mabswid
.25397 .45169 Mdot
.797 1 0 r
.5 Mabswid
.29813 .36042 m
.27953 .33483 L
s
0 0 0 r
2.5 Mabswid
.27953 .33483 Mdot
.801 1 0 r
.5 Mabswid
.30903 .34915 m
.2898 .32237 L
s
0 0 0 r
2.5 Mabswid
.2898 .32237 Mdot
1 .886 0 r
.5 Mabswid
.27289 .47104 m
.24833 .39967 L
s
0 0 0 r
2.5 Mabswid
.24833 .39967 Mdot
0 1 .495 r
.5 Mabswid
.5247 .57327 m
.33949 .39133 L
s
0 0 0 r
2.5 Mabswid
.33949 .39133 Mdot
0 1 .253 r
.5 Mabswid
.52889 .55785 m
.34568 .37719 L
s
0 0 0 r
2.5 Mabswid
.34568 .37719 Mdot
0 1 .243 r
.5 Mabswid
.53309 .54241 m
.35186 .36305 L
s
0 0 0 r
2.5 Mabswid
.35186 .36305 Mdot
0 .538 1 r
.5 Mabswid
.41593 .64111 m
.21428 .61738 L
s
0 0 0 r
2.5 Mabswid
.21428 .61738 Mdot
0 .711 1 r
.5 Mabswid
.50235 .44728 m
.40252 .68575 L
s
0 0 0 r
2.5 Mabswid
.40252 .68575 Mdot
0 .13 1 r
.5 Mabswid
.667 .54315 m
.68982 .61424 L
s
0 0 0 r
2.5 Mabswid
.68982 .61424 Mdot
0 1 .284 r
.5 Mabswid
.50784 .43027 m
.40848 .51086 L
s
0 0 0 r
2.5 Mabswid
.40848 .51086 Mdot
0 1 .394 r
.5 Mabswid
.49052 .3912 m
.39484 .57073 L
s
0 0 0 r
2.5 Mabswid
.39484 .57073 Mdot
0 1 .928 r
.5 Mabswid
.31612 .40528 m
.27737 .38853 L
s
0 0 0 r
2.5 Mabswid
.27737 .38853 Mdot
0 1 .754 r
.5 Mabswid
.29764 .40383 m
.26353 .3892 L
s
0 0 0 r
2.5 Mabswid
.26353 .3892 Mdot
0 1 .653 r
.5 Mabswid
.27909 .40238 m
.2497 .38986 L
s
0 0 0 r
2.5 Mabswid
.2497 .38986 Mdot
0 1 .542 r
.5 Mabswid
.26048 .40092 m
.23589 .39052 L
s
0 0 0 r
2.5 Mabswid
.23589 .39052 Mdot
0 .111 1 r
.5 Mabswid
.70311 .59623 m
.73504 .61087 L
s
0 0 0 r
2.5 Mabswid
.73504 .61087 Mdot
0 .498 1 r
.5 Mabswid
.68491 .5948 m
.72113 .61154 L
s
0 0 0 r
2.5 Mabswid
.72113 .61154 Mdot
0 .449 1 r
.5 Mabswid
.66678 .59338 m
.7072 .6122 L
s
0 0 0 r
2.5 Mabswid
.7072 .6122 Mdot
.06 1 0 r
.5 Mabswid
.50846 .62201 m
.60763 .49698 L
s
0 0 0 r
2.5 Mabswid
.60763 .49698 Mdot
0 1 .063 r
.5 Mabswid
.47672 .57586 m
.60591 .46988 L
s
0 0 0 r
2.5 Mabswid
.60591 .46988 Mdot
0 .364 1 r
.5 Mabswid
.38022 .36112 m
.34124 .34117 L
s
0 0 0 r
2.5 Mabswid
.34124 .34117 Mdot
0 .418 1 r
.5 Mabswid
.47061 .5313 m
.25689 .59565 L
s
0 0 0 r
2.5 Mabswid
.25689 .59565 Mdot
0 .298 1 r
.5 Mabswid
.49657 .59233 m
.60413 .34298 L
s
0 0 0 r
2.5 Mabswid
.60413 .34298 Mdot
0 1 .532 r
.5 Mabswid
.46774 .33573 m
.58127 .80709 L
s
0 0 0 r
2.5 Mabswid
.58127 .80709 Mdot
0 1 .247 r
.5 Mabswid
.47972 .5496 m
.66257 .37637 L
s
0 0 0 r
2.5 Mabswid
.66257 .37637 Mdot
0 1 .326 r
.5 Mabswid
.48398 .56496 m
.66881 .39049 L
s
0 0 0 r
2.5 Mabswid
.66881 .39049 Mdot
.81 1 0 r
.5 Mabswid
.72686 .47575 m
.75425 .40526 L
s
0 0 0 r
2.5 Mabswid
.75425 .40526 Mdot
.806 1 0 r
.5 Mabswid
.74322 .47554 m
.76718 .41449 L
s
0 0 0 r
2.5 Mabswid
.76718 .41449 Mdot
.803 1 0 r
.5 Mabswid
.75964 .47534 m
.7801 .4237 L
s
0 0 0 r
2.5 Mabswid
.7801 .4237 Mdot
.8 1 0 r
.5 Mabswid
.6661 .27194 m
.69383 .28468 L
s
0 0 0 r
2.5 Mabswid
.69383 .28468 Mdot
.746 1 0 r
.5 Mabswid
.74064 .46413 m
.74624 .47249 L
s
0 0 0 r
2.5 Mabswid
.74624 .47249 Mdot
.741 1 0 r
.5 Mabswid
.73298 .4779 m
.73908 .48739 L
s
0 0 0 r
2.5 Mabswid
.73908 .48739 Mdot
.737 1 0 r
.5 Mabswid
.72531 .49168 m
.73179 .50216 L
s
0 0 0 r
2.5 Mabswid
.73179 .50216 Mdot
.732 1 0 r
.5 Mabswid
.78497 .37214 m
.79581 .37139 L
s
0 0 0 r
2.5 Mabswid
.79581 .37139 Mdot
.514 1 0 r
.5 Mabswid
.64041 .24978 m
.63156 .23783 L
s
0 0 0 r
2.5 Mabswid
.63156 .23783 Mdot
0 .938 1 r
.5 Mabswid
.50178 .32571 m
.50083 .37109 L
s
0 0 0 r
2.5 Mabswid
.50083 .37109 Mdot
1 .728 0 r
.5 Mabswid
.30728 .30087 m
.61113 .74207 L
s
0 0 0 r
2.5 Mabswid
.61113 .74207 Mdot
.778 1 0 r
.5 Mabswid
.26812 .48096 m
.66785 .67253 L
s
0 0 0 r
2.5 Mabswid
.66785 .67253 Mdot
.789 1 0 r
.5 Mabswid
.26103 .4663 m
.66442 .65917 L
s
0 0 0 r
2.5 Mabswid
.66442 .65917 Mdot
.793 1 0 r
.5 Mabswid
.25397 .45169 m
.66019 .64547 L
s
0 0 0 r
2.5 Mabswid
.66019 .64547 Mdot
.797 1 0 r
.5 Mabswid
.27953 .33483 m
.69504 .56403 L
s
0 0 0 r
2.5 Mabswid
.69504 .56403 Mdot
.801 1 0 r
.5 Mabswid
.2898 .32237 m
.70416 .55018 L
s
0 0 0 r
2.5 Mabswid
.70416 .55018 Mdot
1 .886 0 r
.5 Mabswid
.24833 .39967 m
.57171 .3906 L
s
0 0 0 r
2.5 Mabswid
.57171 .3906 Mdot
0 .692 1 r
.5 Mabswid
.33949 .39133 m
.52605 .46434 L
s
0 0 0 r
2.5 Mabswid
.52605 .46434 Mdot
0 .685 1 r
.5 Mabswid
.34568 .37719 m
.5305 .44904 L
s
0 0 0 r
2.5 Mabswid
.5305 .44904 Mdot
0 .695 1 r
.5 Mabswid
.35186 .36305 m
.53495 .43374 L
s
0 0 0 r
2.5 Mabswid
.53495 .43374 Mdot
0 .538 1 r
.5 Mabswid
.21428 .61738 m
.25065 .54758 L
s
0 0 0 r
2.5 Mabswid
.25065 .54758 Mdot
0 .13 1 r
.5 Mabswid
.68982 .61424 m
.25048 .44069 L
s
0 0 0 r
2.5 Mabswid
.25048 .44069 Mdot
0 1 .284 r
.5 Mabswid
.40848 .51086 m
.35521 .63972 L
s
0 0 0 r
2.5 Mabswid
.35521 .63972 Mdot
0 1 .394 r
.5 Mabswid
.39484 .57073 m
.41325 .77518 L
s
0 0 0 r
2.5 Mabswid
.41325 .77518 Mdot
0 .595 1 r
.5 Mabswid
.27737 .38853 m
.62856 .53395 L
s
0 0 0 r
2.5 Mabswid
.62856 .53395 Mdot
0 .042 1 r
.5 Mabswid
.72113 .61154 m
.36524 .46665 L
s
0 0 0 r
2.5 Mabswid
.36524 .46665 Mdot
0 .046 1 r
.5 Mabswid
.7072 .6122 m
.35213 .46792 L
s
0 0 0 r
2.5 Mabswid
.35213 .46792 Mdot
.06 1 0 r
.5 Mabswid
.60763 .49698 m
.55685 .26245 L
s
0 0 0 r
2.5 Mabswid
.55685 .26245 Mdot
0 1 .063 r
.5 Mabswid
.60591 .46988 m
.65846 .34746 L
s
0 0 0 r
2.5 Mabswid
.65846 .34746 Mdot
0 .364 1 r
.5 Mabswid
.34124 .34117 m
.57951 .78948 L
s
0 0 0 r
2.5 Mabswid
.57951 .78948 Mdot
0 1 .532 r
.5 Mabswid
.58127 .80709 m
.58143 .7988 L
s
0 0 0 r
2.5 Mabswid
.58143 .7988 Mdot
0 .877 1 r
.5 Mabswid
.66257 .37637 m
.4868 .44894 L
s
0 0 0 r
2.5 Mabswid
.4868 .44894 Mdot
0 .601 1 r
.5 Mabswid
.66881 .39049 m
.4914 .46421 L
s
0 0 0 r
2.5 Mabswid
.4914 .46421 Mdot
.699 1 0 r
.5 Mabswid
.75425 .40526 m
.43058 .39774 L
s
0 0 0 r
2.5 Mabswid
.43058 .39774 Mdot
.435 1 0 r
.5 Mabswid
.76718 .41449 m
.43858 .40719 L
s
0 0 0 r
2.5 Mabswid
.43858 .40719 Mdot
.371 1 0 r
.5 Mabswid
.7801 .4237 m
.44658 .41665 L
s
0 0 0 r
2.5 Mabswid
.44658 .41665 Mdot
.8 1 0 r
.5 Mabswid
.69383 .28468 m
.55651 .76348 L
s
0 0 0 r
2.5 Mabswid
.55651 .76348 Mdot
.746 1 0 r
.5 Mabswid
.74624 .47249 m
.34509 .66874 L
s
0 0 0 r
2.5 Mabswid
.34509 .66874 Mdot
.741 1 0 r
.5 Mabswid
.73908 .48739 m
.3427 .68174 L
s
0 0 0 r
2.5 Mabswid
.3427 .68174 Mdot
0 .627 1 r
.5 Mabswid
.73179 .50216 m
.43795 .52591 L
s
0 0 0 r
2.5 Mabswid
.43795 .52591 Mdot
.732 1 0 r
.5 Mabswid
.79581 .37139 m
.4744 .64993 L
s
0 0 0 r
2.5 Mabswid
.4744 .64993 Mdot
.514 1 0 r
.5 Mabswid
.63156 .23783 m
.39893 .60968 L
s
0 0 0 r
2.5 Mabswid
.39893 .60968 Mdot
.018 0 1 r
.5 Mabswid
.50083 .37109 m
.49957 .43203 L
s
0 0 0 r
2.5 Mabswid
.49957 .43203 Mdot
1 .728 0 r
.5 Mabswid
.61113 .74207 m
.63207 .72109 L
s
0 0 0 r
2.5 Mabswid
.63207 .72109 Mdot
.778 1 0 r
.5 Mabswid
.66785 .67253 m
.71668 .56392 L
s
0 0 0 r
2.5 Mabswid
.71668 .56392 Mdot
.789 1 0 r
.5 Mabswid
.66442 .65917 m
.62682 .59752 L
s
0 0 0 r
2.5 Mabswid
.62682 .59752 Mdot
.793 1 0 r
.5 Mabswid
.66019 .64547 m
.62074 .58065 L
s
0 0 0 r
2.5 Mabswid
.62074 .58065 Mdot
.797 1 0 r
.5 Mabswid
.69504 .56403 m
.69568 .58799 L
s
0 0 0 r
2.5 Mabswid
.69568 .58799 Mdot
.801 1 0 r
.5 Mabswid
.70416 .55018 m
.70494 .57338 L
s
0 0 0 r
2.5 Mabswid
.70494 .57338 Mdot
1 .886 0 r
.5 Mabswid
.57171 .3906 m
.74158 .67092 L
s
0 0 0 r
2.5 Mabswid
.74158 .67092 Mdot
0 .692 1 r
.5 Mabswid
.52605 .46434 m
.70388 .53394 L
s
0 0 0 r
2.5 Mabswid
.70388 .53394 Mdot
0 .685 1 r
.5 Mabswid
.5305 .44904 m
.70789 .518 L
s
0 0 0 r
2.5 Mabswid
.70789 .518 Mdot
0 .695 1 r
.5 Mabswid
.53495 .43374 m
.71189 .50206 L
s
0 0 0 r
2.5 Mabswid
.71189 .50206 Mdot
0 .538 1 r
.5 Mabswid
.25065 .54758 m
.45164 .33827 L
s
0 0 0 r
2.5 Mabswid
.45164 .33827 Mdot
0 .13 1 r
.5 Mabswid
.25048 .44069 m
.24727 .44208 L
s
0 0 0 r
2.5 Mabswid
.24727 .44208 Mdot
0 .588 1 r
.5 Mabswid
.35521 .63972 m
.48669 .58496 L
s
0 0 0 r
2.5 Mabswid
.48669 .58496 Mdot
0 .884 1 r
.5 Mabswid
.41325 .77518 m
.50718 .70923 L
s
0 0 0 r
2.5 Mabswid
.50718 .70923 Mdot
0 .038 1 r
.5 Mabswid
.55685 .26245 m
.39752 .36269 L
s
0 0 0 r
2.5 Mabswid
.39752 .36269 Mdot
0 .932 1 r
.5 Mabswid
.65846 .34746 m
.54494 .39314 L
s
0 0 0 r
2.5 Mabswid
.54494 .39314 Mdot
0 .364 1 r
.5 Mabswid
.57951 .78948 m
.59996 .77667 L
s
0 0 0 r
2.5 Mabswid
.59996 .77667 Mdot
0 1 .532 r
.5 Mabswid
.58143 .7988 m
.49118 .23463 L
s
0 0 0 r
2.5 Mabswid
.49118 .23463 Mdot
0 .877 1 r
.5 Mabswid
.4868 .44894 m
.30542 .52382 L
s
0 0 0 r
2.5 Mabswid
.30542 .52382 Mdot
0 .601 1 r
.5 Mabswid
.4914 .46421 m
.30953 .53978 L
s
0 0 0 r
2.5 Mabswid
.30953 .53978 Mdot
.699 1 0 r
.5 Mabswid
.43058 .39774 m
.27509 .66406 L
s
0 0 0 r
2.5 Mabswid
.27509 .66406 Mdot
.435 1 0 r
.5 Mabswid
.43858 .40719 m
.29591 .65221 L
s
0 0 0 r
2.5 Mabswid
.29591 .65221 Mdot
.371 1 0 r
.5 Mabswid
.44658 .41665 m
.31663 .64042 L
s
0 0 0 r
2.5 Mabswid
.31663 .64042 Mdot
.8 1 0 r
.5 Mabswid
.55651 .76348 m
.48655 .75814 L
s
0 0 0 r
2.5 Mabswid
.48655 .75814 Mdot
.746 1 0 r
.5 Mabswid
.34509 .66874 m
.2918 .55208 L
s
0 0 0 r
2.5 Mabswid
.2918 .55208 Mdot
.741 1 0 r
.5 Mabswid
.3427 .68174 m
.29371 .5748 L
s
0 0 0 r
2.5 Mabswid
.29371 .5748 Mdot
.732 1 0 r
.5 Mabswid
.4744 .64993 m
.41866 .69824 L
s
0 0 0 r
2.5 Mabswid
.41866 .69824 Mdot
0 1 .124 r
.5 Mabswid
.39893 .60968 m
.46469 .52623 L
s
0 0 0 r
2.5 Mabswid
.46469 .52623 Mdot
.018 0 1 r
.5 Mabswid
.49957 .43203 m
.53983 .55076 L
s
0 0 0 r
2.5 Mabswid
.53983 .55076 Mdot
1 .728 0 r
.5 Mabswid
.63207 .72109 m
.54586 .24477 L
s
0 0 0 r
2.5 Mabswid
.54586 .24477 Mdot
.778 1 0 r
.5 Mabswid
.71668 .56392 m
.50131 .21158 L
s
0 0 0 r
2.5 Mabswid
.50131 .21158 Mdot
0 1 .003 r
.5 Mabswid
.62682 .59752 m
.56483 .49587 L
s
0 0 0 r
2.5 Mabswid
.56483 .49587 Mdot
0 1 .128 r
.5 Mabswid
.62074 .58065 m
.55871 .47873 L
s
0 0 0 r
2.5 Mabswid
.55871 .47873 Mdot
.797 1 0 r
.5 Mabswid
.69568 .58799 m
.17451 .43485 L
s
0 0 0 r
2.5 Mabswid
.17451 .43485 Mdot
.801 1 0 r
.5 Mabswid
.70494 .57338 m
.17632 .41728 L
s
0 0 0 r
2.5 Mabswid
.17632 .41728 Mdot
1 .886 0 r
.5 Mabswid
.74158 .67092 m
.75394 .70878 L
s
0 0 0 r
2.5 Mabswid
.75394 .70878 Mdot
0 .538 1 r
.5 Mabswid
.45164 .33827 m
.46216 .3273 L
s
0 0 0 r
2.5 Mabswid
.46216 .3273 Mdot
0 .13 1 r
.5 Mabswid
.24727 .44208 m
.82696 .56622 L
s
0 0 0 r
2.5 Mabswid
.82696 .56622 Mdot
0 .588 1 r
.5 Mabswid
.48669 .58496 m
.56389 .48951 L
s
0 0 0 r
2.5 Mabswid
.56389 .48951 Mdot
0 .884 1 r
.5 Mabswid
.50718 .70923 m
.62288 .41041 L
s
0 0 0 r
2.5 Mabswid
.62288 .41041 Mdot
0 .038 1 r
.5 Mabswid
.39752 .36269 m
.36562 .65202 L
s
0 0 0 r
2.5 Mabswid
.36562 .65202 Mdot
0 .932 1 r
.5 Mabswid
.54494 .39314 m
.42458 .54389 L
s
0 0 0 r
2.5 Mabswid
.42458 .54389 Mdot
0 .364 1 r
.5 Mabswid
.59996 .77667 m
.64434 .25445 L
s
0 0 0 r
2.5 Mabswid
.64434 .25445 Mdot
0 1 .532 r
.5 Mabswid
.49118 .23463 m
.49546 .23054 L
s
0 0 0 r
2.5 Mabswid
.49546 .23054 Mdot
.052 0 1 r
.5 Mabswid
.30542 .52382 m
.56502 .51631 L
s
0 0 0 r
2.5 Mabswid
.56502 .51631 Mdot
.699 1 0 r
.5 Mabswid
.27509 .66406 m
.25852 .71851 L
s
0 0 0 r
2.5 Mabswid
.25852 .71851 Mdot
.435 1 0 r
.5 Mabswid
.29591 .65221 m
.27307 .72787 L
s
0 0 0 r
2.5 Mabswid
.27307 .72787 Mdot
.371 1 0 r
.5 Mabswid
.31663 .64042 m
.28839 .73474 L
s
0 0 0 r
2.5 Mabswid
.28839 .73474 Mdot
.8 1 0 r
.5 Mabswid
.48655 .75814 m
.33432 .25684 L
s
0 0 0 r
2.5 Mabswid
.33432 .25684 Mdot
.746 1 0 r
.5 Mabswid
.2918 .55208 m
.51012 .20659 L
s
0 0 0 r
2.5 Mabswid
.51012 .20659 Mdot
.741 1 0 r
.5 Mabswid
.29371 .5748 m
.51917 .21889 L
s
0 0 0 r
2.5 Mabswid
.51917 .21889 Mdot
.732 1 0 r
.5 Mabswid
.41866 .69824 m
.31834 .75977 L
s
0 0 0 r
2.5 Mabswid
.31834 .75977 Mdot
0 1 .943 r
.5 Mabswid
.46469 .52623 m
.54241 .42761 L
s
0 0 0 r
2.5 Mabswid
.54241 .42761 Mdot
.018 0 1 r
.5 Mabswid
.53983 .55076 m
.53715 .60832 L
s
0 0 0 r
2.5 Mabswid
.53715 .60832 Mdot
1 .728 0 r
.5 Mabswid
.54586 .24477 m
.48103 .26337 L
s
0 0 0 r
2.5 Mabswid
.48103 .26337 Mdot
.778 1 0 r
.5 Mabswid
.50131 .21158 m
.41428 .22583 L
s
0 0 0 r
2.5 Mabswid
.41428 .22583 Mdot
0 1 .003 r
.5 Mabswid
.56483 .49587 m
.41915 .5072 L
s
0 0 0 r
2.5 Mabswid
.41915 .5072 Mdot
0 1 .128 r
.5 Mabswid
.55871 .47873 m
.42057 .48928 L
s
0 0 0 r
2.5 Mabswid
.42057 .48928 Mdot
.797 1 0 r
.5 Mabswid
.17451 .43485 m
.17299 .43403 L
s
0 0 0 r
2.5 Mabswid
.17299 .43403 Mdot
0 1 .522 r
.5 Mabswid
.17632 .41728 m
.70042 .47282 L
s
0 0 0 r
2.5 Mabswid
.70042 .47282 Mdot
.388 1 0 r
.5 Mabswid
.75394 .70878 m
.60985 .69777 L
s
0 0 0 r
2.5 Mabswid
.60985 .69777 Mdot
0 .538 1 r
.5 Mabswid
.46216 .3273 m
.55325 .24398 L
s
0 0 0 r
2.5 Mabswid
.55325 .24398 Mdot
0 .588 1 r
.5 Mabswid
.56389 .48951 m
.48706 .31762 L
s
0 0 0 r
2.5 Mabswid
.48706 .31762 Mdot
0 .884 1 r
.5 Mabswid
.62288 .41041 m
.50338 .27315 L
s
0 0 0 r
2.5 Mabswid
.50338 .27315 Mdot
0 .038 1 r
.5 Mabswid
.36562 .65202 m
.42792 .74119 L
s
0 0 0 r
2.5 Mabswid
.42792 .74119 Mdot
0 .932 1 r
.5 Mabswid
.42458 .54389 m
.49189 .70585 L
s
0 0 0 r
2.5 Mabswid
.49189 .70585 Mdot
0 .364 1 r
.5 Mabswid
.64434 .25445 m
.60979 .22274 L
s
0 0 0 r
2.5 Mabswid
.60979 .22274 Mdot
0 1 .532 r
.5 Mabswid
.49546 .23054 m
.62292 .76358 L
s
0 0 0 r
2.5 Mabswid
.62292 .76358 Mdot
.052 0 1 r
.5 Mabswid
.56502 .51631 m
.76286 .51059 L
s
0 0 0 r
2.5 Mabswid
.76286 .51059 Mdot
.699 1 0 r
.5 Mabswid
.25852 .71851 m
.40511 .71 L
s
0 0 0 r
2.5 Mabswid
.40511 .71 Mdot
0 1 .832 r
.5 Mabswid
.27307 .72787 m
.43374 .58971 L
s
0 0 0 r
2.5 Mabswid
.43374 .58971 Mdot
0 1 .67 r
.5 Mabswid
.28839 .73474 m
.45454 .59242 L
s
0 0 0 r
2.5 Mabswid
.45454 .59242 Mdot
.8 1 0 r
.5 Mabswid
.33432 .25684 m
.36116 .25127 L
s
0 0 0 r
2.5 Mabswid
.36116 .25127 Mdot
.746 1 0 r
.5 Mabswid
.51012 .20659 m
.54429 .24127 L
s
0 0 0 r
2.5 Mabswid
.54429 .24127 Mdot
.741 1 0 r
.5 Mabswid
.51917 .21889 m
.55878 .25913 L
s
0 0 0 r
2.5 Mabswid
.55878 .25913 Mdot
0 1 .453 r
.5 Mabswid
.31834 .75977 m
.33254 .65506 L
s
0 0 0 r
2.5 Mabswid
.33254 .65506 Mdot
0 .149 1 r
.5 Mabswid
.54241 .42761 m
.42773 .8205 L
s
0 0 0 r
2.5 Mabswid
.42773 .8205 Mdot
1 .728 0 r
.5 Mabswid
.48103 .26337 m
.45842 .72474 L
s
0 0 0 r
2.5 Mabswid
.45842 .72474 Mdot
.778 1 0 r
.5 Mabswid
.41428 .22583 m
.27589 .52506 L
s
0 0 0 r
2.5 Mabswid
.27589 .52506 Mdot
0 1 .003 r
.5 Mabswid
.41915 .5072 m
.30043 .43735 L
s
0 0 0 r
2.5 Mabswid
.30043 .43735 Mdot
0 1 .128 r
.5 Mabswid
.42057 .48928 m
.28639 .60585 L
s
0 0 0 r
2.5 Mabswid
.28639 .60585 Mdot
.797 1 0 r
.5 Mabswid
.17299 .43403 m
.1756 .43377 L
s
0 0 0 r
2.5 Mabswid
.1756 .43377 Mdot
0 1 .522 r
.5 Mabswid
.70042 .47282 m
.79954 .49073 L
s
0 0 0 r
2.5 Mabswid
.79954 .49073 Mdot
.388 1 0 r
.5 Mabswid
.60985 .69777 m
.5115 .67465 L
s
0 0 0 r
2.5 Mabswid
.5115 .67465 Mdot
0 .538 1 r
.5 Mabswid
.55325 .24398 m
.62326 .19223 L
s
0 0 0 r
2.5 Mabswid
.62326 .19223 Mdot
0 .327 1 r
.5 Mabswid
.50338 .27315 m
.40654 .33855 L
s
0 0 0 r
2.5 Mabswid
.40654 .33855 Mdot
0 .038 1 r
.5 Mabswid
.42792 .74119 m
.67438 .55398 L
s
0 0 0 r
2.5 Mabswid
.67438 .55398 Mdot
0 .364 1 r
.5 Mabswid
.60979 .22274 m
.33883 .41946 L
s
0 0 0 r
2.5 Mabswid
.33883 .41946 Mdot
0 1 .532 r
.5 Mabswid
.62292 .76358 m
.59065 .77323 L
s
0 0 0 r
2.5 Mabswid
.59065 .77323 Mdot
.699 1 0 r
.5 Mabswid
.40511 .71 m
.60157 .63687 L
s
0 0 0 r
2.5 Mabswid
.60157 .63687 Mdot
0 1 .832 r
.5 Mabswid
.43374 .58971 m
.52244 .4957 L
s
0 0 0 r
2.5 Mabswid
.52244 .4957 Mdot
0 1 .67 r
.5 Mabswid
.45454 .59242 m
.52821 .51459 L
s
0 0 0 r
2.5 Mabswid
.52821 .51459 Mdot
.8 1 0 r
.5 Mabswid
.36116 .25127 m
.68383 .62726 L
s
0 0 0 r
2.5 Mabswid
.68383 .62726 Mdot
.746 1 0 r
.5 Mabswid
.54429 .24127 m
.54422 .7952 L
s
0 0 0 r
2.5 Mabswid
.54422 .7952 Mdot
.741 1 0 r
.5 Mabswid
.55878 .25913 m
.55931 .80314 L
s
0 0 0 r
2.5 Mabswid
.55931 .80314 Mdot
0 1 .453 r
.5 Mabswid
.33254 .65506 m
.50705 .1752 L
s
0 0 0 r
2.5 Mabswid
.50705 .1752 Mdot
0 .149 1 r
.5 Mabswid
.42773 .8205 m
.42601 .82542 L
s
0 0 0 r
2.5 Mabswid
.42601 .82542 Mdot
1 .728 0 r
.5 Mabswid
.45842 .72474 m
.50076 .6694 L
s
0 0 0 r
2.5 Mabswid
.50076 .6694 Mdot
.778 1 0 r
.5 Mabswid
.27589 .52506 m
.42702 .72858 L
s
0 0 0 r
2.5 Mabswid
.42702 .72858 Mdot
0 1 .766 r
.5 Mabswid
.30043 .43735 m
.60061 .53784 L
s
0 0 0 r
2.5 Mabswid
.60061 .53784 Mdot
0 .739 1 r
.5 Mabswid
.28639 .60585 m
.5482 .56813 L
s
0 0 0 r
2.5 Mabswid
.5482 .56813 Mdot
.797 1 0 r
.5 Mabswid
.1756 .43377 m
.75252 .4963 L
s
0 0 0 r
2.5 Mabswid
.75252 .4963 Mdot
0 .348 1 r
.5 Mabswid
.79954 .49073 m
.62449 .57983 L
s
0 0 0 r
2.5 Mabswid
.62449 .57983 Mdot
.388 1 0 r
.5 Mabswid
.5115 .67465 m
.49601 .66969 L
s
0 0 0 r
2.5 Mabswid
.49601 .66969 Mdot
0 .538 1 r
.5 Mabswid
.62326 .19223 m
.65254 .24382 L
s
0 0 0 r
2.5 Mabswid
.65254 .24382 Mdot
0 .327 1 r
.5 Mabswid
.40654 .33855 m
.38464 .66578 L
s
0 0 0 r
2.5 Mabswid
.38464 .66578 Mdot
0 .038 1 r
.5 Mabswid
.67438 .55398 m
.60725 .2378 L
s
0 0 0 r
2.5 Mabswid
.60725 .2378 Mdot
0 .364 1 r
.5 Mabswid
.33883 .41946 m
.36773 .7359 L
s
0 0 0 r
2.5 Mabswid
.36773 .7359 Mdot
0 1 .532 r
.5 Mabswid
.59065 .77323 m
.27751 .45053 L
s
0 0 0 r
2.5 Mabswid
.27751 .45053 Mdot
.699 1 0 r
.5 Mabswid
.60157 .63687 m
.72425 .50475 L
s
0 0 0 r
2.5 Mabswid
.72425 .50475 Mdot
0 1 .832 r
.5 Mabswid
.52244 .4957 m
.31191 .41535 L
s
0 0 0 r
2.5 Mabswid
.31191 .41535 Mdot
0 1 .67 r
.5 Mabswid
.52821 .51459 m
.51864 .42848 L
s
0 0 0 r
2.5 Mabswid
.51864 .42848 Mdot
.8 1 0 r
.5 Mabswid
.68383 .62726 m
.61537 .6507 L
s
0 0 0 r
2.5 Mabswid
.61537 .6507 Mdot
.746 1 0 r
.5 Mabswid
.54422 .7952 m
.528 .79175 L
s
0 0 0 r
2.5 Mabswid
.528 .79175 Mdot
.741 1 0 r
.5 Mabswid
.55931 .80314 m
.54737 .80062 L
s
0 0 0 r
2.5 Mabswid
.54737 .80062 Mdot
0 1 .453 r
.5 Mabswid
.50705 .1752 m
.51285 .16753 L
s
0 0 0 r
2.5 Mabswid
.51285 .16753 Mdot
0 .149 1 r
.5 Mabswid
.42601 .82542 m
.42663 .81462 L
s
0 0 0 r
2.5 Mabswid
.42663 .81462 Mdot
1 .728 0 r
.5 Mabswid
.50076 .6694 m
.58334 .30281 L
s
0 0 0 r
2.5 Mabswid
.58334 .30281 Mdot
.778 1 0 r
.5 Mabswid
.42702 .72858 m
.63788 .70572 L
s
0 0 0 r
2.5 Mabswid
.63788 .70572 Mdot
0 .739 1 r
.5 Mabswid
.5482 .56813 m
.60574 .39949 L
s
0 0 0 r
2.5 Mabswid
.60574 .39949 Mdot
.797 1 0 r
.5 Mabswid
.75252 .4963 m
.76768 .53766 L
s
0 0 0 r
2.5 Mabswid
.76768 .53766 Mdot
0 .348 1 r
.5 Mabswid
.62449 .57983 m
.38439 .70205 L
s
0 0 0 r
2.5 Mabswid
.38439 .70205 Mdot
.388 1 0 r
.5 Mabswid
.49601 .66969 m
.37788 .59799 L
s
0 0 0 r
2.5 Mabswid
.37788 .59799 Mdot
0 .538 1 r
.5 Mabswid
.65254 .24382 m
.70742 .49633 L
s
0 0 0 r
2.5 Mabswid
.70742 .49633 Mdot
0 .327 1 r
.5 Mabswid
.38464 .66578 m
.46198 .75222 L
s
0 0 0 r
2.5 Mabswid
.46198 .75222 Mdot
0 .038 1 r
.5 Mabswid
.60725 .2378 m
.53583 .23819 L
s
0 0 0 r
2.5 Mabswid
.53583 .23819 Mdot
0 .364 1 r
.5 Mabswid
.36773 .7359 m
.4441 .72692 L
s
0 0 0 r
2.5 Mabswid
.4441 .72692 Mdot
0 1 .532 r
.5 Mabswid
.27751 .45053 m
.35548 .33353 L
s
0 0 0 r
2.5 Mabswid
.35548 .33353 Mdot
.699 1 0 r
.5 Mabswid
.72425 .50475 m
.73882 .48044 L
s
0 0 0 r
2.5 Mabswid
.73882 .48044 Mdot
0 .092 1 r
.5 Mabswid
.31191 .41535 m
.55639 .52504 L
s
0 0 0 r
2.5 Mabswid
.55639 .52504 Mdot
0 1 .67 r
.5 Mabswid
.51864 .42848 m
.43965 .20348 L
s
0 0 0 r
2.5 Mabswid
.43965 .20348 Mdot
.8 1 0 r
.5 Mabswid
.61537 .6507 m
.30947 .5148 L
s
0 0 0 r
2.5 Mabswid
.30947 .5148 Mdot
.746 1 0 r
.5 Mabswid
.528 .79175 m
.30122 .24066 L
s
0 0 0 r
2.5 Mabswid
.30122 .24066 Mdot
.741 1 0 r
.5 Mabswid
.54737 .80062 m
.319 .24403 L
s
0 0 0 r
2.5 Mabswid
.319 .24403 Mdot
0 1 .453 r
.5 Mabswid
.51285 .16753 m
.50384 .45271 L
s
0 0 0 r
2.5 Mabswid
.50384 .45271 Mdot
0 .149 1 r
.5 Mabswid
.42663 .81462 m
.45239 .5852 L
s
0 0 0 r
2.5 Mabswid
.45239 .5852 Mdot
.142 1 0 r
.5 Mabswid
.58334 .30281 m
.5129 .37881 L
s
0 0 0 r
2.5 Mabswid
.5129 .37881 Mdot
.778 1 0 r
.5 Mabswid
.63788 .70572 m
.73558 .40853 L
s
0 0 0 r
2.5 Mabswid
.73558 .40853 Mdot
0 .739 1 r
.5 Mabswid
.60574 .39949 m
.59567 .20882 L
s
0 0 0 r
2.5 Mabswid
.59567 .20882 Mdot
.797 1 0 r
.5 Mabswid
.76768 .53766 m
.26163 .57435 L
s
0 0 0 r
2.5 Mabswid
.26163 .57435 Mdot
.388 1 0 r
.5 Mabswid
.37788 .59799 m
.23083 .36026 L
s
0 0 0 r
2.5 Mabswid
.23083 .36026 Mdot
0 .538 1 r
.5 Mabswid
.70742 .49633 m
.70324 .7538 L
s
0 0 0 r
2.5 Mabswid
.70324 .7538 Mdot
0 .327 1 r
.5 Mabswid
.46198 .75222 m
.70415 .58552 L
s
0 0 0 r
2.5 Mabswid
.70415 .58552 Mdot
0 .038 1 r
.5 Mabswid
.53583 .23819 m
.25118 .54428 L
s
0 0 0 r
2.5 Mabswid
.25118 .54428 Mdot
0 .364 1 r
.5 Mabswid
.4441 .72692 m
.68748 .40393 L
s
0 0 0 r
2.5 Mabswid
.68748 .40393 Mdot
0 1 .532 r
.5 Mabswid
.35548 .33353 m
.59165 .31156 L
s
0 0 0 r
2.5 Mabswid
.59165 .31156 Mdot
.699 1 0 r
.5 Mabswid
.73882 .48044 m
.80552 .35677 L
s
0 0 0 r
2.5 Mabswid
.80552 .35677 Mdot
0 .272 1 r
.5 Mabswid
.43965 .20348 m
.44738 .37219 L
s
0 0 0 r
2.5 Mabswid
.44738 .37219 Mdot
.8 1 0 r
.5 Mabswid
.30947 .5148 m
.45254 .32271 L
s
0 0 0 r
2.5 Mabswid
.45254 .32271 Mdot
.746 1 0 r
.5 Mabswid
.30122 .24066 m
.30497 .2379 L
s
0 0 0 r
2.5 Mabswid
.30497 .2379 Mdot
.741 1 0 r
.5 Mabswid
.319 .24403 m
.32637 .23866 L
s
0 0 0 r
2.5 Mabswid
.32637 .23866 Mdot
0 1 .453 r
.5 Mabswid
.50384 .45271 m
.4928 .80205 L
s
0 0 0 r
2.5 Mabswid
.4928 .80205 Mdot
0 .149 1 r
.5 Mabswid
.45239 .5852 m
.4944 .21099 L
s
0 0 0 r
2.5 Mabswid
.4944 .21099 Mdot
.142 1 0 r
.5 Mabswid
.5129 .37881 m
.40892 .491 L
s
0 0 0 r
2.5 Mabswid
.40892 .491 Mdot
.778 1 0 r
.5 Mabswid
.73558 .40853 m
.64656 .29348 L
s
0 0 0 r
2.5 Mabswid
.64656 .29348 Mdot
.797 1 0 r
.5 Mabswid
.26163 .57435 m
.23339 .54078 L
s
0 0 0 r
2.5 Mabswid
.23339 .54078 Mdot
.388 1 0 r
.5 Mabswid
.23083 .36026 m
.21914 .32753 L
s
0 0 0 r
2.5 Mabswid
.21914 .32753 Mdot
0 .538 1 r
.5 Mabswid
.70324 .7538 m
.69885 .76835 L
s
0 0 0 r
2.5 Mabswid
.69885 .76835 Mdot
0 .327 1 r
.5 Mabswid
.70415 .58552 m
.65984 .30623 L
s
0 0 0 r
2.5 Mabswid
.65984 .30623 Mdot
0 .038 1 r
.5 Mabswid
.25118 .54428 m
.26071 .63769 L
s
0 0 0 r
2.5 Mabswid
.26071 .63769 Mdot
0 .364 1 r
.5 Mabswid
.68748 .40393 m
.66079 .29732 L
s
0 0 0 r
2.5 Mabswid
.66079 .29732 Mdot
0 1 .532 r
.5 Mabswid
.59165 .31156 m
.73906 .62686 L
s
0 0 0 r
2.5 Mabswid
.73906 .62686 Mdot
.699 1 0 r
.5 Mabswid
.80552 .35677 m
.6345 .37426 L
s
0 0 0 r
2.5 Mabswid
.6345 .37426 Mdot
0 .272 1 r
.5 Mabswid
.44738 .37219 m
.47142 .53118 L
s
0 0 0 r
2.5 Mabswid
.47142 .53118 Mdot
.8 1 0 r
.5 Mabswid
.45254 .32271 m
.57422 .34916 L
s
0 0 0 r
2.5 Mabswid
.57422 .34916 Mdot
.746 1 0 r
.5 Mabswid
.30497 .2379 m
.70162 .63076 L
s
0 0 0 r
2.5 Mabswid
.70162 .63076 Mdot
.741 1 0 r
.5 Mabswid
.32637 .23866 m
.71969 .62746 L
s
0 0 0 r
2.5 Mabswid
.71969 .62746 Mdot
0 1 .453 r
.5 Mabswid
.4928 .80205 m
.51376 .77437 L
s
0 0 0 r
2.5 Mabswid
.51376 .77437 Mdot
0 .149 1 r
.5 Mabswid
.4944 .21099 m
.53693 .24319 L
s
0 0 0 r
2.5 Mabswid
.53693 .24319 Mdot
.142 1 0 r
.5 Mabswid
.40892 .491 m
.56115 .64942 L
s
0 0 0 r
2.5 Mabswid
.56115 .64942 Mdot
.778 1 0 r
.5 Mabswid
.64656 .29348 m
.24985 .3725 L
s
0 0 0 r
2.5 Mabswid
.24985 .3725 Mdot
.797 1 0 r
.5 Mabswid
.23339 .54078 m
.67998 .30424 L
s
0 0 0 r
2.5 Mabswid
.67998 .30424 Mdot
0 .542 1 r
.5 Mabswid
.21914 .32753 m
.39722 .34247 L
s
0 0 0 r
2.5 Mabswid
.39722 .34247 Mdot
0 .538 1 r
.5 Mabswid
.69885 .76835 m
.69261 .76773 L
s
0 0 0 r
2.5 Mabswid
.69261 .76773 Mdot
0 .327 1 r
.5 Mabswid
.65984 .30623 m
.5341 .32044 L
s
0 0 0 r
2.5 Mabswid
.5341 .32044 Mdot
0 .038 1 r
.5 Mabswid
.26071 .63769 m
.5494 .7243 L
s
0 0 0 r
2.5 Mabswid
.5494 .7243 Mdot
0 1 .532 r
.5 Mabswid
.73906 .62686 m
.67879 .70172 L
s
0 0 0 r
2.5 Mabswid
.67879 .70172 Mdot
.699 1 0 r
.5 Mabswid
.6345 .37426 m
.52435 .39925 L
s
0 0 0 r
2.5 Mabswid
.52435 .39925 Mdot
0 .272 1 r
.5 Mabswid
.47142 .53118 m
.71354 .46612 L
s
0 0 0 r
2.5 Mabswid
.71354 .46612 Mdot
.8 1 0 r
.5 Mabswid
.57422 .34916 m
.59532 .74958 L
s
0 0 0 r
2.5 Mabswid
.59532 .74958 Mdot
.746 1 0 r
.5 Mabswid
.70162 .63076 m
.66982 .65105 L
s
0 0 0 r
2.5 Mabswid
.66982 .65105 Mdot
.741 1 0 r
.5 Mabswid
.71969 .62746 m
.69239 .64497 L
s
0 0 0 r
2.5 Mabswid
.69239 .64497 Mdot
0 1 .453 r
.5 Mabswid
.51376 .77437 m
.54557 .2815 L
s
0 0 0 r
2.5 Mabswid
.54557 .2815 Mdot
0 .149 1 r
.5 Mabswid
.53693 .24319 m
.55457 .77052 L
s
0 0 0 r
2.5 Mabswid
.55457 .77052 Mdot
.142 1 0 r
.5 Mabswid
.56115 .64942 m
.68155 .7105 L
s
0 0 0 r
2.5 Mabswid
.68155 .7105 Mdot
.778 1 0 r
.5 Mabswid
.24985 .3725 m
.22523 .42857 L
s
0 0 0 r
2.5 Mabswid
.22523 .42857 Mdot
.797 1 0 r
.5 Mabswid
.67998 .30424 m
.72724 .35206 L
s
0 0 0 r
2.5 Mabswid
.72724 .35206 Mdot
0 .542 1 r
.5 Mabswid
.39722 .34247 m
.51157 .37177 L
s
0 0 0 r
2.5 Mabswid
.51157 .37177 Mdot
0 .538 1 r
.5 Mabswid
.69261 .76773 m
.3934 .65489 L
s
0 0 0 r
2.5 Mabswid
.3934 .65489 Mdot
0 .327 1 r
.5 Mabswid
.5341 .32044 m
.34647 .54268 L
s
0 0 0 r
2.5 Mabswid
.34647 .54268 Mdot
0 .038 1 r
.5 Mabswid
.5494 .7243 m
.77585 .54593 L
s
0 0 0 r
2.5 Mabswid
.77585 .54593 Mdot
0 1 .532 r
.5 Mabswid
.67879 .70172 m
.24321 .56153 L
s
0 0 0 r
2.5 Mabswid
.24321 .56153 Mdot
.699 1 0 r
.5 Mabswid
.52435 .39925 m
.30368 .44932 L
s
0 0 0 r
2.5 Mabswid
.30368 .44932 Mdot
.8 1 0 r
.5 Mabswid
.59532 .74958 m
.57677 .79765 L
s
0 0 0 r
2.5 Mabswid
.57677 .79765 Mdot
.746 1 0 r
.5 Mabswid
.66982 .65105 m
.388 .49328 L
s
0 0 0 r
2.5 Mabswid
.388 .49328 Mdot
.741 1 0 r
.5 Mabswid
.69239 .64497 m
.21187 .53631 L
s
0 0 0 r
2.5 Mabswid
.21187 .53631 Mdot
0 1 .453 r
.5 Mabswid
.54557 .2815 m
.5149 .22031 L
s
0 0 0 r
2.5 Mabswid
.5149 .22031 Mdot
0 .149 1 r
.5 Mabswid
.55457 .77052 m
.53167 .75794 L
s
0 0 0 r
2.5 Mabswid
.53167 .75794 Mdot
.778 1 0 r
.5 Mabswid
.22523 .42857 m
.58227 .76581 L
s
0 0 0 r
2.5 Mabswid
.58227 .76581 Mdot
.797 1 0 r
.5 Mabswid
.72724 .35206 m
.48254 .80633 L
s
0 0 0 r
2.5 Mabswid
.48254 .80633 Mdot
0 .542 1 r
.5 Mabswid
.51157 .37177 m
.60915 .44315 L
s
0 0 0 r
2.5 Mabswid
.60915 .44315 Mdot
0 .538 1 r
.5 Mabswid
.3934 .65489 m
.24615 .44525 L
s
0 0 0 r
2.5 Mabswid
.24615 .44525 Mdot
0 .327 1 r
.5 Mabswid
.34647 .54268 m
.38048 .67296 L
s
0 0 0 r
2.5 Mabswid
.38048 .67296 Mdot
0 .038 1 r
.5 Mabswid
.77585 .54593 m
.73227 .39879 L
s
0 0 0 r
2.5 Mabswid
.73227 .39879 Mdot
0 1 .532 r
.5 Mabswid
.24321 .56153 m
.20902 .48477 L
s
0 0 0 r
2.5 Mabswid
.20902 .48477 Mdot
.699 1 0 r
.5 Mabswid
.30368 .44932 m
.2012 .52443 L
s
0 0 0 r
2.5 Mabswid
.2012 .52443 Mdot
.142 1 0 r
.5 Mabswid
.57677 .79765 m
.40013 .47774 L
s
0 0 0 r
2.5 Mabswid
.40013 .47774 Mdot
0 1 .749 r
.5 Mabswid
.388 .49328 m
.60386 .54516 L
s
0 0 0 r
2.5 Mabswid
.60386 .54516 Mdot
.741 1 0 r
.5 Mabswid
.21187 .53631 m
.21998 .49115 L
s
0 0 0 r
2.5 Mabswid
.21998 .49115 Mdot
0 1 .453 r
.5 Mabswid
.5149 .22031 m
.34308 .54166 L
s
0 0 0 r
2.5 Mabswid
.34308 .54166 Mdot
0 .149 1 r
.5 Mabswid
.53167 .75794 m
.27287 .30827 L
s
0 0 0 r
2.5 Mabswid
.27287 .30827 Mdot
.778 1 0 r
.5 Mabswid
.58227 .76581 m
.62643 .76293 L
s
0 0 0 r
2.5 Mabswid
.62643 .76293 Mdot
.797 1 0 r
.5 Mabswid
.48254 .80633 m
.4641 .80198 L
s
0 0 0 r
2.5 Mabswid
.4641 .80198 Mdot
0 .542 1 r
.5 Mabswid
.60915 .44315 m
.7527 .72227 L
s
0 0 0 r
2.5 Mabswid
.7527 .72227 Mdot
0 .538 1 r
.5 Mabswid
.24615 .44525 m
.22202 .34725 L
s
0 0 0 r
2.5 Mabswid
.22202 .34725 Mdot
0 .038 1 r
.5 Mabswid
.73227 .39879 m
.35101 .19834 L
s
0 0 0 r
2.5 Mabswid
.35101 .19834 Mdot
0 1 .532 r
.5 Mabswid
.20902 .48477 m
.51623 .3537 L
s
0 0 0 r
2.5 Mabswid
.51623 .3537 Mdot
0 1 .711 r
.5 Mabswid
.2012 .52443 m
.36124 .55769 L
s
0 0 0 r
2.5 Mabswid
.36124 .55769 Mdot
.142 1 0 r
.5 Mabswid
.40013 .47774 m
.65577 .34568 L
s
0 0 0 r
2.5 Mabswid
.65577 .34568 Mdot
0 1 .749 r
.5 Mabswid
.60386 .54516 m
.7369 .57713 L
s
0 0 0 r
2.5 Mabswid
.7369 .57713 Mdot
.741 1 0 r
.5 Mabswid
.21998 .49115 m
.75888 .35494 L
s
0 0 0 r
2.5 Mabswid
.75888 .35494 Mdot
0 1 .453 r
.5 Mabswid
.34308 .54166 m
.27124 .67601 L
s
0 0 0 r
2.5 Mabswid
.27124 .67601 Mdot
0 .149 1 r
.5 Mabswid
.27287 .30827 m
.30315 .2814 L
s
0 0 0 r
2.5 Mabswid
.30315 .2814 Mdot
.778 1 0 r
.5 Mabswid
.62643 .76293 m
.53677 .30209 L
s
0 0 0 r
2.5 Mabswid
.53677 .30209 Mdot
.797 1 0 r
.5 Mabswid
.4641 .80198 m
.40461 .19529 L
s
0 0 0 r
2.5 Mabswid
.40461 .19529 Mdot
0 .542 1 r
.5 Mabswid
.7527 .72227 m
.62708 .7119 L
s
0 0 0 r
2.5 Mabswid
.62708 .7119 Mdot
0 .538 1 r
.5 Mabswid
.22202 .34725 m
.37705 .32699 L
s
0 0 0 r
2.5 Mabswid
.37705 .32699 Mdot
0 .038 1 r
.5 Mabswid
.35101 .19834 m
.39663 .69642 L
s
0 0 0 r
2.5 Mabswid
.39663 .69642 Mdot
0 1 .532 r
.5 Mabswid
.51623 .3537 m
.73916 .25859 L
s
0 0 0 r
2.5 Mabswid
.73916 .25859 Mdot
0 1 .711 r
.5 Mabswid
.36124 .55769 m
.63617 .61483 L
s
0 0 0 r
2.5 Mabswid
.63617 .61483 Mdot
0 1 .381 r
.5 Mabswid
.65577 .34568 m
.68215 .38081 L
s
0 0 0 r
2.5 Mabswid
.68215 .38081 Mdot
0 .005 1 r
.5 Mabswid
.7369 .57713 m
.50578 .53818 L
s
0 0 0 r
2.5 Mabswid
.50578 .53818 Mdot
.741 1 0 r
.5 Mabswid
.75888 .35494 m
.76886 .38037 L
s
0 0 0 r
2.5 Mabswid
.76886 .38037 Mdot
0 1 .453 r
.5 Mabswid
.27124 .67601 m
.25458 .72501 L
s
0 0 0 r
2.5 Mabswid
.25458 .72501 Mdot
0 .149 1 r
.5 Mabswid
.30315 .2814 m
.75662 .53433 L
s
0 0 0 r
2.5 Mabswid
.75662 .53433 Mdot
.778 1 0 r
.5 Mabswid
.53677 .30209 m
.50361 .21665 L
s
0 0 0 r
2.5 Mabswid
.50361 .21665 Mdot
.797 1 0 r
.5 Mabswid
.40461 .19529 m
.40744 .19149 L
s
0 0 0 r
2.5 Mabswid
.40744 .19149 Mdot
0 .542 1 r
.5 Mabswid
.62708 .7119 m
.40448 .64513 L
s
0 0 0 r
2.5 Mabswid
.40448 .64513 Mdot
0 .538 1 r
.5 Mabswid
.37705 .32699 m
.56589 .36527 L
s
0 0 0 r
2.5 Mabswid
.56589 .36527 Mdot
0 .038 1 r
.5 Mabswid
.39663 .69642 m
.46482 .75441 L
s
0 0 0 r
2.5 Mabswid
.46482 .75441 Mdot
0 1 .532 r
.5 Mabswid
.73916 .25859 m
.73737 .42831 L
s
0 0 0 r
2.5 Mabswid
.73737 .42831 Mdot
0 1 .381 r
.5 Mabswid
.68215 .38081 m
.34607 .72828 L
s
0 0 0 r
2.5 Mabswid
.34607 .72828 Mdot
0 .005 1 r
.5 Mabswid
.50578 .53818 m
.26127 .49698 L
s
0 0 0 r
2.5 Mabswid
.26127 .49698 Mdot
.741 1 0 r
.5 Mabswid
.76886 .38037 m
.43747 .69299 L
s
0 0 0 r
2.5 Mabswid
.43747 .69299 Mdot
0 1 .453 r
.5 Mabswid
.25458 .72501 m
.32524 .72418 L
s
0 0 0 r
2.5 Mabswid
.32524 .72418 Mdot
0 .149 1 r
.5 Mabswid
.75662 .53433 m
.72894 .57631 L
s
0 0 0 r
2.5 Mabswid
.72894 .57631 Mdot
.333 1 0 r
.5 Mabswid
.50361 .21665 m
.36142 .46775 L
s
0 0 0 r
2.5 Mabswid
.36142 .46775 Mdot
.797 1 0 r
.5 Mabswid
.40744 .19149 m
.5667 .71304 L
s
0 0 0 r
2.5 Mabswid
.5667 .71304 Mdot
0 .542 1 r
.5 Mabswid
.40448 .64513 m
.1787 .50844 L
s
0 0 0 r
2.5 Mabswid
.1787 .50844 Mdot
0 .538 1 r
.5 Mabswid
.56589 .36527 m
.68351 .45265 L
s
0 0 0 r
2.5 Mabswid
.68351 .45265 Mdot
0 .038 1 r
.5 Mabswid
.46482 .75441 m
.72883 .41324 L
s
0 0 0 r
2.5 Mabswid
.72883 .41324 Mdot
0 1 .532 r
.5 Mabswid
.73737 .42831 m
.68513 .61273 L
s
0 0 0 r
2.5 Mabswid
.68513 .61273 Mdot
0 1 .381 r
.5 Mabswid
.34607 .72828 m
.32034 .7352 L
s
0 0 0 r
2.5 Mabswid
.32034 .7352 Mdot
.741 1 0 r
.5 Mabswid
.43747 .69299 m
.3632 .60515 L
s
0 0 0 r
2.5 Mabswid
.3632 .60515 Mdot
0 1 .453 r
.5 Mabswid
.32524 .72418 m
.49583 .6841 L
s
0 0 0 r
2.5 Mabswid
.49583 .6841 Mdot
0 .149 1 r
.5 Mabswid
.72894 .57631 m
.24259 .54841 L
s
0 0 0 r
2.5 Mabswid
.24259 .54841 Mdot
.333 1 0 r
.5 Mabswid
.36142 .46775 m
.24364 .67574 L
s
0 0 0 r
2.5 Mabswid
.24364 .67574 Mdot
.797 1 0 r
.5 Mabswid
.5667 .71304 m
.56383 .74622 L
s
0 0 0 r
2.5 Mabswid
.56383 .74622 Mdot
0 .542 1 r
.5 Mabswid
.1787 .50844 m
.19732 .46094 L
s
0 0 0 r
2.5 Mabswid
.19732 .46094 Mdot
0 .538 1 r
.5 Mabswid
.68351 .45265 m
.78986 .61843 L
s
0 0 0 r
2.5 Mabswid
.78986 .61843 Mdot
0 .038 1 r
.5 Mabswid
.72883 .41324 m
.69783 .33985 L
s
0 0 0 r
2.5 Mabswid
.69783 .33985 Mdot
0 1 .532 r
.5 Mabswid
.68513 .61273 m
.50402 .82502 L
s
0 0 0 r
2.5 Mabswid
.50402 .82502 Mdot
0 1 .381 r
.5 Mabswid
.32034 .7352 m
.4966 .31472 L
s
0 0 0 r
2.5 Mabswid
.4966 .31472 Mdot
.741 1 0 r
.5 Mabswid
.3632 .60515 m
.42024 .31456 L
s
0 0 0 r
2.5 Mabswid
.42024 .31456 Mdot
0 1 .453 r
.5 Mabswid
.49583 .6841 m
.69359 .60185 L
s
0 0 0 r
2.5 Mabswid
.69359 .60185 Mdot
0 .149 1 r
.5 Mabswid
.24259 .54841 m
.26574 .50309 L
s
0 0 0 r
2.5 Mabswid
.26574 .50309 Mdot
.333 1 0 r
.5 Mabswid
.24364 .67574 m
.30658 .68494 L
s
0 0 0 r
2.5 Mabswid
.30658 .68494 Mdot
.797 1 0 r
.5 Mabswid
.56383 .74622 m
.43818 .26331 L
s
0 0 0 r
2.5 Mabswid
.43818 .26331 Mdot
0 .542 1 r
.5 Mabswid
.19732 .46094 m
.58074 .20748 L
s
0 0 0 r
2.5 Mabswid
.58074 .20748 Mdot
0 .538 1 r
.5 Mabswid
.78986 .61843 m
.744 .64305 L
s
0 0 0 r
2.5 Mabswid
.744 .64305 Mdot
0 .038 1 r
.5 Mabswid
.69783 .33985 m
.19116 .38958 L
s
0 0 0 r
2.5 Mabswid
.19116 .38958 Mdot
0 1 .532 r
.5 Mabswid
.50402 .82502 m
.48773 .83769 L
s
0 0 0 r
2.5 Mabswid
.48773 .83769 Mdot
0 1 .381 r
.5 Mabswid
.4966 .31472 m
.66561 .36887 L
s
0 0 0 r
2.5 Mabswid
.66561 .36887 Mdot
.741 1 0 r
.5 Mabswid
.42024 .31456 m
.61564 .4172 L
s
0 0 0 r
2.5 Mabswid
.61564 .4172 Mdot
0 1 .453 r
.5 Mabswid
.69359 .60185 m
.80779 .4986 L
s
0 0 0 r
2.5 Mabswid
.80779 .4986 Mdot
0 .149 1 r
.5 Mabswid
.26574 .50309 m
.59719 .38369 L
s
0 0 0 r
2.5 Mabswid
.59719 .38369 Mdot
.333 1 0 r
.5 Mabswid
.30658 .68494 m
.47751 .65503 L
s
0 0 0 r
2.5 Mabswid
.47751 .65503 Mdot
.797 1 0 r
.5 Mabswid
.43818 .26331 m
.45172 .24627 L
s
0 0 0 r
2.5 Mabswid
.45172 .24627 Mdot
0 .542 1 r
.5 Mabswid
.58074 .20748 m
.63442 .20918 L
s
0 0 0 r
2.5 Mabswid
.63442 .20918 Mdot
0 .538 1 r
.5 Mabswid
.744 .64305 m
.34251 .62197 L
s
0 0 0 r
2.5 Mabswid
.34251 .62197 Mdot
0 .038 1 r
.5 Mabswid
.19116 .38958 m
.18989 .39735 L
s
0 0 0 r
2.5 Mabswid
.18989 .39735 Mdot
0 1 .532 r
.5 Mabswid
.48773 .83769 m
.436 .7467 L
s
0 0 0 r
2.5 Mabswid
.436 .7467 Mdot
0 1 .381 r
.5 Mabswid
.66561 .36887 m
.69996 .54744 L
s
0 0 0 r
2.5 Mabswid
.69996 .54744 Mdot
.741 1 0 r
.5 Mabswid
.61564 .4172 m
.76664 .49652 L
s
0 0 0 r
2.5 Mabswid
.76664 .49652 Mdot
0 1 .643 r
.5 Mabswid
.80779 .4986 m
.69134 .44517 L
s
0 0 0 r
2.5 Mabswid
.69134 .44517 Mdot
0 .149 1 r
.5 Mabswid
.59719 .38369 m
.63795 .65345 L
s
0 0 0 r
2.5 Mabswid
.63795 .65345 Mdot
.333 1 0 r
.5 Mabswid
.47751 .65503 m
.80672 .59744 L
s
0 0 0 r
2.5 Mabswid
.80672 .59744 Mdot
.797 1 0 r
.5 Mabswid
.45172 .24627 m
.62084 .77153 L
s
0 0 0 r
2.5 Mabswid
.62084 .77153 Mdot
0 .542 1 r
.5 Mabswid
.63442 .20918 m
.67716 .46828 L
s
0 0 0 r
2.5 Mabswid
.67716 .46828 Mdot
0 .538 1 r
.5 Mabswid
.34251 .62197 m
.27785 .47275 L
s
0 0 0 r
2.5 Mabswid
.27785 .47275 Mdot
0 .038 1 r
.5 Mabswid
.18989 .39735 m
.73104 .68387 L
s
0 0 0 r
2.5 Mabswid
.73104 .68387 Mdot
0 1 .532 r
.5 Mabswid
.436 .7467 m
.37558 .58609 L
s
0 0 0 r
2.5 Mabswid
.37558 .58609 Mdot
0 1 .381 r
.5 Mabswid
.69996 .54744 m
.31139 .74824 L
s
0 0 0 r
2.5 Mabswid
.31139 .74824 Mdot
.741 1 0 r
.5 Mabswid
.76664 .49652 m
.59103 .66237 L
s
0 0 0 r
2.5 Mabswid
.59103 .66237 Mdot
0 1 .643 r
.5 Mabswid
.69134 .44517 m
.62405 .43547 L
s
0 0 0 r
2.5 Mabswid
.62405 .43547 Mdot
0 .149 1 r
.5 Mabswid
.63795 .65345 m
.55708 .71069 L
s
0 0 0 r
2.5 Mabswid
.55708 .71069 Mdot
.333 1 0 r
.5 Mabswid
.80672 .59744 m
.82047 .59029 L
s
0 0 0 r
2.5 Mabswid
.82047 .59029 Mdot
.797 1 0 r
.5 Mabswid
.62084 .77153 m
.62045 .78429 L
s
0 0 0 r
2.5 Mabswid
.62045 .78429 Mdot
0 .542 1 r
.5 Mabswid
.67716 .46828 m
.60504 .78068 L
s
0 0 0 r
2.5 Mabswid
.60504 .78068 Mdot
0 .538 1 r
.5 Mabswid
.27785 .47275 m
.57624 .4081 L
s
0 0 0 r
2.5 Mabswid
.57624 .4081 Mdot
0 .038 1 r
.5 Mabswid
.73104 .68387 m
.74059 .68125 L
s
0 0 0 r
2.5 Mabswid
.74059 .68125 Mdot
0 1 .532 r
.5 Mabswid
.37558 .58609 m
.26516 .29257 L
s
0 0 0 r
2.5 Mabswid
.26516 .29257 Mdot
0 1 .381 r
.5 Mabswid
.31139 .74824 m
.29163 .72131 L
s
0 0 0 r
2.5 Mabswid
.29163 .72131 Mdot
.741 1 0 r
.5 Mabswid
.59103 .66237 m
.30928 .74777 L
s
0 0 0 r
2.5 Mabswid
.30928 .74777 Mdot
0 1 .643 r
.5 Mabswid
.62405 .43547 m
.24794 .3812 L
s
0 0 0 r
2.5 Mabswid
.24794 .3812 Mdot
0 .149 1 r
.5 Mabswid
.55708 .71069 m
.26604 .29726 L
s
0 0 0 r
2.5 Mabswid
.26604 .29726 Mdot
.333 1 0 r
.5 Mabswid
.82047 .59029 m
.65344 .47316 L
s
0 0 0 r
2.5 Mabswid
.65344 .47316 Mdot
.797 1 0 r
.5 Mabswid
.62045 .78429 m
.41715 .39017 L
s
0 0 0 r
2.5 Mabswid
.41715 .39017 Mdot
0 .542 1 r
.5 Mabswid
.60504 .78068 m
.55163 .74826 L
s
0 0 0 r
2.5 Mabswid
.55163 .74826 Mdot
0 .538 1 r
.5 Mabswid
.57624 .4081 m
.70924 .74657 L
s
0 0 0 r
2.5 Mabswid
.70924 .74657 Mdot
0 .038 1 r
.5 Mabswid
.74059 .68125 m
.30992 .32391 L
s
0 0 0 r
2.5 Mabswid
.30992 .32391 Mdot
0 1 .532 r
.5 Mabswid
.26516 .29257 m
.26388 .26098 L
s
0 0 0 r
2.5 Mabswid
.26388 .26098 Mdot
0 1 .381 r
.5 Mabswid
.29163 .72131 m
.33915 .29316 L
s
0 0 0 r
2.5 Mabswid
.33915 .29316 Mdot
.741 1 0 r
.5 Mabswid
.30928 .74777 m
.28247 .69129 L
s
0 0 0 r
2.5 Mabswid
.28247 .69129 Mdot
0 1 .643 r
.5 Mabswid
.24794 .3812 m
.20126 .3839 L
s
0 0 0 r
2.5 Mabswid
.20126 .3839 Mdot
0 .149 1 r
.5 Mabswid
.26604 .29726 m
.28453 .28187 L
s
0 0 0 r
2.5 Mabswid
.28453 .28187 Mdot
.333 1 0 r
.5 Mabswid
.65344 .47316 m
.38101 .28212 L
s
0 0 0 r
2.5 Mabswid
.38101 .28212 Mdot
.797 1 0 r
.5 Mabswid
.41715 .39017 m
.37502 .30849 L
s
0 0 0 r
2.5 Mabswid
.37502 .30849 Mdot
0 .542 1 r
.5 Mabswid
.55163 .74826 m
.29736 .44307 L
s
0 0 0 r
2.5 Mabswid
.29736 .44307 Mdot
0 .038 1 r
.5 Mabswid
.30992 .32391 m
.31983 .31261 L
s
0 0 0 r
2.5 Mabswid
.31983 .31261 Mdot
0 .829 1 r
.5 Mabswid
.26388 .26098 m
.34915 .30548 L
s
0 0 0 r
2.5 Mabswid
.34915 .30548 Mdot
0 1 .381 r
.5 Mabswid
.33915 .29316 m
.42492 .23688 L
s
0 0 0 r
2.5 Mabswid
.42492 .23688 Mdot
.741 1 0 r
.5 Mabswid
.28247 .69129 m
.4081 .20662 L
s
0 0 0 r
2.5 Mabswid
.4081 .20662 Mdot
0 .439 1 r
.5 Mabswid
.20126 .3839 m
.36078 .44716 L
s
0 0 0 r
2.5 Mabswid
.36078 .44716 Mdot
0 .149 1 r
.5 Mabswid
.28453 .28187 m
.76285 .61601 L
s
0 0 0 r
2.5 Mabswid
.76285 .61601 Mdot
.045 1 0 r
.5 Mabswid
.38101 .28212 m
.37656 .40641 L
s
0 0 0 r
2.5 Mabswid
.37656 .40641 Mdot
.797 1 0 r
.5 Mabswid
.37502 .30849 m
.33165 .2325 L
s
0 0 0 r
2.5 Mabswid
.33165 .2325 Mdot
0 .542 1 r
.5 Mabswid
.29736 .44307 m
.28686 .34294 L
s
0 0 0 r
2.5 Mabswid
.28686 .34294 Mdot
0 .038 1 r
.5 Mabswid
.31983 .31261 m
.69647 .76994 L
s
0 0 0 r
2.5 Mabswid
.69647 .76994 Mdot
0 .829 1 r
.5 Mabswid
.34915 .30548 m
.44807 .38038 L
s
0 0 0 r
2.5 Mabswid
.44807 .38038 Mdot
0 1 .381 r
.5 Mabswid
.42492 .23688 m
.71206 .3679 L
s
0 0 0 r
2.5 Mabswid
.71206 .3679 Mdot
.741 1 0 r
.5 Mabswid
.4081 .20662 m
.43088 .17935 L
s
0 0 0 r
2.5 Mabswid
.43088 .17935 Mdot
0 .439 1 r
.5 Mabswid
.36078 .44716 m
.66462 .56765 L
s
0 0 0 r
2.5 Mabswid
.66462 .56765 Mdot
0 .149 1 r
.5 Mabswid
.76285 .61601 m
.77279 .6379 L
s
0 0 0 r
2.5 Mabswid
.77279 .6379 Mdot
.045 1 0 r
.5 Mabswid
.37656 .40641 m
.37023 .58328 L
s
0 0 0 r
2.5 Mabswid
.37023 .58328 Mdot
0 1 .522 r
.5 Mabswid
.33165 .2325 m
.41085 .33608 L
s
0 0 0 r
2.5 Mabswid
.41085 .33608 Mdot
0 .542 1 r
.5 Mabswid
.28686 .34294 m
.66036 .39109 L
s
0 0 0 r
2.5 Mabswid
.66036 .39109 Mdot
0 .829 1 r
.5 Mabswid
.44807 .38038 m
.78897 .63848 L
s
0 0 0 r
2.5 Mabswid
.78897 .63848 Mdot
0 1 .381 r
.5 Mabswid
.71206 .3679 m
.75233 .5884 L
s
0 0 0 r
2.5 Mabswid
.75233 .5884 Mdot
.741 1 0 r
.5 Mabswid
.43088 .17935 m
.56816 .30016 L
s
0 0 0 r
2.5 Mabswid
.56816 .30016 Mdot
0 .149 1 r
.5 Mabswid
.77279 .6379 m
.41721 .48181 L
s
0 0 0 r
2.5 Mabswid
.41721 .48181 Mdot
.045 1 0 r
.5 Mabswid
.37023 .58328 m
.80021 .64643 L
s
0 0 0 r
2.5 Mabswid
.80021 .64643 Mdot
0 1 .522 r
.5 Mabswid
.41085 .33608 m
.65876 .63526 L
s
0 0 0 r
2.5 Mabswid
.65876 .63526 Mdot
0 .542 1 r
.5 Mabswid
.66036 .39109 m
.79078 .48616 L
s
0 0 0 r
2.5 Mabswid
.79078 .48616 Mdot
0 .829 1 r
.5 Mabswid
.78897 .63848 m
.77949 .63531 L
s
0 0 0 r
2.5 Mabswid
.77949 .63531 Mdot
0 1 .381 r
.5 Mabswid
.75233 .5884 m
.62174 .71152 L
s
0 0 0 r
2.5 Mabswid
.62174 .71152 Mdot
.741 1 0 r
.5 Mabswid
.56816 .30016 m
.67743 .46848 L
s
0 0 0 r
2.5 Mabswid
.67743 .46848 Mdot
0 .149 1 r
.5 Mabswid
.41721 .48181 m
.21899 .3948 L
s
0 0 0 r
2.5 Mabswid
.21899 .3948 Mdot
.045 1 0 r
.5 Mabswid
.80021 .64643 m
.80378 .64583 L
s
0 0 0 r
2.5 Mabswid
.80378 .64583 Mdot
0 1 .522 r
.5 Mabswid
.65876 .63526 m
.73508 .73359 L
s
0 0 0 r
2.5 Mabswid
.73508 .73359 Mdot
0 .542 1 r
.5 Mabswid
.79078 .48616 m
.66075 .64929 L
s
0 0 0 r
2.5 Mabswid
.66075 .64929 Mdot
0 .829 1 r
.5 Mabswid
.77949 .63531 m
.24083 .42017 L
s
0 0 0 r
2.5 Mabswid
.24083 .42017 Mdot
0 1 .381 r
.5 Mabswid
.62174 .71152 m
.22646 .68174 L
s
0 0 0 r
2.5 Mabswid
.22646 .68174 Mdot
.741 1 0 r
.5 Mabswid
.67743 .46848 m
.76837 .69498 L
s
0 0 0 r
2.5 Mabswid
.76837 .69498 Mdot
0 .149 1 r
.5 Mabswid
.21899 .3948 m
.18623 .38014 L
s
0 0 0 r
2.5 Mabswid
.18623 .38014 Mdot
.045 1 0 r
.5 Mabswid
.80378 .64583 m
.80158 .63622 L
s
0 0 0 r
2.5 Mabswid
.80158 .63622 Mdot
0 .2 1 r
.5 Mabswid
.73508 .73359 m
.69433 .72488 L
s
0 0 0 r
2.5 Mabswid
.69433 .72488 Mdot
0 .542 1 r
.5 Mabswid
.66075 .64929 m
.40241 .76371 L
s
0 0 0 r
2.5 Mabswid
.40241 .76371 Mdot
0 .829 1 r
.5 Mabswid
.24083 .42017 m
.25154 .40022 L
s
0 0 0 r
2.5 Mabswid
.25154 .40022 Mdot
0 1 .381 r
.5 Mabswid
.22646 .68174 m
.21557 .67479 L
s
0 0 0 r
2.5 Mabswid
.21557 .67479 Mdot
.741 1 0 r
.5 Mabswid
.76837 .69498 m
.75155 .70145 L
s
0 0 0 r
2.5 Mabswid
.75155 .70145 Mdot
.045 1 0 r
.5 Mabswid
.80158 .63622 m
.63427 .36274 L
s
0 0 0 r
2.5 Mabswid
.63427 .36274 Mdot
0 .2 1 r
.5 Mabswid
.69433 .72488 m
.49108 .61561 L
s
0 0 0 r
2.5 Mabswid
.49108 .61561 Mdot
0 .542 1 r
.5 Mabswid
.40241 .76371 m
.27518 .65245 L
s
0 0 0 r
2.5 Mabswid
.27518 .65245 Mdot
0 .829 1 r
.5 Mabswid
.25154 .40022 m
.71653 .49209 L
s
0 0 0 r
2.5 Mabswid
.71653 .49209 Mdot
0 1 .381 r
.5 Mabswid
.21557 .67479 m
.21552 .6745 L
s
0 0 0 r
2.5 Mabswid
.21552 .6745 Mdot
.741 1 0 r
.5 Mabswid
.75155 .70145 m
.40162 .68716 L
s
0 0 0 r
2.5 Mabswid
.40162 .68716 Mdot
.045 1 0 r
.5 Mabswid
.63427 .36274 m
.43188 .17341 L
s
0 0 0 r
2.5 Mabswid
.43188 .17341 Mdot
0 .2 1 r
.5 Mabswid
.49108 .61561 m
.17239 .44428 L
s
0 0 0 r
2.5 Mabswid
.17239 .44428 Mdot
0 .542 1 r
.5 Mabswid
.27518 .65245 m
.29582 .40615 L
s
0 0 0 r
2.5 Mabswid
.29582 .40615 Mdot
0 .829 1 r
.5 Mabswid
.71653 .49209 m
.67462 .58926 L
s
0 0 0 r
2.5 Mabswid
.67462 .58926 Mdot
0 1 .381 r
.5 Mabswid
.21552 .6745 m
.34788 .28172 L
s
0 0 0 r
2.5 Mabswid
.34788 .28172 Mdot
.741 1 0 r
.5 Mabswid
.40162 .68716 m
.18237 .57139 L
s
0 0 0 r
2.5 Mabswid
.18237 .57139 Mdot
.045 1 0 r
.5 Mabswid
.43188 .17341 m
.30039 .46315 L
s
0 0 0 r
2.5 Mabswid
.30039 .46315 Mdot
0 .2 1 r
.5 Mabswid
.17239 .44428 m
.17713 .4404 L
s
0 0 0 r
2.5 Mabswid
.17713 .4404 Mdot
0 .542 1 r
.5 Mabswid
.29582 .40615 m
.58836 .19758 L
s
0 0 0 r
2.5 Mabswid
.58836 .19758 Mdot
0 .829 1 r
.5 Mabswid
.67462 .58926 m
.23402 .62578 L
s
0 0 0 r
2.5 Mabswid
.23402 .62578 Mdot
0 1 .381 r
.5 Mabswid
.34788 .28172 m
.42901 .2251 L
s
0 0 0 r
2.5 Mabswid
.42901 .2251 Mdot
.741 1 0 r
.5 Mabswid
.18237 .57139 m
.19282 .53906 L
s
0 0 0 r
2.5 Mabswid
.19282 .53906 Mdot
.045 1 0 r
.5 Mabswid
.30039 .46315 m
.34272 .73044 L
s
0 0 0 r
2.5 Mabswid
.34272 .73044 Mdot
0 .2 1 r
.5 Mabswid
.17713 .4404 m
.75795 .39073 L
s
0 0 0 r
2.5 Mabswid
.75795 .39073 Mdot
0 .542 1 r
.5 Mabswid
.58836 .19758 m
.63133 .2215 L
s
0 0 0 r
2.5 Mabswid
.63133 .2215 Mdot
0 .829 1 r
.5 Mabswid
.23402 .62578 m
.22765 .57145 L
s
0 0 0 r
2.5 Mabswid
.22765 .57145 Mdot
0 1 .381 r
.5 Mabswid
.42901 .2251 m
.72462 .45901 L
s
0 0 0 r
2.5 Mabswid
.72462 .45901 Mdot
.741 1 0 r
.5 Mabswid
.19282 .53906 m
.41341 .2992 L
s
0 0 0 r
2.5 Mabswid
.41341 .2992 Mdot
.045 1 0 r
.5 Mabswid
.34272 .73044 m
.38266 .79787 L
s
0 0 0 r
2.5 Mabswid
.38266 .79787 Mdot
0 .2 1 r
.5 Mabswid
.75795 .39073 m
.79041 .40539 L
s
0 0 0 r
2.5 Mabswid
.79041 .40539 Mdot
0 .542 1 r
.5 Mabswid
.63133 .2215 m
.71272 .71909 L
s
0 0 0 r
2.5 Mabswid
.71272 .71909 Mdot
0 .829 1 r
.5 Mabswid
.22765 .57145 m
.51206 .19849 L
s
0 0 0 r
2.5 Mabswid
.51206 .19849 Mdot
0 1 .381 r
.5 Mabswid
.72462 .45901 m
.76295 .64157 L
s
0 0 0 r
2.5 Mabswid
.76295 .64157 Mdot
.741 1 0 r
.5 Mabswid
.41341 .2992 m
.62959 .21812 L
s
0 0 0 r
2.5 Mabswid
.62959 .21812 Mdot
.045 1 0 r
.5 Mabswid
.38266 .79787 m
.47281 .7706 L
s
0 0 0 r
2.5 Mabswid
.47281 .7706 Mdot
0 .2 1 r
.5 Mabswid
.79041 .40539 m
.50721 .54692 L
s
0 0 0 r
2.5 Mabswid
.50721 .54692 Mdot
0 .542 1 r
.5 Mabswid
.71272 .71909 m
.68914 .73754 L
s
0 0 0 r
2.5 Mabswid
.68914 .73754 Mdot
0 .829 1 r
.5 Mabswid
.51206 .19849 m
.54782 .21361 L
s
0 0 0 r
2.5 Mabswid
.54782 .21361 Mdot
0 1 .381 r
.5 Mabswid
.76295 .64157 m
.61662 .68408 L
s
0 0 0 r
2.5 Mabswid
.61662 .68408 Mdot
.741 1 0 r
.5 Mabswid
.62959 .21812 m
.6574 .29526 L
s
0 0 0 r
2.5 Mabswid
.6574 .29526 Mdot
.045 1 0 r
.5 Mabswid
.47281 .7706 m
.62729 .6649 L
s
0 0 0 r
2.5 Mabswid
.62729 .6649 Mdot
0 .2 1 r
.5 Mabswid
.50721 .54692 m
.24236 .67929 L
s
0 0 0 r
2.5 Mabswid
.24236 .67929 Mdot
0 .542 1 r
.5 Mabswid
.68914 .73754 m
.2085 .43941 L
s
0 0 0 r
2.5 Mabswid
.2085 .43941 Mdot
0 .829 1 r
.5 Mabswid
.54782 .21361 m
.69194 .77297 L
s
0 0 0 r
2.5 Mabswid
.69194 .77297 Mdot
0 1 .381 r
.5 Mabswid
.61662 .68408 m
.18804 .54843 L
s
0 0 0 r
2.5 Mabswid
.18804 .54843 Mdot
.741 1 0 r
.5 Mabswid
.6574 .29526 m
.67359 .55409 L
s
0 0 0 r
2.5 Mabswid
.67359 .55409 Mdot
.045 1 0 r
.5 Mabswid
.62729 .6649 m
.69115 .58699 L
s
0 0 0 r
2.5 Mabswid
.69115 .58699 Mdot
.2 0 1 r
.5 Mabswid
.24236 .67929 m
.25686 .66031 L
s
0 0 0 r
2.5 Mabswid
.25686 .66031 Mdot
0 .542 1 r
.5 Mabswid
.2085 .43941 m
.2105 .41322 L
s
0 0 0 r
2.5 Mabswid
.2105 .41322 Mdot
0 1 .381 r
.5 Mabswid
.18804 .54843 m
.17316 .53288 L
s
0 0 0 r
2.5 Mabswid
.17316 .53288 Mdot
.741 1 0 r
.5 Mabswid
.67359 .55409 m
.67011 .60081 L
s
0 0 0 r
2.5 Mabswid
.67011 .60081 Mdot
.045 1 0 r
.5 Mabswid
.69115 .58699 m
.75343 .45959 L
s
0 0 0 r
2.5 Mabswid
.75343 .45959 Mdot
.2 0 1 r
.5 Mabswid
.25686 .66031 m
.594 .37378 L
s
0 0 0 r
2.5 Mabswid
.594 .37378 Mdot
0 .542 1 r
.5 Mabswid
.2105 .41322 m
.73875 .32626 L
s
0 0 0 r
2.5 Mabswid
.73875 .32626 Mdot
0 1 .381 r
.5 Mabswid
.17316 .53288 m
.37836 .34639 L
s
0 0 0 r
2.5 Mabswid
.37836 .34639 Mdot
.741 1 0 r
.5 Mabswid
.67011 .60081 m
.66225 .66689 L
s
0 0 0 r
2.5 Mabswid
.66225 .66689 Mdot
.045 1 0 r
.5 Mabswid
.75343 .45959 m
.78227 .33321 L
s
0 0 0 r
2.5 Mabswid
.78227 .33321 Mdot
.2 0 1 r
.5 Mabswid
.594 .37378 m
.60828 .36165 L
s
0 0 0 r
2.5 Mabswid
.60828 .36165 Mdot
0 .542 1 r
.5 Mabswid
.73875 .32626 m
.7593 .35341 L
s
0 0 0 r
2.5 Mabswid
.7593 .35341 Mdot
0 1 .381 r
.5 Mabswid
.37836 .34639 m
.60752 .22858 L
s
0 0 0 r
2.5 Mabswid
.60752 .22858 Mdot
.741 1 0 r
.5 Mabswid
.66225 .66689 m
.66154 .67259 L
s
0 0 0 r
2.5 Mabswid
.66154 .67259 Mdot
.045 1 0 r
.5 Mabswid
.78227 .33321 m
.73374 .31655 L
s
0 0 0 r
2.5 Mabswid
.73374 .31655 Mdot
.2 0 1 r
.5 Mabswid
.60828 .36165 m
.73598 .25646 L
s
0 0 0 r
2.5 Mabswid
.73598 .25646 Mdot
0 .542 1 r
.5 Mabswid
.7593 .35341 m
.47336 .81252 L
s
0 0 0 r
2.5 Mabswid
.47336 .81252 Mdot
0 1 .381 r
.5 Mabswid
.60752 .22858 m
.66543 .21224 L
s
0 0 0 r
2.5 Mabswid
.66543 .21224 Mdot
.741 1 0 r
.5 Mabswid
.66154 .67259 m
.62167 .78595 L
s
0 0 0 r
2.5 Mabswid
.62167 .78595 Mdot
.045 1 0 r
.5 Mabswid
.73374 .31655 m
.50969 .29957 L
s
0 0 0 r
2.5 Mabswid
.50969 .29957 Mdot
.2 0 1 r
.5 Mabswid
.73598 .25646 m
.67088 .46968 L
s
0 0 0 r
2.5 Mabswid
.67088 .46968 Mdot
0 .542 1 r
.5 Mabswid
.47336 .81252 m
.45589 .8115 L
s
0 0 0 r
2.5 Mabswid
.45589 .8115 Mdot
0 1 .381 r
.5 Mabswid
.66543 .21224 m
.67445 .26355 L
s
0 0 0 r
2.5 Mabswid
.67445 .26355 Mdot
.741 1 0 r
.5 Mabswid
.62167 .78595 m
.48324 .70802 L
s
0 0 0 r
2.5 Mabswid
.48324 .70802 Mdot
.045 1 0 r
.5 Mabswid
.50969 .29957 m
.46816 .30758 L
s
0 0 0 r
2.5 Mabswid
.46816 .30758 Mdot
.2 0 1 r
.5 Mabswid
.67088 .46968 m
.63369 .53988 L
s
0 0 0 r
2.5 Mabswid
.63369 .53988 Mdot
0 .542 1 r
.5 Mabswid
.45589 .8115 m
.36487 .26702 L
s
0 0 0 r
2.5 Mabswid
.36487 .26702 Mdot
0 1 .381 r
.5 Mabswid
.67445 .26355 m
.67674 .39341 L
s
0 0 0 r
2.5 Mabswid
.67674 .39341 Mdot
.741 1 0 r
.5 Mabswid
.48324 .70802 m
.19219 .40255 L
s
0 0 0 r
2.5 Mabswid
.19219 .40255 Mdot
.045 1 0 r
.5 Mabswid
.46816 .30758 m
.42968 .31827 L
s
0 0 0 r
2.5 Mabswid
.42968 .31827 Mdot
.2 0 1 r
.5 Mabswid
.63369 .53988 m
.56015 .61985 L
s
0 0 0 r
2.5 Mabswid
.56015 .61985 Mdot
0 .542 1 r
.5 Mabswid
.36487 .26702 m
.37804 .23647 L
s
0 0 0 r
2.5 Mabswid
.37804 .23647 Mdot
0 1 .381 r
.5 Mabswid
.67674 .39341 m
.66129 .49402 L
s
0 0 0 r
2.5 Mabswid
.66129 .49402 Mdot
.741 1 0 r
.5 Mabswid
.19219 .40255 m
.18571 .38358 L
s
0 0 0 r
2.5 Mabswid
.18571 .38358 Mdot
.045 1 0 r
.5 Mabswid
.42968 .31827 m
.3747 .33914 L
s
0 0 0 r
2.5 Mabswid
.3747 .33914 Mdot
.2 0 1 r
.5 Mabswid
.56015 .61985 m
.36579 .70658 L
s
0 0 0 r
2.5 Mabswid
.36579 .70658 Mdot
0 .542 1 r
.5 Mabswid
.37804 .23647 m
.73411 .54322 L
s
0 0 0 r
2.5 Mabswid
.73411 .54322 Mdot
0 1 .381 r
.5 Mabswid
.66129 .49402 m
.63101 .69134 L
s
0 0 0 r
2.5 Mabswid
.63101 .69134 Mdot
.741 1 0 r
.5 Mabswid
.18571 .38358 m
.34995 .30061 L
s
0 0 0 r
2.5 Mabswid
.34995 .30061 Mdot
.045 1 0 r
.5 Mabswid
.3747 .33914 m
.34253 .35445 L
s
0 0 0 r
2.5 Mabswid
.34253 .35445 Mdot
.2 0 1 r
.5 Mabswid
.36579 .70658 m
.26961 .72675 L
s
0 0 0 r
2.5 Mabswid
.26961 .72675 Mdot
0 .542 1 r
.5 Mabswid
.73411 .54322 m
.72797 .5966 L
s
0 0 0 r
2.5 Mabswid
.72797 .5966 Mdot
0 1 .381 r
.5 Mabswid
.63101 .69134 m
.58262 .7898 L
s
0 0 0 r
2.5 Mabswid
.58262 .7898 Mdot
.741 1 0 r
.5 Mabswid
.34995 .30061 m
.7504 .29042 L
s
0 0 0 r
2.5 Mabswid
.7504 .29042 Mdot
.045 1 0 r
.5 Mabswid
.34253 .35445 m
.16489 .49923 L
s
0 0 0 r
2.5 Mabswid
.16489 .49923 Mdot
0 .542 1 r
.5 Mabswid
.72797 .5966 m
.20821 .55601 L
s
0 0 0 r
2.5 Mabswid
.20821 .55601 Mdot
0 1 .381 r
.5 Mabswid
.58262 .7898 m
.45021 .64614 L
s
0 0 0 r
2.5 Mabswid
.45021 .64614 Mdot
.741 1 0 r
.5 Mabswid
.7504 .29042 m
.75686 .30819 L
s
0 0 0 r
2.5 Mabswid
.75686 .30819 Mdot
.045 1 0 r
.5 Mabswid
.16489 .49923 m
.17284 .5242 L
s
0 0 0 r
2.5 Mabswid
.17284 .5242 Mdot
0 .542 1 r
.5 Mabswid
.20821 .55601 m
.20881 .53399 L
s
0 0 0 r
2.5 Mabswid
.20881 .53399 Mdot
0 1 .381 r
.5 Mabswid
.45021 .64614 m
.26782 .44826 L
s
0 0 0 r
2.5 Mabswid
.26782 .44826 Mdot
.741 1 0 r
.5 Mabswid
.75686 .30819 m
.51276 .8375 L
s
0 0 0 r
2.5 Mabswid
.51276 .8375 Mdot
.045 1 0 r
.5 Mabswid
.17284 .5242 m
.53019 .81371 L
s
0 0 0 r
2.5 Mabswid
.53019 .81371 Mdot
0 .542 1 r
.5 Mabswid
.20881 .53399 m
.72763 .27463 L
s
0 0 0 r
2.5 Mabswid
.72763 .27463 Mdot
0 1 .381 r
.5 Mabswid
.26782 .44826 m
.45302 .34388 L
s
0 0 0 r
2.5 Mabswid
.45302 .34388 Mdot
.741 1 0 r
.5 Mabswid
.51276 .8375 m
.51244 .83766 L
s
0 0 0 r
2.5 Mabswid
.51244 .83766 Mdot
.045 1 0 r
.5 Mabswid
.53019 .81371 m
.56568 .80959 L
s
0 0 0 r
2.5 Mabswid
.56568 .80959 Mdot
0 .542 1 r
.5 Mabswid
.72763 .27463 m
.73477 .27585 L
s
0 0 0 r
2.5 Mabswid
.73477 .27585 Mdot
0 1 .381 r
.5 Mabswid
.45302 .34388 m
.61357 .25339 L
s
0 0 0 r
2.5 Mabswid
.61357 .25339 Mdot
.741 1 0 r
.5 Mabswid
.51244 .83766 m
.50326 .83704 L
s
0 0 0 r
2.5 Mabswid
.50326 .83704 Mdot
.045 1 0 r
.5 Mabswid
.56568 .80959 m
.76961 .44624 L
s
0 0 0 r
2.5 Mabswid
.76961 .44624 Mdot
0 .542 1 r
.5 Mabswid
.73477 .27585 m
.35427 .60993 L
s
0 0 0 r
2.5 Mabswid
.35427 .60993 Mdot
0 1 .381 r
.5 Mabswid
.61357 .25339 m
.66214 .45138 L
s
0 0 0 r
2.5 Mabswid
.66214 .45138 Mdot
.741 1 0 r
.5 Mabswid
.50326 .83704 m
.21175 .56883 L
s
0 0 0 r
2.5 Mabswid
.21175 .56883 Mdot
.045 1 0 r
.5 Mabswid
.76961 .44624 m
.7268 .33096 L
s
0 0 0 r
2.5 Mabswid
.7268 .33096 Mdot
0 .542 1 r
.5 Mabswid
.35427 .60993 m
.41793 .60726 L
s
0 0 0 r
2.5 Mabswid
.41793 .60726 Mdot
0 1 .381 r
.5 Mabswid
.66214 .45138 m
.7121 .65506 L
s
0 0 0 r
2.5 Mabswid
.7121 .65506 Mdot
.741 1 0 r
.5 Mabswid
.21175 .56883 m
.1958 .47544 L
s
0 0 0 r
2.5 Mabswid
.1958 .47544 Mdot
.045 1 0 r
.5 Mabswid
.7268 .33096 m
.3993 .2345 L
s
0 0 0 r
2.5 Mabswid
.3993 .2345 Mdot
0 1 .381 r
.5 Mabswid
.7121 .65506 m
.4845 .68019 L
s
0 0 0 r
2.5 Mabswid
.4845 .68019 Mdot
.741 1 0 r
.5 Mabswid
.1958 .47544 m
.40526 .2776 L
s
0 0 0 r
2.5 Mabswid
.40526 .2776 Mdot
.045 1 0 r
.5 Mabswid
.3993 .2345 m
.295 .31337 L
s
0 0 0 r
2.5 Mabswid
.295 .31337 Mdot
0 1 .381 r
.5 Mabswid
.4845 .68019 m
.22878 .56166 L
s
0 0 0 r
2.5 Mabswid
.22878 .56166 Mdot
.741 1 0 r
.5 Mabswid
.40526 .2776 m
.69968 .2699 L
s
0 0 0 r
2.5 Mabswid
.69968 .2699 Mdot
.045 1 0 r
.5 Mabswid
.295 .31337 m
.32783 .67881 L
s
0 0 0 r
2.5 Mabswid
.32783 .67881 Mdot
0 1 .381 r
.5 Mabswid
.22878 .56166 m
.29436 .4445 L
s
0 0 0 r
2.5 Mabswid
.29436 .4445 Mdot
.741 1 0 r
.5 Mabswid
.69968 .2699 m
.75507 .34695 L
s
0 0 0 r
2.5 Mabswid
.75507 .34695 Mdot
.045 1 0 r
.5 Mabswid
.32783 .67881 m
.48743 .70053 L
s
0 0 0 r
2.5 Mabswid
.48743 .70053 Mdot
0 1 .381 r
.5 Mabswid
.29436 .4445 m
.7528 .27787 L
s
0 0 0 r
2.5 Mabswid
.7528 .27787 Mdot
.741 1 0 r
.5 Mabswid
.75507 .34695 m
.7395 .74119 L
s
0 0 0 r
2.5 Mabswid
.7395 .74119 Mdot
.045 1 0 r
.5 Mabswid
.48743 .70053 m
.71285 .53993 L
s
0 0 0 r
2.5 Mabswid
.71285 .53993 Mdot
0 .702 1 r
.5 Mabswid
.7528 .27787 m
.38338 .68137 L
s
0 0 0 r
2.5 Mabswid
.38338 .68137 Mdot
.741 1 0 r
.5 Mabswid
.7395 .74119 m
.21617 .54824 L
s
0 0 0 r
2.5 Mabswid
.21617 .54824 Mdot
.045 1 0 r
.5 Mabswid
.71285 .53993 m
.56308 .30483 L
s
0 0 0 r
2.5 Mabswid
.56308 .30483 Mdot
0 .702 1 r
.5 Mabswid
.38338 .68137 m
.36835 .64528 L
s
0 0 0 r
2.5 Mabswid
.36835 .64528 Mdot
.741 1 0 r
.5 Mabswid
.21617 .54824 m
.20007 .49895 L
s
0 0 0 r
2.5 Mabswid
.20007 .49895 Mdot
.045 1 0 r
.5 Mabswid
.56308 .30483 m
.33002 .33977 L
s
0 0 0 r
2.5 Mabswid
.33002 .33977 Mdot
0 .702 1 r
.5 Mabswid
.36835 .64528 m
.54023 .37262 L
s
0 0 0 r
2.5 Mabswid
.54023 .37262 Mdot
.741 1 0 r
.5 Mabswid
.20007 .49895 m
.60784 .36796 L
s
0 0 0 r
2.5 Mabswid
.60784 .36796 Mdot
.045 1 0 r
.5 Mabswid
.33002 .33977 m
.39733 .59596 L
s
0 0 0 r
2.5 Mabswid
.39733 .59596 Mdot
.741 1 0 r
.5 Mabswid
.60784 .36796 m
.73383 .37725 L
s
0 0 0 r
2.5 Mabswid
.73383 .37725 Mdot
.045 1 0 r
.5 Mabswid
.39733 .59596 m
.44732 .78623 L
s
0 0 0 r
2.5 Mabswid
.44732 .78623 Mdot
.741 1 0 r
.5 Mabswid
.73383 .37725 m
.57592 .62998 L
s
0 0 0 r
2.5 Mabswid
.57592 .62998 Mdot
0 1 .632 r
.5 Mabswid
.44732 .78623 m
.53392 .69257 L
s
0 0 0 r
2.5 Mabswid
.53392 .69257 Mdot
.741 1 0 r
.5 Mabswid
.57592 .62998 m
.46017 .81523 L
s
0 0 0 r
2.5 Mabswid
.46017 .81523 Mdot
0 1 .632 r
.5 Mabswid
.53392 .69257 m
.74838 .27126 L
s
0 0 0 r
2.5 Mabswid
.74838 .27126 Mdot
0 .989 1 r
.5 Mabswid
.46017 .81523 m
.4428 .77395 L
s
0 0 0 r
2.5 Mabswid
.4428 .77395 Mdot
0 1 .632 r
.5 Mabswid
.74838 .27126 m
.35991 .30167 L
s
0 0 0 r
2.5 Mabswid
.35991 .30167 Mdot
0 .989 1 r
.5 Mabswid
.4428 .77395 m
.44361 .26603 L
s
0 0 0 r
2.5 Mabswid
.44361 .26603 Mdot
0 1 .632 r
.5 Mabswid
.35991 .30167 m
.20679 .45482 L
s
0 0 0 r
2.5 Mabswid
.20679 .45482 Mdot
0 .989 1 r
.5 Mabswid
.44361 .26603 m
.47722 .20997 L
s
0 0 0 r
2.5 Mabswid
.47722 .20997 Mdot
0 1 .632 r
.5 Mabswid
.20679 .45482 m
.2552 .60309 L
s
0 0 0 r
2.5 Mabswid
.2552 .60309 Mdot
0 .989 1 r
.5 Mabswid
.47722 .20997 m
.65265 .49039 L
s
0 0 0 r
2.5 Mabswid
.65265 .49039 Mdot
0 1 .632 r
.5 Mabswid
.2552 .60309 m
.57402 .8179 L
s
0 0 0 r
2.5 Mabswid
.57402 .8179 Mdot
0 .989 1 r
.5 Mabswid
.65265 .49039 m
.77595 .68748 L
s
0 0 0 r
2.5 Mabswid
.77595 .68748 Mdot
0 1 .632 r
.5 Mabswid
.57402 .8179 m
.59335 .81993 L
s
0 0 0 r
2.5 Mabswid
.59335 .81993 Mdot
0 .989 1 r
.5 Mabswid
.77595 .68748 m
.42448 .62847 L
s
0 0 0 r
2.5 Mabswid
.42448 .62847 Mdot
0 1 .632 r
.5 Mabswid
.59335 .81993 m
.71816 .6502 L
s
0 0 0 r
2.5 Mabswid
.71816 .6502 Mdot
0 .989 1 r
.5 Mabswid
.42448 .62847 m
.28879 .48283 L
s
0 0 0 r
2.5 Mabswid
.28879 .48283 Mdot
0 1 .632 r
.5 Mabswid
.71816 .6502 m
.77552 .43192 L
s
0 0 0 r
2.5 Mabswid
.77552 .43192 Mdot
0 .989 1 r
.5 Mabswid
.28879 .48283 m
.24326 .35579 L
s
0 0 0 r
2.5 Mabswid
.24326 .35579 Mdot
0 1 .632 r
.5 Mabswid
.77552 .43192 m
.76722 .30704 L
s
0 0 0 r
2.5 Mabswid
.76722 .30704 Mdot
0 .989 1 r
.5 Mabswid
.24326 .35579 m
.38654 .30623 L
s
0 0 0 r
2.5 Mabswid
.38654 .30623 Mdot
0 1 .632 r
.5 Mabswid
.76722 .30704 m
.71546 .27393 L
s
0 0 0 r
2.5 Mabswid
.71546 .27393 Mdot
0 .989 1 r
.5 Mabswid
.38654 .30623 m
.62597 .35263 L
s
0 0 0 r
2.5 Mabswid
.62597 .35263 Mdot
0 1 .632 r
.5 Mabswid
.71546 .27393 m
.28437 .25463 L
s
0 0 0 r
2.5 Mabswid
.28437 .25463 Mdot
0 .989 1 r
.5 Mabswid
.62597 .35263 m
.80979 .4996 L
s
0 0 0 r
2.5 Mabswid
.80979 .4996 Mdot
0 1 .632 r
.5 Mabswid
.28437 .25463 m
.25748 .26848 L
s
0 0 0 r
2.5 Mabswid
.25748 .26848 Mdot
0 .989 1 r
.5 Mabswid
.80979 .4996 m
.81096 .50081 L
s
0 0 0 r
2.5 Mabswid
.81096 .50081 Mdot
0 1 .632 r
.5 Mabswid
.25748 .26848 m
.2631 .43516 L
s
0 0 0 r
2.5 Mabswid
.2631 .43516 Mdot
0 .989 1 r
.5 Mabswid
.81096 .50081 m
.83456 .52801 L
s
0 0 0 r
2.5 Mabswid
.83456 .52801 Mdot
0 1 .632 r
.5 Mabswid
.2631 .43516 m
.33085 .62657 L
s
0 0 0 r
2.5 Mabswid
.33085 .62657 Mdot
0 .989 1 r
.5 Mabswid
.83456 .52801 m
.79103 .54977 L
s
0 0 0 r
2.5 Mabswid
.79103 .54977 Mdot
0 1 .632 r
.5 Mabswid
.33085 .62657 m
.44318 .75482 L
s
0 0 0 r
2.5 Mabswid
.44318 .75482 Mdot
0 .989 1 r
.5 Mabswid
.79103 .54977 m
.75081 .56611 L
s
0 0 0 r
2.5 Mabswid
.75081 .56611 Mdot
0 1 .632 r
.5 Mabswid
.44318 .75482 m
.54545 .82252 L
s
0 0 0 r
2.5 Mabswid
.54545 .82252 Mdot
0 .989 1 r
.5 Mabswid
.75081 .56611 m
.64173 .60379 L
s
0 0 0 r
2.5 Mabswid
.64173 .60379 Mdot
0 1 .632 r
.5 Mabswid
.54545 .82252 m
.59191 .76949 L
s
0 0 0 r
2.5 Mabswid
.59191 .76949 Mdot
0 .989 1 r
.5 Mabswid
.64173 .60379 m
.39622 .64995 L
s
0 0 0 r
2.5 Mabswid
.39622 .64995 Mdot
0 1 .632 r
.5 Mabswid
.59191 .76949 m
.6651 .63355 L
s
0 0 0 r
2.5 Mabswid
.6651 .63355 Mdot
0 .989 1 r
.5 Mabswid
.39622 .64995 m
.21483 .65603 L
s
0 0 0 r
2.5 Mabswid
.21483 .65603 Mdot
0 1 .632 r
.5 Mabswid
.6651 .63355 m
.69791 .46056 L
s
0 0 0 r
2.5 Mabswid
.69791 .46056 Mdot
0 .989 1 r
.5 Mabswid
.21483 .65603 m
.22551 .61538 L
s
0 0 0 r
2.5 Mabswid
.22551 .61538 Mdot
0 1 .632 r
.5 Mabswid
.69791 .46056 m
.64826 .22772 L
s
0 0 0 r
2.5 Mabswid
.64826 .22772 Mdot
0 .989 1 r
.5 Mabswid
.22551 .61538 m
.48704 .25361 L
s
0 0 0 r
2.5 Mabswid
.48704 .25361 Mdot
0 1 .632 r
.5 Mabswid
.64826 .22772 m
.6313 .18737 L
s
0 0 0 r
2.5 Mabswid
.6313 .18737 Mdot
0 .989 1 r
.5 Mabswid
.48704 .25361 m
.61095 .18565 L
s
0 0 0 r
2.5 Mabswid
.61095 .18565 Mdot
0 1 .632 r
.5 Mabswid
.6313 .18737 m
.60065 .18972 L
s
0 0 0 r
2.5 Mabswid
.60065 .18972 Mdot
0 .989 1 r
.5 Mabswid
.61095 .18565 m
.63849 .21517 L
s
0 0 0 r
2.5 Mabswid
.63849 .21517 Mdot
0 1 .632 r
.5 Mabswid
.60065 .18972 m
.30854 .31456 L
s
0 0 0 r
2.5 Mabswid
.30854 .31456 Mdot
0 .989 1 r
.5 Mabswid
.63849 .21517 m
.77773 .51857 L
s
0 0 0 r
2.5 Mabswid
.77773 .51857 Mdot
0 1 .632 r
.5 Mabswid
.30854 .31456 m
.22587 .488 L
s
0 0 0 r
2.5 Mabswid
.22587 .488 Mdot
0 .989 1 r
.5 Mabswid
.77773 .51857 m
.75332 .6471 L
s
0 0 0 r
2.5 Mabswid
.75332 .6471 Mdot
0 1 .632 r
.5 Mabswid
.22587 .488 m
.32688 .75191 L
s
0 0 0 r
2.5 Mabswid
.32688 .75191 Mdot
0 .989 1 r
.5 Mabswid
.75332 .6471 m
.47339 .74532 L
s
0 0 0 r
2.5 Mabswid
.47339 .74532 Mdot
0 1 .632 r
.5 Mabswid
.32688 .75191 m
.42301 .78042 L
s
0 0 0 r
2.5 Mabswid
.42301 .78042 Mdot
0 .989 1 r
.5 Mabswid
.47339 .74532 m
.32696 .65066 L
s
0 0 0 r
2.5 Mabswid
.32696 .65066 Mdot
0 1 .632 r
.5 Mabswid
.42301 .78042 m
.76433 .70486 L
s
0 0 0 r
2.5 Mabswid
.76433 .70486 Mdot
0 .989 1 r
.5 Mabswid
.32696 .65066 m
.42093 .2416 L
s
0 0 0 r
2.5 Mabswid
.42093 .2416 Mdot
0 1 .632 r
.5 Mabswid
.76433 .70486 m
.69193 .29498 L
s
0 0 0 r
2.5 Mabswid
.69193 .29498 Mdot
0 .989 1 r
.5 Mabswid
.42093 .2416 m
.48967 .2204 L
s
0 0 0 r
2.5 Mabswid
.48967 .2204 Mdot
0 1 .632 r
.5 Mabswid
.69193 .29498 m
.60374 .24571 L
s
0 0 0 r
2.5 Mabswid
.60374 .24571 Mdot
0 .989 1 r
.5 Mabswid
.48967 .2204 m
.8229 .56129 L
s
0 0 0 r
2.5 Mabswid
.8229 .56129 Mdot
0 1 .632 r
.5 Mabswid
.60374 .24571 m
.27631 .37026 L
s
0 0 0 r
2.5 Mabswid
.27631 .37026 Mdot
0 .989 1 r
.5 Mabswid
.8229 .56129 m
.82055 .57372 L
s
0 0 0 r
2.5 Mabswid
.82055 .57372 Mdot
0 1 .632 r
.5 Mabswid
.27631 .37026 m
.23226 .54847 L
s
0 0 0 r
2.5 Mabswid
.23226 .54847 Mdot
0 .989 1 r
.5 Mabswid
.82055 .57372 m
.36391 .76682 L
s
0 0 0 r
2.5 Mabswid
.36391 .76682 Mdot
0 1 .632 r
.5 Mabswid
.23226 .54847 m
.39012 .67486 L
s
0 0 0 r
2.5 Mabswid
.39012 .67486 Mdot
0 .989 1 r
.5 Mabswid
.36391 .76682 m
.31168 .75889 L
s
0 0 0 r
2.5 Mabswid
.31168 .75889 Mdot
0 1 .632 r
.5 Mabswid
.39012 .67486 m
.71461 .63485 L
s
0 0 0 r
2.5 Mabswid
.71461 .63485 Mdot
0 .989 1 r
.5 Mabswid
.31168 .75889 m
.26311 .50291 L
s
0 0 0 r
2.5 Mabswid
.26311 .50291 Mdot
0 1 .632 r
.5 Mabswid
.71461 .63485 m
.79345 .57118 L
s
0 0 0 r
2.5 Mabswid
.79345 .57118 Mdot
0 .989 1 r
.5 Mabswid
.26311 .50291 m
.29925 .25248 L
s
0 0 0 r
2.5 Mabswid
.29925 .25248 Mdot
0 1 .632 r
.5 Mabswid
.79345 .57118 m
.62236 .3671 L
s
0 0 0 r
2.5 Mabswid
.62236 .3671 Mdot
0 .989 1 r
.5 Mabswid
.29925 .25248 m
.35655 .24608 L
s
0 0 0 r
2.5 Mabswid
.35655 .24608 Mdot
0 1 .632 r
.5 Mabswid
.62236 .3671 m
.21254 .36553 L
s
0 0 0 r
2.5 Mabswid
.21254 .36553 Mdot
0 .989 1 r
.5 Mabswid
.35655 .24608 m
.83539 .47614 L
s
0 0 0 r
2.5 Mabswid
.83539 .47614 Mdot
0 1 .632 r
.5 Mabswid
.21254 .36553 m
.18829 .37522 L
s
0 0 0 r
2.5 Mabswid
.18829 .37522 Mdot
0 .989 1 r
.5 Mabswid
.83539 .47614 m
.55046 .79438 L
s
0 0 0 r
2.5 Mabswid
.55046 .79438 Mdot
0 .989 1 r
.5 Mabswid
.55046 .79438 m
.46858 .80846 L
s
0 0 0 r
2.5 Mabswid
.46858 .80846 Mdot
0 .989 1 r
.5 Mabswid
.46858 .80846 m
.28145 .60442 L
s
0 0 0 r
2.5 Mabswid
.28145 .60442 Mdot
0 .989 1 r
.5 Mabswid
.28145 .60442 m
.27336 .29676 L
s
0 0 0 r
2.5 Mabswid
.27336 .29676 Mdot
0 .989 1 r
.5 Mabswid
.27336 .29676 m
.34766 .24143 L
s
0 0 0 r
2.5 Mabswid
.34766 .24143 Mdot
0 .989 1 r
.5 Mabswid
.34766 .24143 m
.73664 .2569 L
s
0 0 0 r
2.5 Mabswid
.73664 .2569 Mdot
0 .989 1 r
.5 Mabswid
.73664 .2569 m
.80417 .4032 L
s
0 0 0 r
2.5 Mabswid
.80417 .4032 Mdot
0 .989 1 r
.5 Mabswid
.80417 .4032 m
.8223 .53459 L
s
0 0 0 r
2.5 Mabswid
.8223 .53459 Mdot
0 .989 1 r
.5 Mabswid
.8223 .53459 m
.7736 .64193 L
s
0 0 0 r
2.5 Mabswid
.7736 .64193 Mdot
0 .989 1 r
.5 Mabswid
.7736 .64193 m
.61693 .81665 L
s
0 0 0 r
2.5 Mabswid
.61693 .81665 Mdot
0 .989 1 r
.5 Mabswid
.61693 .81665 m
.61608 .81705 L
s
0 0 0 r
2.5 Mabswid
.61608 .81705 Mdot
0 .989 1 r
.5 Mabswid
.61608 .81705 m
.59578 .81611 L
s
0 0 0 r
2.5 Mabswid
.59578 .81611 Mdot
0 .989 1 r
.5 Mabswid
.59578 .81611 m
.28222 .66851 L
s
0 0 0 r
2.5 Mabswid
.28222 .66851 Mdot
0 .989 1 r
.5 Mabswid
.28222 .66851 m
.20732 .52617 L
s
0 0 0 r
2.5 Mabswid
.20732 .52617 Mdot
0 .989 1 r
.5 Mabswid
.20732 .52617 m
.28455 .29868 L
s
0 0 0 r
2.5 Mabswid
.28455 .29868 Mdot
0 .989 1 r
.5 Mabswid
.28455 .29868 m
.43683 .18028 L
s
0 0 0 r
2.5 Mabswid
.43683 .18028 Mdot
0 .989 1 r
.5 Mabswid
.43683 .18028 m
.50383 .18222 L
s
0 0 0 r
2.5 Mabswid
.50383 .18222 Mdot
0 .989 1 r
.5 Mabswid
.50383 .18222 m
.76635 .39389 L
s
0 0 0 r
2.5 Mabswid
.76635 .39389 Mdot
0 .989 1 r
.5 Mabswid
.76635 .39389 m
.81096 .5063 L
s
0 0 0 r
2.5 Mabswid
.81096 .5063 Mdot
0 .989 1 r
.5 Mabswid
.81096 .5063 m
.67339 .64946 L
s
0 0 0 r
2.5 Mabswid
.67339 .64946 Mdot
0 .989 1 r
.5 Mabswid
.67339 .64946 m
.63489 .67243 L
s
0 0 0 r
2.5 Mabswid
.63489 .67243 Mdot
0 .989 1 r
.5 Mabswid
.63489 .67243 m
.4003 .75642 L
s
0 0 0 r
2.5 Mabswid
.4003 .75642 Mdot
0 .989 1 r
.5 Mabswid
.4003 .75642 m
.30991 .76621 L
s
0 0 0 r
2.5 Mabswid
.30991 .76621 Mdot
0 .989 1 r
.5 Mabswid
.30991 .76621 m
.28521 .69021 L
s
0 0 0 r
2.5 Mabswid
.28521 .69021 Mdot
0 .989 1 r
.5 Mabswid
.28521 .69021 m
.31019 .36975 L
s
0 0 0 r
2.5 Mabswid
.31019 .36975 Mdot
0 .989 1 r
.5 Mabswid
.31019 .36975 m
.3733 .21726 L
s
0 0 0 r
2.5 Mabswid
.3733 .21726 Mdot
0 .989 1 r
.5 Mabswid
.3733 .21726 m
.39254 .18124 L
s
0 0 0 r
2.5 Mabswid
.39254 .18124 Mdot
0 .989 1 r
.5 Mabswid
.39254 .18124 m
.58039 .33546 L
s
0 0 0 r
2.5 Mabswid
.58039 .33546 Mdot
0 .989 1 r
.5 Mabswid
.58039 .33546 m
.64278 .42628 L
s
0 0 0 r
2.5 Mabswid
.64278 .42628 Mdot
0 .989 1 r
.5 Mabswid
.64278 .42628 m
.68508 .59313 L
s
0 0 0 r
2.5 Mabswid
.68508 .59313 Mdot
0 .989 1 r
.5 Mabswid
.68508 .59313 m
.68262 .77919 L
s
0 0 0 r
2.5 Mabswid
.68262 .77919 Mdot
0 .989 1 r
.5 Mabswid
.68262 .77919 m
.60342 .7476 L
s
0 0 0 r
2.5 Mabswid
.60342 .7476 Mdot
0 .989 1 r
.5 Mabswid
.60342 .7476 m
.47357 .68013 L
s
0 0 0 r
2.5 Mabswid
.47357 .68013 Mdot
0 .989 1 r
.5 Mabswid
.47357 .68013 m
.38009 .61761 L
s
0 0 0 r
2.5 Mabswid
.38009 .61761 Mdot
0 .989 1 r
.5 Mabswid
.38009 .61761 m
.29776 .552 L
s
0 0 0 r
2.5 Mabswid
.29776 .552 Mdot
0 .989 1 r
.5 Mabswid
.29776 .552 m
.21779 .46652 L
s
0 0 0 r
2.5 Mabswid
.21779 .46652 Mdot
0 .989 1 r
.5 Mabswid
.21779 .46652 m
.18345 .41237 L
s
0 0 0 r
2.5 Mabswid
.18345 .41237 Mdot
0 .989 1 r
.5 Mabswid
.18345 .41237 m
.26112 .36789 L
s
0 0 0 r
2.5 Mabswid
.26112 .36789 Mdot
0 .989 1 r
.5 Mabswid
.26112 .36789 m
.42254 .31069 L
s
0 0 0 r
2.5 Mabswid
.42254 .31069 Mdot
0 .989 1 r
.5 Mabswid
.42254 .31069 m
.56061 .29298 L
s
0 0 0 r
2.5 Mabswid
.56061 .29298 Mdot
0 .989 1 r
.5 Mabswid
.56061 .29298 m
.77014 .32296 L
s
0 0 0 r
2.5 Mabswid
.77014 .32296 Mdot
0 .989 1 r
.5 Mabswid
.77014 .32296 m
.77112 .37053 L
s
0 0 0 r
2.5 Mabswid
.77112 .37053 Mdot
0 .989 1 r
.5 Mabswid
.77112 .37053 m
.5566 .80392 L
s
0 0 0 r
2.5 Mabswid
.5566 .80392 Mdot
0 .989 1 r
.5 Mabswid
.5566 .80392 m
.52369 .81938 L
s
0 0 0 r
2.5 Mabswid
.52369 .81938 Mdot
0 .989 1 r
.5 Mabswid
.52369 .81938 m
.26015 .59839 L
s
0 0 0 r
2.5 Mabswid
.26015 .59839 Mdot
0 .989 1 r
.5 Mabswid
.26015 .59839 m
.2061 .44181 L
s
0 0 0 r
2.5 Mabswid
.2061 .44181 Mdot
0 .989 1 r
.5 Mabswid
.2061 .44181 m
.33641 .30128 L
s
0 0 0 r
2.5 Mabswid
.33641 .30128 Mdot
0 .989 1 r
.5 Mabswid
.33641 .30128 m
.61496 .29914 L
s
0 0 0 r
2.5 Mabswid
.61496 .29914 Mdot
0 .989 1 r
.5 Mabswid
.61496 .29914 m
.72559 .56147 L
s
0 0 0 r
2.5 Mabswid
.72559 .56147 Mdot
0 .989 1 r
.5 Mabswid
.72559 .56147 m
.59528 .68003 L
s
0 0 0 r
2.5 Mabswid
.59528 .68003 Mdot
0 .989 1 r
.5 Mabswid
.59528 .68003 m
.19704 .48113 L
s
0 0 0 r
2.5 Mabswid
.19704 .48113 Mdot
0 .989 1 r
.5 Mabswid
.19704 .48113 m
.21505 .46334 L
s
0 0 0 r
2.5 Mabswid
.21505 .46334 Mdot
0 .989 1 r
.5 Mabswid
.21505 .46334 m
.73554 .43424 L
s
0 0 0 r
2.5 Mabswid
.73554 .43424 Mdot
0 .989 1 r
.5 Mabswid
.73554 .43424 m
.74354 .45549 L
s
0 0 0 r
2.5 Mabswid
.74354 .45549 Mdot
0 .989 1 r
.5 Mabswid
.74354 .45549 m
.35895 .68671 L
s
0 0 0 r
2.5 Mabswid
.35895 .68671 Mdot
0 .989 1 r
.5 Mabswid
.35895 .68671 m
.31784 .58781 L
s
0 0 0 r
2.5 Mabswid
.31784 .58781 Mdot
0 .989 1 r
.5 Mabswid
.31784 .58781 m
.59121 .22889 L
s
0 0 0 r
2.5 Mabswid
.59121 .22889 Mdot
0 .989 1 r
.5 Mabswid
.59121 .22889 m
.63458 .26565 L
s
0 0 0 r
2.5 Mabswid
.63458 .26565 Mdot
0 .989 1 r
.5 Mabswid
.63458 .26565 m
.67508 .74601 L
s
0 0 0 r
2.5 Mabswid
.67508 .74601 Mdot
0 .989 1 r
.5 Mabswid
.67508 .74601 m
.63886 .76097 L
s
0 0 0 r
2.5 Mabswid
.63886 .76097 Mdot
0 .989 1 r
.5 Mabswid
.63886 .76097 m
.28109 .492 L
s
0 0 0 r
2.5 Mabswid
.28109 .492 Mdot
0 .989 1 r
.5 Mabswid
.28109 .492 m
.35876 .40048 L
s
0 0 0 r
2.5 Mabswid
.35876 .40048 Mdot
0 .989 1 r
.5 Mabswid
.35876 .40048 m
.65553 .43222 L
s
0 0 0 r
2.5 Mabswid
.65553 .43222 Mdot
.544 1 0 r
.5 Mabswid
.81193 .5 m
.97619 .53034 L
s
0 0 0 r
2.5 Mabswid
.97619 .53034 Mdot
.549 1 0 r
.5 Mabswid
.79899 .5 m
.97619 .53286 L
s
0 0 0 r
2.5 Mabswid
.97619 .53286 Mdot
.554 1 0 r
.5 Mabswid
.78614 .5 m
.97619 .53537 L
s
0 0 0 r
2.5 Mabswid
.97619 .53537 Mdot
.559 1 0 r
.5 Mabswid
.77336 .5 m
.97619 .53789 L
s
0 0 0 r
2.5 Mabswid
.97619 .53789 Mdot
.564 1 0 r
.5 Mabswid
.76068 .5 m
.97619 .54042 L
s
0 0 0 r
2.5 Mabswid
.97619 .54042 Mdot
.569 1 0 r
.5 Mabswid
.74807 .5 m
.97619 .54294 L
s
0 0 0 r
2.5 Mabswid
.97619 .54294 Mdot
.831 1 0 r
.5 Mabswid
.73574 .5 m
.97619 .5 L
s
0 0 0 r
2.5 Mabswid
.97619 .5 Mdot
.833 1 0 r
.5 Mabswid
.72352 .5 m
.97619 .5 L
s
0 0 0 r
2.5 Mabswid
.97619 .5 Mdot
.834 1 0 r
.5 Mabswid
.71134 .5 m
.97619 .5 L
s
0 0 0 r
2.5 Mabswid
.97619 .5 Mdot
.836 1 0 r
.5 Mabswid
.6992 .5 m
.97619 .5 L
s
0 0 0 r
2.5 Mabswid
.97619 .5 Mdot
.838 1 0 r
.5 Mabswid
.68709 .5 m
.97619 .5 L
s
0 0 0 r
2.5 Mabswid
.97619 .5 Mdot
.84 1 0 r
.5 Mabswid
.67503 .5 m
.97619 .5 L
s
0 0 0 r
2.5 Mabswid
.97619 .5 Mdot
.933 1 0 r
.5 Mabswid
.66304 .5 m
.67634 .5 L
s
0 0 0 r
2.5 Mabswid
.67634 .5 Mdot
.934 1 0 r
.5 Mabswid
.65115 .5 m
.66279 .5 L
s
0 0 0 r
2.5 Mabswid
.66279 .5 Mdot
.934 1 0 r
.5 Mabswid
.63928 .5 m
.64925 .5 L
s
0 0 0 r
2.5 Mabswid
.64925 .5 Mdot
.934 1 0 r
.5 Mabswid
.6274 .5 m
.63571 .5 L
s
0 0 0 r
2.5 Mabswid
.63571 .5 Mdot
.934 1 0 r
.5 Mabswid
.61552 .5 m
.62217 .5 L
s
0 0 0 r
2.5 Mabswid
.62217 .5 Mdot
.934 1 0 r
.5 Mabswid
.60365 .5 m
.60863 .5 L
s
0 0 0 r
2.5 Mabswid
.60863 .5 Mdot
.934 1 0 r
.5 Mabswid
.59177 .5 m
.5951 .5 L
s
0 0 0 r
2.5 Mabswid
.5951 .5 Mdot
.934 1 0 r
.5 Mabswid
.5799 .5 m
.58156 .5 L
s
0 0 0 r
2.5 Mabswid
.58156 .5 Mdot
.934 1 0 r
.5 Mabswid
.56803 .5 m
.56803 .5 L
s
0 0 0 r
2.5 Mabswid
.56803 .5 Mdot
.934 1 0 r
.5 Mabswid
.55615 .5 m
.55449 .5 L
s
0 0 0 r
2.5 Mabswid
.55449 .5 Mdot
.934 1 0 r
.5 Mabswid
.54428 .5 m
.54096 .5 L
s
0 0 0 r
2.5 Mabswid
.54096 .5 Mdot
.934 1 0 r
.5 Mabswid
.53241 .5 m
.52742 .5 L
s
0 0 0 r
2.5 Mabswid
.52742 .5 Mdot
.934 1 0 r
.5 Mabswid
.52053 .5 m
.51388 .5 L
s
0 0 0 r
2.5 Mabswid
.51388 .5 Mdot
.934 1 0 r
.5 Mabswid
.50866 .5 m
.50034 .5 L
s
0 0 0 r
2.5 Mabswid
.50034 .5 Mdot
.934 1 0 r
.5 Mabswid
.49678 .5 m
.4868 .5 L
s
0 0 0 r
2.5 Mabswid
.4868 .5 Mdot
.934 1 0 r
.5 Mabswid
.4849 .5 m
.47326 .5 L
s
0 0 0 r
2.5 Mabswid
.47326 .5 Mdot
.933 1 0 r
.5 Mabswid
.47302 .5 m
.45972 .5 L
s
0 0 0 r
2.5 Mabswid
.45972 .5 Mdot
.933 1 0 r
.5 Mabswid
.46114 .5 m
.44617 .5 L
s
0 0 0 r
2.5 Mabswid
.44617 .5 Mdot
.933 1 0 r
.5 Mabswid
.44925 .5 m
.43262 .5 L
s
0 0 0 r
2.5 Mabswid
.43262 .5 Mdot
.933 1 0 r
.5 Mabswid
.43736 .5 m
.41907 .5 L
s
0 0 0 r
2.5 Mabswid
.41907 .5 Mdot
.933 1 0 r
.5 Mabswid
.42547 .5 m
.40551 .5 L
s
0 0 0 r
2.5 Mabswid
.40551 .5 Mdot
.933 1 0 r
.5 Mabswid
.41357 .5 m
.39195 .5 L
s
0 0 0 r
2.5 Mabswid
.39195 .5 Mdot
.933 1 0 r
.5 Mabswid
.40167 .5 m
.37838 .5 L
s
0 0 0 r
2.5 Mabswid
.37838 .5 Mdot
.932 1 0 r
.5 Mabswid
.38977 .5 m
.36481 .5 L
s
0 0 0 r
2.5 Mabswid
.36481 .5 Mdot
.932 1 0 r
.5 Mabswid
.37786 .5 m
.35124 .5 L
s
0 0 0 r
2.5 Mabswid
.35124 .5 Mdot
.932 1 0 r
.5 Mabswid
.36595 .5 m
.33766 .5 L
s
0 0 0 r
2.5 Mabswid
.33766 .5 Mdot
.932 1 0 r
.5 Mabswid
.35403 .5 m
.32407 .5 L
s
0 0 0 r
2.5 Mabswid
.32407 .5 Mdot
.932 1 0 r
.5 Mabswid
.34211 .5 m
.31048 .5 L
s
0 0 0 r
2.5 Mabswid
.31048 .5 Mdot
.819 1 0 r
.5 Mabswid
.33009 .5 m
.02381 .5 L
s
0 0 0 r
2.5 Mabswid
.02381 .5 Mdot
.817 1 0 r
.5 Mabswid
.31779 .5 m
.02381 .5 L
s
0 0 0 r
2.5 Mabswid
.02381 .5 Mdot
.815 1 0 r
.5 Mabswid
.30544 .5 m
.02381 .5 L
s
0 0 0 r
2.5 Mabswid
.02381 .5 Mdot
.813 1 0 r
.5 Mabswid
.29306 .5 m
.02381 .5 L
s
0 0 0 r
2.5 Mabswid
.02381 .5 Mdot
.811 1 0 r
.5 Mabswid
.28063 .5 m
.02381 .5 L
s
0 0 0 r
2.5 Mabswid
.02381 .5 Mdot
.809 1 0 r
.5 Mabswid
.26816 .5 m
.02381 .5 L
s
0 0 0 r
2.5 Mabswid
.02381 .5 Mdot
.807 1 0 r
.5 Mabswid
.25564 .5 m
.02381 .5 L
s
0 0 0 r
2.5 Mabswid
.02381 .5 Mdot
.508 1 0 r
.5 Mabswid
.24256 .5 m
.02381 .53934 L
s
0 0 0 r
2.5 Mabswid
.02381 .53934 Mdot
.5 1 0 r
.5 Mabswid
.22936 .5 m
.02381 .53682 L
s
0 0 0 r
2.5 Mabswid
.02381 .53682 Mdot
.494 1 0 r
.5 Mabswid
.21607 .5 m
.02381 .53431 L
s
0 0 0 r
2.5 Mabswid
.02381 .53431 Mdot
.488 1 0 r
.5 Mabswid
.20269 .5 m
.02381 .53179 L
s
0 0 0 r
2.5 Mabswid
.02381 .53179 Mdot
0 1 .067 r
.5 Mabswid
.43333 .39212 m
.23613 .34843 L
s
0 0 0 r
2.5 Mabswid
.23613 .34843 Mdot
0 .668 1 r
.5 Mabswid
.39584 .37774 m
.1983 .33404 L
s
0 0 0 r
2.5 Mabswid
.1983 .33404 Mdot
0 .56 1 r
.5 Mabswid
.37556 .36722 m
.02466 .20079 L
s
0 0 0 r
2.5 Mabswid
.02466 .20079 Mdot
0 .58 1 r
.5 Mabswid
.35878 .35753 m
.02381 .19872 L
s
0 0 0 r
2.5 Mabswid
.02381 .19872 Mdot
0 .599 1 r
.5 Mabswid
.34175 .34783 m
.02381 .19715 L
s
0 0 0 r
2.5 Mabswid
.02381 .19715 Mdot
0 .939 1 r
.5 Mabswid
.32588 .33843 m
.02381 .24403 L
s
0 0 0 r
2.5 Mabswid
.02381 .24403 Mdot
.261 1 0 r
.5 Mabswid
.32929 .49022 m
.5129 .20188 L
s
0 0 0 r
2.5 Mabswid
.5129 .20188 Mdot
1 .397 0 r
.5 Mabswid
.34102 .48237 m
.16405 .19492 L
s
0 0 0 r
2.5 Mabswid
.16405 .19492 Mdot
1 .403 0 r
.5 Mabswid
.35294 .47488 m
.17756 .18642 L
s
0 0 0 r
2.5 Mabswid
.17756 .18642 Mdot
1 .401 0 r
.5 Mabswid
.36484 .46741 m
.19105 .17794 L
s
0 0 0 r
2.5 Mabswid
.19105 .17794 Mdot
1 .398 0 r
.5 Mabswid
.37671 .45996 m
.20451 .16947 L
s
0 0 0 r
2.5 Mabswid
.20451 .16947 Mdot
1 .396 0 r
.5 Mabswid
.38855 .45253 m
.21794 .16101 L
s
0 0 0 r
2.5 Mabswid
.21794 .16101 Mdot
1 .356 0 r
.5 Mabswid
.24627 .55701 m
.40099 .14741 L
s
0 0 0 r
2.5 Mabswid
.40099 .14741 Mdot
1 .24 0 r
.5 Mabswid
.25514 .54921 m
.41258 .14103 L
s
0 0 0 r
2.5 Mabswid
.41258 .14103 Mdot
1 .242 0 r
.5 Mabswid
.26401 .54142 m
.42418 .13462 L
s
0 0 0 r
2.5 Mabswid
.42418 .13462 Mdot
1 .244 0 r
.5 Mabswid
.2729 .53361 m
.43579 .12819 L
s
0 0 0 r
2.5 Mabswid
.43579 .12819 Mdot
1 .246 0 r
.5 Mabswid
.2818 .5258 m
.44742 .12173 L
s
0 0 0 r
2.5 Mabswid
.44742 .12173 Mdot
1 .228 0 r
.5 Mabswid
.29163 .51823 m
.19182 .41166 L
s
0 0 0 r
2.5 Mabswid
.19182 .41166 Mdot
1 .286 0 r
.5 Mabswid
.30557 .42791 m
.3839 .66936 L
s
0 0 0 r
2.5 Mabswid
.3839 .66936 Mdot
1 .16 0 r
.5 Mabswid
.32594 .39485 m
.42008 .43536 L
s
0 0 0 r
2.5 Mabswid
.42008 .43536 Mdot
1 .247 0 r
.5 Mabswid
.33387 .40351 m
.19584 .46175 L
s
0 0 0 r
2.5 Mabswid
.19584 .46175 Mdot
1 .242 0 r
.5 Mabswid
.34229 .41238 m
.20698 .47129 L
s
0 0 0 r
2.5 Mabswid
.20698 .47129 Mdot
1 .168 0 r
.5 Mabswid
.35132 .4215 m
.02381 .28799 L
s
0 0 0 r
2.5 Mabswid
.02381 .28799 Mdot
1 .168 0 r
.5 Mabswid
.36113 .43094 m
.02381 .29418 L
s
0 0 0 r
2.5 Mabswid
.02381 .29418 Mdot
1 .169 0 r
.5 Mabswid
.37093 .44037 m
.02381 .30041 L
s
0 0 0 r
2.5 Mabswid
.02381 .30041 Mdot
1 .17 0 r
.5 Mabswid
.38072 .44979 m
.02381 .30669 L
s
0 0 0 r
2.5 Mabswid
.02381 .30669 Mdot
1 .163 0 r
.5 Mabswid
.62525 .55595 m
.97619 .70506 L
s
0 0 0 r
2.5 Mabswid
.97619 .70506 Mdot
1 .162 0 r
.5 Mabswid
.63509 .56542 m
.97619 .71106 L
s
0 0 0 r
2.5 Mabswid
.97619 .71106 Mdot
1 .161 0 r
.5 Mabswid
.64494 .5749 m
.97619 .71702 L
s
0 0 0 r
2.5 Mabswid
.97619 .71702 Mdot
1 .26 0 r
.5 Mabswid
.65453 .58427 m
.80243 .53808 L
s
0 0 0 r
2.5 Mabswid
.80243 .53808 Mdot
1 .243 0 r
.5 Mabswid
.66295 .59314 m
.81371 .54774 L
s
0 0 0 r
2.5 Mabswid
.81371 .54774 Mdot
1 .173 0 r
.5 Mabswid
.67111 .60189 m
.59536 .57612 L
s
0 0 0 r
2.5 Mabswid
.59536 .57612 Mdot
1 .173 0 r
.5 Mabswid
.67885 .61046 m
.60373 .58575 L
s
0 0 0 r
2.5 Mabswid
.60373 .58575 Mdot
1 .184 0 r
.5 Mabswid
.69782 .57894 m
.64222 .36366 L
s
0 0 0 r
2.5 Mabswid
.64222 .36366 Mdot
1 .245 0 r
.5 Mabswid
.71425 .52362 m
.82969 .43036 L
s
0 0 0 r
2.5 Mabswid
.82969 .43036 Mdot
1 .234 0 r
.5 Mabswid
.7234 .5313 m
.60403 .16748 L
s
0 0 0 r
2.5 Mabswid
.60403 .16748 Mdot
1 .234 0 r
.5 Mabswid
.73229 .53902 m
.61514 .17324 L
s
0 0 0 r
2.5 Mabswid
.61514 .17324 Mdot
1 .233 0 r
.5 Mabswid
.74117 .54674 m
.62628 .17902 L
s
0 0 0 r
2.5 Mabswid
.62628 .17902 Mdot
1 .233 0 r
.5 Mabswid
.75004 .55446 m
.63744 .18481 L
s
0 0 0 r
2.5 Mabswid
.63744 .18481 Mdot
1 .232 0 r
.5 Mabswid
.75891 .56217 m
.64863 .19061 L
s
0 0 0 r
2.5 Mabswid
.64863 .19061 Mdot
1 .421 0 r
.5 Mabswid
.61686 .45748 m
.80086 .18298 L
s
0 0 0 r
2.5 Mabswid
.80086 .18298 Mdot
1 .422 0 r
.5 Mabswid
.6289 .46498 m
.81447 .19144 L
s
0 0 0 r
2.5 Mabswid
.81447 .19144 Mdot
1 .424 0 r
.5 Mabswid
.64096 .4725 m
.82812 .19991 L
s
0 0 0 r
2.5 Mabswid
.82812 .19991 Mdot
1 .427 0 r
.5 Mabswid
.65306 .48004 m
.84181 .20839 L
s
0 0 0 r
2.5 Mabswid
.84181 .20839 Mdot
1 .429 0 r
.5 Mabswid
.66519 .4876 m
.85552 .21689 L
s
0 0 0 r
2.5 Mabswid
.85552 .21689 Mdot
1 .388 0 r
.5 Mabswid
.67677 .49598 m
.51836 .23025 L
s
0 0 0 r
2.5 Mabswid
.51836 .23025 Mdot
1 .392 0 r
.5 Mabswid
.68831 .50449 m
.53081 .23783 L
s
0 0 0 r
2.5 Mabswid
.53081 .23783 Mdot
0 1 .635 r
.5 Mabswid
.61907 .35292 m
.96418 .18843 L
s
0 0 0 r
2.5 Mabswid
.96418 .18843 Mdot
0 .375 1 r
.5 Mabswid
.60346 .36257 m
.94261 .20081 L
s
0 0 0 r
2.5 Mabswid
.94261 .20081 Mdot
0 .43 1 r
.5 Mabswid
.57382 .37544 m
.7677 .33182 L
s
0 0 0 r
2.5 Mabswid
.7677 .33182 Mdot
0 .402 1 r
.5 Mabswid
.54111 .38908 m
.73459 .34546 L
s
0 0 0 r
2.5 Mabswid
.73459 .34546 Mdot
0 .645 1 r
.5 Mabswid
.2803 .35822 m
.02381 .27493 L
s
0 0 0 r
2.5 Mabswid
.02381 .27493 Mdot
0 1 .72 r
.5 Mabswid
.32339 .36171 m
.02381 .26453 L
s
0 0 0 r
2.5 Mabswid
.02381 .26453 Mdot
0 1 .922 r
.5 Mabswid
.72024 .3425 m
.97619 .25953 L
s
0 0 0 r
2.5 Mabswid
.97619 .25953 Mdot
0 1 .827 r
.5 Mabswid
.76162 .33936 m
.97619 .24032 L
s
0 0 0 r
2.5 Mabswid
.97619 .24032 Mdot
.54 1 0 r
.5 Mabswid
.38889 .81257 m
.3683 .97619 L
s
0 0 0 r
2.5 Mabswid
.3683 .97619 Mdot
.8 1 0 r
.5 Mabswid
.81193 .5 m
.85409 .32768 L
s
0 0 0 r
2.5 Mabswid
.85409 .32768 Mdot
.765 1 0 r
.5 Mabswid
.79899 .5 m
.85664 .26343 L
s
0 0 0 r
2.5 Mabswid
.85664 .26343 Mdot
.766 1 0 r
.5 Mabswid
.78614 .5 m
.85917 .19908 L
s
0 0 0 r
2.5 Mabswid
.85917 .19908 Mdot
.767 1 0 r
.5 Mabswid
.77336 .5 m
.86168 .13462 L
s
0 0 0 r
2.5 Mabswid
.86168 .13462 Mdot
.768 1 0 r
.5 Mabswid
.76068 .5 m
.86417 .07005 L
s
0 0 0 r
2.5 Mabswid
.86417 .07005 Mdot
.77 1 0 r
.5 Mabswid
.74807 .5 m
.86222 .02381 L
s
0 0 0 r
2.5 Mabswid
.86222 .02381 Mdot
.93 1 0 r
.5 Mabswid
.55618 .70422 m
.50273 .94658 L
s
0 0 0 r
2.5 Mabswid
.50273 .94658 Mdot
.774 1 0 r
.5 Mabswid
.67988 .50569 m
.7653 .25154 L
s
0 0 0 r
2.5 Mabswid
.7653 .25154 Mdot
.785 1 0 r
.5 Mabswid
.74023 .28354 m
.74072 .02714 L
s
0 0 0 r
2.5 Mabswid
.74072 .02714 Mdot
.194 1 0 r
.5 Mabswid
.26516 .72193 m
.28438 .97619 L
s
0 0 0 r
2.5 Mabswid
.28438 .97619 Mdot
.703 1 0 r
.5 Mabswid
.31502 .49955 m
.21581 .7731 L
s
0 0 0 r
2.5 Mabswid
.21581 .7731 Mdot
.761 1 0 r
.5 Mabswid
.4708 .40496 m
.45499 .04661 L
s
0 0 0 r
2.5 Mabswid
.45499 .04661 Mdot
.782 1 0 r
.5 Mabswid
.24256 .5 m
.13506 .07269 L
s
0 0 0 r
2.5 Mabswid
.13506 .07269 Mdot
.757 1 0 r
.5 Mabswid
.22936 .5 m
.13767 .13691 L
s
0 0 0 r
2.5 Mabswid
.13767 .13691 Mdot
.757 1 0 r
.5 Mabswid
.21607 .5 m
.14029 .20108 L
s
0 0 0 r
2.5 Mabswid
.14029 .20108 Mdot
.756 1 0 r
.5 Mabswid
.20269 .5 m
.14294 .26523 L
s
0 0 0 r
2.5 Mabswid
.14294 .26523 Mdot
0 .77 1 r
.5 Mabswid
.27737 .38853 m
.56032 .50255 L
s
0 0 0 r
2.5 Mabswid
.56032 .50255 Mdot
0 1 .774 r
.5 Mabswid
.26353 .3892 m
.54624 .50396 L
s
0 0 0 r
2.5 Mabswid
.54624 .50396 Mdot
0 1 .668 r
.5 Mabswid
.2497 .38986 m
.53213 .50537 L
s
0 0 0 r
2.5 Mabswid
.53213 .50537 Mdot
0 1 .553 r
.5 Mabswid
.23589 .39052 m
.51797 .50678 L
s
0 0 0 r
2.5 Mabswid
.51797 .50678 Mdot
0 .101 1 r
.5 Mabswid
.73504 .61087 m
.40438 .48464 L
s
0 0 0 r
2.5 Mabswid
.40438 .48464 Mdot
0 .108 1 r
.5 Mabswid
.72113 .61154 m
.38982 .48583 L
s
0 0 0 r
2.5 Mabswid
.38982 .48583 Mdot
0 .008 1 r
.5 Mabswid
.7072 .6122 m
.37525 .487 L
s
0 0 0 r
2.5 Mabswid
.37525 .487 Mdot
0 1 .37 r
.5 Mabswid
.75425 .40526 m
.24126 .02381 L
s
0 0 0 r
2.5 Mabswid
.24126 .02381 Mdot
.327 1 0 r
.5 Mabswid
.76718 .41449 m
.25976 .02381 L
s
0 0 0 r
2.5 Mabswid
.25976 .02381 Mdot
.389 1 0 r
.5 Mabswid
.7801 .4237 m
.275 .02381 L
s
0 0 0 r
2.5 Mabswid
.275 .02381 Mdot
.761 1 0 r
.5 Mabswid
.73179 .50216 m
.38558 .58244 L
s
0 0 0 r
2.5 Mabswid
.38558 .58244 Mdot
0 .565 1 r
.5 Mabswid
.50083 .37109 m
.49644 .58281 L
s
0 0 0 r
2.5 Mabswid
.49644 .58281 Mdot
0 1 .391 r
.5 Mabswid
.35521 .63972 m
.36585 .92497 L
s
0 0 0 r
2.5 Mabswid
.36585 .92497 Mdot
0 1 .62 r
.5 Mabswid
.41325 .77518 m
.55173 .97619 L
s
0 0 0 r
2.5 Mabswid
.55173 .97619 Mdot
0 1 .017 r
.5 Mabswid
.55685 .26245 m
.26004 .02381 L
s
0 0 0 r
2.5 Mabswid
.26004 .02381 Mdot
0 1 .202 r
.5 Mabswid
.65846 .34746 m
.66129 .04046 L
s
0 0 0 r
2.5 Mabswid
.66129 .04046 Mdot
.57 1 0 r
.5 Mabswid
.62682 .59752 m
.33535 .11958 L
s
0 0 0 r
2.5 Mabswid
.33535 .11958 Mdot
.493 1 0 r
.5 Mabswid
.62074 .58065 m
.32695 .09792 L
s
0 0 0 r
2.5 Mabswid
.32695 .09792 Mdot
0 1 .516 r
.5 Mabswid
.46469 .52623 m
.86063 .02381 L
s
0 0 0 r
2.5 Mabswid
.86063 .02381 Mdot
.659 1 0 r
.5 Mabswid
.17632 .41728 m
.17355 .41597 L
s
0 0 0 r
2.5 Mabswid
.17355 .41597 Mdot
1 .984 0 r
.5 Mabswid
.75394 .70878 m
.51856 .97619 L
s
0 0 0 r
2.5 Mabswid
.51856 .97619 Mdot
.114 0 1 r
.5 Mabswid
.82696 .56622 m
.82975 .56689 L
s
0 0 0 r
2.5 Mabswid
.82975 .56689 Mdot
.486 1 0 r
.5 Mabswid
.27307 .72787 m
.30706 .97619 L
s
0 0 0 r
2.5 Mabswid
.30706 .97619 Mdot
.249 1 0 r
.5 Mabswid
.28839 .73474 m
.32277 .97619 L
s
0 0 0 r
2.5 Mabswid
.32277 .97619 Mdot
0 .502 1 r
.5 Mabswid
.48706 .31762 m
.20334 .02381 L
s
0 0 0 r
2.5 Mabswid
.20334 .02381 Mdot
0 .585 1 r
.5 Mabswid
.50338 .27315 m
.02381 .09371 L
s
0 0 0 r
2.5 Mabswid
.02381 .09371 Mdot
0 1 .969 r
.5 Mabswid
.49189 .70585 m
.72739 .97619 L
s
0 0 0 r
2.5 Mabswid
.72739 .97619 Mdot
0 .709 1 r
.5 Mabswid
.30043 .43735 m
.28997 .36364 L
s
0 0 0 r
2.5 Mabswid
.28997 .36364 Mdot
0 1 .303 r
.5 Mabswid
.28639 .60585 m
.2055 .88892 L
s
0 0 0 r
2.5 Mabswid
.2055 .88892 Mdot
0 1 .953 r
.5 Mabswid
.31191 .41535 m
.08322 .34294 L
s
0 0 0 r
2.5 Mabswid
.08322 .34294 Mdot
0 1 .779 r
.5 Mabswid
.43965 .20348 m
.33628 .02381 L
s
0 0 0 r
2.5 Mabswid
.33628 .02381 Mdot
0 .072 1 r
.5 Mabswid
.59567 .20882 m
.49099 .02381 L
s
0 0 0 r
2.5 Mabswid
.49099 .02381 Mdot
.479 1 0 r
.5 Mabswid
.21914 .32753 m
.42716 .02381 L
s
0 0 0 r
2.5 Mabswid
.42716 .02381 Mdot
0 .332 1 r
.5 Mabswid
.66079 .29732 m
.1334 .05903 L
s
0 0 0 r
2.5 Mabswid
.1334 .05903 Mdot
0 .156 1 r
.5 Mabswid
.71354 .46612 m
.97619 .4429 L
s
0 0 0 r
2.5 Mabswid
.97619 .4429 Mdot
.203 1 0 r
.5 Mabswid
.68155 .7105 m
.97619 .55068 L
s
0 0 0 r
2.5 Mabswid
.97619 .55068 Mdot
.321 1 0 r
.5 Mabswid
.57677 .79765 m
.108 .75906 L
s
0 0 0 r
2.5 Mabswid
.108 .75906 Mdot
0 .267 1 r
.5 Mabswid
.38048 .67296 m
.82631 .79416 L
s
0 0 0 r
2.5 Mabswid
.82631 .79416 Mdot
0 1 .862 r
.5 Mabswid
.65577 .34568 m
.97619 .26223 L
s
0 0 0 r
2.5 Mabswid
.97619 .26223 Mdot
0 .531 1 r
.5 Mabswid
.70924 .74657 m
.72336 .86052 L
s
0 0 0 r
2.5 Mabswid
.72336 .86052 Mdot
0 .137 1 r
.5 Mabswid
.69647 .76994 m
.69838 .77164 L
s
0 0 0 r
2.5 Mabswid
.69838 .77164 Mdot
0 .957 1 r
.5 Mabswid
.69194 .77297 m
.68433 .7934 L
s
0 0 0 r
2.5 Mabswid
.68433 .7934 Mdot
0 .414 1 r
.5 Mabswid
.41793 .60726 m
.7596 .59291 L
s
0 0 0 r
2.5 Mabswid
.7596 .59291 Mdot
.608 1 0 r
.5 Mabswid
.46017 .81523 m
.30778 .90834 L
s
0 0 0 r
2.5 Mabswid
.30778 .90834 Mdot
0 1 .795 r
.5 Mabswid
.18829 .37522 m
.02381 .77647 L
s
0 0 0 r
2.5 Mabswid
.02381 .77647 Mdot
.903 1 0 r
.5 Mabswid
.82012 .4778 m
.97619 .39478 L
s
0 0 0 r
2.5 Mabswid
.97619 .39478 Mdot
.983 1 0 r
.5 Mabswid
.81001 .46936 m
.97619 .38076 L
s
0 0 0 r
2.5 Mabswid
.97619 .38076 Mdot
.989 1 0 r
.5 Mabswid
.79982 .46094 m
.97619 .36671 L
s
0 0 0 r
2.5 Mabswid
.97619 .36671 Mdot
.996 1 0 r
.5 Mabswid
.78954 .45256 m
.97097 .35542 L
s
0 0 0 r
2.5 Mabswid
.97097 .35542 Mdot
1 .998 0 r
.5 Mabswid
.77919 .44421 m
.95558 .34956 L
s
0 0 0 r
2.5 Mabswid
.95558 .34956 Mdot
1 .991 0 r
.5 Mabswid
.76875 .43589 m
.9401 .34374 L
s
0 0 0 r
2.5 Mabswid
.9401 .34374 Mdot
1 .921 0 r
.5 Mabswid
.2178 .44285 m
.03236 .34567 L
s
0 0 0 r
2.5 Mabswid
.03236 .34567 Mdot
.92 1 0 r
.5 Mabswid
.20787 .45141 m
.02381 .35516 L
s
0 0 0 r
2.5 Mabswid
.02381 .35516 Mdot
.912 1 0 r
.5 Mabswid
.19802 .46001 m
.02381 .36911 L
s
0 0 0 r
2.5 Mabswid
.02381 .36911 Mdot
.905 1 0 r
.5 Mabswid
.18825 .46865 m
.02381 .38303 L
s
0 0 0 r
2.5 Mabswid
.02381 .38303 Mdot
0 1 .91 r
.5 Mabswid
.24352 .38952 m
.02381 .35156 L
s
0 0 0 r
2.5 Mabswid
.02381 .35156 Mdot
0 1 .874 r
.5 Mabswid
.23871 .37737 m
.02381 .31016 L
s
0 0 0 r
2.5 Mabswid
.02381 .31016 Mdot
0 1 .858 r
.5 Mabswid
.23441 .36517 m
.02381 .2992 L
s
0 0 0 r
2.5 Mabswid
.02381 .2992 Mdot
0 .547 1 r
.5 Mabswid
.30484 .36275 m
.17943 .30562 L
s
0 0 0 r
2.5 Mabswid
.17943 .30562 Mdot
.834 1 0 r
.5 Mabswid
.60042 .61907 m
.97619 .65258 L
s
0 0 0 r
2.5 Mabswid
.97619 .65258 Mdot
.201 1 0 r
.5 Mabswid
.64608 .52903 m
.97619 .66986 L
s
0 0 0 r
2.5 Mabswid
.97619 .66986 Mdot
.317 1 0 r
.5 Mabswid
.29127 .39702 m
.47736 .47466 L
s
0 0 0 r
2.5 Mabswid
.47736 .47466 Mdot
.266 1 0 r
.5 Mabswid
.29883 .40568 m
.48414 .48344 L
s
0 0 0 r
2.5 Mabswid
.48414 .48344 Mdot
.254 1 0 r
.5 Mabswid
.3064 .41435 m
.49114 .4923 L
s
0 0 0 r
2.5 Mabswid
.49114 .4923 Mdot
.235 1 0 r
.5 Mabswid
.31398 .42303 m
.49849 .50129 L
s
0 0 0 r
2.5 Mabswid
.49849 .50129 Mdot
.282 1 0 r
.5 Mabswid
.69269 .58461 m
.55035 .52844 L
s
0 0 0 r
2.5 Mabswid
.55035 .52844 Mdot
.251 1 0 r
.5 Mabswid
.70022 .59323 m
.55578 .5367 L
s
0 0 0 r
2.5 Mabswid
.55578 .5367 Mdot
.243 1 0 r
.5 Mabswid
.70774 .60184 m
.56129 .54501 L
s
0 0 0 r
2.5 Mabswid
.56129 .54501 Mdot
.235 1 0 r
.5 Mabswid
.35462 .47182 m
.02381 .33623 L
s
0 0 0 r
2.5 Mabswid
.02381 .33623 Mdot
.265 1 0 r
.5 Mabswid
.36191 .48046 m
.03168 .25276 L
s
0 0 0 r
2.5 Mabswid
.03168 .25276 Mdot
.103 1 0 r
.5 Mabswid
.40303 .39181 m
.02381 .3666 L
s
0 0 0 r
2.5 Mabswid
.02381 .3666 Mdot
0 .892 1 r
.5 Mabswid
.73905 .39075 m
.96149 .35348 L
s
0 0 0 r
2.5 Mabswid
.96149 .35348 Mdot
0 .42 1 r
.5 Mabswid
.21366 .34902 m
.02381 .26691 L
s
0 0 0 r
2.5 Mabswid
.02381 .26691 Mdot
0 .918 1 r
.5 Mabswid
.22571 .34844 m
.02381 .26118 L
s
0 0 0 r
2.5 Mabswid
.02381 .26118 Mdot
0 .175 1 r
.5 Mabswid
.69673 .74183 m
.8892 .97619 L
s
0 0 0 r
2.5 Mabswid
.8892 .97619 Mdot
0 .785 1 r
.5 Mabswid
.78261 .33258 m
.97619 .24794 L
s
0 0 0 r
2.5 Mabswid
.97619 .24794 Mdot
0 .475 1 r
.5 Mabswid
.78922 .33926 m
.97619 .26713 L
s
0 0 0 r
2.5 Mabswid
.97619 .26713 Mdot
.918 1 0 r
.5 Mabswid
.66241 .70856 m
.65586 .93917 L
s
0 0 0 r
2.5 Mabswid
.65586 .93917 Mdot
.76 1 0 r
.5 Mabswid
.67009 .69708 m
.66444 .92257 L
s
0 0 0 r
2.5 Mabswid
.66444 .92257 Mdot
.769 1 0 r
.5 Mabswid
.67777 .68559 m
.67298 .90602 L
s
0 0 0 r
2.5 Mabswid
.67298 .90602 Mdot
.871 1 0 r
.5 Mabswid
.68493 .67276 m
.45275 .97619 L
s
0 0 0 r
2.5 Mabswid
.45275 .97619 Mdot
0 1 .255 r
.5 Mabswid
.58329 .25395 m
.49076 .07515 L
s
0 0 0 r
2.5 Mabswid
.49076 .07515 Mdot
0 1 .989 r
.5 Mabswid
.35347 .41174 m
.30845 .39585 L
s
0 0 0 r
2.5 Mabswid
.30845 .39585 Mdot
0 1 .846 r
.5 Mabswid
.6517 .59472 m
.71419 .57131 L
s
0 0 0 r
2.5 Mabswid
.71419 .57131 Mdot
0 1 .735 r
.5 Mabswid
.71983 .45626 m
.83812 .48433 L
s
0 0 0 r
2.5 Mabswid
.83812 .48433 Mdot
0 1 .68 r
.5 Mabswid
.42234 .7644 m
.52582 .96942 L
s
0 0 0 r
2.5 Mabswid
.52582 .96942 Mdot
.664 1 0 r
.5 Mabswid
.33082 .69068 m
.34944 .91855 L
s
0 0 0 r
2.5 Mabswid
.34944 .91855 Mdot
.713 1 0 r
.5 Mabswid
.33861 .70217 m
.35839 .93523 L
s
0 0 0 r
2.5 Mabswid
.35839 .93523 Mdot
0 1 .497 r
.5 Mabswid
.41653 .47882 m
.52553 .20379 L
s
0 0 0 r
2.5 Mabswid
.52553 .20379 Mdot
0 .881 1 r
.5 Mabswid
.33949 .39133 m
.16851 .12225 L
s
0 0 0 r
2.5 Mabswid
.16851 .12225 Mdot
0 1 .37 r
.5 Mabswid
.34568 .37719 m
.17326 .10348 L
s
0 0 0 r
2.5 Mabswid
.17326 .10348 Mdot
0 1 .36 r
.5 Mabswid
.35186 .36305 m
.17801 .08465 L
s
0 0 0 r
2.5 Mabswid
.17801 .08465 Mdot
0 .502 1 r
.5 Mabswid
.40252 .68575 m
.27879 .97619 L
s
0 0 0 r
2.5 Mabswid
.27879 .97619 Mdot
0 .407 1 r
.5 Mabswid
.25689 .59565 m
.02381 .63867 L
s
0 0 0 r
2.5 Mabswid
.02381 .63867 Mdot
0 .123 1 r
.5 Mabswid
.60413 .34298 m
.66558 .02381 L
s
0 0 0 r
2.5 Mabswid
.66558 .02381 Mdot
0 1 .692 r
.5 Mabswid
.66257 .37637 m
.85312 .10228 L
s
0 0 0 r
2.5 Mabswid
.85312 .10228 Mdot
0 1 .44 r
.5 Mabswid
.66881 .39049 m
.85783 .12089 L
s
0 0 0 r
2.5 Mabswid
.85783 .12089 Mdot
0 .409 1 r
.5 Mabswid
.62856 .53395 m
.97619 .67864 L
s
0 0 0 r
2.5 Mabswid
.97619 .67864 Mdot
.152 0 1 r
.5 Mabswid
.36524 .46665 m
.02381 .32941 L
s
0 0 0 r
2.5 Mabswid
.02381 .32941 Mdot
.149 0 1 r
.5 Mabswid
.35213 .46792 m
.02381 .33646 L
s
0 0 0 r
2.5 Mabswid
.02381 .33646 Mdot
0 1 .049 r
.5 Mabswid
.39893 .60968 m
.18905 .97619 L
s
0 0 0 r
2.5 Mabswid
.18905 .97619 Mdot
0 .581 1 r
.5 Mabswid
.70388 .53394 m
.84328 .64368 L
s
0 0 0 r
2.5 Mabswid
.84328 .64368 Mdot
0 .559 1 r
.5 Mabswid
.70789 .518 m
.84806 .62703 L
s
0 0 0 r
2.5 Mabswid
.84806 .62703 Mdot
0 .57 1 r
.5 Mabswid
.71189 .50206 m
.85284 .61038 L
s
0 0 0 r
2.5 Mabswid
.85284 .61038 Mdot
0 .521 1 r
.5 Mabswid
.30542 .52382 m
.18063 .63397 L
s
0 0 0 r
2.5 Mabswid
.18063 .63397 Mdot
0 .473 1 r
.5 Mabswid
.30953 .53978 m
.18553 .65053 L
s
0 0 0 r
2.5 Mabswid
.18553 .65053 Mdot
.364 1 0 r
.5 Mabswid
.31834 .75977 m
.02381 .76171 L
s
0 0 0 r
2.5 Mabswid
.02381 .76171 Mdot
0 .31 1 r
.5 Mabswid
.54241 .42761 m
.55218 .49438 L
s
0 0 0 r
2.5 Mabswid
.55218 .49438 Mdot
.16 0 1 r
.5 Mabswid
.76286 .51059 m
.97619 .44406 L
s
0 0 0 r
2.5 Mabswid
.97619 .44406 Mdot
0 1 .846 r
.5 Mabswid
.79954 .49073 m
.94094 .67062 L
s
0 0 0 r
2.5 Mabswid
.94094 .67062 Mdot
0 1 .772 r
.5 Mabswid
.60061 .53784 m
.81543 .59148 L
s
0 0 0 r
2.5 Mabswid
.81543 .59148 Mdot
1 .992 0 r
.5 Mabswid
.58334 .30281 m
.59268 .02381 L
s
0 0 0 r
2.5 Mabswid
.59268 .02381 Mdot
0 .313 1 r
.5 Mabswid
.38439 .70205 m
.02381 .62008 L
s
0 0 0 r
2.5 Mabswid
.02381 .62008 Mdot
.019 0 1 r
.5 Mabswid
.55639 .52504 m
.62715 .56124 L
s
0 0 0 r
2.5 Mabswid
.62715 .56124 Mdot
.595 1 0 r
.5 Mabswid
.388 .49328 m
.19288 .34635 L
s
0 0 0 r
2.5 Mabswid
.19288 .34635 Mdot
.599 1 0 r
.5 Mabswid
.2012 .52443 m
.05797 .93686 L
s
0 0 0 r
2.5 Mabswid
.05797 .93686 Mdot
0 1 .968 r
.5 Mabswid
.7369 .57713 m
.85214 .61691 L
s
0 0 0 r
2.5 Mabswid
.85214 .61691 Mdot
0 1 .704 r
.5 Mabswid
.63617 .61483 m
.97619 .52153 L
s
0 0 0 r
2.5 Mabswid
.97619 .52153 Mdot
.417 1 0 r
.5 Mabswid
.50361 .21665 m
.21434 .25085 L
s
0 0 0 r
2.5 Mabswid
.21434 .25085 Mdot
0 1 .8 r
.5 Mabswid
.80779 .4986 m
.82319 .02381 L
s
0 0 0 r
2.5 Mabswid
.82319 .02381 Mdot
0 .305 1 r
.5 Mabswid
.26388 .26098 m
.47343 .02381 L
s
0 0 0 r
2.5 Mabswid
.47343 .02381 Mdot
0 .852 1 r
.5 Mabswid
.20126 .3839 m
.06145 .48954 L
s
0 0 0 r
2.5 Mabswid
.06145 .48954 Mdot
0 1 .2 r
.5 Mabswid
.38101 .28212 m
.02381 .24667 L
s
0 0 0 r
2.5 Mabswid
.02381 .24667 Mdot
.852 1 0 r
.5 Mabswid
.33165 .2325 m
.24244 .02381 L
s
0 0 0 r
2.5 Mabswid
.24244 .02381 Mdot
0 .339 1 r
.5 Mabswid
.66462 .56765 m
.97619 .68619 L
s
0 0 0 r
2.5 Mabswid
.97619 .68619 Mdot
0 1 .727 r
.5 Mabswid
.73508 .73359 m
.80449 .97619 L
s
0 0 0 r
2.5 Mabswid
.80449 .97619 Mdot
0 .016 1 r
.5 Mabswid
.18623 .38014 m
.02381 .2309 L
s
0 0 0 r
2.5 Mabswid
.02381 .2309 Mdot
0 1 .96 r
.5 Mabswid
.7528 .27787 m
.97619 .30244 L
s
0 0 0 r
2.5 Mabswid
.97619 .30244 Mdot
0 .244 1 r
.5 Mabswid
.54023 .37262 m
.75879 .13944 L
s
0 0 0 r
2.5 Mabswid
.75879 .13944 Mdot
0 1 .347 r
.5 Mabswid
.44732 .78623 m
.64906 .97619 L
s
0 0 0 r
2.5 Mabswid
.64906 .97619 Mdot
0 .968 1 r
.5 Mabswid
.65553 .43222 m
.97619 .717 L
s
0 0 0 r
2.5 Mabswid
.97619 .717 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{586.125, 586.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"Solitaire Diamond Example"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
 TurboPlot[sol,ColorView->Log[Intensity],CreateStereoView->Crossed, \
PlotType->Full3D, PlotRange->Automatic];\
\>", "Input",
  CellTags->"Solitaire Diamond Example"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .57143 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0136054 0.47619 [
[ 0 0 0 0 ]
[ 1 .57143 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .57143 L
0 .57143 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0136054 0.568027 0.557823 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4219 .50097 m
.64041 .42899 L
s
0 0 0 r
2.5 Mabswid
.39834 .47193 Mdot
0 1 .516 r
.5 Mabswid
.4591 .5112 m
.39834 .47193 L
s
0 1 .635 r
.40769 .55644 m
.50853 .47822 L
s
0 .375 1 r
.40223 .55599 m
.50103 .479 L
s
.785 1 0 r
.36623 .45295 m
.58036 .46965 L
s
0 g
.64041 .42899 m
.39689 .13256 L
s
.79941 .37661 m
.64041 .42899 L
s
.65012 .8409 m
.64041 .42899 L
s
1 .429 0 r
.38442 .55041 m
.51513 .54989 L
s
1 .427 0 r
.38125 .5439 m
.512 .54332 L
s
1 .424 0 r
.37808 .53738 m
.50888 .53675 L
s
1 .422 0 r
.37491 .53087 m
.50575 .53019 L
s
0 1 .202 r
.34581 .44139 m
.52462 .48497 L
s
1 .421 0 r
.37174 .52435 m
.50263 .52362 L
s
0 0 0 r
2.5 Mabswid
.54519 .5495 Mdot
0 1 .922 r
.5 Mabswid
.55661 .49456 m
.54519 .5495 L
s
0 0 0 r
2.5 Mabswid
.44952 .65095 Mdot
0 .156 1 r
.5 Mabswid
.5375 .55051 m
.44952 .65095 L
s
0 0 0 r
2.5 Mabswid
.57658 .53231 Mdot
0 1 .827 r
.5 Mabswid
.5805 .50009 m
.57658 .53231 L
s
0 0 0 r
2.5 Mabswid
.61429 .39924 Mdot
.77 1 0 r
.5 Mabswid
.55227 .57249 m
.61429 .39924 L
s
.774 1 0 r
.36425 .5445 m
.52129 .561 L
s
0 0 0 r
2.5 Mabswid
.61628 .41673 Mdot
.768 1 0 r
.5 Mabswid
.56027 .57434 m
.61628 .41673 L
s
0 0 0 r
2.5 Mabswid
.60749 .53147 Mdot
0 1 .862 r
.5 Mabswid
.52383 .48352 m
.60749 .53147 L
s
0 0 0 r
2.5 Mabswid
.46647 .66948 Mdot
.84 1 0 r
.5 Mabswid
.51917 .55748 m
.46647 .66948 L
s
0 0 0 r
2.5 Mabswid
.614 .38573 Mdot
0 1 .8 r
.5 Mabswid
.62054 .57159 m
.614 .38573 L
s
0 0 0 r
2.5 Mabswid
.47429 .66727 Mdot
.838 1 0 r
.5 Mabswid
.52458 .56002 m
.47429 .66727 L
s
1 .232 0 r
.34174 .50162 m
.56538 .59964 L
s
0 0 0 r
2.5 Mabswid
.44547 .69642 Mdot
.203 1 0 r
.5 Mabswid
.54666 .64712 m
.44547 .69642 L
s
1 .233 0 r
.33912 .4968 m
.55955 .59495 L
s
0 .43 1 r
.35981 .56284 m
.49224 .47634 L
s
0 0 0 r
2.5 Mabswid
.48208 .66508 Mdot
.836 1 0 r
.5 Mabswid
.52999 .56255 m
.48208 .66508 L
s
1 .233 0 r
.33649 .492 m
.55372 .59027 L
s
1 .234 0 r
.33388 .48721 m
.54789 .58558 L
s
0 0 0 r
2.5 Mabswid
.48985 .66289 Mdot
.834 1 0 r
.5 Mabswid
.5354 .56508 m
.48985 .66289 L
s
1 .245 0 r
.37595 .62307 m
.53652 .57607 L
s
1 .234 0 r
.33126 .48244 m
.54207 .5809 L
s
0 0 0 r
2.5 Mabswid
.49761 .6607 Mdot
.833 1 0 r
.5 Mabswid
.54081 .56761 m
.49761 .6607 L
s
0 0 0 r
2.5 Mabswid
.61606 .44079 Mdot
.767 1 0 r
.5 Mabswid
.56831 .5762 m
.61606 .44079 L
s
0 0 0 r
2.5 Mabswid
.50534 .65852 Mdot
.831 1 0 r
.5 Mabswid
.54622 .57013 m
.50534 .65852 L
s
0 g
.57733 .05514 m
.79941 .37661 L
s
.79941 .37661 m
.83714 .79854 L
s
0 .402 1 r
.35076 .55997 m
.48316 .47286 L
s
.761 1 0 r
.29171 .39309 m
.46338 .45934 L
s
0 0 0 r
2.5 Mabswid
.61583 .46532 Mdot
.766 1 0 r
.5 Mabswid
.57637 .57807 m
.61583 .46532 L
s
1 0 0 r
.36481 .63807 m
.5926 .58183 L
s
0 0 0 r
2.5 Mabswid
.4358 .76509 Mdot
1 .163 0 r
.5 Mabswid
.50358 .56947 m
.4358 .76509 L
s
1 0 0 r
.36208 .63556 m
.58447 .57994 L
s
.35934 .63304 m
.57637 .57807 L
s
0 0 0 r
2.5 Mabswid
.44113 .76635 Mdot
1 .162 0 r
.5 Mabswid
.50613 .57638 m
.44113 .76635 L
s
0 0 0 r
2.5 Mabswid
.69831 .52011 Mdot
0 1 .96 r
.5 Mabswid
.59236 .46787 m
.69831 .52011 L
s
1 .243 0 r
.36768 .66474 m
.51607 .59552 L
s
1 0 0 r
.35659 .63051 m
.56831 .5762 L
s
1 .392 0 r
.31159 .48886 m
.52508 .56224 L
s
1 .26 0 r
.36499 .65807 m
.51159 .58995 L
s
0 0 0 r
2.5 Mabswid
.44642 .76761 Mdot
1 .161 0 r
.5 Mabswid
.50868 .58329 m
.44642 .76761 L
s
1 .184 0 r
.33406 .56188 m
.53334 .59596 L
s
0 0 0 r
2.5 Mabswid
.6156 .49032 Mdot
.765 1 0 r
.5 Mabswid
.58447 .57994 m
.6156 .49032 L
s
1 .388 0 r
.30856 .48275 m
.51999 .55609 L
s
1 0 0 r
.35383 .62797 m
.56027 .57434 L
s
0 0 0 r
2.5 Mabswid
.7532 .48092 Mdot
0 .785 1 r
.5 Mabswid
.60281 .49748 m
.7532 .48092 L
s
1 0 0 r
.35106 .62543 m
.55227 .57249 L
s
.34828 .62287 m
.54622 .57013 L
s
.261 1 0 r
.29438 .4582 m
.42076 .45426 L
s
1 0 0 r
.34548 .6203 m
.54081 .56761 L
s
0 0 0 r
2.5 Mabswid
.75809 .48734 Mdot
0 .475 1 r
.5 Mabswid
.60367 .50226 m
.75809 .48734 L
s
1 .246 0 r
.2795 .41507 m
.41483 .4524 L
s
1 0 0 r
.34268 .61772 m
.5354 .56508 L
s
0 0 0 r
2.5 Mabswid
.59526 .65166 Mdot
.569 1 0 r
.5 Mabswid
.55227 .57249 m
.59526 .65166 L
s
0 0 0 r
2.5 Mabswid
.61535 .51581 Mdot
.8 1 0 r
.5 Mabswid
.5926 .58183 m
.61535 .51581 L
s
0 0 0 r
2.5 Mabswid
.60098 .64898 Mdot
.564 1 0 r
.5 Mabswid
.56027 .57434 m
.60098 .64898 L
s
1 0 0 r
.33986 .61513 m
.52999 .56255 L
s
1 .244 0 r
.27614 .41434 m
.41562 .4519 L
s
0 0 0 r
2.5 Mabswid
.6067 .6463 Mdot
.559 1 0 r
.5 Mabswid
.56831 .5762 m
.6067 .6463 L
s
.933 1 0 r
.33754 .61299 m
.51442 .55476 L
s
1 0 0 r
.33704 .61254 m
.52458 .56002 L
s
0 0 0 r
2.5 Mabswid
.61243 .64361 Mdot
.554 1 0 r
.5 Mabswid
.57637 .57807 m
.61243 .64361 L
s
0 0 0 r
2.5 Mabswid
.61816 .64093 Mdot
.549 1 0 r
.5 Mabswid
.58447 .57994 m
.61816 .64093 L
s
1 .242 0 r
.27277 .41359 m
.41642 .4514 L
s
1 0 0 r
.3342 .60993 m
.51917 .55748 L
s
0 0 0 r
2.5 Mabswid
.6239 .63824 Mdot
.544 1 0 r
.5 Mabswid
.5926 .58183 m
.6239 .63824 L
s
0 0 0 r
2.5 Mabswid
.46998 .31283 Mdot
0 .072 1 r
.5 Mabswid
.53913 .40034 m
.46998 .31283 L
s
.934 1 0 r
.33392 .60967 m
.51126 .55156 L
s
0 0 0 r
2.5 Mabswid
.77755 .37168 Mdot
0 1 .692 r
.5 Mabswid
.6267 .46571 m
.77755 .37168 L
s
.493 1 0 r
.26485 .39672 m
.50201 .57941 L
s
1 0 0 r
.33135 .60731 m
.51442 .55476 L
s
1 .24 0 r
.26937 .41284 m
.41722 .45089 L
s
0 0 0 r
2.5 Mabswid
.7791 .38033 Mdot
0 1 .44 r
.5 Mabswid
.62949 .47318 m
.7791 .38033 L
s
.934 1 0 r
.33029 .60633 m
.50809 .54835 L
s
.57 1 0 r
.26631 .40739 m
.50345 .58871 L
s
1 0 0 r
.32849 .60468 m
.51126 .55156 L
s
.934 1 0 r
.32664 .60298 m
.5049 .54513 L
s
0 g
.58561 .45825 m
.55871 .39735 L
s
.53311 .47896 m
.58561 .45825 L
s
.5856 .45823 m
.5331 .47894 L
s
.60353 .52364 m
.5856 .45823 L
s
.59023 .45675 m
.5856 .45826 L
s
.5856 .45826 m
.5587 .39736 L
s
.58559 .45823 m
.59022 .45672 L
s
.60352 .52364 m
.58559 .45823 L
s
1 .356 0 r
.26596 .41208 m
.41803 .45038 L
s
0 .989 1 r
.58568 .45579 m
.59489 .53693 L
s
0 0 0 r
2.5 Mabswid
.58568 .45579 Mdot
0 .989 1 r
.5 Mabswid
.50319 .3267 m
.58568 .45579 L
s
1 0 0 r
.32562 .60204 m
.50809 .54835 L
s
0 1 .532 r
.58845 .45647 m
.62673 .51495 L
s
0 0 0 r
2.5 Mabswid
.58845 .45647 Mdot
0 1 .532 r
.5 Mabswid
.47697 .45063 m
.58845 .45647 L
s
.2 0 1 r
.58672 .45504 m
.64294 .50446 L
s
0 0 0 r
2.5 Mabswid
.58672 .45504 Mdot
.2 0 1 r
.5 Mabswid
.50306 .47971 m
.58672 .45504 L
s
0 .414 1 r
.34433 .66255 m
.44348 .53485 L
s
0 1 .632 r
.59013 .46434 m
.53089 .34696 L
s
0 0 0 r
2.5 Mabswid
.59013 .46434 Mdot
0 1 .632 r
.5 Mabswid
.48083 .60633 m
.59013 .46434 L
s
0 g
.59022 .45674 m
.56333 .39576 L
s
.65105 .44646 m
.59022 .45674 L
s
.59021 .45672 m
.65105 .44644 L
s
.60817 .5222 m
.59021 .45672 L
s
.56334 .39576 m
.59023 .45675 L
s
.59022 .45672 m
.60818 .5222 L
s
0 0 0 r
2.5 Mabswid
.43234 .30127 Mdot
.479 1 0 r
.5 Mabswid
.44281 .32873 m
.43234 .30127 L
s
0 .702 1 r
.59236 .46787 m
.54704 .52359 L
s
0 0 0 r
2.5 Mabswid
.59236 .46787 Mdot
0 1 .381 r
.5 Mabswid
.42094 .41959 m
.59236 .46787 L
s
0 1 .632 r
.59047 .4855 m
.59492 .45216 L
s
0 0 0 r
2.5 Mabswid
.59047 .4855 Mdot
0 1 .632 r
.5 Mabswid
.62027 .53171 m
.59047 .4855 L
s
0 0 0 r
2.5 Mabswid
.59954 .30524 Mdot
1 .992 0 r
.5 Mabswid
.60232 .41271 m
.59954 .30524 L
s
0 .542 1 r
.57893 .46505 m
.55491 .4748 L
s
0 0 0 r
2.5 Mabswid
.57893 .46505 Mdot
0 .542 1 r
.5 Mabswid
.59504 .45676 m
.57893 .46505 L
s
.934 1 0 r
.32297 .5996 m
.50169 .54189 L
s
0 1 .394 r
.58036 .46965 m
.62574 .40653 L
s
0 0 0 r
2.5 Mabswid
.58036 .46965 Mdot
.865 1 0 r
.5 Mabswid
.60647 .46475 m
.58036 .46965 L
s
1 0 0 r
.32274 .59938 m
.5049 .54513 L
s
.045 1 0 r
.59336 .5006 m
.60422 .47327 L
s
0 0 0 r
2.5 Mabswid
.59336 .5006 Mdot
.045 1 0 r
.5 Mabswid
.62671 .53417 m
.59336 .5006 L
s
.741 1 0 r
.58444 .48429 m
.5224 .65735 L
s
0 0 0 r
2.5 Mabswid
.58444 .48429 Mdot
.741 1 0 r
.5 Mabswid
.59635 .47088 m
.58444 .48429 L
s
0 g
.60354 .52362 m
.55034 .572 L
s
.53311 .47892 m
.60354 .52362 L
s
.60352 .5236 m
.55024 .57203 L
s
.61027 .58593 m
.60352 .5236 L
s
.60351 .5236 m
.60818 .52216 L
s
.61026 .58593 m
.60351 .5236 L
s
.5331 .47894 m
.60353 .52364 L
s
.60818 .5222 m
.60352 .52364 L
s
0 .502 1 r
.2291 .30808 m
.47255 .42588 L
s
.699 1 0 r
.60458 .51486 m
.51156 .49176 L
s
0 0 0 r
2.5 Mabswid
.60458 .51486 Mdot
.699 1 0 r
.5 Mabswid
.63129 .53689 m
.60458 .51486 L
s
1 0 0 r
.31984 .59672 m
.50169 .54189 L
s
.934 1 0 r
.31929 .59622 m
.49848 .53864 L
s
0 g
.60816 .5222 m
.65948 .48763 L
s
.65103 .44644 m
.60816 .5222 L
s
.60817 .52217 m
.65945 .4876 L
s
.615 .58455 m
.60817 .52217 L
s
.65105 .44644 m
.60817 .5222 L
s
.60818 .52216 m
.61501 .58454 L
s
0 0 0 r
2.5 Mabswid
.59635 .47088 Mdot
.741 1 0 r
.5 Mabswid
.45102 .37109 m
.59635 .47088 L
s
0 0 0 r
2.5 Mabswid
.60367 .50226 Mdot
0 .686 1 r
.5 Mabswid
.5805 .50009 m
.60367 .50226 L
s
0 0 0 r
2.5 Mabswid
.60281 .49748 Mdot
0 .931 1 r
.5 Mabswid
.55661 .49456 m
.60281 .49748 L
s
0 0 0 r
2.5 Mabswid
.30002 .28923 Mdot
.389 1 0 r
.5 Mabswid
.57895 .54238 m
.30002 .28923 L
s
0 0 0 r
2.5 Mabswid
.5805 .50009 Mdot
0 1 .693 r
.5 Mabswid
.48316 .47286 m
.5805 .50009 L
s
.741 1 0 r
.5637 .45509 m
.60913 .49192 L
s
0 0 0 r
2.5 Mabswid
.5637 .45509 Mdot
.741 1 0 r
.5 Mabswid
.5446 .35099 m
.5637 .45509 L
s
1 0 0 r
.31693 .59405 m
.49848 .53864 L
s
0 .989 1 r
.60187 .48946 m
.58051 .51637 L
s
0 0 0 r
2.5 Mabswid
.60187 .48946 Mdot
0 .989 1 r
.5 Mabswid
.50063 .43437 m
.60187 .48946 L
s
0 .542 1 r
.57044 .48989 m
.61021 .49577 L
s
0 0 0 r
2.5 Mabswid
.57044 .48989 Mdot
0 .542 1 r
.5 Mabswid
.45971 .35554 m
.57044 .48989 L
s
.934 1 0 r
.31559 .59281 m
.49524 .53537 L
s
.732 1 0 r
.5877 .51954 m
.61052 .51584 L
s
0 0 0 r
2.5 Mabswid
.5877 .51954 Mdot
.732 1 0 r
.5 Mabswid
.47279 .42153 m
.5877 .51954 L
s
0 1 .381 r
.57298 .41621 m
.55414 .44657 L
s
0 0 0 r
2.5 Mabswid
.57298 .41621 Mdot
0 1 .381 r
.5 Mabswid
.53773 .41323 m
.57298 .41621 L
s
0 0 0 r
2.5 Mabswid
.59504 .45676 Mdot
0 .542 1 r
.5 Mabswid
.46041 .40881 m
.59504 .45676 L
s
.8 1 0 r
.55629 .46146 m
.57062 .62244 L
s
0 0 0 r
2.5 Mabswid
.55629 .46146 Mdot
.8 1 0 r
.5 Mabswid
.59367 .43382 m
.55629 .46146 L
s
1 0 0 r
.31401 .59136 m
.49524 .53537 L
s
0 1 .632 r
.55871 .39844 m
.55997 .38737 L
s
0 0 0 r
2.5 Mabswid
.55871 .39844 Mdot
0 1 .632 r
.5 Mabswid
.57802 .4144 m
.55871 .39844 L
s
0 g
.55873 .39738 m
.52581 .34832 L
s
.48862 .39974 m
.55873 .39738 L
s
.55873 .39735 m
.53323 .47898 L
s
.48862 .39972 m
.55873 .39735 L
s
.56335 .39579 m
.55872 .39738 L
s
.55872 .39738 m
.5258 .34833 L
s
.55871 .39735 m
.53311 .47896 L
s
.5587 .39736 m
.56334 .39576 L
s
0 .989 1 r
.58051 .51637 m
.525 .6554 L
s
0 0 0 r
2.5 Mabswid
.58051 .51637 Mdot
.045 1 0 r
.5 Mabswid
.56269 .49013 m
.52589 .33736 L
s
0 0 0 r
2.5 Mabswid
.56269 .49013 Mdot
.045 1 0 r
.5 Mabswid
.6226 .53518 m
.56269 .49013 L
s
0 1 .381 r
.55414 .44657 m
.52659 .51009 L
s
0 0 0 r
2.5 Mabswid
.55414 .44657 Mdot
0 .989 1 r
.5 Mabswid
.59489 .53693 m
.61545 .59378 L
s
0 0 0 r
2.5 Mabswid
.59489 .53693 Mdot
0 g
.5 Mabswid
.56331 .39576 m
.65108 .44643 L
s
.63246 .41104 m
.56331 .39576 L
s
.56334 .39578 m
.53048 .34663 L
s
.63249 .41106 m
.56334 .39578 L
s
.56333 .39576 m
.65105 .44646 L
s
.53049 .34664 m
.56335 .39579 L
s
.934 1 0 r
.31187 .58939 m
.492 .53209 L
s
0 .989 1 r
.5532 .41413 m
.57245 .58456 L
s
0 0 0 r
2.5 Mabswid
.5532 .41413 Mdot
0 .989 1 r
.5 Mabswid
.56007 .38962 m
.5532 .41413 L
s
.732 1 0 r
.61052 .51584 m
.45924 .57109 L
s
0 0 0 r
2.5 Mabswid
.61052 .51584 Mdot
.741 1 0 r
.5 Mabswid
.57812 .52047 m
.56877 .54389 L
s
0 0 0 r
2.5 Mabswid
.57812 .52047 Mdot
.741 1 0 r
.5 Mabswid
.61062 .49614 m
.57812 .52047 L
s
0 .538 1 r
.55038 .43182 m
.53369 .56266 L
s
0 0 0 r
2.5 Mabswid
.55038 .43182 Mdot
0 .538 1 r
.5 Mabswid
.56479 .39527 m
.55038 .43182 L
s
1 0 0 r
.31108 .58867 m
.492 .53209 L
s
0 0 0 r
2.5 Mabswid
.30121 .28221 Mdot
.327 1 0 r
.5 Mabswid
.57311 .53586 m
.30121 .28221 L
s
0 1 .632 r
.59492 .45216 m
.47457 .31536 L
s
0 0 0 r
2.5 Mabswid
.59492 .45216 Mdot
.55661 .49456 Mdot
0 1 .676 r
.5 Mabswid
.49224 .47634 m
.55661 .49456 L
s
0 0 0 r
2.5 Mabswid
.77864 .53521 Mdot
.903 1 0 r
.5 Mabswid
.61653 .56778 m
.77864 .53521 L
s
0 0 0 r
2.5 Mabswid
.3814 .28318 Mdot
0 1 .779 r
.5 Mabswid
.4973 .35173 m
.3814 .28318 L
s
0 0 0 r
2.5 Mabswid
.74892 .56525 Mdot
.16 0 1 r
.5 Mabswid
.62791 .55955 m
.74892 .56525 L
s
.797 1 0 r
.5436 .46867 m
.61339 .48292 L
s
0 0 0 r
2.5 Mabswid
.5436 .46867 Mdot
.797 1 0 r
.5 Mabswid
.47853 .41648 m
.5436 .46867 L
s
0 0 0 r
2.5 Mabswid
.79076 .52559 Mdot
.983 1 0 r
.5 Mabswid
.61755 .56044 m
.79076 .52559 L
s
0 g
.40659 .89607 m
.65012 .8409 L
s
0 .989 1 r
.57515 .52623 m
.61963 .5763 L
s
0 0 0 r
2.5 Mabswid
.57515 .52623 Mdot
0 .989 1 r
.5 Mabswid
.54019 .35363 m
.57515 .52623 L
s
.934 1 0 r
.30813 .58596 m
.48873 .52879 L
s
0 0 0 r
2.5 Mabswid
.80307 .51589 Mdot
.989 1 0 r
.5 Mabswid
.61859 .55305 m
.80307 .51589 L
s
0 0 0 r
2.5 Mabswid
.56479 .39527 Mdot
0 .538 1 r
.5 Mabswid
.51259 .40751 m
.56479 .39527 L
s
0 .2 1 r
.57102 .5233 m
.61532 .52693 L
s
0 0 0 r
2.5 Mabswid
.57102 .5233 Mdot
0 .2 1 r
.5 Mabswid
.42642 .36458 m
.57102 .5233 L
s
.514 1 0 r
.54398 .42381 m
.58429 .48347 L
s
0 0 0 r
2.5 Mabswid
.54398 .42381 Mdot
.514 1 0 r
.5 Mabswid
.58558 .41791 m
.54398 .42381 L
s
0 0 0 r
2.5 Mabswid
.81016 .5072 Mdot
.996 1 0 r
.5 Mabswid
.61964 .54562 m
.81016 .5072 L
s
0 .332 1 r
.22107 .31799 m
.53737 .46095 L
s
0 0 0 r
2.5 Mabswid
.53737 .46095 Mdot
0 .364 1 r
.5 Mabswid
.63035 .48551 m
.53737 .46095 L
s
0 0 0 r
2.5 Mabswid
.56007 .38962 Mdot
0 .989 1 r
.5 Mabswid
.48734 .3945 m
.56007 .38962 L
s
.741 1 0 r
.53671 .45909 m
.51794 .58116 L
s
0 0 0 r
2.5 Mabswid
.53671 .45909 Mdot
.741 1 0 r
.5 Mabswid
.57441 .40476 m
.53671 .45909 L
s
0 g
.53313 .47894 m
.51612 .52575 L
s
.49156 .45723 m
.53313 .47894 L
s
.5161 .52573 m
.53311 .47892 L
s
.53323 .47898 m
.49156 .45726 L
s
1 0 0 r
.30517 .58324 m
.48545 .52547 L
s
0 .542 1 r
.57142 .40399 m
.52045 .54408 L
s
0 0 0 r
2.5 Mabswid
.57142 .40399 Mdot
0 .542 1 r
.5 Mabswid
.53432 .3958 m
.57142 .40399 L
s
0 .327 1 r
.53439 .46524 m
.60354 .40066 L
s
0 0 0 r
2.5 Mabswid
.53439 .46524 Mdot
0 .327 1 r
.5 Mabswid
.63125 .57223 m
.53439 .46524 L
s
.371 1 0 r
.57895 .54238 m
.61737 .40286 L
s
0 0 0 r
2.5 Mabswid
.57895 .54238 Mdot
.803 1 0 r
.5 Mabswid
.62703 .54313 m
.57895 .54238 L
s
.934 1 0 r
.30438 .5825 m
.48545 .52547 L
s
.435 1 0 r
.57311 .53586 m
.61003 .39786 L
s
0 0 0 r
2.5 Mabswid
.57311 .53586 Mdot
.806 1 0 r
.5 Mabswid
.63003 .53664 m
.57311 .53586 L
s
0 .989 1 r
.53691 .43858 m
.588 .65033 L
s
0 0 0 r
2.5 Mabswid
.53691 .43858 Mdot
0 .989 1 r
.5 Mabswid
.57434 .39463 m
.53691 .43858 L
s
0 .364 1 r
.5403 .41085 m
.55202 .38157 L
s
0 0 0 r
2.5 Mabswid
.5403 .41085 Mdot
0 .364 1 r
.5 Mabswid
.58727 .42072 m
.5403 .41085 L
s
0 0 0 r
2.5 Mabswid
.80818 .50382 Mdot
0 .892 1 r
.5 Mabswid
.62121 .50107 m
.80818 .50382 L
s
.045 1 0 r
.60422 .47327 m
.59033 .38668 L
s
0 0 0 r
2.5 Mabswid
.60422 .47327 Mdot
0 1 .37 r
.5 Mabswid
.56726 .52933 m
.30255 .27366 L
s
.699 1 0 r
.56726 .52933 m
.60271 .39288 L
s
0 0 0 r
2.5 Mabswid
.56726 .52933 Mdot
.81 1 0 r
.5 Mabswid
.63305 .53011 m
.56726 .52933 L
s
0 0 0 r
2.5 Mabswid
.80683 .50057 Mdot
1 .998 0 r
.5 Mabswid
.62072 .53815 m
.80683 .50057 L
s
0 0 0 r
2.5 Mabswid
.57802 .4144 Mdot
0 1 .632 r
.5 Mabswid
.63697 .51197 m
.57802 .4144 L
s
0 0 0 r
2.5 Mabswid
.30255 .27366 Mdot
.53773 .41323 Mdot
0 1 .381 r
.5 Mabswid
.44363 .40456 m
.53773 .41323 L
s
.741 1 0 r
.60913 .49192 m
.59027 .66882 L
s
0 0 0 r
2.5 Mabswid
.60913 .49192 Mdot
.53913 .40034 Mdot
0 .739 1 r
.5 Mabswid
.63938 .4505 m
.53913 .40034 L
s
0 .542 1 r
.61021 .49577 m
.50167 .63644 L
s
0 0 0 r
2.5 Mabswid
.61021 .49577 Mdot
1 0 0 r
.5 Mabswid
.3022 .58051 m
.48216 .52214 L
s
0 .542 1 r
.54061 .39255 m
.57561 .40638 L
s
0 0 0 r
2.5 Mabswid
.54061 .39255 Mdot
0 .542 1 r
.5 Mabswid
.52032 .36832 m
.54061 .39255 L
s
0 0 0 r
2.5 Mabswid
.61062 .49614 Mdot
.741 1 0 r
.5 Mabswid
.41653 .40976 m
.61062 .49614 L
s
0 .038 1 r
.5349 .41782 m
.56877 .37891 L
s
0 0 0 r
2.5 Mabswid
.5349 .41782 Mdot
0 .038 1 r
.5 Mabswid
.64036 .54458 m
.5349 .41782 L
s
0 1 .632 r
.55997 .38737 m
.5077 .33877 L
s
0 0 0 r
2.5 Mabswid
.55997 .38737 Mdot
.73363 .28546 Mdot
0 .123 1 r
.5 Mabswid
.61878 .43218 m
.73363 .28546 L
s
.934 1 0 r
.3006 .57903 m
.48216 .52214 L
s
0 0 0 r
2.5 Mabswid
.80347 .49391 Mdot
1 .991 0 r
.5 Mabswid
.62182 .53063 m
.80347 .49391 L
s
0 .989 1 r
.61258 .57328 m
.55524 .63996 L
s
0 0 0 r
2.5 Mabswid
.61258 .57328 Mdot
0 .989 1 r
.5 Mabswid
.46956 .3447 m
.61258 .57328 L
s
.778 1 0 r
.55676 .52755 m
.6011 .43306 L
s
0 0 0 r
2.5 Mabswid
.55676 .52755 Mdot
.778 1 0 r
.5 Mabswid
.60274 .61394 m
.55676 .52755 L
s
0 0 0 r
2.5 Mabswid
.57441 .40476 Mdot
.741 1 0 r
.5 Mabswid
.46172 .3928 m
.57441 .40476 L
s
0 1 .632 r
.53124 .42095 m
.49952 .35156 L
s
0 0 0 r
2.5 Mabswid
.53124 .42095 Mdot
0 1 .632 r
.5 Mabswid
.60206 .45002 m
.53124 .42095 L
s
1 .173 0 r
.31825 .63673 m
.52628 .60579 L
s
.31629 .63055 m
.5209 .60084 L
s
0 .2 1 r
.61532 .52693 m
.47087 .53274 L
s
0 0 0 r
2.5 Mabswid
.61532 .52693 Mdot
0 .542 1 r
.5 Mabswid
.57561 .40638 m
.56496 .65646 L
s
0 0 0 r
2.5 Mabswid
.57561 .40638 Mdot
.53432 .3958 Mdot
0 .542 1 r
.5 Mabswid
.42212 .3843 m
.53432 .3958 L
s
1 0 0 r
.29922 .57776 m
.47885 .5188 L
s
0 0 0 r
2.5 Mabswid
.75904 .35848 Mdot
0 .244 1 r
.5 Mabswid
.6258 .41805 m
.75904 .35848 L
s
0 .038 1 r
.55252 .52854 m
.6137 .46715 L
s
0 0 0 r
2.5 Mabswid
.55252 .52854 Mdot
0 .038 1 r
.5 Mabswid
.55082 .59 m
.55252 .52854 L
s
0 .932 1 r
.52462 .48497 m
.63452 .42597 L
s
0 0 0 r
2.5 Mabswid
.52462 .48497 Mdot
0 1 .063 r
.5 Mabswid
.65348 .47731 m
.52462 .48497 L
s
0 .77 1 r
.29508 .56767 m
.42977 .38503 L
s
0 1 .381 r
.52383 .48352 m
.62552 .47513 L
s
0 0 0 r
2.5 Mabswid
.52383 .48352 Mdot
.142 1 0 r
.5 Mabswid
.60381 .4159 m
.52383 .48352 L
s
0 g
.61026 .5859 m
.61501 .58451 L
s
.60446 .63732 m
.61026 .5859 L
s
.61027 .58591 m
.55024 .57201 L
s
.60448 .63733 m
.61027 .58591 L
s
.55024 .57203 m
.61027 .58593 L
s
.61501 .58454 m
.61026 .58593 L
s
.934 1 0 r
.29681 .57554 m
.47885 .5188 L
s
1 0 0 r
.29622 .57501 m
.47552 .51543 L
s
0 .267 1 r
.35336 .75615 m
.43905 .5523 L
s
0 1 .381 r
.52443 .49652 m
.63672 .55172 L
s
0 0 0 r
2.5 Mabswid
.52443 .49652 Mdot
0 1 .381 r
.5 Mabswid
.59408 .38659 m
.52443 .49652 L
s
0 g
.615 .58453 m
.65945 .48758 L
s
.60933 .63597 m
.615 .58453 L
s
.65945 .4876 m
.615 .58455 L
s
.61501 .58451 m
.60934 .63596 L
s
0 0 0 r
2.5 Mabswid
.60647 .46475 Mdot
.865 1 0 r
.5 Mabswid
.62057 .4678 m
.60647 .46475 L
s
0 0 0 r
2.5 Mabswid
.60206 .45002 Mdot
0 1 .632 r
.5 Mabswid
.59629 .65804 m
.60206 .45002 L
s
0 1 .774 r
.29109 .56466 m
.42975 .37935 L
s
0 0 0 r
2.5 Mabswid
.59367 .43382 Mdot
.8 1 0 r
.5 Mabswid
.45112 .46253 m
.59367 .43382 L
s
0 0 0 r
2.5 Mabswid
.5926 .58183 Mdot
.8 1 0 r
.5 Mabswid
.5926 .58183 m
.5926 .58183 L
s
0 0 0 r
2.5 Mabswid
.5926 .58183 Mdot
.8 1 0 r
.5 Mabswid
.5926 .58183 m
.5926 .58183 L
s
0 0 0 r
2.5 Mabswid
.5926 .58183 Mdot
.8 1 0 r
.5 Mabswid
.5926 .58183 m
.5926 .58183 L
s
.5926 .58183 m
.5926 .58183 L
s
0 0 0 r
2.5 Mabswid
.5926 .58183 Mdot
.8 1 0 r
.5 Mabswid
.5926 .58183 m
.5926 .58183 L
s
0 0 0 r
2.5 Mabswid
.5926 .58183 Mdot
1 .058 0 r
.5 Mabswid
.5926 .58183 m
.5926 .58183 L
s
0 0 0 r
2.5 Mabswid
.5926 .58183 Mdot
1 .866 0 r
.5 Mabswid
.5926 .58183 m
.61653 .56778 L
s
0 0 0 r
2.5 Mabswid
.5926 .58183 Mdot
1 0 0 r
.5 Mabswid
.29321 .57224 m
.47218 .51205 L
s
.934 1 0 r
.29299 .57204 m
.47552 .51543 L
s
0 1 .381 r
.52659 .51009 m
.51403 .55167 L
s
0 0 0 r
2.5 Mabswid
.52659 .51009 Mdot
.045 1 0 r
.5 Mabswid
.61653 .56778 m
.45304 .4427 L
s
0 0 0 r
2.5 Mabswid
.61653 .56778 Mdot
.58558 .41791 Mdot
.514 1 0 r
.5 Mabswid
.50202 .59746 m
.58558 .41791 L
s
0 .989 1 r
.55527 .55079 m
.53122 .52133 L
s
0 0 0 r
2.5 Mabswid
.55527 .55079 Mdot
0 .989 1 r
.5 Mabswid
.62761 .51661 m
.55527 .55079 L
s
0 0 0 r
2.5 Mabswid
.58727 .42072 Mdot
0 .364 1 r
.5 Mabswid
.57269 .64374 m
.58727 .42072 L
s
0 0 0 r
2.5 Mabswid
.58447 .57994 Mdot
.765 1 0 r
.5 Mabswid
.58447 .57994 m
.58447 .57994 L
s
0 0 0 r
2.5 Mabswid
.58447 .57994 Mdot
.765 1 0 r
.5 Mabswid
.58447 .57994 m
.58447 .57994 L
s
0 0 0 r
2.5 Mabswid
.58447 .57994 Mdot
.765 1 0 r
.5 Mabswid
.58447 .57994 m
.58447 .57994 L
s
.58447 .57994 m
.58447 .57994 L
s
0 0 0 r
2.5 Mabswid
.58447 .57994 Mdot
.765 1 0 r
.5 Mabswid
.58447 .57994 m
.58447 .57994 L
s
0 0 0 r
2.5 Mabswid
.58447 .57994 Mdot
1 .059 0 r
.5 Mabswid
.58447 .57994 m
.58447 .57994 L
s
0 0 0 r
2.5 Mabswid
.58447 .57994 Mdot
1 .878 0 r
.5 Mabswid
.58447 .57994 m
.61755 .56044 L
s
0 0 0 r
2.5 Mabswid
.58447 .57994 Mdot
.022 1 0 r
.5 Mabswid
.61755 .56044 m
.44263 .42521 L
s
0 0 0 r
2.5 Mabswid
.61755 .56044 Mdot
0 .829 1 r
.5 Mabswid
.52102 .39025 m
.57414 .67286 L
s
0 0 0 r
2.5 Mabswid
.52102 .39025 Mdot
0 .829 1 r
.5 Mabswid
.54826 .36057 m
.52102 .39025 L
s
1 0 0 r
.29019 .56946 m
.46882 .50866 L
s
0 .542 1 r
.5193 .50562 m
.62244 .55986 L
s
0 0 0 r
2.5 Mabswid
.5193 .50562 Mdot
0 .542 1 r
.5 Mabswid
.50009 .3442 m
.5193 .50562 L
s
.797 1 0 r
.61339 .48292 m
.5011 .63687 L
s
0 0 0 r
2.5 Mabswid
.61339 .48292 Mdot
.57637 .57807 Mdot
.766 1 0 r
.5 Mabswid
.57637 .57807 m
.57637 .57807 L
s
0 0 0 r
2.5 Mabswid
.57637 .57807 Mdot
.766 1 0 r
.5 Mabswid
.57637 .57807 m
.57637 .57807 L
s
0 0 0 r
2.5 Mabswid
.57637 .57807 Mdot
.766 1 0 r
.5 Mabswid
.57637 .57807 m
.57637 .57807 L
s
.57637 .57807 m
.57637 .57807 L
s
0 0 0 r
2.5 Mabswid
.57637 .57807 Mdot
.766 1 0 r
.5 Mabswid
.57637 .57807 m
.57637 .57807 L
s
0 0 0 r
2.5 Mabswid
.57637 .57807 Mdot
1 .059 0 r
.5 Mabswid
.57637 .57807 m
.57637 .57807 L
s
0 0 0 r
2.5 Mabswid
.57637 .57807 Mdot
1 .871 0 r
.5 Mabswid
.57637 .57807 m
.61859 .55305 L
s
0 0 0 r
2.5 Mabswid
.57637 .57807 Mdot
.045 1 0 r
.5 Mabswid
.5131 .48635 m
.51076 .33162 L
s
0 0 0 r
2.5 Mabswid
.5131 .48635 Mdot
.045 1 0 r
.5 Mabswid
.59845 .63766 m
.5131 .48635 L
s
.746 1 0 r
.55462 .55923 m
.53074 .50711 L
s
0 0 0 r
2.5 Mabswid
.55462 .55923 Mdot
.746 1 0 r
.5 Mabswid
.62944 .5309 m
.55462 .55923 L
s
0 1 .668 r
.28707 .56163 m
.42973 .37363 L
s
.934 1 0 r
.28916 .56852 m
.47218 .51205 L
s
.031 1 0 r
.61859 .55305 m
.43991 .41348 L
s
0 0 0 r
2.5 Mabswid
.61859 .55305 Mdot
0 1 .381 r
.5 Mabswid
.54449 .54912 m
.61243 .62351 L
s
0 0 0 r
2.5 Mabswid
.54449 .54912 Mdot
0 1 .381 r
.5 Mabswid
.5325 .34344 m
.54449 .54912 L
s
0 0 0 r
2.5 Mabswid
.51259 .40751 Mdot
0 .538 1 r
.5 Mabswid
.46368 .4232 m
.51259 .40751 L
s
0 0 0 r
2.5 Mabswid
.6179 .49842 Mdot
0 .282 1 r
.5 Mabswid
.50853 .47822 m
.6179 .49842 L
s
0 0 0 r
2.5 Mabswid
.56831 .5762 Mdot
.767 1 0 r
.5 Mabswid
.56831 .5762 m
.56831 .5762 L
s
0 0 0 r
2.5 Mabswid
.56831 .5762 Mdot
.767 1 0 r
.5 Mabswid
.56831 .5762 m
.56831 .5762 L
s
0 0 0 r
2.5 Mabswid
.56831 .5762 Mdot
.767 1 0 r
.5 Mabswid
.56831 .5762 m
.56831 .5762 L
s
.56831 .5762 m
.56831 .5762 L
s
0 0 0 r
2.5 Mabswid
.56831 .5762 Mdot
.767 1 0 r
.5 Mabswid
.56831 .5762 m
.56831 .5762 L
s
0 0 0 r
2.5 Mabswid
.56831 .5762 Mdot
1 .06 0 r
.5 Mabswid
.56831 .5762 m
.56831 .5762 L
s
0 0 0 r
2.5 Mabswid
.56831 .5762 Mdot
1 .864 0 r
.5 Mabswid
.56831 .5762 m
.61964 .54562 L
s
0 0 0 r
2.5 Mabswid
.56831 .5762 Mdot
.50853 .47822 Mdot
0 1 .598 r
.5 Mabswid
.4672 .36919 m
.50853 .47822 L
s
0 .989 1 r
.61229 .5958 m
.58325 .59957 L
s
0 0 0 r
2.5 Mabswid
.61229 .5958 Mdot
0 .989 1 r
.5 Mabswid
.62005 .57376 m
.61229 .5958 L
s
.741 1 0 r
.51014 .41661 m
.55289 .64812 L
s
0 0 0 r
2.5 Mabswid
.51014 .41661 Mdot
.741 1 0 r
.5 Mabswid
.55788 .36826 m
.51014 .41661 L
s
.699 1 0 r
.51156 .49176 m
.4784 .47242 L
s
0 0 0 r
2.5 Mabswid
.51156 .49176 Mdot
1 .396 0 r
.5 Mabswid
.2262 .37408 m
.43866 .45572 L
s
1 0 0 r
.28715 .56666 m
.46544 .50524 L
s
0 1 .017 r
.5084 .41782 m
.36547 .25666 L
s
0 .038 1 r
.5084 .41782 m
.57299 .37406 L
s
0 0 0 r
2.5 Mabswid
.5084 .41782 Mdot
.06 1 0 r
.5 Mabswid
.658 .48879 m
.5084 .41782 L
s
.039 1 0 r
.61964 .54562 m
.43881 .4029 L
s
0 0 0 r
2.5 Mabswid
.61964 .54562 Mdot
.746 1 0 r
.5 Mabswid
.50997 .40388 m
.55366 .63859 L
s
0 0 0 r
2.5 Mabswid
.50997 .40388 Mdot
.746 1 0 r
.5 Mabswid
.55123 .36203 m
.50997 .40388 L
s
0 0 0 r
2.5 Mabswid
.56027 .57434 Mdot
.768 1 0 r
.5 Mabswid
.56027 .57434 m
.56027 .57434 L
s
0 0 0 r
2.5 Mabswid
.56027 .57434 Mdot
.768 1 0 r
.5 Mabswid
.56027 .57434 m
.56027 .57434 L
s
0 0 0 r
2.5 Mabswid
.56027 .57434 Mdot
.768 1 0 r
.5 Mabswid
.56027 .57434 m
.56027 .57434 L
s
.56027 .57434 m
.56027 .57434 L
s
0 0 0 r
2.5 Mabswid
.56027 .57434 Mdot
.768 1 0 r
.5 Mabswid
.56027 .57434 m
.56027 .57434 L
s
0 0 0 r
2.5 Mabswid
.56027 .57434 Mdot
1 .06 0 r
.5 Mabswid
.56027 .57434 m
.56027 .57434 L
s
0 0 0 r
2.5 Mabswid
.56027 .57434 Mdot
1 .857 0 r
.5 Mabswid
.56027 .57434 m
.62072 .53815 L
s
0 0 0 r
2.5 Mabswid
.56027 .57434 Mdot
.62027 .53171 Mdot
0 1 .632 r
.5 Mabswid
.61553 .61161 m
.62027 .53171 L
s
0 0 0 r
2.5 Mabswid
.36547 .25666 Mdot
.797 1 0 r
.5 Mabswid
.5554 .57144 m
.62494 .57415 L
s
0 0 0 r
2.5 Mabswid
.5554 .57144 Mdot
.797 1 0 r
.5 Mabswid
.42731 .36064 m
.5554 .57144 L
s
.934 1 0 r
.28531 .56497 m
.46882 .50866 L
s
0 1 .643 r
.52796 .53677 m
.50484 .51605 L
s
0 0 0 r
2.5 Mabswid
.52796 .53677 Mdot
0 1 .643 r
.5 Mabswid
.62054 .57159 m
.52796 .53677 L
s
.741 1 0 r
.54884 .565 m
.5241 .51456 L
s
0 0 0 r
2.5 Mabswid
.54884 .565 Mdot
.741 1 0 r
.5 Mabswid
.63212 .53348 m
.54884 .565 L
s
0 1 .553 r
.28301 .55856 m
.42971 .36787 L
s
0 0 0 r
2.5 Mabswid
.5375 .55051 Mdot
0 .272 1 r
.5 Mabswid
.65074 .4542 m
.5375 .55051 L
s
0 .149 1 r
.50657 .403 m
.56702 .62625 L
s
0 0 0 r
2.5 Mabswid
.50657 .403 Mdot
0 .149 1 r
.5 Mabswid
.54935 .35821 m
.50657 .403 L
s
0 0 0 r
2.5 Mabswid
.55227 .57249 Mdot
.77 1 0 r
.5 Mabswid
.55227 .57249 m
.55227 .57249 L
s
0 0 0 r
2.5 Mabswid
.55227 .57249 Mdot
.77 1 0 r
.5 Mabswid
.55227 .57249 m
.55227 .57249 L
s
0 0 0 r
2.5 Mabswid
.55227 .57249 Mdot
.77 1 0 r
.5 Mabswid
.55227 .57249 m
.55227 .57249 L
s
.55227 .57249 m
.55227 .57249 L
s
0 0 0 r
2.5 Mabswid
.55227 .57249 Mdot
.77 1 0 r
.5 Mabswid
.55227 .57249 m
.55227 .57249 L
s
0 0 0 r
2.5 Mabswid
.55227 .57249 Mdot
1 .061 0 r
.5 Mabswid
.55227 .57249 m
.55227 .57249 L
s
0 0 0 r
2.5 Mabswid
.55227 .57249 Mdot
1 .85 0 r
.5 Mabswid
.55227 .57249 m
.62182 .53063 L
s
0 0 0 r
2.5 Mabswid
.55227 .57249 Mdot
.047 1 0 r
.5 Mabswid
.62072 .53815 m
.43767 .39216 L
s
0 0 0 r
2.5 Mabswid
.62072 .53815 Mdot
.741 1 0 r
.5 Mabswid
.61875 .49424 m
.48883 .5899 L
s
0 0 0 r
2.5 Mabswid
.61875 .49424 Mdot
.741 1 0 r
.5 Mabswid
.50199 .48254 m
.61875 .49424 L
s
1 0 0 r
.2841 .56386 m
.46205 .50181 L
s
.741 1 0 r
.50136 .43991 m
.52057 .54422 L
s
0 0 0 r
2.5 Mabswid
.50136 .43991 Mdot
.741 1 0 r
.5 Mabswid
.51448 .33223 m
.50136 .43991 L
s
.793 1 0 r
.58751 .59198 m
.62225 .57739 L
s
0 0 0 r
2.5 Mabswid
.58751 .59198 Mdot
.793 1 0 r
.5 Mabswid
.54721 .37851 m
.58751 .59198 L
s
0 1 .453 r
.52222 .35852 m
.53585 .35289 L
s
0 0 0 r
2.5 Mabswid
.52222 .35852 Mdot
0 1 .453 r
.5 Mabswid
.42832 .52827 m
.52222 .35852 L
s
0 g
.55026 .57201 m
.60449 .63732 L
s
.51455 .58636 m
.55026 .57201 L
s
.51614 .52573 m
.49158 .45722 L
s
.51459 .58641 m
.51614 .52573 L
s
.55027 .57203 m
.51457 .58639 L
s
.51611 .52571 m
.55027 .57203 L
s
.55024 .57201 m
.60448 .63733 L
s
.51457 .58639 m
.51611 .52571 L
s
.51612 .52575 m
.49156 .45723 L
s
.55034 .572 m
.5161 .52573 L
s
.53051 .34666 m
.52581 .34835 L
s
.52581 .34835 m
.49068 .3181 L
s
.52582 .34834 m
.49069 .31808 L
s
.48863 .39976 m
.52582 .34834 L
s
.52581 .34832 m
.48862 .39974 L
s
.5258 .34833 m
.53049 .34664 L
s
0 0 0 r
2.5 Mabswid
.50306 .47971 Mdot
.2 0 1 r
.5 Mabswid
.49767 .48132 m
.50306 .47971 L
s
0 .989 1 r
.57245 .58456 m
.61221 .62294 L
s
0 0 0 r
2.5 Mabswid
.57245 .58456 Mdot
.50063 .43437 Mdot
0 .989 1 r
.5 Mabswid
.45954 .402 m
.50063 .43437 L
s
0 0 0 r
2.5 Mabswid
.57434 .39463 Mdot
0 .989 1 r
.5 Mabswid
.42083 .49349 m
.57434 .39463 L
s
0 1 .453 r
.53585 .35289 m
.47172 .48975 L
s
0 0 0 r
2.5 Mabswid
.53585 .35289 Mdot
.62005 .57376 Mdot
0 .989 1 r
.5 Mabswid
.62028 .57278 m
.62005 .57376 L
s
0 0 0 r
2.5 Mabswid
.62028 .57278 Mdot
0 .989 1 r
.5 Mabswid
.62246 .44333 m
.62028 .57278 L
s
.045 1 0 r
.49798 .44106 m
.52775 .35156 L
s
0 0 0 r
2.5 Mabswid
.49798 .44106 Mdot
.045 1 0 r
.5 Mabswid
.63487 .55338 m
.49798 .44106 L
s
0 1 .797 r
.50103 .479 m
.62121 .50107 L
s
0 0 0 r
2.5 Mabswid
.50103 .479 Mdot
0 1 .056 r
.5 Mabswid
.46027 .37105 m
.50103 .479 L
s
0 0 0 r
2.5 Mabswid
.50199 .48254 Mdot
.741 1 0 r
.5 Mabswid
.45751 .38992 m
.50199 .48254 L
s
0 0 0 r
2.5 Mabswid
.62121 .50107 Mdot
.056 1 0 r
.5 Mabswid
.62182 .53063 m
.43711 .38176 L
s
0 0 0 r
2.5 Mabswid
.62182 .53063 Mdot
0 g
.5 Mabswid
.53049 .34665 m
.49546 .31631 L
s
.6325 .41108 m
.53049 .34665 L
s
.53048 .34663 m
.63249 .41106 L
s
.49548 .31632 m
.53051 .34666 L
s
1 .096 0 r
.54622 .57013 m
.64273 .52405 L
s
0 0 0 r
2.5 Mabswid
.54622 .57013 Mdot
.62054 .57159 Mdot
0 1 .453 r
.5 Mabswid
.53363 .60475 m
.62054 .57159 L
s
0 .038 1 r
.6137 .46715 m
.43061 .34719 L
s
0 0 0 r
2.5 Mabswid
.6137 .46715 Mdot
.934 1 0 r
.5 Mabswid
.28144 .56141 m
.46544 .50524 L
s
0 0 0 r
2.5 Mabswid
.59436 .25903 Mdot
0 .305 1 r
.5 Mabswid
.46586 .31221 m
.59436 .25903 L
s
0 .989 1 r
.61963 .5763 m
.52771 .62132 L
s
0 0 0 r
2.5 Mabswid
.61963 .5763 Mdot
1 .398 0 r
.5 Mabswid
.22184 .3736 m
.43498 .45545 L
s
0 1 .453 r
.49829 .42475 m
.55772 .36721 L
s
0 0 0 r
2.5 Mabswid
.49829 .42475 Mdot
0 1 .453 r
.5 Mabswid
.49713 .63356 m
.49829 .42475 L
s
1 0 0 r
.28103 .56104 m
.45864 .49837 L
s
0 1 .381 r
.58647 .40901 m
.51473 .53331 L
s
0 0 0 r
2.5 Mabswid
.58647 .40901 Mdot
0 1 .381 r
.5 Mabswid
.45965 .4279 m
.58647 .40901 L
s
0 1 .522 r
.53077 .55094 m
.6213 .56515 L
s
0 0 0 r
2.5 Mabswid
.53077 .55094 Mdot
0 1 .522 r
.5 Mabswid
.43277 .35172 m
.53077 .55094 L
s
.761 1 0 r
.26802 .58254 m
.54446 .57026 L
s
0 .627 1 r
.54446 .57026 m
.62939 .44518 L
s
0 0 0 r
2.5 Mabswid
.54446 .57026 Mdot
.737 1 0 r
.5 Mabswid
.63483 .53609 m
.54446 .57026 L
s
0 .989 1 r
.61545 .59378 m
.58344 .63538 L
s
0 0 0 r
2.5 Mabswid
.61545 .59378 Mdot
0 1 .846 r
.5 Mabswid
.6213 .56515 m
.81624 .63898 L
s
0 .348 1 r
.6213 .56515 m
.50305 .58005 L
s
0 0 0 r
2.5 Mabswid
.6213 .56515 Mdot
0 g
.5 Mabswid
.49158 .45722 m
.45368 .41684 L
s
.48864 .39972 m
.49158 .45726 L
s
.49158 .45726 m
.45367 .41689 L
s
.49156 .45726 m
.48862 .39972 L
s
.789 1 0 r
.58166 .59454 m
.62391 .5768 L
s
0 0 0 r
2.5 Mabswid
.58166 .59454 Mdot
.789 1 0 r
.5 Mabswid
.5408 .37984 m
.58166 .59454 L
s
0 0 0 r
2.5 Mabswid
.6226 .53518 Mdot
.045 1 0 r
.5 Mabswid
.53067 .6598 m
.6226 .53518 L
s
1 .096 0 r
.54081 .56761 m
.64594 .51706 L
s
0 0 0 r
2.5 Mabswid
.54081 .56761 Mdot
1 .16 0 r
.5 Mabswid
.26386 .51186 m
.42851 .40875 L
s
.778 1 0 r
.6011 .43306 m
.43244 .36527 L
s
0 0 0 r
2.5 Mabswid
.6011 .43306 Mdot
0 1 .381 r
.5 Mabswid
.61892 .48248 m
.56493 .60932 L
s
0 0 0 r
2.5 Mabswid
.61892 .48248 Mdot
0 1 .381 r
.5 Mabswid
.48311 .36434 m
.61892 .48248 L
s
0 .989 1 r
.60438 .60904 m
.6127 .61145 L
s
0 0 0 r
2.5 Mabswid
.60438 .60904 Mdot
0 .989 1 r
.5 Mabswid
.55161 .35935 m
.60438 .60904 L
s
1 0 0 r
.27795 .55821 m
.45521 .4949 L
s
0 .542 1 r
.62244 .55986 m
.52213 .61856 L
s
0 0 0 r
2.5 Mabswid
.62244 .55986 Mdot
.933 1 0 r
.5 Mabswid
.27755 .55784 m
.46205 .50181 L
s
0 1 .381 r
.51473 .53331 m
.61506 .61196 L
s
0 0 0 r
2.5 Mabswid
.51473 .53331 Mdot
.49767 .48132 Mdot
.2 0 1 r
.5 Mabswid
.42944 .49928 m
.49767 .48132 L
s
0 0 0 r
2.5 Mabswid
.61076 .61195 Mdot
.114 0 1 r
.5 Mabswid
.61048 .61082 m
.61076 .61195 L
s
.741 1 0 r
.52057 .54422 m
.59896 .65397 L
s
0 0 0 r
2.5 Mabswid
.52057 .54422 Mdot
0 .542 1 r
.5 Mabswid
.52045 .54408 m
.5718 .64774 L
s
0 0 0 r
2.5 Mabswid
.52045 .54408 Mdot
0 .989 1 r
.5 Mabswid
.58325 .59957 m
.56138 .59986 L
s
0 0 0 r
2.5 Mabswid
.58325 .59957 Mdot
0 .038 1 r
.5 Mabswid
.62342 .50144 m
.48896 .31582 L
s
0 0 0 r
2.5 Mabswid
.62342 .50144 Mdot
0 .038 1 r
.5 Mabswid
.5733 .59575 m
.62342 .50144 L
s
0 .538 1 r
.53369 .56266 m
.57208 .66791 L
s
0 0 0 r
2.5 Mabswid
.53369 .56266 Mdot
1 .097 0 r
.5 Mabswid
.5354 .56508 m
.64917 .50999 L
s
0 0 0 r
2.5 Mabswid
.5354 .56508 Mdot
.61048 .61082 Mdot
0 .13 1 r
.5 Mabswid
.48931 .37401 m
.61048 .61082 L
s
.778 1 0 r
.48917 .43295 m
.55424 .36246 L
s
0 0 0 r
2.5 Mabswid
.48917 .43295 Mdot
.778 1 0 r
.5 Mabswid
.58086 .6439 m
.48917 .43295 L
s
0 .565 1 r
.28593 .58866 m
.47242 .45355 L
s
0 0 0 r
2.5 Mabswid
.5733 .59575 Mdot
0 .038 1 r
.5 Mabswid
.58728 .59583 m
.5733 .59575 L
s
.778 1 0 r
.57577 .59712 m
.6256 .5762 L
s
0 0 0 r
2.5 Mabswid
.57577 .59712 Mdot
.778 1 0 r
.5 Mabswid
.53434 .38118 m
.57577 .59712 L
s
1 .401 0 r
.21744 .37312 m
.43126 .45517 L
s
1 0 0 r
.27486 .55536 m
.45177 .49142 L
s
0 1 .532 r
.4974 .38494 m
.58055 .64309 L
s
0 0 0 r
2.5 Mabswid
.4974 .38494 Mdot
0 1 .532 r
.5 Mabswid
.55804 .3635 m
.4974 .38494 L
s
0 0 0 r
2.5 Mabswid
.54019 .35363 Mdot
0 .989 1 r
.5 Mabswid
.50593 .33815 m
.54019 .35363 L
s
0 .101 1 r
.27455 .55643 m
.55802 .61571 L
s
1 .097 0 r
.52999 .56255 m
.65245 .50284 L
s
0 0 0 r
2.5 Mabswid
.52999 .56255 Mdot
0 g
.5 Mabswid
.45367 .41689 m
.48864 .39972 L
s
.49069 .31808 m
.48863 .39976 L
s
.48879 .39979 m
.45368 .41691 L
s
.49071 .31807 m
.48879 .39979 L
s
.933 1 0 r
.27363 .55424 m
.45864 .49837 L
s
.741 1 0 r
.50284 .50587 m
.62772 .55465 L
s
0 0 0 r
2.5 Mabswid
.50284 .50587 Mdot
.741 1 0 r
.5 Mabswid
.56521 .3655 m
.50284 .50587 L
s
1 0 0 r
.27175 .5525 m
.44831 .48792 L
s
0 .585 1 r
.48595 .40934 m
.29544 .2021 L
s
0 .327 1 r
.48595 .40934 m
.56866 .36888 L
s
0 0 0 r
2.5 Mabswid
.48595 .40934 Mdot
0 .884 1 r
.5 Mabswid
.64009 .4615 m
.48595 .40934 L
s
0 0 0 r
2.5 Mabswid
.80592 .58353 Mdot
0 1 .704 r
.5 Mabswid
.63408 .56101 m
.80592 .58353 L
s
.813 1 0 r
.53652 .57607 m
.66724 .46097 L
s
0 0 0 r
2.5 Mabswid
.53652 .57607 Mdot
1 .115 0 r
.5 Mabswid
.64957 .51862 m
.53652 .57607 L
s
1 .097 0 r
.52458 .56002 m
.65577 .49561 L
s
0 0 0 r
2.5 Mabswid
.52458 .56002 Mdot
0 1 .632 r
.5 Mabswid
.58645 .60898 m
.62783 .44644 L
s
0 0 0 r
2.5 Mabswid
.58645 .60898 Mdot
0 1 .632 r
.5 Mabswid
.61967 .60205 m
.58645 .60898 L
s
0 .989 1 r
.6127 .61145 m
.46403 .58346 L
s
0 0 0 r
2.5 Mabswid
.6127 .61145 Mdot
.819 1 0 r
.5 Mabswid
.54207 .5809 m
.58731 .38004 L
s
0 0 0 r
2.5 Mabswid
.54207 .5809 Mdot
1 .115 0 r
.5 Mabswid
.64629 .5281 m
.54207 .5809 L
s
0 0 0 r
2.5 Mabswid
.49224 .47634 Mdot
0 1 .066 r
.5 Mabswid
.45336 .37295 m
.49224 .47634 L
s
0 1 .255 r
.58341 .39875 m
.6977 .24805 L
s
0 .711 1 r
.58341 .39875 m
.47141 .48695 L
s
0 0 0 r
2.5 Mabswid
.58341 .39875 Mdot
0 1 .145 r
.5 Mabswid
.49626 .49159 m
.58341 .39875 L
s
0 1 .643 r
.50484 .51605 m
.4311 .36865 L
s
0 0 0 r
2.5 Mabswid
.50484 .51605 Mdot
.514 1 0 r
.5 Mabswid
.52508 .56224 m
.62353 .40711 L
s
0 0 0 r
2.5 Mabswid
.52508 .56224 Mdot
1 .092 0 r
.5 Mabswid
.64342 .53643 m
.52508 .56224 L
s
0 0 0 r
2.5 Mabswid
.54826 .36057 Mdot
0 .829 1 r
.5 Mabswid
.41956 .44848 m
.54826 .36057 L
s
0 1 .532 r
.62673 .51495 m
.62856 .57898 L
s
0 0 0 r
2.5 Mabswid
.62673 .51495 Mdot
.814 1 0 r
.5 Mabswid
.54789 .58558 m
.59388 .38444 L
s
0 0 0 r
2.5 Mabswid
.54789 .58558 Mdot
1 .115 0 r
.5 Mabswid
.64303 .53754 m
.54789 .58558 L
s
.514 1 0 r
.51999 .55609 m
.61649 .40239 L
s
0 0 0 r
2.5 Mabswid
.51999 .55609 Mdot
1 .092 0 r
.5 Mabswid
.6462 .52837 m
.51999 .55609 L
s
.933 1 0 r
.2697 .55062 m
.45521 .4949 L
s
0 .108 1 r
.27053 .55346 m
.5503 .61358 L
s
0 0 0 r
2.5 Mabswid
.48734 .3945 Mdot
0 .989 1 r
.5 Mabswid
.42407 .46646 m
.48734 .3945 L
s
.333 1 0 r
.51218 .54042 m
.53484 .34623 L
s
0 0 0 r
2.5 Mabswid
.51218 .54042 Mdot
.333 1 0 r
.5 Mabswid
.61141 .61926 m
.51218 .54042 L
s
.81 1 0 r
.55372 .59027 m
.60043 .38893 L
s
0 0 0 r
2.5 Mabswid
.55372 .59027 Mdot
1 .115 0 r
.5 Mabswid
.63978 .54695 m
.55372 .59027 L
s
.732 1 0 r
.51513 .54989 m
.6351 .50392 L
s
0 0 0 r
2.5 Mabswid
.51513 .54989 Mdot
1 .093 0 r
.5 Mabswid
.64899 .5203 m
.51513 .54989 L
s
0 0 0 r
2.5 Mabswid
.49626 .49159 Mdot
0 1 .145 r
.5 Mabswid
.63516 .54973 m
.49626 .49159 L
s
1 .403 0 r
.213 .37263 m
.42751 .45489 L
s
0 .542 1 r
.5494 .58761 m
.62619 .58702 L
s
0 0 0 r
2.5 Mabswid
.5494 .58761 Mdot
0 .542 1 r
.5 Mabswid
.51716 .33243 m
.5494 .58761 L
s
1 0 0 r
.26862 .54963 m
.44482 .4844 L
s
.806 1 0 r
.55955 .59495 m
.60695 .39361 L
s
0 0 0 r
2.5 Mabswid
.55955 .59495 Mdot
1 .115 0 r
.5 Mabswid
.63655 .55632 m
.55955 .59495 L
s
1 .098 0 r
.51917 .55748 m
.65912 .48829 L
s
0 0 0 r
2.5 Mabswid
.51917 .55748 Mdot
.62671 .53417 Mdot
.045 1 0 r
.5 Mabswid
.63288 .56789 m
.62671 .53417 L
s
0 g
.1675 .23097 m
.39689 .13256 L
s
0 1 .284 r
.52129 .561 m
.64655 .42388 L
s
0 0 0 r
2.5 Mabswid
.52129 .561 Mdot
.89 1 0 r
.5 Mabswid
.65209 .51389 m
.52129 .561 L
s
.803 1 0 r
.56538 .59964 m
.61346 .3983 L
s
0 0 0 r
2.5 Mabswid
.56538 .59964 Mdot
1 .115 0 r
.5 Mabswid
.63332 .56566 m
.56538 .59964 L
s
.737 1 0 r
.512 .54332 m
.6352 .49582 L
s
0 0 0 r
2.5 Mabswid
.512 .54332 Mdot
1 .093 0 r
.5 Mabswid
.65178 .51222 m
.512 .54332 L
s
0 0 0 r
2.5 Mabswid
.62761 .51661 Mdot
0 .989 1 r
.5 Mabswid
.46652 .37735 m
.62761 .51661 L
s
0 0 0 r
2.5 Mabswid
.61141 .61926 Mdot
.333 1 0 r
.5 Mabswid
.597 .62211 m
.61141 .61926 L
s
0 0 0 r
2.5 Mabswid
.62703 .54313 Mdot
.803 1 0 r
.5 Mabswid
.57269 .5396 m
.62703 .54313 L
s
0 1 .381 r
.51403 .55167 m
.51874 .62886 L
s
0 0 0 r
2.5 Mabswid
.51403 .55167 Mdot
.55123 .36203 Mdot
.746 1 0 r
.5 Mabswid
.41739 .46759 m
.55123 .36203 L
s
1 .728 0 r
.48342 .39748 m
.56232 .56949 L
s
0 0 0 r
2.5 Mabswid
.48342 .39748 Mdot
1 .728 0 r
.5 Mabswid
.57323 .38399 m
.48342 .39748 L
s
.741 1 0 r
.50888 .53675 m
.63529 .48771 L
s
0 0 0 r
2.5 Mabswid
.50888 .53675 Mdot
1 .094 0 r
.5 Mabswid
.65458 .50412 m
.50888 .53675 L
s
.933 1 0 r
.26575 .54699 m
.45177 .49142 L
s
0 0 0 r
2.5 Mabswid
.597 .62211 Mdot
.333 1 0 r
.5 Mabswid
.46004 .57437 m
.597 .62211 L
s
1 .116 0 r
.51442 .55476 m
.64681 .51515 L
s
0 0 0 r
2.5 Mabswid
.51442 .55476 Mdot
1 0 0 r
.5 Mabswid
.26548 .54675 m
.44133 .48086 L
s
.793 1 0 r
.62225 .57739 m
.49895 .378 L
s
0 0 0 r
2.5 Mabswid
.62225 .57739 Mdot
0 .989 1 r
.5 Mabswid
.56138 .59986 m
.50878 .59516 L
s
0 0 0 r
2.5 Mabswid
.56138 .59986 Mdot
0 .008 1 r
.5 Mabswid
.26649 .55048 m
.54253 .61145 L
s
0 .989 1 r
.51177 .54775 m
.59644 .65362 L
s
0 0 0 r
2.5 Mabswid
.51177 .54775 Mdot
0 .989 1 r
.5 Mabswid
.54303 .35315 m
.51177 .54775 L
s
.746 1 0 r
.50575 .53019 m
.63539 .47958 L
s
0 0 0 r
2.5 Mabswid
.50575 .53019 Mdot
1 .094 0 r
.5 Mabswid
.65738 .496 m
.50575 .53019 L
s
0 .989 1 r
.60283 .42302 m
.54682 .59359 L
s
0 0 0 r
2.5 Mabswid
.60283 .42302 Mdot
0 .989 1 r
.5 Mabswid
.44857 .36657 m
.60283 .42302 L
s
0 0 0 r
2.5 Mabswid
.55788 .36826 Mdot
.741 1 0 r
.5 Mabswid
.41963 .47798 m
.55788 .36826 L
s
.62772 .55465 m
.495 .60836 L
s
0 0 0 r
2.5 Mabswid
.62772 .55465 Mdot
1 .397 0 r
.5 Mabswid
.20851 .37214 m
.42372 .4546 L
s
.8 1 0 r
.50263 .52362 m
.63522 .47155 L
s
0 0 0 r
2.5 Mabswid
.50263 .52362 Mdot
1 .094 0 r
.5 Mabswid
.66019 .48788 m
.50263 .52362 L
s
1 0 0 r
.26233 .54385 m
.43781 .47731 L
s
0 .989 1 r
.54682 .59359 m
.61186 .58382 L
s
0 0 0 r
2.5 Mabswid
.54682 .59359 Mdot
.57323 .38399 Mdot
1 .728 0 r
.5 Mabswid
.52807 .64059 m
.57323 .38399 L
s
0 1 .453 r
.55772 .36721 m
.42265 .48219 L
s
0 0 0 r
2.5 Mabswid
.55772 .36721 Mdot
1 .116 0 r
.5 Mabswid
.51126 .55156 m
.64916 .51002 L
s
0 0 0 r
2.5 Mabswid
.51126 .55156 Mdot
.933 1 0 r
.5 Mabswid
.26177 .54333 m
.44831 .48792 L
s
.801 1 0 r
.53356 .58524 m
.633 .56642 L
s
0 0 0 r
2.5 Mabswid
.53356 .58524 Mdot
.801 1 0 r
.5 Mabswid
.49722 .33775 m
.53356 .58524 L
s
0 .038 1 r
.56877 .37891 m
.49176 .42131 L
s
0 0 0 r
2.5 Mabswid
.56877 .37891 Mdot
.62944 .5309 Mdot
.746 1 0 r
.5 Mabswid
.46495 .41175 m
.62944 .5309 L
s
0 0 0 r
2.5 Mabswid
.50593 .33815 Mdot
0 .989 1 r
.5 Mabswid
.48828 .3287 m
.50593 .33815 L
s
.778 1 0 r
.55174 .36037 m
.48493 .35486 L
s
0 0 0 r
2.5 Mabswid
.55174 .36037 Mdot
.778 1 0 r
.5 Mabswid
.54215 .59305 m
.55174 .36037 L
s
0 1 .381 r
.62552 .47513 m
.50696 .54414 L
s
0 0 0 r
2.5 Mabswid
.62552 .47513 Mdot
.417 1 0 r
.5 Mabswid
.55424 .36246 m
.63086 .22286 L
s
.333 1 0 r
.55424 .36246 m
.43023 .45427 L
s
0 0 0 r
2.5 Mabswid
.55424 .36246 Mdot
.54215 .59305 Mdot
.778 1 0 r
.5 Mabswid
.61543 .60489 m
.54215 .59305 L
s
0 .272 1 r
.4973 .35173 m
.59963 .38958 L
s
0 0 0 r
2.5 Mabswid
.4973 .35173 Mdot
0 1 .67 r
.5 Mabswid
.64675 .42729 m
.4973 .35173 L
s
0 0 0 r
2.5 Mabswid
.54935 .35821 Mdot
0 .149 1 r
.5 Mabswid
.45421 .53459 m
.54935 .35821 L
s
0 0 0 r
2.5 Mabswid
.47697 .45063 Mdot
0 1 .532 r
.5 Mabswid
.4634 .38541 m
.47697 .45063 L
s
0 0 0 r
2.5 Mabswid
.63003 .53664 Mdot
.806 1 0 r
.5 Mabswid
.57918 .53286 m
.63003 .53664 L
s
.045 1 0 r
.51076 .33162 m
.53065 .39209 L
s
0 0 0 r
2.5 Mabswid
.51076 .33162 Mdot
1 0 0 r
.5 Mabswid
.25916 .54093 m
.43427 .47373 L
s
0 0 0 r
2.5 Mabswid
.62791 .55955 Mdot
.052 0 1 r
.5 Mabswid
.48764 .53521 m
.62791 .55955 L
s
0 1 .381 r
.56493 .60932 m
.60038 .61175 L
s
0 0 0 r
2.5 Mabswid
.56493 .60932 Mdot
.47255 .42588 Mdot
0 .588 1 r
.5 Mabswid
.66347 .46709 m
.47255 .42588 L
s
1 .116 0 r
.50809 .54835 m
.65154 .50483 L
s
0 0 0 r
2.5 Mabswid
.50809 .54835 Mdot
0 .709 1 r
.5 Mabswid
.23201 .45654 m
.42204 .41865 L
s
0 .149 1 r
.55045 .60028 m
.48474 .4219 L
s
0 0 0 r
2.5 Mabswid
.55045 .60028 Mdot
0 .149 1 r
.5 Mabswid
.62721 .56824 m
.55045 .60028 L
s
.933 1 0 r
.25778 .53966 m
.44482 .4844 L
s
0 0 0 r
2.5 Mabswid
.48316 .47286 Mdot
0 1 .075 r
.5 Mabswid
.44648 .37489 m
.48316 .47286 L
s
0 g
.60448 .6373 m
.53017 .63149 L
s
.58592 .67003 m
.60448 .6373 L
s
.60447 .6373 m
.60934 .63593 L
s
.58591 .67003 m
.60447 .6373 L
s
.60449 .63732 m
.53026 .63139 L
s
.60934 .63596 m
.60446 .63732 L
s
0 0 0 r
2.5 Mabswid
.75824 .65682 Mdot
.834 1 0 r
.5 Mabswid
.63516 .54973 m
.75824 .65682 L
s
.789 1 0 r
.62391 .5768 m
.5057 .38515 L
s
0 0 0 r
2.5 Mabswid
.62391 .5768 Mdot
0 1 .067 r
.5 Mabswid
.22604 .44158 m
.45304 .4427 L
s
0 .538 1 r
.58948 .62825 m
.61425 .61736 L
s
0 0 0 r
2.5 Mabswid
.58948 .62825 Mdot
0 .538 1 r
.5 Mabswid
.63891 .50271 m
.58948 .62825 L
s
1 0 0 r
.25598 .538 m
.43072 .47014 L
s
0 0 0 r
2.5 Mabswid
.63129 .53689 Mdot
.699 1 0 r
.5 Mabswid
.63546 .54136 m
.63129 .53689 L
s
0 0 0 r
2.5 Mabswid
.51448 .33223 Mdot
.741 1 0 r
.5 Mabswid
.48999 .34272 m
.51448 .33223 L
s
.797 1 0 r
.53005 .58932 m
.63208 .57018 L
s
0 0 0 r
2.5 Mabswid
.53005 .58932 Mdot
.797 1 0 r
.5 Mabswid
.49334 .33998 m
.53005 .58932 L
s
0 .13 1 r
.51507 .5749 m
.62762 .5816 L
s
0 0 0 r
2.5 Mabswid
.51507 .5749 Mdot
0 .13 1 r
.5 Mabswid
.56079 .38131 m
.51507 .5749 L
s
0 g
.60932 .636 m
.65288 .51182 L
s
.65943 .48762 m
.60932 .636 L
s
.60933 .63596 m
.65285 .51175 L
s
.59092 .66868 m
.60933 .63596 L
s
.60934 .63593 m
.59093 .66866 L
s
.65945 .48758 m
.60933 .63597 L
s
.801 1 0 r
.59599 .63368 m
.61089 .63097 L
s
0 0 0 r
2.5 Mabswid
.59599 .63368 Mdot
.801 1 0 r
.5 Mabswid
.55889 .37655 m
.59599 .63368 L
s
0 0 0 r
2.5 Mabswid
.63035 .48551 Mdot
0 .364 1 r
.5 Mabswid
.55587 .56702 m
.63035 .48551 L
s
0 0 0 r
2.5 Mabswid
.54303 .35315 Mdot
0 .989 1 r
.5 Mabswid
.47688 .38598 m
.54303 .35315 L
s
0 1 .928 r
.52428 .58604 m
.64171 .54069 L
s
0 0 0 r
2.5 Mabswid
.52428 .58604 Mdot
0 1 .928 r
.5 Mabswid
.51578 .36394 m
.52428 .58604 L
s
.797 1 0 r
.62494 .57415 m
.41971 .4643 L
s
0 0 0 r
2.5 Mabswid
.62494 .57415 Mdot
1 .116 0 r
.5 Mabswid
.5049 .54513 m
.65394 .49959 L
s
0 0 0 r
2.5 Mabswid
.5049 .54513 Mdot
.741 1 0 r
.5 Mabswid
.51794 .58116 m
.52021 .60021 L
s
0 0 0 r
2.5 Mabswid
.51794 .58116 Mdot
.55161 .35935 Mdot
0 .989 1 r
.5 Mabswid
.48102 .36538 m
.55161 .35935 L
s
0 .877 1 r
.6267 .46571 m
.46701 .48318 L
s
0 0 0 r
2.5 Mabswid
.6267 .46571 Mdot
0 1 .247 r
.5 Mabswid
.46294 .52613 m
.6267 .46571 L
s
0 1 .735 r
.63251 .51921 m
.78712 .52634 L
s
0 .418 1 r
.63251 .51921 m
.4607 .5152 L
s
0 0 0 r
2.5 Mabswid
.63251 .51921 Mdot
0 1 .592 r
.5 Mabswid
.48914 .51392 m
.63251 .51921 L
s
0 1 .754 r
.53068 .59168 m
.63846 .55051 L
s
0 0 0 r
2.5 Mabswid
.53068 .59168 Mdot
0 1 .754 r
.5 Mabswid
.52233 .36871 m
.53068 .59168 L
s
0 0 0 r
2.5 Mabswid
.63212 .53348 Mdot
.741 1 0 r
.5 Mabswid
.4744 .41928 m
.63212 .53348 L
s
.933 1 0 r
.25376 .53596 m
.44133 .48086 L
s
0 0 0 r
2.5 Mabswid
.59845 .63766 Mdot
.045 1 0 r
.5 Mabswid
.60555 .6408 m
.59845 .63766 L
s
0 0 0 r
2.5 Mabswid
.47688 .38598 Mdot
0 .989 1 r
.5 Mabswid
.47962 .61245 m
.47688 .38598 L
s
0 1 .653 r
.53711 .59734 m
.63523 .56027 L
s
0 0 0 r
2.5 Mabswid
.53711 .59734 Mdot
0 1 .653 r
.5 Mabswid
.5289 .37349 m
.53711 .59734 L
s
1 0 0 r
.25278 .53506 m
.42714 .46652 L
s
0 .149 1 r
.57419 .62263 m
.61218 .62514 L
s
0 0 0 r
2.5 Mabswid
.57419 .62263 Mdot
0 .149 1 r
.5 Mabswid
.4841 .32319 m
.57419 .62263 L
s
0 .601 1 r
.62949 .47318 m
.468 .49123 L
s
0 0 0 r
2.5 Mabswid
.62949 .47318 Mdot
0 1 .326 r
.5 Mabswid
.46385 .53434 m
.62949 .47318 L
s
.142 1 0 r
.47561 .46035 m
.61215 .42282 L
s
0 0 0 r
2.5 Mabswid
.47561 .46035 Mdot
.142 1 0 r
.5 Mabswid
.60232 .41271 m
.47561 .46035 L
s
.282 1 0 r
.53334 .59596 m
.58692 .38428 L
s
0 0 0 r
2.5 Mabswid
.53334 .59596 Mdot
1 .115 0 r
.5 Mabswid
.64631 .52998 m
.53334 .59596 L
s
0 0 0 r
2.5 Mabswid
.63305 .53011 Mdot
.81 1 0 r
.5 Mabswid
.58566 .52613 m
.63305 .53011 L
s
0 1 .542 r
.54356 .60302 m
.63202 .56996 L
s
0 0 0 r
2.5 Mabswid
.54356 .60302 Mdot
0 1 .542 r
.5 Mabswid
.5355 .37829 m
.54356 .60302 L
s
1 .116 0 r
.50169 .54189 m
.65637 .4943 L
s
0 0 0 r
2.5 Mabswid
.50169 .54189 Mdot
.797 1 0 r
.5 Mabswid
.4769 .38269 m
.54926 .35545 L
s
0 0 0 r
2.5 Mabswid
.4769 .38269 Mdot
.797 1 0 r
.5 Mabswid
.5799 .61392 m
.4769 .38269 L
s
0 0 0 r
2.5 Mabswid
.60232 .41271 Mdot
1 .728 0 r
.5 Mabswid
.46711 .58752 m
.60232 .41271 L
s
0 0 0 r
2.5 Mabswid
.62721 .56824 Mdot
0 .149 1 r
.5 Mabswid
.45319 .34249 m
.62721 .56824 L
s
.797 1 0 r
.59077 .63563 m
.60978 .63219 L
s
0 0 0 r
2.5 Mabswid
.59077 .63563 Mdot
.797 1 0 r
.5 Mabswid
.55338 .37732 m
.59077 .63563 L
s
0 0 0 r
2.5 Mabswid
.48311 .36434 Mdot
0 1 .381 r
.5 Mabswid
.51696 .33955 m
.48311 .36434 L
s
0 1 .532 r
.60646 .41819 m
.56223 .62311 L
s
0 0 0 r
2.5 Mabswid
.60646 .41819 Mdot
0 1 .532 r
.5 Mabswid
.4421 .39029 m
.60646 .41819 L
s
.018 0 1 r
.47242 .45355 m
.64645 .42141 L
s
0 0 0 r
2.5 Mabswid
.47242 .45355 Mdot
0 .938 1 r
.5 Mabswid
.60037 .39119 m
.47242 .45355 L
s
.699 1 0 r
.4784 .47242 m
.42015 .42589 L
s
0 0 0 r
2.5 Mabswid
.4784 .47242 Mdot
.932 1 0 r
.5 Mabswid
.24972 .53225 m
.43781 .47731 L
s
0 .829 1 r
.58588 .63359 m
.48292 .36374 L
s
0 0 0 r
2.5 Mabswid
.58588 .63359 Mdot
0 .829 1 r
.5 Mabswid
.61021 .63129 m
.58588 .63359 L
s
1 0 0 r
.24956 .5321 m
.42355 .46289 L
s
.801 1 0 r
.61089 .63097 m
.43562 .3797 L
s
0 0 0 r
2.5 Mabswid
.61089 .63097 Mdot
.46368 .4232 Mdot
0 .538 1 r
.5 Mabswid
.45938 .4251 m
.46368 .4232 L
s
.884 1 0 r
.50499 .55587 m
.61393 .61133 L
s
0 0 0 r
2.5 Mabswid
.50499 .55587 Mdot
.884 1 0 r
.5 Mabswid
.60919 .40995 m
.50499 .55587 L
s
.797 1 0 r
.49373 .33536 m
.51116 .32863 L
s
0 0 0 r
2.5 Mabswid
.49373 .33536 Mdot
.797 1 0 r
.5 Mabswid
.52811 .62011 m
.49373 .33536 L
s
0 0 0 r
2.5 Mabswid
.76262 .66791 Mdot
0 .409 1 r
.5 Mabswid
.65021 .51584 m
.76262 .66791 L
s
0 .668 1 r
.21518 .42438 m
.44263 .42521 L
s
0 g
.48628 .60513 m
.51459 .58641 L
s
0 0 0 r
2.5 Mabswid
.48999 .34272 Mdot
.741 1 0 r
.5 Mabswid
.43495 .52301 m
.48999 .34272 L
s
0 0 0 r
2.5 Mabswid
.60555 .6408 Mdot
.045 1 0 r
.5 Mabswid
.60706 .6395 m
.60555 .6408 L
s
0 g
.51457 .58636 m
.5302 .63151 L
s
.48626 .60509 m
.51457 .58636 L
s
.53026 .63139 m
.51455 .58636 L
s
0 0 0 r
2.5 Mabswid
.55802 .61571 Mdot
0 .111 1 r
.5 Mabswid
.62975 .57725 m
.55802 .61571 L
s
0 0 0 r
2.5 Mabswid
.55804 .3635 Mdot
0 1 .532 r
.5 Mabswid
.55911 .652 m
.55804 .3635 L
s
.778 1 0 r
.6256 .5762 m
.51247 .39232 L
s
0 0 0 r
2.5 Mabswid
.6256 .5762 Mdot
.48102 .36538 Mdot
0 .989 1 r
.5 Mabswid
.52495 .49275 m
.48102 .36538 L
s
.732 1 0 r
.6351 .50392 m
.41883 .4484 L
s
0 0 0 r
2.5 Mabswid
.6351 .50392 Mdot
.778 1 0 r
.5 Mabswid
.48493 .35486 m
.51262 .41599 L
s
0 0 0 r
2.5 Mabswid
.48493 .35486 Mdot
1 .116 0 r
.5 Mabswid
.49848 .53864 m
.65882 .48895 L
s
0 0 0 r
2.5 Mabswid
.49848 .53864 Mdot
.62246 .44333 Mdot
0 .989 1 r
.5 Mabswid
.5464 .35458 m
.62246 .44333 L
s
.8 1 0 r
.46195 .41811 m
.61953 .42316 L
s
0 0 0 r
2.5 Mabswid
.46195 .41811 Mdot
.8 1 0 r
.5 Mabswid
.53901 .41667 m
.46195 .41811 L
s
0 0 0 r
2.5 Mabswid
.60706 .6395 Mdot
.045 1 0 r
.5 Mabswid
.57271 .46292 m
.60706 .6395 L
s
0 .989 1 r
.58344 .63538 m
.55228 .67501 L
s
0 0 0 r
2.5 Mabswid
.58344 .63538 Mdot
.63483 .53609 Mdot
.737 1 0 r
.5 Mabswid
.48389 .42685 m
.63483 .53609 L
s
1 0 0 r
.24633 .52913 m
.42056 .45899 L
s
.737 1 0 r
.6352 .49582 m
.41822 .43888 L
s
0 0 0 r
2.5 Mabswid
.6352 .49582 Mdot
0 .989 1 r
.5 Mabswid
.49839 .32299 m
.61471 .42127 L
s
0 0 0 r
2.5 Mabswid
.49839 .32299 Mdot
0 .989 1 r
.5 Mabswid
.48132 .33571 m
.49839 .32299 L
s
0 .042 1 r
.5503 .61358 m
.57796 .40502 L
s
0 0 0 r
2.5 Mabswid
.5503 .61358 Mdot
0 .498 1 r
.5 Mabswid
.63257 .56941 m
.5503 .61358 L
s
0 0 0 r
2.5 Mabswid
.48914 .51392 Mdot
0 1 .592 r
.5 Mabswid
.5778 .40996 m
.48914 .51392 L
s
.932 1 0 r
.24565 .52851 m
.43427 .47373 L
s
0 1 .532 r
.56223 .62311 m
.60463 .62564 L
s
0 0 0 r
2.5 Mabswid
.56223 .62311 Mdot
.797 1 0 r
.5 Mabswid
.51116 .32863 m
.49897 .62238 L
s
0 0 0 r
2.5 Mabswid
.51116 .32863 Mdot
1 .886 0 r
.5 Mabswid
.53717 .60661 m
.61479 .56282 L
s
0 0 0 r
2.5 Mabswid
.53717 .60661 Mdot
1 .886 0 r
.5 Mabswid
.6178 .40677 m
.53717 .60661 L
s
0 .695 1 r
.48072 .49037 m
.63797 .53507 L
s
0 0 0 r
2.5 Mabswid
.48072 .49037 Mdot
0 .695 1 r
.5 Mabswid
.54771 .36384 m
.48072 .49037 L
s
1 .116 0 r
.49524 .53537 m
.66086 .48368 L
s
0 0 0 r
2.5 Mabswid
.49524 .53537 Mdot
0 .829 1 r
.5 Mabswid
.52144 .59619 m
.46678 .46066 L
s
0 0 0 r
2.5 Mabswid
.52144 .59619 Mdot
0 .829 1 r
.5 Mabswid
.63651 .53268 m
.52144 .59619 L
s
0 0 0 r
2.5 Mabswid
.53363 .60475 Mdot
0 1 .453 r
.5 Mabswid
.46824 .59226 m
.53363 .60475 L
s
.741 1 0 r
.63529 .48771 m
.41874 .42965 L
s
0 0 0 r
2.5 Mabswid
.63529 .48771 Mdot
.45938 .4251 Mdot
0 .538 1 r
.5 Mabswid
.41707 .44829 m
.45938 .4251 L
s
.874 1 0 r
.50313 .56078 m
.61064 .6159 L
s
0 0 0 r
2.5 Mabswid
.50313 .56078 Mdot
.874 1 0 r
.5 Mabswid
.61137 .40915 m
.50313 .56078 L
s
0 .046 1 r
.54253 .61145 m
.56913 .40308 L
s
0 0 0 r
2.5 Mabswid
.54253 .61145 Mdot
0 .449 1 r
.5 Mabswid
.63541 .56152 m
.54253 .61145 L
s
0 0 0 r
2.5 Mabswid
.61021 .63129 Mdot
0 .829 1 r
.5 Mabswid
.45749 .44202 m
.61021 .63129 L
s
1 0 0 r
.24308 .52615 m
.41921 .45438 L
s
0 0 0 r
2.5 Mabswid
.45965 .4279 Mdot
0 1 .381 r
.5 Mabswid
.50517 .38018 m
.45965 .4279 L
s
.797 1 0 r
.60978 .63219 m
.43397 .38041 L
s
0 0 0 r
2.5 Mabswid
.60978 .63219 Mdot
.63697 .51197 Mdot
0 1 .632 r
.5 Mabswid
.62593 .58248 m
.63697 .51197 L
s
0 0 0 r
2.5 Mabswid
.61878 .43218 Mdot
0 .298 1 r
.5 Mabswid
.46691 .55049 m
.61878 .43218 L
s
0 0 0 r
2.5 Mabswid
.63546 .54136 Mdot
.699 1 0 r
.5 Mabswid
.62847 .56058 m
.63546 .54136 L
s
0 0 0 r
2.5 Mabswid
.63651 .53268 Mdot
0 .829 1 r
.5 Mabswid
.42809 .37949 m
.63651 .53268 L
s
.746 1 0 r
.63539 .47958 m
.41927 .42039 L
s
0 0 0 r
2.5 Mabswid
.63539 .47958 Mdot
.932 1 0 r
.5 Mabswid
.24157 .52476 m
.43072 .47014 L
s
.88 1 0 r
.51159 .58995 m
.65197 .4444 L
s
0 0 0 r
2.5 Mabswid
.51159 .58995 Mdot
1 .116 0 r
.5 Mabswid
.66188 .48417 m
.51159 .58995 L
s
.274 1 0 r
.50868 .58329 m
.62823 .58189 L
s
0 0 0 r
2.5 Mabswid
.50868 .58329 Mdot
1 .116 0 r
.5 Mabswid
.66575 .47259 m
.50868 .58329 L
s
.492 .53209 m
.66278 .47841 L
s
0 0 0 r
2.5 Mabswid
.492 .53209 Mdot
.865 1 0 r
.5 Mabswid
.51607 .59552 m
.65376 .45352 L
s
0 0 0 r
2.5 Mabswid
.51607 .59552 Mdot
1 .116 0 r
.5 Mabswid
.65802 .49574 m
.51607 .59552 L
s
.284 1 0 r
.50613 .57638 m
.63063 .5746 L
s
0 0 0 r
2.5 Mabswid
.50613 .57638 Mdot
1 .116 0 r
.5 Mabswid
.66963 .46099 m
.50613 .57638 L
s
0 1 .632 r
.62783 .44644 m
.45558 .33724 L
s
0 0 0 r
2.5 Mabswid
.62783 .44644 Mdot
.298 1 0 r
.5 Mabswid
.50358 .56947 m
.63303 .56729 L
s
0 0 0 r
2.5 Mabswid
.50358 .56947 Mdot
1 .116 0 r
.5 Mabswid
.67351 .44938 m
.50358 .56947 L
s
.741 1 0 r
.52021 .60021 m
.52494 .62638 L
s
0 0 0 r
2.5 Mabswid
.52021 .60021 Mdot
1 0 0 r
.5 Mabswid
.23981 .52314 m
.41784 .44973 L
s
.4 1 0 r
.5209 .60084 m
.57151 .40509 L
s
0 0 0 r
2.5 Mabswid
.5209 .60084 Mdot
1 .116 0 r
.5 Mabswid
.65415 .5073 m
.5209 .60084 L
s
0 0 0 r
2.5 Mabswid
.78342 .66604 Mdot
0 .339 1 r
.5 Mabswid
.63969 .54758 m
.78342 .66604 L
s
.8 1 0 r
.63522 .47155 m
.42732 .47246 L
s
0 0 0 r
2.5 Mabswid
.63522 .47155 Mdot
.45954 .402 Mdot
0 .989 1 r
.5 Mabswid
.43308 .36798 m
.45954 .402 L
s
0 .685 1 r
.47922 .49578 m
.6375 .54095 L
s
0 0 0 r
2.5 Mabswid
.47922 .49578 Mdot
0 .685 1 r
.5 Mabswid
.54714 .36757 m
.47922 .49578 L
s
0 g
.43867 .37674 m
.45369 .4169 L
s
.45369 .4169 m
.42289 .42938 L
s
.45368 .41684 m
.42288 .42933 L
s
.45368 .41691 m
.43865 .37675 L
s
.49071 .3181 m
.45808 .31256 L
s
.43865 .37677 m
.49071 .3181 L
s
.49549 .31633 m
.4907 .31811 L
s
.4907 .31811 m
.45808 .31257 L
s
.43865 .37675 m
.49071 .31807 L
s
.49068 .3181 m
.49548 .31632 L
s
.406 1 0 r
.52628 .60579 m
.5778 .40996 L
s
0 0 0 r
2.5 Mabswid
.52628 .60579 Mdot
1 .116 0 r
.5 Mabswid
.65029 .51885 m
.52628 .60579 L
s
0 0 0 r
2.5 Mabswid
.63891 .50271 Mdot
0 .538 1 r
.5 Mabswid
.62517 .42503 m
.63891 .50271 L
s
.866 1 0 r
.50125 .56574 m
.60629 .61996 L
s
0 0 0 r
2.5 Mabswid
.50125 .56574 Mdot
.866 1 0 r
.5 Mabswid
.61357 .40835 m
.50125 .56574 L
s
0 0 0 r
2.5 Mabswid
.79899 .6542 Mdot
.201 1 0 r
.5 Mabswid
.64834 .52056 m
.79899 .6542 L
s
0 0 0 r
2.5 Mabswid
.46172 .3928 Mdot
.741 1 0 r
.5 Mabswid
.42022 .41814 m
.46172 .3928 L
s
.932 1 0 r
.23746 .52098 m
.42714 .46652 L
s
0 .57 1 r
.63797 .53507 m
.79489 .58751 L
s
0 0 0 r
2.5 Mabswid
.63797 .53507 Mdot
1 .116 0 r
.5 Mabswid
.48873 .52879 m
.66471 .47308 L
s
0 0 0 r
2.5 Mabswid
.48873 .52879 Mdot
0 g
.5 Mabswid
.49543 .31629 m
.6325 .41101 L
s
.61387 .40137 m
.49543 .31629 L
s
.49547 .31632 m
.46298 .31071 L
s
.61392 .4014 m
.49547 .31632 L
s
.463 .31073 m
.49549 .31633 L
s
.49546 .31631 m
.6325 .41108 L
s
0 0 0 r
2.5 Mabswid
.6977 .24805 Mdot
0 .989 1 r
.5 Mabswid
.61471 .42127 m
.64042 .47576 L
s
0 0 0 r
2.5 Mabswid
.61471 .42127 Mdot
1 0 0 r
.5 Mabswid
.23653 .52013 m
.41646 .44503 L
s
0 1 .749 r
.49789 .55881 m
.6275 .58078 L
s
0 0 0 r
2.5 Mabswid
.49789 .55881 Mdot
0 1 .749 r
.5 Mabswid
.59819 .41987 m
.49789 .55881 L
s
0 .149 1 r
.61218 .62514 m
.44633 .47733 L
s
0 0 0 r
2.5 Mabswid
.61218 .62514 Mdot
.5325 .34344 Mdot
0 1 .381 r
.5 Mabswid
.45676 .36034 m
.5325 .34344 L
s
0 0 0 r
2.5 Mabswid
.78712 .52634 Mdot
.48132 .33571 Mdot
0 .989 1 r
.5 Mabswid
.43246 .39004 m
.48132 .33571 L
s
0 0 0 r
2.5 Mabswid
.77624 .68261 Mdot
0 .968 1 r
.5 Mabswid
.63962 .48332 m
.77624 .68261 L
s
0 .692 1 r
.47771 .50122 m
.63702 .54688 L
s
0 0 0 r
2.5 Mabswid
.47771 .50122 Mdot
0 .692 1 r
.5 Mabswid
.54656 .37133 m
.47771 .50122 L
s
1 .116 0 r
.48545 .52547 m
.66667 .4677 L
s
0 0 0 r
2.5 Mabswid
.48545 .52547 Mdot
0 .348 1 r
.5 Mabswid
.50305 .58005 m
.53925 .53653 L
s
0 0 0 r
2.5 Mabswid
.50305 .58005 Mdot
0 .56 1 r
.5 Mabswid
.17485 .33221 m
.43991 .41348 L
s
.932 1 0 r
.23333 .51718 m
.42355 .46289 L
s
.797 1 0 r
.54926 .35545 m
.53891 .65791 L
s
0 0 0 r
2.5 Mabswid
.54926 .35545 Mdot
1 0 0 r
.5 Mabswid
.23323 .51709 m
.41507 .44029 L
s
0 1 .532 r
.46338 .45934 m
.5933 .38423 L
s
0 0 0 r
2.5 Mabswid
.46338 .45934 Mdot
.813 1 0 r
.5 Mabswid
.65811 .44119 m
.46338 .45934 L
s
.857 1 0 r
.49936 .57074 m
.60192 .62406 L
s
0 0 0 r
2.5 Mabswid
.49936 .57074 Mdot
.857 1 0 r
.5 Mabswid
.61578 .40754 m
.49936 .57074 L
s
0 0 0 r
2.5 Mabswid
.63962 .48332 Mdot
0 .989 1 r
.5 Mabswid
.43195 .42352 m
.63962 .48332 L
s
0 1 .128 r
.50201 .57941 m
.66229 .46056 L
s
0 0 0 r
2.5 Mabswid
.50201 .57941 Mdot
.793 1 0 r
.5 Mabswid
.6236 .58704 m
.50201 .57941 L
s
0 0 0 r
2.5 Mabswid
.48764 .53521 Mdot
.052 0 1 r
.5 Mabswid
.53506 .42044 m
.48764 .53521 L
s
0 .989 1 r
.50878 .59516 m
.43837 .54783 L
s
0 0 0 r
2.5 Mabswid
.50878 .59516 Mdot
.45749 .44202 Mdot
0 .829 1 r
.5 Mabswid
.44931 .37339 m
.45749 .44202 L
s
0 1 .968 r
.6275 .58078 m
.79498 .59034 L
s
0 .005 1 r
.6275 .58078 m
.47063 .52838 L
s
0 0 0 r
2.5 Mabswid
.6275 .58078 Mdot
0 .559 1 r
.5 Mabswid
.6375 .54095 m
.79446 .59394 L
s
0 0 0 r
2.5 Mabswid
.6375 .54095 Mdot
0 1 .381 r
.5 Mabswid
.61243 .62351 m
.51079 .62279 L
s
0 0 0 r
2.5 Mabswid
.61243 .62351 Mdot
0 1 .522 r
.5 Mabswid
.45023 .41111 m
.51957 .61218 L
s
0 0 0 r
2.5 Mabswid
.45023 .41111 Mdot
0 1 .522 r
.5 Mabswid
.49177 .32038 m
.45023 .41111 L
s
0 .711 1 r
.47141 .48695 m
.55577 .53063 L
s
0 0 0 r
2.5 Mabswid
.47141 .48695 Mdot
.60919 .40995 Mdot
.884 1 0 r
.5 Mabswid
.41483 .4524 m
.60919 .40995 L
s
0 .989 1 r
.59644 .65362 m
.5899 .50095 L
s
0 0 0 r
2.5 Mabswid
.59644 .65362 Mdot
.741 1 0 r
.5 Mabswid
.53803 .62272 m
.46251 .4105 L
s
0 0 0 r
2.5 Mabswid
.53803 .62272 Mdot
.741 1 0 r
.5 Mabswid
.62085 .60001 m
.53803 .62272 L
s
0 0 0 r
2.5 Mabswid
.34887 .84135 Mdot
0 1 .969 r
.5 Mabswid
.47093 .60029 m
.34887 .84135 L
s
0 1 .453 r
.47172 .48975 m
.5391 .62755 L
s
0 0 0 r
2.5 Mabswid
.47172 .48975 Mdot
1 .116 0 r
.5 Mabswid
.48216 .52214 m
.66864 .46227 L
s
0 0 0 r
2.5 Mabswid
.48216 .52214 Mdot
1 0 0 r
.5 Mabswid
.22992 .51404 m
.41366 .43549 L
s
0 .58 1 r
.16827 .31982 m
.43881 .4029 L
s
0 1 .003 r
.50345 .58871 m
.66449 .47004 L
s
0 0 0 r
2.5 Mabswid
.50345 .58871 Mdot
.789 1 0 r
.5 Mabswid
.61972 .59612 m
.50345 .58871 L
s
0 0 0 r
2.5 Mabswid
.63487 .55338 Mdot
.045 1 0 r
.5 Mabswid
.46867 .5968 m
.63487 .55338 L
s
.8 1 0 r
.61953 .42316 m
.58379 .62567 L
s
0 0 0 r
2.5 Mabswid
.61953 .42316 Mdot
0 .989 1 r
.5 Mabswid
.64042 .47576 m
.63281 .56863 L
s
0 0 0 r
2.5 Mabswid
.64042 .47576 Mdot
0 .038 1 r
.5 Mabswid
.48896 .31582 m
.44868 .5667 L
s
0 0 0 r
2.5 Mabswid
.48896 .31582 Mdot
.2 0 1 r
.5 Mabswid
.64294 .50446 m
.64853 .52096 L
s
0 0 0 r
2.5 Mabswid
.64294 .50446 Mdot
.045 1 0 r
.5 Mabswid
.59033 .38668 m
.58113 .37659 L
s
0 0 0 r
2.5 Mabswid
.59033 .38668 Mdot
1 0 0 r
.5 Mabswid
.22659 .51098 m
.41224 .43065 L
s
0 1 .522 r
.51957 .61218 m
.59323 .66293 L
s
0 0 0 r
2.5 Mabswid
.51957 .61218 Mdot
0 .327 1 r
.5 Mabswid
.60354 .40066 m
.56321 .4371 L
s
0 0 0 r
2.5 Mabswid
.60354 .40066 Mdot
1 .096 0 r
.5 Mabswid
.64273 .52405 m
.57605 .44489 L
s
0 0 0 r
2.5 Mabswid
.64273 .52405 Mdot
1 .116 0 r
.5 Mabswid
.47885 .5188 m
.67063 .45678 L
s
0 0 0 r
2.5 Mabswid
.47885 .5188 Mdot
0 .581 1 r
.5 Mabswid
.63702 .54688 m
.79403 .60042 L
s
0 0 0 r
2.5 Mabswid
.63702 .54688 Mdot
.8 1 0 r
.5 Mabswid
.46864 .34909 m
.62519 .58629 L
s
0 0 0 r
2.5 Mabswid
.46864 .34909 Mdot
.8 1 0 r
.5 Mabswid
.50161 .32792 m
.46864 .34909 L
s
0 .989 1 r
.61221 .62294 m
.47608 .61087 L
s
0 0 0 r
2.5 Mabswid
.61221 .62294 Mdot
0 .599 1 r
.5 Mabswid
.16156 .30725 m
.43767 .39216 L
s
0 .877 1 r
.46701 .48318 m
.53506 .42044 L
s
0 0 0 r
2.5 Mabswid
.46701 .48318 Mdot
0 .989 1 r
.5 Mabswid
.52771 .62132 m
.51471 .62253 L
s
0 0 0 r
2.5 Mabswid
.52771 .62132 Mdot
.46956 .3447 Mdot
0 .989 1 r
.5 Mabswid
.48169 .31832 m
.46956 .3447 L
s
0 .542 1 r
.46421 .3587 m
.51716 .33243 L
s
0 0 0 r
2.5 Mabswid
.46421 .3587 Mdot
0 .542 1 r
.5 Mabswid
.52041 .62407 m
.46421 .3587 L
s
0 0 0 r
2.5 Mabswid
.61137 .40915 Mdot
.874 1 0 r
.5 Mabswid
.41562 .4519 m
.61137 .40915 L
s
0 0 0 r
2.5 Mabswid
.64009 .4615 Mdot
0 .884 1 r
.5 Mabswid
.58644 .57311 m
.64009 .4615 L
s
.741 1 0 r
.59896 .65397 m
.58363 .65575 L
s
0 0 0 r
2.5 Mabswid
.59896 .65397 Mdot
0 .038 1 r
.5 Mabswid
.5674 .64529 m
.60541 .63657 L
s
0 0 0 r
2.5 Mabswid
.5674 .64529 Mdot
0 .038 1 r
.5 Mabswid
.44319 .34535 m
.5674 .64529 L
s
0 1 .403 r
.45304 .4427 m
.43444 .37168 L
s
0 0 0 r
2.5 Mabswid
.45304 .4427 Mdot
.746 1 0 r
.5 Mabswid
.52603 .62133 m
.59819 .41987 L
s
0 0 0 r
2.5 Mabswid
.52603 .62133 Mdot
.746 1 0 r
.5 Mabswid
.6222 .59496 m
.52603 .62133 L
s
.045 1 0 r
.52589 .33736 m
.44325 .35592 L
s
0 0 0 r
2.5 Mabswid
.52589 .33736 Mdot
0 .542 1 r
.5 Mabswid
.62619 .58702 m
.41958 .43291 L
s
0 0 0 r
2.5 Mabswid
.62619 .58702 Mdot
0 .149 1 r
.5 Mabswid
.63401 .44211 m
.51333 .6152 L
s
0 0 0 r
2.5 Mabswid
.63401 .44211 Mdot
0 .149 1 r
.5 Mabswid
.41329 .43597 m
.63401 .44211 L
s
1 0 0 r
.22324 .5079 m
.41337 .42464 L
s
0 .601 1 r
.468 .49123 m
.53655 .42909 L
s
0 0 0 r
2.5 Mabswid
.468 .49123 Mdot
0 1 .871 r
.5 Mabswid
.46881 .49394 m
.56079 .38131 L
s
0 0 0 r
2.5 Mabswid
.46881 .49394 Mdot
0 1 .871 r
.5 Mabswid
.64834 .52056 m
.46881 .49394 L
s
.797 1 0 r
.45258 .38421 m
.49177 .32038 L
s
0 0 0 r
2.5 Mabswid
.45258 .38421 Mdot
.797 1 0 r
.5 Mabswid
.44846 .43701 m
.45258 .38421 L
s
1 .116 0 r
.47552 .51543 m
.67265 .45124 L
s
0 0 0 r
2.5 Mabswid
.47552 .51543 Mdot
0 .538 1 r
.5 Mabswid
.61425 .61736 m
.54357 .47937 L
s
0 0 0 r
2.5 Mabswid
.61425 .61736 Mdot
0 .542 1 r
.5 Mabswid
.52213 .61856 m
.52234 .57926 L
s
0 0 0 r
2.5 Mabswid
.52213 .61856 Mdot
.741 1 0 r
.5 Mabswid
.58363 .65575 m
.44684 .5648 L
s
0 0 0 r
2.5 Mabswid
.58363 .65575 Mdot
.59629 .65804 Mdot
0 1 .632 r
.5 Mabswid
.47828 .6086 m
.59629 .65804 L
s
0 1 .381 r
.63672 .55172 m
.45304 .55683 L
s
0 0 0 r
2.5 Mabswid
.63672 .55172 Mdot
.63938 .4505 Mdot
0 .739 1 r
.5 Mabswid
.65238 .50098 m
.63938 .4505 L
s
1 0 0 r
.21987 .5048 m
.41463 .41848 L
s
0 0 0 r
2.5 Mabswid
.44846 .43701 Mdot
.797 1 0 r
.5 Mabswid
.57234 .65469 m
.44846 .43701 L
s
1 .984 0 r
.58673 .65913 m
.45506 .74881 L
s
.388 1 0 r
.58673 .65913 m
.60548 .59944 L
s
0 0 0 r
2.5 Mabswid
.58673 .65913 Mdot
1 .886 0 r
.5 Mabswid
.6078 .63139 m
.58673 .65913 L
s
0 0 0 r
2.5 Mabswid
.62517 .42503 Mdot
0 .538 1 r
.5 Mabswid
.54904 .35849 m
.62517 .42503 L
s
1 .116 0 r
.47218 .51205 m
.67468 .44563 L
s
0 0 0 r
2.5 Mabswid
.47218 .51205 Mdot
1 .228 0 r
.5 Mabswid
.20311 .45496 m
.41575 .45281 L
s
0 0 0 r
2.5 Mabswid
.61357 .40835 Mdot
.866 1 0 r
.5 Mabswid
.41642 .4514 m
.61357 .40835 L
s
1 .096 0 r
.64594 .51706 m
.58606 .44481 L
s
0 0 0 r
2.5 Mabswid
.64594 .51706 Mdot
.81624 .63898 Mdot
.51716 .33243 Mdot
0 g
.5 Mabswid
.5302 .6315 m
.55609 .67731 L
s
.48625 .60508 m
.5302 .6315 L
s
.58593 .67003 m
.53017 .63148 L
s
.53017 .63148 m
.55607 .6773 L
s
.5302 .63151 m
.48626 .60509 L
s
.53017 .63149 m
.58592 .67003 L
s
.801 1 0 r
.633 .56642 m
.43277 .35172 L
s
0 0 0 r
2.5 Mabswid
.633 .56642 Mdot
.44363 .40456 Mdot
0 1 .381 r
.5 Mabswid
.43301 .40201 m
.44363 .40456 L
s
.741 1 0 r
.52494 .62638 m
.5254 .62865 L
s
0 0 0 r
2.5 Mabswid
.52494 .62638 Mdot
1 .242 0 r
.5 Mabswid
.20838 .47514 m
.42738 .42344 L
s
0 0 0 r
2.5 Mabswid
.45676 .36034 Mdot
0 1 .381 r
.5 Mabswid
.43412 .48694 m
.45676 .36034 L
s
0 0 0 r
2.5 Mabswid
.6078 .63139 Mdot
1 .886 0 r
.5 Mabswid
.63585 .43479 m
.6078 .63139 L
s
0 1 .517 r
.44263 .42521 m
.4336 .39178 L
s
0 0 0 r
2.5 Mabswid
.44263 .42521 Mdot
1 0 0 r
.5 Mabswid
.21648 .50169 m
.41591 .41223 L
s
0 0 0 r
2.5 Mabswid
.59408 .38659 Mdot
0 1 .381 r
.5 Mabswid
.44931 .55519 m
.59408 .38659 L
s
1 .116 0 r
.64681 .51515 m
.52882 .44526 L
s
0 0 0 r
2.5 Mabswid
.64681 .51515 Mdot
1 .247 0 r
.5 Mabswid
.20541 .46782 m
.42745 .41612 L
s
1 .286 0 r
.24417 .59053 m
.4235 .4162 L
s
0 0 0 r
2.5 Mabswid
.63332 .56566 Mdot
1 .115 0 r
.5 Mabswid
.55926 .41366 m
.63332 .56566 L
s
0 g
.65012 .8409 m
.83714 .79854 L
s
.35892 .58214 m
.65012 .8409 L
s
1 .116 0 r
.46882 .50866 m
.67108 .44184 L
s
0 0 0 r
2.5 Mabswid
.46882 .50866 Mdot
0 1 .243 r
.5 Mabswid
.47828 .538 m
.54771 .36384 L
s
0 0 0 r
2.5 Mabswid
.47828 .538 Mdot
0 1 .243 r
.5 Mabswid
.61064 .6159 m
.47828 .538 L
s
0 .149 1 r
.51333 .6152 m
.5949 .58976 L
s
0 0 0 r
2.5 Mabswid
.51333 .6152 Mdot
.741 1 0 r
.5 Mabswid
.5254 .62865 m
.5718 .65608 L
s
0 0 0 r
2.5 Mabswid
.5254 .62865 Mdot
.63125 .57223 Mdot
0 .327 1 r
.5 Mabswid
.47625 .60995 m
.63125 .57223 L
s
0 0 0 r
2.5 Mabswid
.45102 .37109 Mdot
.741 1 0 r
.5 Mabswid
.43919 .33895 m
.45102 .37109 L
s
0 .364 1 r
.4416 .41222 m
.53542 .35423 L
s
0 0 0 r
2.5 Mabswid
.4416 .41222 Mdot
0 .364 1 r
.5 Mabswid
.63706 .55628 m
.4416 .41222 L
s
0 .038 1 r
.60541 .63657 m
.44005 .36787 L
s
0 0 0 r
2.5 Mabswid
.60541 .63657 Mdot
.741 1 0 r
.5 Mabswid
.46978 .32878 m
.62085 .60001 L
s
0 0 0 r
2.5 Mabswid
.46978 .32878 Mdot
.741 1 0 r
.5 Mabswid
.48915 .32064 m
.46978 .32878 L
s
0 0 0 r
2.5 Mabswid
.62085 .60001 Mdot
0 1 .542 r
.5 Mabswid
.63202 .56996 m
.49504 .35959 L
s
0 0 0 r
2.5 Mabswid
.63202 .56996 Mdot
.44931 .37339 Mdot
0 .829 1 r
.5 Mabswid
.46586 .31221 m
.44931 .37339 L
s
0 0 0 r
2.5 Mabswid
.70855 .31151 Mdot
0 1 .497 r
.5 Mabswid
.61521 .41936 m
.70855 .31151 L
s
.243 1 0 r
.62823 .58189 m
.72537 .47239 L
s
0 .449 1 r
.62823 .58189 m
.42104 .42887 L
s
0 0 0 r
2.5 Mabswid
.62823 .58189 Mdot
1 0 0 r
.5 Mabswid
.21308 .49856 m
.41721 .40587 L
s
0 .542 1 r
.59376 .66317 m
.5233 .63588 L
s
0 0 0 r
2.5 Mabswid
.59376 .66317 Mdot
0 .542 1 r
.5 Mabswid
.64825 .46821 m
.59376 .66317 L
s
0 0 0 r
2.5 Mabswid
.60037 .39119 Mdot
0 .938 1 r
.5 Mabswid
.5 .60094 m
.60037 .39119 L
s
0 0 0 r
2.5 Mabswid
.62975 .57725 Mdot
0 .111 1 r
.5 Mabswid
.53892 .38277 m
.62975 .57725 L
s
0 0 0 r
2.5 Mabswid
.61578 .40754 Mdot
.857 1 0 r
.5 Mabswid
.41722 .45089 m
.61578 .40754 L
s
0 1 .665 r
.43991 .41348 m
.48155 .35198 L
s
0 0 0 r
2.5 Mabswid
.43991 .41348 Mdot
.4421 .39029 Mdot
0 1 .532 r
.5 Mabswid
.51258 .38281 m
.4421 .39029 L
s
.251 1 0 r
.63063 .5746 m
.72381 .46682 L
s
0 .498 1 r
.63063 .5746 m
.42258 .42025 L
s
0 0 0 r
2.5 Mabswid
.63063 .5746 Mdot
1 .116 0 r
.5 Mabswid
.46544 .50524 m
.66274 .4396 L
s
0 0 0 r
2.5 Mabswid
.46544 .50524 Mdot
.045 1 0 r
.5 Mabswid
.58113 .37659 m
.57071 .36906 L
s
0 0 0 r
2.5 Mabswid
.58113 .37659 Mdot
0 1 .953 r
.5 Mabswid
.17943 .39645 m
.42542 .41276 L
s
0 1 .653 r
.63523 .56027 m
.50818 .36369 L
s
0 0 0 r
2.5 Mabswid
.63523 .56027 Mdot
.63585 .43479 Mdot
1 .886 0 r
.5 Mabswid
.4282 .37781 m
.63585 .43479 L
s
0 0 0 r
2.5 Mabswid
.61967 .60205 Mdot
0 1 .632 r
.5 Mabswid
.55342 .52112 m
.61967 .60205 L
s
.797 1 0 r
.63208 .57018 m
.43389 .35821 L
s
0 0 0 r
2.5 Mabswid
.63208 .57018 Mdot
1 .116 0 r
.5 Mabswid
.64916 .51002 m
.54105 .44517 L
s
0 0 0 r
2.5 Mabswid
.64916 .51002 Mdot
1 .097 0 r
.5 Mabswid
.64917 .50999 m
.59596 .44473 L
s
0 0 0 r
2.5 Mabswid
.64917 .50999 Mdot
.8 1 0 r
.5 Mabswid
.50369 .60892 m
.53901 .41667 L
s
0 0 0 r
2.5 Mabswid
.50369 .60892 Mdot
.8 1 0 r
.5 Mabswid
.62519 .58629 m
.50369 .60892 L
s
0 0 0 r
2.5 Mabswid
.44857 .36657 Mdot
0 .989 1 r
.5 Mabswid
.45829 .3667 m
.44857 .36657 L
s
.282 1 0 r
.63303 .56729 m
.72226 .4613 L
s
0 .111 1 r
.63303 .56729 m
.42412 .41158 L
s
0 0 0 r
2.5 Mabswid
.63303 .56729 Mdot
0 1 .699 r
.5 Mabswid
.47204 .52893 m
.63706 .55628 L
s
0 0 0 r
2.5 Mabswid
.47204 .52893 Mdot
0 1 .699 r
.5 Mabswid
.57151 .40509 m
.47204 .52893 L
s
0 1 .253 r
.47682 .54381 m
.54714 .36757 L
s
0 0 0 r
2.5 Mabswid
.47682 .54381 Mdot
0 1 .253 r
.5 Mabswid
.60629 .61996 m
.47682 .54381 L
s
.852 1 0 r
.49177 .32038 m
.62037 .14654 L
s
0 0 0 r
2.5 Mabswid
.49177 .32038 Mdot
.61553 .61161 Mdot
0 1 .632 r
.5 Mabswid
.54506 .67054 m
.61553 .61161 L
s
0 0 0 r
2.5 Mabswid
.50319 .3267 Mdot
0 .989 1 r
.5 Mabswid
.44826 .33778 m
.50319 .3267 L
s
0 0 0 r
2.5 Mabswid
.63655 .55632 Mdot
1 .115 0 r
.5 Mabswid
.56823 .41572 m
.63655 .55632 L
s
0 0 0 r
2.5 Mabswid
.63288 .56789 Mdot
.045 1 0 r
.5 Mabswid
.61803 .58624 m
.63288 .56789 L
s
0 .542 1 r
.56496 .65646 m
.59137 .65005 L
s
0 0 0 r
2.5 Mabswid
.56496 .65646 Mdot
0 .989 1 r
.5 Mabswid
.51471 .62253 m
.46714 .59148 L
s
0 0 0 r
2.5 Mabswid
.51471 .62253 Mdot
0 1 .754 r
.5 Mabswid
.63846 .55051 m
.52122 .36777 L
s
0 0 0 r
2.5 Mabswid
.63846 .55051 Mdot
1 .116 0 r
.5 Mabswid
.46205 .50181 m
.6544 .43736 L
s
0 0 0 r
2.5 Mabswid
.46205 .50181 Mdot
0 .005 1 r
.5 Mabswid
.47063 .52838 m
.50396 .39975 L
s
0 0 0 r
2.5 Mabswid
.47063 .52838 Mdot
0 1 .653 r
.5 Mabswid
.43881 .4029 m
.47597 .34658 L
s
0 0 0 r
2.5 Mabswid
.43881 .4029 Mdot
.64036 .54458 Mdot
0 .038 1 r
.5 Mabswid
.46726 .59453 m
.64036 .54458 L
s
0 0 0 r
2.5 Mabswid
.5446 .35099 Mdot
.741 1 0 r
.5 Mabswid
.42065 .3906 m
.5446 .35099 L
s
0 0 0 r
2.5 Mabswid
.64825 .46821 Mdot
0 .542 1 r
.5 Mabswid
.6225 .40748 m
.64825 .46821 L
s
0 0 0 r
2.5 Mabswid
.79489 .58751 Mdot
.6258 .41805 Mdot
0 .702 1 r
.5 Mabswid
.43323 .53637 m
.6258 .41805 L
s
0 g
.58592 .67002 m
.59094 .66865 L
s
.55606 .67729 m
.58592 .67002 L
s
.55607 .6773 m
.58593 .67003 L
s
.59093 .66866 m
.58591 .67003 L
s
0 1 .381 r
.61506 .61196 m
.46423 .58746 L
s
0 0 0 r
2.5 Mabswid
.61506 .61196 Mdot
.746 1 0 r
.5 Mabswid
.4687 .31965 m
.6222 .59496 L
s
0 0 0 r
2.5 Mabswid
.4687 .31965 Mdot
.746 1 0 r
.5 Mabswid
.47866 .31544 m
.4687 .31965 L
s
0 .2 1 r
.47087 .53274 m
.45736 .49309 L
s
0 0 0 r
2.5 Mabswid
.47087 .53274 Mdot
.6178 .40677 Mdot
1 .886 0 r
.5 Mabswid
.41803 .45038 m
.6178 .40677 L
s
0 0 0 r
2.5 Mabswid
.6222 .59496 Mdot
.741 1 0 r
.5 Mabswid
.48883 .5899 m
.52031 .62757 L
s
0 0 0 r
2.5 Mabswid
.48883 .5899 Mdot
0 .538 1 r
.5 Mabswid
.64335 .44177 m
.57258 .66629 L
s
0 0 0 r
2.5 Mabswid
.64335 .44177 Mdot
0 .538 1 r
.5 Mabswid
.41652 .42654 m
.64335 .44177 L
s
0 1 .928 r
.64171 .54069 m
.53417 .37181 L
s
0 0 0 r
2.5 Mabswid
.64171 .54069 Mdot
.54666 .64712 Mdot
.142 1 0 r
.5 Mabswid
.62093 .55398 m
.54666 .64712 L
s
0 0 0 r
2.5 Mabswid
.79498 .59034 Mdot
0 .989 1 r
.5 Mabswid
.63281 .56863 m
.57327 .67302 L
s
0 0 0 r
2.5 Mabswid
.63281 .56863 Mdot
1 .116 0 r
.5 Mabswid
.65154 .50483 m
.55316 .44507 L
s
0 0 0 r
2.5 Mabswid
.65154 .50483 Mdot
0 1 .495 r
.5 Mabswid
.47534 .54966 m
.54656 .37133 L
s
0 0 0 r
2.5 Mabswid
.47534 .54966 Mdot
0 1 .495 r
.5 Mabswid
.60192 .62406 m
.47534 .54966 L
s
0 g
.59092 .66868 m
.65286 .51174 L
s
.56121 .67591 m
.59092 .66868 L
s
.59094 .66865 m
.56123 .67588 L
s
0 0 0 r
2.5 Mabswid
.63257 .56941 Mdot
0 .498 1 r
.5 Mabswid
.54844 .3891 m
.63257 .56941 L
s
0 g
.65285 .51175 m
.59092 .66868 L
s
1 .116 0 r
.45864 .49837 m
.64605 .43512 L
s
0 0 0 r
2.5 Mabswid
.45864 .49837 Mdot
.741 1 0 r
.5 Mabswid
.59027 .66882 m
.41838 .43324 L
s
0 0 0 r
2.5 Mabswid
.59027 .66882 Mdot
0 1 .64 r
.5 Mabswid
.43767 .39216 m
.47026 .34148 L
s
0 0 0 r
2.5 Mabswid
.43767 .39216 Mdot
.63978 .54695 Mdot
1 .115 0 r
.5 Mabswid
.57719 .41777 m
.63978 .54695 L
s
0 .13 1 r
.62762 .5816 m
.4217 .3989 L
s
0 0 0 r
2.5 Mabswid
.62762 .5816 Mdot
0 1 .727 r
.5 Mabswid
.59323 .66293 m
.68112 .78402 L
s
0 .2 1 r
.59323 .66293 m
.55782 .65508 L
s
0 0 0 r
2.5 Mabswid
.59323 .66293 Mdot
.045 1 0 r
.5 Mabswid
.43631 .4318 m
.57271 .46292 L
s
0 0 0 r
2.5 Mabswid
.43631 .4318 Mdot
.045 1 0 r
.5 Mabswid
.53484 .34623 m
.43631 .4318 L
s
0 g
.4333 .33523 m
.43866 .37677 L
s
.43866 .37677 m
.45809 .31256 L
s
.43885 .37678 m
.4229 .42939 L
s
.43331 .3352 m
.43885 .37678 L
s
.42289 .42938 m
.43867 .37674 L
s
.45808 .31256 m
.43865 .37677 L
s
1 .097 0 r
.65245 .50284 m
.60578 .44466 L
s
0 0 0 r
2.5 Mabswid
.65245 .50284 Mdot
.48915 .32064 Mdot
.741 1 0 r
.5 Mabswid
.52024 .65185 m
.48915 .32064 L
s
0 .2 1 r
.55782 .65508 m
.46485 .55972 L
s
0 0 0 r
2.5 Mabswid
.55782 .65508 Mdot
0 1 .532 r
.5 Mabswid
.62856 .57898 m
.53187 .64524 L
s
0 0 0 r
2.5 Mabswid
.62856 .57898 Mdot
.79446 .59394 Mdot
1 .116 0 r
.5 Mabswid
.45521 .4949 m
.63769 .43287 L
s
0 0 0 r
2.5 Mabswid
.45521 .4949 Mdot
.63969 .54758 Mdot
0 .439 1 r
.5 Mabswid
.4306 .44492 m
.63969 .54758 L
s
.741 1 0 r
.495 .60836 m
.47781 .548 L
s
0 0 0 r
2.5 Mabswid
.495 .60836 Mdot
.50161 .32792 Mdot
.8 1 0 r
.5 Mabswid
.48265 .61999 m
.50161 .32792 L
s
0 0 0 r
2.5 Mabswid
.78597 .5685 Mdot
0 1 .772 r
.5 Mabswid
.65385 .50618 m
.78597 .5685 L
s
0 1 .2 r
.53484 .34623 m
.39046 .22296 L
s
0 0 0 r
2.5 Mabswid
.53484 .34623 Mdot
0 1 .381 r
.5 Mabswid
.51874 .62886 m
.56346 .64674 L
s
0 0 0 r
2.5 Mabswid
.51874 .62886 Mdot
1 .728 0 r
.5 Mabswid
.64244 .43716 m
.54543 .66382 L
s
0 0 0 r
2.5 Mabswid
.64244 .43716 Mdot
1 .728 0 r
.5 Mabswid
.42076 .45426 m
.64244 .43716 L
s
0 0 0 r
2.5 Mabswid
.64834 .52056 Mdot
.303 1 0 r
.5 Mabswid
.42851 .40875 m
.64834 .52056 L
s
0 0 0 r
2.5 Mabswid
.47866 .31544 Mdot
.746 1 0 r
.5 Mabswid
.50943 .64366 m
.47866 .31544 L
s
0 .932 1 r
.63452 .42597 m
.61723 .45212 L
s
0 0 0 r
2.5 Mabswid
.63452 .42597 Mdot
0 .939 1 r
.5 Mabswid
.43711 .38176 m
.21834 .29177 L
s
0 1 .65 r
.43711 .38176 m
.51669 .35457 L
s
0 0 0 r
2.5 Mabswid
.43711 .38176 Mdot
.45319 .34249 Mdot
0 .149 1 r
.5 Mabswid
.4828 .32964 m
.45319 .34249 L
s
0 1 .532 r
.5933 .38423 m
.53538 .66268 L
s
0 0 0 r
2.5 Mabswid
.5933 .38423 Mdot
0 1 .381 r
.5 Mabswid
.51079 .62279 m
.42119 .41997 L
s
0 0 0 r
2.5 Mabswid
.51079 .62279 Mdot
.47824 .56923 Mdot
.018 0 1 r
.5 Mabswid
.65861 .48769 m
.47824 .56923 L
s
0 .418 1 r
.4607 .5152 m
.48982 .44849 L
s
0 0 0 r
2.5 Mabswid
.4607 .5152 Mdot
1 .116 0 r
.5 Mabswid
.65394 .49959 m
.56516 .44498 L
s
0 0 0 r
2.5 Mabswid
.65394 .49959 Mdot
.43195 .42352 Mdot
0 .989 1 r
.5 Mabswid
.51852 .40104 m
.43195 .42352 L
s
1 .728 0 r
.44654 .35478 m
.58845 .62624 L
s
0 0 0 r
2.5 Mabswid
.44654 .35478 Mdot
1 .728 0 r
.5 Mabswid
.50654 .33671 m
.44654 .35478 L
s
0 1 .943 r
.4591 .5112 m
.64844 .43567 L
s
0 0 0 r
2.5 Mabswid
.4591 .5112 Mdot
0 1 .124 r
.5 Mabswid
.58429 .48347 m
.4591 .5112 L
s
0 0 0 r
2.5 Mabswid
.62519 .58629 Mdot
.65348 .47731 Mdot
0 1 .063 r
.5 Mabswid
.63486 .48239 m
.65348 .47731 L
s
0 0 0 r
2.5 Mabswid
.64303 .53754 Mdot
1 .115 0 r
.5 Mabswid
.58615 .41982 m
.64303 .53754 L
s
1 .116 0 r
.45177 .49142 m
.62933 .43063 L
s
0 0 0 r
2.5 Mabswid
.45177 .49142 Mdot
0 .531 1 r
.5 Mabswid
.57258 .66629 m
.58431 .7235 L
s
0 0 0 r
2.5 Mabswid
.57258 .66629 Mdot
.46294 .52613 Mdot
0 1 .247 r
.5 Mabswid
.51373 .51737 m
.46294 .52613 L
s
.045 1 0 r
.57071 .36906 m
.55229 .36157 L
s
0 0 0 r
2.5 Mabswid
.57071 .36906 Mdot
.6225 .40748 Mdot
0 .542 1 r
.5 Mabswid
.56528 .36787 m
.6225 .40748 L
s
0 0 0 r
2.5 Mabswid
.64342 .53643 Mdot
1 .092 0 r
.5 Mabswid
.53092 .40717 m
.64342 .53643 L
s
0 0 0 r
2.5 Mabswid
.63541 .56152 Mdot
0 .449 1 r
.5 Mabswid
.55801 .39547 m
.63541 .56152 L
s
.819 1 0 r
.58731 .38004 m
.43461 .49361 L
s
0 0 0 r
2.5 Mabswid
.58731 .38004 Mdot
.56521 .3655 Mdot
.741 1 0 r
.5 Mabswid
.42787 .51743 m
.56521 .3655 L
s
0 .038 1 r
.44005 .36787 m
.51373 .34063 L
s
0 0 0 r
2.5 Mabswid
.44005 .36787 Mdot
0 g
.5 Mabswid
.65108 .44643 m
.67479 .44319 L
s
.67478 .44316 m
.65103 .44644 L
s
0 .149 1 r
.44633 .47733 m
.42913 .36245 L
s
0 0 0 r
2.5 Mabswid
.44633 .47733 Mdot
.4289 .19234 Mdot
.782 1 0 r
.5 Mabswid
.41337 .42464 m
.4289 .19234 L
s
.814 1 0 r
.59388 .38444 m
.43613 .50229 L
s
0 0 0 r
2.5 Mabswid
.59388 .38444 Mdot
.79403 .60042 Mdot
.29544 .2021 Mdot
.48169 .31832 Mdot
0 .989 1 r
.5 Mabswid
.413 .43488 m
.48169 .31832 L
s
.801 1 0 r
.43866 .45572 m
.55889 .37655 L
s
0 0 0 r
2.5 Mabswid
.43866 .45572 Mdot
1 .098 0 r
.5 Mabswid
.62516 .4445 m
.43866 .45572 L
s
1 .17 0 r
.15136 .34669 m
.43642 .45214 L
s
1 .097 0 r
.65577 .49561 m
.61551 .44458 L
s
0 0 0 r
2.5 Mabswid
.65577 .49561 Mdot
.46385 .53434 Mdot
0 1 .326 r
.5 Mabswid
.51344 .52626 m
.46385 .53434 L
s
.81 1 0 r
.60043 .38893 m
.42147 .48838 L
s
0 0 0 r
2.5 Mabswid
.60043 .38893 Mdot
0 1 .72 r
.5 Mabswid
.4336 .39178 m
.24932 .28731 L
s
0 1 .935 r
.4336 .39178 m
.46058 .33397 L
s
0 0 0 r
2.5 Mabswid
.4336 .39178 Mdot
.15358 .33998 Mdot
1 .169 0 r
.5 Mabswid
.43378 .445 m
.15358 .33998 L
s
0 g
.48628 .60509 m
.48032 .61917 L
s
.44592 .5666 m
.48628 .60509 L
s
.48042 .61901 m
.48625 .60508 L
s
.48628 .60513 m
.48628 .60513 L
s
.44592 .56664 m
.48628 .60513 L
s
1 .116 0 r
.44831 .48792 m
.62096 .42838 L
s
0 0 0 r
2.5 Mabswid
.44831 .48792 Mdot
.806 1 0 r
.5 Mabswid
.60695 .39361 m
.42297 .49663 L
s
0 0 0 r
2.5 Mabswid
.60695 .39361 Mdot
1 .116 0 r
.5 Mabswid
.65637 .4943 m
.57706 .44488 L
s
0 0 0 r
2.5 Mabswid
.65637 .4943 Mdot
.385 1 0 r
.5 Mabswid
.43642 .45214 m
.5355 .37829 L
s
0 0 0 r
2.5 Mabswid
.43642 .45214 Mdot
1 .116 0 r
.5 Mabswid
.67066 .44004 m
.43642 .45214 L
s
0 .538 1 r
.57208 .66791 m
.57858 .6717 L
s
0 0 0 r
2.5 Mabswid
.57208 .66791 Mdot
.16008 .33493 Mdot
1 .168 0 r
.5 Mabswid
.43114 .43785 m
.16008 .33493 L
s
.803 1 0 r
.61346 .3983 m
.42449 .50493 L
s
0 0 0 r
2.5 Mabswid
.61346 .3983 Mdot
.378 1 0 r
.5 Mabswid
.43378 .445 m
.5289 .37349 L
s
0 0 0 r
2.5 Mabswid
.43378 .445 Mdot
1 .116 0 r
.5 Mabswid
.65976 .43341 m
.43378 .445 L
s
.2 0 1 r
.64853 .52096 m
.63273 .53595 L
s
0 0 0 r
2.5 Mabswid
.64853 .52096 Mdot
.16652 .32992 Mdot
1 .168 0 r
.5 Mabswid
.42849 .43069 m
.16652 .32992 L
s
.37 1 0 r
.43114 .43785 m
.52233 .36871 L
s
0 0 0 r
2.5 Mabswid
.43114 .43785 Mdot
1 .116 0 r
.5 Mabswid
.64884 .42676 m
.43114 .43785 L
s
0 0 0 r
2.5 Mabswid
.5464 .35458 Mdot
0 .989 1 r
.5 Mabswid
.43509 .35428 m
.5464 .35458 L
s
.045 1 0 r
.44325 .35592 m
.5169 .50935 L
s
0 0 0 r
2.5 Mabswid
.44325 .35592 Mdot
.6462 .52837 Mdot
1 .092 0 r
.5 Mabswid
.54345 .41004 m
.6462 .52837 L
s
.364 1 0 r
.42849 .43069 m
.51578 .36394 L
s
0 0 0 r
2.5 Mabswid
.42849 .43069 Mdot
1 .116 0 r
.5 Mabswid
.63789 .4201 m
.42849 .43069 L
s
0 .542 1 r
.5233 .63588 m
.43918 .54853 L
s
0 0 0 r
2.5 Mabswid
.5233 .63588 Mdot
.64629 .5281 Mdot
1 .115 0 r
.5 Mabswid
.59511 .42187 m
.64629 .5281 L
s
0 0 0 r
2.5 Mabswid
.65021 .51584 Mdot
0 .595 1 r
.5 Mabswid
.42977 .38503 m
.65021 .51584 L
s
.871 1 0 r
.61393 .61133 m
.65594 .67225 L
s
0 .538 1 r
.61393 .61133 m
.44203 .55018 L
s
0 0 0 r
2.5 Mabswid
.61393 .61133 Mdot
.865 1 0 r
.5 Mabswid
.65376 .45352 m
.6086 .40105 L
s
0 0 0 r
2.5 Mabswid
.65376 .45352 Mdot
.46691 .55049 Mdot
0 .298 1 r
.5 Mabswid
.52977 .58506 m
.46691 .55049 L
s
0 1 .632 r
.47457 .31536 m
.45595 .3162 L
s
0 0 0 r
2.5 Mabswid
.47457 .31536 Mdot
.88 1 0 r
.5 Mabswid
.65197 .4444 m
.49199 .50697 L
s
0 0 0 r
2.5 Mabswid
.65197 .4444 Mdot
.801 1 0 r
.5 Mabswid
.43562 .3797 m
.49722 .33775 L
s
0 0 0 r
2.5 Mabswid
.43562 .3797 Mdot
.865 1 0 r
.5 Mabswid
.42738 .42344 m
.62057 .4678 L
s
0 0 0 r
2.5 Mabswid
.42738 .42344 Mdot
1 .116 0 r
.5 Mabswid
.62692 .41342 m
.42738 .42344 L
s
1 .115 0 r
.44482 .4844 m
.61259 .42613 L
s
0 0 0 r
2.5 Mabswid
.44482 .4844 Mdot
0 1 .846 r
.5 Mabswid
.63706 .55628 m
.76242 .53047 L
s
0 0 0 r
2.5 Mabswid
.63706 .55628 Mdot
.658 .48879 Mdot
.06 1 0 r
.5 Mabswid
.62672 .51923 m
.658 .48879 L
s
.89 1 0 r
.42745 .41612 m
.61665 .45887 L
s
0 0 0 r
2.5 Mabswid
.42745 .41612 Mdot
1 .116 0 r
.5 Mabswid
.61593 .40673 m
.42745 .41612 L
s
0 0 0 r
2.5 Mabswid
.52807 .64059 Mdot
1 .728 0 r
.5 Mabswid
.58845 .62624 m
.52807 .64059 L
s
.797 1 0 r
.43498 .45545 m
.55338 .37732 L
s
0 0 0 r
2.5 Mabswid
.43498 .45545 Mdot
1 .097 0 r
.5 Mabswid
.61551 .44458 m
.43498 .45545 L
s
0 0 0 r
2.5 Mabswid
.62593 .58248 Mdot
0 1 .632 r
.5 Mabswid
.57446 .63688 m
.62593 .58248 L
s
0 0 0 r
2.5 Mabswid
.42851 .40875 Mdot
1 .116 0 r
.5 Mabswid
.6049 .40002 m
.42851 .40875 L
s
0 1 .632 r
.53089 .34696 m
.42187 .38589 L
s
0 0 0 r
2.5 Mabswid
.53089 .34696 Mdot
.4306 .44492 Mdot
0 .439 1 r
.5 Mabswid
.45086 .34183 m
.4306 .44492 L
s
1 .116 0 r
.65882 .48895 m
.58884 .44479 L
s
0 0 0 r
2.5 Mabswid
.65882 .48895 Mdot
.51696 .33955 Mdot
0 1 .381 r
.5 Mabswid
.47865 .52742 m
.51696 .33955 L
s
0 .175 1 r
.58987 .65508 m
.72566 .79883 L
s
0 0 0 r
2.5 Mabswid
.58987 .65508 Mdot
0 .38 1 r
.5 Mabswid
.51669 .35457 m
.58987 .65508 L
s
1 .098 0 r
.65912 .48829 m
.62516 .4445 L
s
0 0 0 r
2.5 Mabswid
.65912 .48829 Mdot
.43246 .39004 Mdot
0 .989 1 r
.5 Mabswid
.43461 .52372 m
.43246 .39004 L
s
0 0 0 r
2.5 Mabswid
.64899 .5203 Mdot
1 .093 0 r
.5 Mabswid
.55594 .4129 m
.64899 .5203 L
s
1 .115 0 r
.44133 .48086 m
.60407 .42393 L
s
0 0 0 r
2.5 Mabswid
.44133 .48086 Mdot
.93 1 0 r
.5 Mabswid
.2755 .75902 m
.492 .6165 L
s
.769 1 0 r
.61064 .6159 m
.76384 .68387 L
s
0 0 0 r
2.5 Mabswid
.61064 .6159 Mdot
0 g
.5 Mabswid
.67507 .44456 m
.65943 .48762 L
s
.65948 .48763 m
.67508 .44458 L
s
.46301 .31072 m
.45809 .31257 L
s
.45809 .31257 m
.4333 .33524 L
s
.45809 .31256 m
.4333 .33523 L
s
.45808 .31257 m
.463 .31073 L
s
0 0 0 r
2.5 Mabswid
.64957 .51862 Mdot
1 .115 0 r
.5 Mabswid
.60407 .42393 m
.64957 .51862 L
s
0 0 0 r
2.5 Mabswid
.44826 .33778 Mdot
0 .989 1 r
.5 Mabswid
.50584 .45779 m
.44826 .33778 L
s
0 .31 1 r
.64844 .43567 m
.72183 .44622 L
s
0 .149 1 r
.64844 .43567 m
.5051 .62253 L
s
0 0 0 r
2.5 Mabswid
.64844 .43567 Mdot
0 .538 1 r
.5 Mabswid
.57858 .6717 m
.5801 .6689 L
s
0 0 0 r
2.5 Mabswid
.57858 .6717 Mdot
.6236 .58704 Mdot
.793 1 0 r
.5 Mabswid
.41994 .40586 m
.6236 .58704 L
s
0 1 .532 r
.60463 .62564 m
.4185 .45099 L
s
0 0 0 r
2.5 Mabswid
.60463 .62564 Mdot
0 .542 1 r
.5 Mabswid
.59137 .65005 m
.42341 .37931 L
s
0 0 0 r
2.5 Mabswid
.59137 .65005 Mdot
.61972 .59612 Mdot
.789 1 0 r
.5 Mabswid
.41758 .41615 m
.61972 .59612 L
s
0 0 0 r
2.5 Mabswid
.57764 .6734 Mdot
0 .137 1 r
.5 Mabswid
.57753 .67197 m
.57764 .6734 L
s
0 0 0 r
2.5 Mabswid
.46586 .31221 Mdot
0 1 .532 r
.5 Mabswid
.44965 .33193 m
.46586 .31221 L
s
0 0 0 r
2.5 Mabswid
.57753 .67197 Mdot
0 .038 1 r
.5 Mabswid
.51373 .34063 m
.57753 .67197 L
s
0 0 0 r
2.5 Mabswid
.61543 .60489 Mdot
.778 1 0 r
.5 Mabswid
.41522 .42648 m
.61543 .60489 L
s
0 g
.46299 .31071 m
.43834 .33334 L
s
.61393 .40139 m
.46299 .31071 L
s
.43837 .33335 m
.46301 .31072 L
s
.46298 .31071 m
.61392 .4014 L
s
.797 1 0 r
.43397 .38041 m
.49334 .33998 L
s
0 0 0 r
2.5 Mabswid
.43397 .38041 Mdot
.793 1 0 r
.5 Mabswid
.43126 .45517 m
.54721 .37851 L
s
0 0 0 r
2.5 Mabswid
.43126 .45517 Mdot
1 .097 0 r
.5 Mabswid
.60578 .44466 m
.43126 .45517 L
s
0 g
.41218 .43043 m
.4229 .42936 L
s
.4229 .42936 m
.41891 .49191 L
s
.4229 .42939 m
.41217 .43046 L
s
.42288 .42933 m
.41888 .49187 L
s
0 0 0 r
2.5 Mabswid
.21834 .29177 Mdot
0 .2 1 r
.5 Mabswid
.46485 .55972 m
.43286 .3618 L
s
0 0 0 r
2.5 Mabswid
.46485 .55972 Mdot
0 .327 1 r
.5 Mabswid
.56866 .36888 m
.55402 .51432 L
s
0 0 0 r
2.5 Mabswid
.56866 .36888 Mdot
0 1 .632 r
.5 Mabswid
.45595 .3162 m
.50065 .37387 L
s
0 0 0 r
2.5 Mabswid
.45595 .3162 Mdot
1 .115 0 r
.5 Mabswid
.43781 .47731 m
.59511 .42187 L
s
0 0 0 r
2.5 Mabswid
.43781 .47731 Mdot
0 .957 1 r
.5 Mabswid
.57414 .67286 m
.57385 .68036 L
s
0 0 0 r
2.5 Mabswid
.57414 .67286 Mdot
.333 1 0 r
.5 Mabswid
.43023 .45427 m
.45929 .49128 L
s
0 0 0 r
2.5 Mabswid
.43023 .45427 Mdot
.44965 .33193 Mdot
0 1 .532 r
.5 Mabswid
.43128 .5125 m
.44965 .33193 L
s
0 1 .394 r
.62574 .40653 m
.59209 .46079 L
s
0 0 0 r
2.5 Mabswid
.62574 .40653 Mdot
0 .538 1 r
.5 Mabswid
.5801 .6689 m
.56324 .50966 L
s
0 0 0 r
2.5 Mabswid
.5801 .6689 Mdot
1 .116 0 r
.5 Mabswid
.66086 .48368 m
.59397 .39345 L
s
0 0 0 r
2.5 Mabswid
.66086 .48368 Mdot
0 .149 1 r
.5 Mabswid
.44845 .33471 m
.4841 .32319 L
s
0 0 0 r
2.5 Mabswid
.44845 .33471 Mdot
0 .149 1 r
.5 Mabswid
.5949 .58976 m
.44845 .33471 L
s
.76 1 0 r
.60629 .61996 m
.7623 .69024 L
s
0 0 0 r
2.5 Mabswid
.60629 .61996 Mdot
0 g
.5 Mabswid
.6325 .41101 m
.67417 .44198 L
s
.67416 .44197 m
.63246 .41104 L
s
0 0 0 r
2.5 Mabswid
.54904 .35849 Mdot
0 .538 1 r
.5 Mabswid
.43767 .34028 m
.54904 .35849 L
s
0 0 0 r
2.5 Mabswid
.65178 .51222 Mdot
1 .093 0 r
.5 Mabswid
.5684 .41576 m
.65178 .51222 L
s
0 0 0 r
2.5 Mabswid
.62037 .14654 Mdot
.4841 .32319 Mdot
.56528 .36787 Mdot
0 .542 1 r
.5 Mabswid
.44281 .32873 m
.56528 .36787 L
s
0 0 0 r
2.5 Mabswid
.45421 .53459 Mdot
0 .149 1 r
.5 Mabswid
.49243 .62284 m
.45421 .53459 L
s
0 0 0 r
2.5 Mabswid
.42793 .21902 Mdot
.757 1 0 r
.5 Mabswid
.41463 .41848 m
.42793 .21902 L
s
0 .272 1 r
.59963 .38958 m
.65074 .4542 L
s
0 0 0 r
2.5 Mabswid
.59963 .38958 Mdot
.63408 .56101 Mdot
0 1 .711 r
.5 Mabswid
.42772 .49505 m
.63408 .56101 L
s
1 .115 0 r
.43427 .47373 m
.58615 .41982 L
s
0 0 0 r
2.5 Mabswid
.43427 .47373 Mdot
.789 1 0 r
.5 Mabswid
.42751 .45489 m
.5408 .37984 L
s
0 0 0 r
2.5 Mabswid
.42751 .45489 Mdot
1 .097 0 r
.5 Mabswid
.59596 .44473 m
.42751 .45489 L
s
0 0 0 r
2.5 Mabswid
.65385 .50618 Mdot
0 1 .766 r
.5 Mabswid
.42204 .41865 m
.65385 .50618 L
s
0 .092 1 r
.42542 .41276 m
.66268 .4808 L
s
0 0 0 r
2.5 Mabswid
.42542 .41276 Mdot
0 1 .832 r
.5 Mabswid
.67117 .45138 m
.42542 .41276 L
s
0 .989 1 r
.588 .65033 m
.54298 .65781 L
s
0 0 0 r
2.5 Mabswid
.588 .65033 Mdot
0 .989 1 r
.5 Mabswid
.57327 .67302 m
.52445 .64442 L
s
0 0 0 r
2.5 Mabswid
.57327 .67302 Mdot
.918 1 0 r
.5 Mabswid
.60192 .62406 m
.76074 .6967 L
s
0 0 0 r
2.5 Mabswid
.60192 .62406 Mdot
0 .645 1 r
.5 Mabswid
.43444 .37168 m
.27532 .28099 L
s
0 1 .975 r
.43444 .37168 m
.4526 .33176 L
s
0 0 0 r
2.5 Mabswid
.43444 .37168 Mdot
1 .116 0 r
.5 Mabswid
.66278 .47841 m
.6049 .40002 L
s
0 0 0 r
2.5 Mabswid
.66278 .47841 Mdot
.65458 .50412 Mdot
1 .094 0 r
.5 Mabswid
.58083 .4186 m
.65458 .50412 L
s
0 1 .599 r
.492 .6165 m
.61521 .41936 L
s
0 0 0 r
2.5 Mabswid
.492 .6165 Mdot
.806 1 0 r
.5 Mabswid
.67082 .44655 m
.492 .6165 L
s
.045 1 0 r
.55229 .36157 m
.53949 .35905 L
s
0 0 0 r
2.5 Mabswid
.55229 .36157 Mdot
.64675 .42729 Mdot
0 1 .67 r
.5 Mabswid
.66878 .46314 m
.64675 .42729 L
s
0 .989 1 r
.54298 .65781 m
.51852 .40104 L
s
0 0 0 r
2.5 Mabswid
.54298 .65781 Mdot
.797 1 0 r
.5 Mabswid
.49897 .62238 m
.5799 .61392 L
s
0 0 0 r
2.5 Mabswid
.49897 .62238 Mdot
1 .115 0 r
.5 Mabswid
.43072 .47014 m
.57719 .41777 L
s
0 0 0 r
2.5 Mabswid
.43072 .47014 Mdot
.51373 .34063 Mdot
.50654 .33671 Mdot
1 .728 0 r
.5 Mabswid
.57565 .64586 m
.50654 .33671 L
s
0 0 0 r
2.5 Mabswid
.76242 .53047 Mdot
0 g
.5 Mabswid
.39689 .13256 m
.57733 .05514 L
s
.35892 .58214 m
.39689 .13256 L
s
0 0 0 r
2.5 Mabswid
.57385 .68036 Mdot
0 .449 1 r
.5 Mabswid
.42104 .42887 m
.55801 .39547 L
s
0 0 0 r
2.5 Mabswid
.42104 .42887 Mdot
.48083 .60633 Mdot
0 1 .632 r
.5 Mabswid
.52908 .60566 m
.48083 .60633 L
s
0 0 0 r
2.5 Mabswid
.48828 .3287 Mdot
0 .989 1 r
.5 Mabswid
.41811 .41942 m
.48828 .3287 L
s
0 1 .128 r
.66229 .46056 m
.61982 .42428 L
s
0 0 0 r
2.5 Mabswid
.66229 .46056 Mdot
1 .99 0 r
.5 Mabswid
.4235 .4162 m
.63516 .54973 L
s
0 0 0 r
2.5 Mabswid
.4235 .4162 Mdot
1 .116 0 r
.5 Mabswid
.59397 .39345 m
.4235 .4162 L
s
.778 1 0 r
.42372 .4546 m
.53434 .38118 L
s
0 0 0 r
2.5 Mabswid
.42372 .4546 Mdot
1 .096 0 r
.5 Mabswid
.58606 .44481 m
.42372 .4546 L
s
0 .498 1 r
.42258 .42025 m
.54844 .3891 L
s
0 0 0 r
2.5 Mabswid
.42258 .42025 Mdot
0 1 .632 r
.5 Mabswid
.5077 .33877 m
.41631 .41101 L
s
0 0 0 r
2.5 Mabswid
.5077 .33877 Mdot
.66347 .46709 Mdot
0 .588 1 r
.5 Mabswid
.63551 .49041 m
.66347 .46709 L
s
0 0 0 r
2.5 Mabswid
.46711 .58752 Mdot
1 .728 0 r
.5 Mabswid
.56232 .56949 m
.46711 .58752 L
s
0 .989 1 r
.52445 .64442 m
.46099 .58437 L
s
0 0 0 r
2.5 Mabswid
.52445 .64442 Mdot
1 .115 0 r
.5 Mabswid
.42714 .46652 m
.56823 .41572 L
s
0 0 0 r
2.5 Mabswid
.42714 .46652 Mdot
0 .038 1 r
.5 Mabswid
.57299 .37406 m
.549 .50156 L
s
0 0 0 r
2.5 Mabswid
.57299 .37406 Mdot
0 1 .284 r
.5 Mabswid
.64655 .42388 m
.61169 .43196 L
s
0 0 0 r
2.5 Mabswid
.64655 .42388 Mdot
.65738 .496 Mdot
1 .094 0 r
.5 Mabswid
.59322 .42144 m
.65738 .496 L
s
1 .116 0 r
.66471 .47308 m
.61593 .40673 L
s
0 0 0 r
2.5 Mabswid
.66471 .47308 Mdot
0 1 .003 r
.5 Mabswid
.66449 .47004 m
.61962 .43203 L
s
0 0 0 r
2.5 Mabswid
.66449 .47004 Mdot
0 .111 1 r
.5 Mabswid
.42412 .41158 m
.53892 .38277 L
s
0 0 0 r
2.5 Mabswid
.42412 .41158 Mdot
.64631 .52998 Mdot
1 .115 0 r
.5 Mabswid
.61259 .42613 m
.64631 .52998 L
s
.819 1 0 r
.43461 .49361 m
.51373 .51737 L
s
0 0 0 r
2.5 Mabswid
.43461 .49361 Mdot
.732 1 0 r
.5 Mabswid
.45924 .57109 m
.453 .5747 L
s
0 0 0 r
2.5 Mabswid
.45924 .57109 Mdot
.42977 .38503 Mdot
0 1 .928 r
.5 Mabswid
.53417 .37181 m
.42977 .38503 L
s
0 0 0 r
2.5 Mabswid
.43418 .49428 Mdot
.03 0 1 r
.5 Mabswid
.48155 .35198 m
.43418 .49428 L
s
0 0 0 r
2.5 Mabswid
.46004 .57437 Mdot
.333 1 0 r
.5 Mabswid
.43264 .53057 m
.46004 .57437 L
s
0 0 0 r
2.5 Mabswid
.61803 .58624 Mdot
.045 1 0 r
.5 Mabswid
.54626 .60238 m
.61803 .58624 L
s
0 0 0 r
2.5 Mabswid
.58431 .7235 Mdot
.4828 .32964 Mdot
0 .149 1 r
.5 Mabswid
.49781 .63179 m
.4828 .32964 L
s
0 0 0 r
2.5 Mabswid
.42204 .41865 Mdot
0 1 .003 r
.5 Mabswid
.61962 .43203 m
.42204 .41865 L
s
0 .364 1 r
.53542 .35423 m
.52758 .65557 L
s
0 0 0 r
2.5 Mabswid
.53542 .35423 Mdot
1 .115 0 r
.5 Mabswid
.42355 .46289 m
.55926 .41366 L
s
0 0 0 r
2.5 Mabswid
.42355 .46289 Mdot
.814 1 0 r
.5 Mabswid
.43613 .50229 m
.51344 .52626 L
s
0 0 0 r
2.5 Mabswid
.43613 .50229 Mdot
.60274 .61394 Mdot
.778 1 0 r
.5 Mabswid
.46335 .58927 m
.60274 .61394 L
s
.018 0 1 r
.64645 .42141 m
.65861 .48769 L
s
0 0 0 r
2.5 Mabswid
.64645 .42141 Mdot
.797 1 0 r
.5 Mabswid
.53891 .65791 m
.57234 .65469 L
s
0 0 0 r
2.5 Mabswid
.53891 .65791 Mdot
.699 1 0 r
.5 Mabswid
.42015 .42589 m
.45565 .40271 L
s
0 0 0 r
2.5 Mabswid
.42015 .42589 Mdot
.045 1 0 r
.5 Mabswid
.52775 .35156 m
.43759 .52354 L
s
0 0 0 r
2.5 Mabswid
.52775 .35156 Mdot
.42076 .45426 Mdot
1 .096 0 r
.5 Mabswid
.57605 .44489 m
.42076 .45426 L
s
0 0 0 r
2.5 Mabswid
.43308 .36798 Mdot
0 .989 1 r
.5 Mabswid
.43928 .35043 m
.43308 .36798 L
s
0 0 0 r
2.5 Mabswid
.49722 .33775 Mdot
.65029 .51885 Mdot
1 .116 0 r
.5 Mabswid
.62096 .42838 m
.65029 .51885 L
s
0 0 0 r
2.5 Mabswid
.66019 .48788 Mdot
1 .094 0 r
.5 Mabswid
.60558 .42427 m
.66019 .48788 L
s
0 .542 1 r
.42116 .42015 m
.50009 .3442 L
s
0 0 0 r
2.5 Mabswid
.42116 .42015 Mdot
0 .542 1 r
.5 Mabswid
.50325 .63265 m
.42116 .42015 L
s
1 .728 0 r
.54543 .66382 m
.57565 .64586 L
s
0 0 0 r
2.5 Mabswid
.54543 .66382 Mdot
.46824 .59226 Mdot
0 1 .453 r
.5 Mabswid
.446 .55282 m
.46824 .59226 L
s
1 .116 0 r
.66667 .4677 m
.62692 .41342 L
s
0 0 0 r
2.5 Mabswid
.66667 .4677 Mdot
.24932 .28731 Mdot
.699 1 0 r
.5 Mabswid
.60271 .39288 m
.48491 .49056 L
s
0 0 0 r
2.5 Mabswid
.60271 .39288 Mdot
.819 1 0 r
.5 Mabswid
.42056 .45899 m
.18587 .40945 L
s
1 .094 0 r
.42056 .45899 m
.60558 .42427 L
s
0 0 0 r
2.5 Mabswid
.42056 .45899 Mdot
.42094 .41959 Mdot
0 1 .381 r
.5 Mabswid
.47266 .42618 m
.42094 .41959 L
s
.045 1 0 r
.53949 .35905 m
.42103 .38724 L
s
0 0 0 r
2.5 Mabswid
.53949 .35905 Mdot
.63516 .54973 Mdot
.41903 .43801 Mdot
.136 0 1 r
.5 Mabswid
.46058 .33397 m
.41903 .43801 L
s
0 0 0 r
2.5 Mabswid
.42694 .24628 Mdot
.757 1 0 r
.5 Mabswid
.41591 .41223 m
.42694 .24628 L
s
0 1 .381 r
.46423 .58746 m
.47266 .42618 L
s
0 0 0 r
2.5 Mabswid
.46423 .58746 Mdot
.44348 .53485 Mdot
0 .542 1 r
.5 Mabswid
.55491 .4748 m
.44348 .53485 L
s
0 0 0 r
2.5 Mabswid
.42975 .37935 Mdot
0 1 .754 r
.5 Mabswid
.52122 .36777 m
.42975 .37935 L
s
.435 1 0 r
.61003 .39786 m
.50287 .48774 L
s
0 0 0 r
2.5 Mabswid
.61003 .39786 Mdot
0 1 .381 r
.5 Mabswid
.45216 .56242 m
.50517 .38018 L
s
0 0 0 r
2.5 Mabswid
.45216 .56242 Mdot
0 1 .381 r
.5 Mabswid
.56346 .64674 m
.45216 .56242 L
s
.813 1 0 r
.66724 .46097 m
.65811 .44119 L
s
0 0 0 r
2.5 Mabswid
.66724 .46097 Mdot
0 1 .36 r
.5 Mabswid
.54771 .36384 m
.61977 .1402 L
s
0 0 0 r
2.5 Mabswid
.54771 .36384 Mdot
.65415 .5073 Mdot
1 .116 0 r
.5 Mabswid
.62933 .43063 m
.65415 .5073 L
s
0 0 0 r
2.5 Mabswid
.62847 .56058 Mdot
.699 1 0 r
.5 Mabswid
.54668 .54633 m
.62847 .56058 L
s
0 0 0 r
2.5 Mabswid
.43509 .35428 Mdot
0 .989 1 r
.5 Mabswid
.52357 .39845 m
.43509 .35428 L
s
0 0 0 r
2.5 Mabswid
.65209 .51389 Mdot
.89 1 0 r
.5 Mabswid
.61665 .45887 m
.65209 .51389 L
s
.103 1 0 r
.58692 .38428 m
.51887 .22296 L
s
0 1 .595 r
.58692 .38428 m
.44218 .54257 L
s
0 0 0 r
2.5 Mabswid
.58692 .38428 Mdot
.371 1 0 r
.5 Mabswid
.61737 .40286 m
.5206 .48494 L
s
0 0 0 r
2.5 Mabswid
.61737 .40286 Mdot
0 1 .381 r
.5 Mabswid
.60038 .61175 m
.44529 .49145 L
s
0 0 0 r
2.5 Mabswid
.60038 .61175 Mdot
.778 1 0 r
.5 Mabswid
.43244 .36527 m
.47181 .36451 L
s
0 0 0 r
2.5 Mabswid
.43244 .36527 Mdot
.019 0 1 r
.5 Mabswid
.66268 .4808 m
.74172 .50008 L
s
0 0 0 r
2.5 Mabswid
.66268 .4808 Mdot
.49334 .33998 Mdot
0 .989 1 r
.5 Mabswid
.46099 .58437 m
.43207 .52851 L
s
0 0 0 r
2.5 Mabswid
.46099 .58437 Mdot
.045 1 0 r
.5 Mabswid
.43759 .52354 m
.52908 .60566 L
s
0 0 0 r
2.5 Mabswid
.43759 .52354 Mdot
.514 1 0 r
.5 Mabswid
.61649 .40239 m
.47719 .6026 L
s
0 0 0 r
2.5 Mabswid
.61649 .40239 Mdot
.817 1 0 r
.5 Mabswid
.41921 .45438 m
.19431 .40627 L
s
1 .094 0 r
.41921 .45438 m
.59322 .42144 L
s
0 0 0 r
2.5 Mabswid
.41921 .45438 Mdot
.778 1 0 r
.5 Mabswid
.5213 .64675 m
.58086 .6439 L
s
0 0 0 r
2.5 Mabswid
.5213 .64675 Mdot
.778 1 0 r
.5 Mabswid
.47181 .36451 m
.5213 .64675 L
s
1 .116 0 r
.66864 .46227 m
.63789 .4201 L
s
0 0 0 r
2.5 Mabswid
.66864 .46227 Mdot
.42772 .49505 Mdot
0 1 .711 r
.5 Mabswid
.45565 .40271 m
.42772 .49505 L
s
0 1 .532 r
.52704 .65165 m
.51258 .38281 L
s
0 0 0 r
2.5 Mabswid
.52704 .65165 Mdot
0 1 .532 r
.5 Mabswid
.58055 .64309 m
.52704 .65165 L
s
.514 1 0 r
.62353 .40711 m
.48327 .61019 L
s
0 0 0 r
2.5 Mabswid
.62353 .40711 Mdot
.703 1 0 r
.5 Mabswid
.19457 .59589 m
.41891 .45314 L
s
0 1 .063 r
.41891 .45314 m
.63486 .48239 L
s
0 0 0 r
2.5 Mabswid
.41891 .45314 Mdot
.865 1 0 r
.5 Mabswid
.6086 .40105 m
.41891 .45314 L
s
0 0 0 r
2.5 Mabswid
.50009 .3442 Mdot
.50325 .63265 Mdot
0 .542 1 r
.5 Mabswid
.5718 .64774 m
.50325 .63265 L
s
0 g
.65284 .5118 m
.56119 .67596 L
s
.67487 .44534 m
.65284 .5118 L
s
.65286 .51174 m
.56121 .67591 L
s
.65288 .51182 m
.67486 .44535 L
s
0 1 .643 r
.4311 .36865 m
.45086 .34183 L
s
0 0 0 r
2.5 Mabswid
.4311 .36865 Mdot
.65802 .49574 Mdot
1 .116 0 r
.5 Mabswid
.63769 .43287 m
.65802 .49574 L
s
.388 1 0 r
.60548 .59944 m
.60316 .5529 L
s
0 0 0 r
2.5 Mabswid
.60548 .59944 Mdot
0 1 .595 r
.5 Mabswid
.44218 .54257 m
.52977 .58506 L
s
0 0 0 r
2.5 Mabswid
.44218 .54257 Mdot
0 1 .453 r
.5 Mabswid
.42265 .48219 m
.43218 .51191 L
s
0 0 0 r
2.5 Mabswid
.42265 .48219 Mdot
.46867 .5968 Mdot
.045 1 0 r
.5 Mabswid
.5169 .50935 m
.46867 .5968 L
s
0 0 0 r
2.5 Mabswid
.47093 .60029 Mdot
0 .932 1 r
.5 Mabswid
.61723 .45212 m
.47093 .60029 L
s
0 0 0 r
2.5 Mabswid
.42973 .37363 Mdot
0 1 .653 r
.5 Mabswid
.50818 .36369 m
.42973 .37363 L
s
0 0 0 r
2.5 Mabswid
.422 .40766 Mdot
0 .029 1 r
.5 Mabswid
.4526 .33176 m
.422 .40766 L
s
0 0 0 r
2.5 Mabswid
.58086 .6439 Mdot
0 1 .37 r
.5 Mabswid
.54714 .36757 m
.61863 .146 L
s
0 0 0 r
2.5 Mabswid
.54714 .36757 Mdot
.44281 .32873 Mdot
.388 1 0 r
.5 Mabswid
.46672 .33906 m
.44281 .32873 L
s
0 0 0 r
2.5 Mabswid
.43128 .5125 Mdot
0 1 .532 r
.5 Mabswid
.47027 .59935 m
.43128 .5125 L
s
0 0 0 r
2.5 Mabswid
.42809 .37949 Mdot
0 .829 1 r
.5 Mabswid
.48292 .36374 m
.42809 .37949 L
s
.815 1 0 r
.41784 .44973 m
.20273 .4031 L
s
1 .094 0 r
.41784 .44973 m
.58083 .4186 L
s
0 0 0 r
2.5 Mabswid
.41784 .44973 Mdot
.58055 .64309 Mdot
0 .547 1 r
.5 Mabswid
.51669 .35457 m
.62176 .2335 L
s
0 0 0 r
2.5 Mabswid
.51669 .35457 Mdot
.4282 .37781 Mdot
1 .886 0 r
.5 Mabswid
.51071 .39069 m
.4282 .37781 L
s
0 .989 1 r
.61186 .58382 m
.41989 .39396 L
s
0 0 0 r
2.5 Mabswid
.61186 .58382 Mdot
.66188 .48417 Mdot
1 .116 0 r
.5 Mabswid
.64605 .43512 m
.66188 .48417 L
s
0 0 0 r
2.5 Mabswid
.72566 .79883 Mdot
.43767 .34028 Mdot
0 .538 1 r
.5 Mabswid
.4887 .37515 m
.43767 .34028 L
s
1 .116 0 r
.67063 .45678 m
.64884 .42676 L
s
0 0 0 r
2.5 Mabswid
.67063 .45678 Mdot
0 .538 1 r
.5 Mabswid
.44203 .55018 m
.45465 .45217 L
s
0 0 0 r
2.5 Mabswid
.44203 .55018 Mdot
.741 1 0 r
.5 Mabswid
.46876 .59879 m
.42909 .35384 L
s
0 0 0 r
2.5 Mabswid
.46876 .59879 Mdot
.741 1 0 r
.5 Mabswid
.5718 .65608 m
.46876 .59879 L
s
0 g
.55608 .67729 m
.56124 .67588 L
s
.51865 .65515 m
.55608 .67729 L
s
.55609 .6773 m
.4803 .61915 L
s
.51866 .65515 m
.55609 .6773 L
s
.55609 .67731 m
.48042 .61901 L
s
.56123 .67588 m
.55606 .67729 L
s
0 0 0 r
2.5 Mabswid
.58845 .62624 Mdot
0 g
.5 Mabswid
.43834 .33334 m
.61393 .40139 L
s
.67357 .44168 m
.61387 .40137 L
s
.6139 .40132 m
.67358 .44167 L
s
.43829 .33331 m
.6139 .40132 L
s
0 0 0 r
2.5 Mabswid
.27532 .28099 Mdot
0 g
.5 Mabswid
.42955 .53406 m
.44593 .5666 L
s
.44593 .5666 m
.48033 .61918 L
s
0 0 0 r
2.5 Mabswid
.5718 .65608 Mdot
0 g
.5 Mabswid
.44594 .56663 m
.4294 .53419 L
s
.4189 .49187 m
.44594 .56663 L
s
.48032 .61917 m
.44592 .5666 L
s
.41888 .49187 m
.44592 .56664 L
s
.56123 .67591 m
.6344 .50402 L
s
.52392 .65369 m
.56123 .67591 L
s
.56124 .67588 m
.52393 .65366 L
s
.56119 .67596 m
.63441 .50409 L
s
0 0 0 r
2.5 Mabswid
.67117 .45138 Mdot
0 1 .832 r
.5 Mabswid
.61017 .47971 m
.67117 .45138 L
s
0 0 0 r
2.5 Mabswid
.57234 .65469 Mdot
.41652 .42654 Mdot
0 .538 1 r
.5 Mabswid
.54357 .47937 m
.41652 .42654 L
s
0 0 0 r
2.5 Mabswid
.67082 .44655 Mdot
.806 1 0 r
.5 Mabswid
.65311 .43109 m
.67082 .44655 L
s
0 0 0 r
2.5 Mabswid
.74172 .50008 Mdot
.42971 .36787 Mdot
0 1 .542 r
.5 Mabswid
.49504 .35959 m
.42971 .36787 L
s
0 0 0 r
2.5 Mabswid
.55889 .37655 Mdot
.813 1 0 r
.5 Mabswid
.41646 .44503 m
.21114 .39993 L
s
1 .093 0 r
.41646 .44503 m
.5684 .41576 L
s
0 0 0 r
2.5 Mabswid
.41646 .44503 Mdot
0 .881 1 r
.5 Mabswid
.54656 .37133 m
.61748 .15184 L
s
0 0 0 r
2.5 Mabswid
.54656 .37133 Mdot
.66575 .47259 Mdot
1 .116 0 r
.5 Mabswid
.6544 .43736 m
.66575 .47259 L
s
0 0 0 r
2.5 Mabswid
.59397 .39345 Mdot
.65238 .50098 Mdot
0 .739 1 r
.5 Mabswid
.42278 .4882 m
.65238 .50098 L
s
0 0 0 r
2.5 Mabswid
.66878 .46314 Mdot
0 1 .67 r
.5 Mabswid
.6183 .48671 m
.66878 .46314 L
s
0 .364 1 r
.52758 .65557 m
.57269 .64374 L
s
0 0 0 r
2.5 Mabswid
.52758 .65557 Mdot
.57565 .64586 Mdot
.49781 .63179 Mdot
0 .149 1 r
.5 Mabswid
.56702 .62625 m
.49781 .63179 L
s
0 0 0 r
2.5 Mabswid
.6086 .40105 Mdot
0 .542 1 r
.5 Mabswid
.43918 .54853 m
.44019 .3908 L
s
0 0 0 r
2.5 Mabswid
.43918 .54853 Mdot
0 .989 1 r
.5 Mabswid
.43207 .52851 m
.41736 .47004 L
s
0 0 0 r
2.5 Mabswid
.43207 .52851 Mdot
0 g
.5 Mabswid
.83714 .79854 m
.57635 .51403 L
s
0 .989 1 r
.55228 .67501 m
.55238 .6749 L
s
0 0 0 r
2.5 Mabswid
.55228 .67501 Mdot
0 1 .391 r
.5 Mabswid
.22948 .70553 m
.43041 .52947 L
s
0 0 0 r
2.5 Mabswid
.65861 .48769 Mdot
.6049 .40002 Mdot
0 .989 1 r
.5 Mabswid
.55238 .6749 m
.5539 .66705 L
s
0 0 0 r
2.5 Mabswid
.55238 .6749 Mdot
.2 0 1 r
.5 Mabswid
.63273 .53595 m
.52698 .53514 L
s
0 0 0 r
2.5 Mabswid
.63273 .53595 Mdot
1 .116 0 r
.5 Mabswid
.67265 .45124 m
.65976 .43341 L
s
0 0 0 r
2.5 Mabswid
.67265 .45124 Mdot
.42594 .27415 Mdot
.756 1 0 r
.5 Mabswid
.41721 .40587 m
.42594 .27415 L
s
0 g
.41236 .4304 m
.4189 .49189 L
s
.4189 .49189 m
.42941 .53422 L
s
.4294 .53419 m
.4189 .49187 L
s
.41891 .49191 m
.41218 .43043 L
s
0 1 .632 r
.49952 .35156 m
.41722 .44074 L
s
0 0 0 r
2.5 Mabswid
.49952 .35156 Mdot
.61593 .40673 Mdot
.42787 .51743 Mdot
.741 1 0 r
.5 Mabswid
.56877 .54389 m
.42787 .51743 L
s
0 .918 1 r
.46058 .33397 m
.53233 .17158 L
s
0 0 0 r
2.5 Mabswid
.46058 .33397 Mdot
0 .13 1 r
.5 Mabswid
.4217 .3989 m
.48931 .37401 L
s
0 0 0 r
2.5 Mabswid
.4217 .3989 Mdot
0 g
.5 Mabswid
.51867 .65517 m
.48031 .61916 L
s
.48031 .61916 m
.47969 .60475 L
s
.48033 .61918 m
.47971 .60477 L
s
.4803 .61915 m
.51866 .65515 L
s
0 0 0 r
2.5 Mabswid
.5718 .64774 Mdot
.8 1 0 r
.5 Mabswid
.58379 .62567 m
.52988 .65799 L
s
0 0 0 r
2.5 Mabswid
.58379 .62567 Mdot
.66963 .46099 Mdot
1 .116 0 r
.5 Mabswid
.66274 .4396 m
.66963 .46099 L
s
0 0 0 r
2.5 Mabswid
.55338 .37732 Mdot
.62692 .41342 Mdot
.72183 .44622 Mdot
.321 1 0 r
.5 Mabswid
.17483 .60227 m
.52988 .65799 L
s
.142 1 0 r
.52988 .65799 m
.60381 .4159 L
s
0 0 0 r
2.5 Mabswid
.52988 .65799 Mdot
.41994 .40586 Mdot
.793 1 0 r
.5 Mabswid
.49895 .378 m
.41994 .40586 L
s
.811 1 0 r
.41507 .44029 m
.21953 .39677 L
s
1 .093 0 r
.41507 .44029 m
.55594 .4129 L
s
0 0 0 r
2.5 Mabswid
.41507 .44029 Mdot
.41758 .41615 Mdot
.789 1 0 r
.5 Mabswid
.5057 .38515 m
.41758 .41615 L
s
0 0 0 r
2.5 Mabswid
.41522 .42648 Mdot
.778 1 0 r
.5 Mabswid
.51247 .39232 m
.41522 .42648 L
s
0 1 .989 r
.56079 .38131 m
.6578 .32048 L
s
0 0 0 r
2.5 Mabswid
.56079 .38131 Mdot
.62093 .55398 Mdot
.142 1 0 r
.5 Mabswid
.61215 .42282 m
.62093 .55398 L
s
0 0 0 r
2.5 Mabswid
.4209 .49831 Mdot
.069 0 1 r
.5 Mabswid
.47026 .34148 m
.4209 .49831 L
s
0 0 0 r
2.5 Mabswid
.57269 .64374 Mdot
.806 1 0 r
.5 Mabswid
.41575 .45281 m
.65311 .43109 L
s
0 0 0 r
2.5 Mabswid
.41575 .45281 Mdot
1 .116 0 r
.5 Mabswid
.58884 .44479 m
.41575 .45281 L
s
0 0 0 r
2.5 Mabswid
.63789 .4201 Mdot
0 .989 1 r
.5 Mabswid
.43837 .54783 m
.44443 .47431 L
s
0 0 0 r
2.5 Mabswid
.43837 .54783 Mdot
0 .42 1 r
.5 Mabswid
.4526 .33176 m
.51902 .17941 L
s
0 0 0 r
2.5 Mabswid
.4526 .33176 Mdot
1 .886 0 r
.5 Mabswid
.61479 .56282 m
.51071 .39069 L
s
0 0 0 r
2.5 Mabswid
.61479 .56282 Mdot
.46672 .33906 Mdot
.388 1 0 r
.5 Mabswid
.57423 .47255 m
.46672 .33906 L
s
0 0 0 r
2.5 Mabswid
.64884 .42676 Mdot
.57446 .63688 Mdot
0 1 .632 r
.5 Mabswid
.52847 .65974 m
.57446 .63688 L
s
0 1 .532 r
.53538 .66268 m
.55911 .652 L
s
0 0 0 r
2.5 Mabswid
.53538 .66268 Mdot
0 .149 1 r
.5 Mabswid
.42913 .36245 m
.43937 .33764 L
s
0 0 0 r
2.5 Mabswid
.42913 .36245 Mdot
1 .116 0 r
.5 Mabswid
.67468 .44563 m
.67066 .44004 L
s
0 0 0 r
2.5 Mabswid
.67468 .44563 Mdot
.67351 .44938 Mdot
1 .116 0 r
.5 Mabswid
.67108 .44184 m
.67351 .44938 L
s
0 1 .858 r
.47026 .34148 m
.54957 .18109 L
s
0 0 0 r
2.5 Mabswid
.47026 .34148 Mdot
.65976 .43341 Mdot
0 g
.5 Mabswid
.67477 .44318 m
.67414 .44196 L
s
.67506 .44459 m
.67477 .44318 L
s
.67479 .44319 m
.67416 .44197 L
s
.67508 .44458 m
.67478 .44316 L
s
0 0 0 r
2.5 Mabswid
.42495 .51099 Mdot
.089 0 1 r
.5 Mabswid
.47597 .34658 m
.42495 .51099 L
s
0 g
.67485 .44538 m
.67506 .44459 L
s
0 0 0 r
2.5 Mabswid
.53417 .37181 Mdot
0 g
.5 Mabswid
.67486 .44535 m
.67507 .44456 L
s
.67414 .44196 m
.67354 .44166 L
s
.67417 .44198 m
.67357 .44168 L
s
0 0 0 r
2.5 Mabswid
.54721 .37851 Mdot
.54506 .67054 Mdot
0 1 .632 r
.5 Mabswid
.54891 .66176 m
.54506 .67054 L
s
0 0 0 r
2.5 Mabswid
.65311 .43109 Mdot
.809 1 0 r
.5 Mabswid
.41366 .43549 m
.22792 .39361 L
s
1 .092 0 r
.41366 .43549 m
.54345 .41004 L
s
0 0 0 r
2.5 Mabswid
.41366 .43549 Mdot
0 g
.5 Mabswid
.67425 .44508 m
.67485 .44538 L
s
.67427 .44504 m
.67487 .44534 L
s
0 0 0 r
2.5 Mabswid
.67066 .44004 Mdot
0 .364 1 r
.5 Mabswid
.55202 .38157 m
.45535 .57244 L
s
0 0 0 r
2.5 Mabswid
.55202 .38157 Mdot
0 g
.5 Mabswid
.67358 .44167 m
.67337 .44246 L
s
.67354 .44166 m
.67333 .44245 L
s
.317 1 0 r
.51578 .36394 m
.70288 .41332 L
s
0 0 0 r
2.5 Mabswid
.51578 .36394 Mdot
0 .989 1 r
.5 Mabswid
.5539 .66705 m
.48868 .49449 L
s
0 0 0 r
2.5 Mabswid
.5539 .66705 Mdot
0 g
.5 Mabswid
.67365 .44384 m
.67428 .44506 L
s
.67428 .44506 m
.63438 .50408 L
s
.67362 .44386 m
.67425 .44508 L
s
.63441 .50409 m
.67427 .44504 L
s
.67337 .44244 m
.67366 .44386 L
s
.60624 .42439 m
.67337 .44244 L
s
.67337 .44246 m
.60622 .42442 L
s
.67333 .44245 m
.67362 .44386 L
s
.67366 .44386 m
.61475 .46756 L
s
.61477 .46754 m
.67365 .44384 L
s
0 0 0 r
2.5 Mabswid
.41329 .43597 Mdot
0 .149 1 r
.5 Mabswid
.48474 .4219 m
.41329 .43597 L
s
0 0 0 r
2.5 Mabswid
.52122 .36777 Mdot
.41483 .4524 Mdot
1 .116 0 r
.5 Mabswid
.57706 .44488 m
.41483 .4524 L
s
0 0 0 r
2.5 Mabswid
.67108 .44184 Mdot
.61977 .1402 Mdot
.266 1 0 r
.5 Mabswid
.52233 .36871 m
.70477 .41953 L
s
0 0 0 r
2.5 Mabswid
.52233 .36871 Mdot
0 1 .874 r
.5 Mabswid
.47597 .34658 m
.55817 .18246 L
s
0 0 0 r
2.5 Mabswid
.47597 .34658 Mdot
0 1 .632 r
.5 Mabswid
.45558 .33724 m
.43247 .339 L
s
0 0 0 r
2.5 Mabswid
.45558 .33724 Mdot
.413 .43488 Mdot
0 .989 1 r
.5 Mabswid
.47456 .55552 m
.413 .43488 L
s
0 0 0 r
2.5 Mabswid
.52032 .36832 Mdot
0 .542 1 r
.5 Mabswid
.42761 .5038 m
.52032 .36832 L
s
0 0 0 r
2.5 Mabswid
.49713 .63356 Mdot
0 1 .453 r
.5 Mabswid
.5391 .62755 m
.49713 .63356 L
s
0 0 0 r
2.5 Mabswid
.56346 .64674 Mdot
.53067 .6598 Mdot
.045 1 0 r
.5 Mabswid
.54234 .64601 m
.53067 .6598 L
s
0 .989 1 r
.41736 .47004 m
.41949 .39678 L
s
0 0 0 r
2.5 Mabswid
.41736 .47004 Mdot
0 .989 1 r
.5 Mabswid
.525 .6554 m
.53841 .64764 L
s
0 0 0 r
2.5 Mabswid
.525 .6554 Mdot
.254 1 0 r
.5 Mabswid
.5289 .37349 m
.70673 .42585 L
s
0 0 0 r
2.5 Mabswid
.5289 .37349 Mdot
.5949 .58976 Mdot
.66274 .4396 Mdot
0 .989 1 r
.5 Mabswid
.47608 .61087 m
.52495 .49275 L
s
0 0 0 r
2.5 Mabswid
.47608 .61087 Mdot
.55911 .652 Mdot
.50818 .36369 Mdot
.5408 .37984 Mdot
.48265 .61999 Mdot
.8 1 0 r
.5 Mabswid
.57062 .62244 m
.48265 .61999 L
s
0 0 0 r
2.5 Mabswid
.68112 .78402 Mdot
.52024 .65185 Mdot
.741 1 0 r
.5 Mabswid
.55289 .64812 m
.52024 .65185 L
s
0 0 0 r
2.5 Mabswid
.72226 .4613 Mdot
.807 1 0 r
.5 Mabswid
.41224 .43065 m
.23629 .39045 L
s
1 .092 0 r
.41224 .43065 m
.53092 .40717 L
s
0 0 0 r
2.5 Mabswid
.41224 .43065 Mdot
.43323 .53637 Mdot
0 .702 1 r
.5 Mabswid
.54704 .52359 m
.43323 .53637 L
s
0 g
.42584 .45551 m
.41236 .4304 L
s
.42584 .45554 m
.41217 .43045 L
s
.41217 .43045 m
.42145 .38514 L
s
.42145 .38516 m
.41217 .43047 L
s
.41217 .43047 m
.43331 .3352 L
s
.41217 .43046 m
.43331 .3352 L
s
0 0 0 r
2.5 Mabswid
.5799 .61392 Mdot
.72381 .46682 Mdot
.235 1 0 r
.5 Mabswid
.5355 .37829 m
.70877 .43234 L
s
0 0 0 r
2.5 Mabswid
.5355 .37829 Mdot
.732 1 0 r
.5 Mabswid
.453 .5747 m
.47804 .55757 L
s
0 0 0 r
2.5 Mabswid
.453 .5747 Mdot
.72537 .47239 Mdot
0 1 .91 r
.5 Mabswid
.48155 .35198 m
.56182 .19936 L
s
0 0 0 r
2.5 Mabswid
.48155 .35198 Mdot
.41739 .46759 Mdot
.746 1 0 r
.5 Mabswid
.53074 .50711 m
.41739 .46759 L
s
0 0 0 r
2.5 Mabswid
.42083 .49349 Mdot
0 .989 1 r
.5 Mabswid
.53122 .52133 m
.42083 .49349 L
s
0 0 0 r
2.5 Mabswid
.65811 .44119 Mdot
.6544 .43736 Mdot
.50943 .64366 Mdot
.746 1 0 r
.5 Mabswid
.55366 .63859 m
.50943 .64366 L
s
0 g
.43838 .33333 m
.43331 .33522 L
s
.43331 .33522 m
.42144 .38518 L
s
.43331 .3352 m
.42145 .38516 L
s
.4333 .33524 m
.43837 .33335 L
s
0 1 .795 r
.43247 .339 m
.23059 .52017 L
s
0 0 0 r
2.5 Mabswid
.43247 .339 Mdot
.49504 .35959 Mdot
.61521 .41936 Mdot
.741 1 0 r
.5 Mabswid
.44684 .5648 m
.43558 .42303 L
s
0 0 0 r
2.5 Mabswid
.44684 .5648 Mdot
.64605 .43512 Mdot
.58728 .59583 Mdot
0 .038 1 r
.5 Mabswid
.42618 .49125 m
.58728 .59583 L
s
0 .588 1 r
.43041 .52947 m
.63551 .49041 L
s
0 0 0 r
2.5 Mabswid
.43041 .52947 Mdot
0 1 .284 r
.5 Mabswid
.61169 .43196 m
.43041 .52947 L
s
0 0 0 r
2.5 Mabswid
.41562 .4519 Mdot
1 .116 0 r
.5 Mabswid
.56516 .44498 m
.41562 .4519 L
s
0 0 0 r
2.5 Mabswid
.53892 .38277 Mdot
.61863 .146 Mdot
0 g
.5 Mabswid
.42665 .3833 m
.43838 .33333 L
s
.43835 .33332 m
.42662 .38329 L
s
.60628 .42444 m
.43835 .33332 L
s
.60622 .42442 m
.43829 .33331 L
s
0 0 0 r
2.5 Mabswid
.54891 .66176 Mdot
0 1 .632 r
.5 Mabswid
.48718 .45216 m
.54891 .66176 L
s
0 .038 1 r
.43061 .34719 m
.44319 .34535 L
s
0 0 0 r
2.5 Mabswid
.43061 .34719 Mdot
.53434 .38118 Mdot
.57062 .62244 Mdot
.60381 .4159 Mdot
.43905 .5523 Mdot
0 .327 1 r
.5 Mabswid
.56321 .4371 m
.43905 .5523 L
s
0 0 0 r
2.5 Mabswid
.63769 .43287 Mdot
0 1 .128 r
.5 Mabswid
.61982 .42428 m
.42278 .4882 L
s
0 0 0 r
2.5 Mabswid
.61982 .42428 Mdot
.54844 .3891 Mdot
0 .852 1 r
.5 Mabswid
.45086 .34183 m
.58841 .27198 L
s
0 0 0 r
2.5 Mabswid
.45086 .34183 Mdot
.56702 .62625 Mdot
.47625 .60995 Mdot
0 .327 1 r
.5 Mabswid
.55402 .51432 m
.47625 .60995 L
s
0 0 0 r
2.5 Mabswid
.41337 .42464 Mdot
.782 1 0 r
.5 Mabswid
.41337 .42464 m
.41337 .42464 L
s
0 0 0 r
2.5 Mabswid
.41337 .42464 Mdot
.782 1 0 r
.5 Mabswid
.41337 .42464 m
.41337 .42464 L
s
0 0 0 r
2.5 Mabswid
.41337 .42464 Mdot
.782 1 0 r
.5 Mabswid
.41337 .42464 m
.41337 .42464 L
s
0 0 0 r
2.5 Mabswid
.41337 .42464 Mdot
.782 1 0 r
.5 Mabswid
.41337 .42464 m
.41337 .42464 L
s
.508 1 0 r
.41337 .42464 m
.33057 .37266 L
s
1 .056 0 r
.41337 .42464 m
.41337 .42464 L
s
0 0 0 r
2.5 Mabswid
.41337 .42464 Mdot
.782 1 0 r
.5 Mabswid
.41337 .42464 m
.41337 .42464 L
s
1 .992 0 r
.41337 .42464 m
.4672 .36919 L
s
0 0 0 r
2.5 Mabswid
.41337 .42464 Mdot
.41337 .42464 Mdot
.741 1 0 r
.5 Mabswid
.42909 .35384 m
.43919 .33895 L
s
0 0 0 r
2.5 Mabswid
.42909 .35384 Mdot
.152 0 1 r
.5 Mabswid
.57796 .40502 m
.49993 .21405 L
s
0 0 0 r
2.5 Mabswid
.57796 .40502 Mdot
.65074 .4542 Mdot
0 .016 1 r
.5 Mabswid
.43937 .33764 m
.51065 .16752 L
s
0 0 0 r
2.5 Mabswid
.43937 .33764 Mdot
.62933 .43063 Mdot
.62672 .51923 Mdot
.06 1 0 r
.5 Mabswid
.44224 .52838 m
.62672 .51923 L
s
0 0 0 r
2.5 Mabswid
.55801 .39547 Mdot
.41963 .47798 Mdot
.741 1 0 r
.5 Mabswid
.5241 .51456 m
.41963 .47798 L
s
0 0 0 r
2.5 Mabswid
.55289 .64812 Mdot
0 .542 1 r
.5 Mabswid
.42341 .37931 m
.45971 .35554 L
s
0 0 0 r
2.5 Mabswid
.42341 .37931 Mdot
.61215 .42282 Mdot
.43919 .33895 Mdot
0 g
.5 Mabswid
.52393 .6537 m
.63441 .50403 L
s
.63441 .50403 m
.48502 .60317 L
s
.63438 .50408 m
.48498 .60322 L
s
.6344 .50402 m
.52392 .65369 L
s
0 .038 1 r
.44868 .5667 m
.55082 .59 L
s
0 0 0 r
2.5 Mabswid
.44868 .5667 Mdot
.70288 .41332 Mdot
.70477 .41953 Mdot
.70673 .42585 Mdot
.70877 .43234 Mdot
.62096 .42838 Mdot
.63551 .49041 Mdot
.149 0 1 r
.5 Mabswid
.56913 .40308 m
.49281 .21995 L
s
0 0 0 r
2.5 Mabswid
.56913 .40308 Mdot
.46335 .58927 Mdot
.778 1 0 r
.5 Mabswid
.51262 .41599 m
.46335 .58927 L
s
0 0 0 r
2.5 Mabswid
.52847 .65974 Mdot
0 1 .632 r
.5 Mabswid
.54236 .58451 m
.52847 .65974 L
s
0 0 0 r
2.5 Mabswid
.41642 .4514 Mdot
1 .116 0 r
.5 Mabswid
.55316 .44507 m
.41642 .4514 L
s
0 .989 1 r
.55524 .63996 m
.49899 .63343 L
s
0 0 0 r
2.5 Mabswid
.55524 .63996 Mdot
0 .989 1 r
.5 Mabswid
.41949 .39678 m
.43928 .35043 L
s
0 0 0 r
2.5 Mabswid
.41949 .39678 Mdot
.235 1 0 r
.5 Mabswid
.57151 .40509 m
.55864 .19379 L
s
0 0 0 r
2.5 Mabswid
.57151 .40509 Mdot
.61748 .15184 Mdot
.61962 .43203 Mdot
.81 1 0 r
.5 Mabswid
.42147 .48838 m
.58566 .52613 L
s
0 0 0 r
2.5 Mabswid
.42147 .48838 Mdot
.63486 .48239 Mdot
.61259 .42613 Mdot
.48292 .36374 Mdot
0 1 .632 r
.5 Mabswid
.41631 .41101 m
.48623 .55456 L
s
0 0 0 r
2.5 Mabswid
.41631 .41101 Mdot
.388 1 0 r
.5 Mabswid
.60316 .5529 m
.6019 .545 L
s
0 0 0 r
2.5 Mabswid
.60316 .5529 Mdot
.62939 .44518 Mdot
.44319 .34535 Mdot
.265 1 0 r
.5 Mabswid
.5778 .40996 m
.57944 .15301 L
s
0 0 0 r
2.5 Mabswid
.5778 .40996 Mdot
.595 1 0 r
.5 Mabswid
.59819 .41987 m
.62582 .25649 L
s
0 0 0 r
2.5 Mabswid
.59819 .41987 Mdot
.55366 .63859 Mdot
0 1 .632 r
.5 Mabswid
.42187 .38589 m
.48718 .45216 L
s
0 0 0 r
2.5 Mabswid
.42187 .38589 Mdot
.41463 .41848 Mdot
.757 1 0 r
.5 Mabswid
.41463 .41848 m
.41463 .41848 L
s
0 0 0 r
2.5 Mabswid
.41463 .41848 Mdot
.757 1 0 r
.5 Mabswid
.41463 .41848 m
.41463 .41848 L
s
0 0 0 r
2.5 Mabswid
.41463 .41848 Mdot
.757 1 0 r
.5 Mabswid
.41463 .41848 m
.41463 .41848 L
s
0 0 0 r
2.5 Mabswid
.41463 .41848 Mdot
.757 1 0 r
.5 Mabswid
.41463 .41848 m
.41463 .41848 L
s
.5 1 0 r
.41463 .41848 m
.33717 .36906 L
s
1 .054 0 r
.41463 .41848 m
.41463 .41848 L
s
0 0 0 r
2.5 Mabswid
.41463 .41848 Mdot
.757 1 0 r
.5 Mabswid
.41463 .41848 m
.41463 .41848 L
s
1 .946 0 r
.41463 .41848 m
.46027 .37105 L
s
0 0 0 r
2.5 Mabswid
.41463 .41848 Mdot
.41463 .41848 Mdot
0 1 .632 r
.5 Mabswid
.50065 .37387 m
.53427 .47976 L
s
0 0 0 r
2.5 Mabswid
.50065 .37387 Mdot
0 g
.5 Mabswid
.43112 .45373 m
.60628 .42442 L
s
.60628 .42442 m
.42662 .38327 L
s
.42662 .38329 m
.60628 .42444 L
s
0 0 0 r
2.5 Mabswid
.62516 .4445 Mdot
0 g
.5 Mabswid
.43106 .45372 m
.60624 .42439 L
s
0 0 0 r
2.5 Mabswid
.60558 .42427 Mdot
.60407 .42393 Mdot
.61169 .43196 Mdot
.47027 .59935 Mdot
0 1 .532 r
.5 Mabswid
.51984 .64915 m
.47027 .59935 L
s
0 0 0 r
2.5 Mabswid
.45971 .35554 Mdot
.806 1 0 r
.5 Mabswid
.42297 .49663 m
.57918 .53286 L
s
0 0 0 r
2.5 Mabswid
.42297 .49663 Mdot
.18587 .40945 Mdot
.46726 .59453 Mdot
0 .038 1 r
.5 Mabswid
.549 .50156 m
.46726 .59453 L
s
0 0 0 r
2.5 Mabswid
.41653 .40976 Mdot
.741 1 0 r
.5 Mabswid
.46251 .4105 m
.41653 .40976 L
s
0 0 0 r
2.5 Mabswid
.59511 .42187 Mdot
.51258 .38281 Mdot
.59322 .42144 Mdot
.045 1 0 r
.5 Mabswid
.53065 .39209 m
.50416 .54473 L
s
0 0 0 r
2.5 Mabswid
.53065 .39209 Mdot
.61551 .44458 Mdot
.50517 .38018 Mdot
.47181 .36451 Mdot
.388 1 0 r
.5 Mabswid
.6019 .545 m
.57423 .47255 L
s
0 0 0 r
2.5 Mabswid
.6019 .545 Mdot
.41722 .45089 Mdot
1 .116 0 r
.5 Mabswid
.54105 .44517 m
.41722 .45089 L
s
0 0 0 r
2.5 Mabswid
.58644 .57311 Mdot
0 .884 1 r
.5 Mabswid
.47504 .60328 m
.58644 .57311 L
s
0 0 0 r
2.5 Mabswid
.49895 .378 Mdot
.42832 .52827 Mdot
0 1 .453 r
.5 Mabswid
.47804 .55757 m
.42832 .52827 L
s
0 0 0 r
2.5 Mabswid
.58615 .41982 Mdot
.48931 .37401 Mdot
.803 1 0 r
.5 Mabswid
.42449 .50493 m
.57269 .5396 L
s
0 0 0 r
2.5 Mabswid
.42449 .50493 Mdot
.43928 .35043 Mdot
.61723 .45212 Mdot
.41707 .44829 Mdot
0 .538 1 r
.5 Mabswid
.45465 .45217 m
.41707 .44829 L
s
0 0 0 r
2.5 Mabswid
.19431 .40627 Mdot
.58083 .4186 Mdot
.4887 .37515 Mdot
0 .538 1 r
.5 Mabswid
.56324 .50966 m
.4887 .37515 L
s
0 0 0 r
2.5 Mabswid
.42212 .3843 Mdot
0 .542 1 r
.5 Mabswid
.44019 .3908 m
.42212 .3843 L
s
0 0 0 r
2.5 Mabswid
.57719 .41777 Mdot
.6183 .48671 Mdot
0 1 .67 r
.5 Mabswid
.44677 .5428 m
.6183 .48671 L
s
0 0 0 r
2.5 Mabswid
.41591 .41223 Mdot
.757 1 0 r
.5 Mabswid
.41591 .41223 m
.41591 .41223 L
s
0 0 0 r
2.5 Mabswid
.41591 .41223 Mdot
.757 1 0 r
.5 Mabswid
.41591 .41223 m
.41591 .41223 L
s
0 0 0 r
2.5 Mabswid
.41591 .41223 Mdot
.757 1 0 r
.5 Mabswid
.41591 .41223 m
.41591 .41223 L
s
0 0 0 r
2.5 Mabswid
.41591 .41223 Mdot
.757 1 0 r
.5 Mabswid
.41591 .41223 m
.41591 .41223 L
s
.494 1 0 r
.41591 .41223 m
.34379 .36545 L
s
1 .053 0 r
.41591 .41223 m
.41591 .41223 L
s
0 0 0 r
2.5 Mabswid
.41591 .41223 Mdot
.757 1 0 r
.5 Mabswid
.41591 .41223 m
.41591 .41223 L
s
1 .954 0 r
.41591 .41223 m
.45336 .37295 L
s
0 0 0 r
2.5 Mabswid
.41591 .41223 Mdot
.41591 .41223 Mdot
.60578 .44466 Mdot
.54234 .64601 Mdot
.045 1 0 r
.5 Mabswid
.43379 .39762 m
.54234 .64601 L
s
.659 1 0 r
.43277 .35172 m
.43114 .35049 L
s
0 0 0 r
2.5 Mabswid
.43277 .35172 Mdot
.43114 .35049 Mdot
.5057 .38515 Mdot
.61665 .45887 Mdot
.62057 .4678 Mdot
.44992 .76126 Mdot
0 1 .62 r
.5 Mabswid
.47504 .60328 m
.44992 .76126 L
s
0 0 0 r
2.5 Mabswid
.5684 .41576 Mdot
.56823 .41572 Mdot
0 1 .303 r
.5 Mabswid
.18256 .64857 m
.42278 .4882 L
s
0 0 0 r
2.5 Mabswid
.42278 .4882 Mdot
.20273 .4031 Mdot
.39046 .22296 Mdot
.797 1 0 r
.5 Mabswid
.41971 .4643 m
.47853 .41648 L
s
0 0 0 r
2.5 Mabswid
.41971 .4643 Mdot
1 .921 0 r
.5 Mabswid
.4672 .36919 m
.5796 .19416 L
s
0 0 0 r
2.5 Mabswid
.4672 .36919 Mdot
.47962 .61245 Mdot
0 .989 1 r
.5 Mabswid
.52031 .62757 m
.47962 .61245 L
s
.797 1 0 r
.5011 .63687 m
.52811 .62011 L
s
0 0 0 r
2.5 Mabswid
.5011 .63687 Mdot
0 .989 1 r
.5 Mabswid
.53841 .64764 m
.42215 .47395 L
s
0 0 0 r
2.5 Mabswid
.53841 .64764 Mdot
.55926 .41366 Mdot
.59596 .44473 Mdot
.51071 .39069 Mdot
.42731 .36064 Mdot
.797 1 0 r
.5 Mabswid
.43068 .35834 m
.42731 .36064 L
s
0 0 0 r
2.5 Mabswid
.42065 .3906 Mdot
.741 1 0 r
.5 Mabswid
.45869 .42684 m
.42065 .3906 L
s
0 0 0 r
2.5 Mabswid
.41803 .45038 Mdot
1 .116 0 r
.5 Mabswid
.52882 .44526 m
.41803 .45038 L
s
0 0 0 r
2.5 Mabswid
.55594 .4129 Mdot
.51247 .39232 Mdot
0 g
.5 Mabswid
.45187 .5321 m
.61479 .46754 L
s
.61479 .46754 m
.43112 .4537 L
s
.48503 .6032 m
.61479 .46752 L
s
.61479 .46752 m
.45187 .53208 L
s
.61475 .46756 m
.43106 .45372 L
s
.48498 .60322 m
.61477 .46754 L
s
0 0 0 r
2.5 Mabswid
.45829 .3667 Mdot
0 .989 1 r
.5 Mabswid
.42215 .47395 m
.45829 .3667 L
s
0 0 0 r
2.5 Mabswid
.42642 .36458 Mdot
0 .2 1 r
.5 Mabswid
.43286 .3618 m
.42642 .36458 L
s
0 .989 1 r
.41989 .39396 m
.46652 .37735 L
s
0 0 0 r
2.5 Mabswid
.41989 .39396 Mdot
.52357 .39845 Mdot
0 .989 1 r
.5 Mabswid
.5899 .50095 m
.52357 .39845 L
s
0 0 0 r
2.5 Mabswid
.61017 .47971 Mdot
0 1 .832 r
.5 Mabswid
.44329 .53423 m
.61017 .47971 L
s
0 0 0 r
2.5 Mabswid
.58884 .44479 Mdot
.21114 .39993 Mdot
.43068 .35834 Mdot
.797 1 0 r
.5 Mabswid
.43389 .35821 m
.43068 .35834 L
s
0 g
.44654 .5338 m
.4294 .5342 L
s
.4294 .5342 m
.42584 .4555 L
s
.47971 .60478 m
.4294 .53418 L
s
.4294 .53418 m
.44653 .53378 L
s
.47971 .60477 m
.42955 .53406 L
s
.42941 .53422 m
.42584 .45551 L
s
0 0 0 r
2.5 Mabswid
.54345 .41004 Mdot
.41721 .40587 Mdot
.756 1 0 r
.5 Mabswid
.41721 .40587 m
.41721 .40587 L
s
0 0 0 r
2.5 Mabswid
.41721 .40587 Mdot
.756 1 0 r
.5 Mabswid
.41721 .40587 m
.41721 .40587 L
s
0 0 0 r
2.5 Mabswid
.41721 .40587 Mdot
.756 1 0 r
.5 Mabswid
.41721 .40587 m
.41721 .40587 L
s
0 0 0 r
2.5 Mabswid
.41721 .40587 Mdot
.756 1 0 r
.5 Mabswid
.41721 .40587 m
.41721 .40587 L
s
.488 1 0 r
.41721 .40587 m
.35042 .36183 L
s
1 .053 0 r
.41721 .40587 m
.41721 .40587 L
s
0 0 0 r
2.5 Mabswid
.41721 .40587 Mdot
.756 1 0 r
.5 Mabswid
.41721 .40587 m
.41721 .40587 L
s
1 .962 0 r
.41721 .40587 m
.44648 .37489 L
s
0 0 0 r
2.5 Mabswid
.41721 .40587 Mdot
.41721 .40587 Mdot
.58606 .44481 Mdot
0 1 .532 r
.5 Mabswid
.4185 .45099 m
.4634 .38541 L
s
0 0 0 r
2.5 Mabswid
.4185 .45099 Mdot
.43389 .35821 Mdot
.741 1 0 r
.5 Mabswid
.5224 .65735 m
.52254 .65728 L
s
0 0 0 r
2.5 Mabswid
.5224 .65735 Mdot
.92 1 0 r
.5 Mabswid
.46027 .37105 m
.57097 .19737 L
s
0 0 0 r
2.5 Mabswid
.46027 .37105 Mdot
.741 1 0 r
.5 Mabswid
.52254 .65728 m
.52606 .65268 L
s
0 0 0 r
2.5 Mabswid
.52254 .65728 Mdot
0 1 .632 r
.5 Mabswid
.41722 .44074 m
.55342 .52112 L
s
0 0 0 r
2.5 Mabswid
.41722 .44074 Mdot
.51852 .40104 Mdot
.53092 .40717 Mdot
0 .989 1 r
.5 Mabswid
.49899 .63343 m
.50584 .45779 L
s
0 0 0 r
2.5 Mabswid
.49899 .63343 Mdot
0 .542 1 r
.5 Mabswid
.50167 .63644 m
.52041 .62407 L
s
0 0 0 r
2.5 Mabswid
.50167 .63644 Mdot
.21953 .39677 Mdot
0 1 .394 r
.5 Mabswid
.59209 .46079 m
.47504 .60328 L
s
0 0 0 r
2.5 Mabswid
.59209 .46079 Mdot
.57706 .44488 Mdot
.46652 .37735 Mdot
.57605 .44489 Mdot
.43286 .3618 Mdot
.58566 .52613 Mdot
.53901 .41667 Mdot
0 1 .532 r
.5 Mabswid
.53187 .64524 m
.51984 .64915 L
s
0 0 0 r
2.5 Mabswid
.53187 .64524 Mdot
0 g
.5 Mabswid
.57635 .51403 m
.57733 .05514 L
s
.912 1 0 r
.45336 .37295 m
.55701 .20912 L
s
0 0 0 r
2.5 Mabswid
.45336 .37295 Mdot
.42215 .47395 Mdot
.56321 .4371 Mdot
0 g
.5 Mabswid
.51867 .65516 m
.52395 .65368 L
s
.47969 .60475 m
.51867 .65516 L
s
.732 1 0 r
.41883 .4484 m
.47279 .42153 L
s
0 0 0 r
2.5 Mabswid
.41883 .4484 Mdot
0 g
.5 Mabswid
.47969 .60475 m
.51867 .65517 L
s
.52393 .65366 m
.51865 .65515 L
s
0 0 0 r
2.5 Mabswid
.5391 .62755 Mdot
.5899 .50095 Mdot
0 .989 1 r
.5 Mabswid
.46714 .59148 m
.47048 .55972 L
s
0 0 0 r
2.5 Mabswid
.46714 .59148 Mdot
.741 1 0 r
.5 Mabswid
.52606 .65268 m
.45869 .42684 L
s
0 0 0 r
2.5 Mabswid
.52606 .65268 Mdot
.63086 .22286 Mdot
.41811 .41942 Mdot
0 .989 1 r
.5 Mabswid
.48868 .49449 m
.41811 .41942 L
s
0 0 0 r
2.5 Mabswid
.57918 .53286 Mdot
.22792 .39361 Mdot
.47828 .6086 Mdot
0 1 .632 r
.5 Mabswid
.48623 .55456 m
.47828 .6086 L
s
0 0 0 r
2.5 Mabswid
.50396 .39975 Mdot
.56516 .44498 Mdot
0 .521 1 r
.5 Mabswid
.53506 .42044 m
.62479 .3872 L
s
0 0 0 r
2.5 Mabswid
.53506 .42044 Mdot
0 g
.5 Mabswid
.52395 .65368 m
.48504 .60315 L
s
.48502 .60317 m
.52393 .6537 L
s
0 0 0 r
2.5 Mabswid
.56232 .56949 Mdot
.54626 .60238 Mdot
.045 1 0 r
.5 Mabswid
.4768 .60234 m
.54626 .60238 L
s
.737 1 0 r
.41822 .43888 m
.48389 .42685 L
s
0 0 0 r
2.5 Mabswid
.41822 .43888 Mdot
.47504 .60328 Mdot
.741 1 0 r
.5 Mabswid
.41838 .43324 m
.45751 .38992 L
s
0 0 0 r
2.5 Mabswid
.41838 .43324 Mdot
.55082 .59 Mdot
.57269 .5396 Mdot
.905 1 0 r
.5 Mabswid
.44648 .37489 m
.54326 .22077 L
s
0 0 0 r
2.5 Mabswid
.44648 .37489 Mdot
.194 1 0 r
.5 Mabswid
.19744 .72185 m
.44224 .52838 L
s
0 1 .049 r
.58429 .48347 m
.4393 .62959 L
s
0 0 0 r
2.5 Mabswid
.58429 .48347 Mdot
0 .364 1 r
.5 Mabswid
.45535 .57244 m
.55587 .56702 L
s
0 0 0 r
2.5 Mabswid
.45535 .57244 Mdot
.57271 .46292 Mdot
.23629 .39045 Mdot
.56877 .54389 Mdot
.741 1 0 r
.5 Mabswid
.41874 .42965 m
.4744 .41928 L
s
0 0 0 r
2.5 Mabswid
.41874 .42965 Mdot
0 .473 1 r
.5 Mabswid
.53655 .42909 m
.62638 .39726 L
s
0 0 0 r
2.5 Mabswid
.53655 .42909 Mdot
.51984 .64915 Mdot
.41956 .44848 Mdot
0 .829 1 r
.5 Mabswid
.46678 .46066 m
.41956 .44848 L
s
0 0 0 r
2.5 Mabswid
.55316 .44507 Mdot
.4634 .38541 Mdot
.57423 .47255 Mdot
.45506 .74881 Mdot
.51262 .41599 Mdot
.55587 .56702 Mdot
.746 1 0 r
.5 Mabswid
.41927 .42039 m
.46495 .41175 L
s
0 0 0 r
2.5 Mabswid
.41927 .42039 Mdot
.43264 .53057 Mdot
.333 1 0 r
.5 Mabswid
.45929 .49128 m
.43264 .53057 L
s
0 0 0 r
2.5 Mabswid
.52811 .62011 Mdot
.54105 .44517 Mdot
0 .542 1 r
.5 Mabswid
.41958 .43291 m
.46041 .40881 L
s
0 0 0 r
2.5 Mabswid
.41958 .43291 Mdot
.54236 .58451 Mdot
0 1 .632 r
.5 Mabswid
.53427 .47976 m
.54236 .58451 L
s
0 0 0 r
2.5 Mabswid
.6578 .32048 Mdot
.42761 .5038 Mdot
0 .542 1 r
.5 Mabswid
.52234 .57926 m
.42761 .5038 L
s
0 0 0 r
2.5 Mabswid
.56324 .50966 Mdot
.608 1 0 r
.5 Mabswid
.52031 .62757 m
.461 .63463 L
s
0 0 0 r
2.5 Mabswid
.52031 .62757 Mdot
.45751 .38992 Mdot
.61936 .75011 Mdot
0 1 .347 r
.5 Mabswid
.52908 .60566 m
.61936 .75011 L
s
0 0 0 r
2.5 Mabswid
.52908 .60566 Mdot
.42022 .41814 Mdot
.741 1 0 r
.5 Mabswid
.43558 .42303 m
.42022 .41814 L
s
0 0 0 r
2.5 Mabswid
.52041 .62407 Mdot
.55491 .4748 Mdot
.42618 .49125 Mdot
0 .038 1 r
.5 Mabswid
.49176 .42131 m
.42618 .49125 L
s
0 .502 1 r
.55577 .53063 m
.62817 .612 L
s
0 0 0 r
2.5 Mabswid
.55577 .53063 Mdot
.045 1 0 r
.5 Mabswid
.42103 .38724 m
.43379 .39762 L
s
0 0 0 r
2.5 Mabswid
.42103 .38724 Mdot
.52882 .44526 Mdot
.55342 .52112 Mdot
.55402 .51432 Mdot
.49176 .42131 Mdot
.49243 .62284 Mdot
0 .149 1 r
.5 Mabswid
.50045 .62572 m
.49243 .62284 L
s
0 0 0 r
2.5 Mabswid
.54668 .54633 Mdot
.699 1 0 r
.5 Mabswid
.44179 .52408 m
.54668 .54633 L
s
0 g
.42665 .38327 m
.42145 .38515 L
s
.42145 .38515 m
.42584 .45554 L
s
.42145 .38514 m
.42584 .45554 L
s
.42144 .38518 m
.42665 .3833 L
s
0 0 0 r
2.5 Mabswid
.446 .55282 Mdot
0 1 .453 r
.5 Mabswid
.45288 .52206 m
.446 .55282 L
s
0 0 0 r
2.5 Mabswid
.54357 .47937 Mdot
.47853 .41648 Mdot
0 1 .68 r
.5 Mabswid
.52977 .58506 m
.72813 .67611 L
s
0 0 0 r
2.5 Mabswid
.52977 .58506 Mdot
.54704 .52359 Mdot
.549 .50156 Mdot
.44019 .3908 Mdot
0 1 .381 r
.5 Mabswid
.42119 .41997 m
.43301 .40201 L
s
0 0 0 r
2.5 Mabswid
.42119 .41997 Mdot
.48474 .4219 Mdot
.599 1 0 r
.5 Mabswid
.45565 .40271 m
.58791 .50393 L
s
0 0 0 r
2.5 Mabswid
.45565 .40271 Mdot
0 g
.5 Mabswid
.43115 .45373 m
.42665 .38327 L
s
.42662 .38327 m
.43112 .45373 L
s
0 .989 1 r
.46403 .58346 m
.47456 .55552 L
s
0 0 0 r
2.5 Mabswid
.46403 .58346 Mdot
.46495 .41175 Mdot
.46041 .40881 Mdot
.46251 .4105 Mdot
.4744 .41928 Mdot
0 .313 1 r
.5 Mabswid
.53925 .53653 m
.43854 .37089 L
s
0 0 0 r
2.5 Mabswid
.53925 .53653 Mdot
.53427 .47976 Mdot
.48389 .42685 Mdot
.43461 .52372 Mdot
0 .989 1 r
.5 Mabswid
.47048 .55972 m
.43461 .52372 L
s
0 0 0 r
2.5 Mabswid
.47279 .42153 Mdot
.42407 .46646 Mdot
0 .989 1 r
.5 Mabswid
.44443 .47431 m
.42407 .46646 L
s
0 .149 1 r
.5051 .62253 m
.50045 .62572 L
s
0 0 0 r
2.5 Mabswid
.5051 .62253 Mdot
0 1 .453 r
.5 Mabswid
.43218 .51191 m
.45288 .52206 L
s
0 0 0 r
2.5 Mabswid
.43218 .51191 Mdot
.50045 .62572 Mdot
.43495 .52301 Mdot
.741 1 0 r
.5 Mabswid
.47781 .548 m
.43495 .52301 L
s
0 0 0 r
2.5 Mabswid
.43379 .39762 Mdot
.42944 .49928 Mdot
.2 0 1 r
.5 Mabswid
.45736 .49309 m
.42944 .49928 L
s
0 0 0 r
2.5 Mabswid
.52234 .57926 Mdot
.47266 .42618 Mdot
.44931 .55519 Mdot
0 1 .381 r
.5 Mabswid
.50696 .54414 m
.44931 .55519 L
s
0 0 0 r
2.5 Mabswid
.53122 .52133 Mdot
.4768 .60234 Mdot
.045 1 0 r
.5 Mabswid
.50416 .54473 m
.4768 .60234 L
s
0 0 0 r
2.5 Mabswid
.53074 .50711 Mdot
.43301 .40201 Mdot
.50584 .45779 Mdot
.2 0 1 r
.5 Mabswid
.52698 .53514 m
.44309 .53232 L
s
0 0 0 r
2.5 Mabswid
.52698 .53514 Mdot
.371 1 0 r
.5 Mabswid
.5206 .48494 m
.44677 .5428 L
s
0 0 0 r
2.5 Mabswid
.5206 .48494 Mdot
.52495 .49275 Mdot
.514 1 0 r
.5 Mabswid
.47719 .6026 m
.50202 .59746 L
s
0 0 0 r
2.5 Mabswid
.47719 .6026 Mdot
.5241 .51456 Mdot
0 .407 1 r
.5 Mabswid
.48982 .44849 m
.47726 .366 L
s
0 0 0 r
2.5 Mabswid
.48982 .44849 Mdot
.45869 .42684 Mdot
.62176 .2335 Mdot
.54 1 0 r
.5 Mabswid
.48327 .61019 m
.47875 .68897 L
s
0 .938 1 r
.48327 .61019 m
.5 .60094 L
s
0 0 0 r
2.5 Mabswid
.48327 .61019 Mdot
.48718 .45216 Mdot
.5169 .50935 Mdot
.50202 .59746 Mdot
.5 .60094 Mdot
.713 1 0 r
.5 Mabswid
.51344 .52626 m
.68093 .6062 L
s
0 0 0 r
2.5 Mabswid
.51344 .52626 Mdot
.664 1 0 r
.5 Mabswid
.51373 .51737 m
.67802 .59413 L
s
0 0 0 r
2.5 Mabswid
.51373 .51737 Mdot
.435 1 0 r
.5 Mabswid
.50287 .48774 m
.44329 .53423 L
s
0 0 0 r
2.5 Mabswid
.50287 .48774 Mdot
.50696 .54414 Mdot
.43558 .42303 Mdot
0 1 .381 r
.5 Mabswid
.45304 .55683 m
.47865 .52742 L
s
0 0 0 r
2.5 Mabswid
.45304 .55683 Mdot
.50416 .54473 Mdot
.51065 .16752 Mdot
.62582 .25649 Mdot
.76384 .68387 Mdot
0 g
.5 Mabswid
.4797 .60478 m
.48506 .60318 L
s
.44652 .53377 m
.4797 .60478 L
s
.44653 .53378 m
.47971 .60478 L
s
.48504 .60315 m
.47969 .60475 L
s
0 0 0 r
2.5 Mabswid
.48868 .49449 Mdot
.8 1 0 r
.5 Mabswid
.42732 .47246 m
.45112 .46253 L
s
0 0 0 r
2.5 Mabswid
.42732 .47246 Mdot
.699 1 0 r
.5 Mabswid
.48491 .49056 m
.44179 .52408 L
s
0 0 0 r
2.5 Mabswid
.48491 .49056 Mdot
.249 1 0 r
.5 Mabswid
.44677 .5428 m
.31196 .71847 L
s
0 0 0 r
2.5 Mabswid
.44677 .5428 Mdot
.46678 .46066 Mdot
.88 1 0 r
.5 Mabswid
.49199 .50697 m
.44224 .52838 L
s
0 0 0 r
2.5 Mabswid
.49199 .50697 Mdot
0 g
.5 Mabswid
.48506 .60318 m
.45189 .53206 L
s
.45187 .53208 m
.48503 .6032 L
s
0 0 0 r
2.5 Mabswid
.45465 .45217 Mdot
.48623 .55456 Mdot
.31196 .71847 Mdot
.486 1 0 r
.5 Mabswid
.44329 .53423 m
.30356 .71503 L
s
0 0 0 r
2.5 Mabswid
.44329 .53423 Mdot
.44309 .53232 Mdot
.44224 .52838 Mdot
.45112 .46253 Mdot
.364 1 0 r
.5 Mabswid
.47804 .55757 m
.46488 .43248 L
s
0 0 0 r
2.5 Mabswid
.47804 .55757 Mdot
.7623 .69024 Mdot
.47781 .548 Mdot
.47865 .52742 Mdot
.44179 .52408 Mdot
.47456 .55552 Mdot
.30356 .71503 Mdot
.45929 .49128 Mdot
0 g
.5 Mabswid
.43115 .45369 m
.42583 .4555 L
s
.42583 .4555 m
.44654 .53381 L
s
.42584 .45554 m
.43115 .45373 L
s
.42584 .4555 m
.44654 .5338 L
s
0 0 0 r
2.5 Mabswid
.47048 .55972 Mdot
.45736 .49309 Mdot
.44443 .47431 Mdot
0 g
.5 Mabswid
.45191 .5321 m
.43115 .45369 L
s
.43112 .4537 m
.45187 .5321 L
s
0 0 0 r
2.5 Mabswid
.51902 .17941 Mdot
.43412 .48694 Mdot
0 1 .381 r
.5 Mabswid
.43431 .48704 m
.43412 .48694 L
s
0 0 0 r
2.5 Mabswid
.43431 .48704 Mdot
0 1 .381 r
.5 Mabswid
.44529 .49145 m
.43431 .48704 L
s
0 0 0 r
2.5 Mabswid
.44529 .49145 Mdot
.76074 .6967 Mdot
.53233 .17158 Mdot
0 g
.5 Mabswid
.44654 .53381 m
.45191 .5321 L
s
.45189 .53206 m
.44652 .53377 L
s
0 0 0 r
2.5 Mabswid
.45288 .52206 Mdot
.33057 .37266 Mdot
.33717 .36906 Mdot
.49281 .21995 Mdot
.49993 .21405 Mdot
.34379 .36545 Mdot
.35042 .36183 Mdot
.57944 .15301 Mdot
.54957 .18109 Mdot
.55817 .18246 Mdot
.51887 .22296 Mdot
.55864 .19379 Mdot
.47875 .68897 Mdot
.461 .63463 Mdot
.56182 .19936 Mdot
.5796 .19416 Mdot
.23059 .52017 Mdot
.54326 .22077 Mdot
.55701 .20912 Mdot
.57097 .19737 Mdot
0 g
.5 Mabswid
.09932 .66347 m
.35892 .58214 L
s
0 0 0 r
2.5 Mabswid
.72813 .67611 Mdot
.65594 .67225 Mdot
.58841 .27198 Mdot
.43854 .37089 Mdot
.62479 .3872 Mdot
.62638 .39726 Mdot
.47726 .366 Mdot
.67802 .59413 Mdot
.68093 .6062 Mdot
.4393 .62959 Mdot
.46488 .43248 Mdot
.62817 .612 Mdot
0 g
.5 Mabswid
.57635 .51403 m
.35892 .58214 L
s
0 0 0 r
2.5 Mabswid
.58791 .50393 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.431973 0.0136054 0.97619 0.557823 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.41347 .49374 m
.61517 .42964 L
s
0 1 .516 r
.37664 .47516 m
.46021 .51148 L
s
0 g
.61517 .42964 m
.40065 .1313 L
s
.77597 .37854 m
.61517 .42964 L
s
.64756 .83863 m
.61517 .42964 L
s
0 1 .635 r
.39193 .54947 m
.50004 .47847 L
s
.785 1 0 r
.35661 .45406 m
.56763 .47 L
s
0 .375 1 r
.38674 .54933 m
.49315 .47925 L
s
0 0 0 r
2.5 Mabswid
.52258 .54959 Mdot
0 1 .922 r
.5 Mabswid
.54541 .49481 m
.52258 .54959 L
s
0 0 0 r
2.5 Mabswid
.55442 .5324 Mdot
0 1 .827 r
.5 Mabswid
.56833 .50032 m
.55442 .5324 L
s
0 0 0 r
2.5 Mabswid
.59218 .39997 Mdot
.77 1 0 r
.5 Mabswid
.54385 .57253 m
.59218 .39997 L
s
1 .429 0 r
.37238 .5508 m
.50854 .55008 L
s
0 0 0 r
2.5 Mabswid
.42766 .65149 Mdot
0 .156 1 r
.5 Mabswid
.52912 .55065 m
.42766 .65149 L
s
1 .427 0 r
.36919 .54425 m
.5056 .54352 L
s
1 .424 0 r
.36599 .53771 m
.50266 .53697 L
s
0 1 .202 r
.33576 .44427 m
.51496 .48523 L
s
1 .422 0 r
.36279 .53116 m
.49973 .53041 L
s
0 0 0 r
2.5 Mabswid
.59514 .41739 Mdot
.768 1 0 r
.5 Mabswid
.55159 .57435 m
.59514 .41739 L
s
1 .421 0 r
.3596 .52461 m
.49679 .52385 L
s
0 0 0 r
2.5 Mabswid
.58655 .53152 Mdot
0 1 .862 r
.5 Mabswid
.5142 .48378 m
.58655 .53152 L
s
0 0 0 r
2.5 Mabswid
.59318 .38655 Mdot
0 1 .8 r
.5 Mabswid
.61158 .57142 m
.59318 .38655 L
s
0 g
.58842 .05741 m
.77597 .37854 L
s
.77597 .37854 m
.837 .79404 L
s
0 0 0 r
2.5 Mabswid
.44655 .66992 Mdot
.84 1 0 r
.5 Mabswid
.51264 .55765 m
.44655 .66992 L
s
0 0 0 r
2.5 Mabswid
.45466 .66766 Mdot
.838 1 0 r
.5 Mabswid
.51774 .56017 m
.45466 .66766 L
s
0 0 0 r
2.5 Mabswid
.59641 .44133 Mdot
.767 1 0 r
.5 Mabswid
.55936 .57618 m
.59641 .44133 L
s
0 0 0 r
2.5 Mabswid
.46274 .6654 Mdot
.836 1 0 r
.5 Mabswid
.52284 .56268 m
.46274 .6654 L
s
0 0 0 r
2.5 Mabswid
.42589 .69709 Mdot
.203 1 0 r
.5 Mabswid
.54662 .64698 m
.42589 .69709 L
s
.774 1 0 r
.35439 .54605 m
.51479 .56116 L
s
0 0 0 r
2.5 Mabswid
.47079 .66315 Mdot
.834 1 0 r
.5 Mabswid
.52793 .56519 m
.47079 .66315 L
s
0 0 0 r
2.5 Mabswid
.47881 .66091 Mdot
.833 1 0 r
.5 Mabswid
.53302 .5677 m
.47881 .66091 L
s
0 0 0 r
2.5 Mabswid
.4868 .65867 Mdot
.831 1 0 r
.5 Mabswid
.5381 .5702 m
.4868 .65867 L
s
0 0 0 r
2.5 Mabswid
.5977 .46573 Mdot
.766 1 0 r
.5 Mabswid
.56715 .57801 m
.5977 .46573 L
s
1 .232 0 r
.33398 .50698 m
.55854 .59954 L
s
1 .233 0 r
.3313 .50213 m
.5527 .5949 L
s
0 .43 1 r
.3489 .55807 m
.4856 .47658 L
s
1 .233 0 r
.32862 .4973 m
.54685 .59025 L
s
1 .245 0 r
.36706 .62108 m
.52959 .57616 L
s
1 .234 0 r
.32595 .49248 m
.541 .5856 L
s
0 0 0 r
2.5 Mabswid
.67996 .52016 Mdot
0 1 .96 r
.5 Mabswid
.57933 .46825 m
.67996 .52016 L
s
1 .234 0 r
.32328 .48767 m
.53514 .58095 L
s
0 0 0 r
2.5 Mabswid
.73428 .48139 Mdot
0 .785 1 r
.5 Mabswid
.59025 .49773 m
.73428 .48139 L
s
0 .402 1 r
.34005 .55573 m
.47793 .4731 L
s
0 0 0 r
2.5 Mabswid
.59901 .49059 Mdot
.765 1 0 r
.5 Mabswid
.57497 .57985 m
.59901 .49059 L
s
0 0 0 r
2.5 Mabswid
.73963 .48774 Mdot
0 .475 1 r
.5 Mabswid
.59105 .50249 m
.73963 .48774 L
s
0 0 0 r
2.5 Mabswid
.41947 .76604 Mdot
1 .163 0 r
.5 Mabswid
.50013 .56968 m
.41947 .76604 L
s
0 0 0 r
2.5 Mabswid
.42517 .76723 Mdot
1 .162 0 r
.5 Mabswid
.50261 .57658 m
.42517 .76723 L
s
1 0 0 r
.35827 .63656 m
.58281 .58169 L
s
.761 1 0 r
.28089 .39504 m
.46085 .45954 L
s
0 0 0 r
2.5 Mabswid
.43082 .76843 Mdot
1 .161 0 r
.5 Mabswid
.50509 .58347 m
.43082 .76843 L
s
0 0 0 r
2.5 Mabswid
.75983 .37359 Mdot
0 1 .692 r
.5 Mabswid
.62053 .46618 m
.75983 .37359 L
s
1 0 0 r
.35547 .6341 m
.57497 .57985 L
s
0 0 0 r
2.5 Mabswid
.76164 .38213 Mdot
0 1 .44 r
.5 Mabswid
.62351 .47362 m
.76164 .38213 L
s
0 0 0 r
2.5 Mabswid
.60034 .51595 Mdot
.8 1 0 r
.5 Mabswid
.58281 .58169 m
.60034 .51595 L
s
1 0 0 r
.35265 .63164 m
.56715 .57801 L
s
0 0 0 r
2.5 Mabswid
.58038 .65119 Mdot
.569 1 0 r
.5 Mabswid
.54385 .57253 m
.58038 .65119 L
s
0 0 0 r
2.5 Mabswid
.58618 .64848 Mdot
.564 1 0 r
.5 Mabswid
.55159 .57435 m
.58618 .64848 L
s
0 0 0 r
2.5 Mabswid
.59198 .64577 Mdot
.559 1 0 r
.5 Mabswid
.55936 .57618 m
.59198 .64577 L
s
1 0 0 r
.34983 .62917 m
.55936 .57618 L
s
0 0 0 r
2.5 Mabswid
.59779 .64307 Mdot
.554 1 0 r
.5 Mabswid
.56715 .57801 m
.59779 .64307 L
s
0 0 0 r
2.5 Mabswid
.60359 .64036 Mdot
.549 1 0 r
.5 Mabswid
.57497 .57985 m
.60359 .64036 L
s
1 .243 0 r
.35923 .66256 m
.51248 .59566 L
s
1 .26 0 r
.35649 .65593 m
.50796 .59012 L
s
0 0 0 r
2.5 Mabswid
.6094 .63764 Mdot
.544 1 0 r
.5 Mabswid
.58281 .58169 m
.6094 .63764 L
s
1 0 0 r
.34699 .62669 m
.55159 .57435 L
s
1 .392 0 r
.30374 .49188 m
.51833 .56239 L
s
1 .184 0 r
.32635 .56392 m
.52847 .59602 L
s
1 .388 0 r
.30059 .48566 m
.51332 .55626 L
s
1 0 0 r
.34415 .6242 m
.54385 .57253 L
s
.34129 .6217 m
.5381 .5702 L
s
.33843 .6192 m
.53302 .5677 L
s
0 g
.57242 .45866 m
.54714 .39789 L
s
.52261 .47923 m
.57242 .45866 L
s
.57241 .45864 m
.52261 .47921 L
s
.59071 .52375 m
.57241 .45864 L
s
.57716 .45717 m
.57241 .45867 L
s
.57241 .45867 m
.54714 .3979 L
s
.5724 .45863 m
.57715 .45714 L
s
.59069 .52375 m
.5724 .45863 L
s
0 0 0 r
2.5 Mabswid
.45672 .31283 Mdot
0 .072 1 r
.5 Mabswid
.52888 .40079 m
.45672 .31283 L
s
0 .989 1 r
.57258 .45621 m
.58304 .53699 L
s
0 0 0 r
2.5 Mabswid
.57258 .45621 Mdot
0 .989 1 r
.5 Mabswid
.503 .32708 m
.57258 .45621 L
s
0 1 .532 r
.57536 .45689 m
.6189 .51511 L
s
0 0 0 r
2.5 Mabswid
.57536 .45689 Mdot
0 1 .532 r
.5 Mabswid
.47158 .45084 m
.57536 .45689 L
s
.2 0 1 r
.57365 .45546 m
.63929 .50469 L
s
0 0 0 r
2.5 Mabswid
.57365 .45546 Mdot
.2 0 1 r
.5 Mabswid
.49503 .47996 m
.57365 .45546 L
s
0 1 .632 r
.57705 .46473 m
.53291 .34755 L
s
0 0 0 r
2.5 Mabswid
.57705 .46473 Mdot
0 1 .632 r
.5 Mabswid
.48463 .60663 m
.57705 .46473 L
s
0 g
.57715 .45717 m
.55189 .39633 L
s
.65066 .44715 m
.57715 .45717 L
s
.57714 .45715 m
.65065 .44712 L
s
.59546 .52232 m
.57714 .45715 L
s
.55191 .39633 m
.57716 .45717 L
s
.57715 .45714 m
.59548 .52231 L
s
0 .702 1 r
.57933 .46825 m
.56049 .52383 L
s
0 0 0 r
2.5 Mabswid
.57933 .46825 Mdot
0 1 .381 r
.5 Mabswid
.42594 .41962 m
.57933 .46825 L
s
1 0 0 r
.33555 .61668 m
.52793 .56519 L
s
0 0 0 r
2.5 Mabswid
.58655 .30642 Mdot
1 .992 0 r
.5 Mabswid
.59684 .41342 m
.58655 .30642 L
s
0 1 .632 r
.57756 .48579 m
.58328 .45262 L
s
0 0 0 r
2.5 Mabswid
.57756 .48579 Mdot
0 1 .632 r
.5 Mabswid
.61087 .53177 m
.57756 .48579 L
s
0 0 0 r
2.5 Mabswid
.76325 .535 Mdot
.903 1 0 r
.5 Mabswid
.60646 .56764 m
.76325 .535 L
s
0 0 0 r
2.5 Mabswid
.77513 .5255 Mdot
.983 1 0 r
.5 Mabswid
.60769 .56033 m
.77513 .5255 L
s
0 .542 1 r
.56618 .46541 m
.56774 .4752 L
s
0 0 0 r
2.5 Mabswid
.56618 .46541 Mdot
0 .542 1 r
.5 Mabswid
.58295 .4572 m
.56618 .46541 L
s
0 0 0 r
2.5 Mabswid
.78718 .51592 Mdot
.989 1 0 r
.5 Mabswid
.60893 .55299 m
.78718 .51592 L
s
0 1 .394 r
.56763 .47 m
.6273 .40741 L
s
0 0 0 r
2.5 Mabswid
.56763 .47 Mdot
.865 1 0 r
.5 Mabswid
.5963 .46518 m
.56763 .47 L
s
.045 1 0 r
.5806 .50083 m
.59316 .47365 L
s
0 0 0 r
2.5 Mabswid
.5806 .50083 Mdot
.045 1 0 r
.5 Mabswid
.61904 .53422 m
.5806 .50083 L
s
0 g
.59072 .52373 m
.54199 .57204 L
s
.52262 .47919 m
.59072 .52373 L
s
.5907 .52372 m
.54188 .57208 L
s
.59983 .5857 m
.5907 .52372 L
s
.59069 .52372 m
.59547 .52228 L
s
.59982 .58571 m
.59069 .52372 L
s
.52261 .47921 m
.59071 .52375 L
s
.59548 .52231 m
.59069 .52375 L
s
.699 1 0 r
.5918 .51502 m
.5031 .492 L
s
0 0 0 r
2.5 Mabswid
.5918 .51502 Mdot
.699 1 0 r
.5 Mabswid
.62486 .53691 m
.5918 .51502 L
s
1 0 0 r
.33267 .61416 m
.52284 .56268 L
s
.741 1 0 r
.57179 .48458 m
.53347 .65735 L
s
0 0 0 r
2.5 Mabswid
.57179 .48458 Mdot
.741 1 0 r
.5 Mabswid
.58382 .47126 m
.57179 .48458 L
s
0 0 0 r
2.5 Mabswid
.79423 .50735 Mdot
.996 1 0 r
.5 Mabswid
.61021 .5456 m
.79423 .50735 L
s
.261 1 0 r
.28294 .4579 m
.42548 .4544 L
s
0 g
.59544 .52232 m
.66 .48801 L
s
.65063 .44713 m
.59544 .52232 L
s
.59546 .52229 m
.65997 .48799 L
s
.60468 .58432 m
.59546 .52229 L
s
.65065 .44712 m
.59546 .52232 L
s
.59547 .52228 m
.60469 .58431 L
s
0 0 0 r
2.5 Mabswid
.73442 .56474 Mdot
.16 0 1 r
.5 Mabswid
.62122 .55943 m
.73442 .56474 L
s
0 0 0 r
2.5 Mabswid
.59105 .50249 Mdot
0 .686 1 r
.5 Mabswid
.56833 .50032 m
.59105 .50249 L
s
0 0 0 r
2.5 Mabswid
.58382 .47126 Mdot
.741 1 0 r
.5 Mabswid
.45035 .37113 m
.58382 .47126 L
s
0 0 0 r
2.5 Mabswid
.59025 .49773 Mdot
0 .931 1 r
.5 Mabswid
.54541 .49481 m
.59025 .49773 L
s
0 0 0 r
2.5 Mabswid
.79253 .50402 Mdot
0 .892 1 r
.5 Mabswid
.61222 .50131 m
.79253 .50402 L
s
.933 1 0 r
.33001 .61183 m
.50822 .55494 L
s
1 0 0 r
.32977 .61163 m
.51774 .56017 L
s
1 .246 0 r
.26761 .41538 m
.4228 .45253 L
s
0 0 0 r
2.5 Mabswid
.7913 .50082 Mdot
1 .998 0 r
.5 Mabswid
.6115 .53817 m
.7913 .50082 L
s
0 .989 1 r
.58953 .48975 m
.56873 .51654 L
s
0 0 0 r
2.5 Mabswid
.58953 .48975 Mdot
0 .989 1 r
.5 Mabswid
.49264 .43463 m
.58953 .48975 L
s
0 0 0 r
2.5 Mabswid
.56833 .50032 Mdot
0 1 .693 r
.5 Mabswid
.47793 .4731 m
.56833 .50032 L
s
.741 1 0 r
.5517 .45547 m
.59813 .49221 L
s
0 0 0 r
2.5 Mabswid
.5517 .45547 Mdot
.741 1 0 r
.5 Mabswid
.54434 .35165 m
.5517 .45547 L
s
.732 1 0 r
.57564 .5197 m
.5986 .516 L
s
0 0 0 r
2.5 Mabswid
.57564 .5197 Mdot
.732 1 0 r
.5 Mabswid
.48715 .42182 m
.57564 .5197 L
s
0 0 0 r
2.5 Mabswid
.58295 .4572 Mdot
0 .542 1 r
.5 Mabswid
.47459 .40903 m
.58295 .4572 L
s
1 0 0 r
.32687 .60909 m
.51264 .55765 L
s
0 0 0 r
2.5 Mabswid
.78835 .49426 Mdot
1 .991 0 r
.5 Mabswid
.61283 .5307 m
.78835 .49426 L
s
.934 1 0 r
.32635 .60864 m
.50545 .55176 L
s
0 .542 1 r
.55853 .49016 m
.59924 .49604 L
s
0 0 0 r
2.5 Mabswid
.55853 .49016 Mdot
0 .542 1 r
.5 Mabswid
.46966 .35568 m
.55853 .49016 L
s
0 1 .381 r
.56113 .41675 m
.54267 .44695 L
s
0 0 0 r
2.5 Mabswid
.56113 .41675 Mdot
0 1 .381 r
.5 Mabswid
.52747 .41365 m
.56113 .41675 L
s
1 .244 0 r
.26437 .41453 m
.42434 .45204 L
s
0 0 0 r
2.5 Mabswid
.42004 .30091 Mdot
.479 1 0 r
.5 Mabswid
.44879 .32867 m
.42004 .30091 L
s
0 .989 1 r
.58304 .53699 m
.6067 .59349 L
s
0 0 0 r
2.5 Mabswid
.58304 .53699 Mdot
0 .989 1 r
.5 Mabswid
.56873 .51654 m
.53289 .65539 L
s
0 0 0 r
2.5 Mabswid
.56873 .51654 Mdot
.732 1 0 r
.5 Mabswid
.5986 .516 m
.46366 .57145 L
s
0 0 0 r
2.5 Mabswid
.5986 .516 Mdot
1 0 0 r
.5 Mabswid
.32395 .60653 m
.50822 .55494 L
s
.8 1 0 r
.54466 .46181 m
.57879 .62224 L
s
0 0 0 r
2.5 Mabswid
.54466 .46181 Mdot
.8 1 0 r
.5 Mabswid
.58384 .43437 m
.54466 .46181 L
s
0 1 .632 r
.54714 .39898 m
.54968 .38795 L
s
0 0 0 r
2.5 Mabswid
.54714 .39898 Mdot
0 1 .632 r
.5 Mabswid
.56736 .41497 m
.54714 .39898 L
s
0 g
.54716 .39792 m
.51767 .3488 L
s
.48168 .39997 m
.54716 .39792 L
s
.54716 .39789 m
.52275 .47925 L
s
.48169 .39995 m
.54716 .39789 L
s
.55192 .39636 m
.54715 .39792 L
s
.54715 .39792 m
.51766 .3488 L
s
.54714 .39789 m
.52261 .47923 L
s
.54714 .3979 m
.55191 .39633 L
s
.045 1 0 r
.55113 .4904 m
.52403 .3379 L
s
0 0 0 r
2.5 Mabswid
.55113 .4904 Mdot
.045 1 0 r
.5 Mabswid
.61385 .53522 m
.55113 .4904 L
s
0 1 .632 r
.58328 .45262 m
.47654 .31552 L
s
0 0 0 r
2.5 Mabswid
.58328 .45262 Mdot
.7204 .28807 Mdot
0 .123 1 r
.5 Mabswid
.61394 .43285 m
.7204 .28807 L
s
.934 1 0 r
.32268 .60542 m
.50266 .54856 L
s
0 1 .381 r
.54267 .44695 m
.51744 .51031 L
s
0 0 0 r
2.5 Mabswid
.54267 .44695 Mdot
.741 1 0 r
.5 Mabswid
.56661 .52063 m
.58054 .54402 L
s
0 0 0 r
2.5 Mabswid
.56661 .52063 Mdot
.741 1 0 r
.5 Mabswid
.59971 .4964 m
.56661 .52063 L
s
0 g
.55187 .39633 m
.65067 .44712 L
s
.63396 .41193 m
.55187 .39633 L
s
.55191 .39635 m
.5225 .34715 L
s
.634 .41195 m
.55191 .39635 L
s
.55189 .39633 m
.65066 .44715 L
s
.52251 .34715 m
.55192 .39636 L
s
0 0 0 r
2.5 Mabswid
.7454 .36046 Mdot
0 .244 1 r
.5 Mabswid
.62465 .41884 m
.7454 .36046 L
s
1 .242 0 r
.2611 .41368 m
.42589 .45154 L
s
0 .989 1 r
.54188 .4146 m
.56392 .58449 L
s
0 0 0 r
2.5 Mabswid
.54188 .4146 Mdot
0 .989 1 r
.5 Mabswid
.54928 .39019 m
.54188 .4146 L
s
1 0 0 r
.32102 .60397 m
.50545 .55176 L
s
0 .538 1 r
.53914 .43224 m
.52622 .56278 L
s
0 0 0 r
2.5 Mabswid
.53914 .43224 Mdot
0 .538 1 r
.5 Mabswid
.55383 .39585 m
.53914 .43224 L
s
0 0 0 r
2.5 Mabswid
.54541 .49481 Mdot
0 1 .676 r
.5 Mabswid
.4856 .47658 m
.54541 .49481 L
s
.493 1 0 r
.25545 .39983 m
.49939 .57961 L
s
0 .989 1 r
.56399 .52636 m
.61071 .5761 L
s
0 0 0 r
2.5 Mabswid
.56399 .52636 Mdot
0 .989 1 r
.5 Mabswid
.53296 .3542 m
.56399 .52636 L
s
.934 1 0 r
.31899 .60219 m
.49986 .54535 L
s
.797 1 0 r
.5326 .46897 m
.6037 .48326 L
s
0 0 0 r
2.5 Mabswid
.5326 .46897 Mdot
.797 1 0 r
.5 Mabswid
.49242 .41679 m
.5326 .46897 L
s
1 0 0 r
.31808 .6014 m
.50266 .54856 L
s
0 .2 1 r
.55999 .52345 m
.60456 .52702 L
s
0 0 0 r
2.5 Mabswid
.55999 .52345 Mdot
0 .2 1 r
.5 Mabswid
.4375 .36452 m
.55999 .52345 L
s
0 0 0 r
2.5 Mabswid
.55383 .39585 Mdot
0 .538 1 r
.5 Mabswid
.50405 .40783 m
.55383 .39585 L
s
1 .24 0 r
.25781 .41282 m
.42746 .45104 L
s
.57 1 0 r
.25701 .41043 m
.50109 .58891 L
s
.045 1 0 r
.59316 .47365 m
.58753 .38748 L
s
0 0 0 r
2.5 Mabswid
.59316 .47365 Mdot
.54928 .39019 Mdot
0 .989 1 r
.5 Mabswid
.48085 .39472 m
.54928 .39019 L
s
.514 1 0 r
.53321 .42422 m
.59579 .48386 L
s
0 0 0 r
2.5 Mabswid
.53321 .42422 Mdot
.514 1 0 r
.5 Mabswid
.57598 .4185 m
.53321 .42422 L
s
.741 1 0 r
.59813 .49221 m
.58988 .66829 L
s
0 0 0 r
2.5 Mabswid
.59813 .49221 Mdot
.389 1 0 r
.5 Mabswid
.56811 .54245 m
.28729 .28751 L
s
.371 1 0 r
.56811 .54245 m
.62147 .40374 L
s
0 0 0 r
2.5 Mabswid
.56811 .54245 Mdot
.803 1 0 r
.5 Mabswid
.61953 .54311 m
.56811 .54245 L
s
0 .542 1 r
.56064 .40457 m
.51304 .54426 L
s
0 0 0 r
2.5 Mabswid
.56064 .40457 Mdot
0 .542 1 r
.5 Mabswid
.52447 .39623 m
.56064 .40457 L
s
.59924 .49604 m
.51314 .63662 L
s
0 0 0 r
2.5 Mabswid
.59924 .49604 Mdot
0 .414 1 r
.5 Mabswid
.33488 .66001 m
.44862 .53519 L
s
.934 1 0 r
.31527 .59894 m
.49704 .54212 L
s
.327 1 0 r
.56238 .53597 m
.28918 .28046 L
s
.435 1 0 r
.56238 .53597 m
.61402 .39874 L
s
0 0 0 r
2.5 Mabswid
.56238 .53597 Mdot
.806 1 0 r
.5 Mabswid
.62327 .53666 m
.56238 .53597 L
s
1 0 0 r
.31514 .59882 m
.49986 .54535 L
s
0 0 0 r
2.5 Mabswid
.59971 .4964 Mdot
.741 1 0 r
.5 Mabswid
.4266 .40977 m
.59971 .4964 L
s
0 .332 1 r
.20928 .31637 m
.52676 .46126 L
s
0 0 0 r
2.5 Mabswid
.52676 .46126 Mdot
0 .364 1 r
.5 Mabswid
.62398 .48586 m
.52676 .46126 L
s
0 0 0 r
2.5 Mabswid
.56736 .41497 Mdot
0 1 .632 r
.5 Mabswid
.63182 .51215 m
.56736 .41497 L
s
0 1 .37 r
.55663 .52947 m
.29138 .27185 L
s
.699 1 0 r
.55663 .52947 m
.60659 .39375 L
s
0 0 0 r
2.5 Mabswid
.55663 .52947 Mdot
.81 1 0 r
.5 Mabswid
.62702 .53017 m
.55663 .52947 L
s
.741 1 0 r
.52616 .45941 m
.51289 .5813 L
s
0 0 0 r
2.5 Mabswid
.52616 .45941 Mdot
.741 1 0 r
.5 Mabswid
.56413 .40536 m
.52616 .45941 L
s
0 .989 1 r
.60178 .57312 m
.56419 .63979 L
s
0 0 0 r
2.5 Mabswid
.60178 .57312 Mdot
0 .989 1 r
.5 Mabswid
.46779 .34482 m
.60178 .57312 L
s
0 g
.52264 .47921 m
.508 .52596 L
s
.48398 .45747 m
.52264 .47921 L
s
.50799 .52594 m
.52262 .47919 L
s
.52275 .47925 m
.48398 .4575 L
s
0 .2 1 r
.60456 .52702 m
.47113 .53303 L
s
0 0 0 r
2.5 Mabswid
.60456 .52702 Mdot
0 .327 1 r
.5 Mabswid
.52394 .46554 m
.60063 .40145 L
s
0 0 0 r
2.5 Mabswid
.52394 .46554 Mdot
0 .327 1 r
.5 Mabswid
.62909 .57203 m
.52394 .46554 L
s
1 .356 0 r
.25449 .41196 m
.42903 .45053 L
s
0 .364 1 r
.52989 .41128 m
.55935 .38224 L
s
0 0 0 r
2.5 Mabswid
.52989 .41128 Mdot
0 .364 1 r
.5 Mabswid
.57768 .42131 m
.52989 .41128 L
s
0 .989 1 r
.52651 .43894 m
.59057 .6499 L
s
0 0 0 r
2.5 Mabswid
.52651 .43894 Mdot
0 .989 1 r
.5 Mabswid
.56584 .39527 m
.52651 .43894 L
s
1 0 0 r
.31217 .59623 m
.49704 .54212 L
s
0 1 .632 r
.54968 .38795 m
.51165 .33921 L
s
0 0 0 r
2.5 Mabswid
.54968 .38795 Mdot
.934 1 0 r
.5 Mabswid
.31154 .59568 m
.49421 .53888 L
s
0 0 0 r
2.5 Mabswid
.52747 .41365 Mdot
0 1 .381 r
.5 Mabswid
.4427 .40461 m
.52747 .41365 L
s
0 0 0 r
2.5 Mabswid
.52888 .40079 Mdot
0 .739 1 r
.5 Mabswid
.63649 .45112 m
.52888 .40079 L
s
0 0 0 r
2.5 Mabswid
.56413 .40536 Mdot
.741 1 0 r
.5 Mabswid
.45864 .39291 m
.56413 .40536 L
s
0 .542 1 r
.53041 .39302 m
.56538 .40697 L
s
0 0 0 r
2.5 Mabswid
.53041 .39302 Mdot
0 .542 1 r
.5 Mabswid
.52821 .36884 m
.53041 .39302 L
s
0 g
.59982 .58568 m
.60468 .58428 L
s
.59825 .63685 m
.59982 .58568 L
s
.59983 .58569 m
.54188 .57206 L
s
.59826 .63686 m
.59983 .58569 L
s
.54188 .57208 m
.59983 .5857 L
s
.60469 .58431 m
.59982 .58571 L
s
0 .542 1 r
.56538 .40697 m
.56436 .65617 L
s
0 0 0 r
2.5 Mabswid
.56538 .40697 Mdot
0 .038 1 r
.5 Mabswid
.5248 .41821 m
.56259 .3796 L
s
0 0 0 r
2.5 Mabswid
.5248 .41821 Mdot
0 .038 1 r
.5 Mabswid
.63882 .54454 m
.5248 .41821 L
s
.778 1 0 r
.54663 .52771 m
.59278 .43365 L
s
0 0 0 r
2.5 Mabswid
.54663 .52771 Mdot
.778 1 0 r
.5 Mabswid
.60624 .61361 m
.54663 .52771 L
s
0 0 0 r
2.5 Mabswid
.28729 .28751 Mdot
0 g
.5 Mabswid
.60467 .5843 m
.65997 .48797 L
s
.60324 .63549 m
.60467 .5843 L
s
.65997 .48799 m
.60468 .58432 L
s
.60468 .58428 m
.60325 .63547 L
s
1 0 0 r
.3092 .59363 m
.49421 .53888 L
s
0 0 0 r
2.5 Mabswid
.5963 .46518 Mdot
.865 1 0 r
.5 Mabswid
.62987 .46832 m
.5963 .46518 L
s
0 1 .632 r
.52135 .42132 m
.50644 .35196 L
s
0 0 0 r
2.5 Mabswid
.52135 .42132 Mdot
0 1 .632 r
.5 Mabswid
.59203 .45051 m
.52135 .42132 L
s
0 .502 1 r
.21761 .30727 m
.46723 .42606 L
s
.934 1 0 r
.30779 .59239 m
.49137 .53561 L
s
0 0 0 r
2.5 Mabswid
.52447 .39623 Mdot
0 .542 1 r
.5 Mabswid
.43263 .38427 m
.52447 .39623 L
s
0 .038 1 r
.54264 .5287 m
.60486 .46758 L
s
0 0 0 r
2.5 Mabswid
.54264 .5287 Mdot
0 .038 1 r
.5 Mabswid
.56263 .59001 m
.54264 .5287 L
s
0 0 0 r
2.5 Mabswid
.37043 .28226 Mdot
0 1 .779 r
.5 Mabswid
.49182 .35202 m
.37043 .28226 L
s
0 0 0 r
2.5 Mabswid
.59203 .45051 Mdot
0 1 .632 r
.5 Mabswid
.59396 .65752 m
.59203 .45051 L
s
.045 1 0 r
.60646 .56764 m
.45138 .44286 L
s
0 0 0 r
2.5 Mabswid
.60646 .56764 Mdot
1 .866 0 r
.5 Mabswid
.58281 .58169 m
.60646 .56764 L
s
0 g
.40289 .89622 m
.64756 .83863 L
s
1 0 0 r
.30622 .59102 m
.49137 .53561 L
s
0 0 0 r
2.5 Mabswid
.58384 .43437 Mdot
.8 1 0 r
.5 Mabswid
.46808 .4628 m
.58384 .43437 L
s
0 .932 1 r
.51496 .48523 m
.63395 .42675 L
s
0 0 0 r
2.5 Mabswid
.51496 .48523 Mdot
0 1 .063 r
.5 Mabswid
.65285 .47776 m
.51496 .48523 L
s
0 0 0 r
2.5 Mabswid
.58281 .58169 Mdot
.8 1 0 r
.5 Mabswid
.58281 .58169 m
.58281 .58169 L
s
0 0 0 r
2.5 Mabswid
.58281 .58169 Mdot
.8 1 0 r
.5 Mabswid
.58281 .58169 m
.58281 .58169 L
s
0 0 0 r
2.5 Mabswid
.58281 .58169 Mdot
.8 1 0 r
.5 Mabswid
.58281 .58169 m
.58281 .58169 L
s
.58281 .58169 m
.58281 .58169 L
s
0 0 0 r
2.5 Mabswid
.58281 .58169 Mdot
.8 1 0 r
.5 Mabswid
.58281 .58169 m
.58281 .58169 L
s
0 0 0 r
2.5 Mabswid
.58281 .58169 Mdot
1 .058 0 r
.5 Mabswid
.58281 .58169 m
.58281 .58169 L
s
0 0 0 r
2.5 Mabswid
.58281 .58169 Mdot
.58281 .58169 Mdot
0 1 .381 r
.5 Mabswid
.5142 .48378 m
.61865 .47554 L
s
0 0 0 r
2.5 Mabswid
.5142 .48378 Mdot
.142 1 0 r
.5 Mabswid
.61161 .41667 m
.5142 .48378 L
s
.022 1 0 r
.60769 .56033 m
.44178 .42531 L
s
0 0 0 r
2.5 Mabswid
.60769 .56033 Mdot
1 .878 0 r
.5 Mabswid
.57497 .57985 m
.60769 .56033 L
s
0 0 0 r
2.5 Mabswid
.57598 .4185 Mdot
.514 1 0 r
.5 Mabswid
.5173 .59767 m
.57598 .4185 L
s
0 0 0 r
2.5 Mabswid
.57768 .42131 Mdot
0 .364 1 r
.5 Mabswid
.57923 .64344 m
.57768 .42131 L
s
.934 1 0 r
.30401 .58909 m
.48851 .53234 L
s
.797 1 0 r
.6037 .48326 m
.51187 .63705 L
s
0 0 0 r
2.5 Mabswid
.6037 .48326 Mdot
.28918 .28046 Mdot
0 1 .381 r
.5 Mabswid
.51502 .49676 m
.63382 .55164 L
s
0 0 0 r
2.5 Mabswid
.51502 .49676 Mdot
0 1 .381 r
.5 Mabswid
.59237 .38742 m
.51502 .49676 L
s
0 0 0 r
2.5 Mabswid
.57497 .57985 Mdot
.765 1 0 r
.5 Mabswid
.57497 .57985 m
.57497 .57985 L
s
0 0 0 r
2.5 Mabswid
.57497 .57985 Mdot
.765 1 0 r
.5 Mabswid
.57497 .57985 m
.57497 .57985 L
s
0 0 0 r
2.5 Mabswid
.57497 .57985 Mdot
.765 1 0 r
.5 Mabswid
.57497 .57985 m
.57497 .57985 L
s
.57497 .57985 m
.57497 .57985 L
s
0 0 0 r
2.5 Mabswid
.57497 .57985 Mdot
.765 1 0 r
.5 Mabswid
.57497 .57985 m
.57497 .57985 L
s
0 0 0 r
2.5 Mabswid
.57497 .57985 Mdot
1 .059 0 r
.5 Mabswid
.57497 .57985 m
.57497 .57985 L
s
0 0 0 r
2.5 Mabswid
.57497 .57985 Mdot
.57497 .57985 Mdot
1 0 0 r
.5 Mabswid
.30322 .5884 m
.48851 .53234 L
s
.031 1 0 r
.60893 .55299 m
.43956 .41355 L
s
0 0 0 r
2.5 Mabswid
.60893 .55299 Mdot
1 .871 0 r
.5 Mabswid
.56715 .57801 m
.60893 .55299 L
s
0 .989 1 r
.54597 .55088 m
.54556 .52159 L
s
0 0 0 r
2.5 Mabswid
.54597 .55088 Mdot
0 .989 1 r
.5 Mabswid
.62002 .51676 m
.54597 .55088 L
s
0 0 0 r
2.5 Mabswid
.60834 .49868 Mdot
0 .282 1 r
.5 Mabswid
.50004 .47847 m
.60834 .49868 L
s
0 .989 1 r
.60282 .59552 m
.5753 .59939 L
s
0 0 0 r
2.5 Mabswid
.60282 .59552 Mdot
0 .989 1 r
.5 Mabswid
.611 .57358 m
.60282 .59552 L
s
0 0 0 r
2.5 Mabswid
.56715 .57801 Mdot
.766 1 0 r
.5 Mabswid
.56715 .57801 m
.56715 .57801 L
s
0 0 0 r
2.5 Mabswid
.56715 .57801 Mdot
.766 1 0 r
.5 Mabswid
.56715 .57801 m
.56715 .57801 L
s
0 0 0 r
2.5 Mabswid
.56715 .57801 Mdot
.766 1 0 r
.5 Mabswid
.56715 .57801 m
.56715 .57801 L
s
.56715 .57801 m
.56715 .57801 L
s
0 0 0 r
2.5 Mabswid
.56715 .57801 Mdot
.766 1 0 r
.5 Mabswid
.56715 .57801 m
.56715 .57801 L
s
0 0 0 r
2.5 Mabswid
.56715 .57801 Mdot
1 .059 0 r
.5 Mabswid
.56715 .57801 m
.56715 .57801 L
s
0 0 0 r
2.5 Mabswid
.56715 .57801 Mdot
.56715 .57801 Mdot
0 1 .381 r
.5 Mabswid
.51744 .51031 m
.50773 .55186 L
s
0 0 0 r
2.5 Mabswid
.51744 .51031 Mdot
.039 1 0 r
.5 Mabswid
.61021 .5456 m
.4389 .40293 L
s
0 0 0 r
2.5 Mabswid
.61021 .5456 Mdot
1 .864 0 r
.5 Mabswid
.55936 .57618 m
.61021 .5456 L
s
0 0 0 r
2.5 Mabswid
.61087 .53177 Mdot
0 1 .632 r
.5 Mabswid
.61419 .61123 m
.61087 .53177 L
s
.934 1 0 r
.30022 .58577 m
.48564 .52904 L
s
.746 1 0 r
.54564 .5593 m
.54517 .50741 L
s
0 0 0 r
2.5 Mabswid
.54564 .5593 Mdot
.746 1 0 r
.5 Mabswid
.62247 .53096 m
.54564 .5593 L
s
0 0 0 r
2.5 Mabswid
.55936 .57618 Mdot
.767 1 0 r
.5 Mabswid
.55936 .57618 m
.55936 .57618 L
s
0 0 0 r
2.5 Mabswid
.55936 .57618 Mdot
.767 1 0 r
.5 Mabswid
.55936 .57618 m
.55936 .57618 L
s
0 0 0 r
2.5 Mabswid
.55936 .57618 Mdot
.767 1 0 r
.5 Mabswid
.55936 .57618 m
.55936 .57618 L
s
.55936 .57618 m
.55936 .57618 L
s
0 0 0 r
2.5 Mabswid
.55936 .57618 Mdot
.767 1 0 r
.5 Mabswid
.55936 .57618 m
.55936 .57618 L
s
0 0 0 r
2.5 Mabswid
.55936 .57618 Mdot
1 .06 0 r
.5 Mabswid
.55936 .57618 m
.55936 .57618 L
s
0 0 0 r
2.5 Mabswid
.55936 .57618 Mdot
.55936 .57618 Mdot
.047 1 0 r
.5 Mabswid
.6115 .53817 m
.4382 .39217 L
s
0 0 0 r
2.5 Mabswid
.6115 .53817 Mdot
1 .857 0 r
.5 Mabswid
.55159 .57435 m
.6115 .53817 L
s
0 0 0 r
2.5 Mabswid
.79371 .5826 Mdot
0 1 .704 r
.5 Mabswid
.6358 .56088 m
.79371 .5826 L
s
.741 1 0 r
.60957 .49452 m
.48913 .59016 L
s
0 0 0 r
2.5 Mabswid
.60957 .49452 Mdot
.741 1 0 r
.5 Mabswid
.4941 .48279 m
.60957 .49452 L
s
0 .829 1 r
.5122 .39063 m
.57632 .67243 L
s
0 0 0 r
2.5 Mabswid
.5122 .39063 Mdot
0 .829 1 r
.5 Mabswid
.54138 .36119 m
.5122 .39063 L
s
0 .542 1 r
.5105 .50585 m
.61387 .55975 L
s
0 0 0 r
2.5 Mabswid
.5105 .50585 Mdot
0 .542 1 r
.5 Mabswid
.50566 .34459 m
.5105 .50585 L
s
0 1 .381 r
.5357 .54924 m
.60885 .62308 L
s
0 0 0 r
2.5 Mabswid
.5357 .54924 Mdot
0 1 .381 r
.5 Mabswid
.52931 .34401 m
.5357 .54924 L
s
1 0 0 r
.2972 .58313 m
.48275 .52573 L
s
0 0 0 r
2.5 Mabswid
.611 .57358 Mdot
0 .989 1 r
.5 Mabswid
.61126 .57259 m
.611 .57358 L
s
0 0 0 r
2.5 Mabswid
.61126 .57259 Mdot
0 .989 1 r
.5 Mabswid
.61706 .44394 m
.61126 .57259 L
s
.045 1 0 r
.5044 .4866 m
.50527 .33203 L
s
0 0 0 r
2.5 Mabswid
.5044 .4866 Mdot
.045 1 0 r
.5 Mabswid
.59275 .63723 m
.5044 .4866 L
s
0 0 0 r
2.5 Mabswid
.61222 .50131 Mdot
0 1 .797 r
.5 Mabswid
.49315 .47925 m
.61222 .50131 L
s
.056 1 0 r
.61283 .5307 m
.43807 .38175 L
s
0 0 0 r
2.5 Mabswid
.61283 .5307 Mdot
1 .85 0 r
.5 Mabswid
.54385 .57253 m
.61283 .5307 L
s
0 0 0 r
2.5 Mabswid
.55159 .57435 Mdot
.768 1 0 r
.5 Mabswid
.55159 .57435 m
.55159 .57435 L
s
0 0 0 r
2.5 Mabswid
.55159 .57435 Mdot
.768 1 0 r
.5 Mabswid
.55159 .57435 m
.55159 .57435 L
s
0 0 0 r
2.5 Mabswid
.55159 .57435 Mdot
.768 1 0 r
.5 Mabswid
.55159 .57435 m
.55159 .57435 L
s
.55159 .57435 m
.55159 .57435 L
s
0 0 0 r
2.5 Mabswid
.55159 .57435 Mdot
.768 1 0 r
.5 Mabswid
.55159 .57435 m
.55159 .57435 L
s
0 0 0 r
2.5 Mabswid
.55159 .57435 Mdot
1 .06 0 r
.5 Mabswid
.55159 .57435 m
.55159 .57435 L
s
0 0 0 r
2.5 Mabswid
.55159 .57435 Mdot
.55159 .57435 Mdot
.934 1 0 r
.5 Mabswid
.2964 .58243 m
.48275 .52573 L
s
0 1 .643 r
.61158 .57142 m
.51962 .53695 L
s
0 0 0 r
2.5 Mabswid
.61158 .57142 Mdot
0 1 .453 r
.5 Mabswid
.52958 .6048 m
.61158 .57142 L
s
.793 1 0 r
.57876 .59182 m
.61496 .57717 L
s
0 0 0 r
2.5 Mabswid
.57876 .59182 Mdot
.793 1 0 r
.5 Mabswid
.55451 .37916 m
.57876 .59182 L
s
0 0 0 r
2.5 Mabswid
.29138 .27185 Mdot
0 .989 1 r
.5 Mabswid
.61071 .5761 m
.52566 .62136 L
s
0 0 0 r
2.5 Mabswid
.61071 .5761 Mdot
.797 1 0 r
.5 Mabswid
.5468 .57148 m
.6187 .57395 L
s
0 0 0 r
2.5 Mabswid
.5468 .57148 Mdot
.797 1 0 r
.5 Mabswid
.43829 .36058 m
.5468 .57148 L
s
0 .038 1 r
.60486 .46758 m
.43946 .3471 L
s
0 0 0 r
2.5 Mabswid
.60486 .46758 Mdot
.50405 .40783 Mdot
0 .538 1 r
.5 Mabswid
.45935 .42336 m
.50405 .40783 L
s
0 1 .846 r
.61247 .56501 m
.8092 .63718 L
s
0 .348 1 r
.61247 .56501 m
.50028 .58025 L
s
0 0 0 r
2.5 Mabswid
.61247 .56501 Mdot
0 1 .522 r
.5 Mabswid
.52288 .55109 m
.61247 .56501 L
s
.741 1 0 r
.54034 .56507 m
.53886 .51485 L
s
0 0 0 r
2.5 Mabswid
.54034 .56507 Mdot
.741 1 0 r
.5 Mabswid
.62588 .53352 m
.54034 .56507 L
s
0 0 0 r
2.5 Mabswid
.50004 .47847 Mdot
0 1 .598 r
.5 Mabswid
.4781 .3694 m
.50004 .47847 L
s
0 .989 1 r
.56392 .58449 m
.60918 .62251 L
s
0 0 0 r
2.5 Mabswid
.56392 .58449 Mdot
0 .989 1 r
.5 Mabswid
.6067 .59349 m
.57864 .63506 L
s
0 0 0 r
2.5 Mabswid
.6067 .59349 Mdot
.56584 .39527 Mdot
0 .989 1 r
.5 Mabswid
.42929 .49376 m
.56584 .39527 L
s
.741 1 0 r
.50169 .41692 m
.5616 .64794 L
s
0 0 0 r
2.5 Mabswid
.50169 .41692 Mdot
.741 1 0 r
.5 Mabswid
.55155 .36892 m
.50169 .41692 L
s
.699 1 0 r
.5031 .492 m
.47397 .47266 L
s
0 0 0 r
2.5 Mabswid
.5031 .492 Mdot
.58583 .26041 Mdot
0 .305 1 r
.5 Mabswid
.46862 .31231 m
.58583 .26041 L
s
0 0 0 r
2.5 Mabswid
.61385 .53522 Mdot
.045 1 0 r
.5 Mabswid
.53849 .65974 m
.61385 .53522 L
s
0 0 0 r
2.5 Mabswid
.54385 .57253 Mdot
.77 1 0 r
.5 Mabswid
.54385 .57253 m
.54385 .57253 L
s
0 0 0 r
2.5 Mabswid
.54385 .57253 Mdot
.77 1 0 r
.5 Mabswid
.54385 .57253 m
.54385 .57253 L
s
0 0 0 r
2.5 Mabswid
.54385 .57253 Mdot
.77 1 0 r
.5 Mabswid
.54385 .57253 m
.54385 .57253 L
s
.54385 .57253 m
.54385 .57253 L
s
0 0 0 r
2.5 Mabswid
.54385 .57253 Mdot
.77 1 0 r
.5 Mabswid
.54385 .57253 m
.54385 .57253 L
s
0 0 0 r
2.5 Mabswid
.54385 .57253 Mdot
1 .061 0 r
.5 Mabswid
.54385 .57253 m
.54385 .57253 L
s
0 0 0 r
2.5 Mabswid
.54385 .57253 Mdot
.54385 .57253 Mdot
1 0 0 r
.5 Mabswid
.29417 .58048 m
.47985 .52241 L
s
0 0 0 r
2.5 Mabswid
.52912 .55065 Mdot
0 .272 1 r
.5 Mabswid
.65798 .45487 m
.52912 .55065 L
s
0 g
.5419 .57206 m
.59828 .63686 L
s
.51009 .58652 m
.5419 .57206 L
s
.54191 .57208 m
.5101 .58654 L
s
.508 .52592 m
.54191 .57208 L
s
.54188 .57206 m
.59826 .63686 L
s
0 1 .643 r
.51962 .53695 m
.49819 .51629 L
s
0 0 0 r
2.5 Mabswid
.51962 .53695 Mdot
0 g
.5 Mabswid
.54199 .57204 m
.50799 .52594 L
s
0 1 .017 r
.50005 .41812 m
.35689 .25544 L
s
0 .038 1 r
.50005 .41812 m
.57648 .37485 L
s
0 0 0 r
2.5 Mabswid
.50005 .41812 Mdot
.06 1 0 r
.5 Mabswid
.65816 .48916 m
.50005 .41812 L
s
.746 1 0 r
.50163 .4042 m
.56289 .63843 L
s
0 0 0 r
2.5 Mabswid
.50163 .4042 Mdot
.746 1 0 r
.5 Mabswid
.54474 .36266 m
.50163 .4042 L
s
0 1 .381 r
.57805 .40966 m
.50729 .53352 L
s
0 0 0 r
2.5 Mabswid
.57805 .40966 Mdot
0 1 .381 r
.5 Mabswid
.45601 .42805 m
.57805 .40966 L
s
1 .173 0 r
.31137 .63751 m
.52285 .60586 L
s
.30931 .63131 m
.51737 .60095 L
s
0 1 .381 r
.61036 .48283 m
.55904 .6092 L
s
0 0 0 r
2.5 Mabswid
.61036 .48283 Mdot
0 1 .381 r
.5 Mabswid
.47863 .36454 m
.61036 .48283 L
s
.934 1 0 r
.29256 .57908 m
.47985 .52241 L
s
0 .542 1 r
.61387 .55975 m
.52042 .61863 L
s
0 0 0 r
2.5 Mabswid
.61387 .55975 Mdot
0 g
.5 Mabswid
.52253 .34717 m
.51768 .34882 L
s
.51768 .34882 m
.48745 .31836 L
s
.51768 .34881 m
.48745 .31835 L
s
.48169 .39998 m
.51768 .34881 L
s
0 1 .453 r
.51408 .35895 m
.52773 .35343 L
s
0 0 0 r
2.5 Mabswid
.51408 .35895 Mdot
0 1 .453 r
.5 Mabswid
.43862 .52863 m
.51408 .35895 L
s
0 g
.51767 .3488 m
.48168 .39997 L
s
.51766 .3488 m
.52251 .34715 L
s
.789 1 0 r
.57341 .5944 m
.61747 .57658 L
s
0 0 0 r
2.5 Mabswid
.57341 .5944 Mdot
.789 1 0 r
.5 Mabswid
.54871 .38045 m
.57341 .5944 L
s
0 .989 1 r
.59602 .60872 m
.60496 .61108 L
s
0 0 0 r
2.5 Mabswid
.59602 .60872 Mdot
0 .989 1 r
.5 Mabswid
.54635 .36 m
.59602 .60872 L
s
0 1 .453 r
.52773 .35343 m
.46943 .49 L
s
0 0 0 r
2.5 Mabswid
.52773 .35343 Mdot
.778 1 0 r
.5 Mabswid
.59278 .43365 m
.43788 .36521 L
s
0 0 0 r
2.5 Mabswid
.59278 .43365 Mdot
0 .038 1 r
.5 Mabswid
.61496 .50168 m
.48684 .31608 L
s
0 0 0 r
2.5 Mabswid
.61496 .50168 Mdot
0 .038 1 r
.5 Mabswid
.56559 .59563 m
.61496 .50168 L
s
1 .096 0 r
.5381 .5702 m
.63921 .52415 L
s
0 0 0 r
2.5 Mabswid
.5381 .5702 Mdot
0 g
.5 Mabswid
.50802 .52594 m
.484 .45745 L
s
.51013 .58656 m
.50802 .52594 L
s
.5101 .58654 m
.508 .52592 L
s
.508 .52596 m
.48398 .45747 L
s
0 .149 1 r
.49845 .4033 m
.5754 .62605 L
s
0 0 0 r
2.5 Mabswid
.49845 .4033 Mdot
0 .149 1 r
.5 Mabswid
.54357 .35885 m
.49845 .4033 L
s
1 0 0 r
.29112 .57782 m
.47693 .51906 L
s
0 0 0 r
2.5 Mabswid
.60243 .61158 Mdot
.114 0 1 r
.5 Mabswid
.60224 .61046 m
.60243 .61158 L
s
.741 1 0 r
.49329 .44018 m
.51315 .5444 L
s
0 0 0 r
2.5 Mabswid
.49329 .44018 Mdot
.741 1 0 r
.5 Mabswid
.50933 .33266 m
.49329 .44018 L
s
0 g
.52251 .34716 m
.4924 .31661 L
s
.63401 .41196 m
.52251 .34716 L
s
.49243 .31662 m
.52253 .34717 L
s
.5225 .34715 m
.634 .41195 L
s
0 0 0 r
2.5 Mabswid
.60224 .61046 Mdot
0 .13 1 r
.5 Mabswid
.4996 .37435 m
.60224 .61046 L
s
0 0 0 r
2.5 Mabswid
.49503 .47996 Mdot
.2 0 1 r
.5 Mabswid
.49035 .48156 m
.49503 .47996 L
s
.761 1 0 r
.25892 .58375 m
.53651 .57034 L
s
0 .627 1 r
.53651 .57034 m
.63755 .44586 L
s
0 0 0 r
2.5 Mabswid
.53651 .57034 Mdot
.737 1 0 r
.5 Mabswid
.62934 .53611 m
.53651 .57034 L
s
0 0 0 r
2.5 Mabswid
.49264 .43463 Mdot
0 .989 1 r
.5 Mabswid
.45629 .40212 m
.49264 .43463 L
s
0 0 0 r
2.5 Mabswid
.52288 .55109 Mdot
0 1 .522 r
.5 Mabswid
.44342 .35168 m
.52288 .55109 L
s
0 .267 1 r
.34558 .75404 m
.44797 .55269 L
s
0 .77 1 r
.28602 .56644 m
.43424 .385 L
s
0 .989 1 r
.5753 .59939 m
.55486 .59978 L
s
0 0 0 r
2.5 Mabswid
.5753 .59939 Mdot
.4941 .48279 Mdot
.741 1 0 r
.5 Mabswid
.47082 .39011 m
.4941 .48279 L
s
0 0 0 r
2.5 Mabswid
.49315 .47925 Mdot
0 1 .056 r
.5 Mabswid
.47166 .37122 m
.49315 .47925 L
s
.934 1 0 r
.2887 .5757 m
.47693 .51906 L
s
.045 1 0 r
.49012 .44131 m
.5322 .35213 L
s
0 0 0 r
2.5 Mabswid
.49012 .44131 Mdot
.045 1 0 r
.5 Mabswid
.63119 .55329 m
.49012 .44131 L
s
1 .096 0 r
.53302 .5677 m
.64319 .51721 L
s
0 0 0 r
2.5 Mabswid
.53302 .5677 Mdot
1 0 0 r
.5 Mabswid
.28807 .57514 m
.474 .5157 L
s
0 1 .453 r
.49054 .42501 m
.5516 .36787 L
s
0 0 0 r
2.5 Mabswid
.49054 .42501 Mdot
0 1 .453 r
.5 Mabswid
.50513 .63376 m
.49054 .42501 L
s
.778 1 0 r
.56803 .59699 m
.62001 .57598 L
s
0 0 0 r
2.5 Mabswid
.56803 .59699 Mdot
.778 1 0 r
.5 Mabswid
.54287 .38176 m
.56803 .59699 L
s
0 0 0 r
2.5 Mabswid
.56559 .59563 Mdot
0 .038 1 r
.5 Mabswid
.59508 .59566 m
.56559 .59563 L
s
0 g
.484 .45745 m
.45045 .41695 L
s
.48171 .39995 m
.484 .4575 L
s
.484 .4575 m
.45045 .417 L
s
.48398 .4575 m
.48169 .39995 L
s
1 .097 0 r
.52793 .56519 m
.64721 .5102 L
s
0 0 0 r
2.5 Mabswid
.52793 .56519 Mdot
0 .989 1 r
.5 Mabswid
.60496 .61108 m
.47813 .58383 L
s
0 0 0 r
2.5 Mabswid
.60496 .61108 Mdot
0 .538 1 r
.5 Mabswid
.52622 .56278 m
.57312 .66752 L
s
0 0 0 r
2.5 Mabswid
.52622 .56278 Mdot
0 1 .532 r
.5 Mabswid
.6189 .51511 m
.62792 .57875 L
s
0 0 0 r
2.5 Mabswid
.6189 .51511 Mdot
0 1 .381 r
.5 Mabswid
.50729 .53352 m
.6141 .61158 L
s
0 0 0 r
2.5 Mabswid
.50729 .53352 Mdot
1 0 0 r
.5 Mabswid
.285 .57246 m
.47105 .51232 L
s
.741 1 0 r
.51315 .5444 m
.59626 .65346 L
s
0 0 0 r
2.5 Mabswid
.51315 .5444 Mdot
0 .542 1 r
.5 Mabswid
.51304 .54426 m
.5782 .64743 L
s
0 0 0 r
2.5 Mabswid
.51304 .54426 Mdot
.934 1 0 r
.5 Mabswid
.28482 .5723 m
.474 .5157 L
s
0 1 .774 r
.28213 .56382 m
.43492 .37931 L
s
0 0 0 r
2.5 Mabswid
.61904 .53422 Mdot
.045 1 0 r
.5 Mabswid
.63136 .56771 m
.61904 .53422 L
s
0 1 .632 r
.57905 .60875 m
.62309 .44705 L
s
0 0 0 r
2.5 Mabswid
.57905 .60875 Mdot
0 1 .632 r
.5 Mabswid
.61815 .6017 m
.57905 .60875 L
s
0 0 0 r
2.5 Mabswid
.49035 .48156 Mdot
.2 0 1 r
.5 Mabswid
.44402 .49958 m
.49035 .48156 L
s
0 0 0 r
2.5 Mabswid
.53296 .3542 Mdot
0 .989 1 r
.5 Mabswid
.50025 .33851 m
.53296 .3542 L
s
0 0 0 r
2.5 Mabswid
.35689 .25544 Mdot
.62002 .51676 Mdot
0 .989 1 r
.5 Mabswid
.47821 .37757 m
.62002 .51676 L
s
0 1 .255 r
.57614 .39943 m
.69203 .25073 L
s
0 .711 1 r
.57614 .39943 m
.46902 .48719 L
s
0 0 0 r
2.5 Mabswid
.57614 .39943 Mdot
0 1 .145 r
.5 Mabswid
.48976 .49183 m
.57614 .39943 L
s
1 .097 0 r
.52284 .56268 m
.65128 .5031 L
s
0 0 0 r
2.5 Mabswid
.52284 .56268 Mdot
.61953 .54311 Mdot
.803 1 0 r
.5 Mabswid
.58426 .53975 m
.61953 .54311 L
s
.778 1 0 r
.48199 .43318 m
.54837 .36311 L
s
0 0 0 r
2.5 Mabswid
.48199 .43318 Mdot
.778 1 0 r
.5 Mabswid
.58597 .64355 m
.48199 .43318 L
s
1 0 0 r
.28192 .56977 m
.46809 .50893 L
s
.333 1 0 r
.60407 .61885 m
.50559 .54063 L
s
0 0 0 r
2.5 Mabswid
.60407 .61885 Mdot
.333 1 0 r
.5 Mabswid
.59003 .62176 m
.60407 .61885 L
s
0 0 0 r
2.5 Mabswid
.7489 .65517 Mdot
.834 1 0 r
.5 Mabswid
.63866 .54968 m
.7489 .65517 L
s
0 1 .532 r
.49032 .38521 m
.58584 .64275 L
s
0 0 0 r
2.5 Mabswid
.49032 .38521 Mdot
0 1 .532 r
.5 Mabswid
.5533 .36418 m
.49032 .38521 L
s
.934 1 0 r
.28092 .56889 m
.47105 .51232 L
s
.793 1 0 r
.61496 .57717 m
.50914 .3784 L
s
0 0 0 r
2.5 Mabswid
.61496 .57717 Mdot
0 1 .668 r
.5 Mabswid
.2782 .56115 m
.4356 .37358 L
s
.813 1 0 r
.52959 .57616 m
.67029 .46159 L
s
0 0 0 r
2.5 Mabswid
.52959 .57616 Mdot
1 .115 0 r
.5 Mabswid
.65035 .51877 m
.52959 .57616 L
s
.819 1 0 r
.53514 .58095 m
.58785 .38087 L
s
0 0 0 r
2.5 Mabswid
.53514 .58095 Mdot
1 .115 0 r
.5 Mabswid
.64647 .52818 m
.53514 .58095 L
s
0 0 0 r
2.5 Mabswid
.54138 .36119 Mdot
0 .829 1 r
.5 Mabswid
.43212 .44863 m
.54138 .36119 L
s
.814 1 0 r
.541 .5856 m
.59444 .38529 L
s
0 0 0 r
2.5 Mabswid
.541 .5856 Mdot
1 .115 0 r
.5 Mabswid
.64259 .53755 m
.541 .5856 L
s
.81 1 0 r
.54685 .59025 m
.60101 .38979 L
s
0 0 0 r
2.5 Mabswid
.54685 .59025 Mdot
1 .115 0 r
.5 Mabswid
.63874 .5469 m
.54685 .59025 L
s
0 g
.45045 .417 m
.48171 .39995 L
s
.48745 .31835 m
.48169 .39998 L
s
.48186 .40002 m
.45046 .41702 L
s
.48747 .31833 m
.48186 .40002 L
s
1 .097 0 r
.51774 .56017 m
.6554 .49593 L
s
0 0 0 r
2.5 Mabswid
.51774 .56017 Mdot
.741 1 0 r
.5 Mabswid
.6205 .55457 m
.4958 .60858 L
s
0 0 0 r
2.5 Mabswid
.6205 .55457 Mdot
.741 1 0 r
.5 Mabswid
.49597 .50611 m
.6205 .55457 L
s
.806 1 0 r
.5527 .5949 m
.60753 .39448 L
s
0 0 0 r
2.5 Mabswid
.5527 .5949 Mdot
1 .115 0 r
.5 Mabswid
.63489 .55621 m
.5527 .5949 L
s
0 0 0 r
2.5 Mabswid
.49597 .50611 Mdot
.741 1 0 r
.5 Mabswid
.56601 .36626 m
.49597 .50611 L
s
0 .542 1 r
.54259 .58762 m
.6232 .58674 L
s
0 0 0 r
2.5 Mabswid
.54259 .58762 Mdot
0 .542 1 r
.5 Mabswid
.51598 .33291 m
.54259 .58762 L
s
.803 1 0 r
.55854 .59954 m
.61405 .39917 L
s
0 0 0 r
2.5 Mabswid
.55854 .59954 Mdot
1 .115 0 r
.5 Mabswid
.63106 .56549 m
.55854 .59954 L
s
0 0 0 r
2.5 Mabswid
.59003 .62176 Mdot
.333 1 0 r
.5 Mabswid
.46451 .57474 m
.59003 .62176 L
s
.514 1 0 r
.51833 .56239 m
.6278 .408 L
s
0 0 0 r
2.5 Mabswid
.51833 .56239 Mdot
1 .092 0 r
.5 Mabswid
.64305 .53645 m
.51833 .56239 L
s
1 0 0 r
.27883 .56706 m
.46511 .50551 L
s
.514 1 0 r
.51332 .55626 m
.62075 .40327 L
s
0 0 0 r
2.5 Mabswid
.51332 .55626 Mdot
1 .092 0 r
.5 Mabswid
.64635 .52845 m
.51332 .55626 L
s
0 .989 1 r
.59598 .42368 m
.54077 .5936 L
s
0 0 0 r
2.5 Mabswid
.59598 .42368 Mdot
0 .989 1 r
.5 Mabswid
.44844 .36658 m
.59598 .42368 L
s
0 1 .643 r
.49819 .51629 m
.43684 .3686 L
s
0 0 0 r
2.5 Mabswid
.49819 .51629 Mdot
0 .585 1 r
.5 Mabswid
.47925 .40955 m
.29585 .19967 L
s
0 .327 1 r
.47925 .40955 m
.57088 .36966 L
s
0 0 0 r
2.5 Mabswid
.47925 .40955 Mdot
0 .884 1 r
.5 Mabswid
.63678 .46204 m
.47925 .40955 L
s
0 0 0 r
2.5 Mabswid
.62247 .53096 Mdot
.746 1 0 r
.5 Mabswid
.47911 .41199 m
.62247 .53096 L
s
.732 1 0 r
.50854 .55008 m
.62938 .50416 L
s
0 0 0 r
2.5 Mabswid
.50854 .55008 Mdot
1 .093 0 r
.5 Mabswid
.64966 .52043 m
.50854 .55008 L
s
.333 1 0 r
.50559 .54063 m
.53546 .34684 L
s
0 0 0 r
2.5 Mabswid
.50559 .54063 Mdot
.4856 .47658 Mdot
0 1 .066 r
.5 Mabswid
.46526 .37308 m
.4856 .47658 L
s
.934 1 0 r
.27699 .56545 m
.46809 .50893 L
s
0 1 .381 r
.61865 .47554 m
.52248 .5444 L
s
0 0 0 r
2.5 Mabswid
.61865 .47554 Mdot
1 .098 0 r
.5 Mabswid
.51264 .55765 m
.65957 .48867 L
s
0 0 0 r
2.5 Mabswid
.51264 .55765 Mdot
.54474 .36266 Mdot
.746 1 0 r
.5 Mabswid
.42583 .46777 m
.54474 .36266 L
s
0 1 .284 r
.51479 .56116 m
.64897 .42474 L
s
0 0 0 r
2.5 Mabswid
.51479 .56116 Mdot
.89 1 0 r
.5 Mabswid
.65556 .51407 m
.51479 .56116 L
s
0 .989 1 r
.55486 .59978 m
.50614 .59533 L
s
0 0 0 r
2.5 Mabswid
.55486 .59978 Mdot
0 1 .553 r
.5 Mabswid
.27423 .55845 m
.43629 .36781 L
s
0 0 0 r
2.5 Mabswid
.48976 .49183 Mdot
0 1 .145 r
.5 Mabswid
.63866 .54968 m
.48976 .49183 L
s
1 0 0 r
.27572 .56434 m
.46212 .50208 L
s
0 0 0 r
2.5 Mabswid
.48085 .39472 Mdot
0 .989 1 r
.5 Mabswid
.4385 .46668 m
.48085 .39472 L
s
.737 1 0 r
.5056 .54352 m
.62971 .49611 L
s
0 0 0 r
2.5 Mabswid
.5056 .54352 Mdot
1 .093 0 r
.5 Mabswid
.65298 .51241 m
.5056 .54352 L
s
1 .396 0 r
.2147 .37248 m
.4402 .45589 L
s
0 0 0 r
2.5 Mabswid
.62327 .53666 Mdot
.806 1 0 r
.5 Mabswid
.59041 .53302 m
.62327 .53666 L
s
0 0 0 r
2.5 Mabswid
.55155 .36892 Mdot
.741 1 0 r
.5 Mabswid
.42884 .4782 m
.55155 .36892 L
s
0 0 0 r
2.5 Mabswid
.62122 .55943 Mdot
.052 0 1 r
.5 Mabswid
.48509 .53546 m
.62122 .55943 L
s
0 1 .381 r
.50773 .55186 m
.51946 .62894 L
s
0 0 0 r
2.5 Mabswid
.50773 .55186 Mdot
.75398 .66608 Mdot
0 .409 1 r
.5 Mabswid
.65032 .51601 m
.75398 .66608 L
s
1 .728 0 r
.56695 .38468 m
.4773 .39768 L
s
0 0 0 r
2.5 Mabswid
.56695 .38468 Mdot
1 .728 0 r
.5 Mabswid
.52994 .64059 m
.56695 .38468 L
s
.741 1 0 r
.50266 .53697 m
.63005 .48806 L
s
0 0 0 r
2.5 Mabswid
.50266 .53697 Mdot
1 .094 0 r
.5 Mabswid
.65629 .50437 m
.50266 .53697 L
s
1 .116 0 r
.50822 .55494 m
.64427 .51532 L
s
0 0 0 r
2.5 Mabswid
.50822 .55494 Mdot
0 .038 1 r
.5 Mabswid
.56259 .3796 m
.50538 .42166 L
s
0 0 0 r
2.5 Mabswid
.56259 .3796 Mdot
0 1 .453 r
.5 Mabswid
.5516 .36787 m
.42843 .48241 L
s
0 0 0 r
2.5 Mabswid
.5516 .36787 Mdot
.934 1 0 r
.5 Mabswid
.27304 .562 m
.46511 .50551 L
s
0 .989 1 r
.50566 .54795 m
.59314 .65312 L
s
0 0 0 r
2.5 Mabswid
.50566 .54795 Mdot
0 .989 1 r
.5 Mabswid
.53773 .35375 m
.50566 .54795 L
s
.789 1 0 r
.61747 .57658 m
.51621 .38557 L
s
0 0 0 r
2.5 Mabswid
.61747 .57658 Mdot
1 0 0 r
.5 Mabswid
.2726 .56161 m
.45911 .49863 L
s
0 .989 1 r
.54077 .5936 m
.61681 .58362 L
s
0 0 0 r
2.5 Mabswid
.54077 .5936 Mdot
.62486 .53691 Mdot
.699 1 0 r
.5 Mabswid
.63036 .54134 m
.62486 .53691 L
s
1 .728 0 r
.4773 .39768 m
.57387 .56953 L
s
0 0 0 r
2.5 Mabswid
.4773 .39768 Mdot
0 g
.5 Mabswid
.59826 .63684 m
.52888 .6315 L
s
.58534 .66953 m
.59826 .63684 L
s
.59825 .63683 m
.60325 .63545 L
s
.58533 .66953 m
.59825 .63683 L
s
.59828 .63686 m
.52898 .6314 L
s
.60325 .63547 m
.59825 .63685 L
s
.778 1 0 r
.54576 .36101 m
.48067 .35507 L
s
0 0 0 r
2.5 Mabswid
.54576 .36101 Mdot
.778 1 0 r
.5 Mabswid
.53637 .59308 m
.54576 .36101 L
s
.746 1 0 r
.49973 .53041 m
.63039 .47999 L
s
0 0 0 r
2.5 Mabswid
.49973 .53041 Mdot
1 .094 0 r
.5 Mabswid
.65962 .49633 m
.49973 .53041 L
s
0 0 0 r
2.5 Mabswid
.62398 .48586 Mdot
0 .364 1 r
.5 Mabswid
.568 .5671 m
.62398 .48586 L
s
.801 1 0 r
.52765 .58532 m
.63051 .56625 L
s
0 0 0 r
2.5 Mabswid
.52765 .58532 Mdot
.801 1 0 r
.5 Mabswid
.5019 .33812 m
.52765 .58532 L
s
.797 1 0 r
.6187 .57395 m
.43058 .46449 L
s
0 0 0 r
2.5 Mabswid
.6187 .57395 Mdot
.417 1 0 r
.5 Mabswid
.54837 .36311 m
.64131 .22508 L
s
.333 1 0 r
.54837 .36311 m
.43315 .45442 L
s
0 0 0 r
2.5 Mabswid
.54837 .36311 Mdot
0 1 .381 r
.5 Mabswid
.55904 .6092 m
.60473 .61144 L
s
0 0 0 r
2.5 Mabswid
.55904 .6092 Mdot
0 g
.5 Mabswid
.60322 .63551 m
.6567 .51202 L
s
.65995 .488 m
.60322 .63551 L
s
0 1 .735 r
.62625 .51935 m
.7792 .52627 L
s
0 .418 1 r
.62625 .51935 m
.46175 .51549 L
s
0 0 0 r
2.5 Mabswid
.62625 .51935 Mdot
0 1 .592 r
.5 Mabswid
.48514 .51417 m
.62625 .51935 L
s
0 g
.60324 .63547 m
.65667 .51195 L
s
.59048 .66815 m
.60324 .63547 L
s
.60325 .63545 m
.59049 .66813 L
s
.65997 .48797 m
.60324 .63549 L
s
0 0 0 r
2.5 Mabswid
.62588 .53352 Mdot
.741 1 0 r
.5 Mabswid
.48859 .41957 m
.62588 .53352 L
s
0 .877 1 r
.62053 .46618 m
.46517 .48342 L
s
0 0 0 r
2.5 Mabswid
.62053 .46618 Mdot
0 1 .247 r
.5 Mabswid
.46421 .52642 m
.62053 .46618 L
s
0 0 0 r
2.5 Mabswid
.54357 .35885 Mdot
0 .149 1 r
.5 Mabswid
.45747 .53491 m
.54357 .35885 L
s
0 .538 1 r
.58356 .62792 m
.61157 .61695 L
s
0 0 0 r
2.5 Mabswid
.58356 .62792 Mdot
0 .538 1 r
.5 Mabswid
.63419 .50296 m
.58356 .62792 L
s
.8 1 0 r
.49679 .52385 m
.63046 .47201 L
s
0 0 0 r
2.5 Mabswid
.49679 .52385 Mdot
1 .094 0 r
.5 Mabswid
.66294 .48827 m
.49679 .52385 L
s
1 .116 0 r
.50545 .55176 m
.6472 .51022 L
s
0 0 0 r
2.5 Mabswid
.50545 .55176 Mdot
.53637 .59308 Mdot
.778 1 0 r
.5 Mabswid
.61693 .60454 m
.53637 .59308 L
s
.801 1 0 r
.59008 .63328 m
.60542 .6305 L
s
0 0 0 r
2.5 Mabswid
.59008 .63328 Mdot
.801 1 0 r
.5 Mabswid
.56492 .37726 m
.59008 .63328 L
s
1 0 0 r
.26947 .55887 m
.45609 .49516 L
s
1 .16 0 r
.25466 .51219 m
.43079 .40877 L
s
1 .398 0 r
.21018 .37172 m
.43714 .4556 L
s
.933 1 0 r
.26907 .55853 m
.46212 .50208 L
s
0 .149 1 r
.54477 .60026 m
.49866 .42223 L
s
0 0 0 r
2.5 Mabswid
.54477 .60026 Mdot
0 .149 1 r
.5 Mabswid
.62138 .56807 m
.54477 .60026 L
s
0 0 0 r
2.5 Mabswid
.50025 .33851 Mdot
0 .989 1 r
.5 Mabswid
.49213 .329 m
.50025 .33851 L
s
0 0 0 r
2.5 Mabswid
.62702 .53017 Mdot
.81 1 0 r
.5 Mabswid
.59654 .52632 m
.62702 .53017 L
s
0 .601 1 r
.62351 .47362 m
.46644 .49148 L
s
0 0 0 r
2.5 Mabswid
.62351 .47362 Mdot
0 1 .326 r
.5 Mabswid
.46542 .53465 m
.62351 .47362 L
s
0 .565 1 r
.27794 .58937 m
.46799 .45376 L
s
0 0 0 r
2.5 Mabswid
.59275 .63723 Mdot
.045 1 0 r
.5 Mabswid
.6002 .64031 m
.59275 .63723 L
s
.50527 .33203 m
.54053 .39263 L
s
0 0 0 r
2.5 Mabswid
.50527 .33203 Mdot
.62138 .56807 Mdot
0 .149 1 r
.5 Mabswid
.45419 .3425 m
.62138 .56807 L
s
0 .272 1 r
.49182 .35202 m
.60189 .39045 L
s
0 0 0 r
2.5 Mabswid
.49182 .35202 Mdot
0 1 .67 r
.5 Mabswid
.64864 .42812 m
.49182 .35202 L
s
0 0 0 r
2.5 Mabswid
.77517 .66408 Mdot
0 .339 1 r
.5 Mabswid
.63894 .54752 m
.77517 .66408 L
s
1 .116 0 r
.50266 .54856 m
.65015 .50507 L
s
0 0 0 r
2.5 Mabswid
.50266 .54856 Mdot
1 0 0 r
.5 Mabswid
.26632 .55612 m
.45304 .49167 L
s
0 0 0 r
2.5 Mabswid
.79042 .6523 Mdot
.201 1 0 r
.5 Mabswid
.64751 .52069 m
.79042 .6523 L
s
0 0 0 r
2.5 Mabswid
.53773 .35375 Mdot
0 .989 1 r
.5 Mabswid
.47217 .38616 m
.53773 .35375 L
s
0 .101 1 r
.26603 .55722 m
.55325 .6156 L
s
.142 1 0 r
.59684 .41342 m
.471 .46057 L
s
0 0 0 r
2.5 Mabswid
.59684 .41342 Mdot
1 .728 0 r
.5 Mabswid
.47121 .58787 m
.59684 .41342 L
s
0 0 0 r
2.5 Mabswid
.54635 .36 Mdot
0 .989 1 r
.5 Mabswid
.47677 .36557 m
.54635 .36 L
s
.732 1 0 r
.62938 .50416 m
.43076 .44855 L
s
0 0 0 r
2.5 Mabswid
.62938 .50416 Mdot
0 1 .532 r
.5 Mabswid
.60098 .41888 m
.55785 .62296 L
s
0 0 0 r
2.5 Mabswid
.60098 .41888 Mdot
0 1 .532 r
.5 Mabswid
.44176 .39032 m
.60098 .41888 L
s
.797 1 0 r
.52478 .58941 m
.63037 .56998 L
s
0 0 0 r
2.5 Mabswid
.52478 .58941 Mdot
.797 1 0 r
.5 Mabswid
.49875 .34032 m
.52478 .58941 L
s
.933 1 0 r
.26507 .55503 m
.45911 .49863 L
s
0 0 0 r
2.5 Mabswid
.47158 .45084 Mdot
0 1 .532 r
.5 Mabswid
.476 .38562 m
.47158 .45084 L
s
0 .149 1 r
.56888 .62241 m
.60808 .6247 L
s
0 0 0 r
2.5 Mabswid
.56888 .62241 Mdot
0 .149 1 r
.5 Mabswid
.48728 .32345 m
.56888 .62241 L
s
.778 1 0 r
.62001 .57598 m
.52332 .39278 L
s
0 0 0 r
2.5 Mabswid
.62001 .57598 Mdot
.801 1 0 r
.5 Mabswid
.60542 .6305 m
.43762 .37967 L
s
0 0 0 r
2.5 Mabswid
.60542 .6305 Mdot
.797 1 0 r
.5 Mabswid
.58545 .63526 m
.60503 .63172 L
s
0 0 0 r
2.5 Mabswid
.58545 .63526 Mdot
.797 1 0 r
.5 Mabswid
.56005 .37801 m
.58545 .63526 L
s
0 1 .928 r
.5191 .58615 m
.64043 .54068 L
s
0 0 0 r
2.5 Mabswid
.5191 .58615 Mdot
0 1 .928 r
.5 Mabswid
.52343 .36444 m
.5191 .58615 L
s
0 0 0 r
2.5 Mabswid
.50933 .33266 Mdot
.741 1 0 r
.5 Mabswid
.48565 .34297 m
.50933 .33266 L
s
0 .13 1 r
.5099 .57506 m
.6268 .58135 L
s
0 0 0 r
2.5 Mabswid
.5099 .57506 Mdot
0 .13 1 r
.5 Mabswid
.56746 .38203 m
.5099 .57506 L
s
0 0 0 r
2.5 Mabswid
.46723 .42606 Mdot
0 .588 1 r
.5 Mabswid
.66547 .46766 m
.46723 .42606 L
s
0 0 0 r
2.5 Mabswid
.47793 .4731 Mdot
0 1 .075 r
.5 Mabswid
.45887 .37499 m
.47793 .4731 L
s
0 0 0 r
2.5 Mabswid
.6002 .64031 Mdot
.045 1 0 r
.5 Mabswid
.60191 .63901 m
.6002 .64031 L
s
0 1 .754 r
.5256 .59176 m
.63692 .55044 L
s
0 0 0 r
2.5 Mabswid
.5256 .59176 Mdot
0 1 .754 r
.5 Mabswid
.53013 .36924 m
.5256 .59176 L
s
1 .401 0 r
.20561 .37094 m
.43405 .45532 L
s
0 0 0 r
2.5 Mabswid
.61706 .44394 Mdot
0 .989 1 r
.5 Mabswid
.54787 .35525 m
.61706 .44394 L
s
0 0 0 r
2.5 Mabswid
.62934 .53611 Mdot
.737 1 0 r
.5 Mabswid
.4981 .42717 m
.62934 .53611 L
s
1 0 0 r
.26316 .55335 m
.44998 .48816 L
s
.737 1 0 r
.62971 .49611 m
.43048 .439 L
s
0 0 0 r
2.5 Mabswid
.62971 .49611 Mdot
.7792 .52627 Mdot
.741 1 0 r
.5 Mabswid
.51289 .5813 m
.51667 .60033 L
s
0 0 0 r
2.5 Mabswid
.51289 .5813 Mdot
0 .829 1 r
.5 Mabswid
.58073 .63325 m
.49255 .36403 L
s
0 0 0 r
2.5 Mabswid
.58073 .63325 Mdot
0 .829 1 r
.5 Mabswid
.6054 .63082 m
.58073 .63325 L
s
0 1 .653 r
.53211 .59738 m
.63343 .56013 L
s
0 0 0 r
2.5 Mabswid
.53211 .59738 Mdot
0 1 .653 r
.5 Mabswid
.53685 .37405 m
.53211 .59738 L
s
1 .116 0 r
.49986 .54535 m
.65314 .49987 L
s
0 0 0 r
2.5 Mabswid
.49986 .54535 Mdot
0 1 .542 r
.5 Mabswid
.53863 .60302 m
.62996 .56977 L
s
0 0 0 r
2.5 Mabswid
.53863 .60302 Mdot
0 1 .542 r
.5 Mabswid
.54358 .37888 m
.53863 .60302 L
s
0 0 0 r
2.5 Mabswid
.60191 .63901 Mdot
.045 1 0 r
.5 Mabswid
.58443 .46339 m
.60191 .63901 L
s
.282 1 0 r
.52847 .59602 m
.59144 .38511 L
s
0 0 0 r
2.5 Mabswid
.52847 .59602 Mdot
1 .115 0 r
.5 Mabswid
.64887 .53005 m
.52847 .59602 L
s
0 0 0 r
2.5 Mabswid
.76872 .68048 Mdot
0 .968 1 r
.5 Mabswid
.63553 .4837 m
.76872 .68048 L
s
.933 1 0 r
.26105 .55151 m
.45609 .49516 L
s
0 .108 1 r
.26175 .55409 m
.54589 .61352 L
s
.741 1 0 r
.63005 .48806 m
.43126 .42974 L
s
0 0 0 r
2.5 Mabswid
.63005 .48806 Mdot
.55325 .6156 Mdot
0 .111 1 r
.5 Mabswid
.6279 .57702 m
.55325 .6156 L
s
0 0 0 r
2.5 Mabswid
.5533 .36418 Mdot
0 1 .532 r
.5 Mabswid
.5668 .65176 m
.5533 .36418 L
s
1 0 0 r
.25999 .55058 m
.44691 .48464 L
s
0 0 0 r
2.5 Mabswid
.63182 .51215 Mdot
0 1 .632 r
.5 Mabswid
.62669 .58223 m
.63182 .51215 L
s
0 .989 1 r
.57864 .63506 m
.55859 .67475 L
s
0 0 0 r
2.5 Mabswid
.57864 .63506 Mdot
.63036 .54134 Mdot
.699 1 0 r
.5 Mabswid
.63227 .56047 m
.63036 .54134 L
s
0 .829 1 r
.63142 .53273 m
.51743 .5963 L
s
0 0 0 r
2.5 Mabswid
.63142 .53273 Mdot
0 .829 1 r
.5 Mabswid
.43413 .37945 m
.63142 .53273 L
s
1 .116 0 r
.49704 .54212 m
.65615 .49463 L
s
0 0 0 r
2.5 Mabswid
.49704 .54212 Mdot
.47217 .38616 Mdot
0 .989 1 r
.5 Mabswid
.49048 .61275 m
.47217 .38616 L
s
.746 1 0 r
.63039 .47999 m
.43204 .42047 L
s
0 0 0 r
2.5 Mabswid
.63039 .47999 Mdot
.6054 .63082 Mdot
0 .829 1 r
.5 Mabswid
.45501 .44219 m
.6054 .63082 L
s
0 0 0 r
2.5 Mabswid
.61394 .43285 Mdot
0 .298 1 r
.5 Mabswid
.46885 .5508 m
.61394 .43285 L
s
0 0 0 r
2.5 Mabswid
.69203 .25073 Mdot
.797 1 0 r
.5 Mabswid
.60503 .63172 m
.43677 .38039 L
s
0 0 0 r
2.5 Mabswid
.60503 .63172 Mdot
.142 1 0 r
.5 Mabswid
.471 .46057 m
.62017 .42359 L
s
0 0 0 r
2.5 Mabswid
.471 .46057 Mdot
0 g
.5 Mabswid
.48787 .6054 m
.51013 .58656 L
s
.51011 .58652 m
.52891 .63152 L
s
.48785 .60536 m
.51011 .58652 L
s
.52898 .6314 m
.51009 .58652 L
s
1 .403 0 r
.20099 .37016 m
.43092 .45503 L
s
.884 1 0 r
.50053 .55608 m
.61464 .61096 L
s
0 0 0 r
2.5 Mabswid
.50053 .55608 Mdot
.884 1 0 r
.5 Mabswid
.60572 .41071 m
.50053 .55608 L
s
.797 1 0 r
.47234 .38286 m
.54623 .35611 L
s
0 0 0 r
2.5 Mabswid
.47234 .38286 Mdot
.797 1 0 r
.5 Mabswid
.58746 .6137 m
.47234 .38286 L
s
0 .042 1 r
.54589 .61352 m
.58633 .40574 L
s
0 0 0 r
2.5 Mabswid
.54589 .61352 Mdot
0 .498 1 r
.5 Mabswid
.63154 .56922 m
.54589 .61352 L
s
.933 1 0 r
.25701 .54798 m
.45304 .49167 L
s
0 0 0 r
2.5 Mabswid
.47863 .36454 Mdot
0 1 .381 r
.5 Mabswid
.51919 .34005 m
.47863 .36454 L
s
1 0 0 r
.2568 .54779 m
.44382 .48109 L
s
0 1 .632 r
.62309 .44705 m
.46369 .33731 L
s
0 0 0 r
2.5 Mabswid
.62309 .44705 Mdot
0 1 .532 r
.5 Mabswid
.55785 .62296 m
.6062 .62524 L
s
0 0 0 r
2.5 Mabswid
.55785 .62296 Mdot
.8 1 0 r
.5 Mabswid
.63046 .47201 m
.44358 .4727 L
s
0 0 0 r
2.5 Mabswid
.63046 .47201 Mdot
0 .008 1 r
.5 Mabswid
.25745 .55095 m
.53848 .61143 L
s
.797 1 0 r
.48937 .33564 m
.50722 .32905 L
s
0 0 0 r
2.5 Mabswid
.48937 .33564 Mdot
.797 1 0 r
.5 Mabswid
.54072 .62015 m
.48937 .33564 L
s
.699 1 0 r
.47397 .47266 m
.42481 .42593 L
s
0 0 0 r
2.5 Mabswid
.47397 .47266 Mdot
.48565 .34297 Mdot
.741 1 0 r
.5 Mabswid
.44948 .52336 m
.48565 .34297 L
s
.018 0 1 r
.46799 .45376 m
.6493 .42228 L
s
0 0 0 r
2.5 Mabswid
.46799 .45376 Mdot
0 .938 1 r
.5 Mabswid
.59891 .39203 m
.46799 .45376 L
s
0 0 0 r
2.5 Mabswid
.63419 .50296 Mdot
0 .538 1 r
.5 Mabswid
.6227 .42578 m
.63419 .50296 L
s
1 .116 0 r
.49421 .53888 m
.65919 .48932 L
s
0 0 0 r
2.5 Mabswid
.49421 .53888 Mdot
.778 1 0 r
.5 Mabswid
.48067 .35507 m
.52513 .41642 L
s
0 0 0 r
2.5 Mabswid
.48067 .35507 Mdot
.47677 .36557 Mdot
0 .989 1 r
.5 Mabswid
.53951 .49308 m
.47677 .36557 L
s
1 .886 0 r
.53304 .60663 m
.62099 .56274 L
s
0 0 0 r
2.5 Mabswid
.53304 .60663 Mdot
1 .886 0 r
.5 Mabswid
.61685 .40761 m
.53304 .60663 L
s
0 .57 1 r
.63337 .53509 m
.78972 .58657 L
s
0 0 0 r
2.5 Mabswid
.63337 .53509 Mdot
0 .695 1 r
.5 Mabswid
.47689 .49062 m
.63337 .53509 L
s
0 0 0 r
2.5 Mabswid
.45935 .42336 Mdot
0 .538 1 r
.5 Mabswid
.45563 .42525 m
.45935 .42336 L
s
0 0 0 r
2.5 Mabswid
.52958 .6048 Mdot
0 1 .453 r
.5 Mabswid
.47309 .59261 m
.52958 .6048 L
s
0 .046 1 r
.53848 .61143 m
.57791 .40377 L
s
0 0 0 r
2.5 Mabswid
.53848 .61143 Mdot
0 .449 1 r
.5 Mabswid
.63519 .56138 m
.53848 .61143 L
s
0 g
.15342 .22858 m
.40065 .1313 L
s
1 0 0 r
.2536 .54499 m
.44071 .47752 L
s
0 .989 1 r
.49434 .3233 m
.61055 .42199 L
s
0 0 0 r
2.5 Mabswid
.49434 .3233 Mdot
0 .989 1 r
.5 Mabswid
.47846 .3359 m
.49434 .3233 L
s
0 .829 1 r
.51743 .5963 m
.4831 .46095 L
s
0 0 0 r
2.5 Mabswid
.51743 .5963 Mdot
.933 1 0 r
.5 Mabswid
.25294 .54442 m
.44998 .48816 L
s
.797 1 0 r
.50722 .32905 m
.50256 .62258 L
s
0 0 0 r
2.5 Mabswid
.50722 .32905 Mdot
.48514 .51417 Mdot
0 1 .592 r
.5 Mabswid
.58677 .41066 m
.48514 .51417 L
s
0 .989 1 r
.61055 .42199 m
.63672 .4762 L
s
0 0 0 r
2.5 Mabswid
.61055 .42199 Mdot
.8 1 0 r
.5 Mabswid
.45783 .41825 m
.61612 .42389 L
s
0 0 0 r
2.5 Mabswid
.45783 .41825 Mdot
.8 1 0 r
.5 Mabswid
.55042 .4172 m
.45783 .41825 L
s
0 .149 1 r
.60808 .6247 m
.44776 .47755 L
s
0 0 0 r
2.5 Mabswid
.60808 .6247 Mdot
.874 1 0 r
.5 Mabswid
.49927 .561 m
.61195 .61551 L
s
0 0 0 r
2.5 Mabswid
.49927 .561 Mdot
.874 1 0 r
.5 Mabswid
.60852 .40993 m
.49927 .561 L
s
1 .116 0 r
.49137 .53561 m
.66182 .4841 L
s
0 0 0 r
2.5 Mabswid
.49137 .53561 Mdot
1 .397 0 r
.5 Mabswid
.19632 .36937 m
.42777 .45474 L
s
0 0 0 r
2.5 Mabswid
.47689 .49062 Mdot
0 .695 1 r
.5 Mabswid
.55253 .36452 m
.47689 .49062 L
s
1 0 0 r
.25038 .54217 m
.43758 .47394 L
s
.88 1 0 r
.50796 .59012 m
.65211 .4451 L
s
0 0 0 r
2.5 Mabswid
.50796 .59012 Mdot
1 .116 0 r
.5 Mabswid
.666 .4846 m
.50796 .59012 L
s
0 0 0 r
2.5 Mabswid
.63553 .4837 Mdot
0 .989 1 r
.5 Mabswid
.43301 .42358 m
.63553 .4837 L
s
.865 1 0 r
.51248 .59566 m
.65382 .45416 L
s
0 0 0 r
2.5 Mabswid
.51248 .59566 Mdot
1 .116 0 r
.5 Mabswid
.66174 .49608 m
.51248 .59566 L
s
.274 1 0 r
.50509 .58347 m
.6263 .58163 L
s
0 0 0 r
2.5 Mabswid
.50509 .58347 Mdot
1 .116 0 r
.5 Mabswid
.67026 .47312 m
.50509 .58347 L
s
0 .559 1 r
.63349 .54094 m
.78993 .59291 L
s
0 0 0 r
2.5 Mabswid
.63349 .54094 Mdot
0 .685 1 r
.5 Mabswid
.47595 .49603 m
.63349 .54094 L
s
.741 1 0 r
.51667 .60033 m
.52377 .62643 L
s
0 0 0 r
2.5 Mabswid
.51667 .60033 Mdot
.4 1 0 r
.5 Mabswid
.51737 .60095 m
.58036 .40579 L
s
0 0 0 r
2.5 Mabswid
.51737 .60095 Mdot
1 .116 0 r
.5 Mabswid
.65748 .50754 m
.51737 .60095 L
s
.933 1 0 r
.24885 .54084 m
.44691 .48464 L
s
0 0 0 r
2.5 Mabswid
.45563 .42525 Mdot
0 .538 1 r
.5 Mabswid
.42748 .44842 m
.45563 .42525 L
s
.284 1 0 r
.50261 .57658 m
.62884 .57439 L
s
0 0 0 r
2.5 Mabswid
.50261 .57658 Mdot
1 .116 0 r
.5 Mabswid
.67452 .46163 m
.50261 .57658 L
s
0 1 .968 r
.62364 .58053 m
.79001 .58936 L
s
0 .005 1 r
.62364 .58053 m
.47069 .52866 L
s
0 0 0 r
2.5 Mabswid
.62364 .58053 Mdot
0 1 .749 r
.5 Mabswid
.49485 .55904 m
.62364 .58053 L
s
0 .709 1 r
.22179 .4567 m
.42657 .41868 L
s
.406 1 0 r
.52285 .60586 m
.58677 .41066 L
s
0 0 0 r
2.5 Mabswid
.52285 .60586 Mdot
1 .116 0 r
.5 Mabswid
.65323 .519 m
.52285 .60586 L
s
0 0 0 r
2.5 Mabswid
.8092 .63718 Mdot
.298 1 0 r
.5 Mabswid
.50013 .56968 m
.63138 .56712 L
s
0 0 0 r
2.5 Mabswid
.50013 .56968 Mdot
1 .116 0 r
.5 Mabswid
.67879 .45013 m
.50013 .56968 L
s
.48851 .53234 m
.66433 .47888 L
s
0 0 0 r
2.5 Mabswid
.48851 .53234 Mdot
.45601 .42805 Mdot
0 1 .381 r
.5 Mabswid
.51524 .38061 m
.45601 .42805 L
s
1 0 0 r
.24715 .53935 m
.43443 .47033 L
s
0 1 .381 r
.60885 .62308 m
.51165 .62292 L
s
0 0 0 r
2.5 Mabswid
.60885 .62308 Mdot
.60572 .41071 Mdot
.884 1 0 r
.5 Mabswid
.4228 .45253 m
.60572 .41071 L
s
0 0 0 r
2.5 Mabswid
.63119 .55329 Mdot
.045 1 0 r
.5 Mabswid
.47446 .59716 m
.63119 .55329 L
s
0 0 0 r
2.5 Mabswid
.52931 .34401 Mdot
0 1 .381 r
.5 Mabswid
.45588 .36039 m
.52931 .34401 L
s
0 .989 1 r
.63672 .4762 m
.63172 .56844 L
s
0 0 0 r
2.5 Mabswid
.63672 .4762 Mdot
.866 1 0 r
.5 Mabswid
.49801 .56596 m
.60816 .61958 L
s
0 0 0 r
2.5 Mabswid
.49801 .56596 Mdot
.866 1 0 r
.5 Mabswid
.61134 .40915 m
.49801 .56596 L
s
0 g
.48747 .31836 m
.46068 .31258 L
s
.43929 .37675 m
.48747 .31836 L
s
.49244 .31663 m
.48746 .31837 L
s
.48746 .31837 m
.46067 .31259 L
s
.43929 .37673 m
.48747 .31833 L
s
.48745 .31836 m
.49243 .31662 L
s
0 1 .067 r
.21477 .44105 m
.45138 .44286 L
s
0 0 0 r
2.5 Mabswid
.47595 .49603 Mdot
0 .685 1 r
.5 Mabswid
.55266 .36824 m
.47595 .49603 L
s
.2 0 1 r
.63929 .50469 m
.64855 .52108 L
s
0 0 0 r
2.5 Mabswid
.63929 .50469 Mdot
0 .989 1 r
.5 Mabswid
.59314 .65312 m
.60089 .50126 L
s
0 0 0 r
2.5 Mabswid
.59314 .65312 Mdot
.8 1 0 r
.5 Mabswid
.61612 .42389 m
.59006 .62538 L
s
0 0 0 r
2.5 Mabswid
.61612 .42389 Mdot
.933 1 0 r
.5 Mabswid
.24473 .53724 m
.44382 .48109 L
s
.797 1 0 r
.54623 .35611 m
.54319 .6578 L
s
0 0 0 r
2.5 Mabswid
.54623 .35611 Mdot
0 g
.5 Mabswid
.49237 .31659 m
.634 .4119 L
s
.61909 .40225 m
.49237 .31659 L
s
.49242 .31662 m
.46578 .31078 L
s
.61914 .40228 m
.49242 .31662 L
s
.4658 .31079 m
.49244 .31663 L
s
.4924 .31661 m
.63401 .41196 L
s
1 .096 0 r
.63921 .52415 m
.58698 .44544 L
s
0 0 0 r
2.5 Mabswid
.63921 .52415 Mdot
.45629 .40212 Mdot
0 .989 1 r
.5 Mabswid
.43785 .36794 m
.45629 .40212 L
s
1 .116 0 r
.48564 .52904 m
.66686 .4736 L
s
0 0 0 r
2.5 Mabswid
.48564 .52904 Mdot
.49485 .55904 Mdot
0 1 .749 r
.5 Mabswid
.6069 .42061 m
.49485 .55904 L
s
1 0 0 r
.2439 .53651 m
.43127 .4667 L
s
0 .581 1 r
.6336 .54683 m
.79014 .5993 L
s
0 0 0 r
2.5 Mabswid
.6336 .54683 Mdot
0 .692 1 r
.5 Mabswid
.47501 .50148 m
.6336 .54683 L
s
0 g
.4393 .37672 m
.45047 .41701 L
s
.45047 .41701 m
.42567 .42944 L
s
.45045 .41695 m
.42565 .42938 L
s
.45046 .41702 m
.43929 .37673 L
s
0 0 0 r
2.5 Mabswid
.45864 .39291 Mdot
.741 1 0 r
.5 Mabswid
.43356 .41821 m
.45864 .39291 L
s
0 0 0 r
2.5 Mabswid
.63678 .46204 Mdot
0 .884 1 r
.5 Mabswid
.5958 .57306 m
.63678 .46204 L
s
0 0 0 r
2.5 Mabswid
.47846 .3359 Mdot
0 .989 1 r
.5 Mabswid
.4349 .39003 m
.47846 .3359 L
s
.60918 .62251 m
.4843 .6112 L
s
0 0 0 r
2.5 Mabswid
.60918 .62251 Mdot
0 .348 1 r
.5 Mabswid
.50028 .58025 m
.55306 .53674 L
s
0 0 0 r
2.5 Mabswid
.50028 .58025 Mdot
0 .327 1 r
.5 Mabswid
.60063 .40145 m
.57449 .43765 L
s
0 0 0 r
2.5 Mabswid
.60063 .40145 Mdot
.045 1 0 r
.5 Mabswid
.58753 .38748 m
.58009 .37739 L
s
0 0 0 r
2.5 Mabswid
.58753 .38748 Mdot
.741 1 0 r
.5 Mabswid
.53537 .6227 m
.4767 .41074 L
s
0 0 0 r
2.5 Mabswid
.53537 .6227 Mdot
.741 1 0 r
.5 Mabswid
.61894 .59967 m
.53537 .6227 L
s
0 .149 1 r
.63092 .44277 m
.51244 .61533 L
s
0 0 0 r
2.5 Mabswid
.63092 .44277 Mdot
0 .149 1 r
.5 Mabswid
.42125 .43605 m
.63092 .44277 L
s
1 0 0 r
.24064 .53366 m
.42809 .46306 L
s
.932 1 0 r
.24059 .53361 m
.44071 .47752 L
s
0 .542 1 r
.6232 .58674 m
.43265 .43302 L
s
0 0 0 r
2.5 Mabswid
.6232 .58674 Mdot
.60852 .40993 Mdot
.874 1 0 r
.5 Mabswid
.42434 .45204 m
.60852 .40993 L
s
0 .989 1 r
.50614 .59533 m
.44572 .54822 L
s
0 0 0 r
2.5 Mabswid
.50614 .59533 Mdot
1 .116 0 r
.5 Mabswid
.48275 .52573 m
.66941 .46827 L
s
0 0 0 r
2.5 Mabswid
.48275 .52573 Mdot
.857 1 0 r
.5 Mabswid
.49673 .57096 m
.60435 .62368 L
s
0 0 0 r
2.5 Mabswid
.49673 .57096 Mdot
.857 1 0 r
.5 Mabswid
.61418 .40836 m
.49673 .57096 L
s
0 1 .128 r
.49939 .57961 m
.66418 .46117 L
s
0 0 0 r
2.5 Mabswid
.49939 .57961 Mdot
.793 1 0 r
.5 Mabswid
.62487 .58677 m
.49939 .57961 L
s
0 0 0 r
2.5 Mabswid
.47501 .50148 Mdot
0 .692 1 r
.5 Mabswid
.5528 .37199 m
.47501 .50148 L
s
.741 1 0 r
.59626 .65346 m
.5814 .65534 L
s
0 0 0 r
2.5 Mabswid
.59626 .65346 Mdot
.48509 .53546 Mdot
.052 0 1 r
.5 Mabswid
.54684 .42095 m
.48509 .53546 L
s
0 1 .381 r
.63382 .55164 m
.46884 .55721 L
s
0 0 0 r
2.5 Mabswid
.63382 .55164 Mdot
.63649 .45112 Mdot
0 .739 1 r
.5 Mabswid
.65718 .50127 m
.63649 .45112 L
s
0 .538 1 r
.61157 .61695 m
.55702 .47975 L
s
0 0 0 r
2.5 Mabswid
.61157 .61695 Mdot
0 1 .003 r
.5 Mabswid
.50109 .58891 m
.66666 .47058 L
s
0 0 0 r
2.5 Mabswid
.50109 .58891 Mdot
.789 1 0 r
.5 Mabswid
.6211 .59582 m
.50109 .58891 L
s
0 1 .532 r
.46085 .45954 m
.59342 .38508 L
s
0 0 0 r
2.5 Mabswid
.46085 .45954 Mdot
.813 1 0 r
.5 Mabswid
.66454 .44197 m
.46085 .45954 L
s
1 0 0 r
.23737 .53079 m
.42555 .45914 L
s
0 .038 1 r
.56509 .64503 m
.6037 .63611 L
s
0 0 0 r
2.5 Mabswid
.56509 .64503 Mdot
0 .038 1 r
.5 Mabswid
.45294 .34536 m
.56509 .64503 L
s
0 .668 1 r
.20329 .42359 m
.44178 .42531 L
s
0 .711 1 r
.46902 .48719 m
.56867 .53083 L
s
0 0 0 r
2.5 Mabswid
.46902 .48719 Mdot
.45501 .44219 Mdot
0 .829 1 r
.5 Mabswid
.44875 .37342 m
.45501 .44219 L
s
1 .096 0 r
.64319 .51721 m
.59647 .44539 L
s
0 0 0 r
2.5 Mabswid
.64319 .51721 Mdot
1 .116 0 r
.5 Mabswid
.47985 .52241 m
.67199 .46289 L
s
0 0 0 r
2.5 Mabswid
.47985 .52241 Mdot
.932 1 0 r
.5 Mabswid
.23642 .52996 m
.43758 .47394 L
s
0 0 0 r
2.5 Mabswid
.59396 .65752 Mdot
0 1 .632 r
.5 Mabswid
.49033 .60892 m
.59396 .65752 L
s
0 0 0 r
2.5 Mabswid
.70506 .3137 Mdot
0 1 .497 r
.5 Mabswid
.62256 .42015 m
.70506 .3137 L
s
0 0 0 r
2.5 Mabswid
.6227 .42578 Mdot
0 .538 1 r
.5 Mabswid
.55164 .35918 m
.6227 .42578 L
s
0 1 .453 r
.46943 .49 m
.55064 .62752 L
s
0 0 0 r
2.5 Mabswid
.46943 .49 Mdot
.741 1 0 r
.5 Mabswid
.5814 .65534 m
.45552 .5652 L
s
0 0 0 r
2.5 Mabswid
.5814 .65534 Mdot
0 1 .522 r
.5 Mabswid
.51746 .61228 m
.5929 .66241 L
s
0 0 0 r
2.5 Mabswid
.51746 .61228 Mdot
0 1 .522 r
.5 Mabswid
.44783 .41121 m
.51746 .61228 L
s
0 0 0 r
2.5 Mabswid
.44783 .41121 Mdot
0 1 .522 r
.5 Mabswid
.49161 .32068 m
.44783 .41121 L
s
0 0 0 r
2.5 Mabswid
.78972 .58657 Mdot
0 .989 1 r
.5 Mabswid
.52566 .62136 m
.51455 .62264 L
s
0 0 0 r
2.5 Mabswid
.52566 .62136 Mdot
0 .038 1 r
.5 Mabswid
.48684 .31608 m
.45799 .5671 L
s
0 0 0 r
2.5 Mabswid
.48684 .31608 Mdot
.801 1 0 r
.5 Mabswid
.63051 .56625 m
.44342 .35168 L
s
0 0 0 r
2.5 Mabswid
.63051 .56625 Mdot
1 .116 0 r
.5 Mabswid
.64427 .51532 m
.542 .4457 L
s
0 0 0 r
2.5 Mabswid
.64427 .51532 Mdot
.61134 .40915 Mdot
.866 1 0 r
.5 Mabswid
.42589 .45154 m
.61134 .40915 L
s
0 g
.64756 .83863 m
.837 .79404 L
s
.39703 .58293 m
.64756 .83863 L
s
.746 1 0 r
.52412 .62138 m
.6069 .42061 L
s
0 0 0 r
2.5 Mabswid
.52412 .62138 Mdot
.746 1 0 r
.5 Mabswid
.6212 .59464 m
.52412 .62138 L
s
1 0 0 r
.23408 .52791 m
.42474 .45452 L
s
1 .984 0 r
.58469 .65867 m
.46773 .7494 L
s
.388 1 0 r
.58469 .65867 m
.61011 .59918 L
s
0 0 0 r
2.5 Mabswid
.58469 .65867 Mdot
1 .886 0 r
.5 Mabswid
.60582 .63093 m
.58469 .65867 L
s
.045 1 0 r
.52403 .3379 m
.44517 .35589 L
s
0 0 0 r
2.5 Mabswid
.52403 .3379 Mdot
.79001 .58936 Mdot
.63106 .56549 Mdot
1 .115 0 r
.5 Mabswid
.56961 .41428 m
.63106 .56549 L
s
1 .116 0 r
.47693 .51906 m
.6746 .45745 L
s
0 0 0 r
2.5 Mabswid
.47693 .51906 Mdot
.60582 .63093 Mdot
1 .886 0 r
.5 Mabswid
.63409 .43551 m
.60582 .63093 L
s
0 0 0 r
2.5 Mabswid
.62909 .57203 Mdot
0 .327 1 r
.5 Mabswid
.48528 .61027 m
.62909 .57203 L
s
.932 1 0 r
.23223 .52629 m
.43443 .47033 L
s
0 .542 1 r
.52042 .61863 m
.53667 .57941 L
s
0 0 0 r
2.5 Mabswid
.52042 .61863 Mdot
.8 1 0 r
.5 Mabswid
.46677 .3492 m
.62493 .58602 L
s
0 0 0 r
2.5 Mabswid
.46677 .3492 Mdot
.8 1 0 r
.5 Mabswid
.50241 .3283 m
.46677 .3492 L
s
0 .877 1 r
.46517 .48342 m
.54684 .42095 L
s
0 0 0 r
2.5 Mabswid
.46517 .48342 Mdot
0 1 .542 r
.5 Mabswid
.62996 .56977 m
.50354 .35996 L
s
0 0 0 r
2.5 Mabswid
.62996 .56977 Mdot
.46779 .34482 Mdot
0 .989 1 r
.5 Mabswid
.4832 .31854 m
.46779 .34482 L
s
0 0 0 r
2.5 Mabswid
.59237 .38742 Mdot
0 1 .381 r
.5 Mabswid
.46399 .55557 m
.59237 .38742 L
s
0 0 0 r
2.5 Mabswid
.61894 .59967 Mdot
.741 1 0 r
.5 Mabswid
.46915 .32889 m
.61894 .59967 L
s
1 0 0 r
.23077 .52502 m
.42392 .44985 L
s
0 .542 1 r
.46245 .35879 m
.51598 .33291 L
s
0 0 0 r
2.5 Mabswid
.46245 .35879 Mdot
0 .542 1 r
.5 Mabswid
.53349 .62415 m
.46245 .35879 L
s
.243 1 0 r
.6263 .58163 m
.73027 .47301 L
s
0 .449 1 r
.6263 .58163 m
.42486 .42893 L
s
0 0 0 r
2.5 Mabswid
.6263 .58163 Mdot
0 .038 1 r
.5 Mabswid
.6037 .63611 m
.44144 .36784 L
s
0 0 0 r
2.5 Mabswid
.6037 .63611 Mdot
.78993 .59291 Mdot
.6279 .57702 Mdot
0 .111 1 r
.5 Mabswid
.54733 .38337 m
.6279 .57702 L
s
1 .116 0 r
.6472 .51022 m
.55366 .44563 L
s
0 0 0 r
2.5 Mabswid
.6472 .51022 Mdot
0 1 .403 r
.5 Mabswid
.45138 .44286 m
.43804 .37164 L
s
0 0 0 r
2.5 Mabswid
.45138 .44286 Mdot
1 .097 0 r
.5 Mabswid
.64721 .5102 m
.60588 .44534 L
s
0 0 0 r
2.5 Mabswid
.64721 .5102 Mdot
.251 1 0 r
.5 Mabswid
.62884 .57439 m
.72869 .4675 L
s
0 .498 1 r
.62884 .57439 m
.42663 .42028 L
s
0 0 0 r
2.5 Mabswid
.62884 .57439 Mdot
1 .116 0 r
.5 Mabswid
.474 .5157 m
.67723 .45196 L
s
0 0 0 r
2.5 Mabswid
.474 .5157 Mdot
0 .601 1 r
.5 Mabswid
.46644 .49148 m
.5487 .42958 L
s
0 0 0 r
2.5 Mabswid
.46644 .49148 Mdot
0 1 .871 r
.5 Mabswid
.46726 .49419 m
.56746 .38203 L
s
0 0 0 r
2.5 Mabswid
.46726 .49419 Mdot
0 1 .871 r
.5 Mabswid
.64751 .52069 m
.46726 .49419 L
s
0 1 .653 r
.63343 .56013 m
.51632 .36414 L
s
0 0 0 r
2.5 Mabswid
.63343 .56013 Mdot
.63409 .43551 Mdot
1 .886 0 r
.5 Mabswid
.43438 .37777 m
.63409 .43551 L
s
0 0 0 r
2.5 Mabswid
.61418 .40836 Mdot
.857 1 0 r
.5 Mabswid
.42746 .45104 m
.61418 .40836 L
s
0 0 0 r
2.5 Mabswid
.78176 .56785 Mdot
0 1 .772 r
.5 Mabswid
.65539 .50642 m
.78176 .56785 L
s
0 g
.5289 .6315 m
.56182 .67701 L
s
.48784 .60535 m
.5289 .6315 L
s
.58535 .66953 m
.52888 .63149 L
s
.52888 .63149 m
.5618 .677 L
s
.52891 .63152 m
.48785 .60536 L
s
.52888 .6315 m
.58534 .66953 L
s
0 0 0 r
2.5 Mabswid
.59891 .39203 Mdot
0 .938 1 r
.5 Mabswid
.51533 .60115 m
.59891 .39203 L
s
.797 1 0 r
.63037 .56998 m
.44527 .35819 L
s
0 0 0 r
2.5 Mabswid
.63037 .56998 Mdot
.932 1 0 r
.5 Mabswid
.228 .5226 m
.43127 .4667 L
s
0 .542 1 r
.59235 .66264 m
.52496 .63593 L
s
0 0 0 r
2.5 Mabswid
.59235 .66264 Mdot
0 .542 1 r
.5 Mabswid
.64661 .46873 m
.59235 .66264 L
s
0 0 0 r
2.5 Mabswid
.34599 .84382 Mdot
0 1 .969 r
.5 Mabswid
.47676 .60063 m
.34599 .84382 L
s
.282 1 0 r
.63138 .56712 m
.72713 .46204 L
s
0 .111 1 r
.63138 .56712 m
.42839 .4116 L
s
0 0 0 r
2.5 Mabswid
.63138 .56712 Mdot
.797 1 0 r
.5 Mabswid
.45108 .38427 m
.49161 .32068 L
s
0 0 0 r
2.5 Mabswid
.45108 .38427 Mdot
.797 1 0 r
.5 Mabswid
.44727 .43715 m
.45108 .38427 L
s
0 0 0 r
2.5 Mabswid
.51598 .33291 Mdot
1 0 0 r
.5 Mabswid
.22745 .52212 m
.42309 .44514 L
s
0 0 0 r
2.5 Mabswid
.61815 .6017 Mdot
0 1 .632 r
.5 Mabswid
.56651 .52136 m
.61815 .6017 L
s
0 0 0 r
2.5 Mabswid
.63489 .55621 Mdot
1 .115 0 r
.5 Mabswid
.57827 .41636 m
.63489 .55621 L
s
.741 1 0 r
.52377 .62643 m
.52444 .62869 L
s
0 0 0 r
2.5 Mabswid
.52377 .62643 Mdot
.63136 .56771 Mdot
.045 1 0 r
.5 Mabswid
.62122 .586 m
.63136 .56771 L
s
0 0 0 r
2.5 Mabswid
.64661 .46873 Mdot
0 .542 1 r
.5 Mabswid
.62249 .40834 m
.64661 .46873 L
s
0 1 .754 r
.63692 .55044 m
.52898 .36829 L
s
0 0 0 r
2.5 Mabswid
.63692 .55044 Mdot
.61419 .61123 Mdot
0 1 .632 r
.5 Mabswid
.55237 .67035 m
.61419 .61123 L
s
0 0 0 r
2.5 Mabswid
.63882 .54454 Mdot
0 .038 1 r
.5 Mabswid
.47727 .59489 m
.63882 .54454 L
s
.045 1 0 r
.58009 .37739 m
.57136 .36984 L
s
0 0 0 r
2.5 Mabswid
.58009 .37739 Mdot
.741 1 0 r
.5 Mabswid
.52444 .62869 m
.57757 .65574 L
s
0 0 0 r
2.5 Mabswid
.52444 .62869 Mdot
1 .116 0 r
.5 Mabswid
.47105 .51232 m
.67989 .44642 L
s
0 0 0 r
2.5 Mabswid
.47105 .51232 Mdot
0 .149 1 r
.5 Mabswid
.51244 .61533 m
.60213 .5896 L
s
0 0 0 r
2.5 Mabswid
.51244 .61533 Mdot
.44727 .43715 Mdot
.797 1 0 r
.5 Mabswid
.57813 .65435 m
.44727 .43715 L
s
1 0 0 r
.22411 .5192 m
.42226 .44038 L
s
0 0 0 r
2.5 Mabswid
.79014 .5993 Mdot
.62465 .41884 Mdot
0 .702 1 r
.5 Mabswid
.44159 .53674 m
.62465 .41884 L
s
.932 1 0 r
.22376 .51889 m
.42809 .46306 L
s
0 .538 1 r
.64205 .44246 m
.57316 .66591 L
s
0 0 0 r
2.5 Mabswid
.64205 .44246 Mdot
0 .538 1 r
.5 Mabswid
.42303 .42658 m
.64205 .44246 L
s
1 .116 0 r
.65015 .50507 m
.56521 .44557 L
s
0 0 0 r
2.5 Mabswid
.65015 .50507 Mdot
0 1 .928 r
.5 Mabswid
.64043 .54068 m
.54154 .37241 L
s
0 0 0 r
2.5 Mabswid
.64043 .54068 Mdot
0 1 .381 r
.5 Mabswid
.6141 .61158 m
.46932 .58782 L
s
0 0 0 r
2.5 Mabswid
.6141 .61158 Mdot
.6212 .59464 Mdot
.746 1 0 r
.5 Mabswid
.46899 .31976 m
.6212 .59464 L
s
0 0 0 r
2.5 Mabswid
.61685 .40761 Mdot
1 .886 0 r
.5 Mabswid
.42903 .45053 m
.61685 .40761 L
s
0 .989 1 r
.63172 .56844 m
.57603 .6726 L
s
0 0 0 r
2.5 Mabswid
.63172 .56844 Mdot
.45588 .36039 Mdot
0 1 .381 r
.5 Mabswid
.45172 .48723 m
.45588 .36039 L
s
0 1 .243 r
.47753 .53827 m
.55253 .36452 L
s
0 0 0 r
2.5 Mabswid
.47753 .53827 Mdot
0 1 .243 r
.5 Mabswid
.61195 .61551 m
.47753 .53827 L
s
0 0 0 r
2.5 Mabswid
.63154 .56922 Mdot
0 .498 1 r
.5 Mabswid
.55697 .38974 m
.63154 .56922 L
s
0 0 0 r
2.5 Mabswid
.4427 .40461 Mdot
0 1 .381 r
.5 Mabswid
.44783 .40211 m
.4427 .40461 L
s
0 0 0 r
2.5 Mabswid
.63874 .5469 Mdot
1 .115 0 r
.5 Mabswid
.58693 .41844 m
.63874 .5469 L
s
0 .542 1 r
.56436 .65617 m
.59315 .6496 L
s
0 0 0 r
2.5 Mabswid
.56436 .65617 Mdot
1 .097 0 r
.5 Mabswid
.65128 .5031 m
.61518 .44528 L
s
0 0 0 r
2.5 Mabswid
.65128 .5031 Mdot
1 .116 0 r
.5 Mabswid
.46809 .50893 m
.6768 .44265 L
s
0 0 0 r
2.5 Mabswid
.46809 .50893 Mdot
0 1 .517 r
.5 Mabswid
.44178 .42531 m
.43522 .39178 L
s
0 0 0 r
2.5 Mabswid
.44178 .42531 Mdot
1 0 0 r
.5 Mabswid
.22076 .51626 m
.42141 .43557 L
s
0 g
.58534 .66952 m
.5905 .66812 L
s
.56179 .67699 m
.58534 .66952 L
s
.5618 .677 m
.58535 .66953 L
s
0 0 0 r
2.5 Mabswid
.46915 .32889 Mdot
.741 1 0 r
.5 Mabswid
.48979 .32092 m
.46915 .32889 L
s
0 g
.59049 .66813 m
.58533 .66953 L
s
0 .13 1 r
.6268 .58135 m
.42879 .39888 L
s
0 0 0 r
2.5 Mabswid
.6268 .58135 Mdot
.45035 .37113 Mdot
.741 1 0 r
.5 Mabswid
.44851 .33892 m
.45035 .37113 L
s
0 g
.59048 .66814 m
.65667 .51195 L
s
.56711 .67557 m
.59048 .66814 L
s
.5905 .66812 m
.56712 .67554 L
s
0 0 0 r
2.5 Mabswid
.54434 .35165 Mdot
.741 1 0 r
.5 Mabswid
.43166 .39058 m
.54434 .35165 L
s
0 g
.65667 .51195 m
.59048 .66815 L
s
0 .364 1 r
.44093 .41229 m
.53965 .35485 L
s
0 0 0 r
2.5 Mabswid
.44093 .41229 Mdot
0 .364 1 r
.5 Mabswid
.63758 .55618 m
.44093 .41229 L
s
.8 1 0 r
.50337 .60911 m
.55042 .4172 L
s
0 0 0 r
2.5 Mabswid
.50337 .60911 Mdot
.8 1 0 r
.5 Mabswid
.62493 .58602 m
.50337 .60911 L
s
0 0 0 r
2.5 Mabswid
.63894 .54752 Mdot
0 .439 1 r
.5 Mabswid
.43292 .44504 m
.63894 .54752 L
s
.741 1 0 r
.58988 .66829 m
.4307 .43335 L
s
0 0 0 r
2.5 Mabswid
.58988 .66829 Mdot
.64751 .52069 Mdot
.303 1 0 r
.5 Mabswid
.43079 .40877 m
.64751 .52069 L
s
0 0 0 r
2.5 Mabswid
.44875 .37342 Mdot
0 .829 1 r
.5 Mabswid
.46862 .31231 m
.44875 .37342 L
s
0 1 .532 r
.62792 .57875 m
.54333 .64521 L
s
0 0 0 r
2.5 Mabswid
.62792 .57875 Mdot
0 .56 1 r
.5 Mabswid
.15924 .32708 m
.43956 .41355 L
s
1 .728 0 r
.64172 .43789 m
.54984 .66364 L
s
0 0 0 r
2.5 Mabswid
.64172 .43789 Mdot
1 .728 0 r
.5 Mabswid
.42548 .4544 m
.64172 .43789 L
s
0 0 0 r
2.5 Mabswid
.503 .32708 Mdot
0 .989 1 r
.5 Mabswid
.45091 .33776 m
.503 .32708 L
s
0 1 .727 r
.5929 .66241 m
.68687 .78174 L
s
0 .2 1 r
.5929 .66241 m
.55799 .65484 L
s
0 0 0 r
2.5 Mabswid
.5929 .66241 Mdot
1 .116 0 r
.5 Mabswid
.65314 .49987 m
.57663 .4455 L
s
0 0 0 r
2.5 Mabswid
.65314 .49987 Mdot
0 .989 1 r
.5 Mabswid
.51455 .62264 m
.47909 .59184 L
s
0 0 0 r
2.5 Mabswid
.51455 .62264 Mdot
0 .932 1 r
.5 Mabswid
.63395 .42675 m
.62628 .45273 L
s
0 0 0 r
2.5 Mabswid
.63395 .42675 Mdot
1 .116 0 r
.5 Mabswid
.46511 .50551 m
.66886 .44041 L
s
0 0 0 r
2.5 Mabswid
.46511 .50551 Mdot
.852 1 0 r
.5 Mabswid
.49161 .32068 m
.62228 .14901 L
s
0 0 0 r
2.5 Mabswid
.49161 .32068 Mdot
1 0 0 r
.5 Mabswid
.21739 .51332 m
.42056 .43071 L
s
0 0 0 r
2.5 Mabswid
.54662 .64698 Mdot
.142 1 0 r
.5 Mabswid
.6268 .55394 m
.54662 .64698 L
s
0 1 .253 r
.47665 .5441 m
.55266 .36824 L
s
0 0 0 r
2.5 Mabswid
.47665 .5441 Mdot
0 1 .253 r
.5 Mabswid
.60816 .61958 m
.47665 .5441 L
s
0 0 0 r
2.5 Mabswid
.65285 .47776 Mdot
0 1 .063 r
.5 Mabswid
.64285 .48282 m
.65285 .47776 L
s
0 1 .699 r
.47188 .52921 m
.63758 .55618 L
s
0 0 0 r
2.5 Mabswid
.47188 .52921 Mdot
0 1 .699 r
.5 Mabswid
.58036 .40579 m
.47188 .52921 L
s
0 0 0 r
2.5 Mabswid
.44176 .39032 Mdot
0 1 .532 r
.5 Mabswid
.52253 .38328 m
.44176 .39032 L
s
0 1 .665 r
.43956 .41355 m
.48999 .35225 L
s
0 0 0 r
2.5 Mabswid
.43956 .41355 Mdot
.64259 .53755 Mdot
1 .115 0 r
.5 Mabswid
.59557 .42051 m
.64259 .53755 L
s
0 0 0 r
2.5 Mabswid
.62493 .58602 Mdot
.64305 .53645 Mdot
1 .092 0 r
.5 Mabswid
.5422 .40769 m
.64305 .53645 L
s
0 0 0 r
2.5 Mabswid
.44844 .36658 Mdot
0 .989 1 r
.5 Mabswid
.46937 .36685 m
.44844 .36658 L
s
0 .2 1 r
.55799 .65484 m
.46766 .56005 L
s
0 0 0 r
2.5 Mabswid
.55799 .65484 Mdot
0 g
.5 Mabswid
.65067 .44712 m
.68008 .44399 L
s
.68007 .44397 m
.65063 .44713 L
s
0 .58 1 r
.15215 .31422 m
.4389 .40293 L
s
0 .005 1 r
.47069 .52866 m
.51594 .40016 L
s
0 0 0 r
2.5 Mabswid
.47069 .52866 Mdot
.63519 .56138 Mdot
0 .449 1 r
.5 Mabswid
.56665 .39614 m
.63519 .56138 L
s
0 1 .532 r
.59342 .38508 m
.54253 .66258 L
s
0 0 0 r
2.5 Mabswid
.59342 .38508 Mdot
1 0 0 r
.5 Mabswid
.214 .51035 m
.42242 .42468 L
s
1 .097 0 r
.6554 .49593 m
.6244 .44523 L
s
0 0 0 r
2.5 Mabswid
.6554 .49593 Mdot
1 .116 0 r
.5 Mabswid
.46212 .50208 m
.66091 .43816 L
s
0 0 0 r
2.5 Mabswid
.46212 .50208 Mdot
.62249 .40834 Mdot
0 .542 1 r
.5 Mabswid
.56794 .36864 m
.62249 .40834 L
s
.741 1 0 r
.48913 .59016 m
.53328 .62764 L
s
0 0 0 r
2.5 Mabswid
.48913 .59016 Mdot
0 .2 1 r
.5 Mabswid
.47113 .53303 m
.47472 .4934 L
s
0 0 0 r
2.5 Mabswid
.47113 .53303 Mdot
1 .116 0 r
.5 Mabswid
.65615 .49463 m
.58793 .44544 L
s
0 0 0 r
2.5 Mabswid
.65615 .49463 Mdot
.46899 .31976 Mdot
.746 1 0 r
.5 Mabswid
.4796 .31563 m
.46899 .31976 L
s
0 1 .653 r
.4389 .40293 m
.48403 .34682 L
s
0 0 0 r
2.5 Mabswid
.4389 .40293 Mdot
0 1 .495 r
.5 Mabswid
.47576 .54995 m
.5528 .37199 L
s
0 0 0 r
2.5 Mabswid
.47576 .54995 Mdot
0 1 .495 r
.5 Mabswid
.60435 .62368 m
.47576 .54995 L
s
0 1 .2 r
.53546 .34684 m
.40124 .22206 L
s
.045 1 0 r
.53546 .34684 m
.43692 .4319 L
s
0 0 0 r
2.5 Mabswid
.53546 .34684 Mdot
.2 0 1 r
.5 Mabswid
.64855 .52108 m
.63805 .536 L
s
0 0 0 r
2.5 Mabswid
.64855 .52108 Mdot
1 0 0 r
.5 Mabswid
.2106 .50738 m
.42442 .41851 L
s
.819 1 0 r
.58785 .38087 m
.43897 .49387 L
s
0 0 0 r
2.5 Mabswid
.58785 .38087 Mdot
0 .531 1 r
.5 Mabswid
.57316 .66591 m
.58795 .72276 L
s
0 0 0 r
2.5 Mabswid
.57316 .66591 Mdot
.045 1 0 r
.5 Mabswid
.57136 .36984 m
.55547 .36227 L
s
0 0 0 r
2.5 Mabswid
.57136 .36984 Mdot
0 .599 1 r
.5 Mabswid
.14491 .30115 m
.4382 .39217 L
s
.814 1 0 r
.59444 .38529 m
.44072 .50257 L
s
0 0 0 r
2.5 Mabswid
.59444 .38529 Mdot
.865 1 0 r
.5 Mabswid
.65382 .45416 m
.61419 .40191 L
s
0 0 0 r
2.5 Mabswid
.65382 .45416 Mdot
.48979 .32092 Mdot
.741 1 0 r
.5 Mabswid
.5283 .65188 m
.48979 .32092 L
s
0 0 0 r
2.5 Mabswid
.64635 .52845 Mdot
1 .092 0 r
.5 Mabswid
.55433 .4106 m
.64635 .52845 L
s
0 0 0 r
2.5 Mabswid
.65032 .51601 Mdot
0 .595 1 r
.5 Mabswid
.43424 .385 m
.65032 .51601 L
s
0 1 .381 r
.51946 .62894 m
.57095 .6465 L
s
0 0 0 r
2.5 Mabswid
.51946 .62894 Mdot
1 .116 0 r
.5 Mabswid
.45911 .49863 m
.65294 .43591 L
s
0 0 0 r
2.5 Mabswid
.45911 .49863 Mdot
.64647 .52818 Mdot
1 .115 0 r
.5 Mabswid
.6042 .42259 m
.64647 .52818 L
s
.81 1 0 r
.60101 .38979 m
.43108 .48864 L
s
0 0 0 r
2.5 Mabswid
.60101 .38979 Mdot
.88 1 0 r
.5 Mabswid
.65211 .4451 m
.50825 .50728 L
s
0 0 0 r
2.5 Mabswid
.65211 .4451 Mdot
.806 1 0 r
.5 Mabswid
.60753 .39448 m
.43295 .49691 L
s
0 0 0 r
2.5 Mabswid
.60753 .39448 Mdot
.56601 .36626 Mdot
.741 1 0 r
.5 Mabswid
.43494 .51776 m
.56601 .36626 L
s
0 0 0 r
2.5 Mabswid
.50241 .3283 Mdot
.8 1 0 r
.5 Mabswid
.4909 .62028 m
.50241 .3283 L
s
0 0 0 r
2.5 Mabswid
.65816 .48916 Mdot
.06 1 0 r
.5 Mabswid
.63441 .51941 m
.65816 .48916 L
s
.803 1 0 r
.61405 .39917 m
.43483 .50524 L
s
0 0 0 r
2.5 Mabswid
.61405 .39917 Mdot
.741 1 0 r
.5 Mabswid
.4958 .60858 m
.49482 .54832 L
s
0 0 0 r
2.5 Mabswid
.4958 .60858 Mdot
0 1 .381 r
.5 Mabswid
.51165 .62292 m
.43517 .42006 L
s
0 0 0 r
2.5 Mabswid
.51165 .62292 Mdot
1 .228 0 r
.5 Mabswid
.19183 .45465 m
.42301 .45295 L
s
0 1 .64 r
.4382 .39217 m
.47789 .34167 L
s
0 0 0 r
2.5 Mabswid
.4382 .39217 Mdot
.871 1 0 r
.5 Mabswid
.61464 .61096 m
.67933 .67116 L
s
0 .538 1 r
.61464 .61096 m
.44827 .55056 L
s
0 0 0 r
2.5 Mabswid
.61464 .61096 Mdot
1 0 0 r
.5 Mabswid
.20718 .50439 m
.42646 .41225 L
s
0 1 .846 r
.63758 .55618 m
.76173 .53038 L
s
0 0 0 r
2.5 Mabswid
.63758 .55618 Mdot
1 .286 0 r
.5 Mabswid
.23622 .5966 m
.42754 .41623 L
s
0 g
.43948 .37676 m
.42567 .42945 L
s
.44191 .3351 m
.43948 .37676 L
s
.4419 .33513 m
.4393 .37675 L
s
.4393 .37675 m
.46068 .31258 L
s
.42567 .42944 m
.4393 .37672 L
s
.46068 .31258 m
.43929 .37675 L
s
.045 1 0 r
.43692 .4319 m
.58443 .46339 L
s
0 0 0 r
2.5 Mabswid
.43692 .4319 Mdot
.4796 .31563 Mdot
.746 1 0 r
.5 Mabswid
.51776 .64378 m
.4796 .31563 L
s
1 .116 0 r
.65919 .48932 m
.59912 .44537 L
s
0 0 0 r
2.5 Mabswid
.65919 .48932 Mdot
0 .538 1 r
.5 Mabswid
.57312 .66752 m
.58044 .67124 L
s
0 0 0 r
2.5 Mabswid
.57312 .66752 Mdot
.47924 .56953 Mdot
.018 0 1 r
.5 Mabswid
.66341 .48809 m
.47924 .56953 L
s
1 .098 0 r
.65957 .48867 m
.63352 .44518 L
s
0 0 0 r
2.5 Mabswid
.65957 .48867 Mdot
1 .116 0 r
.5 Mabswid
.45609 .49516 m
.64497 .43366 L
s
0 0 0 r
2.5 Mabswid
.45609 .49516 Mdot
.62669 .58223 Mdot
0 1 .632 r
.5 Mabswid
.58123 .6366 m
.62669 .58223 L
s
0 g
.66 .48801 m
.6804 .44537 L
s
.6804 .44535 m
.65995 .488 L
s
1 .242 0 r
.19683 .47685 m
.42937 .42349 L
s
0 0 0 r
2.5 Mabswid
.64966 .52043 Mdot
1 .093 0 r
.5 Mabswid
.56641 .41351 m
.64966 .52043 L
s
0 0 0 r
2.5 Mabswid
.45419 .3425 Mdot
0 .149 1 r
.5 Mabswid
.48728 .32989 m
.45419 .3425 L
s
0 .418 1 r
.46175 .51549 m
.50483 .44883 L
s
0 0 0 r
2.5 Mabswid
.46175 .51549 Mdot
0 1 .943 r
.5 Mabswid
.46021 .51148 m
.64929 .43644 L
s
0 0 0 r
2.5 Mabswid
.46021 .51148 Mdot
0 1 .124 r
.5 Mabswid
.59579 .48386 m
.46021 .51148 L
s
1 .247 0 r
.19368 .46944 m
.42957 .41616 L
s
1 0 0 r
.20375 .50138 m
.42853 .40588 L
s
0 .939 1 r
.43807 .38175 m
.21864 .2894 L
s
0 1 .65 r
.43807 .38175 m
.52264 .35507 L
s
0 0 0 r
2.5 Mabswid
.43807 .38175 Mdot
.65035 .51877 Mdot
1 .115 0 r
.5 Mabswid
.61282 .42466 m
.65035 .51877 L
s
0 .31 1 r
.64929 .43644 m
.72559 .44711 L
s
0 .149 1 r
.64929 .43644 m
.51937 .6227 L
s
0 0 0 r
2.5 Mabswid
.64929 .43644 Mdot
1 .728 0 r
.5 Mabswid
.44765 .35476 m
.59388 .62593 L
s
0 0 0 r
2.5 Mabswid
.44765 .35476 Mdot
1 .728 0 r
.5 Mabswid
.51019 .33715 m
.44765 .35476 L
s
0 0 0 r
2.5 Mabswid
.54787 .35525 Mdot
0 .989 1 r
.5 Mabswid
.44044 .35422 m
.54787 .35525 L
s
0 0 0 r
2.5 Mabswid
.46421 .52642 Mdot
0 1 .247 r
.5 Mabswid
.52903 .51765 m
.46421 .52642 L
s
0 0 0 r
2.5 Mabswid
.43301 .42358 Mdot
0 .989 1 r
.5 Mabswid
.52988 .40152 m
.43301 .42358 L
s
1 .116 0 r
.45304 .49167 m
.63699 .4314 L
s
0 0 0 r
2.5 Mabswid
.45304 .49167 Mdot
.769 1 0 r
.5 Mabswid
.61195 .61551 m
.77514 .68181 L
s
0 0 0 r
2.5 Mabswid
.61195 .61551 Mdot
.4832 .31854 Mdot
0 .989 1 r
.5 Mabswid
.42107 .43495 m
.4832 .31854 L
s
0 0 0 r
2.5 Mabswid
.62487 .58677 Mdot
.793 1 0 r
.5 Mabswid
.42713 .40586 m
.62487 .58677 L
s
0 .175 1 r
.59138 .65462 m
.72832 .79582 L
s
0 0 0 r
2.5 Mabswid
.59138 .65462 Mdot
0 .38 1 r
.5 Mabswid
.52264 .35507 m
.59138 .65462 L
s
0 .542 1 r
.52496 .63593 m
.44599 .54891 L
s
0 0 0 r
2.5 Mabswid
.52496 .63593 Mdot
1 .116 0 r
.5 Mabswid
.66182 .4841 m
.5997 .39428 L
s
0 0 0 r
2.5 Mabswid
.66182 .4841 Mdot
0 g
.5 Mabswid
.48786 .60536 m
.48738 .61948 L
s
.45241 .56699 m
.48786 .60536 L
s
.48748 .61932 m
.48784 .60535 L
s
0 0 0 r
2.5 Mabswid
.76173 .53038 Mdot
0 g
.5 Mabswid
.48787 .6054 m
.48787 .6054 L
s
.45241 .56703 m
.48787 .6054 L
s
0 0 0 r
2.5 Mabswid
.6211 .59582 Mdot
.789 1 0 r
.5 Mabswid
.42478 .41617 m
.6211 .59582 L
s
0 .149 1 r
.44776 .47755 m
.43667 .36239 L
s
0 0 0 r
2.5 Mabswid
.44776 .47755 Mdot
0 .038 1 r
.5 Mabswid
.44144 .36784 m
.51732 .34112 L
s
0 0 0 r
2.5 Mabswid
.44144 .36784 Mdot
.46542 .53465 Mdot
0 1 .326 r
.5 Mabswid
.52871 .52653 m
.46542 .53465 L
s
0 1 .532 r
.6062 .62524 m
.42984 .45114 L
s
0 0 0 r
2.5 Mabswid
.6062 .62524 Mdot
.61693 .60454 Mdot
.778 1 0 r
.5 Mabswid
.42243 .42652 m
.61693 .60454 L
s
0 0 0 r
2.5 Mabswid
.65298 .51241 Mdot
1 .093 0 r
.5 Mabswid
.57845 .4164 m
.65298 .51241 L
s
0 0 0 r
2.5 Mabswid
.52994 .64059 Mdot
1 .728 0 r
.5 Mabswid
.59388 .62593 m
.52994 .64059 L
s
0 g
.634 .4119 m
.67953 .4428 L
s
.67952 .44279 m
.63396 .41193 L
s
0 1 .394 r
.6273 .40741 m
.60276 .4613 L
s
0 0 0 r
2.5 Mabswid
.6273 .40741 Mdot
0 .542 1 r
.5 Mabswid
.59315 .6496 m
.43268 .37926 L
s
0 0 0 r
2.5 Mabswid
.59315 .6496 Mdot
.43038 .19176 Mdot
.782 1 0 r
.5 Mabswid
.42242 .42468 m
.43038 .19176 L
s
.801 1 0 r
.4402 .45589 m
.56492 .37726 L
s
0 0 0 r
2.5 Mabswid
.4402 .45589 Mdot
1 .098 0 r
.5 Mabswid
.63352 .44518 m
.4402 .45589 L
s
0 .538 1 r
.58044 .67124 m
.58228 .66845 L
s
0 0 0 r
2.5 Mabswid
.58044 .67124 Mdot
0 1 .632 r
.5 Mabswid
.53291 .34755 m
.43167 .38586 L
s
0 0 0 r
2.5 Mabswid
.53291 .34755 Mdot
1 .116 0 r
.5 Mabswid
.44998 .48816 m
.62899 .42914 L
s
0 0 0 r
2.5 Mabswid
.44998 .48816 Mdot
.57959 .67294 Mdot
0 .137 1 r
.5 Mabswid
.57952 .67152 m
.57959 .67294 L
s
0 1 .953 r
.16537 .39446 m
.42886 .41278 L
s
0 1 .72 r
.43522 .39178 m
.2524 .28521 L
s
0 1 .935 r
.43522 .39178 m
.46769 .33407 L
s
0 0 0 r
2.5 Mabswid
.43522 .39178 Mdot
.57952 .67152 Mdot
0 .038 1 r
.5 Mabswid
.51732 .34112 m
.57952 .67152 L
s
0 1 .632 r
.47654 .31552 m
.45882 .31621 L
s
0 0 0 r
2.5 Mabswid
.47654 .31552 Mdot
.76 1 0 r
.5 Mabswid
.60816 .61958 m
.77454 .68811 L
s
0 0 0 r
2.5 Mabswid
.60816 .61958 Mdot
.46885 .5508 Mdot
0 .298 1 r
.5 Mabswid
.54336 .58517 m
.46885 .5508 L
s
1 .17 0 r
.43815 .45229 m
.14418 .34283 L
s
.385 1 0 r
.43815 .45229 m
.54358 .37888 L
s
0 0 0 r
2.5 Mabswid
.43815 .45229 Mdot
1 .116 0 r
.5 Mabswid
.67618 .44086 m
.43815 .45229 L
s
0 0 0 r
2.5 Mabswid
.6358 .56088 Mdot
0 1 .711 r
.5 Mabswid
.43334 .49532 m
.6358 .56088 L
s
0 0 0 r
2.5 Mabswid
.65539 .50642 Mdot
0 1 .766 r
.5 Mabswid
.42657 .41868 m
.65539 .50642 L
s
0 0 0 r
2.5 Mabswid
.62228 .14901 Mdot
.51919 .34005 Mdot
0 1 .381 r
.5 Mabswid
.49572 .52774 m
.51919 .34005 L
s
1 .169 0 r
.43557 .44513 m
.15105 .3377 L
s
.378 1 0 r
.43557 .44513 m
.53685 .37405 L
s
0 0 0 r
2.5 Mabswid
.43557 .44513 Mdot
1 .116 0 r
.5 Mabswid
.66535 .43425 m
.43557 .44513 L
s
0 .327 1 r
.57088 .36966 m
.56712 .51458 L
s
0 0 0 r
2.5 Mabswid
.57088 .36966 Mdot
0 .957 1 r
.5 Mabswid
.57632 .67243 m
.57697 .67991 L
s
0 0 0 r
2.5 Mabswid
.57632 .67243 Mdot
.045 1 0 r
.5 Mabswid
.44517 .35589 m
.53207 .50965 L
s
0 0 0 r
2.5 Mabswid
.44517 .35589 Mdot
0 .538 1 r
.5 Mabswid
.58228 .66845 m
.57583 .50993 L
s
0 0 0 r
2.5 Mabswid
.58228 .66845 Mdot
1 .116 0 r
.5 Mabswid
.66433 .47888 m
.61064 .40087 L
s
0 0 0 r
2.5 Mabswid
.66433 .47888 Mdot
1 .168 0 r
.5 Mabswid
.43297 .43795 m
.15784 .33262 L
s
.37 1 0 r
.43297 .43795 m
.53013 .36924 L
s
0 0 0 r
2.5 Mabswid
.43297 .43795 Mdot
1 .116 0 r
.5 Mabswid
.65448 .42762 m
.43297 .43795 L
s
0 0 0 r
2.5 Mabswid
.65629 .50437 Mdot
1 .094 0 r
.5 Mabswid
.59043 .41928 m
.65629 .50437 L
s
1 .168 0 r
.43038 .43077 m
.16456 .32759 L
s
.364 1 0 r
.43038 .43077 m
.52343 .36444 L
s
0 0 0 r
2.5 Mabswid
.43038 .43077 Mdot
1 .116 0 r
.5 Mabswid
.64358 .42097 m
.43038 .43077 L
s
.801 1 0 r
.43762 .37967 m
.5019 .33812 L
s
0 0 0 r
2.5 Mabswid
.43762 .37967 Mdot
0 .272 1 r
.5 Mabswid
.60189 .39045 m
.65798 .45487 L
s
0 0 0 r
2.5 Mabswid
.60189 .39045 Mdot
1 .115 0 r
.5 Mabswid
.44691 .48464 m
.62098 .42688 L
s
0 0 0 r
2.5 Mabswid
.44691 .48464 Mdot
.64864 .42812 Mdot
0 1 .67 r
.5 Mabswid
.67326 .46375 m
.64864 .42812 L
s
.865 1 0 r
.42937 .42349 m
.62987 .46832 L
s
0 0 0 r
2.5 Mabswid
.42937 .42349 Mdot
1 .116 0 r
.5 Mabswid
.63264 .41429 m
.42937 .42349 L
s
0 0 0 r
2.5 Mabswid
.55164 .35918 Mdot
0 .538 1 r
.5 Mabswid
.44392 .34021 m
.55164 .35918 L
s
.797 1 0 r
.43714 .4556 m
.56005 .37801 L
s
0 0 0 r
2.5 Mabswid
.43714 .4556 Mdot
1 .097 0 r
.5 Mabswid
.6244 .44523 m
.43714 .4556 L
s
.89 1 0 r
.42957 .41616 m
.62597 .45944 L
s
0 0 0 r
2.5 Mabswid
.42957 .41616 Mdot
1 .116 0 r
.5 Mabswid
.62166 .40759 m
.42957 .41616 L
s
0 1 .128 r
.66418 .46117 m
.62743 .42506 L
s
0 0 0 r
2.5 Mabswid
.66418 .46117 Mdot
.918 1 0 r
.5 Mabswid
.60435 .62368 m
.77394 .69449 L
s
0 0 0 r
2.5 Mabswid
.60435 .62368 Mdot
.56794 .36864 Mdot
0 .542 1 r
.5 Mabswid
.44879 .32867 m
.56794 .36864 L
s
0 .989 1 r
.59057 .6499 m
.54624 .65767 L
s
0 0 0 r
2.5 Mabswid
.59057 .6499 Mdot
.66547 .46766 Mdot
0 .588 1 r
.5 Mabswid
.64332 .49079 m
.66547 .46766 L
s
0 0 0 r
2.5 Mabswid
.43079 .40877 Mdot
1 .116 0 r
.5 Mabswid
.61064 .40087 m
.43079 .40877 L
s
0 0 0 r
2.5 Mabswid
.43292 .44504 Mdot
0 .439 1 r
.5 Mabswid
.45993 .34188 m
.43292 .44504 L
s
0 g
.46581 .31079 m
.46068 .31259 L
s
.46068 .31259 m
.4419 .33514 L
s
.46068 .31258 m
.4419 .33513 L
s
.46067 .31259 m
.4658 .31079 L
s
0 .989 1 r
.57603 .6726 m
.52832 .64443 L
s
0 0 0 r
2.5 Mabswid
.57603 .6726 Mdot
1 .115 0 r
.5 Mabswid
.44382 .48109 m
.61282 .42466 L
s
0 0 0 r
2.5 Mabswid
.44382 .48109 Mdot
.4349 .39003 Mdot
0 .989 1 r
.5 Mabswid
.44894 .52408 m
.4349 .39003 L
s
1 .116 0 r
.66686 .4736 m
.62166 .40759 L
s
0 0 0 r
2.5 Mabswid
.66686 .4736 Mdot
.65962 .49633 Mdot
1 .094 0 r
.5 Mabswid
.60238 .42215 m
.65962 .49633 L
s
0 1 .003 r
.66666 .47058 m
.62785 .43276 L
s
0 0 0 r
2.5 Mabswid
.66666 .47058 Mdot
.46862 .31231 Mdot
0 1 .532 r
.5 Mabswid
.45262 .33192 m
.46862 .31231 L
s
0 0 0 r
2.5 Mabswid
.45091 .33776 Mdot
0 .989 1 r
.5 Mabswid
.52049 .45816 m
.45091 .33776 L
s
0 1 .284 r
.64897 .42474 m
.62033 .43268 L
s
0 0 0 r
2.5 Mabswid
.64897 .42474 Mdot
0 g
.5 Mabswid
.4472 .33329 m
.46581 .31079 L
s
.46579 .31077 m
.44717 .33328 L
s
.61915 .40228 m
.46579 .31077 L
s
.46578 .31078 m
.61914 .40228 L
s
0 .2 1 r
.46766 .56005 m
.44463 .36178 L
s
0 0 0 r
2.5 Mabswid
.46766 .56005 Mdot
.29585 .19967 Mdot
0 1 .632 r
.5 Mabswid
.45882 .31621 m
.51036 .37427 L
s
0 0 0 r
2.5 Mabswid
.45882 .31621 Mdot
.64887 .53005 Mdot
1 .115 0 r
.5 Mabswid
.62098 .42688 m
.64887 .53005 L
s
.045 1 0 r
.55547 .36227 m
.54421 .35969 L
s
0 0 0 r
2.5 Mabswid
.55547 .36227 Mdot
.57697 .67991 Mdot
.797 1 0 r
.5 Mabswid
.43677 .38039 m
.49875 .34032 L
s
0 0 0 r
2.5 Mabswid
.43677 .38039 Mdot
.48728 .32345 Mdot
0 .149 1 r
.5 Mabswid
.45147 .33469 m
.48728 .32345 L
s
.793 1 0 r
.43405 .45532 m
.55451 .37916 L
s
0 0 0 r
2.5 Mabswid
.43405 .45532 Mdot
1 .097 0 r
.5 Mabswid
.61518 .44528 m
.43405 .45532 L
s
0 .989 1 r
.54624 .65767 m
.52988 .40152 L
s
0 0 0 r
2.5 Mabswid
.54624 .65767 Mdot
.45262 .33192 Mdot
0 1 .532 r
.5 Mabswid
.43727 .51281 m
.45262 .33192 L
s
1 .115 0 r
.44071 .47752 m
.6042 .42259 L
s
0 0 0 r
2.5 Mabswid
.44071 .47752 Mdot
0 g
.5 Mabswid
.42052 .43049 m
.42568 .42942 L
s
.42568 .42942 m
.42587 .49216 L
s
.42567 .42945 m
.42052 .43052 L
s
0 0 0 r
2.5 Mabswid
.45147 .33469 Mdot
0 .149 1 r
.5 Mabswid
.60213 .5896 m
.45147 .33469 L
s
0 g
.42565 .42938 m
.42584 .49213 L
s
.333 1 0 r
.43315 .45442 m
.47654 .49159 L
s
0 0 0 r
2.5 Mabswid
.43315 .45442 Mdot
.018 0 1 r
.5 Mabswid
.6493 .42228 m
.66341 .48809 L
s
0 0 0 r
2.5 Mabswid
.6493 .42228 Mdot
.66294 .48827 Mdot
1 .094 0 r
.5 Mabswid
.61427 .42501 m
.66294 .48827 L
s
0 0 0 r
2.5 Mabswid
.62122 .586 Mdot
.045 1 0 r
.5 Mabswid
.55803 .60238 m
.62122 .586 L
s
0 .038 1 r
.57648 .37485 m
.56244 .50187 L
s
0 0 0 r
2.5 Mabswid
.57648 .37485 Mdot
1 .116 0 r
.5 Mabswid
.66941 .46827 m
.63264 .41429 L
s
0 0 0 r
2.5 Mabswid
.66941 .46827 Mdot
.45747 .53491 Mdot
0 .149 1 r
.5 Mabswid
.50604 .62308 m
.45747 .53491 L
s
0 0 0 r
2.5 Mabswid
.65323 .519 Mdot
1 .116 0 r
.5 Mabswid
.62899 .42914 m
.65323 .519 L
s
0 0 0 r
2.5 Mabswid
.51732 .34112 Mdot
.93 1 0 r
.5 Mabswid
.26892 .76687 m
.49555 .61674 L
s
0 1 .599 r
.49555 .61674 m
.62256 .42015 L
s
0 0 0 r
2.5 Mabswid
.49555 .61674 Mdot
.806 1 0 r
.5 Mabswid
.67509 .44731 m
.49555 .61674 L
s
0 0 0 r
2.5 Mabswid
.51019 .33715 Mdot
1 .728 0 r
.5 Mabswid
.58162 .64554 m
.51019 .33715 L
s
.797 1 0 r
.50256 .62258 m
.58746 .6137 L
s
0 0 0 r
2.5 Mabswid
.50256 .62258 Mdot
.60624 .61361 Mdot
.778 1 0 r
.5 Mabswid
.47283 .58964 m
.60624 .61361 L
s
1 .115 0 r
.43758 .47394 m
.59557 .42051 L
s
0 0 0 r
2.5 Mabswid
.43758 .47394 Mdot
.43121 .21853 Mdot
.757 1 0 r
.5 Mabswid
.42442 .41851 m
.43121 .21853 L
s
0 0 0 r
2.5 Mabswid
.58795 .72276 Mdot
.813 1 0 r
.5 Mabswid
.67029 .46159 m
.66454 .44197 L
s
0 0 0 r
2.5 Mabswid
.67029 .46159 Mdot
0 .989 1 r
.5 Mabswid
.52832 .64443 m
.46648 .58474 L
s
0 0 0 r
2.5 Mabswid
.52832 .64443 Mdot
.49213 .329 Mdot
0 .989 1 r
.5 Mabswid
.43012 .41948 m
.49213 .329 L
s
.789 1 0 r
.43092 .45503 m
.54871 .38045 L
s
0 0 0 r
2.5 Mabswid
.43092 .45503 Mdot
1 .097 0 r
.5 Mabswid
.60588 .44534 m
.43092 .45503 L
s
0 0 0 r
2.5 Mabswid
.48463 .60663 Mdot
0 1 .632 r
.5 Mabswid
.54207 .60573 m
.48463 .60663 L
s
.51165 .33921 m
.42596 .41102 L
s
0 0 0 r
2.5 Mabswid
.51165 .33921 Mdot
.63866 .54968 Mdot
1 .99 0 r
.5 Mabswid
.42754 .41623 m
.63866 .54968 L
s
0 .092 1 r
.42886 .41278 m
.66605 .48126 L
s
0 0 0 r
2.5 Mabswid
.42886 .41278 Mdot
0 1 .832 r
.5 Mabswid
.6754 .4521 m
.42886 .41278 L
s
0 0 0 r
2.5 Mabswid
.65748 .50754 Mdot
1 .116 0 r
.5 Mabswid
.63699 .4314 m
.65748 .50754 L
s
0 .645 1 r
.43804 .37164 m
.28044 .27911 L
s
0 1 .975 r
.43804 .37164 m
.45999 .3318 L
s
0 0 0 r
2.5 Mabswid
.43804 .37164 Mdot
.699 1 0 r
.5 Mabswid
.60659 .39375 m
.50113 .49088 L
s
0 0 0 r
2.5 Mabswid
.60659 .39375 Mdot
.65556 .51407 Mdot
.89 1 0 r
.5 Mabswid
.62597 .45944 m
.65556 .51407 L
s
0 g
.837 .79404 m
.62521 .51439 L
s
.019 0 1 r
.66605 .48126 m
.74434 .50038 L
s
0 0 0 r
2.5 Mabswid
.66605 .48126 Mdot
1 .116 0 r
.5 Mabswid
.67199 .46289 m
.64358 .42097 L
s
0 0 0 r
2.5 Mabswid
.67199 .46289 Mdot
1 .115 0 r
.5 Mabswid
.43443 .47033 m
.58693 .41844 L
s
0 0 0 r
2.5 Mabswid
.43443 .47033 Mdot
0 .364 1 r
.5 Mabswid
.53965 .35485 m
.53398 .65555 L
s
0 0 0 r
2.5 Mabswid
.53965 .35485 Mdot
.63227 .56047 Mdot
.699 1 0 r
.5 Mabswid
.55994 .54651 m
.63227 .56047 L
s
.435 1 0 r
.61402 .39874 m
.51828 .48806 L
s
0 0 0 r
2.5 Mabswid
.61402 .39874 Mdot
.14418 .34283 Mdot
.797 1 0 r
.5 Mabswid
.54319 .6578 m
.57813 .65435 L
s
0 0 0 r
2.5 Mabswid
.54319 .6578 Mdot
.15105 .3377 Mdot
.47121 .58787 Mdot
1 .728 0 r
.5 Mabswid
.57387 .56953 m
.47121 .58787 L
s
0 0 0 r
2.5 Mabswid
.15784 .33262 Mdot
.72832 .79582 Mdot
.16456 .32759 Mdot
0 .449 1 r
.5 Mabswid
.42486 .42893 m
.56665 .39614 L
s
0 0 0 r
2.5 Mabswid
.42486 .42893 Mdot
.371 1 0 r
.5 Mabswid
.62147 .40374 m
.53519 .48529 L
s
0 0 0 r
2.5 Mabswid
.62147 .40374 Mdot
.045 1 0 r
.5 Mabswid
.5322 .35213 m
.44311 .52387 L
s
0 0 0 r
2.5 Mabswid
.5322 .35213 Mdot
1 .728 0 r
.5 Mabswid
.54984 .66364 m
.58162 .64554 L
s
0 0 0 r
2.5 Mabswid
.54984 .66364 Mdot
.66174 .49608 Mdot
1 .116 0 r
.5 Mabswid
.64497 .43366 m
.66174 .49608 L
s
0 g
.65665 .512 m
.56709 .67562 L
s
.6803 .44613 m
.65665 .512 L
s
.65667 .51195 m
.56711 .67557 L
s
.6567 .51202 m
.6803 .44614 L
s
.514 1 0 r
.62075 .40327 m
.49215 .60293 L
s
0 0 0 r
2.5 Mabswid
.62075 .40327 Mdot
0 1 .381 r
.5 Mabswid
.60473 .61144 m
.46307 .49176 L
s
0 0 0 r
2.5 Mabswid
.60473 .61144 Mdot
.48728 .32989 Mdot
0 .149 1 r
.5 Mabswid
.50443 .63199 m
.48728 .32989 L
s
0 g
.40065 .1313 m
.58842 .05741 L
s
.39703 .58293 m
.40065 .1313 L
s
0 0 0 r
2.5 Mabswid
.42754 .41623 Mdot
1 .116 0 r
.5 Mabswid
.5997 .39428 m
.42754 .41623 L
s
.778 1 0 r
.42777 .45474 m
.54287 .38176 L
s
0 0 0 r
2.5 Mabswid
.42777 .45474 Mdot
1 .096 0 r
.5 Mabswid
.59647 .44539 m
.42777 .45474 L
s
0 0 0 r
2.5 Mabswid
.74434 .50038 Mdot
0 .498 1 r
.5 Mabswid
.42663 .42028 m
.55697 .38974 L
s
0 0 0 r
2.5 Mabswid
.42663 .42028 Mdot
.514 1 0 r
.5 Mabswid
.6278 .408 m
.49844 .61048 L
s
0 0 0 r
2.5 Mabswid
.6278 .408 Mdot
.103 1 0 r
.5 Mabswid
.59144 .38511 m
.53977 .22384 L
s
0 1 .595 r
.59144 .38511 m
.44798 .54293 L
s
0 0 0 r
2.5 Mabswid
.59144 .38511 Mdot
1 .115 0 r
.5 Mabswid
.43127 .4667 m
.57827 .41636 L
s
0 0 0 r
2.5 Mabswid
.43127 .4667 Mdot
.732 1 0 r
.5 Mabswid
.46366 .57145 m
.46144 .57509 L
s
0 0 0 r
2.5 Mabswid
.46366 .57145 Mdot
.045 1 0 r
.5 Mabswid
.54421 .35969 m
.43453 .38723 L
s
0 0 0 r
2.5 Mabswid
.54421 .35969 Mdot
.5019 .33812 Mdot
.46451 .57474 Mdot
.333 1 0 r
.5 Mabswid
.44554 .53094 m
.46451 .57474 L
s
0 1 .36 r
.55253 .36452 m
.62647 .14276 L
s
0 0 0 r
2.5 Mabswid
.55253 .36452 Mdot
.819 1 0 r
.5 Mabswid
.43897 .49387 m
.52903 .51765 L
s
0 0 0 r
2.5 Mabswid
.43897 .49387 Mdot
0 .111 1 r
.5 Mabswid
.42839 .4116 m
.54733 .38337 L
s
0 0 0 r
2.5 Mabswid
.42839 .4116 Mdot
1 .116 0 r
.5 Mabswid
.6746 .45745 m
.65448 .42762 L
s
0 0 0 r
2.5 Mabswid
.6746 .45745 Mdot
.666 .4846 Mdot
1 .116 0 r
.5 Mabswid
.65294 .43591 m
.666 .4846 L
s
.388 1 0 r
.61011 .59918 m
.61171 .55291 L
s
0 0 0 r
2.5 Mabswid
.61011 .59918 Mdot
.43866 .49454 Mdot
.03 0 1 r
.5 Mabswid
.48999 .35225 m
.43866 .49454 L
s
0 0 0 r
2.5 Mabswid
.43424 .385 Mdot
0 1 .928 r
.5 Mabswid
.54154 .37241 m
.43424 .385 L
s
0 0 0 r
2.5 Mabswid
.21864 .2894 Mdot
.814 1 0 r
.5 Mabswid
.44072 .50257 m
.52871 .52653 L
s
0 0 0 r
2.5 Mabswid
.44072 .50257 Mdot
.47309 .59261 Mdot
0 1 .453 r
.5 Mabswid
.45988 .55321 m
.47309 .59261 L
s
0 0 0 r
2.5 Mabswid
.42657 .41868 Mdot
0 1 .003 r
.5 Mabswid
.62785 .43276 m
.42657 .41868 L
s
0 0 0 r
2.5 Mabswid
.6754 .4521 Mdot
0 1 .832 r
.5 Mabswid
.62004 .48014 m
.6754 .4521 L
s
1 .115 0 r
.42809 .46306 m
.56961 .41428 L
s
0 0 0 r
2.5 Mabswid
.42809 .46306 Mdot
.67509 .44731 Mdot
.806 1 0 r
.5 Mabswid
.65894 .43193 m
.67509 .44731 L
s
0 0 0 r
2.5 Mabswid
.43785 .36794 Mdot
0 .989 1 r
.5 Mabswid
.44968 .35042 m
.43785 .36794 L
s
0 0 0 r
2.5 Mabswid
.58597 .64355 Mdot
.778 1 0 r
.5 Mabswid
.52662 .64679 m
.58597 .64355 L
s
0 .989 1 r
.61681 .58362 m
.43099 .39395 L
s
0 0 0 r
2.5 Mabswid
.61681 .58362 Mdot
.699 1 0 r
.5 Mabswid
.42481 .42593 m
.4697 .4029 L
s
0 0 0 r
2.5 Mabswid
.42481 .42593 Mdot
.67026 .47312 Mdot
1 .116 0 r
.5 Mabswid
.66091 .43816 m
.67026 .47312 L
s
0 0 0 r
2.5 Mabswid
.42548 .4544 Mdot
1 .096 0 r
.5 Mabswid
.58698 .44544 m
.42548 .4544 L
s
0 0 0 r
2.5 Mabswid
.67326 .46375 Mdot
0 1 .67 r
.5 Mabswid
.62745 .4871 m
.67326 .46375 L
s
0 1 .381 r
.46932 .58782 m
.48727 .42646 L
s
0 0 0 r
2.5 Mabswid
.46932 .58782 Mdot
.52662 .64679 Mdot
.778 1 0 r
.5 Mabswid
.48205 .36474 m
.52662 .64679 L
s
0 1 .532 r
.53239 .65164 m
.52253 .38328 L
s
0 0 0 r
2.5 Mabswid
.53239 .65164 Mdot
0 1 .532 r
.5 Mabswid
.58584 .64275 m
.53239 .65164 L
s
0 0 0 r
2.5 Mabswid
.72559 .44711 Mdot
0 .542 1 r
.5 Mabswid
.42597 .42019 m
.50566 .34459 L
s
0 0 0 r
2.5 Mabswid
.42597 .42019 Mdot
0 .542 1 r
.5 Mabswid
.50881 .63281 m
.42597 .42019 L
s
0 0 0 r
2.5 Mabswid
.58584 .64275 Mdot
.65718 .50127 Mdot
0 .739 1 r
.5 Mabswid
.43356 .48846 m
.65718 .50127 L
s
0 0 0 r
2.5 Mabswid
.49875 .34032 Mdot
1 .116 0 r
.5 Mabswid
.67723 .45196 m
.66535 .43425 L
s
0 0 0 r
2.5 Mabswid
.67723 .45196 Mdot
0 1 .381 r
.5 Mabswid
.45734 .56279 m
.51524 .38061 L
s
0 0 0 r
2.5 Mabswid
.45734 .56279 Mdot
0 1 .381 r
.5 Mabswid
.57095 .6465 m
.45734 .56279 L
s
0 g
.44717 .33328 m
.61915 .40228 L
s
.67906 .4425 m
.61909 .40225 L
s
.61912 .40221 m
.67907 .44249 L
s
.44712 .33325 m
.61912 .40221 L
s
0 0 0 r
2.5 Mabswid
.44862 .53519 Mdot
0 .542 1 r
.5 Mabswid
.56774 .4752 m
.44862 .53519 L
s
0 1 .37 r
.55266 .36824 m
.6261 .14851 L
s
0 0 0 r
2.5 Mabswid
.55266 .36824 Mdot
.66341 .48809 Mdot
.819 1 0 r
.5 Mabswid
.42555 .45914 m
.19275 .40846 L
s
1 .094 0 r
.42555 .45914 m
.61427 .42501 L
s
0 0 0 r
2.5 Mabswid
.42555 .45914 Mdot
.42594 .41962 Mdot
0 1 .381 r
.5 Mabswid
.48727 .42646 m
.42594 .41962 L
s
0 0 0 r
2.5 Mabswid
.59388 .62593 Mdot
.50566 .34459 Mdot
.50881 .63281 Mdot
0 .542 1 r
.5 Mabswid
.5782 .64743 m
.50881 .63281 L
s
0 0 0 r
2.5 Mabswid
.43206 .24587 Mdot
.757 1 0 r
.5 Mabswid
.42646 .41225 m
.43206 .24587 L
s
0 0 0 r
2.5 Mabswid
.43492 .37931 Mdot
0 1 .754 r
.5 Mabswid
.52898 .36829 m
.43492 .37931 L
s
0 0 0 r
2.5 Mabswid
.4241 .43809 Mdot
.136 0 1 r
.5 Mabswid
.46769 .33407 m
.4241 .43809 L
s
0 .989 1 r
.46648 .58474 m
.43888 .52886 L
s
0 0 0 r
2.5 Mabswid
.46648 .58474 Mdot
.67452 .46163 Mdot
1 .116 0 r
.5 Mabswid
.66886 .44041 m
.67452 .46163 L
s
0 g
.56181 .67699 m
.56714 .67554 L
s
.53033 .65518 m
.56181 .67699 L
s
.56182 .677 m
.48736 .61945 L
s
.53034 .65519 m
.56182 .677 L
s
.56182 .67701 m
.48748 .61932 L
s
.56712 .67554 m
.56179 .67699 L
s
.2 0 1 r
.63805 .536 m
.54147 .53538 L
s
0 0 0 r
2.5 Mabswid
.63805 .536 Mdot
.44044 .35422 Mdot
0 .989 1 r
.5 Mabswid
.53442 .39895 m
.44044 .35422 L
s
.865 1 0 r
.61419 .40191 m
.42455 .45327 L
s
0 0 0 r
2.5 Mabswid
.61419 .40191 Mdot
.741 1 0 r
.5 Mabswid
.57757 .65574 m
.47499 .59914 L
s
0 0 0 r
2.5 Mabswid
.57757 .65574 Mdot
.57813 .65435 Mdot
.5997 .39428 Mdot
.778 1 0 r
.5 Mabswid
.43788 .36521 m
.48205 .36474 L
s
0 0 0 r
2.5 Mabswid
.43788 .36521 Mdot
0 .547 1 r
.5 Mabswid
.52264 .35507 m
.63553 .23557 L
s
0 0 0 r
2.5 Mabswid
.52264 .35507 Mdot
0 g
.5 Mabswid
.56714 .67554 m
.53581 .65366 L
s
.56712 .67557 m
.64207 .5043 L
s
.53579 .65369 m
.56712 .67557 L
s
.56709 .67562 m
.64208 .50437 L
s
.045 1 0 r
.44311 .52387 m
.54207 .60573 L
s
0 0 0 r
2.5 Mabswid
.44311 .52387 Mdot
.61064 .40087 Mdot
.47446 .59716 Mdot
.045 1 0 r
.5 Mabswid
.53207 .50965 m
.47446 .59716 L
s
0 0 0 r
2.5 Mabswid
.47676 .60063 Mdot
0 .932 1 r
.5 Mabswid
.62628 .45273 m
.47676 .60063 L
s
0 0 0 r
2.5 Mabswid
.62166 .40759 Mdot
.56492 .37726 Mdot
.58162 .64554 Mdot
.63264 .41429 Mdot
1 .116 0 r
.5 Mabswid
.67989 .44642 m
.67618 .44086 L
s
0 0 0 r
2.5 Mabswid
.67989 .44642 Mdot
.817 1 0 r
.5 Mabswid
.42474 .45452 m
.20181 .40528 L
s
1 .094 0 r
.42474 .45452 m
.60238 .42215 L
s
0 0 0 r
2.5 Mabswid
.42474 .45452 Mdot
.43334 .49532 Mdot
0 1 .711 r
.5 Mabswid
.4697 .4029 m
.43334 .49532 L
s
0 0 0 r
2.5 Mabswid
.64358 .42097 Mdot
0 1 .595 r
.5 Mabswid
.44798 .54293 m
.54336 .58517 L
s
0 0 0 r
2.5 Mabswid
.44798 .54293 Mdot
.67879 .45013 Mdot
1 .116 0 r
.5 Mabswid
.6768 .44265 m
.67879 .45013 L
s
0 g
.68006 .44398 m
.6795 .44278 L
s
.68038 .44539 m
.68006 .44398 L
s
.68008 .44399 m
.67952 .44279 L
s
.6804 .44537 m
.68007 .44397 L
s
0 1 .643 r
.43684 .3686 m
.45993 .34188 L
s
0 0 0 r
2.5 Mabswid
.43684 .3686 Mdot
0 .881 1 r
.5 Mabswid
.5528 .37199 m
.62574 .1543 L
s
0 0 0 r
2.5 Mabswid
.5528 .37199 Mdot
.6268 .55394 Mdot
.142 1 0 r
.5 Mabswid
.62017 .42359 m
.6268 .55394 L
s
.703 1 0 r
.18332 .60708 m
.42455 .45327 L
s
0 1 .063 r
.42455 .45327 m
.64285 .48282 L
s
0 0 0 r
2.5 Mabswid
.42455 .45327 Mdot
0 g
.5 Mabswid
.68029 .44617 m
.68038 .44539 L
s
.6803 .44614 m
.6804 .44535 L
s
0 0 0 r
2.5 Mabswid
.65448 .42762 Mdot
0 g
.5 Mabswid
.6795 .44278 m
.67903 .44247 L
s
.67953 .4428 m
.67906 .4425 L
s
0 0 0 r
2.5 Mabswid
.66535 .43425 Mdot
0 1 .453 r
.5 Mabswid
.42843 .48241 m
.44665 .51224 L
s
0 0 0 r
2.5 Mabswid
.42843 .48241 Mdot
0 .989 1 r
.5 Mabswid
.55859 .67475 m
.55874 .67463 L
s
0 0 0 r
2.5 Mabswid
.55859 .67475 Mdot
.44879 .32867 Mdot
.388 1 0 r
.5 Mabswid
.47422 .33922 m
.44879 .32867 L
s
0 0 0 r
2.5 Mabswid
.4356 .37358 Mdot
0 1 .653 r
.5 Mabswid
.51632 .36414 m
.4356 .37358 L
s
0 g
.67982 .44587 m
.68029 .44617 L
s
.67984 .44583 m
.6803 .44613 L
s
0 0 0 r
2.5 Mabswid
.67618 .44086 Mdot
0 g
.5 Mabswid
.67907 .44249 m
.67897 .44327 L
s
.67903 .44247 m
.67893 .44325 L
s
0 .989 1 r
.55874 .67463 m
.56126 .66679 L
s
0 0 0 r
2.5 Mabswid
.55874 .67463 Mdot
.8 1 0 r
.5 Mabswid
.59006 .62538 m
.53676 .65794 L
s
0 0 0 r
2.5 Mabswid
.59006 .62538 Mdot
0 .364 1 r
.5 Mabswid
.53398 .65555 m
.57923 .64344 L
s
0 0 0 r
2.5 Mabswid
.53398 .65555 Mdot
.741 1 0 r
.5 Mabswid
.47499 .59914 m
.43824 .35376 L
s
0 0 0 r
2.5 Mabswid
.47499 .59914 Mdot
.42787 .40767 Mdot
0 .029 1 r
.5 Mabswid
.45999 .3318 m
.42787 .40767 L
s
0 0 0 r
2.5 Mabswid
.43727 .51281 Mdot
0 1 .532 r
.5 Mabswid
.48018 .5997 m
.43727 .51281 L
s
0 g
.67929 .44464 m
.67985 .44584 L
s
.67985 .44584 m
.64205 .50436 L
s
.67926 .44466 m
.67982 .44587 L
s
.64208 .50437 m
.67984 .44583 L
s
0 0 0 r
2.5 Mabswid
.5782 .64743 Mdot
.65894 .43193 Mdot
.806 1 0 r
.5 Mabswid
.42301 .45295 m
.65894 .43193 L
s
0 g
.67897 .44325 m
.67929 .44466 L
s
.61491 .42512 m
.67897 .44325 L
s
.67897 .44327 m
.61489 .42516 L
s
.67893 .44325 m
.67926 .44466 L
s
1 .886 0 r
.62099 .56274 m
.5215 .39113 L
s
0 0 0 r
2.5 Mabswid
.62099 .56274 Mdot
.72713 .46204 Mdot
.43413 .37945 Mdot
0 .829 1 r
.5 Mabswid
.49255 .36403 m
.43413 .37945 L
s
0 g
.67929 .44466 m
.62447 .46807 L
s
.6245 .46806 m
.67929 .44464 L
s
0 0 0 r
2.5 Mabswid
.72869 .4675 Mdot
.6768 .44265 Mdot
.73027 .47301 Mdot
.57923 .64344 Mdot
0 .538 1 r
.5 Mabswid
.44827 .55056 m
.47122 .45243 L
s
0 0 0 r
2.5 Mabswid
.44827 .55056 Mdot
.44392 .34021 Mdot
0 .538 1 r
.5 Mabswid
.49913 .37548 m
.44392 .34021 L
s
0 0 0 r
2.5 Mabswid
.56005 .37801 Mdot
.43438 .37777 Mdot
1 .886 0 r
.5 Mabswid
.5215 .39113 m
.43438 .37777 L
s
0 0 0 r
2.5 Mabswid
.50443 .63199 Mdot
0 .149 1 r
.5 Mabswid
.5754 .62605 m
.50443 .63199 L
s
.815 1 0 r
.42392 .44985 m
.21084 .4021 L
s
1 .094 0 r
.42392 .44985 m
.59043 .41928 L
s
0 0 0 r
2.5 Mabswid
.42392 .44985 Mdot
0 1 .989 r
.5 Mabswid
.56746 .38203 m
.6689 .32226 L
s
0 0 0 r
2.5 Mabswid
.56746 .38203 Mdot
.68687 .78174 Mdot
0 g
.5 Mabswid
.44082 .53444 m
.45241 .567 L
s
.45241 .567 m
.48738 .61949 L
s
.45243 .56703 m
.44067 .53457 L
s
.42586 .49212 m
.45243 .56703 L
s
.48738 .61948 m
.45241 .56699 L
s
.42584 .49213 m
.45241 .56703 L
s
0 0 0 r
2.5 Mabswid
.2524 .28521 Mdot
.58123 .6366 Mdot
0 1 .632 r
.5 Mabswid
.53763 .6597 m
.58123 .6366 L
s
0 0 0 r
2.5 Mabswid
.66886 .44041 Mdot
.321 1 0 r
.5 Mabswid
.15679 .60027 m
.53676 .65794 L
s
.142 1 0 r
.53676 .65794 m
.61161 .41667 L
s
0 0 0 r
2.5 Mabswid
.53676 .65794 Mdot
0 1 .632 r
.5 Mabswid
.50644 .35196 m
.42864 .44086 L
s
0 0 0 r
2.5 Mabswid
.50644 .35196 Mdot
.62647 .14276 Mdot
.43629 .36781 Mdot
0 1 .542 r
.5 Mabswid
.50354 .35996 m
.43629 .36781 L
s
0 0 0 r
2.5 Mabswid
.42303 .42658 Mdot
0 .538 1 r
.5 Mabswid
.55702 .47975 m
.42303 .42658 L
s
0 0 0 r
2.5 Mabswid
.66454 .44197 Mdot
0 1 .532 r
.5 Mabswid
.54253 .66258 m
.5668 .65176 L
s
0 0 0 r
2.5 Mabswid
.54253 .66258 Mdot
.66091 .43816 Mdot
0 g
.5 Mabswid
.53035 .6552 m
.48737 .61946 L
s
.48737 .61946 m
.49581 .60506 L
s
.48738 .61949 m
.49583 .60508 L
s
.48736 .61945 m
.53034 .65519 L
s
0 .542 1 r
.44599 .54891 m
.45418 .3909 L
s
0 0 0 r
2.5 Mabswid
.44599 .54891 Mdot
.813 1 0 r
.5 Mabswid
.42309 .44514 m
.21986 .39893 L
s
1 .093 0 r
.42309 .44514 m
.57845 .4164 L
s
0 0 0 r
2.5 Mabswid
.42309 .44514 Mdot
.55451 .37916 Mdot
0 .989 1 r
.5 Mabswid
.43888 .52886 m
.4255 .47023 L
s
0 0 0 r
2.5 Mabswid
.43888 .52886 Mdot
.55237 .67035 Mdot
0 1 .632 r
.5 Mabswid
.55723 .66156 m
.55237 .67035 L
s
0 .364 1 r
.55935 .38224 m
.4678 .57283 L
s
0 0 0 r
2.5 Mabswid
.55935 .38224 Mdot
0 .918 1 r
.5 Mabswid
.46769 .33407 m
.54993 .17273 L
s
0 0 0 r
2.5 Mabswid
.46769 .33407 Mdot
.54154 .37241 Mdot
0 .989 1 r
.5 Mabswid
.56126 .66679 m
.50482 .49481 L
s
0 0 0 r
2.5 Mabswid
.56126 .66679 Mdot
.60213 .5896 Mdot
.65294 .43591 Mdot
.43294 .27382 Mdot
.756 1 0 r
.5 Mabswid
.42853 .40588 m
.43294 .27382 L
s
0 0 0 r
2.5 Mabswid
.57095 .6465 Mdot
0 g
.5 Mabswid
.4207 .43045 m
.42586 .49215 L
s
.42586 .49215 m
.44067 .5346 L
s
.44067 .53457 m
.42586 .49212 L
s
.42587 .49216 m
.42052 .43049 L
s
0 0 0 r
2.5 Mabswid
.43494 .51776 Mdot
.741 1 0 r
.5 Mabswid
.58054 .54402 m
.43494 .51776 L
s
0 0 0 r
2.5 Mabswid
.7092 .41451 Mdot
.317 1 0 r
.5 Mabswid
.52343 .36444 m
.7092 .41451 L
s
0 0 0 r
2.5 Mabswid
.71107 .42067 Mdot
.266 1 0 r
.5 Mabswid
.53013 .36924 m
.71107 .42067 L
s
0 0 0 r
2.5 Mabswid
.52343 .36444 Mdot
.62256 .42015 Mdot
0 .13 1 r
.5 Mabswid
.42879 .39888 m
.4996 .37435 L
s
0 0 0 r
2.5 Mabswid
.42879 .39888 Mdot
.71501 .43336 Mdot
.235 1 0 r
.5 Mabswid
.54358 .37888 m
.71501 .43336 L
s
0 0 0 r
2.5 Mabswid
.713 .42693 Mdot
.254 1 0 r
.5 Mabswid
.53685 .37405 m
.713 .42693 L
s
0 .42 1 r
.45999 .3318 m
.53632 .18033 L
s
0 0 0 r
2.5 Mabswid
.45999 .3318 Mdot
.58746 .6137 Mdot
.47422 .33922 Mdot
.388 1 0 r
.5 Mabswid
.5861 .47298 m
.47422 .33922 L
s
0 0 0 r
2.5 Mabswid
.5668 .65176 Mdot
.52898 .36829 Mdot
0 .989 1 r
.5 Mabswid
.44572 .54822 m
.46189 .47459 L
s
0 0 0 r
2.5 Mabswid
.44572 .54822 Mdot
.42713 .40586 Mdot
.793 1 0 r
.5 Mabswid
.50914 .3784 m
.42713 .40586 L
s
0 0 0 r
2.5 Mabswid
.6261 .14851 Mdot
.64497 .43366 Mdot
.53013 .36924 Mdot
0 1 .858 r
.5 Mabswid
.47789 .34167 m
.56918 .18249 L
s
.069 0 1 r
.47789 .34167 m
.42813 .49859 L
s
0 0 0 r
2.5 Mabswid
.47789 .34167 Mdot
.42478 .41617 Mdot
.789 1 0 r
.5 Mabswid
.51621 .38557 m
.42478 .41617 L
s
0 0 0 r
2.5 Mabswid
.42813 .49859 Mdot
.811 1 0 r
.5 Mabswid
.42226 .44038 m
.22886 .39577 L
s
1 .093 0 r
.42226 .44038 m
.56641 .41351 L
s
0 0 0 r
2.5 Mabswid
.42226 .44038 Mdot
.53849 .65974 Mdot
.045 1 0 r
.5 Mabswid
.55248 .64591 m
.53849 .65974 L
s
0 0 0 r
2.5 Mabswid
.42243 .42652 Mdot
.778 1 0 r
.5 Mabswid
.52332 .39278 m
.42243 .42652 L
s
0 0 0 r
2.5 Mabswid
.65798 .45487 Mdot
.52821 .36884 Mdot
0 .542 1 r
.5 Mabswid
.44083 .50411 m
.52821 .36884 L
s
0 0 0 r
2.5 Mabswid
.42301 .45295 Mdot
1 .116 0 r
.5 Mabswid
.59912 .44537 m
.42301 .45295 L
s
0 0 0 r
2.5 Mabswid
.54871 .38045 Mdot
0 .989 1 r
.5 Mabswid
.53289 .65539 m
.54892 .64755 L
s
0 0 0 r
2.5 Mabswid
.53289 .65539 Mdot
.53685 .37405 Mdot
.59508 .59566 Mdot
0 .038 1 r
.5 Mabswid
.43959 .49153 m
.59508 .59566 L
s
0 1 .128 r
.62743 .42506 m
.43356 .48846 L
s
0 0 0 r
2.5 Mabswid
.62743 .42506 Mdot
.61161 .41667 Mdot
0 .149 1 r
.5 Mabswid
.43667 .36239 m
.44856 .3376 L
s
0 0 0 r
2.5 Mabswid
.43667 .36239 Mdot
.50513 .63376 Mdot
0 1 .453 r
.5 Mabswid
.55064 .62752 m
.50513 .63376 L
s
0 0 0 r
2.5 Mabswid
.54358 .37888 Mdot
.63699 .4314 Mdot
.5283 .65188 Mdot
.741 1 0 r
.5 Mabswid
.5616 .64794 m
.5283 .65188 L
s
0 0 0 r
2.5 Mabswid
.63441 .51941 Mdot
.06 1 0 r
.5 Mabswid
.45916 .52874 m
.63441 .51941 L
s
0 g
.53581 .6537 m
.64208 .50431 L
s
.64208 .50431 m
.50137 .60346 L
s
.64205 .50436 m
.50134 .60351 L
s
.64207 .5043 m
.53579 .65369 L
s
0 0 0 r
2.5 Mabswid
.51632 .36414 Mdot
0 1 .874 r
.5 Mabswid
.48403 .34682 m
.57848 .18399 L
s
.089 0 1 r
.48403 .34682 m
.43262 .5113 L
s
0 0 0 r
2.5 Mabswid
.48403 .34682 Mdot
.28044 .27911 Mdot
.43262 .5113 Mdot
.8 1 0 r
.5 Mabswid
.57879 .62224 m
.4909 .62028 L
s
0 0 0 r
2.5 Mabswid
.57879 .62224 Mdot
.64332 .49079 Mdot
0 .588 1 r
.5 Mabswid
.43913 .52983 m
.64332 .49079 L
s
0 0 0 r
2.5 Mabswid
.62017 .42359 Mdot
.55723 .66156 Mdot
0 1 .632 r
.5 Mabswid
.50243 .45249 m
.55723 .66156 L
s
.46369 .33731 m
.44107 .33891 L
s
0 0 0 r
2.5 Mabswid
.46369 .33731 Mdot
.51776 .64378 Mdot
.746 1 0 r
.5 Mabswid
.56289 .63843 m
.51776 .64378 L
s
0 0 0 r
2.5 Mabswid
.4909 .62028 Mdot
0 .989 1 r
.5 Mabswid
.4843 .6112 m
.53951 .49308 L
s
0 0 0 r
2.5 Mabswid
.4843 .6112 Mdot
.62899 .42914 Mdot
.54733 .38337 Mdot
.809 1 0 r
.5 Mabswid
.42141 .43557 m
.23783 .39262 L
s
1 .092 0 r
.42141 .43557 m
.55433 .4106 L
s
0 0 0 r
2.5 Mabswid
.42141 .43557 Mdot
.5754 .62605 Mdot
.152 0 1 r
.5 Mabswid
.58633 .40574 m
.5187 .21467 L
s
0 0 0 r
2.5 Mabswid
.58633 .40574 Mdot
.64285 .48282 Mdot
.54287 .38176 Mdot
.55697 .38974 Mdot
0 1 .91 r
.5 Mabswid
.48999 .35225 m
.58377 .20091 L
s
0 0 0 r
2.5 Mabswid
.48999 .35225 Mdot
.50354 .35996 Mdot
.62574 .1543 Mdot
.62785 .43276 Mdot
.63755 .44586 Mdot
.4228 .45253 Mdot
1 .116 0 r
.5 Mabswid
.58793 .44544 m
.4228 .45253 L
s
0 0 0 r
2.5 Mabswid
.42125 .43605 Mdot
0 .149 1 r
.5 Mabswid
.49866 .42223 m
.42125 .43605 L
s
0 0 0 r
2.5 Mabswid
.56665 .39614 Mdot
.62098 .42688 Mdot
.42107 .43495 Mdot
0 .989 1 r
.5 Mabswid
.49169 .55584 m
.42107 .43495 L
s
0 0 0 r
2.5 Mabswid
.5616 .64794 Mdot
.732 1 0 r
.5 Mabswid
.46144 .57509 m
.49499 .55789 L
s
0 0 0 r
2.5 Mabswid
.46144 .57509 Mdot
0 .989 1 r
.5 Mabswid
.4255 .47023 m
.429 .39677 L
s
0 0 0 r
2.5 Mabswid
.4255 .47023 Mdot
.63352 .44518 Mdot
.388 1 0 r
.5 Mabswid
.61171 .55291 m
.61101 .54506 L
s
0 0 0 r
2.5 Mabswid
.61171 .55291 Mdot
.44159 .53674 Mdot
0 .702 1 r
.5 Mabswid
.56049 .52383 m
.44159 .53674 L
s
.149 0 1 r
.57791 .40377 m
.51154 .22047 L
s
0 0 0 r
2.5 Mabswid
.57791 .40377 Mdot
.595 1 0 r
.5 Mabswid
.6069 .42061 m
.64037 .25846 L
s
0 0 0 r
2.5 Mabswid
.6069 .42061 Mdot
0 g
.5 Mabswid
.44864 .45394 m
.61494 .42516 L
s
.61494 .42516 m
.4407 .38328 L
s
.4407 .3833 m
.61494 .42518 L
s
.61494 .42518 m
.44718 .33326 L
s
.61489 .42516 m
.44712 .33325 L
s
.235 1 0 r
.58036 .40579 m
.57991 .1953 L
s
0 0 0 r
2.5 Mabswid
.58036 .40579 Mdot
0 g
.5 Mabswid
.44859 .45393 m
.61491 .42512 L
s
0 1 .391 r
.22218 .71858 m
.43913 .52983 L
s
0 0 0 r
2.5 Mabswid
.61427 .42501 Mdot
0 1 .284 r
.5 Mabswid
.62033 .43268 m
.43913 .52983 L
s
0 0 0 r
2.5 Mabswid
.62033 .43268 Mdot
.61282 .42466 Mdot
0 .989 1 r
.5 Mabswid
.56419 .63979 m
.51046 .63363 L
s
0 0 0 r
2.5 Mabswid
.56419 .63979 Mdot
.807 1 0 r
.5 Mabswid
.42056 .43071 m
.24678 .38948 L
s
1 .092 0 r
.42056 .43071 m
.5422 .40769 L
s
0 0 0 r
2.5 Mabswid
.42056 .43071 Mdot
0 g
.5 Mabswid
.44311 .45572 m
.4207 .43045 L
s
.44311 .45575 m
.42052 .4305 L
s
.42052 .4305 m
.43527 .38513 L
s
.43527 .38515 m
.42052 .43052 L
s
.42052 .43052 m
.44191 .33511 L
s
.42052 .43052 m
.44191 .3351 L
s
.741 1 0 r
.45552 .5652 m
.45138 .42319 L
s
0 0 0 r
2.5 Mabswid
.45552 .5652 Mdot
0 g
.5 Mabswid
.44721 .33327 m
.44191 .33512 L
s
.44191 .33512 m
.43527 .38516 L
s
.44191 .33511 m
.43527 .38515 L
s
.4419 .33514 m
.4472 .33329 L
s
0 0 0 r
2.5 Mabswid
.42929 .49376 Mdot
0 .989 1 r
.5 Mabswid
.54556 .52159 m
.42929 .49376 L
s
.265 1 0 r
.58677 .41066 m
.59798 .15497 L
s
0 0 0 r
2.5 Mabswid
.58677 .41066 Mdot
0 1 .795 r
.5 Mabswid
.44107 .33891 m
.25147 .52071 L
s
0 0 0 r
2.5 Mabswid
.44107 .33891 Mdot
.42583 .46777 Mdot
.746 1 0 r
.5 Mabswid
.54517 .50741 m
.42583 .46777 L
s
0 0 0 r
2.5 Mabswid
.53763 .6597 Mdot
0 1 .632 r
.5 Mabswid
.555 .58458 m
.53763 .6597 L
s
0 0 0 r
2.5 Mabswid
.48528 .61027 Mdot
0 .327 1 r
.5 Mabswid
.56712 .51458 m
.48528 .61027 L
s
0 0 0 r
2.5 Mabswid
.6244 .44523 Mdot
.43913 .52983 Mdot
0 g
.5 Mabswid
.44073 .38332 m
.44721 .33327 L
s
.44718 .33326 m
.4407 .3833 L
s
0 0 0 r
2.5 Mabswid
.6042 .42259 Mdot
.56289 .63843 Mdot
0 .038 1 r
.5 Mabswid
.43946 .3471 m
.45294 .34536 L
s
0 0 0 r
2.5 Mabswid
.43946 .3471 Mdot
.60238 .42215 Mdot
.44797 .55269 Mdot
0 .327 1 r
.5 Mabswid
.57449 .43765 m
.44797 .55269 L
s
.388 1 0 r
.61101 .54506 m
.5861 .47298 L
s
0 0 0 r
2.5 Mabswid
.61101 .54506 Mdot
.42434 .45204 Mdot
1 .116 0 r
.5 Mabswid
.57663 .4455 m
.42434 .45204 L
s
0 .852 1 r
.45993 .34188 m
.61428 .27355 L
s
0 0 0 r
2.5 Mabswid
.45993 .34188 Mdot
.62628 .45273 Mdot
.62745 .4871 Mdot
0 1 .67 r
.5 Mabswid
.46307 .54318 m
.62745 .4871 L
s
0 0 0 r
2.5 Mabswid
.5958 .57306 Mdot
0 .884 1 r
.5 Mabswid
.48728 .60361 m
.5958 .57306 L
s
0 0 0 r
2.5 Mabswid
.59557 .42051 Mdot
0 .016 1 r
.5 Mabswid
.44856 .3376 m
.52636 .16832 L
s
0 0 0 r
2.5 Mabswid
.44856 .3376 Mdot
.741 1 0 r
.5 Mabswid
.43824 .35376 m
.44851 .33892 L
s
0 0 0 r
2.5 Mabswid
.43824 .35376 Mdot
0 .038 1 r
.5 Mabswid
.45799 .5671 m
.56263 .59001 L
s
0 0 0 r
2.5 Mabswid
.45799 .5671 Mdot
.61518 .44528 Mdot
.62597 .45944 Mdot
.62987 .46832 Mdot
.42242 .42468 Mdot
.782 1 0 r
.5 Mabswid
.42242 .42468 m
.42242 .42468 L
s
0 0 0 r
2.5 Mabswid
.42242 .42468 Mdot
.782 1 0 r
.5 Mabswid
.42242 .42468 m
.42242 .42468 L
s
0 0 0 r
2.5 Mabswid
.42242 .42468 Mdot
.782 1 0 r
.5 Mabswid
.42242 .42468 m
.42242 .42468 L
s
0 0 0 r
2.5 Mabswid
.42242 .42468 Mdot
.782 1 0 r
.5 Mabswid
.42242 .42468 m
.42242 .42468 L
s
.42242 .42468 m
.42242 .42468 L
s
1 .992 0 r
.42242 .42468 m
.4781 .3694 L
s
0 0 0 r
2.5 Mabswid
.42242 .42468 Mdot
1 .056 0 r
.5 Mabswid
.42242 .42468 m
.42242 .42468 L
s
.508 1 0 r
.42242 .42468 m
.34861 .37209 L
s
0 0 0 r
2.5 Mabswid
.42242 .42468 Mdot
.42242 .42468 Mdot
.47283 .58964 Mdot
.778 1 0 r
.5 Mabswid
.52513 .41642 m
.47283 .58964 L
s
0 0 0 r
2.5 Mabswid
.59043 .41928 Mdot
.44851 .33892 Mdot
.49255 .36403 Mdot
0 1 .632 r
.5 Mabswid
.51036 .37427 m
.54815 .48013 L
s
0 0 0 r
2.5 Mabswid
.51036 .37427 Mdot
.42884 .4782 Mdot
.741 1 0 r
.5 Mabswid
.53886 .51485 m
.42884 .4782 L
s
0 .542 1 r
.43268 .37926 m
.46966 .35568 L
s
0 0 0 r
2.5 Mabswid
.43268 .37926 Mdot
.58693 .41844 Mdot
.045 1 0 r
.5 Mabswid
.54053 .39263 m
.51983 .54499 L
s
0 0 0 r
2.5 Mabswid
.54053 .39263 Mdot
.52253 .38328 Mdot
0 g
.5 Mabswid
.47024 .53246 m
.62452 .46805 L
s
.62452 .46805 m
.44864 .45391 L
s
.50139 .60349 m
.62451 .46803 L
s
.62451 .46803 m
.47023 .53244 L
s
.62447 .46807 m
.44859 .45393 L
s
.50134 .60351 m
.6245 .46806 L
s
0 .989 1 r
.429 .39677 m
.44968 .35042 L
s
0 0 0 r
2.5 Mabswid
.429 .39677 Mdot
.42589 .45154 Mdot
1 .116 0 r
.5 Mabswid
.56521 .44557 m
.42589 .45154 L
s
0 0 0 r
2.5 Mabswid
.57845 .4164 Mdot
.60588 .44534 Mdot
.48018 .5997 Mdot
0 1 .532 r
.5 Mabswid
.53211 .64919 m
.48018 .5997 L
s
0 0 0 r
2.5 Mabswid
.51524 .38061 Mdot
.57827 .41636 Mdot
.45294 .34536 Mdot
.62004 .48014 Mdot
0 1 .832 r
.5 Mabswid
.46003 .5346 m
.62004 .48014 L
s
0 0 0 r
2.5 Mabswid
.55248 .64591 Mdot
.045 1 0 r
.5 Mabswid
.44836 .3977 m
.55248 .64591 L
s
.81 1 0 r
.43108 .48864 m
.59654 .52632 L
s
0 0 0 r
2.5 Mabswid
.43108 .48864 Mdot
.46966 .35568 Mdot
.47727 .59489 Mdot
0 .038 1 r
.5 Mabswid
.56244 .50187 m
.47727 .59489 L
s
0 0 0 r
2.5 Mabswid
.50914 .3784 Mdot
0 1 .632 r
.5 Mabswid
.42596 .41102 m
.50277 .55486 L
s
0 0 0 r
2.5 Mabswid
.42596 .41102 Mdot
0 1 .632 r
.5 Mabswid
.43167 .38586 m
.50243 .45249 L
s
0 0 0 r
2.5 Mabswid
.43167 .38586 Mdot
.4996 .37435 Mdot
.56961 .41428 Mdot
.48205 .36474 Mdot
.59912 .44537 Mdot
.42442 .41851 Mdot
.757 1 0 r
.5 Mabswid
.42442 .41851 m
.42442 .41851 L
s
0 0 0 r
2.5 Mabswid
.42442 .41851 Mdot
.757 1 0 r
.5 Mabswid
.42442 .41851 m
.42442 .41851 L
s
0 0 0 r
2.5 Mabswid
.42442 .41851 Mdot
.757 1 0 r
.5 Mabswid
.42442 .41851 m
.42442 .41851 L
s
0 0 0 r
2.5 Mabswid
.42442 .41851 Mdot
.757 1 0 r
.5 Mabswid
.42442 .41851 m
.42442 .41851 L
s
.42442 .41851 m
.42442 .41851 L
s
1 .946 0 r
.42442 .41851 m
.47166 .37122 L
s
0 0 0 r
2.5 Mabswid
.42442 .41851 Mdot
1 .054 0 r
.5 Mabswid
.42442 .41851 m
.42442 .41851 L
s
.5 1 0 r
.42442 .41851 m
.35551 .36851 L
s
0 0 0 r
2.5 Mabswid
.42442 .41851 Mdot
.42442 .41851 Mdot
.56641 .41351 Mdot
.49913 .37548 Mdot
0 .538 1 r
.5 Mabswid
.57583 .50993 m
.49913 .37548 L
s
0 .989 1 r
.54892 .64755 m
.43403 .47418 L
s
0 0 0 r
2.5 Mabswid
.54892 .64755 Mdot
.806 1 0 r
.5 Mabswid
.43295 .49691 m
.59041 .53302 L
s
0 0 0 r
2.5 Mabswid
.43295 .49691 Mdot
.51621 .38557 Mdot
.59647 .44539 Mdot
.4266 .40977 Mdot
.741 1 0 r
.5 Mabswid
.4767 .41074 m
.4266 .40977 L
s
0 0 0 r
2.5 Mabswid
.44968 .35042 Mdot
.5215 .39113 Mdot
.43862 .52863 Mdot
0 1 .453 r
.5 Mabswid
.49499 .55789 m
.43862 .52863 L
s
.797 1 0 r
.51187 .63705 m
.54072 .62015 L
s
0 0 0 r
2.5 Mabswid
.51187 .63705 Mdot
0 1 .394 r
.5 Mabswid
.60276 .4613 m
.48728 .60361 L
s
0 0 0 r
2.5 Mabswid
.60276 .4613 Mdot
.53442 .39895 Mdot
0 .989 1 r
.5 Mabswid
.60089 .50126 m
.53442 .39895 L
s
0 0 0 r
2.5 Mabswid
.42746 .45104 Mdot
1 .116 0 r
.5 Mabswid
.55366 .44563 m
.42746 .45104 L
s
0 0 0 r
2.5 Mabswid
.52332 .39278 Mdot
.64131 .22508 Mdot
.55433 .4106 Mdot
.803 1 0 r
.5 Mabswid
.43483 .50524 m
.58426 .53975 L
s
0 0 0 r
2.5 Mabswid
.43483 .50524 Mdot
.58793 .44544 Mdot
.49048 .61275 Mdot
0 .989 1 r
.5 Mabswid
.53328 .62764 m
.49048 .61275 L
s
0 0 0 r
2.5 Mabswid
.58698 .44544 Mdot
.59654 .52632 Mdot
.42748 .44842 Mdot
0 .538 1 r
.5 Mabswid
.47122 .45243 m
.42748 .44842 L
s
0 0 0 r
2.5 Mabswid
.46062 .76194 Mdot
0 1 .62 r
.5 Mabswid
.48728 .60361 m
.46062 .76194 L
s
0 0 0 r
2.5 Mabswid
.43263 .38427 Mdot
0 .542 1 r
.5 Mabswid
.45418 .3909 m
.43263 .38427 L
s
1 .921 0 r
.4781 .3694 m
.60146 .19597 L
s
0 0 0 r
2.5 Mabswid
.4781 .3694 Mdot
.659 1 0 r
.5 Mabswid
.44342 .35168 m
.4418 .35043 L
s
0 0 0 r
2.5 Mabswid
.44342 .35168 Mdot
.741 1 0 r
.5 Mabswid
.53347 .65735 m
.53365 .65728 L
s
0 0 0 r
2.5 Mabswid
.53347 .65735 Mdot
.4418 .35043 Mdot
.741 1 0 r
.5 Mabswid
.53365 .65728 m
.53774 .65267 L
s
0 0 0 r
2.5 Mabswid
.53365 .65728 Mdot
0 g
.5 Mabswid
.62521 .51439 m
.58842 .05741 L
s
0 0 0 r
2.5 Mabswid
.60089 .50126 Mdot
.42646 .41225 Mdot
.757 1 0 r
.5 Mabswid
.42646 .41225 m
.42646 .41225 L
s
0 0 0 r
2.5 Mabswid
.42646 .41225 Mdot
.757 1 0 r
.5 Mabswid
.42646 .41225 m
.42646 .41225 L
s
0 0 0 r
2.5 Mabswid
.42646 .41225 Mdot
.757 1 0 r
.5 Mabswid
.42646 .41225 m
.42646 .41225 L
s
0 0 0 r
2.5 Mabswid
.42646 .41225 Mdot
.757 1 0 r
.5 Mabswid
.42646 .41225 m
.42646 .41225 L
s
.42646 .41225 m
.42646 .41225 L
s
1 .954 0 r
.42646 .41225 m
.46526 .37308 L
s
0 0 0 r
2.5 Mabswid
.42646 .41225 Mdot
1 .053 0 r
.5 Mabswid
.42646 .41225 m
.42646 .41225 L
s
.494 1 0 r
.42646 .41225 m
.36242 .36492 L
s
0 0 0 r
2.5 Mabswid
.42646 .41225 Mdot
.42646 .41225 Mdot
.5422 .40769 Mdot
.46937 .36685 Mdot
0 .989 1 r
.5 Mabswid
.43403 .47418 m
.46937 .36685 L
s
0 0 0 r
2.5 Mabswid
.57449 .43765 Mdot
.59041 .53302 Mdot
0 1 .303 r
.5 Mabswid
.17175 .66344 m
.43356 .48846 L
s
0 0 0 r
2.5 Mabswid
.43356 .48846 Mdot
.52988 .40152 Mdot
.55042 .4172 Mdot
.797 1 0 r
.5 Mabswid
.43058 .46449 m
.49242 .41679 L
s
0 0 0 r
2.5 Mabswid
.43058 .46449 Mdot
.43829 .36058 Mdot
.797 1 0 r
.5 Mabswid
.44196 .35829 m
.43829 .36058 L
s
0 1 .532 r
.54333 .64521 m
.53211 .64919 L
s
0 0 0 r
2.5 Mabswid
.54333 .64521 Mdot
.57663 .4455 Mdot
0 .542 1 r
.5 Mabswid
.51314 .63662 m
.53349 .62415 L
s
0 0 0 r
2.5 Mabswid
.51314 .63662 Mdot
0 .989 1 r
.5 Mabswid
.51046 .63363 m
.52049 .45816 L
s
0 0 0 r
2.5 Mabswid
.51046 .63363 Mdot
.55064 .62752 Mdot
.43166 .39058 Mdot
.741 1 0 r
.5 Mabswid
.47385 .42708 m
.43166 .39058 L
s
0 0 0 r
2.5 Mabswid
.4375 .36452 Mdot
0 .2 1 r
.5 Mabswid
.44463 .36178 m
.4375 .36452 L
s
0 0 0 r
2.5 Mabswid
.57387 .56953 Mdot
.42903 .45053 Mdot
1 .116 0 r
.5 Mabswid
.542 .4457 m
.42903 .45053 L
s
.92 1 0 r
.47166 .37122 m
.59337 .19906 L
s
0 0 0 r
2.5 Mabswid
.47166 .37122 Mdot
0 1 .049 r
.5 Mabswid
.59579 .48386 m
.47057 .63014 L
s
0 0 0 r
2.5 Mabswid
.59579 .48386 Mdot
.58426 .53975 Mdot
0 .989 1 r
.5 Mabswid
.43099 .39395 m
.47821 .37757 L
s
0 0 0 r
2.5 Mabswid
.43099 .39395 Mdot
.40124 .22206 Mdot
0 g
.5 Mabswid
.53034 .6552 m
.53583 .65368 L
s
.49581 .60506 m
.53034 .6552 L
s
.49581 .60506 m
.53035 .6552 L
s
.741 1 0 r
.53774 .65267 m
.47385 .42708 L
s
0 0 0 r
2.5 Mabswid
.53774 .65267 Mdot
0 g
.5 Mabswid
.53581 .65366 m
.53033 .65518 L
s
0 0 0 r
2.5 Mabswid
.44196 .35829 Mdot
.797 1 0 r
.5 Mabswid
.44527 .35819 m
.44196 .35829 L
s
0 g
.49583 .60508 m
.44082 .53444 L
s
.46466 .53417 m
.44067 .53458 L
s
.44067 .53458 m
.4431 .4557 L
s
.49583 .60509 m
.44066 .53456 L
s
.44066 .53456 m
.46465 .53414 L
s
.44067 .5346 m
.44311 .45572 L
s
0 .521 1 r
.54684 .42095 m
.65026 .38836 L
s
0 0 0 r
2.5 Mabswid
.54684 .42095 Mdot
.58443 .46339 Mdot
.55803 .60238 Mdot
.045 1 0 r
.5 Mabswid
.49153 .60266 m
.55803 .60238 L
s
0 0 0 r
2.5 Mabswid
.44527 .35819 Mdot
.6689 .32226 Mdot
.56263 .59001 Mdot
.58054 .54402 Mdot
.47821 .37757 Mdot
0 g
.5 Mabswid
.53583 .65368 m
.50139 .60344 L
s
.50137 .60346 m
.53581 .6537 L
s
0 0 0 r
2.5 Mabswid
.42853 .40588 Mdot
.756 1 0 r
.5 Mabswid
.42853 .40588 m
.42853 .40588 L
s
0 0 0 r
2.5 Mabswid
.42853 .40588 Mdot
.756 1 0 r
.5 Mabswid
.42853 .40588 m
.42853 .40588 L
s
0 0 0 r
2.5 Mabswid
.42853 .40588 Mdot
.756 1 0 r
.5 Mabswid
.42853 .40588 m
.42853 .40588 L
s
0 0 0 r
2.5 Mabswid
.42853 .40588 Mdot
.756 1 0 r
.5 Mabswid
.42853 .40588 m
.42853 .40588 L
s
.42853 .40588 m
.42853 .40588 L
s
1 .962 0 r
.42853 .40588 m
.45887 .37499 L
s
0 0 0 r
2.5 Mabswid
.42853 .40588 Mdot
1 .053 0 r
.5 Mabswid
.42853 .40588 m
.42853 .40588 L
s
.488 1 0 r
.42853 .40588 m
.36933 .36133 L
s
0 0 0 r
2.5 Mabswid
.42853 .40588 Mdot
.42853 .40588 Mdot
0 1 .532 r
.5 Mabswid
.42984 .45114 m
.476 .38562 L
s
0 0 0 r
2.5 Mabswid
.42984 .45114 Mdot
.5861 .47298 Mdot
.51594 .40016 Mdot
0 1 .632 r
.5 Mabswid
.42864 .44086 m
.56651 .52136 L
s
0 0 0 r
2.5 Mabswid
.42864 .44086 Mdot
.56521 .44557 Mdot
0 .473 1 r
.5 Mabswid
.5487 .42958 m
.65225 .39836 L
s
0 0 0 r
2.5 Mabswid
.5487 .42958 Mdot
0 .989 1 r
.5 Mabswid
.47909 .59184 m
.48779 .56006 L
s
0 0 0 r
2.5 Mabswid
.47909 .59184 Mdot
.568 .5671 Mdot
0 .364 1 r
.5 Mabswid
.4678 .57283 m
.568 .5671 L
s
.912 1 0 r
.46526 .37308 m
.57944 .21057 L
s
0 0 0 r
2.5 Mabswid
.46526 .37308 Mdot
.49033 .60892 Mdot
0 1 .632 r
.5 Mabswid
.50277 .55486 m
.49033 .60892 L
s
0 0 0 r
2.5 Mabswid
.44463 .36178 Mdot
.63121 .74882 Mdot
0 1 .347 r
.5 Mabswid
.54207 .60573 m
.63121 .74882 L
s
0 0 0 r
2.5 Mabswid
.53211 .64919 Mdot
.48728 .60361 Mdot
.43403 .47418 Mdot
.52513 .41642 Mdot
.19275 .40846 Mdot
.732 1 0 r
.5 Mabswid
.43076 .44855 m
.48715 .42182 L
s
0 0 0 r
2.5 Mabswid
.43076 .44855 Mdot
.43012 .41948 Mdot
0 .989 1 r
.5 Mabswid
.50482 .49481 m
.43012 .41948 L
s
0 0 0 r
2.5 Mabswid
.55366 .44563 Mdot
.54072 .62015 Mdot
.57583 .50993 Mdot
.555 .58458 Mdot
0 1 .632 r
.5 Mabswid
.54815 .48013 m
.555 .58458 L
s
.905 1 0 r
.45887 .37499 m
.56571 .22199 L
s
0 0 0 r
2.5 Mabswid
.45887 .37499 Mdot
.4678 .57283 Mdot
.476 .38562 Mdot
.56774 .4752 Mdot
.737 1 0 r
.5 Mabswid
.43048 .439 m
.4981 .42717 L
s
0 0 0 r
2.5 Mabswid
.43048 .439 Mdot
.20181 .40528 Mdot
.741 1 0 r
.5 Mabswid
.4307 .43335 m
.47082 .39011 L
s
0 0 0 r
2.5 Mabswid
.4307 .43335 Mdot
0 .502 1 r
.5 Mabswid
.56867 .53083 m
.66126 .61157 L
s
0 0 0 r
2.5 Mabswid
.56867 .53083 Mdot
.46773 .7494 Mdot
.608 1 0 r
.5 Mabswid
.53328 .62764 m
.48326 .63506 L
s
0 0 0 r
2.5 Mabswid
.53328 .62764 Mdot
.54207 .60573 Mdot
.53349 .62415 Mdot
.741 1 0 r
.5 Mabswid
.43126 .42974 m
.48859 .41957 L
s
0 0 0 r
2.5 Mabswid
.43126 .42974 Mdot
.56651 .52136 Mdot
.56712 .51458 Mdot
.43212 .44863 Mdot
0 .829 1 r
.5 Mabswid
.4831 .46095 m
.43212 .44863 L
s
0 0 0 r
2.5 Mabswid
.542 .4457 Mdot
.21084 .4021 Mdot
.55994 .54651 Mdot
.699 1 0 r
.5 Mabswid
.45894 .52443 m
.55994 .54651 L
s
.746 1 0 r
.43204 .42047 m
.47911 .41199 L
s
0 0 0 r
2.5 Mabswid
.43204 .42047 Mdot
.44554 .53094 Mdot
.333 1 0 r
.5 Mabswid
.47654 .49159 m
.44554 .53094 L
s
0 0 0 r
2.5 Mabswid
.55702 .47975 Mdot
.56049 .52383 Mdot
.56244 .50187 Mdot
.21986 .39893 Mdot
.47082 .39011 Mdot
0 1 .68 r
.5 Mabswid
.54336 .58517 m
.74875 .67442 L
s
0 0 0 r
2.5 Mabswid
.54336 .58517 Mdot
0 .542 1 r
.5 Mabswid
.43265 .43302 m
.47459 .40903 L
s
0 0 0 r
2.5 Mabswid
.43265 .43302 Mdot
0 .038 1 r
.5 Mabswid
.50538 .42166 m
.43959 .49153 L
s
0 0 0 r
2.5 Mabswid
.50538 .42166 Mdot
.50604 .62308 Mdot
0 .149 1 r
.5 Mabswid
.51479 .62591 m
.50604 .62308 L
s
0 0 0 r
2.5 Mabswid
.44083 .50411 Mdot
0 .542 1 r
.5 Mabswid
.53667 .57941 m
.44083 .50411 L
s
0 0 0 r
2.5 Mabswid
.77514 .68181 Mdot
0 .313 1 r
.5 Mabswid
.55306 .53674 m
.46564 .37104 L
s
0 0 0 r
2.5 Mabswid
.55306 .53674 Mdot
.54815 .48013 Mdot
.22886 .39577 Mdot
.43356 .41821 Mdot
.741 1 0 r
.5 Mabswid
.45138 .42319 m
.43356 .41821 L
s
0 0 0 r
2.5 Mabswid
.43959 .49153 Mdot
.49242 .41679 Mdot
.49866 .42223 Mdot
.045 1 0 r
.5 Mabswid
.43453 .38723 m
.44836 .3977 L
s
0 0 0 r
2.5 Mabswid
.43453 .38723 Mdot
.63553 .23557 Mdot
.45988 .55321 Mdot
0 1 .453 r
.5 Mabswid
.471 .5224 m
.45988 .55321 L
s
0 0 0 r
2.5 Mabswid
.23783 .39262 Mdot
.599 1 0 r
.5 Mabswid
.4697 .4029 m
.63284 .50433 L
s
0 0 0 r
2.5 Mabswid
.4697 .4029 Mdot
.4981 .42717 Mdot
0 .149 1 r
.5 Mabswid
.51937 .6227 m
.51479 .62591 L
s
0 0 0 r
2.5 Mabswid
.51937 .6227 Mdot
0 .989 1 r
.5 Mabswid
.47813 .58383 m
.49169 .55584 L
s
0 0 0 r
2.5 Mabswid
.47813 .58383 Mdot
.48859 .41957 Mdot
.54556 .52159 Mdot
.53667 .57941 Mdot
.47911 .41199 Mdot
.45418 .3909 Mdot
0 g
.5 Mabswid
.44073 .38329 m
.43527 .38513 L
s
.43527 .38513 m
.4431 .45575 L
s
.43527 .38513 m
.44311 .45575 L
s
.43527 .38516 m
.44073 .38332 L
s
0 0 0 r
2.5 Mabswid
.51479 .62591 Mdot
.4767 .41074 Mdot
.47459 .40903 Mdot
.54517 .50741 Mdot
.2 0 1 r
.5 Mabswid
.54147 .53538 m
.45997 .53268 L
s
0 0 0 r
2.5 Mabswid
.54147 .53538 Mdot
.48715 .42182 Mdot
0 1 .381 r
.5 Mabswid
.43517 .42006 m
.44783 .40211 L
s
0 0 0 r
2.5 Mabswid
.43517 .42006 Mdot
.53951 .49308 Mdot
0 g
.5 Mabswid
.44867 .45394 m
.44073 .38329 L
s
.4407 .38328 m
.44864 .45394 L
s
0 0 0 r
2.5 Mabswid
.24678 .38948 Mdot
.371 1 0 r
.5 Mabswid
.53519 .48529 m
.46307 .54318 L
s
0 0 0 r
2.5 Mabswid
.53519 .48529 Mdot
.194 1 0 r
.5 Mabswid
.19018 .73816 m
.45916 .52874 L
s
0 0 0 r
2.5 Mabswid
.52049 .45816 Mdot
.77454 .68811 Mdot
.48727 .42646 Mdot
.44894 .52408 Mdot
0 .989 1 r
.5 Mabswid
.48779 .56006 m
.44894 .52408 L
s
0 0 0 r
2.5 Mabswid
.53886 .51485 Mdot
.49153 .60266 Mdot
.045 1 0 r
.5 Mabswid
.51983 .54499 m
.49153 .60266 L
s
0 1 .453 r
.44665 .51224 m
.471 .5224 L
s
0 0 0 r
2.5 Mabswid
.44665 .51224 Mdot
.64037 .25846 Mdot
.44948 .52336 Mdot
.741 1 0 r
.5 Mabswid
.49482 .54832 m
.44948 .52336 L
s
0 0 0 r
2.5 Mabswid
.4385 .46668 Mdot
0 .989 1 r
.5 Mabswid
.46189 .47459 m
.4385 .46668 L
s
0 0 0 r
2.5 Mabswid
.44836 .3977 Mdot
.46399 .55557 Mdot
0 1 .381 r
.5 Mabswid
.52248 .5444 m
.46399 .55557 L
s
0 0 0 r
2.5 Mabswid
.44402 .49958 Mdot
.2 0 1 r
.5 Mabswid
.47472 .4934 m
.44402 .49958 L
s
0 .407 1 r
.50483 .44883 m
.50694 .3664 L
s
0 0 0 r
2.5 Mabswid
.50483 .44883 Mdot
.514 1 0 r
.5 Mabswid
.49215 .60293 m
.5173 .59767 L
s
0 0 0 r
2.5 Mabswid
.49215 .60293 Mdot
.53207 .50965 Mdot
.44783 .40211 Mdot
.713 1 0 r
.5 Mabswid
.52871 .52653 m
.70892 .60555 L
s
0 0 0 r
2.5 Mabswid
.52871 .52653 Mdot
.54 1 0 r
.5 Mabswid
.49844 .61048 m
.50084 .68928 L
s
0 .938 1 r
.49844 .61048 m
.51533 .60115 L
s
0 0 0 r
2.5 Mabswid
.49844 .61048 Mdot
.664 1 0 r
.5 Mabswid
.52903 .51765 m
.70583 .59362 L
s
0 0 0 r
2.5 Mabswid
.52903 .51765 Mdot
.50243 .45249 Mdot
.5173 .59767 Mdot
.51533 .60115 Mdot
.47385 .42708 Mdot
.435 1 0 r
.5 Mabswid
.51828 .48806 m
.46003 .5346 L
s
0 0 0 r
2.5 Mabswid
.51828 .48806 Mdot
.52248 .5444 Mdot
.77394 .69449 Mdot
.52636 .16832 Mdot
.51983 .54499 Mdot
0 1 .381 r
.5 Mabswid
.46884 .55721 m
.49572 .52774 L
s
0 0 0 r
2.5 Mabswid
.46884 .55721 Mdot
.45138 .42319 Mdot
.50482 .49481 Mdot
0 g
.5 Mabswid
.49582 .60509 m
.50141 .60347 L
s
.46464 .53414 m
.49582 .60509 L
s
.46465 .53414 m
.49583 .60509 L
s
.50139 .60344 m
.49581 .60506 L
s
.699 1 0 r
.50113 .49088 m
.45894 .52443 L
s
0 0 0 r
2.5 Mabswid
.50113 .49088 Mdot
.88 1 0 r
.5 Mabswid
.50825 .50728 m
.45916 .52874 L
s
0 0 0 r
2.5 Mabswid
.50825 .50728 Mdot
0 g
.5 Mabswid
.50141 .60347 m
.47026 .53242 L
s
.47023 .53244 m
.50139 .60349 L
s
0 0 0 r
2.5 Mabswid
.4831 .46095 Mdot
.249 1 0 r
.5 Mabswid
.46307 .54318 m
.32791 .72047 L
s
0 0 0 r
2.5 Mabswid
.46307 .54318 Mdot
.50277 .55486 Mdot
.8 1 0 r
.5 Mabswid
.44358 .4727 m
.46808 .4628 L
s
0 0 0 r
2.5 Mabswid
.44358 .4727 Mdot
.47122 .45243 Mdot
.364 1 0 r
.5 Mabswid
.49499 .55789 m
.49914 .43284 L
s
0 0 0 r
2.5 Mabswid
.49499 .55789 Mdot
.486 1 0 r
.5 Mabswid
.46003 .5346 m
.31991 .71709 L
s
0 0 0 r
2.5 Mabswid
.46003 .5346 Mdot
.49482 .54832 Mdot
.49572 .52774 Mdot
.45997 .53268 Mdot
.46808 .4628 Mdot
.53632 .18033 Mdot
.49169 .55584 Mdot
.45916 .52874 Mdot
.47654 .49159 Mdot
.48779 .56006 Mdot
.45894 .52443 Mdot
.54993 .17273 Mdot
.47472 .4934 Mdot
0 g
.5 Mabswid
.44867 .45391 m
.44309 .45571 L
s
.44309 .45571 m
.46465 .53418 L
s
.4431 .45575 m
.44867 .45394 L
s
.4431 .4557 m
.46466 .53417 L
s
0 0 0 r
2.5 Mabswid
.46189 .47459 Mdot
0 g
.5 Mabswid
.47027 .53246 m
.44867 .45391 L
s
.44864 .45391 m
.47024 .53246 L
s
0 0 0 r
2.5 Mabswid
.45172 .48723 Mdot
0 1 .381 r
.5 Mabswid
.45193 .48733 m
.45172 .48723 L
s
0 0 0 r
2.5 Mabswid
.45193 .48733 Mdot
0 1 .381 r
.5 Mabswid
.46307 .49176 m
.45193 .48733 L
s
0 0 0 r
2.5 Mabswid
.46307 .49176 Mdot
.32791 .72047 Mdot
.471 .5224 Mdot
0 g
.5 Mabswid
.46465 .53418 m
.47027 .53246 L
s
.47026 .53242 m
.46464 .53414 L
s
0 0 0 r
2.5 Mabswid
.59798 .15497 Mdot
.51154 .22047 Mdot
.31991 .71709 Mdot
.5187 .21467 Mdot
.56918 .18249 Mdot
.34861 .37209 Mdot
.35551 .36851 Mdot
.36242 .36492 Mdot
.57848 .18399 Mdot
.36933 .36133 Mdot
.53977 .22384 Mdot
.57991 .1953 Mdot
.60146 .19597 Mdot
.58377 .20091 Mdot
.50084 .68928 Mdot
.56571 .22199 Mdot
.57944 .21057 Mdot
.59337 .19906 Mdot
.74875 .67442 Mdot
.48326 .63506 Mdot
.67933 .67116 Mdot
.25147 .52071 Mdot
.65026 .38836 Mdot
.61428 .27355 Mdot
.65225 .39836 Mdot
0 g
.5 Mabswid
.09074 .67495 m
.39703 .58293 L
s
0 0 0 r
2.5 Mabswid
.46564 .37104 Mdot
.70583 .59362 Mdot
.70892 .60555 Mdot
.50694 .3664 Mdot
.47057 .63014 Mdot
.66126 .61157 Mdot
.49914 .43284 Mdot
0 g
.5 Mabswid
.62521 .51439 m
.39703 .58293 L
s
0 0 0 r
2.5 Mabswid
.63284 .50433 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{769.875, 439.938},
  ImageMargins->{{43, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<10001]b000`400?l00000o`00003ooooooooo
oooooooooooo1?ooool00?ooooooooooooooooooo`Cooooo003oooooooooooooooooool4ooooo`00
oooooooooooooooooooo1?ooool00?ooooooooooooooooooo`Cooooo003oooooooooooooooooool4
ooooo`00oooooooooooooooooooo1?ooool00?ooooooooooooooooooo`Cooooo003ooooooooooooo
ooooool4ooooo`00oooooooooooooooooooo1?ooool00?ooooooooooooooooooo`Cooooo003ooooo
ooooooooooooool4ooooo`00oooooooooooooooooooo1?ooool00?ooooooooooooooooooo`Cooooo
003oooooooooooooooooool4ooooo`00oooooooooooooooooooo1?ooool00?oooooooooooooooooo
o`Cooooo003oooooooooooooooooool4ooooo`00oooooooooooooooooooo1?ooool00?oooooooooo
ooooooooo`Cooooo003oooooooooooooooooool4ooooo`00oooooooooooooooooooo1?ooool00?oo
ooooooooooooooooo`Cooooo003oooooooooooooooooool4ooooo`00oooooooooooooooooooo1?oo
ool00?ooooooooooooooooooo`Cooooo003oooooooooooooooooool4ooooo`00oooooooooooooooo
oooo1?ooool00?ooooooooooooooooooo`Cooooo003oooooooooooooooooool4ooooo`00oooooooo
oooooooooooo1?ooool00?ooooooooooooooooooo`Cooooo003oooooooooooooooooool4ooooo`00
ooooool3ooooo`;o0000ooooooonooooo`00ooooool3o`000003ooooool0003ooooo0?oooooo?Ooo
ool2o`000;kooooo003mooooo`;o00001?ooool2o`000?oooooo>_ooool3o`000003ooooool0003o
oooo0;gooooo003kooooo`;o00001_ooool00ol0003oooooo`00003oooooocOooooo0_l00004oooo
o`;o0000_Oooool00?Sooooo0ol00008ooooo`03o`000?oooooo00000?oooooo=?ooool3o`0000Ko
oooo0_l0002mooooo`00m_ooool2o`0000_ooooo00Co0000oooooooooooo0000oooooolaooooo`;o
00002Oooool00ol0003oooooo`00002looooo`00m?ooool2o`0000gooooo00Go0000oooooooooooo
ooooo`00003oooooobgooooo0ol0000;ooooo`04o`000?ooooooooooo`000;_ooooo003aooooo`?o
00003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo9oooool3o`0000ko
oooo00Co0000oooooooooooo0000^oooool00>oooooo0_l0000Booooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0oooooolUooooo`;o00004_ooool01?l0003oooooooooool0002joooo
o`00kOooool2o`0001Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooob7o
oooo0ol0000Dooooo`04o`000?ooooooooooo`000;[ooooo003Zooooo`?o00005_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo7_ooool2o`0001Oooooo00Go0000oooooooo
ooooooooo`00002iooooo`00j?ooool2o`0001Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3ooooooa_ooooo0ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0]_ooool00>Kooooo0_l0000Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooolHooooo`;o00007?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;Kooooo
003Sooooo`?o00007Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo5?oo
ool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2eooooo`00hOooool2
o`00023ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooa;ooooo0_l0000Q
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0]Oooool00=oooooo0_l0000Roooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0ooooool>ooooo`?o00008oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0;Cooooo003Looooo`?o00009?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo0?oooooo2_ooool3o`0002Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2dooooo`00f_ooool2o`0002Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000Yooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0/oooool00=Sooooo0_l0000Yooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0ooooool4ooooo`?o0000:oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0;;ooooo003Eooooo`?o0000:oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo0?oooooo0Oooool2o`0002kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2b
ooooo`00doooool2o`0002kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3loooo
o`?o0000<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;7ooooo003Aooooo`;o
0000<?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?[ooooo0_l0000dooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00<kooooo0ol0000booooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0m_ooool3o`0003Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2`ooooo`00c?ooool2o`0003Gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`3cooooo`;o0000>Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo0:oooooo003:ooooo`;o0000=oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo0?3ooooo0ol0000kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0[oooool0
0<Oooooo0ol0000iooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0kOooool2o`00
03kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2^ooooo`00aOooool2o`0003co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3Yooooo`?o0000@?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo0:kooooo0033ooooo`;o0000?_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0>Kooooo0ol00013ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0[Oooool00<3ooooo0ol00010ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0hoooool2o`0004Kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`2]ooooo`00__ooool2o`0004?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3O
ooooo`?o0000B?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:cooooo002loooo
o`;o0000AOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0=gooooo0_l0001;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Zoooool00;Wooooo0ol00017ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0fOooool3o`0004gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`2[ooooo`00]oooool2o`0004[ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`3Fooooo`;o0000D?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo0:[ooooo002eooooo`;o000000?oooooo`000?ooool0BOooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo0=;ooooo0ol000000ooooooo0000ooooo`1?ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0Z_ooool00;;ooooo0ol00003ooooo`;o0000BOooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0=3ooooo0_l00004ooooo`;o0000D?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Wooooo002`ooooo`;o00001_ooool00ol0
003oooooo`000018ooooo`03o`000?oooooooooo00kooooo0_l00005ooooo`03o`000?oooooooooo
0<cooooo0ol00006ooooo`03o`000?oooooo000004oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`2Xooooo`00[_ooool2o`0000Sooooo00Co0000oooooooooooo0000Aoooool00ol0
003oooooooooo`0>ooooo`;o00001_ooool00ol0003oooooooooo`39ooooo`;o00002Oooool01?l0
003oooooooooool0001>ooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`03o`000?oooooo
oooo0:Sooooo002[ooooo`?o00002_ooool01Ol0003ooooooooooooooooo000004Kooooo00?o0000
ooooooooool03oooool00ol0oecoooooooooo`04ooooo`03o`000?oooooooooo0<Kooooo0ol0000;
ooooo`04o`000?ooooooooooo`0004kooooo00?o0000ooooooooool02Oooool2o`0000Cooooo00?o
0000ooooooooool0Yoooool00:Wooooo0_l0000=ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0@oooool00ol0003oooooooooo`0>ooooo`?o00001_ooool00ol0003oooooooooo`33
ooooo`;o00003_ooool01Ol0003ooooooooooooooooo000004gooooo00?o0000ooooooooool02_oo
ool00ol0oecoooooooooo`02ooooo`03o`000?oooooooooo0:Oooooo002Wooooo`;o00003_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool03_ooool3
o`0000Oooooo00?o0000ooooooooool0_oooool3o`00013ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00Oooooo1?l00005ooooo`03o`000?oooooo
oooo0:Kooooo002Uooooo`;o00004?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool03_ooool2o`0000Sooooo00?o0000ooooooooool0_Oooool2o`00
01?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
00Oooooo1?l00005ooooo`03o`000?oooooooooo0:Kooooo002Rooooo`?o00004_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo047ooooo0ol0000=ooooo`03om[o0?l0003o000000Wo
oooo00?o0000ooooooooool0^Oooool3o`0001Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`19ooooo`03o`000?oooooooooo00Oooooo00?of_l0o`000?l000001oooool00ol0003o
ooooooooo`2Uooooo`00X?ooool2o`0001Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`10ooooo`?o00003?ooool00ooJo`3o0?mLo`3Qo`0;ooooo`03o`000?oooooooooo0;Kooooo
0_l0000Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0B?ooool2o`0000Oooooo
00Cof_l0ooooool0003o00002?ooool00ol0003oooooooooo`2Tooooo`00W_ooool2o`0001Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0oooooo`03o`000?m3o`3ooooo00cooooo
00?of_l0o`3oG?l0hOl02oooool00ol0003oooooooooo`2cooooo`?o00006_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo04Oooooo0_l00006ooooo`05om[o0?ooooooooooo`3oG_l0
hOl02?ooool00ol0003oooooooooo`2Tooooo`00Voooool3o`0001Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0oooooo`03o`000?m3o`3ooooo00_ooooo00?of_l0ooooool0hOl0
3Oooool00ol0003oooooooooo`2`ooooo`;o00007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04Oooooo00?o0000od?o0?ooool01Oooool01OoJo`3oooooooooool0oeko0>7o00Wo
oooo00?o0000ooooooooool0Xoooool009Wooooo0_l0000Looooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0?_ooool00ol0003o@ol0ooooo`0:ooooo`04om[o0?oooooo0?mLo`3Qo`ko
oooo00?o0000ooooooooool0[?ooool3o`0001oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`16ooooo`03o`000?m3o`3ooooo00Cooooo00Gof_l0oooooooooooo0?mNo`3Qo`0:oooo
o`03o`000?oooooooooo0:?ooooo002Gooooo`;o00007_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo03gooooo00?o0000od?o0?ooool02_ooool01?oJo`3oooooo`3oG?l0hOl?oooo
o`03o`000?oooooooooo0:Wooooo0_l0000Rooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0AOooool00ol0003o@ol0ooooo`03ooooo`06om[o0?ooooooooooooooool0oeko0>7o2ooo
ool00ol0003oooooooooo`2Rooooo`00UOooool2o`00023ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Pooooo`;o00006_ooool00ol0003o@ol0ooooo`09ooooo`04om[o0?oooooo
ooooo`3Qoa3ooooo00?o0000ooooooooool0Y_ooool3o`0002Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Wooooo`;o00007Oooool01Ol0003ooooooooooooooooof_l000Cooooo
00?o0?mNo`3Qooooool02_ooool00ol0003oooooooooo`2Rooooo`00T_ooool3o`0002;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Oooooo`;o00006_ooool00ol0003o@ol0oooo
o`08ooooo`05om[o0?ooooooooooo`3oG?l0hOl04Oooool00ol0003oooooooooo`2Sooooo`;o0000
9oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Kooooo0_l0000Mooooo`05o`00
0?oooooooooooooooooJo`000oooool00ol0oeko0>7oooooo`0<ooooo`03o`000?oooooooooo0:7o
oooo002@ooooo`;o00009Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo
00?o00Coooooooooool01_ooool2o`00017ooooo00?o0000od?o0?ooool01oooool01_oJo`3ooooo
oooooooooooo0?mLo`3Qoa;ooooo00?o0000ooooooooool0Woooool3o`0002Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Uooooo`03o`04oooooooooooo00Oooooo0_l0000Coooo
o`04o`000?ooooooooooom[o00Cooooo00?o0?mNo`3Qooooool03Oooool00ol0003oooooooooo`2P
ooooo`00S_ooool2o`0002Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Noooo
o`03o`04oooooooooooo00Kooooo0_l0000Aooooo`03o`000?m3o`3ooooo00Oooooo00Gof_l0oooo
ooooooooooooo`3Qo`0Cooooo`03o`000?oooooooooo09gooooo0_l0000/ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool09?ooool00ol01?ooooooooooo`07ooooo`;o00004oooool0
0ol0003oooooom[o0005ooooo`03o`3oG_l0hOoooooo00gooooo00?o0000ooooooooool0X?ooool0
08_ooooo0ol0000Xooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool00ol0
1?ooooooooooo`06ooooo`03o`3[oooooooooooo013ooooo00?o0000od?o0?ooool01_ooool01_oJ
o`3ooooooooooooooooo0?mLo`3QoaCooooo00?o0000ooooooooool0VOooool3o`0002kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Sooooo`03o`04oooooooooooo00Sooooo00?o
0>_oooooooooool04_ooool00ol0003of_l0ooooo`04ooooo`03o`3oG_l0hOoooooo00oooooo00?o
0000ooooooooool0Woooool008Wooooo0_l0000[ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool06oooool01?l01?ooooooooooooooool2o`0000Cooooo00?o0>_oooooooooool04?oo
ool00ol0003o@ol0ooooo`05ooooo`03om[o0?oooooooooo00;ooooo00?o0?mLo`3Qooooool05?oo
ool00ol0003oooooooooo`2Eooooo`?o0000<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo02;ooooo00?o00Coooooooooool00_ooool2o`0000Cooooo00?o0>_oooooooooool04_oo
ool00ol0003oooooooooo`04ooooo`03o`3oG_l0hOoooooo00oooooo00?o0000ooooooooool0Wooo
ool008Oooooo0_l0000]ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06_ooool0
1?l01?ooooooooooooooool2o`0000?ooooo00?o0>_oooooooooool01Oooool2o`0000;ooooo0_l0
0006ooooo`03o`000?m3o`3ooooo00Cooooo00?of_l0ooooooooool00oooool00ol0hOoooooooooo
o`0Dooooo`03o`000?oooooooooo09?ooooo0_l0000dooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool08?ooool00ol01?ooooooooooo`03ooooo`;o00000oooool00ol0jooooooooooo
o`06ooooo`;o00002oooool00ol0003oooooooooo`04ooooo`03o`3oG_l0hOoooooo013ooooo00?o
0000ooooooooool0W_ooool008Gooooo0_l0000_ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool06?ooool00ol01?ooooooooooo`02ooooo`03o`1[oooooooooooo00;ooooo00?o0>_o
ooooooooool01Oooool2o`0000;ooooo0_l00006ooooo`03o`000?m3o`3ooooo00Cooooo00?of_l0
ooooooooool00_ooool00ol0oeco0>7oooooo`0Fooooo`03o`000?oooooooooo08oooooo0ol0000f
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08?ooool00ol01?ooooooooooo`03
ooooo`03o`1[oooooooooooo00;ooooo00?o0>_oooooooooool01_ooool2o`0000;ooooo0_l00006
ooooo`03od?o0?l0003ooooo00Cooooo00?o0?mNo`3Qooooool04_ooool00ol0003oooooooooo`2M
ooooo`00P_ooool3o`00037ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Goooo
o`03o`04oooooooooooo00;ooooo00?o06_oooooooooool00_ooool00ol0joooooooooooo`05oooo
o`04o`3ofoooooooooooo`3og`Sooooo00?o0000od?o0?ooool00oooool00ooJo`3oooooooooo`03
ooooo`03o`3oG?l0hOoooooo01Oooooo00?o0000ooooooooool0S?ooool2o`0003Wooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Oooooo`03o`04oooooooooooo00?ooooo00Go06_o
ooooooooooooooooo`3[o`09ooooo`04o`3ofoooooooooooooooo`;o00001Oooool00ooJo`3o@ol0
o`000005ooooo`03o`3oG_l0hOoooooo01;ooooo00?o0000ooooooooool0WOooool0083ooooo0_l0
000dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05_ooool00ol01?oooooooooo
o`02ooooo`03o`1[oooooooooooo00;ooooo00?o0>_oooooooooool01_ooool01?l0om_ooooooooo
ool0oml8ooooo`03o`000?m3o`3ooooo00;ooooo00?of_l0ooooooooool01?ooool00ol0hOoooooo
ooooo`0Hooooo`03o`000?oooooooooo08Sooooo0ol0000kooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool07Oooool00ol01?ooooooooooo`03ooooo`03o`1[oooooooooooo00;ooooo
00?o0>_oooooooooool01oooool01?l0om_oooooooooool0oml6ooooo`04om[o0?oooooo@ol0o`00
00Gooooo00?o0?mNo`3Qooooool04oooool00ol0003oooooooooo`2Looooo`00O_ooool2o`0003Ko
oooo00?o0000ooooooooool03?ooool00oo8o`3o0000ooooo`04ooooo`03o`000?oooooooooo01Go
oooo00?o00Coooooooooool00_ooool00ol0Joooooooooooo`02ooooo`03o`3[oooooooooooo00Go
oooo00Co0?oKoooooooooooo0?oO2Oooool00ol0003o@ol0ooooo`02ooooo`03om[o0?oooooooooo
00?ooooo00?o0?mLo`3Qooooool06Oooool00ol0003oooooooooo`26ooooo`;o0000?_ooool00ol0
003oooooooooo`09ooooo`03o`000?o8o`3ooooo00?ooooo00?o0000ooooooooool07?ooool00ol0
1?ooooooooooo`03ooooo`05o`1[ooooooooooooooooool0jol02Oooool01Ol0om_ooooooooooooo
oooo0?oO00Kooooo00Cof_l0oooooom3o`3o00001?ooool00ol0oeko0>7oooooo`0Dooooo`03o`00
0?oooooooooo09cooooo001kooooo`?o0000>?ooool00ol0003oooooooooo`0<ooooo`03olSo0?l0
003ooooo00Gooooo00?o0000ooooooooool05?ooool00ol01?ooooooooooo`02ooooo`05o`1[oooo
ooooooooooooool0jol02?ooool01Ol0om_oooooooooool0omoooooo00;o00001_ooool3o`000003
oooooooJo`3ooooo00Gooooo00?o0?mLo`3Qooooool06_ooool00ol0003oooooooooo`22ooooo`?o
0000@?ooool00ol0003oooooooooo`09ooooo`03o`000?o8o`3ooooo00?ooooo00?o0000oooooooo
ool06oooool00ol01?ooooooooooo`03ooooo`03o`1[oooooooooooo00;ooooo00?o0>_ooooooooo
ool01_ooool01_l0om_ooooooooooooooooo0?oOooooo`;o00000oooool01OoJo`3ooooooooooom3
o`3o000000Cooooo00?o0?mNo`3Qooooool05Oooool00ol0003oooooooooo`2Kooooo`00NOooool2
o`0003_ooooo00?o0000ooooooooool03?ooool00oo8o`3oooooooooo`06ooooo`03o`000?oooooo
oooo01;ooooo00?o00Coooooooooool00_ooool00ol0Joooooooooooo`02ooooo`03o`3[oooooooo
oooo00Gooooo00Co0?oKoooooooooooo0?oO0_ooool2o`0000?ooooo0_l000001Ooooooo0000o`00
0?l0003of_l000Oooooo00?o0>7oooooooooool06oooool00ol0003oooooooooo`1oooooo`;o0000
@oooool00ol0003oooooooooo`0:ooooo`03olSo0?oooooooooo00?ooooo00?o0000ooooooooool0
6_ooool00ol01?ooooooooooo`03ooooo`05o`1[ooooooooooooooooool0jol02Oooool01?l0om_o
ooooooooool0oml2ooooo`;o00000_ooool01OoJo`3ooooooooooooooooo@ol000;o00000oooool0
0ol0oeko0>7oooooo`0Eooooo`03o`000?oooooooooo09_ooooo001gooooo`;o0000?Oooool00ol0
003oooooooooo`0<ooooo`03olSo0?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0
1?ooooooooooo`02ooooo`05o`1[ooooooooooooooooool0jol02?ooool01?l0om_oooooooooool0
oml3ooooo`;o00000_ooool2o`000004ooooool0003o@ol0om[o00Oooooo00?o0?mLo`3Qooooool0
7?ooool00ol0003oooooooooo`1looooo`?o00006Oooool2o`0002[ooooo00?o0000ooooooooool0
2_ooool00oo8o`3oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o00Coooooooooool0
0oooool00ol0Joooooooooooo`02ooooo`03o`3[oooooooooooo00Kooooo00Go0?oKoooooooooooo
ooooo`3og`03ooooo`03occo0?oooooof_l000;ooooo0_l000000om3o`3o0000o`000002ooooo`03
o`3oG_l0hOoooooo01Oooooo00?o0000ooooooooool0V_ooool007Gooooo0_l0000Fooooo`;o0000
9oooool00ol0003oooooooooo`0<ooooo`03olSo0?oooooooooo00Oooooo00?o0000ooooooooool0
4?ooool00ol01?ooooooooooo`02ooooo`03o`1[oooooooooooo00;ooooo00?o0>_oooooooooool0
1Oooool01?l0om_oooooooooool0oml4ooooo`;o00000oooool01Oo[o`3oon/0o`000?m3o`3of_l0
00Oooooo00?o0?mLo`3Qooooool07Oooool00ol0003oooooooooo`1iooooo`;o00007?ooool2o`00
02[ooooo00?o0000ooooooooool02_ooool00oo8o`3oooooooooo`05ooooo`03o`000?oooooooooo
01Oooooo00?o00Coooooooooool00oooool01Ol0Jooooooooooooooooooo0>_o00Wooooo00Co0?oK
oooooooooooo0?oO1?ooool00ollo`3o0000o`000002ooooo`;o000000?o@ol0ooo[0?l000000_oo
ool00ol0oeko0>7oooooo`0Hooooo`03o`000?oooooooooo09Wooooo001booooo`?o00006?ooool2
o`0002Kooooo00?o0000ooooooooool03Oooool00oo8o`3oooooooooo`08ooooo`03o`000?oooooo
oooo00oooooo00?o00Coooooooooool00_ooool01Ol0Jooooooooooooooooooo0>_o00Sooooo00Co
0?oKoooooooooooo0?oO1?ooool02Ollo`3ooooooooooooooooojol0ooooooooj`3o0000od?o0008
ooooo`03o`3Qoooooooooooo01kooooo00?o0000ooooooooool0MOooool3o`0001kooooo00?o09Go
ooooooooool0:Oooool00ol0003oooooooooo`0:ooooo`03olSo0?oooooooooo00Gooooo00?o0000
ooooooooool05_ooool00ol01?ooooooooooo`03ooooo`03o`1[oooooooooooo00;ooooo00?o0>_o
ooooooooool01_ooool01Ol0om_ooooooooooooooooo0?oO00Cooooo00?o??l0o`000?l000000_oo
ool01Oo[o`3oooooooo[0?oooooo000000;ooooo00?o0?mNo`3Qooooool06?ooool00ol0003ooooo
ooooo`2Iooooo`00L?ooool2o`0001cooooo00?o09Goooooooooool09?ooool00ol0003ooooooooo
o`0=ooooo`03olSo0?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol01?oooooooooo
o`02ooooo`03o`1[oooooooooooo00;ooooo00?o0>_oooooooooool01Oooool01?l0om_ooooooooo
ool0oml5ooooo`09occo0?ooooooooooon_o0?ooooooon/0ooooool0003o@ol000Oooooo00?o0?mL
o`3Qooooool07oooool00ol0003oooooooooo`1cooooo`;o00008_ooool00ol0UOooooooooooo`0X
ooooo`03o`000?oooooooooo00[ooooo00?ob?l0ooooooooool01_ooool00ol0003oooooooooo`0E
ooooo`03o`04oooooooooooo00?ooooo00Go06_oooooooooooooooooo`3[o`08ooooo`05o`3ofooo
ooooooooooooool0oml01Oooool01Ollo`3o0?oXoooooooooooojol000;ooooo00Koon/0ooooool0
003oooooo`3oG_l0hOlKooooo`03o`000?oooooooooo09Sooooo001^ooooo`;o00007oooool00ol0
UOooooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00?ob?l0ooooooooool02_ooool00ol0
003oooooooooo`0<ooooo`03o`04oooooooooooo00;ooooo00?o06_oooooooooool00_ooool00ol0
joooooooooooo`05ooooo`04o`3ofoooooooooooo`3og`?ooooo0_l000002Ollo`3oooooooooooo[
o`3oon/0oooooooJo`3o0000od?o0007ooooo`03o`3oG?l0hOoooooo023ooooo00?o0000oooooooo
ool0Koooool3o`0002Gooooo00?o09Goooooooooool09oooool00ol0003oooooooooo`0:ooooo`03
olSo0?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol01?ooooooooooo`03ooooo`03
o`1[oooooooooooo00;ooooo00?o0>_oooooooooool01_ooool01Ol0om_ooooooooooooooooo0?oO
00Cooooo00?of_l0occo0?ooool00_ooool02Oo[o`3oooooooo[0?m3o`3oooooo`000?oooooo0?mN
o`3Qo`0Kooooo`03o`000?oooooooooo09Sooooo001[ooooo`?o00008_ooool00ol0UOoooooooooo
o`0Rooooo`03o`000?oooooooooo00gooooo00?ob?l0ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`03o`04oooooooooooo00;ooooo00Go06_oooooooooooooooooo`3[o`07ooooo`04o`3o
foooooooooooo`3og`Cooooo0_l000002Ollo`3oooooon_o0?ooooooon/0oooooooJo`3o0000od?o
0007ooooo`03o`3oG_l0hOoooooo027ooooo00?o0000ooooooooool0K?ooool2o`0002Wooooo00?o
09Goooooooooool09_ooool00ol0003oooooooooo`0:ooooo`03olSo0?oooooooooo00Oooooo00?o
0000ooooooooool04oooool00ol01?ooooooooooo`03ooooo`05o`1[ooooooooooooooooool0jol0
2?ooool01Ol0om_ooooooooooooooooo0?oO00Gooooo0_l00002ooooo`0:on_o0?ooooooon/0oooo
oom3o`3oooooo`000?oooooo0?mNo`3Qoacooooo00?o0000ooooooooool0Uoooool006Wooooo0_l0
000Vooooo`03o`2Eoooooooooooo027ooooo00?o0000ooooooooool03?ooool00oo8o`3ooooooooo
o`0=ooooo`03o`000?oooooooooo00Wooooo00Ko00Coooooool0003o0000ooooool0Jol4ooooo`03
o`3[oooooooooooo00Gooooo00Co0?oKoooooooooooo0?oO1?ooool02ooYo`3oooooocco0?o[o`3o
ooooooo[0?oooooof_l0ooooool0003o@ol000Kooooo00?o0?mLo`3Qooooool08_ooool00ol0003o
ooooooooo`1Yooooo`?o0000;?ooool00ol0UOooooooooooo`0Uooooo`03o`000?oooooooooo00[o
oooo00?ob?l0ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`04oooooooooooo00?o
oooo00?o06_oooooooooool00_ooool00ol0joooooooooooo`06ooooo`04o`3ofoooooooooooo`3o
g`Gooooo00Oof_l0o`000?l0003oooooon_o0?ooooooon/000;ooooo00Go@ol0ooooool0003o0?mN
o`3Qo`0Nooooo`03o`000?oooooooooo09Kooooo001Wooooo`;o0000:Oooool00ol0UOoooooooooo
o`0Pooooo`03o`000?oooooooooo00cooooo00?ob?l0ooooooooool03Oooool00ol0003ooooooooo
o`09ooooo`06o`04oooooooo0000o`000?oooooo06_o0oooool00ol0joooooooooooo`05ooooo`04
o`3ofoooooooooooo`3og`Cooooo00SojOl0o`3oj?oooooo??l0on_o0?ooooooon/0om[o00;ooooo
00?o0000od?o0?ooool01Oooool00ol0oeco0>7oooooo`0Sooooo`03o`000?oooooooooo06Kooooo
0_l0000`ooooo`03o`2Eoooooooooooo02Cooooo00?o0000ooooooooool02_ooool00oo8o`3ooooo
ooooo`09ooooo`03o`000?oooooooooo013ooooo00?o00Coooooooooool00_ooool2o`0000?ooooo
00?o0>_oooooooooool01_ooool01Ol0om_ooooooooooooooooo0?oO00Cooooo00Gof_l0oooooooY
o`3o??l0on_o0002ooooo`08ooo[0?oooooooooood?o0?oooooo0000o`3oG_l0hOlNooooo`03o`00
0?oooooooooo09Kooooo001Uooooo`;o0000;?ooool00ol0UOooooooooooo`0Oooooo`03o`000?oo
oooooooo00cooooo0_l0000?ooooo`03o`000?oooooooooo00Oooooo00Ko00Cooooooooooooooooo
obH0ool0Jol4ooooo`03o`3[oooooooooooo00Gooooo00Co0?oKoooooooooooo0?oO1?ooool02?oY
o`3oooooooooooo[o`3o??l0ooo[0?oooooof_l00_ooool00ol0003o@ol0ooooo`05ooooo`03o`3o
G_l0hOoooooo02Cooooo00?o0000ooooooooool0H_ooool3o`0003?ooooo00?o09Goooooooooool0
8oooool00ol0003oooooooooo`09ooooo`03o`000?o1o`3ooooo00_ooooo00?o0000ooooooooool0
3_ooool00ol01?ooooooooooo`03ooooo`;o00000_ooool00ol0joooooooooooo`07ooooo`04o`3o
foooooooooooo`3og`Cooooo00Sof_l0oooooooYo`3oooooocco0?o[o`3oooooooo[00?ooooo00Go
@ol0ooooool0003o0?mNo`3Qo`0Oooooo`03o`000?oooooooooo09Gooooo001Rooooo`?o0000;ooo
ool00ol0UOooooooooooo`0Nooooo`03o`000?oooooooooo00cooooo00?o0000ol7o0?ooool03ooo
ool00ol0003oooooooooo`06ooooo`;o00000oooool01OlV0?oooooooooooooooooo0>_o00Oooooo
00Co0?oKoooooooooooo0?oO0_l00002ooooo`08onWo0?ooooooooooooooooo[o`3oon/0oooooooJ
o`03ooooo`03o`000?m3o`3ooooo00Gooooo00?o0>7oooooooooool09Oooool00ol0003ooooooooo
o`1Oooooo`;o0000=oooool00ol0UOooooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo00?o
0000ol7o0?ooool02oooool00ol0003oooooooooo`0>ooooo`03o`04oooooooooooo00;o000000?o
ooooo`1[oolV0?l00_ooool00ol0joooooooooooo`06ooooo`05o`3ofoooooooooooooooool0oml0
0oooool02?oJo`3oooooo`3oj?oYo`3oooooon_o0?ooooooon/01?ooool01?m3o`3oooooo`000?l0
hOlPooooo`03o`000?oooooooooo09Gooooo001Pooooo`;o0000<oooool00ol0UOooooooooooo`0M
ooooo`;o00003Oooool00oo8o`3o`Ol0ooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o00Co
o`000?l000000_ooool00ol0Jooo9P3oooooo`02ooooo`04o`3[oooooooo0000o`0000Cooooo00Co
0?oKoooooooooooo0?oO0_l00002ooooo`07onWo0?ooooooooooon_o0?ooooooon/0om[o0004oooo
o`03o`000?m3o`3ooooo00Cooooo00?o0?mLo`3Qooooool03?ooool2o`0001Sooooo00?o0000oooo
ooooool0G?ooool3o`0003[ooooo00?o09Goooooooooool08Oooool2o`0000[ooooo00?ob?l0ol7o
0?ooool03?ooool00ol0003oooooooooo`0=ooooo`03o`04oooooooooooo00;o000000Go06_ooooo
oolV0?ooooooo`3[o`05ooooo`;o000000?oooooo`3ofoooool00_ooool00ol0omooooooooooo`02
o`000008om[o0?oooooojOl0ooooooo[o`3o??l0ooooooooj`04ooooo`04od?o0?oooooo0000o`3Q
ob7ooooo00?o0000ooooooooool0U?ooool005kooooo0_l0000fooooo`03o`2Eoooooooooooo01co
oooo0_l000000ol0oc?oooooooooo`0:ooooo`03olSo0?o1o`3ooooo017ooooo00?o0000oooooooo
ool00oooool01ol01?oooooooooooolV0?ooooooo`1[oolV0?l00oooool01?l0joooooooo`000?l0
0003ooooo`06o`3ofoooooooooooo`3ogoooooooiol00_ooool01ooYo`3oooooooooooo[o`3ooooo
ooo[0?llo`001Oooool00ol0003o@ol0ooooo`04ooooo`03o`3oG?l0hOoooooo00cooooo0_l0000I
ooooo`03o`000?oooooooooo05Wooooo0_l0000mooooo`03o`2Eoooooooooooo027ooooo0_l00000
0ol0oc?oooooooooo`07ooooo`03olSo0?o1o`3ooooo00gooooo00?o0000ooooooooool02oooool0
0ol01?ooooooooooo`02ooooo`06obH0ool0JoooooooobH0oooooooo0>_o1Oooool2o`000003oooo
ool0om_ooooo00;ooooo00?o0?oOooooooooool00_l000001ooooooojOl0oooooooooooojol0occo
0?ooj`001Oooool01?m3o`3oooooo`000?l0hOl>ooooo`;o00004Oooool00ol0003oooooooooo`2D
ooooo`00Foooool3o`0003Wooooo00?o09Goooooooooool06oooool01?l0003oooooooooool0oc<;
ooooo`03olSo0?o1o`3ooooo017ooooo00?o0000ooooooooool00oooool01Ol01?oooooooooooolV
0?oo06_o00;ooooo00?o9P3oooooool0jol01?ooool01?lJo`3oooooooooool0om/2ooooo`06o`3o
gooWo`3ooooooooooooYo`3o0?oX0_ooool01?o[o`3oon/0oooooollo`05ooooo`03o`000?m3o`3o
oooo00Cooooo00?o0>7oooooooooool03?ooool00omZo`3oooooooooo`0Iooooo`03o`000?oooooo
oooo05Gooooo0ol00010ooooo`03o`2Eoooooooooooo023ooooo00Co0000oooooooooooo0?lc2?oo
ool00oo8o`3o`Ol0ooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o00Coooooooooool00_oo
ool01OlV0?oooooooooooooooooo9P3o00Kooooo00?o6_l0ooooool0om/00oooool01ol0omoooooo
ooooooooooooiol0oooooooYo`000_ooool00oo[o`3oooooooo[0006ooooo`04od?o0?l0oeko0>7o
o`0000kooooo0_l0000Booooo`03o`000?oooooooooo09?ooooo001Iooooo`;o0000?Oooool00ol0
UOooooooooooo`0Jooooo`05o`000?ooooooooooooooool0oc<02_ooool00oo8o`3o`Ol0ooooo`0B
ooooo`05o`000?ooooooooooooooool01?l00oooool01olV0?oo06_ooooooooooooo9P3oooooool0
jol01?ooool00olJo`3oooooo`3of`02ooooo`03o`3ogoooooooiol000;ooooo00SojOl0oooooooo
oooojol0ooooooooj`3of_l0occo00Gooooo00?o0000od?o0?ooool00oooool00ol0oeco0>7ooooo
o`0=ooooo`03of[o0?oooooooooo01Wooooo00?o0000ooooooooool0E?ooool00ol0003ooooooooo
o`12ooooo`03o`2Eoooooooooooo01oooooo00Go0000ooooooooooooooooo`3o<`07ooooo`03olSo
0?o1o`3ooooo00kooooo00?o0000ooooooooool02Oooool00ol01?ooooooooooo`03ooooo`05obH0
oooooooooooooooooolV0?l01_ooool00olJo`3oooooo`3of`02ooooo`05o`3ogooooooooooooooo
oooWo`000_ooool01_oYo`3oooooon_o0?ooooooon/0occo00Kooooo00Co@ol0o`3oG_l0hOoo0000
3_ooool00omZo`3oooooooooo`0Booooo`03o`000?oooooooooo09;ooooo001Hooooo`03o`000?oo
oooooooo03kooooo00?o09Goooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`3o<ooo
oooooooo00Oooooo00?ob?l0ol7o0?ooool04oooool01?l0003oooooooooool01?l4ooooo`05obH0
oooooooooooooooooolV0?l01Oooool00olJo`3oooooo`3of`02ooooo`0=o`3ogooWo`3ooooooooo
oooYo`3o0?oXooooooo[o`3oooooooo[0?oJo`3oooooocco0005ooooo`03o`000?m3o`3ooooo00?o
oooo00?o0?mLo`3Qooooool02Oooool2o`000003oooooomZo`3ooooo01cooooo00?o0000oooooooo
ool0VOooool00ol0UOooooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00?o0?lcoooooooo
ool01?ooool00oo8o`3o`Ol0ooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o00Cooooooooo
ool00_ooool01_l0JoooooooobH0oooooooo0>_oobH0o`Oooooo00Go0?oKooooooooooooooooo`3o
g`03ooooo`05onOo0?oooooojOl0ooooooo[o`000_ooool00oooj`3o??l0ooooo`05ooooo`04od?o
0?l0oeko0>7oo`0000gooooo00?oJ_l0ooooooooool04oooool00ol0003oooooooooo`2Booooo`00
VOooool00ol0UOooooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0?lcooooooooool0
1_ooool00oo8o`3o`Ol0ooooo`0Dooooo`03o`000?l01?oooooo00?ooooo00?o06_oobH0ooooool0
0_ooool00olV0?ooooooooooo`04ooooo`09o`3ofoooooooooooo`3ogoooooooiol0oooooooYo`3o
0?oX00;ooooo00?ojol0ooo[0?oJo`000_ooool00ollo`3oooooooooo`03ooooo`03o`000?m3o`3o
oooo00?ooooo00?o0>7oooooooooool02Oooool2o`000003oooooomZo`3ooooo01gooooo00?o0000
ooooooooool0VOooool00ol0UOooooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00?o0?lc
ooooooooool00oooool00oo8o`3o`Ol0ooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o00Co
ooooooooool00oooool01ol0JoooooooobH0oooooooo0>_ooooooolV0?l01Oooool01Ol0om_o6_l0
oooooooooooo0?oO00?ooooo00?oiol0oooooooYo`000_ooool01Oo[o`3oooooooo[0?oooooo??l0
00Gooooo00Go@ol0o`3oG_l0hOooooooo`00000<ooooo`;o00005_ooool00ol0003oooooooooo`2A
ooooo`00V_ooool00ol0UOooooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo0_l0oc<6oooo
o`03olSo0?o1o`3ooooo01Gooooo00?o00Coooooooooool00_ooool01ol0JoooooooobH0oooooooo
0>_ooooooolV0?l01Oooool01Ol0om_oooooooooool0omooiol000;ooooo00OojOl0o`3oj?oooooo
jol0ooooooooj`3of_l000;ooooo00?o??l0ooooooooool00oooool00ol0003o@ol0ooooo`02oooo
o`03o`3oG?l0hOoooooo00_ooooo00?o08coof[o0?ooool07_ooool00ol0003oooooooooo`2Joooo
o`03o`2Eoooooooooooo01cooooo00?o0000ooooooooool01?ooool00ol0oc?oooooooooo`02oooo
o`03olSo0?o1o`3ooooo013ooooo00?o0000ooooooooool01_ooool00ol01?ooooooooooo`02oooo
o`05o`1[ooooooooooooobH0ool0jol00_ooool00olV0?ooooooooooo`03ooooo`05o`3ofolJo`3o
ooooooooool0oml00_ooool02?oWo`3ooooooooooooYo`3oooooon_o0?ooooooon/00_ooool00oll
o`3oooooooooo`03ooooo`05od?o0?l0oeko0>7oooooool000003?ooool2o`0001Kooooo00?o0000
ooooooooool0TOooool009_ooooo00?o09Goooooooooool05_ooool00ol0003oooooooooo`07oooo
o`03o`3o<ooooooooooo00?ooooo00?o`Ol0ooooooooool05Oooool01Ol01?oo0000oooooooooooo
06_o00;ooooo00Go9P3oooooool0joooooooobH0o`04ooooo`05o`3ofooooooo6_l0o`3ogooWo`00
0_ooool01ooYo`3o0?oXooooooo[o`3oooooooo[0?oJo`000oooool00ollo`3oooooooooo`03oooo
o`03o`000?m3o`3ooooo00;ooooo00?o0?mLo`3Qooooool02_ooool00ol0S?ooJ_l0ooooo`0Poooo
o`03o`000?oooooooooo09[ooooo00?o09Goooooooooool06oooool00ol0003oooooooooo`05oooo
o`06o`3o<oooooooooooooooooo8o`3o`Ol04_ooool00ol0003oooooooooo`04ooooo`03o`04oooo
oooooooo00?ooooo00Go06_oooooooooooooooooobH0o`02ooooo`03obH0oooooooooooo00;ooooo
00Go0?oKoooooooooooo6_l0o`3og`02ooooo`06onOo0?ooooooooooonWo0?oooooojol00_ooool0
1?ooj`3ooooooooooollo`05ooooo`05od?o0?l0oeko0>7oooooool000002oooool00omZo`3o08co
ooooo`0Gooooo`03o`000?oooooooooo093ooooo002Looooo`03o`2Eoooooooooooo01Gooooo00?o
0000ooooooooool02?ooool00ol0oc?oooooooooo`02ooooo`03ol7o0?oooooooooo01Cooooo00?o
00Coooooool000000_ooool01Ol0Jooooooooooooooooooo9P3o00;ooooo00?o9P3oooooooooool0
0_ooool01Ol0om_ooooooa[o0?l0omooiol000;ooooo00KojOl0o`3oj?oooooojol0ooo[0?oJo`04
ooooo`03occo0?oooooooooo00?ooooo00?o0000od?o0?ooool00_ooool00ol0hOooooooooooo`09
ooooo`03o`2<ooooooooJ_l002;ooooo00?o0000ooooooooool0V_ooool00ol0UOooooooooooo`0J
ooooo`03o`000?oooooooooo00Kooooo00Go0?lcoooooooooooob?l0ol7o000Cooooo`03o`000?oo
oooooooo00?ooooo00?o00Coooooooooool00_ooool01_l0Jooooooooooooooooooo0>_oobH0o`?o
oooo00Go9P3oooooooooooooooooo`3of`02ooooo`0<oa[o0?l0omoooooooooooooWo`3oooooonWo
0?l0onSoooooon_o0?ooooooon/00oooool00ollo`3oooooooooo`03ooooo`05od?o0?l0hOoooooo
ooooool000002oooool00ol0S?ooooooooooo`0Hooooo`03o`000?oooooooooo08oooooo002Moooo
o`03o`2Eoooooooooooo01Cooooo00?o0000ooooooooool02Oooool01Ol0oc?ooooooooooooooooo
`Ol001Kooooo00Go00Cooooooooooooo0000o`1[o`04ooooo`05obH0oooooooooooooooooolV0?l0
0_ooool01Ol0om_oooooooooool0omooiol000;ooooo00OojOl0o`3oj?oooooojol0ooooooooj`3o
f_l000Cooooo00?o??l0ooooooooool00oooool01_l0003o@ol0oooooooooooo0?mLo`3Qo`[ooooo
00?o08cooooooomZo`008oooool00ol0003oooooooooo`2Jooooo`03o`2Eoooooooooooo01[ooooo
00?o0000ooooooooool01oooool01?l0oc?oooooolSo0?o1o`0Cooooo`03o`000?oooooooooo00;o
oooo00?o00Coooooooooool00oooool01_l0Jooooooooooooooooooo0>_oobH0o`?ooooo00Co9P3o
oooooooooooo0?oK0oooool02ol0omoooooooooooooWo`3oooooonWo0?l0onSoooooon_o0?oooooo
on/000Cooooo00?o??l0ooooooooool00oooool01Om3o`3o0>7ooooooooooooo000000[ooooo00?o
08coooooooooool06Oooool00ol0003oooooooooo`2?ooooo`00W_ooool00ol0UOooooooooooo`0C
ooooo`03o`000?oooooooooo00[ooooo00Go0?lcoooooooooooo0000ol7o000Dooooo`03o`04oooo
oooooooo00;ooooo00?o06_oooooooooool00_ooool01OlV0?oooooooooooooooooo9P3o00;ooooo
00go0?oKoooooooooooo0?oOonOo0?oooooojOl0ooooool0onSoooooon_o0?ooj`3of_l000Gooooo
00?o??l0ooooooooool00oooool01_l0003o@ol0oooooooooooo0?mLo`3Qo`Wooooo00Co08cooooo
ooooooooJ_l07oooool2o`0000?ooooo00?o0000ooooooooool0V_ooool00ol0UOooooooooooo`0I
ooooo`03o`000?oooooooooo00Sooooo00Co0?lcolSo0?o1o`3o00004oooool01Ol0003ooooooooo
oooooooo00Co00Cooooo00Go06_oooooooooooooooooo`3[o`02ooooo`07obH0oooooooooooooooo
oolV0?ooooooo`3of`02ooooo`04o`3ogooooooo6_l0onOo00;ooooo00GojOl0ooooooo[o`3ooooo
ooo[0005ooooo`03occo0?oooooooooo00?ooooo00Go@ol0o`3Qooooooooooooo`000009ooooo`03
o`2<oooooooooooo01_ooooo00?o0000ooooooooool0S_ooool009oooooo00?o09Goooooooooool0
4_ooool00ol0003oooooooooo`0;ooooo`04o`3o<ooooooo0000ol7o01Cooooo00?o00Cooooooooo
ool00_ooool01ol0Jooo0000oooooooooooo0>_ooooooolV0?l00oooool03_lV0?oo0?oKoooooooo
oooo0?oOonOo0?lJo`3oooooonWo0?l0onSoooooon_o0?ooooooon/01_ooool00ollo`3ooooooooo
o`03ooooo`05o`000?m3o`3oooooooooool0hOl02Oooool01?l0S?oooooooooooomZo`0Pooooo`;o
00001?ooool00ol0003oooooooooo`2Jooooo`03o`2Eoooooooooooo01Sooooo00?o0000oooooooo
ool02Oooool00oo8o`3o`Ol0o`00000Dooooo`03o`000?oooooo00Co00Gooooo00Go06_ooooooooo
ooooooooo`3[o`02ooooo`06obH0oooooooooooooooooolV0?oo0?oK0oooool02?l0omoooooooa[o
0?oWo`3oooooonWo0?l0onSojol00_ooool00oooj`3oooooooooo`03ooooo`03occo0?oooooooooo
00;ooooo00?o0?mNod?o0?ooool00_ooool00ol0003oooooooooo`06ooooo`03o`2<oomZo`3ooooo
01cooooo00?o0000ooooooooool0S_ooool00:3ooooo00?o09Goooooooooool04Oooool00ol0003o
ooooooooo`0<ooooo`03olSo0?o1o`3o`Ol001?ooooo00?o00Coooooooooool00_ooool02?l0Jooo
ooooooooool0003oooooo`3[oooooooo9P3o0oooool01OlV0?oo0?oKooooooooooooiol000;ooooo
00KojOl0ooooool0onSojol0ooooooooj`07ooooo`03occo0?oooooooooo00?ooooo00Go0000od?o
0?oooooo0?mLo`3Qo`08ooooo`05o`2<oooooooooooooooooomZo`008Oooool00ol0od7ooooooooo
o`03ooooo`03o`000?oooooooooo09[ooooo00?o09Goooooooooool05oooool00ol0003ooooooooo
o`09ooooo`03olSo0?o1o`3ooooo01Gooooo00?o0000o`04ooooool00oooool01Ol0Jooooooooooo
oooooooo0>_o00Cooooo00Co9P3ooooooooooooo9P3o0oooool02ol0omoooooooooooooWo`3ooooo
onWo0?l0onSoooooon_o0?ooooooon/000Kooooo00?o??l0ooooooooool00_ooool00ol0oeko@ol0
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o08coof[o0?ooool06Oooool2o`0000?ooooo
00?o0000ooooooooool0SOooool00:7ooooo00?o09Goooooooooool04?ooool00ol0003ooooooooo
o`0<ooooo`03olSo0?o1o`3o`Ol001?ooooo00?o00Coooooooooool00_ooool01Ol0Jooooooooooo
oooooooo0>_o00?ooooo00Co9P3ooooooooooooo9P3o0_ooool02_l0omooiol0oooooooYo`3o6_l0
o`3oj?oooooojol0ooo[0?oJo`07ooooo`03occo0?oooooooooo00?ooooo00Go0000od?o0?oooooo
0?mLo`3Qo`07ooooo`05o`2<oooooooooooooooooomZo`008Oooool00ol0od7oooooooooo`04oooo
o`03o`000?oooooooooo09_ooooo00?o09Goooooooooool05_ooool00ol0003oooooooooo`09oooo
o`;o`Ol00_l0oc<Dooooo`03o`04oooooooooooo00?ooooo00Go06_oooooooooooooooooo`3[o`04
ooooo`05obH0ooooooooooooo`3ofolV0?l00_ooool02_l0omooooooonOo0?oooooo6_l0onWo0?oo
oooojol0ooooooooj`07ooooo`03occo0?oooooooooo00;ooooo00?o0?mNod?o0?ooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`2<oomZo`3ooooo01[ooooo0_l00003ooooo`03o`000?oooooo
oooo08gooooo002Rooooo`03o`2Eoooooooooooo00Gooooo0_l00008ooooo`03o`000?oooooooooo
00cooooo00Cob?l0ol7o0?o1o`3o0?lc4_ooool01Ol01?oooooooooooooooooo06_o00Cooooo00Go
0>_oooooooooooooooooobH0o`02ooooo`04o`3ofolV0?ooooooonOo00;ooooo00KojOl0ooooool0
onSojol0ooooooooj`08ooooo`03occo0?oooooooooo00?ooooo00Co0000od?o0?oooooo0>7o2?oo
ool01Ol0S?ooooooooooooooooooJ_l000?ooooo0_l0000Kooooo`03o`3o@Ooooooooooo00Kooooo
00?o0000ooooooooool0Voooool00ol0UOooooooooooo`02ooooo`;o00004Oooool00ol0003ooooo
ooooo`09ooooo`;o`Ol00_ooool00ol0oc?oooooooooo`0Aooooo`03o`04ool0003ooooo00;ooooo
00Go06_oooooooooooooooooo`3[o`05ooooo`0>obH0oooooooo0?oKoooooolV0?ooooooo`3ogooo
oooof_l0onOo0?oooooojOl0o`3oj?o[o`02ooooo`03ooo[0?oooooooooo00Gooooo00Oo??l0oooo
ooooooooooooo`3oG_l0hOoo@ol000?ooooo00?o0000ooooooooool00oooool00ol0S?ooooooof[o
000Kooooo`03o`3o@Ooooooooooo00?ooooo00?o0000ooooooooool0S?ooool00:?ooooo00?o09Go
ooooooooool01?ooool2o`0000Sooooo00?o0000ooooooooool03?ooool01Oo8o`3o`Ol0ol7o0?oo
oooo0?lc013ooooo00?o00Coooooooooool00_ooool01ol0Jooooooooooooooooooo0>_oooooool0
00000_ooool01_lV0?ooooooo`3ofooooooo9P3oonOo00;ooooo00KojOl0ooooool0onSojol0oooo
ooooj`0:ooooo`03occo0?oooooooooo00;ooooo00Co0000od?o0?l0oeco0>7o0oooool2o`1>o`;o
oooo00Go08coooooooooooooooooof[o0004ooooo`;o00006_ooool00ol0od7oooooooooo`08oooo
o`03o`000?oooooooooo09_ooooo00Co09Gooooooooooooooooo0_l0000Aooooo`03o`000?oooooo
oooo00Wooooo0_o1o`03ooooo`03o`3o<ooooooooooo013ooooo00?o00Coooooool000000_ooool0
1Ol0Jooooooooooooooooooo0>_o00Kooooo00oo9P3oo`3ofooooooo9P3oooooool0omoof_l0onOo
0?oooooojOl0o`3oj?oooooojol0ooooooooj`002?ooool01ollo`3ooooooooooooooooo0?mNo`3Q
oom3o`001?ooool01ol0003ooooooooooooooooo08cooooooomZo`001oooool2o`0001;ooooo00?o
0?m1ooooooooool01Oooool00ol0003oooooooooo`2;ooooo`00Y?ooool00ol0UOooooooooooo`05
ooooo`03o`3o1?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00oo8o`3o`Ol0ol7o0002
ooooo`03o`3o<ooooooooooo00gooooo00Go00Coooooooooooooooooo`1[o`04ooooo`04o`3[oooo
ooooooooo`0000;ooooo00Go9P3oo`3ofoooooooooooonOo0002ooooo`06onWo0?l0onSoooooon_o
0?ooj`3of_l02_ooool00ollo`3oooooooooo`02ooooo`04o`000?m3o`3o0?mLo`3Qo`?o04ko0_l0
00000ooooooo08coooooo`03ooooo`03of[o0?oooooooooo00?ooooo00?oV?l0ooooooooool06?oo
ool00ol0od7oooooooooo`08ooooo`03o`000?oooooooooo09cooooo00?o09Goooooooooool00_oo
ool00ol0o`Coooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo0_o1o`04ooooo`03o`3o<ooo
oooooooo00kooooo00Ko00Coooooooooooooooooo`000?l0Jol3ooooo`03o`3[oooooooooooo00Go
oooo00Oo9P3oooooooooooooooooobH0oooJo`3oiol000;ooooo00GojOl0ooooooo[o`3oooooooo[
0009ooooo`07occo0?oooooo04koo`1>ool0oeko0>7ood?o0004ooooo`06o`000?ooooooooooo`2<
ooooooooJ_l02?ooool2o`00017ooooo00?o0?m1ooooooooool01_ooool00ol0003oooooooooo`2;
ooooo`00YOooool00ol0UOooooooooooo`05ooooo`03o`3o1?oooooooooo00?ooooo00?o0000oooo
ooooool03Oooool00oo8o`3o`Ol0ol7o0003ooooo`;o0?lc3?ooool00ol01?ooooooooooo`02oooo
o`05o`1[ooooooooooooooooool0jol01?ooool00ol0003oooooobH0o`02ooooo`09onOo0?lV0?oo
ooooonWo0?oooooo0?oXon_o0?ooooooon/000_ooooo00?o??l0ooooooooool00_ooool01?l0003o
@ol0o`3Qool0C_l5ooooo`03o`2<oooooooooooo00;ooooo00?oJ_l0ooooooooool01?ooool00onH
o`3oooooooooo`0Gooooo`03o`3o@Ooooooooooo00[ooooo00?o0000ooooooooool0W?ooool00ol0
UOooooooooooo`02ooooo`03o`3o1?oooooooooo00gooooo00?o0000ooooooooool02Oooool2ol7o
00Gooooo00?o0?lcooooooooool03Oooool01_l01?oooooooooooooooooo0000o`1[o`?ooooo00?o
0>_oooooooooool01?ooool01ol0om_o9P3ooooooooooooo0?oOobH0oooWo`000_ooool01_oYo`3o
0?oXon_o0?lJo`3oooooooo[00Wooooo00Oo??l0o`1>ool0003o0?mLo`3Qoooooooo@ol000Cooooo
00?o0000ooooool0S?l00_ooool00omZo`3oooooooooo`06ooooo`03oiSo0?oooooooooo00oooooo
00?o0?m1ooooooooool02?ooool00ol0003oooooooooo`2:ooooo`00YOooool00ol0UOoooooooooo
o`06ooooo`03o`3o1?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00oo8o`3o`Ol0oooo
o`05ooooo`03o`3o<ooooooooooo00Wooooo00Go00Coooooooooooooooooo`1[o`04ooooo`03o`3[
oooooooooooo00?ooooo00go0000o`3ofolV0?ooooooonOo0?oooooojOl0ooooool0onSojol0oooo
ooooj`3o6_l000_ooooo00?o??l0ooooooooool00_ooool00ol0003o@ol0o`3Qo`05ooooo`03o`2<
oooooooooooo00?ooooo00?oJ_l0ooooooooool00oooool00onHo`3oooooooooo`0Gooooo`03o`3o
@Ooooooooooo00cooooo00?o0000ooooooooool0Voooool00ol0UOooooooooooo`03ooooo`03o`3o
1?oooooooooo00cooooo00?o0000ooooooooool02Oooool2ol7o00Kooooo00?o0?lcooooooooool0
2oooool00ol01?ooooooooooo`02ooooo`05o`1[ool0003oooooooooool0jol01oooool03_l0om_o
ooooobH0oooooooo0?oOobH0oooWo`3oooooonWo0?l0onSoooooon_o0?lJo`3oon/01oooool3o`1>
o`07occo0?ooooooooooo`3oG_l0hOoooooood?o0004ooooo`05o`000?l0S?oooooooooooomZo`00
2?ooool00onHo`3oooooooooo`0@ooooo`03o`3o@Ooooooooooo00Sooooo00?o0000ooooooooool0
R_ooool00:Kooooo00?o09Goooooooooool01_ooool01Ol0o`Cooooooooooooooooo000000oooooo
00?ob?l0ol7o0?ooool01_ooool00ol0oc?oooooooooo`07ooooo`03o`04oooooooooooo00;ooooo
00?o06_oooooooooool00_ooool00ol0joooooooooooo`03ooooo`0;o`000?l0om_o9P3oonOo0?l0
omooooooonWo0?oooooo0?oXon_o0?ooj`000_ooool00olJo`3oooooooooo`08ooooo`03occo0?oo
oooo04ko00;o04ko00?o0000od?o0?l0hOl01?ooool00ol0S?ooooooooooo`03ooooo`03of[o0?oo
oooooooo00Cooooo00?oV?l0ooooooooool05_ooool00ol0od7oooooooooo`0=ooooo`03o`000?oo
oooooooo09cooooo00?o09Goooooooooool00oooool00ol0o`Coooooooooo`0;ooooo`03o`000?oo
oooooooo00Wooooo0_o1o`07ooooo`03o`3o<ooooooooooo00[ooooo00?o00Coooooooooool00_oo
ool01Ol0Joooooooo`000?oooooo0>_o00Kooooo00oo0?oKoooooooooooo9P3oo`3ogooJo`3oiol0
obH0oooYo`3oooooo`3oj?o[o`3oooooooo[0?lJo`001Oooool2o`1>o`?ooooo00Oo??l0oooooooo
oooo0?mNo`3Qoooooooo@ol000Cooooo00Co0000ooooooooooooJ_l02Oooool00onHo`3ooooooooo
o`0?ooooo`03o`3o@Ooooooooooo00[ooooo00?o0000ooooooooool0ROooool00:Oooooo00?o09Go
ooooooooool01_ooool01?l0o`Coooooooooool0000?ooooo`03olSo0?o1o`3ooooo00Oooooo00?o
0?lcooooooooool01_ooool00ol01?ooooooooooo`02ooooo`05o`1[ooooooooooooooooool0jol0
1_ooool02ol0om_o0000onOo0?lV0?ooooooonWo0?lV0?oo0?oXon_o0?ooooooon/000;ooooo00?o
6_l0ooooooooool02?ooool00ollo`3o04koooooo`02ooooo`04o`000?m3o`3o0>7oooooo`;o0000
00?o08coooooooooool00oooool00omZo`3oooooooooo`05ooooo`03oiSo0?oooooooooo01Kooooo
00?o0?m1ooooooooool03_ooool00ol0003oooooooooo`21ooooo`;o00006Oooool00ol0UOoooooo
ooooo`03ooooo`03o`3o1?oooooooooo00[ooooo00?o0000ooooooooool02Oooool2ol7o00Sooooo
00?o0?lcooooooooool02?ooool00ol01?ooooooooooo`02ooooo`05o`1[ooooooooooooo`000?l0
jol01oooool03ol0om_ooooooooooolV0?oo0?oOonOo0?oooooo9P3oonWo0?l0onSojol0oooooooo
j`3ooooooa[o0003ooooo`;o04ko1Oooool01?llo`3oooooo`3oG?l0hOl2ooooo`06od?o0?oooooo
ooooooooool0S?oo00000_ooool00omZo`3oooooooooo`07ooooo`03oiSo0?oooooooooo00kooooo
00?o0?m1ooooooooool03?ooool00ol0003oooooooooo`28ooooo`00T?ooool2o`000003o`3oG_oo
oooooooo01?ooooo00?o09Goooooooooool01_ooool00ol0o`Coooooo`00000?ooooo`;o00002Ooo
ool00ol0oc?oooooooooo`05ooooo`05o`04ooooooooooooooooool0Jol01?ooool00ol0jooooooo
ooooo`04ooooo`05o`3ofoooooooiol0obH0oooYo`000_ooool00olV0?oojol0ooo[0003ooooo`03
oa[o0?oooooooooo00Kooooo0_l0C_l00ollo`3oooooooooo`02ooooo`04o`000?m3o`3ooooooooo
o`;o00001_ooool00omZo`3oooooooooo`05ooooo`03oiSo0?oooooooooo01Gooooo00?o0?m1oooo
ooooool04?ooool00ol0003oooooooooo`20ooooo`;o00006_ooool00ol0UOooooooooooo`03oooo
o`03o`3o1?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00oo1o`3o0000o`000008oooo
o`03o`3o<ooooooooooo00Oooooo00?o00Coooooooooool00_ooool01Ol0Jooooooooooooooooooo
0>_o00Kooooo00_o0?oKooooooooooooooooo`3ogolV0?ooiol0oooooooYo`3o0?oXon_o0002oooo
o`04ooo[0?oooooo6_l0ooooo`;o04ko1oooool01?llo`3oooooo`3oG_l0hOl2ooooo`08od?o0?oo
ooooooooo`2<oooooooo0000ooooool0f_l2o`0000Sooooo00?oV?l0ooooooooool03Oooool00ol0
od7oooooooooo`0=ooooo`03o`000?oooooooooo08Sooooo002@ooooo`;o000000?oooooo`3oG_oo
ool05?ooool00ol0UOooooooooooo`06ooooo`03o`3o1?l0003ooooo00kooooo00?o0000ol7o0?oo
ool02Oooool00ol0oc?oooooooooo`03ooooo`03o`04oooooooooooo00;ooooo00Go06_ooooooooo
ooooooooo`3[o`06ooooo`0:o`3ofoooooooiol0o`3ogolV0?oojOl0ooooool0onSojol0ooo[00Go
oooo00?o6_l0ooooooooool00_ooool3o`1>o`;ooooo00?o??l0ooooooooool00_ooool01Ol0003o
@ol0o`3Jool0f_oo08co00Kooooo00?oJ_l0ooooooooool01_ooool00onHo`3oooooooooo`0Doooo
o`03o`3o@Ooooooooooo01;ooooo00?o0000ooooooooool0POooool00ol0oekoooooooooo`0Hoooo
o`03o`2Eoooooooooooo00?ooooo00?o0?l4ooooooooool02?ooool00ol0003oooooooooo`09oooo
o`03ol7o0?l0003o`Ol000Wooooo00?o0?lcooooooooool01Oooool00ol01?ooooooooooo`02oooo
o`07o`1[ooooooooooooooooool0joooooooo`000005ooooo`0=o`3ofoooooooooooo`3ogooJo`3o
iol0oooooooYo`3oooooo`3oj?o[o`3oooooooo[0002ooooo`03o`1>oolJo`3ooooo00Sooooo00Co
??l0ooooool0oeko0>7o0_ooool00om3o`3oooooo`2<o`02ooooo`03o`000?l0f_oooooo00;o0000
2?ooool00onHo`3oooooooooo`0<ooooo`03o`3o@Ooooooooooo00oooooo00?o0000ooooooooool0
Qoooool009Cooooo00?o0?mNooooooooool04oooool00ol0UOooooooooooo`06ooooo`03o`000?oo
oooooooo00gooooo0_o1o`0;ooooo`;o0?lc0oooool01Ol01?oooooooooooooooooo06_o00Cooooo
00?o0>_oooooooooool01?ooool02_l0om_oooooonOo0?l0omoojOl0obH0oooooooojol0om[o0?oo
j`05ooooo`03oa[o0?oooooooooo00;o04ko1Oooool00ollo`3oooooooooo`02ooooo`05o`000?m3
o`3oooooooooool0S?l01_ooool00omZo`3oooooooooo`06ooooo`03oiSo0?oooooooooo01?ooooo
00?o0?m1ooooooooool04oooool00ol0003oooooooooo`1jooooo`;o00001_ooool00ol0oekooooo
ooooo`0Hooooo`03o`2Eoooooooooooo00?ooooo00?o0?l4ooooooooool01oooool00ol0003ooooo
ooooo`09ooooo`?o`Ol02_ooool00ol0oc?oooooooooo`04ooooo`03o`04oooooooooooo00;ooooo
00Go06_oooooooooooooooooo`3[o`02ooooo`05o`000?ooooooooooooooool0om/00oooool02Ol0
omooiol0oooooolV0?oojOl0o`3oj?o[o`3oooooooo[0003o`1>o`03oooooolJo`3ooooo00Sooooo
00?o??l0o`3oG?l0hOl00oooool00om3o`3o08coo`3Jo`02o`3Jo`03o`000?mZo`3ooooo00Wooooo
00?oV?l0ooooooooool03Oooool00ol0od7oooooooooo`0?ooooo`03o`000?oooooooooo08Oooooo
0024ooooo`;o00003oooool00ol0oekoooooooooo`0Cooooo`03o`2Eoooooooooooo00Gooooo00?o
0000ooooooooool03Oooool2ol7o00gooooo00?o0?lcooooool01?l01?ooool01Ol0Jooooooooooo
oooooooo0>_o00Kooooo00_o0?oKoooooooWo`3o0?oOoooooooYo`3o9P3oo`3oj?o[o`3oon/0obH0
o`06ooooo`03oa[o0?l0C_oooooo00Kooooo00?o??l0ooooooooool00_l0f_l01?l0003o@ol0oooo
ool0S?l6ooooo`03of[o0?oooooooooo00Kooooo00?oV?l0ooooooooool04oooool00ol0od7ooooo
ooooo`0Eooooo`03o`000?oooooooooo07Wooooo0_l000001Ol0YOooooooo`000?l0003oDol000;o
oooo00?o0?mNooooooooool06?ooool00ol0UOooooooooooo`02ooooo`03o`3o1?oooooooooo00Oo
oooo00?o0000ooooooooool02Oooool3ol7o00_ooooo00?o0?lcooooooooool00_ooool00ol01?oo
ooooooooo`02ooooo`05o`1[ooooooooooooooooool0jol00oooool01?l0003oooooooooool0om/3
ooooo`0:o`3ogooWo`3ooooooooooooYo`3o0?oXon_o0?oooooo9P3oooo[00Cooooo00?o6_l0oooo
ooooool01oooool00ollo`3o0?mNo`3Qo`03ooooo`;o0=[o0oooool00ol0003oooooooooo`09oooo
o`03oiSo0?oooooooooo00cooooo00?o0?m1ooooooooool04Oooool00ol0003oooooooooo`26oooo
o`00Q?ooool2o`000003o`2Uoooooooooooo00Kooooo00?o0000oe?o0?mCo`001?ooool00ol0oeko
ooooooooo`0Cooooo`03o`2Eoooooooooooo00;ooooo00Co0000o`3oaol0003o0?l43_ooool2ol7o
00kooooo00?o0?lco`04ooooool00_ooool00ol0Joooooooooooo`02ooooo`03o`3[oooooooooooo
00Cooooo00Go0?oKonOo0?oooooo0?oOonWo0002ooooo`04on_o0?ooj`3oooooobH0o`?ooooo0ol0
C_l00olJo`3oooooooooo`06ooooo`08occo0?l0f_oo0=[oooooool0oeco0000od?o0?l0S?l7oooo
o`03of[o0?oooooooooo00Kooooo00?oV?l0ooooooooool04oooool00ol0od7oooooooooo`0Foooo
o`03o`000?oooooooooo07_ooooo0_l0YOl00ol0003ooooooe?o0002ooooo`03o`3oG_oooooooooo
01Sooooo00?o09Goo`3oaol0olL00_ooool00ol0o`Coooooooooo`06ooooo`03o`000?oooooooooo
00Sooooo00Cob?l0ol7o0?o1o`3o`Ol03?ooool01Ol0oc?ooooooooooooooooo00Co00Cooooo00Go
06_oooooooooooooooooo`3[o`04ooooo`03o`000?oooooo0?oK00?ooooo00Wo0?oOonOo0?oooooo
jOl0obH0ool0onSojol0o`1>ooooj`001_ooool00olJo`3oooooooooo`06ooooo`04occo0?l0oeko
0>7oooooo`;o0=[o00Ko@ol0ooooooooooooooooof[o0?l0000;ooooo`03oiSo0?oooooooooo00_o
oooo00?o0?m1ooooooooool04_ooool00ol0003oooooooooo`26ooooo`00Qoooool2o`2Uo`Kooooo
0_l000000oooooooDol0ooooo`03ooooo`03o`3oG_oooooooooo01?ooooo00Co09Gooooooooooooo
oooo0ol000000ol0olOo0?l4ooooo`0<ooooo`;o`Ol03oooool01Ol01?oooooooooooooooooo06_o
00?ooooo00?o0>_oooooooooool01?ooool01Ol0om_oooooonOo0?l0omoojOl000;ooooo00?ojol0
obH0ooooj`000_ooool00olV0?oo04koo`1>o`04ooooo`03oa[o0?oooooooooo00Cooooo00?o0=[o
occo0?ooool00_ooool00ol0oeko0000od?o0007ooooo`03of[o0?oooooooooo00Oooooo00?oV?l0
ooooooooool04_ooool00ol0od7oooooooooo`0Fooooo`03o`000?l07ooooooo06gooooo0_l00000
0ol0okSoooooooooo`0<ooooo`04o`2Uoooooooooooooe?o00;ooooo00?o0?mNooooooooool06?oo
ool01_l0UOoo0000o`3oaol0olOoooooo`3o10Oooooo00?o0000ooooooooool02?ooool01?o8o`3o
`Ol0ol7o0?o1o`0=ooooo`;o0?lc00?o00Coooooooooool00_ooool01Ol0Jooooooooooooooooooo
0>_o00Kooooo00ko0?oKooooooooooooooooo`3ogooWo`3oooooonWo0?oooooo0?oXon_o0?oooooo
on/0obH0o`Kooooo00?o6_l0ooooooooool01_ooool01_llo`3o0>7oo`3Jool0f_oo08cood?o00Co
oooo00?oJ_l0o`000?ooool02_ooool00onHo`3oooooooooo`0:ooooo`03o`3o@Ooooooooooo01Co
oooo00?o0000ooooooooool0QOooool007[ooooo0_l0000=ooooo`;o0:Go2?ooool00omCo`3ooooo
ooooo`02ooooo`03o`3oG_oooooooooo01?ooooo00?o09Goooooooooool00_ooool01?l0003ooooo
o`3oaol0o`@<ooooo`;o`Ol03_ooool00ol01?ooooooo`3o<`02ooooo`05o`1[oooooooooooooooo
ool0jol01_ooool01Ol0om_oiol0ooooool0omoojOl000;ooooo00Kojol0ooo[0?oooooo0000o`1>
oolV0?l6ooooo`03oa[o0?oooooooooo00;ooooo0_l0f_l02?oooooo??l0oooooooooooo0?mLo`3Q
ool0003o@ol01oooool00omZo`3oooooooooo`07ooooo`03oiSo0?oooooooooo017ooooo00?o0?m1
ooooooooool05oooool00ol0003o01ooo`00001]ooooo`;o000000?oooooo`3o^?l0okP02_ooool2
o`000005of?o0?l0YOoo0:GooooooomCo`000_ooool00ol0oekoooooooooo`0Gooooo`07o`2Eoooo
ooooooooooooool0olOoooooo`3o1006ooooo`03o`000?oooooooooo00Sooooo00Cob?l0ol7o0?o1
o`3o`Ol03oooool00ol01?ooooooooooo`02ooooo`05o`1[ooooooooooooooooool0jol01_ooool0
3?l0om_ooooooooooooJo`3oiol0ooooool0C_oojOl0o`3oj?o[o`3o9P3oooo[00;ooooo00?o9P3o
ooooooooool00oooool00olJo`3oooooooooo`06ooooo`;o0=[o00Coooooo`2<oooooooo@ol00ooo
ool01?mZo`3oooooooooool0000:ooooo`03oiSo0?oooooooooo00[ooooo00?o0?m1ooooooooool0
4oooool00ol0003o01ooo`000026ooooo`00N_ooool2o`0000;o0?nh3Oooool01Ol0YOoooooooooo
oooooooo000000;oHol00_ooool00omCo`3oooooooooo`02ooooo`03o`3oG_oooooooooo01?ooooo
00Co09Gooooooooooooo00001?ooool00ol0o`Co0?o7ooooo`09ooooo`;o`Ol03_ooool01Ol01?oo
ooooooooool0oc?o06_o00Cooooo00?o0>_oooooooooool00oooool01Ol0om_oiol0ooooool0omoo
jOl000;ooooo00Sojol0om[o0?ooj`3o9P3oo`1>ool0003oooooobH0o`Gooooo00?o6_l0oooooooo
ool00_l0f_l3ooooo`07occo0?ooooooooooo`3oG?l0hOoo0000od?o0006ooooo`03of[o0?oooooo
oooo00Sooooo00?oV?l0ooooooooool04?ooool00ol0od7oooooooooo`0Hooooo`04o`0Ooooooooo
ooooo`0005kooooo0_l000000ol0l?ooooooooooo`0>ooooo`03o`3o^?oooooooooo00Oooooo0_l0
00000oooooooHol0ooooo`02o`2Uo`04oe?o0?ooooooooooo`3oGQWooooo00Co09Gooooooooooooo
oooo0_l0olL00ol0o`Coooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00Cob?l0ol7o0?oo
oooo`Ol03oooool01Ol01?oo0?lcoooooooooooo06_o00?ooooo00?o0>_oooooooooool01?ooool0
3Ol0om_oooooo`000?oJo`3o0?oOonOo0?l0C_oojOl0ooooooo[o`3oooooobH0ooooj`000_ooool0
0olV0?ooooooooooo`04ooooo`03oa[o0?oooooooooo00;ooooo0ol0f_l00ollo`3o0>7oo`2<o`02
ooooo`04od?o0?ooooooooooof[o00?ooooo00?o0000ooooooooool01oooool00onHo`3ooooooooo
o`0:ooooo`03o`3o@Ooooooooooo01Cooooo00?o0000o`0Oool00000Q_ooool006gooooo0_l0000?
ooooo`03o`3o^?oooooooooo00_ooooo0_l0YOl01Ooooooo0000o`000?ooooooHol000;ooooo00?o
Dol0ooooooooool00_ooool00ol0oekoooooooooo`0Cooooo`03o`2Eoooooooo000000Gooooo00?o
0?l4o`3oaoooool01oooool00oo8o`3o`Ol0ol7o000=ooooo`03o`04oooooooooooo00;ooooo00Go
06_oo`3o<oooooooooooo`3[o`06ooooo`04o`3ofooWo`3oooooonWo00;ooooo00Gojol0o`3oj?oo
j`3oooooobH0o`02ooooo`03o`000?lV0?oooooo00Gooooo0_l0f_l5ooooo`07occo0?oooooooooo
o`2<ool0hOoo0000od?o0006ooooo`03of[o0?oooooooooo00Oooooo00?oV?l0ooooooooool04Ooo
ool00ol0od7oooooooooo`0Gooooo`05o`0Oooooooooooooooooool00000G_ooool2o`000004oooo
ool0l?oo0?3oo`3`o`kooooo0_l0okP;ooooo`03of?o0?oooooooooo00;o0:Go0_ooool00ol0oeko
ooooooooo`0Gooooo`03o`2Eoooooooooooo00;ooooo00?o0?o7o`3o1?ooool00oooool00ol0003o
ooooooooo`08ooooo`04olSo0?o1o`3ooooool7o00kooooo00Ko00Cooooooooooooo0?lcooooool0
Jol3ooooo`03o`3[oooooooooooo00Cooooo00go0?oKoooooooooooo0?oOonOo0?oooooojOl0oooo
ool0onSojol0ooooooooj`3o9P3o00;ooooo00?o9P3oooooooooool01?ooool00olJo`3ooooooooo
o`02o`3Jo`;ooooo00?o0?mLocco0?l0S?l00oooool01?m3o`3ooooooooooomZo`03ooooo`03o`00
0?oooooooooo00Oooooo00?oV?l0ooooooooool02Oooool00ol0od7oooooooooo`0Eooooo`04o`0O
ooooooooooooo`0008Gooooo001]ooooo`;o00000ol0l?l=ooooo`;o0?nh3Oooool2o`2Uo`?ooooo
00CoHol0ooooooooooooDol01?ooool00ol0oekoooooooooo`0Booooo`03o`2Eoooooooo000000Ko
oooo00?o0?l4o`3oaol0olL01_ooool00oo8o`3o`Ol0ol7o000=ooooo`05o`04oooooooooooooooo
ool0Jol00_ooool00ol0oc?oooooo`3[o`05ooooo`09o`3ofooWo`3oooooo`3ogooYo`3oooooo`1>
ooo[o`3oon/000?ooooo00Go9P3ooooooooooooo0000obH0o`03ooooo`;o0=[o00?o6_l0oooooooo
ool01?ooool01ollo`3oooooo`2<ool0hOooooooo`000?m3o`001Oooool00omZo`3oooooooooo`08
ooooo`03oiSo0?oooooooooo013ooooo00?o0?m1ooooooooool05oooool00ol07oooooooooooo`03
ooooo`03o`000?oooooooooo067ooooo0_l0l?l>ooooo`;o0?nh2_ooool01OmSo`3ooooooooooooo
oooo0:Go00;ooooo00?o0?mNooooooooool05oooool00ol0UOooooooooooo`03ooooo`05o`3o1?l0
olOoooooooooool000002_ooool01?o8o`3o`Ol0ooooooo1o`0>ooooo`05o`04oooooooooooooooo
ool0Jol00oooool00ol0joooooooooooo`04ooooo`0>o`3ofooooooo04koom[o0?oWo`3o0000oooo
oooYo`3oooooon_o0?ooooooon/0oooooolV0?l3ooooo`03obH0oooooooooooo00?ooooo00?o6_l0
o`3Jool0f_l01?ooool00ol0oeko??l0ooooo`03ooooo`03od?o0?ooooooJ_l000Cooooo00?o0000
ooooooooool01oooool00onHo`3oooooooooo`08ooooo`03o`3o@Ooooooooooo01Gooooo00Go01oo
ooooooooooooooooo`000025ooooo`00L_ooool2o`3`o`gooooo0_l0okP=ooooo`;o0:Go0_ooool0
1?mSo`3ooooooooooomCo`04ooooo`03o`3oG_oooooooooo01;ooooo00?o09Goo`000?ooool01_oo
ool01?l0o`Coooooo`3oaol0olL4ooooo`03olSo0?o1o`3o`Ol000cooooo00?o00Coooooooooool0
0_ooool01Ol0Jooooooooooooooooooo0>_o00Kooooo00Co0?oKonOo0?oooooojOl00_l0C_l00oo[
o`3of_l0ooo[0003ooooo`06obH0ooooooooooooo`000?lV0?oooooo0_l0f_l3ooooo`03oa[o0?oo
oooooooo00?ooooo00Oo??l0ooooool0S?oo0>7oooooool0003o@ol000Cooooo00?oJ_l0oooooooo
ool02Oooool00onHo`3oooooooooo`0?ooooo`03o`3o@Ooooooooooo01Sooooo00?o01oooooooooo
ool01?ooool00ol0003oooooooooo`1Rooooo`;o0?3o3_ooool00ol0okSoooooooooo`08ooooo`04
of?o0?ooooooooooooooo`;o0:Go00?oooooo`3oG_ooool06?ooool00ol0UOooooooooooo`03oooo
o`04o`3o1?l0olOoooooo`0000[ooooo00Cob?l0ol7o0?oooooo`Ol03Oooool00ol01?oooooooooo
o`02ooooo`04o`1[ool0oc?oooooo`3[o`Kooooo00[o0?oKo`1>ool0C_oof_l0o`3ogooWo`3o0000
onWo0?oooooojol00_ooool00oooj`3oooooobH0o`03ooooo`03obH0oooooooooooo00;ooooo0_l0
f_l00olJo`3oooooooooo`03ooooo`03o`2<oollo`3ooooo00?ooooo00?o@ol0of[o0?ooool01?oo
ool00ol0003oooooooooo`07ooooo`03oiSo0?oooooooooo00Oooooo00?o0?m1ooooooooool05Ooo
ool00ol07oooooooooooo`03ooooo`03o`000?oooooooooo08;ooooo001dooooo`;o0?3o3Oooool2
o`3o^0gooooo0_l0YOl01OooooooHol0ooooooooooooDol000Cooooo00?o0?mNooooooooool04_oo
ool00ol0003oooooooooo`05ooooo`05o`3o1?ooooooooooooooool0olL00oooool00oo8o`3o`Ol0
ooooo`0<ooooo`05o`04ooooooooooooooooool0Jol01?ooool00ol0jooo0?lcooooo`03ooooo`09
o`3ofooWo`3o04koo`3ogooYo`3oooooon_o0?l0onSoon/000Gooooo00Go9P3ooooooooooooo9P3o
o`3Jo`05ooooo`03oa[o0?oooooooooo00?ooooo00Oo??l0o`2<ool0oeco0>7oooooool0003o@ol0
00Cooooo00?oJ_l0ooooooooool02Oooool00onHo`3oooooooooo`0>ooooo`03o`3o@Ooooooooooo
01Sooooo00?o01ooooooooooool01Oooool00ol0003oooooooooo`1Tooooo`?o0?3o3?ooool2o`3o
^0Wooooo00GoHol0oooooooooooooooooe?o0002o`2Uo`03o`3oG_oooooooooo01Oooooo00?o09Go
ooooooooool00_ooool01?l0o`Coooooo`3oaol0000:ooooo`04olSo0?o1o`3ooooool7o00gooooo
00Go00Coooooooooooooooooo`1[o`02ooooo`03o`3o<ol0jooooooo00?ooooo0_l0C_l03?l0om_o
ooooom[o0?ooooooiol0oooooooYo`3o0000o`3oj?o[o`3oooooooo[00?ooooo00Ko9P3ooooooooo
ooooooooobH0ooooool2o`3Jo`;ooooo00?o6_l0ooooooooool00_ooool00ol0oeco0>7oocco0004
ooooo`03od?o0?oooooooooo00Cooooo00?o0000ooooooooool01oooool00onHo`3oooooooooo`07
ooooo`03o`3o@Ooooooooooo01Gooooo00?o01ooooooooooool01?ooool00ol0003oooooooooo`21
ooooo`00M_ooool3o`3`o`cooooo00?o0?nhooooooooool03?ooool00ol0YOooooooof?o0002oooo
o`03oe?o0?oooooooooo00;ooooo00?o0?mNooooooooool04Oooool00ol0003o09Goooooo`06oooo
o`04o`3o1?ooooooooooooooo`;o0?o700?oooooolSo0?o1o`000_ooool00ol0003oN_l0ooooo`08
ooooo`05o`04ooooooooooooooooool0Jol00oooool01?l0joooooooooooool0oc<3ooooo`04onOo
0?l0C_ooooooonWo00;ooooo00?ojol0ooo[0?ooool01Oooool01OlV0?oo0=[oo`3Joooooooo9P3o
00Gooooo00?o6_l0ooooooooool00oooool00ol0S?oo??l0o`3Qo`02ooooo`03o`000?m3o`3ooooo
00;ooooo00?oJ_l0ooooooooool02_ooool00onHo`3oooooooooo`0>ooooo`03o`3o@Ooooooooooo
01Oooooo00?o01ooooooooooool01oooool00ol0003oooooooooo`0kooooo`?o09Wo:?ooool2o`3`
o`cooooo0_l0okP8ooooo`06of?o0?oooooooooooooooomCo`3ooooo0_l0YOlIooooo`03o`2Eoooo
oooooooo00;ooooo00?o0?l4ooooool000000_l0olL4ooooo`08o`000?mjo`3oN_l0ooooooo8o`3o
`Ol0ooooooo1o`0<ooooo`03o`04oooooooooooo00;ooooo00Go06_ooooooooooooo0>_oo`3o<`02
ooooo`;o04ko00Koooooo`3ofooooooof_l0oooooooWo`02ooooo`05onWo0?oooooojol0oooooooo
j`001?ooool00olV0?ooooooooooo`03o`3Jo`Cooooo00?o6_l0ooooooooool00_ooool00ol0S?oo
0>7oocco0004ooooo`03od?o0?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00onHo`3o
ooooooooo`07ooooo`03o`3o@Ooooooooooo01Gooooo00?o01ooooooooooool01Oooool00ol0003o
ooooooooo`21ooooo`00NOooool2o`3`o`_ooooo0_l0okP=ooooo`;o0:Go00CoHol0oooooooooooo
Dol01?ooool00ol0oekoooooooooo`0@ooooo`03o`000?oooooo09Go00Oooooo00?o0?l4oooooooo
ool00_ooool00ol0olOob?l0ol7o0002ooooo`03o`000?mjo`3ooooo00Oooooo00Go00Cooooooooo
ooooooooo`1[o`04ooooo`0:o`3[ooooooooooooooooool0oc?o04koo`3ofooWo`3oooooonWo00;o
oooo00?ojol0o`3oj?ooj`001Oooool00ol0f_oo9P3oooooo`02ooooo`03obH0ool0003ooooo00Co
oooo00So6_l0ooooooooooooooooo`2<oooooooo??l0o`3Qo`;ooooo00?o0000od?o0?ooool00_oo
ool01?mZo`3oooooooooooooool2o`0000Oooooo00?oV?l0ooooooooool03Oooool00ol0od7ooooo
ooooo`0Gooooo`03o`0Ooooooooooooo00Wooooo00?o0000ooooooooool0?Oooool3o`2IobOooooo
0_l0l?l<ooooo`;o0?nh1oooool01OmSo`3oooooooooooooooooDol000;ooooo00?o0:Gooooooooo
ool05oooool00ol0UOooooooooooo`02ooooo`04o`3o1?l0003oooooooooo`;o0?o70_ooool2o`00
0006oooooomjo`3ob?l0ol7o0?oooooo`Ol03?ooool01Ol01?oooooooooooooooooo06_o00?ooooo
00Co0>_oooooool0oc?o04ko0oooool02ol0om_oooooom[o0?oWo`3o0?oOoooooooYo`3oooooon_o
0?l0003oon/000Kooooo0_l0f_l00ooooooo9P3oooooo`05ooooo`07oa[o0?ooooooooooo`2<ool0
oeko0>7oocco0003ooooo`03of[o0?m3o`3ooooo00Gooooo00?o0000ooooooooool01_ooool00onH
o`3oooooooooo`06ooooo`03o`3o@Ooooooooooo01Gooooo00?o01ooooooooooool01oooool00ol0
003oooooooooo`20ooooo`00E_ooool3o`2Iob;ooooo0ol0l?l:ooooo`;o0?nh3Oooool2o`2Uo`;o
oooo00?oDol0ooooooooool00_ooool00ol0oekoooooooooo`0?ooooo`04o`000?ooooooooooo`2E
o`Oooooo00?o0?l4ooooooooool00_ooool2ol7o00Cooooo00?oN_l0ooooooooool01Oooool01Ol0
1?oooooooooooooooooo06_o00Cooooo00Oo0>_oooooool0C_oo04koooooool0oc?oiol000;ooooo
00GojOl0oooooooooooojol0ooo[0004ooooo`;o0=[o0_ooool01_lV0?oooooooooooooooooo9P3o
o`0000Cooooo00Co6_l0oooooooooooo08co0_ooool01_llo`3o0>7ooooooooooooo0000od?o00;o
oooo00?oJ_l0ooooooooool00_ooool00ol0003oood0ooooo`05ooooo`03oiSo0?oooooooooo00go
oooo00?o0?m1ooooooooool05oooool00ol07oooooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo0ol0VOlVooooo`?o0?3o2oooool00ol0okSoooooooooo`05ooooo`05of?o0?oooooooooooooo
oomCo`000_ooool2o`2UoaSooooo00?o09Goooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`3oaooooooooooo00?ooooo00Cob?l0ol7o0?oooooo`Ol02oooool00ol01?ooooooooooo`02
ooooo`04o`1[ooooooooooooo`3[o`;o04ko00goooooo`3o<oooooooooooo`3ofooooooof_l0oooo
oooWo`3oooooonWo0?oooooojol000;ooooo00?oon/0ooooooooool00_ooool2o`3Jo`05obH0oooo
oooooooooooooolV0?l01Oooool03?lJo`3oooooo`2<ool0oeco0>7ooooooollo`3oooooo`000?mZ
o`3ooooood?o00Kooooo00?o0000ooooooooool01_ooool00onHo`3oooooooooo`05ooooo`03o`3o
@Ooooooooooo01Gooooo00?o01ooooooooooool02?ooool00ol0003oooooooooo`20ooooo`00FOoo
ool3o`2IoaKooooo0_l0P?l:ooooo`;o0?3o2_ooool2o`3o^0gooooo0_l0YOl00oooooooDol0oooo
o`03ooooo`03o`3oG_oooooooooo00kooooo00Go0000ooooooooooooooooo`2Eo`07ooooo`04o`3o
1?ooooooooooooooo`;o`Ol00_l0olL2ooooo`03og[o0?oooooooooo00Cooooo00?o00Cooooooooo
ool00_ooool01Ol0Jooooooooooooooooooo0>_o00;o04ko0oooool01?l0om_oiol0o`3o<ooYo`02
ooooo`03on_o0?ooj`3ooooo00?ooooo00?o0=[oooooooooool00_ooool01_lV0?oooooooooooooo
oooo9P3oo`0000Gooooo00?o6_l0o`2<ooooool00_ooool01_llo`3ooooooooooooooooo0000od?o
00;ooooo00?oJ_l0ooooooooool00oooool00oooo@3oooooooooo`04ooooo`03oiSo0?oooooooooo
00cooooo00?o0?m1ooooooooool06?ooool00ol07oooooooooooo`0;ooooo`03o`000?oooooooooo
04;ooooo0ol0VOlCooooo`;o083o4Oooool2o`3`o`[ooooo0_l0okP6ooooo`05of?o0?oooooooooo
oooooomCo`000_ooool00ol0oeko0:Goo`2Uo`0Fooooo`03o`2Eoooooooooooo00;ooooo00?o0000
o`3o1?ooool00oooool2o`3oa`?ooooo00Cob?l0ol7o0?oooooo`Ol02oooool01_l01?oooooooooo
oooooooo06_oooooo`;o04ko00?o0>_oooooooooool00_ooool02?l0oc?o0?oKoooooooJo`3ooooo
onOo0?oooooojOl00_ooool01_o[o`3oooooooo[0?oooooo0000ooooo`;o0=[o0_ooool01OlV0?oo
oooooooooooooooo9P3o00Gooooo00co6_l0o`2<oooooooo0?mNo`3Qoooooooo??l0ooooool0003o
J_l0oooooom3o`06ooooo`03o`000?oooooooooo00Kooooo00?oV?l0ooooooooool01?ooool00ol0
od7oooooooooo`0Fooooo`03o`0Ooooooooooooo00Wooooo00?o0000ooooooooool0Ooooool005co
oooo0ol0VOlEooooo`;o083o2_ooool3o`3`o`Wooooo00?o0?nhooooooooool02oooool01?mSo`3o
0:Goo`2UoomCo`04ooooo`03o`3oG_oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0
UOooooooooooo`05ooooo`03o`3o1?oooooooooo00;o`Ol00_ooool2o`3oa`03og[o0?oooooooooo
00Cooooo00Go00Coooooooooooooooooo`1[o`04o`000003o`3[oooooooooooo00?ooooo00Soiol0
oooooooooooojOl0ooooooo[o`3o0?oXooo[00;ooooo0_l0f_l6ooooo`06obH0oooooooooooooooo
oolV0?oo00001?ooool01_l0S?oooooooooooooooooo0?mLocco00?ooooo00Co0000od?o0?oooooo
J_l01_ooool00oooo@3oooooooooo`04ooooo`03oiSo0?oooooooooo00cooooo00?o0?m1oooooooo
ool05?ooool01?l0ogoo0000ooooool07ol?ooooo`03o`000?oooooooooo04Cooooo1?l0VOlAoooo
o`;o083o4Oooool2o`3`o`[ooooo0_l0okP5ooooo`05of?o0?oooooooooooooooomCo`000_ooool0
0ol0oekoooooo`2Uo`0Fooooo`07o`2Eooooooooooooooooool0003oooooo`3o1005ooooo`;o0?o7
00CoooooolSo0?o1o`3o`Ol02oooool00ol01?oo0000o`000002o`000004o`1[ool0C_ooooooo`3[
o`Kooooo00_o0?oKom[o0?ooooooiol0o`3ogooooooojOl0ooooooo[o`3oooooooo[0002ooooo`;o
0=[o1Oooool01?lV0?oooooooooooolV0?l5ooooo`0<o`2<oolJo`3oooooo`3oG_l0hOooooooocco
0?ooooooJ_l0ooom0?oooooo@ol01_ooool00ol0003oooooooooo`06ooooo`03oiSo0?oooooooooo
00Cooooo00?o0?m1ooooooooool05Oooool00ol07oooooooooooo`0:ooooo`03o`000?oooooooooo
07oooooo001Oooooo`?o09Wo5?ooool2o`20o`_ooooo0_l0l?l8ooooo`;o0?nh3?ooool00omSo`3o
ooooo`2Uo`02oe?o00?ooooo00?o0?mNooooooooool03?ooool00ol0003oooooooooo`03ooooo`03
o`2Eoooooooooooo00Gooooo00Co0?l4ooooooo1o`3o`Ol01?ooool00ol0olOoN_l0ooooo`03oooo
o`03o`04oooooooooooo00;o000000Go06_oo`000?l0ohSo0000o`3[o`05o`000009onOo0?l0003o
ooooonWo0?oooooo0?lcon_o0?ooj`3ooooo00;o0=[o2?ooool01olV0?oooooooooooooooooo9P3o
ooooool000000_ooool00ol0S?oo6_l0ooooo`02ooooo`03o`3oG?llo`3ooooo00;ooooo00Co0000
od?o0?ooooooJ_l01_ooool00oooo@3oooooooooo`04ooooo`03oiSo0?oooooooooo00_ooooo00?o
0?m1ooooooooool05Oooool00ol0ogoo0000o`0Oo`0Aooooo`03o`000?oooooooooo03[ooooo0ol0
U?l:ooooo`?o09Wo4?ooool2o`20oa7ooooo0ol0l?l9ooooo`03o`3o^?oooooooooo00?ooooo0_mS
o`02ooooo`05oe?o0?ooooooooooo`3oG_ooool00_l0YOlEooooo`04o`2Eooooooooooooo`0000;o
oooo00?o0?l4ooooooooool01?ooool01Ol0olOob?l0ol7o0?o1o`3oN_l000Sooooo00?o0000o`0B
ool01?l00ol000001Ol0Jooo0000o`000?l0003o0>_o00;o00000oooool02Ol0om_oooooo`3o<ooo
ooooiol0oooooooYo`3oooooon_o0002ooooo`05ooo[0?l0f_oo0=[oooooool000001Oooool01OlV
0?oooooooooooooooooo9P3o00?ooooo00Go08cooooooolJo`3o0?mLo`3Qo`02ooooo`06occo0?mZ
o`3oooooooom0?oooooo@ol01_ooool00ol0003oooooooooo`05ooooo`03oiSo0?oooooooooo00Co
oooo00?o0?m1ooooooooool05Oooool00ol07ooo0?moo`00000<ooooo`03o`000?oooooooooo07ko
oooo001Rooooo`?o09Wo4oooool2o`20o`_ooooo0_l0l?l8ooooo`;o0?nh2oooool2of?o00;o0:Go
00GoDol0ooooooooooooooooo`3oGP0<ooooo`03o`000?oooooooooo00Gooooo00?o09Gooooooooo
ool01Oooool00ol0o`Co`Ol0ol7o0005ooooo`;o0?o70oooool01Ol01?ooooooo`000?l0003o06_o
00;o0?nQ00?o0?n8o`3oXOl0jol00_l000002_nno`3o0000o`000?oWo`3o0000onWo0?l0omoo0000
on_o0?ooj`02o`3Jo`[ooooo00Go9P3oooooooooooooooooobH0o`02ooooo`05o`000?oooooo08co
oooooolJo`000_ooool00ol0hOoo??l0ooooo`02ooooo`03o`000?m3o`3oJ_l000Oooooo00?oood0
ooooooooool01?ooool00onHo`3oooooooooo`0:ooooo`03o`3o@Ooooooooooo01Gooooo00?o0?mo
ooooool07ol04_ooool00ol0003oooooooooo`0mooooo`?o09Co2_ooool3o`2Io`Gooooo0_l0E?l8
ooooo`;o083o4_ooool2o`3`o`Sooooo0_l0okP5ooooo`03of?o0?oooooooooo00;oDol000Cooooo
o`3oG_oooooooooo0_l0YOlDooooo`03o`2Eoooooooo000000?ooooo00?o0?l4ooooooooool01?oo
ool01Oo8o`3o`Ol0ol7o0?ooooooN_l000Oooooo00Co0000o`04ool0003o00000_l0oj401_l0Jooo
0?nQo`000?l0jooo__l0ooooo`Co000000Ko0?oKom[o0?ooooooiol0o`3ogooYo`02ooooo`03on_o
0?l0f_ooon/000Gooooo00?o0000ooooooooool00_ooool01OlV0?oooooooooooooooooo9P3o00;o
oooo00Ko08cooooooooooooo6_l0o`3oG_l0hOl2ooooo`06occo0?mZo`3oooooooom0?oooooo@ol0
1_ooool00ol0003oooooooooo`05ooooo`03oiSo0?oooooooooo00?ooooo00?o0?m1ooooooooool0
5_ooool00ol07ooo0?moo`00000=ooooo`03o`000?oooooooooo07gooooo001Uooooo`Co09Wo1_oo
ool2o`1Do`Wooooo0_l0P?l;ooooo`?o0?3o1oooool2o`3o^0_ooooo00CoHol0ooooool0YOoo0:Go
0oooool00ol0oekoooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o09Goooooooooool0
1Oooool2ol7o00Gooooo00KoN_l0ooooool0olOo0?o7ooooool01?l3o`000006o`1[oooooooo0?n8
o`000?l0jooo__l01?l000002?oWo`3o0000o`000?oYo`3o0000on_o0?l0f_ooon/00_l0oc<;oooo
o`05obH0oooooooooooooooooolV0?l00_ooool02?l0S?oooooooooooolJo`3oooooo`3oG?l0hOoo
??l00oooool00ol0003o@ol0of[o0007ooooo`03ooom0?oooooooooo00Cooooo00?oV?l0oooooooo
ool02Oooool00ol0od7oooooooooo`0Eooooo`04o`3oOoooooooooooo`0Ooa?ooooo00?o0000oooo
ooooool0?oooool3o`2Do`[ooooo0ol0VOl4ooooo`;o05Co2?ooool3o`20oa7ooooo0_l0l?l8oooo
o`;o0?nh1?ooool01omSo`3oooooooooooooooooDol0ooooool0oeh00oooool2o`2Uoa?ooooo00?o
09Goo`000?ooool00oooool00ol0o`Coooooooooo`03ooooo`06olSo0?o1o`3o`Ol0o`3oaooooooo
N_l01oooool02Ol01?oo0000oooooooooooo06_oo`000?nno`3o0000o`3[o`02o`00000>o`3mool0
003oooooo`3ofooJo`3o0000onOo0?l0omooooooonWo0?oooooojol0o`3Jooooj`07ooooo`03o`00
0?oooooooooo00;ooooo00Ko9P3ooooooooooooo9P3oooooool0S?l4ooooo`05o`3oG_l0hOoooooo
oooooollo`000_ooool00oooo@3ooooood?o0007ooooo`03o`000?oooooooooo00Cooooo00?oV?l0
ooooooooool00_ooool00ol0od7oooooooooo`0Fooooo`03o`0Oool0ogoooooo00kooooo00?o0000
ooooooooool0OOooool005Sooooo0ol0U?l>ooooo`?o09Wo1Oooool2o`1Do`Wooooo0_l0P?l<oooo
o`;o0?3o1oooool00ol0okSoooooooooo`09ooooo`03of?o0?oooooooooo00;o0:Go0_ooool00ol0
oekoooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o09Goooooooooool01?ooool2ol7o
00Kooooo00CoN_l0oooooooooooo00Co0_l000001ooooooo06_oo`3oXOl0ohSo0=Coo`000?l0jol0
0_ooool02ol04_oo__l0onOo0?l0om_oooooonWo0?l0omoo0=[oon_o0?ooj`3ooooo00;o000000?o
0?lcooooooooool02?ooool02OlV0?oooooooooooooooooo9P3oooooool0S?ooooooo`000002oooo
o`04oa[o0?l0oeco0>7oocco00?ooooo00?o0000od?o0?ooool01oooool00oooo@3oooooooooo`03
ooooo`03oiSo0?oooooooooo00[ooooo00Co0?m1oooooooooooooooo0_l0000Aooooo`04o`3oOooo
ooooooooo`0OoaGooooo00?o0000ooooooooool0@Oooool3o`2Do`[ooooo1?l0VOl2ooooo`;o05Co
2Oooool2o`20oa7ooooo0ol0l?l7ooooo`;o0?nh0oooool01omSo`3oooooooooooooooooDol0oooo
ool0oeh01?ooool00ol0YOooooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0?l4oooo
ooooool00oooool3ol7o0004ooooool0olOo0?o7og[o00Gooooo00_o00Coo`000?l0oj7o01;oo`3o
R?l0Jooo__l0ooooool0jooooooookko0002o`0000;o_Ol000_o0?oKooooool0003oiol0o`3ogooY
o`3o0=[oon_o0?l0onSoooooooo[0008ooooo`05o`000?oooooooooooooooolV0?l00oooool00olV
0?ooooooooooo`02ooooo`06o`3oG?l0hOoooooooooooomZo`3o??l00_ooool00oooo@3ooooood?o
0007ooooo`03o`000?oooooooooo00Cooooo00GoV?l0ooooooooooooooooo`3o@@0Hooooo`03o`0O
ool0ogoooooo013ooooo00?o0000ooooooooool0O?ooool005_ooooo0ol0U?l>ooooo`?o09Wo1?oo
ool3o`1Do`Sooooo0ol0P?l;ooooo`?o0?3o1Oooool2o`3o^0[ooooo00CoHol0ooooooooooooDol0
0_l0YOl00ooooooo0?mNooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o09Goooooooooool0
1?ooool2ol7o00Kooooo00CoN_l0ooooool0003o00Co0_l0olL01ooooooo06_oo`3oR?l0oj7o0=Co
o`3[oonno`000oooool01?nno`3oiol0o`000?oYo`02o`3Jo`05on_o0?l0oOooon/0o`000?ooool0
0_l000000ol0oc?oooooooooo`08ooooo`05obH0oooooooooooooooooolV0?l00_ooool01ol0003o
oooooooooolJo`3o0?mNo`3Qoollo`000oooool00ol0003o@ol0ooooo`07ooooo`03ooom0?oooooo
oooo00?ooooo00?oV?l0ooooooooool02Oooool01Ol0od7ooooooooooooooooo0?om00;o00004?oo
ool01?l0ogooooooooooool07olFooooo`03o`000?oooooooooo04Cooooo1?l0U?l:ooooo`?o09Wo
00Coooooo`1Dool0E?oo05Co2?ooool2o`20oa;ooooo0_l0l?l7ooooo`05o`3o^?oooooooooooooo
oomSo`000oooool00omCo`3oooooo`3oGP04ooooo`;o0:Go4Oooool00ol0003o09Goooooo`03oooo
o`03o`3o1?oooooooooo00;ooooo0oo1o`03ooooo`;o0?o70oooool03Ol0003o00Coo`000?oooooo
0?nQo`1[ool0e?oo__l0ooooool0jooooooookko0?l0oOl00_l09_l02ol0om_o0000o`3moooWo`3o
0?oOonWo0?l0f_ooooooon_o0?l0oc?oon/000Wooooo00Go0000ooooooooooooooooobH0o`02oooo
o`03o`2<oolV0?oooooo00?ooooo00Ko0?mNo`3Qooooooooooooof[o0?llo`03ooooo`03ooom0?m3
o`3ooooo00Kooooo00?o0000ooooooooool01?ooool01OnHo`3ooooooooooooooooo0?m100_ooooo
00?o0?omo`000?l000002Oooool00ol07ooo0?moooooo`0Aooooo`03o`000?oooooooooo07cooooo
001Nooooo`?o09Co3_ooool3o`2Io`Cooooo0_l0E?l9ooooo`;o083o3?ooool2o`3`o`Gooooo0_l0
okP9ooooo`05of?o0?oooooooooooe?o0?ooool00_l0YOl00ol0oekoooooooooo`06ooooo`03o`00
0?oooooooooo00Sooooo00?o09Goooooooooool00oooool2ol7o0003o`3o1?oooooooooo00?ooooo
00?oN_l0o`000?l01?l00oooool04_l0olOo06_ooooooooooooo0?nQo`3[oooooooo__l0okgo0?l0
9_ooiol0o`3ofol0f_oojOl0o`3ogoo[o`3o0?goooo[00Ko000000?o0?lcooooooooool01oooool0
1OlV0?ooooooooooool0S?oo9P3o00?ooooo00Ko0000ooooool0oeco0>7ooooooollo`03ooooo`03
o`000?m3o`3ooooo00Oooooo00?oood0ooooooooool00oooool00onHo`3oooooooooo`08ooooo`03
o`3o@Ooooooooooo00;o0?om4_ooool01?l0ogooooooooooool07olHooooo`03o`000?oooooooooo
04Oooooo0ol0U?l:ooooo`?o09Wo00?oooooo`1Dool0E?l02?ooool2o`20oa;ooooo0ol0l?l5oooo
o`;o0?nh0_ooool01omSo`3oooooooooooooooooDol0ooooool0oeh01Oooool2o`2Uo`oooooo00?o
0000ooooool0UOl01?ooool01?l0o`Coooooooooooooool3ol7o00Gooooo0_l0olL02ol0003ooooo
o`04oooooooo0?n8ooooool0Jooo01;oooooool0jooooooo00?o02Ko00go0?nQo`3ofol0003o0000
onOo0?l0f_oojOl0o`000?oooooojol0o`000?ooj`3o0?lc00[ooooo00So0000oooooooooooooooo
obH0ool0S?ooooooobH0o`Cooooo00Ko0?mNo`3QoolJo`3oJ_l0oooooollo`03ooooo`03ooom0?m3
o`3ooooo00Kooooo00?o0000ooooooooool00oooool01OnHo`3ooooooooooooooooo0?m100[ooooo
0_l0ood00ooooooo0000o`000009ooooo`03o`0Oool0ogoooooo01;ooooo00?o0000ooooooooool0
Noooool0067ooooo1?l0U?l=ooooo`?o09Wo0oooool2o`1Do`Wooooo0_l0P?l<ooooo`?o0?3o1?oo
ool2o`3o^0Sooooo00CoHol0ooooooooooooDol00_ooool00ol0YOoo0?mNooooo`06ooooo`03o`00
0?oooooooooo00Wooooo00?o09Goooooooooool00_ooool2ol7o0003ooooool0o`Cooooo00?ooooo
00Co0000of?o0?l01?oo08[o0_ooool01_l0Joooooooo`3oaol0e?oo0?nQo`3[o`?o02Ko00kooooo
onOo0?l0f_oojOl0o`3ogol0oOoojol0ooo[0?l0onSo0?goo`000?o<o`3o0000ooooo`;o000000?o
0?lcooooooooool01_ooool01OlV0?ooooooo`2<oooooooo9P3o00Cooooo00Go0000o`3oG?l0hOoo
ooooocco0002ooooo`03of[o0?l0003o@ol000Sooooo00?oood0ooooooooool00oooool00onHo`3o
ooooooooo`07ooooo`04o`3o@Ooooooo0?omo`3ooA?ooooo00Co0?mooooooooooooo01oo6_ooool0
0ol0003oooooooooo`0iooooo`;o08oo0_l0000<ooooo`?o09Co2_ooool3o`2Io`;o05Co2?ooool2
o`20oa?ooooo0_l0l?l5ooooo`;o0?nh00?oooooof?o0?ooool00_ooool00omCo`3oooooo`3oGP06
ooooo`;o0:Go3Oooool00ol0003oooooo`2Eo`05ooooo`03o`3o1?oooooooooo00?o`Ol01_ooool2
of?o000Ko`04ool0003o0?n8ooooool0Jooo0=Coo`3oXOl09_oo0>_oo`0Voooooooo0?gookko0?l0
2Ooo0?oKo`3JoooWo`3o0000o`3ogooYo`3o0000on_o0?l0onSoon/0o`000?oooooo0?lc00[ooooo
00Co0000oooooooooooo9P3o0oooool01olV0?ooooooooooool0oeco0>7ooooooolJo`000_ooool0
1_llo`3oooooooooooooooooood0od?o00Oooooo00?o0000ooooooooool00oooool01?nHo`3ooooo
ooooool0od4:ooooo`03o`3ooOoooooooooo00_ooooo00?o01ooo`3oOoooool04oooool00ol0003o
ooooooooo`1kooooo`00Eoooool00ol0003oob/0ool[000;ooooo`?o09Co3Oooool4o`2Io`03oooo
ool0E?oo05Co00Wooooo0_l0P?l=ooooo`;o0?3o1?ooool00ol0okSoooooooooo`06ooooo`04of?o
0?oooooooooooe?o00;ooooo0_l0YOl6ooooo`03o`000?oooooooooo00[ooooo00Co09Gooooooooo
oooob?l00_o1o`02ooooo`03o`3o1?oooooooooo00;o000000Co00Coo`000?mSo`3oHol00_l00002
ooooo`03o`0Vool0jooo02Ko00;o000000Wo0=[oonOo0?l0om_o0000onWo0?l0omoojol0o`000?oo
j`000ol00002olco0005o`3mool0003o0000o`000?l0oc<02?ooool01OlV0?oooooooooooooooooo
9P3o00Cooooo00Co0?mNo`3Qoooooooo??l00_ooool00omZo`3o0000od?o0008ooooo`03ooom0?oo
oooooooo00?ooooo00?oV?l0ooooooooool01_ooool00ol0od7oooooo`3oo@0Dooooo`05o`3oOooo
ooooooooooooool07ol06_ooool00ol0003oooooooooo`0kooooo`;o00000ooo:`0<ooooo`?o09Co
2_ooool3o`2Io`03o`1Doooooooooooo00Kooooo0_l0P?lCooooo`;o0?3o1Oooool00ol0okSooooo
of?o0003ooooo`03oe?o0?oooooo0?mN00Oooooo00?o0:Goooooooooool02_ooool01?l0003ooooo
ooooool0UOl5ooooo`03o`3o1?oooooo`Ol000;o`Ol01Oooool3o`000005o`04oomSo`3o08[ooooo
ool0Jol00_l09_l00ol0jooooooookko0002o`3mo`0=okko0?l0f_oo0=[oo`000?oWo`3o0?oOonWo
0?l0003ojol0o`3oj?l0003oon/0ooooo`02o`000003o`3o<ooooooooooo00Oooooo00Go0000oooo
ool0S?ooooooobH0o`02ooooo`07obH0ooooooooooooo`3oG_l0hOoooooooa[o0002ooooo`06occo
0?ooooooooooooooooooo@3o@ol01oooool00ol0003oooooooooo`03ooooo`03oiSo0?oooooo0?m1
00Wooooo0_l0ood=ooooo`03o`0Oool0ogoooooo01Gooooo00?o0000ooooooooool0N_ooool005Oo
oooo0_l000001Oooooooob/0ool[0?oo:`3o08oo00[ooooo0ol0U?l>ooooo`?o09Wo0_l0E?l9oooo
o`;o083o3Oooool2o`3`o`?ooooo0_l0okP7ooooo`04of?o0?oooooooooooe?o00?ooooo0_l0YOl4
ooooo`03o`000?oooooooooo00_ooooo00?o09Goooooooo8o`000_o1o`03ooooo`08o`3o1?l0003o
0000o`000?l01?ooooooo`000?l0ohP2o`000005o`2:ool0003o0000o`3[ool0olL00_l0f_l02OoW
o`3o0?oKo`0VoooYo`3o0?oOo`3mooo[o`3oon/0o`3oj002olco00;o000000Ko0?goo`000?l0oOoo
c?l0o`2:ool00002o`3o<`Gooooo00?o08coobH0ooooool00_ooool03_lV0?oooooooooooooooooo
0?mLo`3Qool0003o6_l0occo0?ooooooJ_l0ooooool0003o@ol02?ooool00oooo@3oooooooooo`03
ooooo`03oiSo0?oooooooooo00Kooooo0_l0oodEooooo`04o`3oOoooooooooooo`0Ooacooooo00?o
0000ooooooooool0=oooool2o`000003ool[0?oooooooooo00;ooooo00Co08ooool[0?oo:`3oob/0
3?ooool4o`2Do`Wooooo1?l0VOl7ooooo`;o083o4oooool3o`3`o`?ooooo0_l0okP01omSo`3ooooo
ooooooooooooDol0ooooool0oeh01oooool2o`2Uo`[ooooo00Go0000ooooooooooooooooo`2Eo`05
ooooo`04o`3o1?o1o`3o`Ol0ol7o00Cooooo0ol000000ol01?oo0?n8o`0Vo`02o`000005of?o0?l0
003o0000o`3[ool0oj400_l0oOl2o`3Jo`05o`3ofol09_ooiol0o`3moooYo`000_o<o`001_o[o`3o
0000ooo[0?o<o`3o_Ol0o`2:o`;o000000?o0?lcooooooooool01oooool01?l0S?oooooooooooolV
0?l3ooooo`09obH0oooooooo0?mNo`3QoomZo`3ooooooa[o0?oooooo??l000?ooooo00?oood0od?o
0?ooool01_ooool00ol0003oooooooooo`03ooooo`03oiSo0?oooooo0?m100Oooooo0_l0ood>oooo
o`03o`0Oool0ogoooooo01Oooooo00?o0000ooooooooool0NOooool005Cooooo00?o0000ool[0?oo
:`001_ooool2ool[00;o08oo2_ooool4o`2Do`gooooo0ol0VOl2o`1Do`Sooooo0_l0P?l=ooooo`?o
0?3o0_ooool2o`3o^0Kooooo00CoHol0ooooooooooooDol00oooool00ol0oeko0:Goo`2Uo`02oooo
o`03o`000?oooooooooo00cooooo00Co09GoolSo0?o1o`3o`Ol00oooool01Ol0003o0?l4o`000?oo
oooo00Co00;o000000Co02Koo`07ooooooooHol00_l00002o`3Jo`0<o`2:ool0oj7oiol0o`3ofooY
o`3o__l0o`3ogoo[o`3oon/0o`3oj?nmo`3oc?l00_ooool00oo<o`3o0000okgo0002o`2:o`05o`3m
ool0003o0000o`000?l0oc<00oooool01?l0S?oooooooooooolV0?l3ooooo`0=obH0oooooooooooo
o`3oG?l0hOoooooooa[o0?llo`3oooooof[o0?oooooo0000od?o0008ooooo`03ooom0?oooooooooo
00;ooooo00?oV?l0ooooooooool01_ooool00ol0oogoooooooooo`0Dooooo`04o`3oOooooooooooo
o`0Ooakooooo00?o0000ooooooooool0=_ooool2o`000004oooooooo:`3oob/0ool[00Cooooo00?o
08ooool[0?oo:`003_ooool3o`2Do`Wooooo00Co05Coo`2Iool0VOoo09Wo1_ooool2o`20oaCooooo
0_l0l?l3ooooo`;o0?nh0oooool00omCo`3oooooo`3oGP08ooooo`;o0:Go2?ooool00ol0003ooooo
ooooo`02ooooo`03o`2Eoooooooooooo00?ooooo0oo1o`03ooooo`;o000000?oooooo`000?l01?l0
1?l000000ol0oOoo0000o`000002o`2:o`;o0=[o00_o0?goo`3ofoo<o`3oiol0o`3mool0omoojOl0
o`3mooo[o`3o0?oXooo[0002o`000003o`2:oooooooo000000;o000000?o0?lcooooooooool01Ooo
ool01Ol0S?ooooooo`000?oooooo9P3o00?ooooo00Co9P3oo`3oG?l0hOooJ_l00_ooool00olJo`3o
ooooocco0003ooooo`03ooom0?m3o`3ooooo00Kooooo00?o0000ooooooooool00oooool00onHo`3o
0?m1ooooo`06ooooo`03o`3ooOoooooooooo00kooooo00?o01ooo`3oOoooool05oooool00ol0003o
ooooooooo`1iooooo`00E?ooool2o`000004oooooooo:`3oob/0ool[00Gooooo0ooo:`02o`2?o`_o
oooo0ol0U?l=ooooo`?o09Wo00?o05Coooooooooool01_ooool2o`20o`kooooo0_l0l?l2ooooo`;o
0?nh1Oooool01?mSo`3ooooooooooomCo`03ooooo`05o`3oG_oooooo0:Goo`2Uool000003oooool3
ol7o00?ooooo00Ko0000ooooool0003o0000ooooool0oj42o`000003o`3oXOl0003o000000;o0=[o
00goHol0o`0Vooooooooiol0o`3ofol0R_oojOl0o`3ogoo[o`3oc?l0ooo[0?l09_oo_Ol000;o0000
00?o_Ol0oonj0?l000000_l000002_o<o`3o0000o`3moooooooo2ol0o`000?l0oc?o0000ooooool0
S?l2ooooo`05obH0oooooooooooooooooolV0?l00_ooool01_l0oeko0>7oooooool0003o??l0of[o
00;ooooo00?o0000od?o0?ooool01oooool00oooo@3oooooooooo`02ooooo`03oiSo0?oooooooooo
00Cooooo0_l0oodFooooo`04o`3oOoooooooooooo`0Oob3ooooo00?o0000ooooooooool0<_ooool2
o`000003ool[0?oooooooooo00Cooooo0ooo:`04ooooo`?oob/000?o08ooooooooooool02oooool3
o`2Do`Wooooo00Co05Coo`2Iool0VOoo09Wo1Oooool3o`20oa?ooooo0_l0l?l3ooooo`;o0?nh0_oo
ool01?mCo`3oooooo`3oG_l0oeh8ooooo`;o0:Go1_ooool00ol0003oooooooooo`03ooooo`03o`2E
oooooooooooo00;ooooo0oo1o`02ooooo`;o000000Coooooo`000?l0003o02Ko0_l0oj401?l0003o
0?nQo`000?l00003o`3Jo`0Fo`3oXOl0R_oo0?oKokko0?o<o`3oiol0olco0?oYo`3o0?nQon_o0?l0
onSo0000ooo[0?oo^P3o0000oonj0?l0oOoo08[oooooool;o`3o0000o`3o<`Gooooo00Oo08cooooo
ooooooooooooo`000?oooooo9P3o00;ooooo00Co9P3oo`3oG_l0hOooJ_l00_ooool00olJo`3ooooo
occo0003ooooo`03od?o0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00onHo`3o0?m1
ooooo`05ooooo`;o0?om4?ooool00ol07ooo0?moooooo`0Iooooo`03o`000?oooooooooo07Sooooo
001Booooo`;oob/01_ooool3ool[00Gooooo0ooo:`02o`2?o`_ooooo1?l0U?l<ooooo`?o09Wo2?oo
ool2o`20o`kooooo0ol0l?l00ooooooo0?nhooooo`04ooooo`;oHol000?ooooooe?o0?ooool00_oo
ool01?l0oekoooooooooool0000?ooooo`?o`Ol00_ooool5o`000005o`3oXOl0ROoo0000o`07ool0
00000_l0f_l03_l0003o02Koo`000?mSo`3oooooonOo0?l0om_ojOl0o`2:ool0omoojol0ooo[0?l0
onSoc?l00ol000000ooo^P3oc?l0o`3oX@04o`000003o`3oHOl;o`3ooooo00;o000000?o0?lco`2<
ooooool00oooool01olV0?oooooooooooooooooo9P3oo`3oG?l0hOl00oooool01_llo`3oJ_l0oooo
oooooooo0000od?o00Sooooo00?oood0ooooooooool00_ooool00onHo`3oooooooooo`02ooooo`;o
0?om00?o0?m1ooooooooool05?ooool01Ol0ogoooooooooooooooooo01oo023ooooo00?o0000oooo
ooooool0<_ooool2o`000004oooooooo:`3oob/0ool[00Kooooo0_oo:`05ooooo`;oob/00_l0Sol=
ooooo`?o09Co2?ooool2o`1Do`?o09Wo1Oooool2o`20oa?ooooo0ol0l?l2ooooo`04o`3o^?oooooo
oooooe?o00;ooooo00?o0?mNooooooooool01oooool00ol0YOooooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00Co09Gooooooooooooob?l00oo1o`02ooooo`;o000000So0?nQo`000?l0003o
0?nQo`0Voooooooo00Ooo`0000;o0=[o0ol000001omSo`3o0?nQo`3ofol0R_ooiol0o`0VoooYo`00
0_nmo`001Oo[o`3o0000ooo[0?l0003o2ol000Go000000Go0?mQo`000?l0003o0?lco`000002oooo
o`03o`2<oooooooooooo00;ooooo00?o0000oooooolV0?l00oooool00olV0?oo0>7oooooo`03oooo
o`03oa[o0?llo`3ooooo00;ooooo00?o@ol0ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`03oiSo0?oooooooooo00?ooooo0_l0oodAooooo`03o`0Oool0ogoooooo01[ooooo00?o0000oooo
ooooool0N?ooool005;ooooo0_l00003ool[00Kooooo0_oo:`06ooooo`;oob/01?l0Sol;ooooo`?o
09Co3?ooool4o`2Io`Kooooo0_l0P?l?ooooo`;o0?3o0_l0okP5ooooo`03of?o0?ooooooDol000?o
oooo00?o0?mNooooool000000_l0YOl=ooooo`;o`Ol000?o09Goooooool0ol/00ol000001Ol09_oo
_Ol0o`29oooooooo0?oi00;o000000?o08Woo`000?lR0?l00_l000002OmSo`3oiol0o`000?oYo`3o
0?nQo`3ogoo[o`3oon/0o`3oj002o`2:o`;o000000Ko08[oo`_o0?l0oj7o00Wooonj0?l02Ol3o`00
00;o0?go00Coooooo`000?l0S?oo0?lc0_l00002ooooo`07obH0oooooooooooooooooolV0?oo0?mL
o`3Qo`03ooooo`06occo0?l0003oooooooooool0003o@ol02?ooool00oooo@3oooooooooo`02oooo
o`05oiSo0?ooooooooooooooool0ood00_ooool00ol0od7oooooooooo`0Cooooo`05o`3oOooooooo
ooooooooool07ol08_ooool00ol0003oooooooooo`0^ooooo`;o000000?oob/0ooooooooool01?oo
ool3ool[00Gooooo0ooo:`04ooooo`?oob/00_l0Sol=ooooo`Co09Co1_ooool2o`1Do`03ooooool0
VOoo09Wo00;o09Wo0oooool2o`20oaCooooo0_l0l?l01Ooooooo0?nho`3o^?ooooooDol000;ooooo
00?o0?mNooooooooool01oooool2o`2Uo`?ooooo00?o0000ooooooooool01Oooool00ol0UOoooooo
olSo0003ol7o0003ooooool0ol_o000000?o000000Co_Ol0o`000?l09_oo0?oi0_l000001_l0ROoo
0000o`000?l0oOoo0000of?o00;o000000coiol0o`3mool0omoojOl0o`2:ooo[o`3o0?oXooo[0?l;
o`3oc?l0o`_o0?l0oj45o`000006ooooool;o`3oooooo`3o<ol0003o08co1_ooool01_l0003o9P3o
oooooooooooo0?mLobH0o`Gooooo00?o6_l0occo0?ooool00_ooool00om3o`3oooooooooo`06oooo
o`06o`000?ooooooooooooooool0od7oV?l01?ooool00ol0oogoooooooooo`0@ooooo`03o`0Oool0
ogoooooo01cooooo00?o0000ooooooooool0Moooool005Oooooo0ooo:`05ooooo`?oob/01Oooool3
ool[0004ooooool0Sooo08ooo`2?o`_ooooo0ol0U?l;ooooo`;o05Co0ol0VOl5ooooo`;o083o3ooo
ool2o`3`o`;o0?nh1?ooool01?mSo`3ooooooe?o0?mCo`02ooooo`04o`000?ooooooooooooooo`;o
0:Go2oooool2ol7o0008ooooool0ol_oooooo`000?oooooo0000okgo0?l02Ol2o`000005o`29ool0
003o0000o`0Vool0onl00_l000003?l0ROooiol0o`000?l0003ojOl0o`3mooo[o`3ookX0ooo[0?l0
onSo0000o`_o00;o08[o0_l000001ol02Oooooooo`3oHOoo^P3oc?l0o`09ool0of400_l000001Ol0
oOoo08coo`3oHOl0of7o0?lc00;o000000?oooooobH0ooooool00_ooool00olV0?oo0?mNo`3Qo`03
ooooo`06of[o0?llo`3o0000ooooool0003o@ol02?ooool00oooo@3oooooooooo`02ooooo`04oiSo
0?oooooo0?omo`3oo@;ooooo00?o0?m1ooooooooool04oooool01Ol0ogoooooooooooooooooo01oo
02Cooooo00?o0000ooooooooool0;Oooool2o`000004oooooooo:`3oob/0ool[00Kooooo0_oo:`06
ooooo`;oob/01Oooool3ool[00;o08oo3_ooool3o`2Do`Gooooo0_l0E?l3ooooo`?o09Wo0_ooool2
o`20oaCooooo0_l0l?l01?mSo`3o0?nho`3o^?mCo`02ooooo`03o`3oG_oooooooooo00Sooooo0_l0
YOl00ooooooo0000ooooo`07ooooo`03o`2Eooo8o`3o`Ol000;o`Ol000Oo0?o;ooooool0003o0000
oooooonmo`3o00Wo00;o000000Ko00Ooo`000?l0003o0?o_ob80ool0ROl2o`00000:o`29ool0003o
iol0o`3moooo^P3ojOl0olco0?o[o`3o0?oXooo[00;o08[o0_l00002o`09o`05oonj0?l0R_oo00Wo
o`3oHOl000000ol0of400ol0S?oo0000o`000006ooooo`05o`000?lV0?ooooooo`3oG_lV0?l01Ooo
ool00olJo`3o??l0ooooo`02ooooo`03od?o0?oooooooooo00Kooooo00Ko0000oooooooooooooooo
o`3o@OnHo`02ooooo`;o0?om4oooool00ol07ooo0?moooooo`0Mooooo`03o`000?oooooooooo07Ko
oooo001Aooooo`;oob/01oooool2ool[00Kooooo0_oo:`06ooooo`;oob/00_ooool3o`2?o`_ooooo
1?l0U?l9ooooo`?o05Co0ol0VOl4ooooo`;o083o3oooool2o`3`o`;o0?nh0oooool01omSo`3ooooo
oooooomCo`3oooooo`000?l0oeh01?ooool2o`2Uo`Wooooo0_o1o`002?l0ol_oooooo`000?l0003o
00Wookgo0?l09_oooooo0_l000001Ol01ooo08Woo`1`ool0oOoo8P3o00;ooooo00Co0000onOo0?oo
^P3ojOl00_l000000oo[o`3oon/0o`3oj002o`29o`03okgo0?l02Ooo08[o00;o00000_l0R_l01?oo
oooookX0olco0?l02Ol3o`3oH@03o`2<ool0003o000000Ko000000Go9P3ooooooooooooo0?mLobH0
o`03ooooo`04of[o0?oooooo??l0ooooo`;o000000?o@ol0ooooooooool01_ooool01oooo@3ooooo
ooooooooooooV?l0ooooool0ood00oooool00ol0od7oooooooooo`0Cooooo`05o`3oOooooooooooo
ooooool07ol09Oooool00ol0003oooooooooo`0cooooo`?oob/01Oooool3ool[00Gooooo0ooo:`05
ooooo`;oob/01?l0Sol=ooooo`?o09Co1?ooool2o`1Do`Cooooo0ol0VOl00ooooooo083oo`20o`0D
ooooo`?o0?3o00Go0?nhoe?o0?ooooooooooo`3oGP0;ooooo`03o`2Uool0003ooooo00Sooooo00Ko
b?l0ol7o0?o1o`3o0?o;ooooool0o`@2o`000003okgo0?l0003o000000;o000000Co08Woo`3oY?l0
L?oo8P3o0_l000003_l0oOoookX0o`000?l0003oiol0o`000?oYo`3o0000on_o0?l0ROoo0?oXooo[
0?o<o`3o08[o0_l000001Ol0R_oooooooonj0?l0of7o00Wo00;o0?mQ0_l000000ol0S?oo0000o`00
0002o`0000Gooooo00Ko0000obH0oooooooo0?mNo`3QoolV0?l5ooooo`05occo0?oooooooooooooo
oom3o`002?ooool01_l0003oooooooooool0od7oV?l0ooooo`;o0?om5?ooool00ol07ooo0?mooooo
o`0Nooooo`03o`000?oooooooooo07Kooooo001Cooooo`?oob/01_ooool3ool[00Gooooo0ooo:`05
ooooo`?oob/00_ooool3o`2?o`cooooo0ol0U?l9ooooo`;o05Co00Coooooo`2Iool0VOoo09Wo0ooo
ool2o`20oa3ooooo00?o0?3oo`3o^?ooool00_ooool01omSo`3ooooooooooomCo`3o0000ooooool0
oeh01Oooool2o`2Uo`Oooooo00Co`Ol0o`3obooooooooooo0ol000002_nmo`3o0000o`000?nmo`3o
00Ooo`3oY?l0L?oo08Woo`3moolR0?l2oonj0009onOo0?l0oOoo0000onWo0?l0003ojol0ooo[0?l0
003o0?oX00;o00Wo00?o08Woo`2:ool0oj400_l0ROl02Ol0of7o0?nQo`2:oooo^P3o08[oo`3oHOl0
2Ooo08[oo`2<o`02o`3oX@Co00000_ooool01_l0003o9P3ooooooooooooo0?mLobH0o`?ooooo00Co
J_l0oooooollo`3o6_l00_l000000om3o`3oooooooooo`06ooooo`06ooom0?oooooooooooooooonH
o`3o0?om0oooool00ol0od7oooooooooo`0Dooooo`04o`3oOoooooooooooo`0OobOooooo00?o0000
ooooooooool0=Oooool2ool[00Kooooo0ooo:`05ooooo`?oob/01?ooool3ool[0004ooooool0Sooo
08ooo`2?o`gooooo0ol0U?l3ooooo`?o05Co1?ooool3o`2Io`;o083o5?ooool01?mSo`3o0?3oo`3o
^?l0okP2ooooo`03o`3oG_oooooooooo00Wooooo00?o0000o`2Uooooool01oooool01?o8o`3o`Ol0
o`3oboo1o`02ooooo`Ko000001Ko00Ooo`3oY?l0ROoo08Woob80oooo^P3o0?goo`_o0?l0oj?o4@3o
onOo0?l0003ojOl0o`000?l09_oojol0o`3oj?ooj`3o08Woo`2:ool0oj7o08Wo0_l0of401Ol0R_oo
okX0o`2:ool02Ooo0?mQ00;o0?nQ00?o08coo`000?l000000_l000000ooooooo0000o`000004oooo
o`05obH0ool0oeco0>7ooooooolV0?l01Oooool01_llo`3ooooooooooooooooo@ol0ooom00Sooooo
00Go0000o`3o@OooooooV?l0o`3oo@0Eooooo`03o`0Oool0ogoooooo023ooooo00?o0000oooooooo
ool0MOooool005Kooooo0ooo:`06ooooo`?oob/01Oooool3ool[00Gooooo0ooo:`02ooooo`Co08oo
2oooool3o`2Do`Sooooo0_l0E?l2ooooo`?o09Wo0_ooool3o`20o`oooooo0_l0okP00ol0l?oooooo
of?o0002ooooo`04o`000?ooooooooooo`3oGPKooooo00?o0:Goooooooooool01?ooool01?l0ol_o
`Ol0ooooooooool3o`000008o`0Vool0003o0000ooooool01ooo0?n8o`1`oooo^P02o`29o`09o`0V
oooWo`3o0?goo`3oXooYo`3o0?goon_o0?l0003oon/000Go000000Co_Ol0o`3oHOl0003o00000ol0
ROl01ooo^P3o08Woo`2:ool0R_oo08coo`3oXOooool01?l000000omEo`3o0?gookgo0002okgo0007
obH0oooooooo0?mNo`3QoolV0?ooooooof[o0002ooooo`05occo0?lJo`3oooooo`000?m3o`002?oo
ool01Oooo@3oooooo`3ooOl0oogoV?l000Cooooo00?o0?m1ooooooooool04oooool01Ol0ogoooooo
oooooooooooo01oo02Sooooo00?o0000ooooooooool0=_ooool3ool[00Kooooo0_oo:`06ooooo`;o
ob/01Oooool2ool[00;ooooo0ol0Sol=ooooo`Co09Co0_ooool2o`1Do`Gooooo1?l0VOlCooooo`03
of?o0?oooooo0?3o00;o0?nh00?oooooo`3oG_ooool02Oooool01?l0003oooooo`2Uool0YOl6oooo
o`04olSo0?l0ol_o`Ol0ol7o00;ooooo1_l000004Ol01ooookX0o`3moolR0?oo08Woo`000?l0oOoo
0?nSolco0?oWo`3o0?goolco0?oYo`3o0000on_o0?l0003oon/000?o000000Oo0?mQolco0?l0003o
0000o`29oooo^P3o08Wo00?o08[o00?o08coo`_o0?l000000_l00002ooooo`;o_Ol000?o0000oooo
ooooool00_ooool01?lV0?oo0>7ooooooolV0?l5ooooo`06occo0?oooooooooooooooom3o`3oood0
2?ooool01?l0003oooooo`3ooOnHo`0Eooooo`03o`0Oool0ogoooooo027ooooo00?o0000oooooooo
ool0MOooool005Wooooo0ooo:`06ooooo`;oob/01_ooool2ool[00Kooooo0_oo:`04ooooo`?o08oo
2oooool4o`2Do`Kooooo0_l0E?l3ooooo`?o09Wo0_ooool2o`20o`oooooo0_l0okP01Ol0l?ooHol0
ooooool0003oDol000;ooooo00?o0?mNooooooooool01?ooool2o`2Uo`?ooooo00?o0?o;ol7o0?o1
o`000_ooool3o`00000Bo`0Vool0oOoo0?goo`3oY?l01ooo0?n8o`1`ool0oOoo8P3oo`3mool0003o
iol0o`3moooYo`3o4@3oolco0?o[o`3oon/00ol000000ol0oj7o08[oo`3mo`04o`0000;o0?go00?o
0?nQoonj0?l0oj400_l000000ol0ROoo08[oo`2:o`02o`000004o`3mool0003o0000o`0000?o0?go
00Ko9P3oo`3oG?l0hOooooooobH0oomZo`03ooooo`05occo0?lJo`3oooooo`000?m3o`002?ooool0
1Oooo@3o0?omooooooooooooV?l000?ooooo00?o0?m1ooooooooool04oooool01Ol0ogoooooooooo
oooooooo01oo02Wooooo00?o0000ooooooooool0>Oooool3ool[00Gooooo0ooo:`05ooooo`?oob/0
1?ooool3ool[00;ooooo0ol0Sol>ooooo`?o09Co00?oooooo`1Dool0E?l01oooool3o`2Ioa7ooooo
00OoHol0ooooooooooooDol0o`3o^?l0l?oo0?mN00Wooooo00Co0000oooooooooooooooo0_l0YOl4
ooooo`05o`3oboo1o`3o`Ol0ol7o0?ooool01Ol000002?l0ooWo0?goo`3mool0oOoo073oob80ool0
oOoo08Wo0_l000001_l0oOooiol0olco0?oYo`3o5P3oon_o00;o000000Coon/0o`2:ool0oOoo0?n[
1?l00002o`3oX@04oonj0?l0of7o0000o`0000;o08[o0_l000000onmo`3o0000o`000005o`000004
oooooomZo`3o9P3oo`3Qo`;ooooo00?o9P3oooooooooool00_ooool01_llo`3o6_l0oooooooooooo
@ol0ooom00Oooooo00Go0?m1o`000?l0oogooooooiSo000Eooooo`03o`0Oool0ogoooooo02;ooooo
00?o0000ooooooooool0M?ooool005cooooo0_oo:`06ooooo`?oob/01Oooool3ool[00Gooooo0ooo
:`04ooooo`?o08oo3?ooool3o`2Do`Gooooo0_l0E?l4ooooo`Co09Wo0_l0P?l?ooooo`;o0?nh00Co
0?3oo`000?ooooooDol00_ooool00ol0oekoooooooooo`05ooooo`;o0:Go00Co0?o;ooooooo1o`3o
`Ol00_ooool4o`00000Co`3mool0ojCo00Ooo`000?l0ohSo073oob80ool0e?oo08[oonOo0?l0003o
08WoonWo0?o<o`3ojol0oaH0ooooj`3oHol0o`L0o`02o`000005okko0?l0of7o_Ol0o`0Vool0oj40
0_l000001?l0oj7o0?nVo`3oY_oo^P02o`000004o`_o0?l0003o2ol0o`_o00;o08[o0_l00003o`29
o`07o`000?lV0?oo0?mLo`3Qool0003o9P3oof[o0003ooooo`06occo0?oooooo6_l0o`000?m3o`3o
00001_ooool2o`3oo@?ooooo00CoV?l0oooooooooooo0?m15Oooool01Ol0ogoooooooooooooooooo
01oo02_ooooo00?o0000ooooooooool0>oooool2ool[00Kooooo0_oo:`06ooooo`;oob/01Oooool3
ool[00;ooooo1?l0Sol=ooooo`?o09Co0_l0E?l7ooooo`04o`20ool0VOoo09Woo`2Io`oooooo00Co
Hol0oooooooooooooooo0_l0okP00ol0l?ooooooooooo`06ooooo`03o`000?oooooooooo00?ooooo
00Go0:Gooooooooooooo0?o;olSo0003ol7o0004ooooool0003o0000o`0Vo`;o000000So0?goo`07
ool02Ooo0?o_ob80ool0oOoo02Koo`3mo`;o000000Soiol0o`3moooYo`3o0?mQoaH0ooo[o`3oHol0
ooo[00;o000000Co02Koo`3mool0oOoo0?nQ0ol000000ol0oOoookX0o`3oH@02o`0000;o0?go00?o
2ol0o`2:ool0R_l01?l00002o`3mo`;o000000?o0?mLo`3QoolV0?l00_ooool00olV0?oooooooooo
o`02ooooo`06occo0?lJo`3ooooooooooom3o`3oood01oooool01Ol0oogo0000ooooooooooooV?l0
01Cooooo00?o01ooo`3oOoooool08oooool00ol0003oooooooooo`1dooooo`00G_ooool3ool[00Ko
oooo0ooo:`05ooooo`?oob/01Oooool2ool[00Gooooo1?l0Sol;ooooo`?o09Co1?ooool3o`1Do`Go
oooo0ol0VOl00ol0P?ooooooooooo`0=ooooo`05o`3o^?l0003o0?3oo`3`oomCo`000_ooool2o`3o
GPGooooo0_l0ol/2o`2Uo`;o`Ol00_ooool01ol0003oc?l0o`000?l0003o0?goo`3oY?l01ol00_l0
oOl04_l0L?oo8P3oo`2:ool0003oiol0o`0VoooYo`3o4@3oo`3oYoo[o`3oon/0o`3oZ_l70?ooHol0
o`2:ool09_oo0000o`3oRP;o000000?o0?nQo`3oY_l0ojH00_l000002Oo<o`3ookX0o`3oZol02Ooo
_Ol0o`_o0?nmo`3o2ol0o`1Mo`02o`3mo`03o`_o0?l0003o000000?o2ol000Go9P3oo`3Qool0003o
0000obH0o`03ooooo`07occo0?oooooo6_l0o`000?m3o`3oooooo`000004ooooo`03o`3ooOoooooo
ood000?ooooo00?oV?l0ooooool0od405Oooool01Ol0ogoooooooooooooooooo01oo023ooooo0_l0
?_l00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03cooooo0ooo:`05ooooo`?oob/01Ooo
ool3ool[00Gooooo0_oo:`04ooooo`?o08oo3Oooool3o`2Do`03o`1Doooooooooooo00Kooooo00Co
083oo`2Iool0VOoo09Wo3Oooool01OmSo`3oooooooooooooooooDol000;o0?nh0_l0l?l4ooooo`03
o`000?oooooooooo00Gooooo00Co0:Goo`3obooooooob?l00oo1o`001?l0UOoo0000o`000?o<o`02
o`00000Do`3mool01ooo0?goo`1`oolR0?oo0000o`3mool0R_ooc?l0onOo0?lA0?oo08WoonWo0?oo
oooojol0okko0?ooj`3oHol0ooooool0oj44o`0000?o0?nV0_l000001_l0of7o00Woo`1Qoonmo`3o
0?goo`_o00;oaol000Co0?goo`_o0?l0003o00000ol;o`001Ol0ROoo0?mNo`3QoolV0?oo000000;o
oooo00Ko9P3oooooooooooooooooocco0?lJo`02ooooo`03od?o0?ooo@3ooooo00Cooooo0_l0ood0
1?oooooo0000oooooonHo`0Dooooo`03o`0Oool0ogoooooo01cooooo0_l00007ooooo`03o`000?oo
oooooooo07?ooooo001Qooooo`?oob/01_ooool2ool[00Kooooo0_oo:`05ooooo`?oob/01_ooool3
o`2?o`_ooooo1?l0U?l3ooooo`;o05Co1_ooool3o`2Io`;ooooo0_l000000omlo`3oooooooooo`07
ooooo`03o`000?l0okSooooo00;o0?3o0oooool01Ol0oekooooooooooooooooo0?o;00Cooooo00?o
0:Gool7o0?ooool01Ol000001Ol0oOoo0?oio`07ool;o`3o0?n800;o08[o00So00WoonOo0?l0oOoo
jOl0o`3moolA0?oojol0ooo[00Co0?n:00?oHol0o`3oR_l0oj400ol000001Ol0ojKoc?l0o`2:ool0
oj7ooooo00?o000000?o_Ol0o`09ool0GOl01Ol;o`000ol0GOoo0000o`000002o`2:o`07o`3oG?lV
0?oo0000o`_o0?mZo`3o9P3oo`000002ooooo`05occo0?ooooooooooo`000?m3o`000_ooool01?l0
003oooooo`3ooOl0ood3ooooo`03ooom0?ooooooV?l000;ooooo00?o0?m1ooooooooool04_ooool0
0ol0ogooooooooooo`02ooooo`03o`0Ooooooooooooo01cooooo0_l0?_l00ooooooo0000o`00000:
ooooo`03o`000?oooooooooo03oooooo0ooo:`05ooooo`?oob/01Oooool3ool[00Cooooo0ooo:`04
ooooo`?o08oo3Oooool3o`2Do`03o`1Doooooooooooo00Gooooo0_l0P?l4o`2Io`Wooooo0_l00000
1Omlo`3ooooooooooomCo`3ooooo00;o0?nh0_l0l?l2ooooo`03o`000?oooooooooo00Gooooo00Co
0?o;ooooool0YOoo0:Go0oo1o`02o`000007olco0?l0003o0000o`000?l01ooo0?n8o`3ok`02o`3m
o`;o08[o00co02Koolco0?oWo`3o4@3oonWo0?l0ROoojol0o`3oZ_ooj`3o08[oo`0VoomSo`03o`3o
RP;o000000Go_Ol0olco0?l0oj_o_Ol0oonj0003o`000003o`1Qool;o`3o2ol000?o2ol000?o05go
o`000?l000000_l0R_l2o`000007o`3oG_l0hOoo9P3oooooool0003oooooobH0o`03ooooo`06occo
0?oooooo6_l0oooooom3o`3oood00oooool2o`3oo@06o`3o@Oooooooooooo`000?ooooooV?l04ooo
ool00ol07ooo0?moooooo`0Mooooo`;o03ko2?ooool00ol0003oooooooooo`1booooo`00I?ooool2
ool[00Kooooo0ooo:`05ooooo`?oob/01Oooool3ool[00Kooooo0ol0Sol<ooooo`?o09Co0_ooool2
o`1Do`Oooooo0_l0VOl2o`000003oooooomlo`3ooooo00Oooooo00Go0000ooooool0okSo0?nhoooo
o`03o`3`o`04ooooool0oekoooooo`3ob`Gooooo0_o1o`000ol0YOoo03?oo`0co`02o`000009o`3m
ool0003o00Ooolgo0?l;o`3o08[oob80ooo7o`3oiol000;o0?n:00SojOl0oa40ooo[o`3o0?n:ooo[
0?l0003o0?nQo`3Do`;o000000CoHol0o`3oY_l0oj7o0?nQ0_l00003o`3oY`;o000000?ookX0o`00
0?l000000_mAo`002Ol;o`3oc?l0olco0?o<o`3o04Goo`1Mool0oj7o0?goo`3Do`02o`000003o`3Q
oolV0?oo08[o00;o2ol000Co9P3oo`000?l0003o??l00_ooool01?l0003o@ol0ooooooooool2o`3o
o@Gooooo00Goood0oooooonHo`3oooooo`3o@@0Dooooo`03o`3oOooooooooooo00;ooooo00?o01oo
ooooooooool06_ooool3o`0noa3ooooo00?o0000ooooooooool0@Oooool2ool[00Kooooo0_oo:`06
ooooo`;oob/01Oooool2ool[00Gooooo0ol0Sol=ooooo`Co09Co1_ooool2o`20o`;ooooo0ol0VOl3
ooooo`;o000000Goooooo`000?l0003oHol0ogco0002ooooo`05oe?o0?oooooo0?mNo`3o^?ooool0
0_l0l?l00ol0003oooooooooo`04ooooo`06o`3oboooooooooooooooooo8o`3o0:Go0_o1o`02o`00
00;o03?o0_l000001Ol01ooo0?n8o`3okolR0?oo08[o00?o0?go00Goiol0oa40oooYo`3o0?n:on_o
0002o`000003ooo[0?l0oh[o0?n:00;o00000_l0oj400oo<o`3o0000o`000003o`3oY`;o000000co
2ol0o`000?l0003oDOl0o`15oomEo`3o0?goo`3Dool0GOoo02Koo`3mooo<o`03o`000007o`3Qool0
R_oo2ol0obH0ool0003oooooobH0o`03ooooo`06occo0?oooooo6_l0oooooom3o`3oood00_ooool0
0ol0oogoooooo`3o@@03ooooo`03o`000?ooooooV?l001?ooooo00?o01ooo`3oOoooool06oooool2
o`0no`[ooooo00?o0000ooooooooool0L_ooool006Kooooo0ooo:`06ooooo`?oob/01Oooool2ool[
00Kooooo0_oo:`07ooooo`?o08oo3?ooool3o`2Do`03ooooool0E?oo05Co00Cooooo0_l000000omn
o`3o083oo`2Io`02o`2Io`;oO?l01_ooool01?l0003ooooooooooomSo`02o`3o^005oe?o0?oooooo
0?3oo`3`ool0ol/01_ooool2ol7o0006ooooool0003o0000o`000?nmo`3o0?go0_l0ohX2o`2:o`?o
0?n:00Ooiol0o`000?oYo`3o0?gooa40ooo[o`3oon/000Ko000000?oHol0o`3oXOl0ojL00ol0ojL2
o`000004o`_o0?l0003o0000o`_o00;o000000?o00Woo`000?mAo`000omAo`000omEo`3o05goo`15
o`02o`3mo`;o000000?o0>7oobH0ool000000_l0R_l01?lV0?oo_Ol0o`000?llo`02ooooo`06o`00
0?m3o`3oooooo`3ooOoooooo00001Oooool01?ooo@3ooooooiSo0?l0od4Dooooo`03o`3oOooooooo
oooo00;ooooo00?o01ooooooooooool06Oooool2o`0noaCooooo00?o0000ooooooooool0@_ooool3
ool[00Gooooo0ooo:`05ooooo`?oob/01?ooool3ool[00Gooooo1?l0Sol<ooooo`04o`1Dool0U?oo
09Coo`2Do`Gooooo0_l0P?l3ooooo`?o09Wo0_l000000omno`3oooooooooo`02ooooo`06ogco0?oo
oooooooooe?o0?oooooo0?mN0_l0okP01?oooooo0000o`3`ool0l?l3ooooo`03o`3obooooooooooo
00;ooooo00Cob?l0ol7o0?o1o`3o`Ol00ol000000onmo`3o0?goo`07o`02o`3oRP;o08[o0ol0ohX0
0ooWo`3o0000onWo0002olOo0003on_o0?l0003oon/000;o08Wo00Co0?nWo`000?l0003oHol00ol0
ojL3o`000004o`_o0?l0003o0000olco00;o000000?o2ol0oe7o0?mAo`000_mAo`001?l0GOoo02Ko
oeGo0?o<o`02o`000009o`3oG_l0hOoo0000o`000?lV0?oo08[oo`000?oooooo9P3o00;ooooo00Ko
??l0oooooolJo`3ooooood?o0?ooo@02o`3oo@03ooooool0od7ooooo00?ooooo00?o0000oooooonH
o`004_ooool00ol07ooo0?moooooo`0Jooooo`;o03ko3Oooool00ol0003oooooooooo`1aooooo`00
JOooool3ool[00Kooooo0_oo:`05ooooo`?oob/01Oooool3ool[00Oooooo1?l0Sol;ooooo`Co09Co
0_l000001_moo`3o0000o`000?ooooooO_l0ooooo`;o083o0_l0VOl00omlo`3o09Woooooo`03oooo
o`03o`000?oooooooooo00;ooooo00GoHol0o`3o^?mCo`3oooooo`3ob`03o`3`o`?ooooo00Cob?l0
ol7o0?o1o`3ooooo0ol000003_l0oOoo0?n:o`07ool0R_oo0000o`3oR?lR0?ooc?l0onOo0?l0oOoo
0000onWo0?l0ojOojol00_l00002o`3oY`;o000000Co08Wookko0?l0oj7oHol00_nmo`04o`_o00;o
000000SoGOl0o`3o`Ol0ol7o0?o1o`000?l0R_oo0000odCo00;o00000omAo`02o`15o`06o`000?l0
hOooc?l0o`3moolV0?oo0?n80_l000002?lV0?oo0000occo0?l0003o2ol0o`000?m3o`3o0?om0ooo
ool00ol0003oooooooooo`02ooooo`03ooom0?ooooooV?l001Gooooo00Go0?mooooooooooooooooo
o`0Oo`0Jooooo`;o03ko5oooool00ol0003oooooooooo`0mooooo`;oofD01Oooool3ool[00Gooooo
0ooo:`05ooooo`?oob/01?ooool3ool[00Kooooo0ol0Sol;ooooo`;o05Co0ol0U?l4ooooo`;o083o
0_ooool2o`0000?o09Wo00?oO_l0ooooooooool00_ooool2ogco0007oooooomCo`3oooooo`3oG_oo
oooo0?nho`000002ooooo`;o0?3o00?o0?o;ooooooooool00oooool05_o8o`3o`Ol0ol7o0?o1o`3o
0000o`3oR_l0003o0?n:o`3mool0oh[o0000o`2:oolR0?oocOl0o`3mooooooooiol0o`3oYol0003o
jOl0o`3Dooo[o`02o`0000;o0?nW00?o__l0o`29ool0oj400_nmo`000omSo`3oc?l0o`_o0002o`00
0004o`_o0?l0003o0000oonj00?o0?o100Go08[oo`000?l0003oA?l0o`000003oe7o000<olco0?l0
oOoo0000o`000?l0hOoo0?goo`000?lV0?oo0000o`2:ool0003o9P3o0_ooool01_llo`3ooooooooo
oolJo`3o@ol0o`3oo@?ooooo00?o0?m1ooooooooool00_ooool00ol0003ooooooiSo000Aooooo`03
o`0Oool0ogoooooo01Wooooo0_l0?_l?ooooo`03o`000?oooooooooo077ooooo001/ooooo`?oob/0
1Oooool3ool[00Gooooo0ooo:`05ooooo`;oob/02Oooool3o`2?o`cooooo0_l000000ol0U?ooOol0
ooooo`02ooooo`;oO_l000Coooooo`20ool0P?oooooo0_mlo`02o`2Io`03ooooool0003ooooo00Co
oooo00?oHol0o`3o^?l0ol/00oooool01?l0oeko0?3oo`3`ooooool3ol7o0006ooooool0003o0000
o`000?l0oOoo08[o0_l00004o`3oY`03onOo0?l0e?oojOl000;o000000Wo0?goo`000?l0003oaol0
ooooool70?oo06Sookgo0?l0oj400_l;o`000omSo`3o2ol0o`3o`@05o`3o`@;o000000KookX0oeko
0?l0003o08[oo`000?l0ond4odCo0003o`000?mAo`3oDOl000;oDOl000?oc?l0o`15oolV0?l00_l0
oOl01?nmo`3o9P3oo`000?llo`03o`000003od?o0?oooooooooo00?ooooo00Oo0000oooooooooooo
ooooooom0?ooooooV?l001Cooooo00?o0?moooooooooool00_ooool00ol07oooooooooooo`0Foooo
o`;o03ko4Oooool2o`3o/@Kooooo00?o0000ooooooooool0?oooool3oomU0003oomV0?ooI@3oofD0
00;ooooo0_oo:`06ooooo`;oob/01_ooool2ool[00Gooooo0_oo:`07ooooo`?o08oo2_ooool2o`1D
o`04ooooool0U?oo09Coo`2Do`;ooooo0_l000001?l0P?oo0000o`000?moo`02ooooo`03o`2Ioomn
o`3oO_l000?ooooo00WoHol0ogco0?ooooooDol0ooooool0oekoooooo`000?l0okP00_ooool00ol0
ol_o0?3oo`3`o`04ooooo`04olSo0?o1o`3o`Ol0ol7o00?o000000Co0?goo`000?l0R_oo08[o1Ol0
ojL00ooWo`3o0000o`000002o`00000;o`3mool0003o0000olOo0?nmo`3o__l0o`0Vool0oj7o08Wo
o`_o0?mSo`000ol0ol401?l0J?oo0?o1o`3o`Ol0ol42o`000003o`_o0?mNo`3o08[o00;o000000Go
0?n[odCo0?m4o`3oA?l0o`000004oe7o0005ooooool0oOoooooookgo0?lV0?l00_l000001?lV0?oo
0000oooooollo`02ooooo`03o`3ooOm3o`3oood000;ooooo00?o0?m1ooooooooool00oooool00ol0
003oV?l0ooooo`0Aooooo`03o`3oOooooooooooo01Oooooo0_l0?_lBooooo`03o`000?oooooooooo
073ooooo001Yooooo`;oofD00_ooI`02oomV00;oob/00_ooI@04ooooo`?oob/01Oooool2ool[00Go
oooo0ooo:`09ooooo`?o08oo1oooool2o`0000?ooooo00?o09Coogoo0?moo`000oooool2ogko0007
ooooool0P?oo083ooooooomlo`3oooooo`000002o`2Io`Gooooo00Co0?o;ooooool0okSo0?nh0_oo
ool00ol0oekoooooo`3`o`03ol7o00?o000000?o0?goo`2:ool0ojL00_l000001?l0onoo0?n8o`3D
oooWo`02o`00000=o`3mool0003o0000ooom0?l0oOoo5P3oo`0Vooo7o`3o0?goo`1Xool0oj7o0?o1
o`29o`02o`000003of?o0?nmo`3o__l000;o000000Co2ol0o`3okOl0ongo0?o]0_l000000ol0R_oo
0?o]o`3o`@02o`0000;o@Ol000Co0000odCo0?m4o`3oA?l00_l00002oe7o0007obH0oomAo`3o_Ol0
o`3moolV0?oo0000occo0002o`3oo@03o`000?m3o`3o6_l000Gooooo00Ko0000ooooooooooooood0
o`3o@OnHo`0Cooooo`03o`3oOooooooooooo00;ooooo00?o01ooooooooooool05Oooool2o`0noa;o
oooo00?o0?nao`000?l000001oooool00ol0003oooooooooo`10ooooo`05oomW0?ooI@3oofD0oomU
0?ooIP000_ooI@001?ooooooob/0ool[0?oo:`05ooooo`?oob/01Oooool3ool[00Cooooo0ooo:`07
ooooo`?o08oo2Oooool2o`1Do`;ooooo0_l0U?l2o`000005ooooool0P?oo083ooooooomoo`001?oo
ool03_mno`3o09Woo`2Iool0VOooHol0ogco0?ooooooDol0ooooool0oeko0000ooooool0okSo0?o;
0oooool3o`3`o`0>ooooooo8o`3o`Ol0ooooooo1o`3o0000o`3oYol0003o0?goo`2:ooo<o`3o0?n8
o`000?lR0?l2o`3Do`03onOo0?l0003o000000?o000000Coood0oaH0ool0oOoo0?go0_l0ol401?l0
oj7o0?o1o`3o`Ol0ROl2o`00000=o`_o0?l0GOoo06Soo`000?oooooo0?mQoonj0?l0ojOo0000o`2:
ool0HOoo0?o1o`3ok@02o`0000;o@Ol01?m4o`000ol0003oDOl0oe7o0002oe7o0007obH0ool0ROoo
0000o`000?lV0?oo0000occo0002o`3oo@05oa[o0?m3o`3oood0ooooool0od401_ooool00ol0003o
V?l0ooooo`0@ooooo`03o`3oOooooooooooo01Kooooo0_l0?_l>ooooo`;o0?na00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1_ooooo`00Joooool3oomU00;oofL000CoofH0ool[0?oo:`3o
ob/00_ooI@04ooooo`;oob/01Oooool3ool[00Gooooo0ooo:`09ooooo`?o08oo1?ooool2o`000003
oh;o0?oooooooooo00?ooooo00KoOol0o`2Dool0U?oo09Cooooooomno`02ooooo`;o083o0_mlo`02
ooooo`?o09Wo00Koooooo`3oboooooooHol0oooooomCo`02o`3o^003ooooool0oekooooo00?o`Ol0
00Wo0000o`3oSOl0R_oo0?gookgo0?l01ooo0?goo`1@ool0e?l00_l000002?l0oj7o0000o`000?l0
oOoo0?o1ooom0?l0ol7o5P3o0_l0ol401?o7o`3o0?goo`3oXOl0J?l2o`0Qo`05o`29ool0003o0?o]
of?o0?l0ond00_l000001_l0ongo0000o`3oHOmNo`3ookX0o`2:o`;o000000GoH?l0o`000?l0003o
oooookko0003od7o0003o`3o?_m4o`3oA?l000;oA?l000?o05?oobH0oomAo`000_mAo`000olV0?oo
??l0o`000002o`000003od?o0?lJo`3o000000Cooooo00Go0000oooooooooooo0?m1oiSo000Coooo
o`03o`3oOooooooooooo00;ooooo00?o01ooooooooooool04oooool3o`0noa;ooooo0_l0ok4:oooo
o`;o0000A?ooool00oooI`3oofD0oomU0002oomV00;oofD000Coooooool[0?oo:`3oob/01Oooool3
ool[00Gooooo0_oo:`05ooooo`;oob/02?ooool4o`2?o`Oooooo0ol0E?l3ooooo`03oh;o0?l0U?oo
09Co00;o083o0_moo`03ooooo`03ogko0?oooooooooo00;o09Wo0_mlo`001_mCo`3oooooo`000?oo
oooo0?o;ooooo`;o0?nh1?ooool01?l0l?oob?l0ol7o0?o1o`03o`000003o`3mool0R_oo00Oo00Co
0=Co00?o2ol0o`000?l000000_l000001?l0D?oo0?o1ooom0?lF0?l2o`3o`@0=o`L0ool0oOoo0?nQ
o`3mooo<o`3o_Ol0o`0Qool0ROoo0000of?o0?mMo`3o06Soo`000004o`3ok@05o`2:ool0003o0000
o`3okOmPo`000_l000000ol0GOoo0?o]od7o0002od7o0007o`3o@?m4o`3oA?l0odCo0?l0AOoo0?go
obH0o`02oe7o0005o`000?lV0?oo0?omocco0?l000000_ooool00om3o`3oooooo`3o@@07ooooo`03
o`000?nHo`3ooooo00oooooo00?o01ooo`3oOoooool05?ooool3o`0no`oooooo00Co0?naooooool0
003o00001?ooool00ol0003oooooooooo`1_ooooo`00K_ooool3oomU00;oofL000GoofH0ool[0?oo
:`3oob/0oomU0004ooooo`?oob/01Oooool3ool[00Gooooo0_oo:`0:ooooo`Co08oo0oooool2oh;o
00Cooooo0_moo`000ol0E?oo09Coo`2Do`02ogko00;ooooo00?o083oo`000?mlo`001?ooool01_l0
ol_o09Woo`2IooooooooHol0ooooo`;oDol000?o0?nhooooool0oeh00_o1o`02o`000004o`2:ool0
003o0?gookgo00;oon8000[o0?o1o`1@ool0003o0000oood0?l0ol7o0?goo`_o0?ooo@3o2ol00_l0
00000ol0oOooooooo`0Qo`02o`0Qo`07o`1Xool0oOoo02Koo`29ool0003oc?l0of?o0002o`00000=
o`0Vool0003oG_l0o`3oHOl0og?o2ol0o`2:ool0ojOo00Woo`000?l0ol7o0?nWokko0002o`0000;o
??l01?m1o`000ol0003oA?l0obH0o`02odCo0003o`3ooOlV0?oo??l000;oDOl000Go0000od?o0?l0
R_oo6_l0o`000004ooooo`04o`000?l0od7oood0oiSo01;ooooo00?o0?moooooooooool00_ooool0
0ol07oooooooooooo`0Booooo`;o03ko4oooool2o`3o/@Wooooo0ol000000ooooooo0000ooooo`16
ooooo`?oofD00_ooIP000oooI@3oooooooooo`02ool[00Kooooo0_oo:`05ooooo`?oob/01?ooool3
ool[00Wooooo0ol0Sol7ooooo`;o05Co0_ooool2oh;o00?o09Co00?o083oogoo0?ooool00_ooool2
ogko00;ooooo00KoHol0o`2Ioomlo`3o09Woo`000?l0ol/4ooooo`;o0?nh0oooool00oo8o`3o`Ol0
ol7o0002o`000004o`2:ool0oOoo0000o`3Do`;o0?o100?o8P3oo`3o`Ol0ol400_l000001_nmo`3o
0?goo`1@ooooo@3o2ol0oaH0o`;o000000?o0?goo`3oXOnno`000ol08Ol03_l0ongo08Woo`000?l0
ongobol0o`1Xool0003o0?n:oeko0?l0og?o2ol0o`2:ool02OooH?l00_l000000ol0ol7o0?nWo`1M
o`02o`0000;o??l00om1o`002ol0003oA?l0odCo0?m4o`3o9P3oo`1CoomAo`3o9P3ooe7o0?llo`3o
08[o00;o000000?o@ol0ooooool0od401oooool00ol0003oV?l0ooooo`0>ooooo`03o`0Oool0ogoo
oooo01?ooooo0_l0?_l@ooooo`;o0?na1oooool3o`00073ooooo001aooooo`;oofD00_ooI`02oomV
00?oob/000?oofD0ooooooooool00_ooool3ool[00Gooooo0_oo:`05ooooo`?oob/02oooool3o`2?
o`;ooooo0_n2o`04ooooo`06ogoo0?l0E?oo05Coooooool0U?ooO_l00_l0U?l01?l0003o083oogco
0?mlo`02o`3ob`?ooooo1?l0VOl01?ooooooDol0o`3o^?l0okP2ol7o00?o000000_o0?goo`3Dool0
1ooo_Ol0o`3o`OoohP3o053oooof0?oom03oon80ooob0004o`3mo`;o00000_l08Ol01Ol0oj7o02Ko
okgo0?l0J?oo02Ko00;o0?go00?o08Wool_o0?o;o`000_l000002_l0oj7o0000o`000?l0of7o0?n8
o`2:oooo^P3oH?l0o`09ool0HOl2o`000003of;o0?l0003o000000;o00000ollo`001_l0003o@Ol0
od7o0?m1o`3o9P3oo`0000;oA?l000Go??l0ooooool02Ooo0000od?o0002oe7o00?o00000_ooool0
1?l0od7o0000ooom0?nHo`0Aooooo`03o`3oOooooooooooo00;ooooo00?o01ooooooooooool04Ooo
ool2o`0noaCooooo00?o0?naooooooooool01?ooool2o`3oL0?o00001?ooool00ol0003ooooooooo
o`18ooooo`?oofD000CoofH0oomU0?ooI@3ooooo0ooo:`05ooooo`?oob/01Oooool3ool[00Cooooo
0ooo:`09ooooo`?o08oo1_ooool2o`1Do`;ooooo00?oP_l0ooooooooool00_l0U?l2ogoo00?ooooo
00OoO_l0ooooooooooooHol0oooooomlo`3o0?o;00;o09Wo1Oooool01?l0okSoooooooooooo8o`02
ol7o00?o000000?o0?goo`000?oohP001?oohP001ooomP3ooo@0o`_o0?oolP3o0?goooom0?l0D?l0
0_l0oOl2o`0000?o027o00Wo02Koo`1Mool;o`3o0?gool_o0?l0ROoobol0olgo0?l0J?l00ol00000
1ol;o`3o08[oo`3okOmPo`3o067oo`3o`Ol0oOl00_l000000ol0GOoo0000o`000002o`0000?o??l0
0om1o`000ol0003o9P3oodCo0002odCo0003obH0oollo`3oDOl000;oDOl000?o@ol0o`3o@Oooo@00
2?ooool00ol0003oooooooooo`0=ooooo`03o`3oOooooooooooo017ooooo0_l0?_lAooooo`03o`3o
/Ooooooooooo00Cooooo0ol00002ooooo`03o`000?oooooooooo06kooooo001cooooo`?oofD00_oo
I`02oomV00;oob/000?oofD0ooooooooool00oooool2ool[00Gooooo0ooo:`05ooooo`;oob/03?oo
ool3o`2?o`03oooooon2o`3ooooo00?ooooo0_moo`03o`1Do`;oO_l000Ko0000o`2Dool0U?oo0?o;
ogco0?l0P?l6ooooo`05of?o0?l0VOoo09Woo`2Iooooool00_o1o`05o`000007o`07oonmo`3o2ol0
o`_o0?oomP3o053oo`3ok@03o`3mo`05oooR0?lA0?oo027oo`0QoolF0?l00_oohP001?l0oj7o02Ko
okgo0?l0J?l3ol_o0006o`29ool0oOoo_Ol0olOo0?mSo`3o0?nQ0_l000002Ol0ohSo0000o`000?oo
^P3o2ol0o`09ool0HOooEOl0of;o0005o`0000;oc?l000KocOl0occo0?llo`3o??l0o`3oR?lV0?l2
od7o0008o`000?llo`3oA?l0odCo0?l0003o@ol0o`15oolJo`04oe7o0005ooooool0od7oooooooom
0?nHo`004?ooool00ol0ogooooooooooo`03ooooo`03o`0Ooooooooooooo00oooooo0_l0?_lDoooo
o`;o0?na1_ooool00ol0og3o0000o`000007ooooo`03o`000?oooooooooo04[ooooo00?oofL0oomU
0?ooI@000_ooIP000oooI@3oooooooooo`03ool[00Gooooo0ooo:`05ooooo`;oob/01Oooool2ool[
00[ooooo0ol0Sol5ooooo`;o05Co00?ooooooh;o0?ooool00oooool01Ol0U?ooOol0o`2Dool0U?oo
oooo00;oO_l000?oooooof?o0?l0ol/00_mlo`000ooooooo09Woo`2Io`02o`2Io`;ooooo0_l0okP0
0oo8o`3o`Ol0ol7o0002o`000003o`3mool0003o000000;o000000Ko8P3oo`3okOoomP3ooo@0oooR
0?oolP03o`3mo`03o`1@oolF0?oo027o00;o027o00Co0000olOo0?nno`3o02Ko0oo;o`001_nmo`3o
08Woo`3mooo=o`3o06Soof?o00;o000000Oo2ol0o`000?l0003o00Woo`3oXOl0HOoo02Ko00;oH_l0
1Ol00002olco0004olgo0?llo`3o??l0occo00;o@Ol000Wo9P3oo`000?l0003o9P3oocco0?m4o`3o
04Goo`000?m3o`001?mAo`05ooooo`03oiSo0?l0003ooooo00gooooo00?o0?moooooooooool04?oo
ool2o`0noa7ooooo0_l0ok44ooooo`03o`000?l0og3o0?m`00Gooooo00?o0000ooooooooool0K_oo
ool007Kooooo0oooI@02oomW0005oomV0?oo:`3oob/0ool[0?ooI@001?ooool3ool[00Gooooo0ooo
:`04ooooo`?oob/03?ooool2o`2?o`;oP_l01?ooool00omoo`3oooooooooo`02o`1Do`03ogko0?oo
oooo0?o;00;o09Co00?oO?l0o`20ool0P?l01Oooool01?mSo`3oooooooooool0VOl2ol7o0005o`00
0?l0R_oo0000o`2:ool;o`000ol000002OoomP3o0?goo`1@ool0oOoo0?nQo`3mool08Ooo4@3oo`0Q
o`02o`000004o`3o3_l0R_oo0?nQoooR00;obol000Ko06SooooR0?oohP3oon80o`_o0?l0ROl2o`3m
o`05olco0?l0oj7o0000o`000?o<o`000_l000000ooo^P3oooooo`3oY`04o`0Lo`04olWo0?l0003o
0000o`0000;ocOl000ko_Ol0olco0?l0GOoo00Woocco0?lV0?oo??l0o`3oZom1o`3o9P3oocco0?m1
o`3o0000od?o00CoA?l000?od?l0o`000?mAo`000_mAo`001_ooo@3oV?l0oooooooooooo0000o`3o
c0cooooo00?o0?moooooooooool00_ooool00ol07oooooooooooo`0>ooooo`;o03ko5Oooool00ol0
ok7oooooooooo`03ooooo`03o`000?l0og3o0?m`00[ooooo00?o0000ooooooooool0COooool3oomU
00;oofH000?oofD0ooooooooool00_oo:`06ooooo`;oob/01Oooool3ool[00Cooooo0ooo:`0:oooo
o`Co08oo0oooool2o`1Do`;oP_l01?ooool00omoo`3o083oo`2Do`02o`2Do`08ogko0?l0ol_oHol0
o`000?ooooooO?l0ooooool0oeh2ooooo`?o09Wo00Co0?n=o`3o^?o1o`3o00000_l0R_l02?l0003o
08[oo`000?nmo`3o8P3oo`000?oomP3ooo@01?l0oOl01?lA0?oo027oo`0Qool0D?l2o`0000;oon80
0oo;o`002_mMo`3o0?n8okgo0?l0ohSoc?l0o`29ool0oOoo06Soo`3Dool0oj44o`000003o`09ool0
ojOo067o00Co01co00CobOl0o`000?l0003o00000_o=o`001?l02Ooo0000o`000?l0oj/2occo0006
obH0oom1o`3o@Ol0od7o0?llo`3o00000_m4o`001Om3o`3oA?l0o`000?l0003ooooo00?oDOl00_oo
ool00onHo`3o0000ooooo`0<ooooo`03o`0Oool0ogoooooo00oooooo0_l0?_lBooooo`04o`3o/Ooo
ooooooooooooo`?o000000?o0?m`o`000?l000001Oooool00ol0003oooooooooo`1^ooooo`00NOoo
ool2oomU00;oofL00_ooIP03ool[0003oomU0?oooooooooo00;ooooo0ooo:`05ooooo`;oob/01Ooo
ool3ool[00cooooo00Co08oooh;o0?l0Sooo08oo0_ooool2ogoo00;ooooo00?o0000ogko0?mno`00
0oooool2ogco00;o09Co1?ooool01?mSo`3oooooooooooo1o`02o`000003o`_o0?l0003o000000?o
08[o00[oooH0o`3mool0oOoo0000o`1@ool0003o0?goo`2:oolA0?oo0?n80_l000002_oohP3o0?nQ
ol_o0?o;o`3oaol0o`0Vool0J?ooGOl0o`0Vool;o`02oooR0004o`29ooo9o`3obOl0olWo00;o0000
00?o08[oo`3oR?l07?l00ol07?l00oo7o`3o05?oolWo0002ol_o0005o`1Mooo<o`3o0000o`000?nm
o`000_l000001Oo7o`3oc?l0o`3og_l08Ooo9P3o00Co??l000Oo0?goo`000?m3o`3o@Ol0o`29ool0
oiSod?l000?oA?l00_l000001_mAo`3oV?l0oe7o0?mAo`3o0000o`3oc0;ooooo00?o08Goo`000?l0
00001_ooool00ol0ogooooooooooo`02ooooo`03o`0Ooooooooooooo00cooooo0ol0?_lEooooo`;o
0?na0oooool2o`0000;o0?m`3?ooool00ol0003oooooooooo`1@ooooo`?oofD000CoofH0oomU0?oo
I@3ooooo0ooo:`05ooooo`?oob/01Oooool2ool[00Gooooo0_oo:`0<ooooo`?o08oo0_ooool2o`1D
o`03oh;o0?oooooooooo00;ooooo0_moo`02o`20o`04o`3obomno`3oO_l0o`0000;ooooo00?oO?l0
ooooool0oeh01?ooool00ol0VOoo`Ol0ol7o0004o`000005o`07ool0003o08[oo`2:oooomP000_l0
oOl01OoolP3o0000ooom0?l0oOoo000000;o0?n800?o053oo`000?l000000_o;o`000oo7o`3o__l0
oooR0005oooR0005oeko0?l0ROoo06SoolWo0?mSo`000_l000000ol0R_oo0?n8o`0Lo`02o`0Lo`06
o`3mooo7o`3oaol0o`1Mooo;o`3oc?l00_l000002Ol02Ooo0?n8o`1Mooooooooc?l0ooooool0omko
027oobH0o`04occo00;o@Ol000?o@ol0o`000?l000000om4o`000ol0003oooooooooo`02oe7o0003
oiSo0?l0003ooooo00[ooooo0_l0QOl2o`0000kooooo0_l0?_lBooooo`;o0?na00Goooooo`000?l0
003o0000ooooo`02o`3oL0Wooooo00?o0000ooooooooool0KOooool007Cooooo0_l00002olko00?o
oooo0oooI@02oomW00;oofH00_oo:`000oooI@3oooooooooo`03ooooo`;oob/01Oooool3ool[00Go
oooo0_oo:`0<ooooo`;oP_l00ol0Sol01_ooooooOol0ooooool0ol_oooooo`1Do`;oO_l00oooool0
0omlo`3oooooo`2Do`02o`2Do`;ooooo00?oHol0o`3oSOo1o`000_l000000onmo`3o0000o`2:o`02
o`3mo`08ooof0?l0003o0000ooob0?l08Oooood0o`1@ool0oOl3o`00000<o`3oR?l0003obol0ol_o
0?oohP3o0?goolOo0?l02Ooo06Soo`3o1?l09_oo0?go0_o9o`001_l0ROooc?l0olOo0?l0of7o0?nQ
o`2:o`;o000000Co0?n:o`3okOo7o`3oaol00_o9o`001oo;o`3o2ol0olco0?l0GOoocOl0o`3oO_l0
Ool00ol000002?o7o`3o0?oNo`3oR?l08Ooo9P3oooooool0Dooooooo0_llo`000ol0003o@ol0oooo
o`04od7o0009o`3oR?l0003oA?l0odCo0?nHo`3oA?l0o`000?ooooooDOl000?o08Go00?oooooo`00
0?l000001Oooool00ol0ogooooooooooo`02ooooo`03o`0Ooooooooooooo00_ooooo0_l0?_lGoooo
o`03o`3o/Ooooooooooo00?o000000?oooooo`3oL?ooool03Oooool00ol0003oooooooooo`1?oooo
o`;o00000_o>o`02oomU00;oofH000?oofD0ooooooooool00ooo:`05ooooo`?oob/01?ooool3ool[
00Cooooo0ooo:`0<ooooo`?o08oo0_ooool2oh;o00Cooooo00KoOol0o`3obol0P?oo083ooooooomn
o`02o`2Do`04oooooomlo`3oDol0o`3oGP;ooooo00Ko0?n=ooooooo1o`3o`Ol0o`000?nmo`02o`00
0006o`_o0?l0003o0?goooof0?oom03o0?nQ0_l000001?ooo@3o0?lCo`3mool;o`03o`00000:o`1@
ool70?oo0?goo`0VoomMo`3oaol0okko0?l09_ooc?l0okgo00?obOl000Ko08Woo`1XoooohP3oon80
o`3oXOl0oOl2o`0000;oH_l00_o7o`001?oo^P3obol0o`1Mooo<o`02olgo0003o`0Lool0003o0000
00;o000000Soc?l0o`3og_l08OoookX0o`1CoolV0?oo00Woooooo`?o??l000Co@ol0od7o0?m1o`3o
@Ol00_l00004odCo0003oooooonHo`3o000000CoDOl01?ooool3o`25o`04ooooool0ogoo0000o`00
00cooooo0_l0?_lCooooo`04o`3o/Ol0003o0000o`0000?ooooo00?o0?m`ooooooooool02Oooool0
0ol0003oooooooooo`1]ooooo`00LOooool2o`000003ooooool0003o000000;ooooo1?o>o`02oooo
o`?oofD00_ooI`001OooIP3oob/0ool[0?oo:`3oofD000Cooooo0ooo:`05ooooo`;oob/01Oooool3
ool[00_ooooo0_n2o`000ooooooo08ooo`2?o`02ogoo00?ooooo00?o05Coogko0?ooool00_ooool2
ogco0003ooooool0P?oo09Co00;o09Co00[o0?n=ol7o0?l0003o0000o`3mool0003o2ol0o`07oooo
mP3ooo@00_l000001_l0ohSoood0o`3oYol0D?oo0?mQoa40o`;o000000?o5P3oo`3oXOl000000ol0
00001?o7o`3oGOl0o`0Vool0J?l2olWo0008oeko0?l0e?oo01coo`29ool07?oo0?mQo`3oXOmSo`03
o`000003olOo0?oo^P3obOl000;obol00_l000001ol0Oooo05goo`1oool0Oooo01coo`3okOl0GOl0
0_l000002oo<o`3o0?n8o`0Qooo=o`3o9P3oo`1Coooooooo??l0obH0ool0003o@ol000;o??l000?o
dOl0o`29ool000000om1o`000ol0003oV?l0o`000003o`25o`03odCo0?oooooooooo00?oDOl01?oo
ool00ol0ogooooooooooo`03ooooo`03o`0Ooooooooooooo00Wooooo0_l0?_lGooooo`;o0?na0ol0
0002ooooo`;o0?m`4?ooool00ol0003oooooooooo`1:ooooo`;o00000_o?o`02o`0000;ooooo1?o>
o`001?ooI@3oofH0oomV0?ooI@02ooooo`;oob/01_ooool2ool[00Gooooo0ooo:`04ooooo`?oob/0
3?ooool3o`2?o`03oooooon2o`3o05Co00;ooooo00So0?o;ogoo0?moo`3oooooo`20ool0003oO_l0
ooooo`;o09Co0_mlo`001?l0oeko0?n=ooooool0oj/2ol7o00;o000000So0?goo`000?l0oOoo0000
o`_o0?oom03o027oooob00;o000000?o0?nZo`3moolA0?l00_o;o`02o`000003o`L0ool0D?oo0000
00;o000000?oaol0okko0?o9o`000_o9o`002Ol0of7oc?l0o`0Lool07?oo06Soo`0Lool0R_oo0?nQ
of?o0003o`000005olOo0?o9o`3obol0ol_o0?o<o`000_l00003o`1oo`0@o`3okOl0GOoo0000o`00
0?l0omkoc?l0o`0Qooo=o`3o05?oobH0ool02Ooo0?goocco0?lV0?ood?l0od?o00;o??l000Co0000
od7o0?m1o`3o@Ol00ol000000om4o`3oV?l0o`000004ooooo`04oe7o0?l0QOoo08Goo`25o`?ooooo
00?o0?moooooooooool02oooool2o`0noa?ooooo0_l0ok400ol0003oooooooooo`02ooooo`;o0?m`
3?ooool00ol0003oooooooooo`1]ooooo`00LOooool2o`000003oloo0?oooooooooo00Kooooo1Oo>
o`02oomU00;oofL00_ooIP03ool[00Cooooo00?o`_l0ool[0?oo:`001Oooool3ool[00Gooooo0_oo
:`0;ooooo`05oh;o0?oooooo0?o;ooooool000000_moo`000ol0Soooooooooooo`02ogko0004o`1D
ooooooooooooogco00;ooooo00Co083oo`3oSOl0U?oo`Ol00_l000003Ol0oOoo0000okgo0?l;o`3o
oo@0o`0QoooolP3o08[oooom0?l0ojOo08[oo`3mool0D?l00_nmo`001ol0ohSo5P3oooooool70?oo
okX0olgo0?mMo`000ol000000ol0J?oo0000o`0Lo`02o`0Lo`07o`3Dool0ROoo0?mQolOo0?l0R_oo
0?nQof?o0002o`000003o`3moooo^P3obol000;o07oo0_l000002Ol0[ooo05goo`3oO_nmo`3o01co
o`09ool0GOoo07ooo`1bo`03o`00000:olgo0?lV0?oo05?oo`09oollo`3o9P3oo`000?m3o`3o0?go
oolM00?o??l00ol000000om1o`3o08Goo`25o`03o`000004o`3oc?m4o`3oA?l0odCo00;ooooo1?mA
o`05ooooo`03o`0Ooooooooooooo00Sooooo0_l0?_lGooooo`;o0?na0_l00003ooooo`;o0?m`4_oo
ool00ol0003oooooooooo`0]ooooo`So0?oc4_ooool2o`000003oloo0?l0003o000000;ooooo1?o?
o`04ooooo`Goc_l000?oofH0ooooooo2o`000ooo:`05ooooo`?oob/01Oooool2ool[00Gooooo0_oo
:`0=ooooo`;o08oo00?oP_l0o`2?ool0ol/00oooool01?moo`3oooooo`000?l0P?l2ogko0004of?o
0?ooooooooooogco00;o09Co00?o0?o6ol7o0?l000001?l000005?nmo`3o0000oood0?l;o`3ooo80
o`2Hooooo@3o08[ool_o0?l0oOoobol0o`3oR?nmo`3o0?n8o`2:ool70?oo053ooego0?l0oOoobOl0
1?l00003o`0Lo`04o`3DoomPo`3o06Soo`2:o`;oaol000Ko0?nQof?o0?l0003o0000o`3mooo;o`03
o`1oo`;o000000Oo0?mnolco0?l0oj7o01coo`1Mool0ohSo07oo00Co000000So05?oobH0ool02Ooo
0?n8occo0?lV0?oo0?nHod?o00;ooad00ollo`001ol0003o@Ol0od7o0?m1o`3oV?l0ooooool00000
0_m4o`03o`25o`;ooooo1?mAo`000ol0ogooooooooooo`09ooooo`;o03ko4_ooool2o`000003o`3o
/Ooooooooooo00Cooooo00?o0?m`ooooooooool03?ooool00ol0003oooooooooo`1]ooooo`00GOoo
ool8o`3ol`Sooooo0_l00002oloo00?ooooo1Oo?o`08ooooo`Coc_l000GoofD0oomW0?ooI`3oofH0
oomU0003ool[00Cooooo0ooo:`05ooooo`?oob/01?ooool3ool[00Wooooo0_n2o`001Ooooooo0000
ooooooooooooOol000?o08oo00Goooooogko0?l0E?oo05Coooooo`02ogco0004o`3oSOoooooo0?n[
ol7o00;o000000Co027oo`000?oomP3o_Ol00_l000000onmo`3oood0o`3oR002ol_o0008o`3moonm
o`3o053oo`3oR?l0oj7o5P3oo`1Mool70?l3olWo0005olOo0?l07?oo01coo`1Xool09_l01?l00000
2_o7o`3o08Woo`2:ool;o`3o0?nQolOo0?mSo`3oon80o`1oool0oOl2o`000009o`09ool0ojOo2ol0
o`2aool0GOoo_Ol0o`2:ool0L_oo05go00;o07;o01;o0?nQolco0?l0003o0000olgo0?oo7@3o9P3o
o`09oollo`3ooad0o`000?m3o`3ooad0o`3mooo?o`3o0?goo`3oR?llo`03o`25o`03oiSo0?l0003o
@Ol000?o@Ol00oooool2o`0000;oA?l000?o0?mooooooomAo`000omAo`000ol07oooooooooooo`07
ooooo`;o03ko5oooool00ol0003o0?nao`000005ooooo`03o`3oL?oooooooooo01;ooooo00?o0000
ooooooooool0=Oooool>o`3ol`Cooooo0_l000000ooooooocol0oloo0002oloo00Cooooo1Oo?o`03
ooooo`03oomU0?o>o`3oc_l000;oc_l00_o2o`03ool[00Gooooo0_oo:`05ooooo`?oob/01?ooool3
ool[00gooooo0_n2o`02o`2?o`;ooooo00goOol0o`000?ooooooooooo`20oomno`3o083oo`3oSOoo
ooooO?l0o`3oG_l0U?oo`Ol000?o000000Co027oo`000?oomP3o_Ol00ol000004?ooo@3obol0ol_o
0?l02Ooo0?goo`1Moonmo`3o5P3oo`3oR?l0R_oo1`3oolWo0?l0D?oobOl0o`0Looo7o`02o`0Lo`03
o`3oHOl0003o000000;o000000[oaol0o`1Xool0ROoo0?mQof;o0?l0oj7o07ooof?o0?oohP3o07oo
0_l0oOl03Oo=o`3o0:ooo`1Mool;o`3o0?mno`3o`Ol0ROoo05goo`3mool0ongo07ooo`3mool0L_l0
0_l00002oolM000;obH0oooo7@3o??l0obH0oooo7@3o@ol0oloo0?l0ohSo08Woo`3`ool000001?ll
o`000onHo`3o@Ol0o`25o`02o`25o`;ooooo0om4o`02ooooo`03o`0Oool0ogooDOl000;oDOl00_l0
0005ooooo`;o03ko4Oooool3o`0000;o0?na1Oooool2o`3oL0oooooo00?o0000ooooooooool0KOoo
ool006Gooooo1Ol0oo<2o`000003om3o0?l0003o000000;o0?oc1Oo?o`03ooooo`Cocol01_ooool0
0omno`3oooooolko0003olko0004oomW0?ooIP3oofH0oomU00;oob/01?ooool01?o2o`3oob/0ool[
0?oo:`05ooooo`;oob/01Oooool3ool[00Cooooo0_l0ol/2ooooo`03oh;o0?l0003ooooo00;ooooo
0_moo`000ooooooo08ooo`2?o`02ogko00;o05Co00Go0?n=ogco0?l0oj_ooooool7o0004o`00000>
oood0?l0oj7o0000o`000?o;o`3oood0ol_o0?l0ojCo0?gookgo0?lA0?oo053oo`3oXOlF0?l3olWo
00?o01co00Go2ol0olOo0?mNo`3o06Soo`0Vo`03olOo0003o`3oR?l0003o08Wo00?o000000?o07oo
o`3oR?mSo`000ol000001_l0oOoo00Woo`1Qool;o`3o07;oo`1Mo`;o07;o00?o0?goo`1Moooo7@00
1Ooo7@02o`000007obH0ool02Ooo??l0o`3oV?l0003o@ol0oloo0002oolM00?o08Go0ooo7@000onH
o`3o??l0occo0003o`0000?o07Wo0_l000000ooooooo0?moodCo0003odCo0003ooooool07oooDOl0
00?oDOl00oooool3o`0noaKooooo0_l00002o`3o/@Gooooo0_l0og0Eooooo`03o`000?oooooooooo
04?ooooo0_l00002om3o00Oo0?oc1Oo?o`001?mno`3oooooooooooooool4oloo0004ooooooooI@3o
ofD0oomU00Coc_l000Co`_l0ool[0?oo:`3oob/01?ooool3ool[00Gooooo0_oo:`05ooooo`;oob/0
2Oooool2o`3ob`;ooooo00?oP_l0ooooool0Sol00_l0Sol2ogoo00?ooooo0_mno`001Ol0oj_ooooo
ogco0?mlo`3o`Ol000?o000000Co0?goooof0?l0003o8P3o0ol000002?l0<ooo0?mQo`2:ool0oOoo
4@3ookgo0?l0oj7o0?n80oo9o`001Ol07?oo053oo`000?mNo`3oaol000;o02Ko00?o0?goo`3oR?o7
o`000_o7o`000ol0003o06Soo`29o`03o`00000>ol_o0?l0ohSoHol0olco0?o=o`3o0000o`3moonm
o`3o05goo`_o0?l0oh[o0?o1okgo0?l0GOl6oolM00;o000000oo0;KoobH0ool0003o??l0oloo0?lV
0?oo@ol0o`3oZol0ohSoood0o`3`oonbo`3ooad0ok;o0?ooool00ol0QOl2o`0000?o@Ol00oooool4
odCo0003ooooool0NOoo07Wo00;o00000omAo`02o`0noa3ooooo0ol00002ooooo`03o`3o/Ooooooo
oooo00Cooooo00?o0?m`ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00I_ooool2o`00
00;ooooo0_l000000oooooood?l0om3o0003om3o00;ooooo0_l0oo<4oloo00?o0?oc1Oo?o`000ol0
oo?oooooogko0003ooooo`03oomU0?o>o`3oc_l000?oc_l000CoofH0ool[0?oo:`3oob/01?ooool0
0oo2o`3oob/0ool[0005ooooo`?oob/01Oooool2ool[0003ooooool0ol_ooooo00?ooooo00?o0000
oh;o0?n2o`001?ooool02Omoo`3ooooooooooooooooo08ooogko0?l0Sooo0?n=o`3oZ`02ogco0005
ol7o0?l0003o0000ooof0?oom0000ol000001?nmo`3o0?nQo`2:ool0ohP2okgo0005o`3oZ_lA0?oo
0000o`1@oonIo`000_l07?l01Ol70?oooooooonj0?o<o`3oG_l000;oaol000Go06SoolOo0?l09_oo
H?l0o`3mo`02o`1oo`04o`2:ool0003o0000olWo00Go000000CookX0o`3moooo7@3o2ol00_oo7@00
1?l0GOoooad0oolM0?l0GOl9oolM00;o000000Go??l0oolM0?l0003o@ol0oolM0002o`25o`06oooo
oonbo`3oc_l0olko0?oo7@3oV?l00ol00003o`1io`?o00001?m1o`04ooooo`?oA?l00oooool3oe7o
01Kooooo0ol000000ooooooo0?naooooo`05ooooo`03o`3oL?oooooooooo01Gooooo00?o0000oooo
ooooool0?oooool2o`0000;od?l00_l00002ooooo`God?l01?ooool3o`3ol`Cocol01?l0oo<4oloo
00?oofD000?oofH0olko0?o>o`000_o>o`02ool[00Gooooo0ooo:`04ooooo`?oob/01?ooool3ool[
00Gooooo00?o0?o;ooooooooool00oooool2oh;o000Eooooool0E?oo0000o`2?oomoo`3oooooo`3o
SOoooooo0?n[ogko0?l0olKo083oolSo0?mlo`3o0000o`3mool0003oooH0oood0?l0003ooo8000?o
000000Oo0?nQo`3oHOl0R_oo0?gookgo0?o9o`3o0?n800;o000000SoVOl0o`2:ool02OoookX0o`1@
ool0o`Coaol0o`0Vo`?oaol000Oo_Ol0o`1oool0Oooo08[oo`1Xooo7o`3o08Wo00;o000000?o0?nQ
o`000?mSo`000ol000001?l0oOoooad0oolM0?l;o`02oolM0003o`1Mool0omko01co00;odOl000Go
07ooo`3oR?oo^P3ocOl0o`1Co`02o`000005o`3oV?llo`3ooad0obH0oom3o`000ooo7@000onbo`3o
oad0o`25o`02o`25o`04o`000?nHo`3o0000o`0000?o??l000Kooooood7o0?m1o`3o@Ol0ooooool0
ogl3o`1io`;oA?l00oooool2o`0no`?oDOl03?ooool3o`0000?ooooo0_l0ok45ooooo`;o0?m`4_oo
ool00ol0003oooooooooo`1]ooooo`00I_ooool2o`0000;od?l02?ooool4om3o00Cooooo1Oo?o`03
ooooo`Gocol01ol0oo<4olko00?oob/01?ooool3ool[00Gooooo0ooo:`04ooooo`03o`3obooo:`3o
ob/000?ooooo00Co0000ooooooooooooP_l01?ooool2ogoo00?ooooo0_mno`02o`2?o`06ol7o0?l0
003o0000ooof0?l0003obol00ol000004?l;o`3o_Ol0o`3oXOl0ohSo_Ol0o`3mooo9o`3o0?n8o`00
0?l0D?oo5P3ooiWo0?l70?oo00Woo`_o0?nmo`03olOo0003o`3mool0J?oo02Ko00?o07oo00[ooad0
o`2:ooo7o`3o2ol0o`29oooo7@3o0?nQo`3oR?oo7@3oHol00ol000003Ol0oOoo2ol0oolM0?oo7@3o
05goooooooo7o`3o05goolWo0?l07?ooaol0o`3moooAo`000_l0ohP00ol0L_oo0?nQo`000003o`00
00?o08Go00GodOl0ok;o0?nbo`3oc_l0o`_o0002omgo0007oiSo0?l0NOoo07Woo`1iool0AOooG_l0
o`000003occo0004o`000?oooooo0?moooooo`?o@Ol000Coooooo`0Ooooooooooooo1?m4o`02oooo
o`CoDOl03oooool3o`0000;ooooo0_l0ok45ooooo`;o0?m`6?ooool00ol0003oooooooooo`0koooo
o`;o00000_oAo`02o`0000;ooooo1Oo@o`04ooooo`Cod?l01Oooool00omno`3ooooooloo0003oloo
00?ooooo00?o0?ocoloo0?o?o`000oo?o`03o`3ol`Goc_l01Oooool2ool[00Gooooo0ooo:`04oooo
o`?oob/000?oooooo`3oboooool01oooool01_n2o`3oooooo`000?oooooo05Coogoo00?o08oo00Co
0?o6ogko0?l0aOoob?l00ol000001OoomP3ooo@0o`3mool0003o0?go00?o000000Oo2ol0o`3oXOo9
o`3o_Ol0olWo0?nbo`3o0?n800;o000000Go2ol0oiWo0?l02OooG_l0o`1@o`03olOo00Co07oo0_o<
o`002?l0R_oo06SoolWo0?oo7@3o08WooolM0?l0oj7o0?n81Ol000000ol0oOoo2ol0oolM0002oolM
0003o`1Moooo7@3ooad000Sooad00ol000000ooAo`3o0000od?o0002olko00?o08Go0ooMo`000ooo
ooooV?l0o`000004o`0000?o??l00ol0NOl00om1o`3oooooooooo`02ooooo`CoA?l01?ooool4oe7o
00Gooooo0ol00005ooooo`03o`3o/Ooooooooooo00?ooooo0_l0og0Eooooo`03o`000?oooooooooo
06cooooo001Sooooo`;o000000?odOl0ooooooooool00_ooool5om3o00Oooooo1Oo@o`04ooooo`Go
col00oooool4oloo00?ooooo0_ooI@02oomW00Coc_l00_oo:`04o`3ol`?oob/000?o0?ocoooooooo
ool00_ooool2ool[0003ooooool0ol_ooooo00;ooooo0_oo:`000ooooooo0000ooooo`02ooooo`;o
P_l01?ooool01Omoo`3oooooo`3oSOoooooo0?n[00;oO_l000_o`Ol0o`000?l0003ooo@0o`000?oo
lP3o0000o`3oHOooo@3o0?goo`_o0002okgo0003o`3mooo9o`3o0?n800;ooad000Co0?nfo`1@oooo
7@3oVOl00oo7o`001ooo7@3o07ooolOo0?l0Oooo06SooolM0?l09_l00_oo7@003_l0R_oo0?mQo`_o
0?oo7@3o08Woo`1bool0oj7o07;oo`3oR?nno`3oHol0oooR0?l0ol7ooaL01Ol000001?l0GOoo0?n8
o`3o`Ol07?l2om7o0007o`1oool0ohSo0?goom3o0?l0Dooo0?nHo`000002o`25o`04o`000?m3o`3o
B?l0ok;o00CogOl00ol0NOl3oolM0003oeko0?l0AOoo000000?o00000ollo`04ooooo`?o@Ol000?o
ooooo`0nool0?_l00_ooool4odCo00;ooooo1?mAo`08ooooo`?o00001?ooool00ol0ok7ooooooooo
o`03ooooo`;o0?m`6_ooool00ol0003oooooooooo`0kooooo`;o00000_ooool5om7o00Cooooo1?o@
o`04ooooo`God?l000?oooooogko0?mno`000oooool4oloo00Gooooo1?o?o`001?ooIP3ooooooooo
ooo2o`04olko00?o0?oc0ooo:`04o`3ol`03oooooooo:`3oob/000Gooooo00?o0?o;ool[0?ooool0
2?ooool01On2o`3o0000oooooooooooo0?n=00;oOol000?o0?o6o`2?ool0Sol00_mno`03o`00000A
oood0?oooooooo80o`000?ooo@3o0000o`3oHOo9o`3o_Ol0olWo0?nmo`3o4@3oo`3oXOl0ohSo5P3o
o`3o]_l70?l00_oo7@02oiWo0005olOo0?l0D?oo07ooolOo0?l09_l01?oo7@000ol0R_oooad0o`1X
o`02oolM0004o`29ool0L_oo07;oo`3oX@;o07;o00GoHol0okgo0?oo5`3ooaL0o`3mo`02o`00000<
o`1Mool0omkodOl0o`3oR?l07?oo_Ol0o`3okOl0Ooood?l0o`3`ool0Dooo0?nH1Ol00003o`25o`?o
gOl000Cooad0ofoo0?oo7@3oV?l00_oo7@000ol0003ooad0o`000004o`1io`?o??l000?ooooood7o
0?m1o`000_m1o`04ooooo`?oA?l01Oooool4oe7o0003o`000?oooooooooo00Cooooo0_l0ok45oooo
o`03o`3oL?oooooooooo01Gooooo00?o0000ooooooooool0K?ooool005oooooo0_l00002om7o00;o
000000?oooooom7o0?oAo`000ooAo`04ooooo`God?l01oooool4om3o00Cooooo00?oTOl0oloo0?o?
o`000_o?o`000omno`3oooooooooo`05oloo00?oofD00_ooI`000oooIP3oc_l0olko0003olko00?o
oooo00?o`_l0ool[0?oo:`001Ol0oo<00ol0ol_oob/0ool[0004o`3ol`03ool[0?l0003oob/000Co
oooo0_n2o`03ooooo`;oOol000_o0?n[ooooool0olKoo`00ogko0?nmo`3ooo@0okgo0?l0003o_Ol0
o`000003okgo000=o`_o0?nmo`3o_Ol0o`3mool0oj7o0?n8olco0?l0okKo5P3oo`000?l0D?oo0000
oiWo0003o`1oo`06oolM0?o7o`3ooad0oolM0?l0J?oo02Ko0_o7o`002?l0R_oo0?mQo`_o0?l0L_oo
c?l0o`29ooo=o`3o0?nQ1Ooo5`001_nmo`3o0000o`000?l0GOoo0?n:oolG00Co00001_oo7@03o`25
o`;ooad01?l000003?oo7@3o07Woo`1iool0NOooKol0olgo0?nHo`3ooad0oooR0?mNo`3oon80oh?o
00Oo00000ollo`001?l07oooooooooooool0?_l4od7o00Gooooo0om4o`03ooooo`?oDOl00_ooool3
o`0000Gooooo0_l0ok45ooooo`03o`3oL?oooooooooo01[ooooo00?o0000ooooooooool0=oooool2
o`0000;odOl02Oooool4om7o00Cooooo1Oo@o`04ooooo`Cod?l01_ooool5oloo00?ooooo00?oofD0
oloo0?o?o`000_o?o`001?oooooo`_l0ol;o0?oo:`04olko00;ooooo0ooo:`001?oooooo0?oco`3o
lol0oo<3ool[0004o`3olol0ol_o0?oco`3ol`?oob/01oooool2oh;o000<o`3oSOoooooo0?n[oooo
oomoo`3o0<Gooooooooo003ob?l0ogko0?nmo`3ooo@00onmo`000ol0003o_Ol0o`000005okgo0006
o`3oXOl0ohSo2ol0oaH0ool0okKoaol00_l00002o`1oo`;oVOl000Gooad0olOo0?oo7@3o02Koo`3m
o`02olOo0003o`2:ool0J?oo07;o00?o07;o00?o08WoolOo0?l0oj401?oo5`000ol0HOoo0?m0o`3m
o`07o`0000Gooad000Co0?nHo`09oooo7@3ooad00ol0QOl00ol0003ogOl0oolM0002oolM0007o`3m
oom_o`3oon80oooR0?nHo`3oon80oeko0003o`1io`Co000000?o0?moooooooooool00ollo`02oooo
o`?o@Ol01?ooool3odCo0004ooooool0003o0000o`0000;ooooo0omAo`03ooooo`03o`3o/Ooooooo
oooo00?ooooo0_l0og0Hooooo`03o`000?oooooooooo06cooooo001Oooooo`;o00000_ooool5om7o
00?ooooo1OoAo`04ooooo`God?l01_ooool5om3o0004oi7o0?ooooooooooooooo`Gocol00oooool4
oloo00;oofD00_ooI`000oooIP3oofD0ool[0004olko0003ooooooo2o`3oob/000;oob/000?ooooo
o`3oboooool00_ooool2ool[00?ooooo00?o0000o`3olooo:`000_oo:`03o`3ol`03oh;o0?l0oo?o
0?oc00;o0?oc00CoOol0o`3olol0oo?o0<Go0ol000001?oolP3o0000o`000?l00002olWo0006odgo
0?nmo`3o08[ookgo0?l0oOoo0?n80_nmo`02o`2:o`04o`000?l0D?oo0000o`0000;oVOl000co0?go
o`2Hooo7o`3o0?goo`1bool0J?oo02Koo`1bool0R_oo0?mQo`_o0?o<o`02oolG000;o`29oooo5`3o
0?nQo`3oR?oo7@3o0?gooolM0?mSo`3ooaL0o`_o0?l0oOl00_oo5`001Ol0GOoooad0o`000?l0003o
0?o100?o00000ol0QOl00ol0Dooo00Woomgo0002omgo00;o00000ol0NOl00ol0003oKol0olgo0002
oooR000;oiSo0?oMo`3oG_l0omgo0?l0ROooPol0o`000?l0AOoooad0oh?o0?l0of@01Ol00003occo
00Gooooo0om1o`05ooooo`CoA?l000?oooooo`000?mAo`000omAo`04ooooo`;o0?na1Oooool2o`3o
L1gooooo00?o0000ooooooooool0=oooool2o`0000;ooooo1OoAo`08ooooo`GodOl01?ooool4om3o
00Cooooo1Oo@o`06ooooo`Cocol00_ooool2oomU00Cocol000Co`_l0ool[0?oo:`3oob/01?o>o`00
0oooooooob/0ool[0005ooooo`03o`3obooo:`3oob/000Cooooo0_oo:`05o`3ol`03o`000?l0oo?o
P_l000Co0?oc0_moo`004Ol0E?oob?l0o`000?l0003o0?goooob0?o9o`3oood0o`000?l09_oo0000
okgo0?nbo`3o_Ol0o`_o0?l0oOoo0?n800?o_Ol00_l0R_l4o`00000<of3o0?l0oOooVOl0olOo0?l0
9_ooH_l0olOo0?l0L_oo08[oo`1bool0J?oooad00ooo5`003?l0ROoooaL0o`3oXOoo7@3ookX0o`3m
oooohP3oHol0oolM0?l;o`3o0?gooolM00?ooaL01Ol000000ol0Oooo0?nHo`1Co`03o`25o`03omgo
0?l0003o000000?o00000_oohP001?m_o`3ofol0om_o0?oKo`03o`1io`07oh?o0?l0003o04Goo`2:
oooo7@3oPol0o`3oO`03o`000003o`0noooooooooooo00?o??l00_ooool3od7o00;ooooo0_l00004
odCo00Gooooo1?mAo`04ooooo`03o`3oL?oooooooooo01Sooooo00?o0000ooooooooool0K?ooool0
06Sooooo1OoAo`03ooooo`CodOl01Oooool4om3o00Kooooo00?oocd0om3o0?o@o`000_o@o`001Ooo
?P3oooooogko0?mno`3ooooo00Cocol00oooool5oloo0004oomW0?ooIP3oofH0oomU00;oob/01?o>
o`001?o2o`3o0?o;ool[0?oo:`04ooooo`?oob/000?o0000ooooooooool00_ooool2ool[00;ooooo
0_n2o`02ool00004oooooomoo`3oOol0o`3ol`;o000000Kooo80o`3mool0003o0?mQo`000?l0om@2
oolM0007okgo0?l;o`3o0?goo`3oR?nmo`3o__l0o`2:o`03okko0003o`L0ool0D?oo000000;ooad0
00?oVOl0o`1bool0L_l00_o7o`000ol0J?oo02KooolG0004oolG0005o`3oHOo<o`3o02Koo`29ool0
oj401Ooo5`001_mSo`3o2ol0o`1Qool0oOoooaL0o`1Mo`;odOl000?ooaL0olco0?oo5`000_l0QOl6
o`000004olko0?l0NOoo07Woo`1io`;oon8000?ocOl0ofoo0?l000000_oMo`000ol0oOooV?l0oeko
0002oolM0006oh?o0?oo7@3ooad0o`15oon3o`3ooad00ol000001?oooooo0000o`0nool00002oooo
o`Co??l01?ooool4od7o00?ooooo0_l00004odCo00;ooooo0_l000000ooooooo0?naooooo`05oooo
o`03o`3oL?oooooooooo01gooooo00?o0000ooooooooool0@?ooool5om7o00Sooooo1?oAo`02oooo
o`;oocd01?o@o`000oooF`3oO_l0ogko0002ooooo`Cod?l01_ooool4oloo00?oofD000?oofL0oloo
0?o?o`000oo?o`02ool[0003ooooooo>o`3oc_l000;oc_l00_oo:`000ooooooo0?o;ooooo`02oooo
o`;oob/01?ooool3ool[00;ooooo00?o0000ooooool0oj/00_n2o`02ool000;o0?oc00coOol0o`3o
lol0003o0000ooob0?o9o`3oood0oolM0?l0003o0?mQo`000?nbo`02okgo0006o`3mool;o`3o0?n8
okgo0?nno`3o08[o0onno`03o`000003oolM0?l0L_oo053o00;oVOl000?oaol0olWo0?oo5`000_oo
5`003?l0J?oooaL0o`3oHOoooooo_Ol0o`0Vool0ROoo0?n8o`3oXOoo^P3o0?goo`09o`;ooaL000So
2ol0oolG0?l0oOoooaL0olOo0?l0l?oooaL0om3o00?ooaL00ol0QOl01_l0003oc_l0ofKo0?l0ohSo
on80ok;o00;ocOl000?o0?3oo`000?l000001?l0NOl01OnHo`3ooad0oolM0?n3o`3o000000;ooad0
00GoPol0oolM0?l0003o0000o`0no`02o`0000Gooooo1?llo`001?l0003o@Ol0od7o0?m1o`05oooo
o`?oA?l00_ooool01?l0ok7oooooooooooooool2oe7o00;o0?m`6oooool00ol0003oooooooooo`1/
ooooo`00KOooool4om7o00?ooooo1OoAo`04ooooo`God?l01?ooool00ooo?@3oTOl0om3o0004om3o
00Cooooo1Oo?o`02ooooo`03oomU0?o?o`3ocol000?ocol00_ooI@02ool[0003ooooool0ol_oc_l0
00;oc_l00_oo:`05ooooo`03o`000?oo:`3oob/000Cooooo0ooo:`000ooo003oP_l0ooooo`02ool0
000<o`35oomoo`3o0000ooob0?l0oj7o0?goo`000?l0of7o0000oolM0?nbo`3o_Ol01?nno`02o`2:
o`07o`3oXOlF0?ooG_l0o`3mool70?oo07;oo`1@o`02o`1bo`03o`09oonIo`3o000000;ooaL000Go
06SooolG0?l0R_ooc?l0o`3oH@02olgo00?ooaL000co08Woo`000?l0003oc?l0okgo0?l0oOoookX0
o`_o0?l02Ooo067oo`3mool0GOl2o`000004oolG0?l0QOoo08Goo`25o`;ogOl00_l00002oolG00?o
07Wo1?l000001?oo7@3oKol0oolM0?oo7@02o`00000;oiSo0?mNo`3o0000o`000?n3o`3ogOl0om_o
0?l0ROoooad0oh?o0?l0of@00_l00002o`0no`04o`0Oool0003o0000o`0000Gooooo0ollo`05oooo
o`?o@Ol01_ooool2odCo00;o000000?o0?naooooooooool00oooool2o`3oL23ooooo00?o0000oooo
ooooool0AOooool4om7o00Sooooo1?oAo`001?ooooooTOl0oolm0?oo?@05om3o00Cooooo1Oo@o`05
ooooo`Gocol000CoofD0oomV0?ooIP3ooooo1?o?o`03ooooo`;oc_l000?o0?o;olko0?o>o`001?oo
ool3ool[00Cooooo0_oo:`000ol0003o0?n[ool00002ool00003oh;o0?oo003oo`0000;oobP000co
Ool0o`000?oolP3o0?nQooom0?lR0?oo01Ooo`000?l0of7o0000o`1ooonmo`04okko00;o08[o00Co
0?nQo`L0ool0oOoo_Ol01?l0L_l04?l0V?oooaL0o`1@ool0003oVOl0oolG0?l0R_ooc?l0o`3oHOl0
J?ooc?l0o`3oHOo<o`3o_Ol0olco0?l0ROl2o`0000?ooaL000Koon80of?o0?l;o`3oc?l0o`3moooo
5`02o`0000;ooaL00ol0QOl3o`000003oolG0?l0003o000000;o00000ooo7@03o`1io`;o000000?o
oad0oeko0?nHo`000_l000001_mNo`3o0000oolM0?n3o`3o08[ooolM00;o00000_ooool3o`0000Co
oooo0ol00003occo0003oooooom1o`3o@Ol000;o@Ol01?ooool4odCo00;ooooo0_l0000Mooooo`03
o`000?oooooooooo06cooooo001aooooo`GodOl00oooool5om7o00Cooooo1Oo@o`000oooooooTOl0
ooooo`02oolm0003oomK0?o@o`3od?l000;od?l01Oooool4oloo0004ooooooooI@3oofD0oomU00?o
col00_l0ol/2ool[00;ooooo1Oo>o`02ooooo`03o`000?oooooooooo00;oob/00_ooool2ool00003
oooooooo:`3oob/000;oP_l000?o0<Gooooooooo00001?l000000ol0of7o_Ol0o`000003okko000=
olOo0?l0oj7o08[oo`2:oolA0?oo0?gookgo0?l0oj7o07;oo`L0ool0L_oo0?oDo`1@o`02okgo00;o
00000_nIo`000oo;o`3o06Soo`2:o`05oolG00Cooad00_l00002oolM0007o`3moooo7@3o2ol0of?o
0?oo5`3o05goo`3mo`03o`25o`;ogOl01?oo5`03o`1io`;o000000?ogOl0oolH0?l000001_l00000
0ol0oOoo0000o`000003o`000003oh?o0?oo7@3oon8000;o000000Oo0?mTo`15oooo7@3o0;?ooolM
0?l07ooooooo00Go00001_ooool3occo00;o00000oooool3od7o00Gooooo00?o0?nao`000?l00000
0oooool2o`3oL2?ooooo00?o0000ooooooooool0B?ooool5om7o00Oooooo1OoAo`001?ooooooocd0
oolm0?oo?@04om3o0003oomK0?oooooooooo00;ooooo1?o@o`06ooooo`Cocol00_ooIP000ooooooo
`_l0oloo0003oloo0004o`3oboooooooooooooooo`Coc_l00oooool2ool[00;ooooo00?o0?n=oooo
ool000000_oo:`001?ooooooo`00ool00?n2o`03oolo00;o000000?o0?mQo`3mool000000_l00000
0ol0of7o__l0o`000002okko0007o`0Gool0ohSo08[oo`2:ool0omCo5P3ookgo0002o`3oX@03o`1b
oooo5`3ooaL000;ooaL000?o_Ol0o`000?l000000_l00002oiWo0003olgo0?l0of7o06So00GooaL0
00Gooad0o`000?l0003ooad0oonj0003oolG0005o`_o0?oo5`3ooaL0o`3mool000000ol0QOl5oolG
00;ooad000Co07;oo`000?l0003ooaP00ol0NOl01Ol0003ookX0o`3mool0ohSogol000;o000000Co
0?goo`000?l0003ooad00ol000001Ol0AOoooooooolM0?l0oj_ooad000?ooooo1Ol00006ooooo`?o
??l00_ooool3od7o0003o`3o/Ooooooooooo00;ooooo0om4o`0Nooooo`03o`000?oooooooooo06co
oooo001fooooo`GodOl00oooool5om7o00Cooooo1Oo@o`02ooooo`;oocd000?ooe/0om3o0?o@o`00
0oo@o`04ooooo`Gocol000?oofD0o`3oboooI`001Oo?o`001Ooo:`3ooooooooooooooooo`_l000Co
c_l00_ooool01?oo003oob/0ool[0?oo:`02ool000;ooooo0_oo:`02oh;o0003oolo0?l0003o0000
00?o000000coaol0o`000?nmo`3o_Ol0o`3oHOl0oj7o08[oo`_o0?lA0?oo0?mQo`3mool0okH6okgo
0009o`1@ool0003o0000o`000?oo5`3o02KooiWo0?l0J?oooaL000;o000000Cooad0o`0Vool0of7o
aol00oo<o`000oo7o`3o08WooolG0003oolG0003o`_o0?oohP3oHol000;o000000?o0?gooolG0?oo
5`000_oo5`001OoohP3o07Woo`1iool0NOooc_l000GooaP000?ocOl0o`000?l000000ol000000ooo
603o0000o`000005o`000003om_o0?o=o`3ooad000;o00000_oo7@000ol0AOoooad0oolM0002oolM
00;o000000Co103oo`000?l0003o00001?ooool3o`000004oooooollo`3o??l0occo00Gooooo1?m1
o`001?l0ok7oooooo`000?l00002ooooo`03o`3oL?oooooooooo02?ooooo00?o0000ooooooooool0
COooool5om7o00Kooooo00?oTOl0om7o0?oAo`000_oAo`001?ooooooocd0oolm0?oo?@05om3o0004
oomK0?ooooooooooooooo`God?l01?ooool00oooI@3ocol0oloo0002oloo0004oomU0?oooooo`_l0
o`3ob`Cocol00_ooool2ool[00Coc_l000Soooooool[0?oo:`3oob/0ool00?l0003oo`00oolo00?o
ob/000Co0;Gooh;o0?n2o`3oodT00_l000000oooo@3o0000o`000003o`0000;o_Ol000Oo0000okgo
0?l0oOoo08[oo`3oHOl;o`3o5P3o00;ooaL000?o_Ol0oolG0?nmo`001?nmo`001Onko`3o0000o`00
0?l0D?oooaL000;o000000GoVOl0o`000?l0J?oo007oo`3oH@02olco000;okgo0?oo5`3ooaL0o`29
ool0oj7ooaL0o`09ool0ogko2ol0oooR0?mSo`000_l000001Ol0QOoooaL0oolG0?oo5`3oon8000?o
oad000Co0?nboolH0?oo603ooaP00ol0NOl;o`000003obCo0?oohP3ooad000?o000000?ooad0o`15
oooo7@001?oo7@05o`0000[ooooo0ollo`000ooooooo0?naod7o0002od7o00;ooooo00?o0?m`oooo
ooooool00_m4o`0Mooooo`03o`000?oooooooooo06_ooooo001/ooooo`oo0:_o1?oAo`04o`2[o`Co
dOl01Ol0Zol4om3o00Ko0:_o1Oo@o`02o`2[o`;ooooo00Co0?o;oloo0?o?o`3ocol00_ooI`000ooo
IP3oofD0oloo0003oloo00;ooooo00?o`_l0o`000?oo:`001?o>o`02ool000?oob/000Goocl0ool0
0?oo003oooooool[0002o`000007ooom0?l0003o0000o`000?lR0?oo0000oolM0002o`000003o`2:
ool0oOoooaL000Ko_Ol000Go0?nQo`3oHOl0of7o^ol0o`1@o`02o`0000;o02Ko00Coaol0o`000?l0
J?oo0?l00_l00002o`3o00CooaL000[oaol0o`0Vool0ROooc?l0o`2_ool0oOoooaL0o`_o0?oo5`3o
05go0_l000000ol0oOood?l0oooR0003o`1io`CooaP000?ooad0ok;o0?oo7@000_oo7@000ooo603o
0000oolH0002oolH00;ooad00ol000000ooo603o0000o`000004o`00000;o`3o8?l0003o0000o`3o
8?l0003o04GooolM0?l40?oooad0o`@0oooo7@000_l0odP6o`0000Oooooo0ollo`04ooooo`03o`3o
/Ooooooo@Ol000;o@Ol000?oooooo`3oL?l0og009_ooool00ol0003oooooooooo`0loooooaKo0:_o
1?oAo`07o`2[o`GodOl01?l0Zol4om3o00Go0:_o1?o@o`03ooooo`;oofD00_o?o`001?l0ol_ocol0
ooooooo2o`02ool[00Gocol00ooo:`04olko0003ool[0?l0003oob/000;o0;Go00GoobP0ool00?oo
:`3oob/0oom90002o`000003ooom0?o7o`3o0?go00;o000000Ko0?goooom0?l0003o0?nQo`000?nm
o`02o`000003oolG0?l;o`3o_Ol000Co_Ol000?o0?mQo`3oXOl0of400_nko`001Ooo5`3o0000o`00
0?l09_oo053o00;o000000?o0?mQoiWo0?l0J?l01Ooo5`001Onmo`3oaol0o`29ool0oj7ookX000;o
oaL000?o2ol0o`1Moooo5`000_l000001?l0oOoofol0oolM0?oo7@04oolH00Co07Wo1?oo7@000om_
o`3ooad0oolM0002o`000003oolH0?l0003o000000Oo000000So0?nIo`000?l0003o04GooolM0?l0
003ooad0o`3oZ`Ko00002oooool01?l0ok7o??l0occo0?llo`02ooooo`?o@Ol00_ooool2o`0001go
oooo00?o0000ooooooooool0Joooool007oooooo1OoAo`03ooooo`GodOl000CoTOl0oooooooooooo
oooo1Oo@o`03oolm00?ooe/00oo@o`000ol0ol_o0:_oo`2[o`02o`2[o`Gocol00ol0Zol5oloo0004
o`2[oooo:`3oob/0ool[00Goc_l00_oo:`03o`2[o`;o000000Ooaol0o`29ool0oOoo0000okgo0?l0
003o08[o00;o00000onmo`001Ol;o`3o0?mQo`3o]_lF0?oooaL000;o00000_nko`001Oo<o`3o0?mQ
o`000?l0003ohol000;o_?l00_l000000ol0J?oo00WooolG0002oolG00?o0?oD00Go0?l0olOo0?oo
5`3ooaL0o`29o`02oolG0006oolM0?l;o`3ooad0o`1MoooohP3oHol00ol0NOl2oolH0005o`3oV?oo
7@3ooad0oolM0?o<o`001Ooo60000om_o`3o0000oolM0002oolM00Ko000000?oPol0o`000?l00000
1_l000000ol40?oo0?lPo`15o`03oolM00;o0?m80_oo7@000ol40?oo0000o`000002o`0000_ooooo
0ollo`000ol0ok7oooooooooo`02ooooo`03o`3oL?l0003o000002Oooooo00?o0000ooooooooool0
E_ooool5om7o0003oi7o0?oooooooooo00;ooooo0_mno`04om7o0004oooooooo?@3oocd0oolm00Go
d?l01?l0Zol4om3o00;o0:_o00?o0?o;o`2[ool0Zol01Oo?o`02ool[00;o0:_o1?o?o`000ooo:`3o
o`00ool00005olko0005ool00?l0Zoooocd0oolm0?oo:`000_l000002oo7o`3o0000o`3mool0L_oo
0?nQo`3moonmo`3o0000o`2:ool0003o_Ol000;o00000_nmo`000ol;o`3o1`3oodgo0002oolG00;o
000000Co^ol0olco0?l09_oo02Ko0_l000001ol0R_oo053oo`000?l0003ooaL0o`09ool0J?l00_nI
o`03o`3o000>oolG0?o7o`3ooaL0o`29oooo5`3o0?l0oolM0?l;o`3o05gooooR0?oo603oHol0oolH
0?l0oOl2oolH0009oolM0?l0NOoo07Woo`1ioooo7@3o/_l0o`09oooo5`3oaol000KooaP000Kooad0
oeko0?oo7@3ooaP0oolM0?oo6006o`00000<o`3o8?l0003o0000omgo0?l0AOoooad0o`@0oooo7@3o
ooooo`3oB?oo7@3o103o0_ooool2o`0000Sooooo00?o0?naooooooooool00_ooool3occo00;ooooo
0om1o`02o`0001cooooo00?o0000ooooooooool0Joooool008Cooooo1OoAo`03ooooo`GodOl000Co
ooooogko0?mno`3ooooo1Oo@o`02oolm0003oomK0?l0ol_ooe/000God?l00_ooool2oomU00Gocol0
00?o0000ool[0?oo:`001Oo?o`02ool[00;oobP01?o>o`000ooo:`3o0000o`000002o`000004oolG
0?l0003o_Ol0o`0000;o_Ol000Ko0?n8o`3mool0R_oooaL0o`0Vool;o`03o`0Vo`;o00000_o<o`02
okco00;o000000?o_?l0oolG0?l0R_l00_l000000ol0J?ooVOl0oiWo0002oolM00CooaL000Coaol0
omgo0?l0ohSo08Wo0_oo7@001Ooo603o2ol0o`1Moooo603oon8000;o000000Co0?l0o`3mool0o`3o
0?nH1Ooo6004o`3o0003ofoo0?l0003o000000?o000000?oG_l0oolH0?oo7@000_oo7@001Ooo603o
0?lPo`3o8?l0ob3ooaP000;o000000?o0?mToolM0?l000001?l000000ooo7@3o0000oolM0002o`00
0003oolM0?l40?oo000000Co00002_ooool2o`3o/@07oooooollo`3o??l0occo0?oooooo0?m`oooo
o`02o`0002Oooooo00?o0000ooooooooool0Foooool5om7o00;ooooo00CoO_l0oooooooooooooooo
1OoAo`04oolm00Cod?l000Kooe/0ooooooooooooooooom3o0?l0ol/3om3o00;oofD000?oofL0oomV
0?ooIP001?o?o`001?oo:`3oooooool00?oo0004oloo0004o`000?oo003oocd0oolm00Coc_l000Go
o`00o`000?l0003o0000oolG0002o`000009o`3oXOnmo`3o_Ol0o`000?nmo`3o0000o`3moonmo`3o
08[o00;ooaL000Go2ol0o`0Vool09_oo02Kook_o0002o`000004o`0Gool0oj7ooaL0oolG00;o0000
0_nlo`02o`000003o`09oooo7@3o06So00;ooaL000SoVOl0oolG0?oo5`3ogOl0olOo0?l0ohSo08Wo
o`3oX@;ooaP000Co2ol0oolH0?oo603ooad00_l000001?l0oOoo07Woo`1iool0NOl3o`3o00GooaP0
0_m_o`001?l0l?oooad0oolM0?oo7@06o`000004obCo0?oo7@3ooaP0o`3o80Ko000000Cooad0o`3o
B?l0odSo0?m80_oo7@001Ol0003ooad0o`000?l0003ooooo00;o00001Oooool2o`3o/@Cooooo0_l0
og02ooooo`?o??l00_ooool2od7o01cooooo00?o0000ooooooooool0Joooool008Wooooo1?oAo`02
ooooo`03oi7o0?oooooodOl000?odOl01Oooool2om3o0004o`3oboo@o`3oocd0oolm00Cooe/01?o@
o`000ol0]Oooo`00ool00002oolo00Cocol00_oo:`02ool000Cocol00_oo?@000oooooooodT0olko
0004o`000008okgo0?l0003o08[oo`000?oo5`3o0?n8okgo0?l0oOl2o`0Vo`03oolM0?l;o`3o5P3o
00;o^ol01?nlo`002_l0oj7ooaL0oolG0?l0D?oocOl0o`_o0?l0R_ooaol0o`09ool0J?l2oolG0007
oiWo0?oo5`3ogOl0omgo0?l09_ooaol0o`2Ho`02oolH0008o`3oXOl0ROoooaP0o`_o0?oo7@3o05go
oolM0?l0GOl2o`000004oolH0?l0oOoooaP0oolH00;ooad000?o/_l0oolM0?l000001Ol000001Ol0
o`3o0000o`3o0?l0o`3oG_l000?o0?l00ol0ob001?lTo`3o0?l0o`2coon3o`02o`000005oolM0?l0
003o0000o`000?oohP001Ol000000ooo7@3oc_l0olko0002olko00;o000000?oc_l0o`000?l00000
2?ooool00ol0ok7oooooooooo`03ooooo`04o`3oL?llo`3o??l0occo02Wooooo00?o0000oooooooo
ool0GOooool2oi7o0003oooooooAo`3odOl000;odOl01oooool4om7o0004ooln0?oo?@3oocd0oolm
00Cod?l000Go0?o;oomK0?ooooooooooo`2eo`04om3o0005oolo0?oo003oo`00ool00?ooool01?o?
o`001?l0oj_ooooooolm0?oo?@05oloo0004oom90?ooooooob/0olko00;o000000GooaL0ob80ool0
003o0000okgo0002o`2:o`05o`000?oo5`3o0000o`3moonmo`000ol09_l02?l0okKo2ol0ok_o0?nk
o`3ooaL0olco0?nmo`3ooaL01Onlo`001?o7o`3ooaL0o`1@ool02Ol2oolG0004o`1XoooMo`3ogOl0
omgo00;oVOl000Goaol0oolH0?oo603ooaP0o`29o`02oolM0004o`_o0?l0omCo0?oDoooR00;o0000
00?o07Woo`3moooo60001?oo6004oolM0003ofoo0?l0003o000000Co00001Ol0o`002OlTo`3o0?lP
o`3o8?l0ob3oPol0o`000?lTo`3ooad0o`3oB005o`000005oooooooo7@3oooooo`000?oo7@001?l0
00000ooooooo0000ooooo`02ooooo`03o`3o/Ooooooooooo00?ooooo00?o0?m`ooooooooool01Ooo
ool3occo01gooooo00?o0000ooooooooool0Joooool008gooooo1OoAo`03ooooo`GodOl000Cooooo
o`3obooooooooooo1Oo@o`02o`2eo`;oocl000?oo`00om3o0?o@o`000oo@o`001?l0003oofL0oomW
0?oo0005oloo0003o`3oa_oo003oo`0000Gocol01_l000002?l0oj7o0000o`3mool0ohSo_Ol0o`3m
ool0R_oo4@3o1Onlo`000oo<o`3ooaL0okgo0002o`000009o`3oXOoMo`3ooaL0o`1@ool0R_oooaL0
o`09ool;o`3o06So00;ogOl000?o01OooiWo0?oo60000_oo60002Oo7o`3ooaP0o`2Hool0ohSooad0
o`29oooo7@3o2ol0o`1Mo`03oolH0005oooR0?oo7@3oHol0o`3oV?l0oOl01Ol000002ooo603o00Wo
oolM0?m_o`3ooad0oolG0?oo7@3o0000oolM0?mNo`3ooaL000?o0?lP00OooaP0oh?o0?oMo`3o9?l0
oolH0?l0o`3oPol000;o000000?oc_l0o`000?l000000_o>o`02o`0000;oc_l01Ol000001?l40?oo
0000o`000?oo7@03o`0000Gooooo0_l0ok45ooooo`03o`3oL?oooooooooo00;ooooo00?o??l0o`00
0?l000009_ooool00ol0003oooooooooo`1Oooooo`03oi7o0?oooooooooo00;ooooo1OoAo`06oooo
o`CodOl000Gooooooolm0?oo?@3o0?o;o`2eo`04om3o0004oolo0?ooooooooooool000God?l000Co
ofH0oolm0?oo?@3oob/01?o?o`000ol0003oo`00ool[0002ool[00Cocol00_l000000ooo:`3o8P3o
o`000002o`00000:o`0Vool0oj7o0000o`3mool0003o0?gookgo0?l0R_oooaL0oaH0o`;o^ol01_nl
o`001?o=o`3ooaL0o`3oXOl0R_l2oolG0006o`0Vool02Ooo0000o`000?oMo`3o06So1Ooo60002?nI
o`3ooad0o`3oR?oo7@3o08Woo`3oXOl0GOoo2ol00ooo60001OoohP3ooaP0of?o0?l0omCo0?go00;o
0?oD00?o/_l0oolH0?l000001?l000001ooo5`3o07;oo`3oR?oo7@3oG_l0oolM0?oMo`000_oo7@03
o`3o8004oolH0?l0C?oo0?l0o`3o00;o000000?o0?l0o`000?l000000_oo7@06o`0000Koc_l00ol0
00000ol0ok7oooooooooo`02ooooo`;o0?m`2oooool2occo01_ooooo00?o0000ooooooooool0Jooo
ool0097ooooo00?oTOl0om7o0?oAo`000ooAo`03ooooo`03o`3obooAo`3odOl000;odOl00_l0]Ol2
oolo00God?l000Gooe/0ool00?oo003ooe/0ooooo`04om3o0003oolm0?ooIP3oobP000;oo`001?o?
o`001?ooB@3o`_l0ool[0?oo:`06o`000004o`2:ool0003o0?n8o`3mo`Co_?l000SooaL0o`3o]_l;
o`3oaol0olco0?ooo@3obol0okgo00;o000000KooaL0o`3oXOl0of7o08[oo`1@ool02Ol2omgo0003
o`1Xoooo603ooaP000;ooaP00_nIo`003?l05oooaol0on?o0?oo603o0?n8oolH0?l0oj7o08Woo`_o
0?l0GOoookX0oolM00Go000000?ooaP0o`3moonbo`000ooo7@000ol0omCoKol0ofoo0003o`3oe003
oolG0?l0003o0?lP00;o0?lP00?ooaL0olko0?o>o`001Oo>o`02o`3oB0;oc_l000?ooaP0oolM0?oo
7@001Ooo7@001?l0ob3o0000o`000?oo7@05o`000004o`1?ool0003o0000ooooo`;o00000_ooool0
0ol0ok7oooooooooo`03ooooo`;o0?m`1_ooool2o`0002Kooooo00?o0000ooooooooool0H?ooool0
0onAo`3oooooooooo`03ooooo`03ogko0?oooooooooo00GodOl00oooool2o`2eo`;odOl000Co0?o;
om7o0?oAo`3oocl00ooo?@05om3o0004ool00?oo?@3oocd0oolm00Cod?l000Coooooo`3oa_oo:`3o
ob/01Oo?o`03ool[0005ooooool0003o0000o`000?l0oOl00ol000001_l0L?oo0?nQo`000?oo5`3o
0000oolG00Ko_?l00_o<o`03oolG0005okgo0?oo5`3ogOl0omgo0?l0oj400_oMo`001_l02OoooaP0
o`000?l0003ooaP0o`1Xo`;ooad00_oSo`001?oo7@3oaol0oiWo0?nIo`02oolH000;o`29ool0GOoo
2ol0oolM0?l0HOoo08WooooR0?l0ROoooad0o`000?l0oOl01?l00002o`3oe003ofoo0?l0omCo0?o]
00?ooad000?oG_l0oolM0?oo7@000ol0ob001On3o`3ocOl0obCo0?oo603oPol000;o0?m80_l00000
0oo>o`3o0000o`000006olko00Ko00000_oo7@02o`000003ooooool0003ooooo00;ooooo00?o0?m`
ooooooooool02oooool2o`0001cooooo00?o0000ooooooooool0J_ooool009;ooooo0_nAo`03oooo
o`;odOl000Co0?o;om7o0?l0]Ooo0;Go0_oo?`04om7o00;oo`000_ooool00ooo003od?l0om3o0003
om3o0004o`000?ooF`3ooe/0oomU00God?l00_oo0002ool[00Cocol000Ko0000o`3mool0003o0000
o`3oXOl00002okco000:o`000?nlo`3o0?gook_o0?lA0?oo_Ol0o`29oooo5`3o2ol0olco00?ooaL0
00?o_Ol0oego0?l0oOl00_oMo`000ol0oj7ooaP0o`1@o`03oolH0005o`1Xoooo7@3ooad0oolM0?l0
oOl00_oo60001_nIo`3oaol0oolH0?l05ooo0?n8o`3ogP;o000000Co08Woo`000?l0003o00000_oo
60001Ol0oiSoon80olgo0?mSo`3o0?go00Cooad000?oKol0o`000?l000000_o>o`02o`3o8003o`00
0?o>o`3oc_l000;oc_l000Go0?oDoolM0?n3o`3ooaP0obCo0002o`3oB007oolM0?oo603ooad0obCo
0?oo7@3ooaP0ooooo`02oolM0007o`3o0?oo^P3ooad0oonj0?l0ob3ooad0o`3ol@02o`000003o`@0
oooo7@3o000000Co000000Co04ooo`000?l0003o0?na1?ooool2o`3oL33ooooo00?o0000oooooooo
ool0HOooool2oi7o00Cooooo00CoO_l0oooooooooooooooo0ol0]Ol4om7o00;oocl000Co0?o;oooo
oooooooooooo1?oAo`000ooo003oocd0oolm0002oolm00Cod?l000Coo`00oomU0?ooI@3oofD01Oo@
o`02ool[00;ooooo1?o?o`000ol0003o0?goo`000003o`0000;ooaL000Ko_?l0o`000?nlo`3o0000
okco0?nmo`02ok_o00;ooaL001Goc?l0o`_o0?oo5`3ocOl0o`3mool0olCo_Ol0omgo0?oo603o08[o
oolH0?l0oj7o00WoolOo0?oMo`3oGOl0o`1@oooo7@3o06Soo`3moooo7@000_oo60001?o7o`3ooaP0
oolH0?oo6002oiWo0003o`3oXOl0ROoo05go00Ko000000?o0?nbof?o0?l0oOl00_oo7@000ooo5`3o
08Woofoo0002o`0000?o0?oD00Coc_l0o`3o8?l0ob3o0?lP1?o>o`002OlTo`3oc_l0o`3oB?l0odSo
0?nIoolM0?l0003o9?l0oolH0005oolM0003oonj0?oo7@3ooad000;ooad00ol000001Ooo7@3o0000
o`000?l0003ooad000;o04oo0_l000000ol0og3oooooooooo`0Zooooo`03o`000?oooooooooo06[o
oooo002Dooooo`?o0;Go0_l0ol/2oolo00GodOl00_oo00000ooooooodOl0om7o0003om7o00;oocd0
0_oo00000ooo?@3od?l0om3o0002om3o0003ool00?ooF`3oofD000;oo`001?o@o`001?oo003oob/0
ool[0?oo:`04o`000006okco0?l0003o0000o`3oR?l0003o^ol00_l0oOl00olA0?oooaL0oolG0002
olco000@o`_o0?l0ROooc?l0omgo0?oo603oGOl0oolH0?l0oOoooaP0o`2:ool02Ooo0?o4o`1@ool;
o`3oaol0o`1Xo`CooaP00_oo7@000ol0003oVOl0o`000003o`000003oolH0?l0oj7o08Wo00;ooad0
00WookX0o`1Mooo>o`3oc_l0oooR0?o>o`3oHol0olko0?l0oOl00oo>o`000ol0Dooo0000o`000002
o`3o8005oeko0?oo7@3o0000oolG0?l0ohP00_oo7@000ooo5`3oPol0o`3oe002o`3oB00:o`3oe?n3
o`3ooad0o`3oI?oo603o9?l0oonj0?oo7@3ooaP0oonj00;ooad000Oo0?l0oolM0?oo7@3o0?oao`3o
8?oo7@3o000000?ooad02Ol00006o`1?oc3ooooo00?o0000ooooooooool0@?ooool[o`3o4@Goocl0
0_l0oa400ooAo`3o0?o;om7o0002om7o0003oooooooo003oo`0000;oocd01OoAo`03ool00003oolX
0?o@o`3od?l000;od?l00_ooI@02ool00003o`000?o@o`3od?l000;od?l000Coob/0oooooooooooo
oooo0_l000001?l0oOoo0000o`000?l00002okco0009o`3oR?l0003ooaL0o`000?nko`3o0?gooolG
0?lF0?oo08Wo00;oc?l000?o2ol0ooom0?oo60000_oo60003Onmo`3ooaP0o`2:ool0of7o2ol0o`09
ool0oj7oaol0o`3oHOmMo`3o053ooolH0?l0J?l00_oo60000ol09_ooc?l0olOo0002oolM00?o0000
00?oVOl0o`29ool000000_oo7@000ol0oiSooad0oooR0002oolM0003olko0?mSo`3o0?go00?oc_l0
00Co05?oo`000?l0003oc_l00ol0ob000ooo7@3o0;?ooolM0002o`3oe00=oh?o0?l0omCo9?l0o`3o
B?n3o`3o0?nIoolH0?oo^P3ooad0o`000?oo603ooad0ooooo`02oolM0004o`3o0?oo7@3ooad0o`3o
80?ooad000?o103ooolM0?oo7@000_l000000ooo7@3o0000o`000004o`0000Co04oo:?ooool00ol0
003oooooooooo`1Zooooo`00LOoooolSo`3o4@;oocl000?o0?o;oolo0?oo?`001Ol0oa42ool000Go
dOl000?oocd0o`3o4Ooo00001OoAo`001?l0003oo`00ool00?l0oa45om3o0004o`3o4OooB@3oo`00
o`3o4@God?l00ol000003ol0oa7o0?nQo`000?nko`3o0000o`3mooo7o`3o_Ol0o`3mool09_ooc?l0
oaH0oooo603o2ol0oolH0002o`29o`0=o`2:oomMo`3oood0oolM0?l0R_oo00WooolH0?l0oj7o053o
oolH0?o7o`3o0?mQo`1Xo`05o`000003olOo0?oo603oVOl000Coc_l000?o2ol0olko0?l0ROl00oo>
o`002Ol0oiSooad0ok;o0?oohP3ohol0of?o0?oo7@3o0?goofoo0003o`3o80;ooad000KoG_l0oolG
0?oo^P3o0000oolM0?oo5`03oonj00;o0?m800Cooad0obCo0?n3o`3ooad00_l0om@01Ooo603o0?oD
obCo0?oo7@3ooaP000Cooad000?o0?l0oolM0?oo7@000_oo7@001Ol0ob3o0000oolM0?l40?oooad0
00Co000000?ooad0olko0?l000000_l00002o`3oL0?ooooo1_l0ColZooooo`03o`000?oooooooooo
067ooooo1Ol0]Ol00oooooooocl0oolo0002oolo00Oooooo00Go0?o;o`3o4Ol0oa7oocd0ool00005
om7o00?o0?lA0_oo0004om7o00;oo`000_l0oa45om3o00?oo`0000?o0?lAom3o0?o@o`000_o@o`02
o`000004o`3mool0003o0000o`0000;o0?nQ00[ooaL0o`000?nko`3o0000olWo0?nmo`3o0?gooolH
0?o<o`3ooaP00_l0ROl02Ol;o`3ogOl0oolM0?oo7@3o0?gookgo0?l0R_oo0?mQo`09o`02oolH0007
o`3oXOoo603oGOl0oolM0?l0D?oo06SooolM0003o`000003olOo0?l0003o000000;oc_l000Co05go
olko0?nIo`3oVOl01Oo>o`002OoohP3oc_l0o`3oUooo7@3o0?gooolM0?m_o`3o05?oo`09o`03o`3o
8003oeko0?oo^P3ooad000;ooad00_oo^P001On3o`3ooad0o`3oB?l0odSoPol000Go0?oD00?o0000
oolM0?oo60001?oo7@000ol0o`3ooad0oolM0004oolM0004o`@0oooo7@3ooad0oolM00?o00000_oo
7@03o`0000?ooooo1_l0ColRooooo`03o`000?oooooooooo06[ooooo002:ooooo`Go0;Go00?ooooo
oolo0?oo?`000_oo?`001?oooooo0?o;oi7o0?nAo`03ooooo`03ogko0?oo003oo`0000;oocd00ooo
0002ooooo`CodOl000Co0?lcoooooooo003oo`001OoAo`001?l0olKoooooool00?oo0005om3o0004
ool00?ooI`3oofH0oomU00?o00000_nko`005_l0003o0?nQo`000?l0oOooaol0okgo0?l0R_oo0?go
okgo0?lF0?ooc?l0o`L0ool;o`3ocOl0o`000?l0ROoo_Ol0oego0?l0R_oo00Woo`3moooo7@02o`00
0004o`1@ool0003o0000o`1Xo`Coc_l01?oo7@02oiWo00Cooad00_l00004oolM00;o00000ooo7@02
o`0000?ooad00_l00002oolM00?o000000?ooad0o`000?l000000_l000001Ooo603o0000o`000?l0
oiWooaP000;o00000_oo6002o`000003o`3oe?oo603o000000;o000000Co0?oDoolM0?l0o`3o08[o
0_oo7@001?l0ob3ooad0o`@0ool00003oolM0004o`000?oo7@3ooad0olko00;o00002oooool6o`1?
o`03ooooool0003o000002;ooooo00?o0000ooooooooool0F_ooool6o`2eo`03oooooooo?`3oocl0
00?oocl01?ooool2ogko00?ooooo00?oocd0o`3obooo?@000ooo00000oooooooo`00ool00003oooo
o`CodOl00_oo:002ool00003o`3oZooAo`3odOl000?odOl00_oo?@000oooB@3o0000om3o0003om3o
0005ool00?ooIP3ooooooooooooo:`000_l000003Ol0oOoooaL0o`000?l0ohSo08[ook_o0?l0003o
0?gooa40ool0003o_Ol0olco0?l0oOl00_oMo`000ooo7@3o_Ol0o`_o0002o`29o`;ooaP000ko_Ol0
oolH0?l02Ooo05goo`_o0?oo7@3oaol0o`3oXOmMo`3o0000o`1@ool0J?oo0000olko00_ooad000?o
VOl0o`000?oo7@000_oo7@02o`0000?ooad00_l00003oolM00;o00000_oo7@03o`000005oolM0?l0
003o0000o`000?lTo`000_l000001Ol0oiWooaP0o`000?l0003ooaP000?o00000_l0om@3o`000007
oolM0?l0003o02KooolM0?l0AOoooad0o`@0o`02oolM0004ooooool0003o0000o`0000;ooad00ol0
0009ooooo`Oo04oo6oooool00ol0003oooooooooo`1Zooooo`00QOooool5o`2eo`;ooooo1?oo?`04
ooooo`05o`3obooooooooooooooooonAo`000ooo00001?oo?@3oO_l0ool00?oo0003ooooo`;oo`00
1?ooool5om7o0004ool00?l0oj_oooooo`3oaPCodOl00_ooool2ool00003oolm0?o@o`3od?l000;o
d?l01?l000002_l0ohSo0000oolH0?l0003o0?nQoolH0?nmo`3oc?l0o`3moolF0?l8oolM0003oego
0?l02Ooooad000Gooad000?o053oo`000?l000002_oo7@001?nIo`3ooad0o`_o0?oo7@02o`0000Co
oad00_l00002o`3o8006oolM0?l0003o0000oolM0?l02OoooaP00_l00002oolH00?o000000?ooaP0
o`000?l000000_l000001Ooo7@3o0000o`000?oo6@3o0?mT00;o00000_oo7@02o`000003oolM0?l0
k_oo000000;o00000_oo7@000ol0omCo0?l0o`3oe002oolM0007o`3o8?oo7@3o0000o`000?oo7@3o
d?l0oolM0005o`00017ooooo00?o04ooo`000?l000008_ooool00ol0003oooooooooo`1Eooooo`Go
0;Go0oooool4oolo00Gooooo00?oTOl0ooooooooool00_ooool4oolm0004o`3obooo003oo`00oooo
o`?oo`000ol0oc<2ool000?ooooo00?oo`00om7o0?oAo`000ooAo`001Ooo003oooooo`35oooooooo
o`0000CodOl00ooo00000oooI@3od?l0om3o0003om3o00Ko000000[o^ol0oolH0?l0oj7o0000o`3o
XOl0003oc?l0oaH0ool70?oo0?go2?oo7@000onmo`3o00WooolM0005oolM0004oego0?oo7@3o0000
o`0000gooad000?o0000oiWo0?nIo`000_oo7@02o`0000;ooad000Co0?lPo`000?l0003ooad00_oo
6002o`0000;ooaP00ol000001Ol0odSo0000o`000?l0003o9?l000;o000000GooaT0oolH0?l0003o
0000oolH0003o`000003oolM0?oo603o000000;o000000Co0?oDoolM0?l0omCooad00_l0om@2oolM
0004o`000?oo7@3ooad0om3o00;ooad00_l000000ooo7@3o0000ooooo`0?ooooo`03o`1?ool0003o
000001Sooooo00?o0000ooooooooool0J_ooool0083ooooo1Ol0]Ol3ooooo`Coocl01oooool01?l0
ol_ooooooolm0?oo?@02ool00003oi7o0?oooooooooo00;oo`0000?oO_l0ooooooooool00_oo0003
ooooo`?oo`000_oo:002ool00003o`000?oAo`3odOl000?odOl000?ooooooom90?oo00001OoAo`00
1?oo003oocd0oomU0?ooI@03o`0000;o0=Co00Go0000oolM0?l0003ooad0o`3oX@03oolM0003o`3m
oooo7@3ooad000;ooad000Go2ol0oolM0?oo7@3ooad0oego0007oolM0003o`1@ool0003o000000Co
oad000?oaol0oolH0?oo60000_oo60002Ol0ohSooaP0oiWo0?l;o`3o0?nQoolH0?l0ROoookX0ok;o
0003o`3o8009oolH0?m_o`3oon80o`1Cool05oooHol0o`3mool02OooG_l000;ooaT000Cooad0on?o
0?oSo`3o00000_l0odP02?oo7@3oPol0oolM0?oo7@3oaol0obCo0?oo5`3o0?mT0_oo7@001Ooo603o
0?oao`3olOlTo`3ooaP000;ooad000?o0?m8oolH0?oo7@000ooo7@001?l09_oo0?l0oolM0?l0AOl3
oolM0009o`3oe?l0003o0000o`000?oo7@3oc_l0oolM0?l0003ooad003Kooooo00?o0000oooooooo
ool0Coooool6o`2eo`?ooooo1Ooo?`09ooooo`Goocd00_ooool01?mno`3o0?o;ool00?ooool2ool0
00Cooooo0_oo00000ooooooo0?lco`3o<`02ool00003ooooool0ohgooooo00;oo`0000?oooooom7o
0?oAo`000ooAo`001?ooB@3oooooool00?l00004om7o00;oo`000_ooI@000oooI`3o0000o`000002
o`0000?o0=Co0_oo7@000ol0003o0?nQo`000004oolM0003o`3moooo7@3ooad000Gooad000?o00Wo
oolM0?oo7@001Ooo7@001OmMo`3o0?nQo`000?l0003ooad000;ooaP000Koaol0oolH0?oo603ooaP0
o`3oR?l0GOl2oolH0006o`_o0?l0oj7o08WooolH0?nbo`3oVOl00ol0ob002_oohP3oKol0o`1Coooo
603o0?goo`1CoomNo`3ooaT0oolG0?oo7@03on?o00;o0?m800koPol0oolM0?oooooooad0obCo0?oo
5`3o0?nIo`3oI?l0oo7ooaP0oooooooo603o0000obCo00;ooad000co0000oolH0?oo7@3ooad0o`0V
oooo7@3o0?l0oooooooo7@3o0?lPo`3oe?oo7@02o`3oe003oolM0?l0003o000000;o000000?ooad0
o`000?l000004Oooool2o`0001Sooooo00?o0000ooooooooool0J_ooool007_ooooo1Ol0]Ol3oooo
o`Goocl02Oooool01?oo?@3o0?o;oolm0?oo?@02ool000?oocX00_oo000Aoolj0003o`000?oo>P3o
ocX000?oocX01?oAo`04oolj00CodOl00ol00002oolM0003o`000?l0e?oo000000;o0=Co0_l0oj42
o`000005o`3mool0ROoo0000o`000?l;o`000_oo60001?l02OooGOl0oolH0?l0of42oolH00?o08Wo
0_l000002?oo603ooad0oolM0?oo7@3ooaP0olOo0?l0oOoooad00ol0ol@03_l0GOoocOl0oiWo0?nI
o`3o0?nHo`3o8?l0ROoo0?lPo`09oooo7@3o067oofoo0?l0V?oo05?o0_oMo`000omSo`3o0?gooeko
0002o`0Go`0@oolM0?oo5`3o0;?oo`3oB?l0003ooaL0oolM0?n3o`3ohol0oolG0?oSo`3oPol0obCo
0?oo7@3ooaL0oolM00;o0?oa00CooaP0oolM0?l0003o00001?oo7@002Ooo603ohOl0on7o0?oo7@3o
okX0o`29oooo7@3ooooooolM0004o`000004o`3oZooo7@3ooad0oolM00?o0000=_ooool00ol0003o
ooooooooo`1:ooooo`Go0;Go1Oooool4oolo00[ooooo1?oo?@05oolj00;oo`0000Co0?o;oolj0?oo
003oo`005_oo>P02oom900CodOl01?oo>P05om7o00Go00000_oo7@02o`3Do`04o`000?l0e?oo0000
o`3oX@Co08Wo00?o0?goo`29ool0ROl00_l000001Ol0R_oo00WooolH0?nmo`3o0?mQ00;o08Wo00Co
oad0o`3oHOo7o`3oGOl00_l000002Ooo7@3o053ooolH0?oo603oaol0oolM0?l09_oooaP0o`1Mo`02
oolM0005o`3oV?l;o`3o0?nQoolM0?l0ROl00_l0ob02oiWo0004omgo0?oohP3o05?oomgo00;o01Oo
00?o0?gooolM0?oo7@000_oo7@001Ol02Ooo0?m8o`3oB?oo7@3oPol000Cohol000Co9?l0o`3oVOoo
5`3o0?mT0_oo7@001?oo603ooad0o`000?lTo`02o`0000;ooaP000?ohOl0oolM0?oo7@000_oo7@00
1?l0o`3ooad0oolM0?l0ob02oolM00;o000000Cod?l0olko0?oo7@3ooad00ol0000/ooooo`03o`00
0?oooooooooo06Wooooo001WoooooaSoocX01?oo?`0:oolj00Coocd000Co0?o;oolj0?oo003oo`00
0oooool2ool000;ooooo0_oo0003ooooo`03ogko0?oo003oo`0000;ooooo0_oo0002ooooo`09o`3o
SOoo003oo`00o`000?oooooo0?o6oooooooo003oodT000;ob?l00_oo0005om7o0003ool00?m2o`3o
@_l000;o000000?o0?goo`000?l0oOl01Ol00004o`3Do`0@o`000?l0oOoo0000o`000?l;o`3ooad0
o`09ool0R_ooGOl0o`2:ool0of7ooad0o`_o0?oo7@3ocol0o`3mo`;o0000027o053oo`3oHOo<o`3o
c_l0oolM0?o7o`3ooad0o`2Iooo@o`3o0?m0oolM0?l0GOoo0?o4o`_o0?l0oj7oVOl0ok;o0?oo7@3o
08Woo`09ool;o`3oKol0oolM0?l0Dooo09SooooR0?l0of7oG_l0of?o0?l0oOoo05?oomgo0?l05ol0
0_l0odP03Ol05ooo0000o`3oR?n3o`3ooaP0o`1boooo7@3oPol0obCo0?oSo`3o0?mTon?o0?oo5`00
0_oo7@02oolH00;o00000_oo7@02on7o0003oolM0?oo603o02Ko00;ooad000?o08Woo`000?l00000
0_l00002oolM0005o`3oL?oo7@3ooad0o`3oe?oo7@000_l0000gooooo`03o`000?oooooooooo03Ko
oooo6Ooo>P05oolo00WoocX01Ooo?@04oolj00?ooooo0_oo00001onAo`3o0?o;ool00?oo003ooooo
ogko0?ooool00_oo0003ooooo`;oo`0000?oobP0od;o0?m2o`000_oo0002od;o0008o`3oZooo003o
o`00od;o0?l0aOoo@_l0oom90?oo0003od;o0003ool00?l0003odOl000CodOl000Coo`00od;o0?m2
o`3o@_l00ol000001_l0oa3o0?goo`3o4?oo603o08[oolco00?o00001?l0e?l2o`00000;o`3moooo
7@3o0000o`000?l02OoooaP0o`_o0?nmo`3o0?mQoolH0?l0oOl00_l0ROl04?o7o`3oGOl0o`000?l0
003o0?mQoolM0?l0D?ooaol0o`3o@?l0oOoo02KooolM0?l0GOood?l0o`3oV?l;o`02o`3o8004o`3o
XOl;o`3o08Woo`1Qo`;ooad00_nIo`001_oohP3oooooomgo0?mNo`3o00Woo`3mo`;o01Oo0_l0odP0
1?l0ohSo04cooolG0?n3o`02oolM0003oolG0?lTo`3o0?nI00?ohol00_oo7@001?oo603o0>;oo`00
0?lTo`02o`000003on7o0?oohP3ooaP000?ooad000GohOl0oolM0?oo7@3o0000oolM0002o`0000;o
oooo00Cooad0o`3oe?l0omCooad00_l0000]ooooo`03o`000?oooooooooo06Wooooo001cooooo`?o
0;Go1Oooool4oolo00Wooooo1Ooo?@03ooooo`03o`3obooo003oo`0000;ooooo0ooo0002ooooo`;o
o`0000?o@_l0oi7o0?m2o`000ooo00001?mno`3o@_l0ool00?oo0003od;o00;oo`0000?o@_l0o`00
0?m2o`000ooo00001?ooB@3o@_l0ool00?oo0004ooooo`;oo`0000Co0?lcom7o0?nco`3o/ol00_l0
00003?l0oOoo0000o`3mool0003o0?goo`000?oo603o4@3oo`3oXOl0R_oo5P3ooolI00?o0=Co0_l0
00001Ol02Ooo0000o`000?mMo`3o_Ol000Oo000000Oo0?nQo`1@ool0ROoo08WooolM0?o7o`3o_Ol0
00;o00000_oo7@02o`3o800Co`_o0?l0oiSo/_l0o`3oXOnIo`3o0?nbo`29ool02OooKol0o`1Qool0
Dooo2ol0oolM0?oohP3oG_l0olWo0?l0oh[oHol0o`3mo`02o`3oB0?ogOl000co0000oh?o0?l05ooo
oaL0o`1bool0ongoPol0obCo0?oo7@3o0?mToolM0?oo5`02on?o0004oolM0?oo603o9?l0o`2Fo`;o
oad000KooaP0oolM0?oo7@3ooad0oolH0?oo^P06o`0000Cooad000?o0?oDoolM0?l000000_l0000g
ooooo`03o`000?oooooooooo04;ooooo0ol0]Ol6ooooo`Coocl02_ooool4oolm00Wo@_l00ooo0000
1?m2o`3oo`00o`3obonAo`02od;o00?oo`000_m2o`03ool00003oolX0?m2o`3oo`0000;oo`0000?o
ooooo`3oSOooool00_oo00001_l0olKob?l0ool00?oo003oodT0olSo00;o0?lc0_oo00000oo8o`3o
0000olSo0003ool00005oooooooAo`3odOl0om7o0?nco`000_l000003_l0oOoo0000o`000?l0oOoo
0?l@olco0?lA0?oo0000o`3o4?l0003o0?nQokgo0?oo7@3o0?nQ1?l0e?l00ol0003o00Woo`000002
o`000003okgo0?l0003o000000?o000000Wo08Wooego0?l0ROoo0?nQoolM0?o<o`3o053oolOo0?oo
7@000_l000006?l09_oo05goo`3o8?l0ob3o2ol0olgo0?l0GOoo0?nQoolM0?l0ROoooad0o`_o0?m_
o`3o05?ooolM0?nIo`3ooad0oeko0?l0/ooo00Woo`3moomSo`3o0?m8omgo00?o01Oo00[oPol0oolM
0?l0L_oo0?oaoh?o0?lTo`3o0?nIoolM0?l0ofCooaL01?oSo`000ol0003o9?l0oolH0002oolM0004
oolH0?l09_oooad0oolI00?ooad01Ol000000ooo7@3o0?oDoolM0002oolM00?o0000;Oooool00ol0
003oooooooooo`1Yooooo`00Moooool4oolo00Wooooo1?oo?@05ooooo`03od;o0?l0ol_o0?o;00?o
@_l00_oo0003od;o00;oo`000oooool2ool00003oi7o0?oooooooooo00;oo`0000?oO_l0oooooooo
00000_oo00002?l0ohgoooooo`3oZol0003oo`00o`3oa_ooooooodT00_oo0003ooooo`?oo`000_oo
ool01?oo003o/ol0ooooooooool2o`00000=o`3mool0003ooaP0o`000?l0oOoo0000oa40ool0R_oo
0?nQo`2:oolF0?oooad0okgo0002o`3oX@07o`3Dool02Ooo0=Coo`3Dool0oa3oGOl0o`000003o`3o
40Ko000000?o053oo`000?l000002ol000004?l0oj7o0?o4oiWo0?l0GOoo08Woo`09ool0Dooo067o
oolM0?o7o`3oG_l0oooR0?l0V?oo00Woo`3oB?l0oOl2oolM0006o`3`oooo7@3ooad0o`000?n3o`3o
gOl00_l05ol01On3o`3o0000o`000?l0ofCooaP000;ooad000CooaL0oolH0?o4o`3o0>ko0_l00002
oolM00;ooaP000?ooad0o`000?l000000_l000001Ooo7@3o08[ooolM0?oo7@3o0?l000?o0?oD00?o
oad0o`000?l000000_oo7@000ol0003oooooooooo`0eooooo`03o`000?oooooooooo04Oooooo1?oo
?`0:ooooo`Coocd02oooool2ool000;ooooo0_oo00000ol0ol_oooooooooo`02ool000?ooooo0_oo
00000oooooooobP0oolX0002ool000?ooooo0ooo00001ooooooo0?o6ool00?oo003ooooooom90?oo
ool00ooo0002ooooo`03o`3o<ol0003oo`0000;o0?lc00?ob?l0ool00?oo00000_nco`001?o8o`3o
0000o`000?l0oOl2oolH0009ooooooo<o`3o0?gooa40ool0003o02Koo`000?l0oj7o_Ol000?o0?l@
00Go0?nQo`3o4?l0oa3o0=Coo`09o`03o`3Do`;o000000Kobol0o`2:ool0of7o0?goo`000?mMo`05
o`000003o`1@ool0003o000000;o000000oo0?lPodgo0?m=o`3o2ol0ok;o0?l0GOoookX0o`3oXOoo
oooo08Woofoo0?l0Dooooad0o`2Hool;o`000_nIo`001Ooo7@3o00Woo`3oB?l0oOooHol000;ooad0
00?ooaL0oh?o0?l05ol00ol05ol03?n3o`3o9?l0o`3oc?oo7@3o0?mToolM0?oo5`3ooaP0on7o0?l0
k_oo0000obCo00;o000000Kooad0o`0Vool0h_oooad0oolH0?oo7@02o`0000;ooad000Co0?l0o`@0
ool0omCo0?oD0ooo7@02o`000003oolM0?oooooooooo02cooooo00?o0000ooooooooool0JOooool0
07?ooooo1?oo?`09ooooo`Coocd02?ooool00ooo003o0?o;ooooo`02ooooo`;oo`000_ooool3ool0
00?ooooo0_oo0002ooooo`?oo`000_ooool2ool000;ooooo00So0?n=ool00?oo003oo`00o`000?l0
olKoo`00oom900Cooooo0_oo0002ooooo`;oo`000_nco`02ooooo`06ool00?l0003o0000o`3mool0
003oc?l00_l000002?oo7@3o0000o`2:oonmo`3o0?nQoaH0ool09_oo_Ol00_l000002ol02Ooo0?go
o`2:ool;o`3o0=Cooego0?l0003o0?mQo`2:oooAo`3o_Ol000Co0?l@00Go0?nQo`1@ool0oa3oood0
olOo0002o`3o8003o`3mool0003o000000So00000_nIo`0:o`000004o`_o0?l0oOoo2ol0o`_o00?o
000000GooaL0o`3olOl0oo7oPol0o`3oV@02o`0000;o01Oo00KocOl0o`oo0?oo7@3ooaL0o`3^oooo
7@02o`0000;ooad01Ol000001Ooo603ooad0o`2moooo7@3o08[o00;o0?oD00?o103ooolM0?oo7@00
0_oo7@02o`000003oolM0?oooooooooo01;ooooo0_l0000Rooooo`03o`000?oooooooooo04;ooooo
1Ooo?`09ooooo`Goocd03Oooool2ool00004oooooooo003oo`00ool000;o0?o;0ooo00000ooooooo
TOl0ool00002ool00003oooooooo:03oobP000;oo`000oooool2ool000;ooooo0ooo00000ol0aOoo
oooooom90002ool000?ooooo0ooo00000ol0003oooooool00002ool000;o/ol000?o0?lcool00?oo
00000_l000001?l0oOoo0000oolM0?o<o`02o`3mo`07oa40ool0003ooad0oaH0ool0003o0?nQo`2@
o`03oolM0005o`3oXOl0003o0000o`3mool;o`000_l0oa02o`0000;o0?l@00[ooad0o`0Vooo7o`3o
GOl0ooom0?oo7@3o0?nQo`29ooo7o`3o053o0_l0ob000ol0oOoo05goo`000008o`000003o`29ool0
003o000000;ooad000GoG_l0oooR0?l0oh[oVOl0o`3oB002o`_o0005o`3mool;o`3o2ol0o`3olOn3
o`000_oo7@001?oo5`3oPol0obCo0?l05ol2o`000008oolH0?oooooohOl0oolG0?l0k_oooad0o`00
0?lTo`02o`000004oolM0?l09_oooaP0o`29o`;o00001?oo7@02o`3oe005olko0?oo7@3ooad0o`00
0?oo7@000_l000000ooo7@3oooooooooo`0Booooo`;o00006?ooool00ol0003oooooooooo`1Yoooo
o`00K_ooool5oolo00Wooooo1?oo?@0:ooooo`;oo`0000?o0?o;ooooooooool00_oo0002ooooo`;o
o`000oooool3ool000;ooooo0_oo0002oolX0003oi7o0?oo003oo`0000;ooooo00WoO_l0ool00?oo
003oooooo`3oZooo003o0000ool00?ooB@000_ooool3ool000;ooooo0_oo0002ok?o00;ooooo0_oo
0002ooooo`Ko000000Kooad0o`000?oo7@3o_Ol0o`3oXOooool2olco00;o000000So_Ol0o`2:ool0
oOoo2ol0oolM0?mMo`3o2ol0okgo00?ooad000Wo0?mQolko0?oo7@3oaol0o`3oXOl0ob3o053oo`3o
8?o7o`000_l0oa003_l0oOoo08Woo`1Mool0oiSo0?n8o`_o0?l0e?oo0?gooolM0?l0oj7ooad0o`1M
ool0DoooVOl02ol000000ol0oOoo0000o`000008o`000003o`3oI?l0003ooaL000?o01Oo00Co0>ko
oolG0?o<o`3o9?l01Ol000001_oo603ookX0oolM0?l0ROoooaP0oolM00;o0?oD0_oo7@001_l40?oo
oad0o`3o0?oo7@3o0000oolM00;o00005?ooool2o`0002;ooooo00?o0000ooooooooool0?_ooool4
oolo00[ooooo1?oo?@0?ooooo`?oo`0000?oooooool00?oo00000_ooool00ol0ol_oo`00ool00003
ooooo`;oo`0000?ooooooi7o0?ooool00ooo00000omno`3oooooool00002ool0000:o`3oSOoooooo
o`00ool00?oooooo0?o6o`35oooo003oodT0ool000?ooooo0_oo0003ooooo`05o`000?oo003ooooo
oooooonco`000ooo0003o`3o<`05o`000?l0oOoo0000o`000?oo7@000_l0oOl02Ol0ohSo0000o`00
0?lF0?oo0000o`3oXOnmo`3o03?oooooo`02olco00;o000000So0?nQo`3mool;o`3ooad0o`3oHOnm
o`3o07ooo`3oH@?o0?l@01OoGOl0o`3o4?l0oa3o0?nQo`3o8?o7o`3o0?m0o`1@ool0ROoo0?gooolM
0?l0ohSo02Kook;o0?l;o`3o0?goo`1Moooo^P3o0?nQo`1Cool0olCo08WooolM0006o`0000;oVOl0
00?o0000o`3mool000000ol000001_l0Oooooad0oolM0?n3o`3o9?l0oolH00;o00000ol05ol02?l0
k_oooaL0oolH0?l0003o9?l0oolM0?oSo`3ooad00ol00004oolM00;o0?oD00?ooad0olko0?l40?l0
0_oo7@02o`000003o`3oZol0003o000001Cooooo0_l0000Hooooo`03o`000?oooooooooo06Wooooo
001Zooooo`Coocl02_ooool4oolm00_ooooo0ooo00000ooooooo0?o;ooooo`02ool000;ooooo0_oo
0003ooooo`;oo`000oooool2ool00003oooooooo:03oo`0000;oo`000_nAo`001Oooooooo`00ool0
0?l0ohgooooo00;oo`0000Co0?o6o`000?ooB@3ooooo0_oo0003ooooo`;oo`0000?ooooook?o0?oo
ool00ooo0002ooooo`;ok_l00ol00002o`3mo`05o`000?l0oOoo0000o`3oR?nmo`000_o<o`002ol7
0?oo_Ol0o`09ool0ROoo08[ooolM0?o?o`3o0?goo`3oXOoo7@3oGOl000;o_Ol000CobOl0olko0?l0
of7ooad00ol0ob002Ol0oj7o0?goo`1@oooo7@3o02Koooom0?l0oOoo05gook;o0002o`29o`05o`_o
0?l0oa3o0?l@o`3o4?l0oj400_l0Dol01?oo^P3o08WooiWo0?mNo`02o`3oB009o`3oa?oo7@3ooad0
oooR0?l0Dooo00_oo`3`ool0oOoo09So00So000000?o0?mTo`000?l000002ol00003oolM0003oolH
0?oo7@3o08Wo00;o0?oD00So0;gooolM0?oo7@3oc_l0o`@0oooo7@3oooooo`0000;o0?n[00?o0000
ooooooooool04oooool00om8o`3o0000o`00000Qooooo`03o`000?oooooooooo03Wooooo1Ooo?`09
ooooo`Goocd04Oooool2ool000;ooooo0_oo0003ooooo`04o`3obooo003oooooooooo`?oo`000ooo
ool2ool000?ooooo0_oo00000omno`3oooooool00002ool00003o`3oZooooooo0?o600;oo`0000?o
odT0ooooooooool00ooo0002ooooo`?oo`0000Go0000oooooonco`3o/ol0ool00002ooooo`Cok_l0
1?l000000ol0oc?o0000o`3mo`02o`3mo`05o`000?l70?oo0000okgo0?l0oj400oo<o`003ol02Ooo
aol0o`29oooo7@3o0?nQo`3mooo9o`3o0?mQokgo0?oo7@3o0?mQo`01ooo;o`3o0?lPoego0002o`3o
8007o`3oXOl0oa3oaol0o`3o4?l0D?oo0?l@o`3mo`02o`29o`0<ok;o0?oo7@3o2ol0o`3mool0GOoo
Kol0o`1Cool0oj7oc?l0o`29ool0olCoG_l00_l0odP02OmVo`3obol0oooR0?l02Ooo0?oaoiWo0?oo
7@3o0?goof?o0008o`000003o`3oI?l0003o000000;o00000ol05ol00ol0003o9?l0omgo0002o`00
0003oolM0?oo603ooaP000;ooad000?ooaP0o`3oe?oo7@000_oo7@001Ol0ob3o103ooolM0?l0003o
0?n[00?o00005Oooool2o`0001Sooooo00?o0000ooooooooool0JOooool006Sooooo0_oo?`09oooo
o`Goocd03Oooool2ool000?ooooo00?o0?o;ool00?oo00000_ooool2ool000;ooooo0ooo0003oooo
o`;oo`0000CooooooolX0?oo003oo`000oooool3ool00008ooooool0ohgoo`00ool00?mno`3ooooo
o`3oa_l00002ool000;ooooo0ooo00000ooooooo/ol0ok?o0002ool00003ooooooo^o`3ok_l000;o
k_l000?oo`00ooooool000000_nno`04o`00000Ao`3mool0003oc?l0okgo0?l0oj7o1`3oo`09oooo
7@3o08Woo`2:ooo?o`3o0?lcoolM0?l0oOoo0?nQoego0?nmo`000_oo7@03o`3o8007oooooooo7@3o
aol0o`3oXOo<o`3o053ook_o0002oolM0006o`3mool0GOoo0?nHoolM0?l0ohSo2ol00_l0ROl00ol0
oOoo0?nQo`3o4003o`3o4005o`29oonIo`3o0?l@odgo0?nno`000_l0ol@00ooohP3o05?oo`3ol@02
o`3ol@09o`3moon3o`3ooad0o`000?l07?ooPol0o`3oVOl0Oooo0?mT00;ohOl000?ooad0okko0?oo
7@001_l000001?oo7@3o0000o`000?oo6003oolM00;o0?oD00_o0>;ooolM0?oo603o0000oolM0?l0
ob3o103ooolM0?l0oj_o0000oolM0002o`0001Cooooo00CoB?l0ooooool0003o00008Oooool00ol0
003oooooooooo`0gooooo`;oocl02_ooool4oolm01Cooooo0_oo00001?ooooooo`00ool00?oo0002
ooooo`;oo`0000?o0?o;ooooooooool00_oo0003ooooo`?oo`000_ooool3ool000;ooooo0_oo0002
ooooo`06o`3oZooo003oo`00ool00?l0aOooodT00ooo0002ooooo`?oo`000oooool01?l0003o/ol0
ool00?ooool3onko00;oo`000_o^o`001?l0003o__l0okko0?nno`03o`000003o`3mool0003o0000
00;o0?go00oo0000olco0?l0oj7o0?goo`09ool0R_oo08WooolM0?l;o`3o0=Coo`3oXOl0oOoo0?mQ
olWo0?nmo`000ol0ob003Ol09_ooGOl0o`09ool0oOoooad0o`3oXOo7o`3oood0olco0?l0D?oo0?go
ok;o0?l0ohP00_l0ROl02_l;o`3o0?l@o`3o4?l0Dooo0?l@o`3oXOoo7@3o067oo`29ool0odP3o`3o
a003o`3olOoohP3o00Wo00;o09So0_nIo`003_l0oOooHol0o`3moonno`3oPol0o`3oVOlTo`3ohOl0
o`3oI?oo7@3o0>3ooolM0?l0k_oooad02?l000001?oo7@3ooaP0oolM0?oo7@02o`3oe0;ooad000Co
c_l0oolM0?oo7@3o103o0_l0oj/01?l0003ooad0o`000?l0000Dooooo`03odSo0?l0003o000001Wo
oooo00?o0000ooooooooool0J?ooool006oooooo1?oo?@0@ooooo`;oo`000oooool01?oo003o0?o;
ooooooooool3ool000;ooooo0_oo0003ooooo`?oo`0000CooooooolX0?oo003oo`000oooool2ool0
00;ooooo0ooo00001_l0oj_ooooooooooooo003oodT0o`0000;ooooo0_oo0003ooooo`03ok?o0?oo
003ok_l000?ok_l00_oo0004onko00?o000000Ko0?goo`000?l0003o0000olco0?l00003o`3mo`04
o`09oooooooo_Ol0o`2:o`?ooad000Go0?lco`3mool;o`3oGOl0okgo0002o`3o800Io`3oHOo9o`3o
oad0oolM0?l0L?ooaol0o`3oXOo;o`3oaol0o`1@ool02Ooooad0o`3mool0oiSoood0o`d0ool;o`3o
0?nbofoo0?oo7@3o05?oo`29ool0oj7o05gooeko0002o`3oB003o`29oonIo`3oVOl000Co0?l@00Go
on80o`3o4?oo7@3ooad0oh?o0003o`000009o`3oYon3o`3o0?nIo`3oI?lTo`3oc?l0o`1boooo5`3o
oad000;o000000[ooaL0oolM0?oo7@3o0000obCo0?oo5`3ooad0o`0VoooSo`3ooad00_l0om@00ol0
5ooooad0oolM0002oolM0003oolH0?l0003ooad000;o0?n[00Go0000oolM0?l0003ooad0o`00000C
ooooo`04odSo0?oooooooooood3o00;o00008Oooool00ol0003oooooooooo`0nooooo`Coocd05Ooo
ool3ool00003oooooooo003oo`0000?ooooo0_oo00000ooooooo0?o;ooooo`02ool000?ooooo0_oo
00000ooo:03oooooooooo`02ool000;ooooo0ooo00000ol0ohgoooooogko0002ool00005o`3oa_oo
oooo0<Gooom90?oo00000oooool2ool000Cooooo00?oo`00ok?o0?nco`000oo^o`000ooo003ok_l0
onko0002onko0004ool00?oooooo0000o`0000;ok_l000?o0?gookko0?nno`000_l000001?o<o`3o
0000olco0?l00002o`3mo`0No`09ool0R_oodOl0o`29oooo7@3o2ol0oolM0?o>o`3o2ol0o`3mool0
oj7o_Ol0oolM0?o=o`3o06_oo`0VoomMo`3ooad0o`3oHOl0oOooaol0o`_o0?oo7@3o0?nHo`1@ool0
oOoo05goo`3oR?oo7@3o2ol00_l0ROl01?l0Dooooad0oonj0?l0oj42o`3oB003o`3o4?l0ROoo0?l@
00;o0?l@0_l0ol@01OoohP3ooad0oolM0?l0V?ooPol000;oVOl000goHol0on7o0?n3o`3o0?nIobCo
0?l0ofCo0?o]oolG0?oo7@3o0>kooolG0?l09_oooad000Oo000000Sohol0o`0Gool0omCo0?oDoolM
0?l0003ooad0olko00;ooad00_l0oj/01Ooo7@3o0000o`000?l0003ooad001Cooooo00?oB?l0oooo
oom0o`006_ooool00ol0003oooooooooo`1Xooooo`00Joooool4oolm017ooooo0ooo0003ooooo`;o
o`0000Co0?o;oooooooo003oo`000oooool2ool000?ooooo0_oo0002ooooo`?oo`000oooool2ool0
00;ooooo0_oo00001?l0ohgoooooo`3oZonAo`02ool00003oom90?l0aOoo000000;oo`000oooool2
ok?o00;ok_l000?oooooool00?oo00000oo^o`03ool00003ooooool0003o0?go00Go000000Co__l0
o`000?lF0?oo_Ol00_l000000ooo7@3o08[oo`29o`02olco00;ooad001go0?lPo`3moomMo`3o0?mQ
okgo0?l0oj7o0?mQo`2:ooo9o`3o007ooolM0?o7o`3ooad0olOo0?o;o`3o053oo`3moonbo`3o0?go
oonj0?o<o`3oood0o`_o0?m_o`3o0?mQo`1Cool0oOoo02Koo`3oX@02o`3oB006oonj0?l02Ooo08Wo
o`1Qoooo7@3oVOl00_l000000om=o`3o05?ooooR0003o`3o40?o000000Ko0?l@o`3oVOl0ofCooad0
obCo0?oo7@03o`0000?ooad000KooaL0o`000?oo7@3o9?l0oolM0?oo5`03o`3oe008oolM0?oohP3o
08WooolM0?oo603o01OooolM0?oo6002o`3oZ`07o`2Fool0003ooad0o`3o0?l0003ooad0o`00000B
ooooo`05odSo0?oooooooooood3o0?ooool00_l0000Qooooo`03o`000?oooooooooo03Wooooo1Ooo
?@0Gooooo`;oo`0000Coooooool00?oo003oo`000_ooool3ool000;ooooo00?o0?o;ool00?oo0000
0oooool2ool00003oolX0?ooooooo`0000;oo`000_ooool2ool00003oooooonAo`3oTOl000?oo`00
00GoO_l0o`3oa_oo003oo`00oom90002ooooo`?oo`000oooool01ooo003ok_l0onko0?nco`3ok_l0
o`000?oo00000oo^o`02ool000?ooooo00Cok_l0o`000?l0oOooo`000_l000002_lA0?oo0000o`00
0?l0003o__l0o`000?l0R_oo0000okgo0?l02Ol2o`000004oolM0?l0ROoo2ol0okgo00;o0?lP00Go
2ol0o`3oHOl0oOoo0?nQo`2:o`02oolM000Ao`0VoomMo`3obol0o`3oHOoo7@3oaol0o`_o0?l0oiSo
05gook;o0?l0D?oooad0o`3oR?l0GOoo2ol0ofoo0?l0Dol00ol0ROl01_l0odSo0?nQo`1Qool0oo7o
08Woo`3ol@;ooad000?o0?l@o`000?l000001?l0oa002ol0V?oo0?gooiWo0?l0003o0?nIoolG0?l0
ofCooad0o`1boooo5`3o0>ko00;ooad00_l00003oolM0004o`000?oQo`3ooad0oooR00;o0?oD00Ko
oad0o`0Gool05ooo01OooolM0?oo6@02o`3oZ`;ooad000Go103oo`000?l0003o0000oolM000Coooo
o`04odSo0?oooooo@?l0ooooo`;o00006?ooool00ol0003oooooooooo`1Xooooo`00JOooool2oolm
01?ooooo0_oo0004ooooo`;oo`0000Coooooo`3obooo003oo`000_ooool3ool000?ooooo0_oo0002
ooooo`;oo`0000?oobP0ooooooooool00ooo00001?ooooooo`00ool00?oo0002ooooo`06o`3oSOoo
003oo`00ool00?l0olKoodT00_oo00000ol0003oO_l0ooooo`02onko0004ok?o0?o^o`3ooooooooo
o`Cok_l000Coooooool00?oo003o0?n40oo^o`001Ol0003o0?goo`000?l0003ok_l000Co000000So
__l0o`09ool0003o0000o`3oXOl0R_oo08WooolM00?o0?lP0_l;o`001?mMo`3o0?mQokgo0?o=o`02
o`3oX@0FoolM0?o9o`3obOl0olOo0?oo7@3oaol0o`1`ooo;o`3o053oo`1Mool0oOoookX0oolM0?m_
o`3o2ol0ooom0?l0Dooooad0o`3mool0odSo0?nQo`1Mo`?o08Wo01?ooad0o`29ool0oo7ooad0oiWo
0?l0003o_?l0o`1CoooohP3ogol0oh?o0?oQo`3o0?o4o`3mool0003ooad0o`3oI?l0oa3o9?l000;o
000000co0?l@o`3^oooo7@3ooaL0oolH0?oo7@3o0000oolG0?oo7@3o0?goobCo0?l0om@2oolM0006
on?o0?oo7@3oon80o`29oooo7@3ooaP00ol0oj/01_oo603ooad0o`000?l40?oo0?l0oolM00;o0000
4_ooool01?m8o`3ooooooooooom0o`02ooooo`03ocko0?oooooooooo023ooooo00?o0000oooooooo
ool0=oooool2oolm01[ooooo0_oo00000oooooooo`00ool00003ooooo`;oo`000oooool00ooo003o
0?o;ooooo`02ooooo`?oo`000_oo:002ool000;ooooo0ooo0002ooooo`?oo`0000?oTOl0o`3oZooo
ool00_oo00000ol0aOooodT0ooooo`02ool000;ooooo00?o0?n4onko0?o^o`000_o^o`02ok?o00;o
k_l000?o0000onko0?oo00000_oo00000oooooook_l0onko0002onko0004ool00?l0003o0?goonko
00;o000000[o4@3oo`000?l0okKo0000o`3mool0003o__l0o`000?l02Ooo03?o0ol00003o`3o8006
oolM0?o7o`3oaol0o`_o0?oo7@3o0?go0_l0oj404ol0R_oo02Kooego0?oo7@3o0?mQol_o0?o7o`3o
0?goo`_o0?l0GOoo3@3oo`1@ooooo@3o0?n8oolM0?l;o`3o05?oo`3mool0GOl00_l0odP01ol0ROoo
0?nQo`3olOl0HOoooad0o`29oomVo`000_m=o`02o`000004oooR0?oo7@3oPol0o`3oa0;o0?l@00Co
0000oiWo0?nIo`3o0?mT0_l0oa000ol0L_oo0>kooolG0002o`000004oolM0?oo5`3ooad0oolM00;o
000000KooaL0o`3oe?l0omCooaP0on?o0?l00002oolM0003olko0?l05ooo0?n[00;o01Oo00Cooad0
o`2Fool0003ooad00ol0000Booooo`03odSo0?oooooo@?l000;ooooo0_l0000Hooooo`03o`000?oo
oooooooo06Sooooo001looooo`;oo`001?ooool2ool00004ooooool0ol_o0?o;ool000;ooooo0_oo
0004ooooo`;oo`000_ooool2ool00003oolX0?oooooooooo00;oo`000_ooool2ool000Cooooo0_oo
00002?l0oj_oooooool00?ooB@3oo`00o`35oooooooo00000_o^o`02ok?o0004ooooooo^o`3ok_l0
onko00;ooooo0_oo0004onko00;oo`0000?ok_l0o`000?l000000_nmo`002_l0oOoo0000ooooool0
003o0?goo`000?nmo`3o08[ookko0?l0oj43o`3o8003olko0?oooooo2ol000;ooad000coGOl0o`3m
oonmo`3o0?mQoolM0?l0VOoo0?nQoolM0?l0of7oaol0okko0?o7o`02ok;o0009o`1Mool0D?oo0?go
o`3Poom_o`3ooad0o`_o0?l0Dooo0?nG00;o0?m800KoG_l0o`0Vool0003o0000oonj0?l02Ol2o`00
00;o08[o00goc?l0oiWo0?nIo`3o05?ooolM0?oohP3ohOl0o`0:ool0oh[o0?n8o`000?l0oiWo0?mT
00;o000000Co09Soo`1oool0k_oo07;o0ol0oa03o`0000;o0?oD00So9?l0oolM0?oo5`3ooaP0oonj
0?oSo`3ooaP0o`3Ro`;o0?n[00WooaP0oolM0?oo7@3o09KooolH0?l0003o103oo`0Goooo7@000_l0
000Booooo`03odSo0?oooooo@?l000;ooooo00?o?_l0ooooooooool08Oooool00ol0003ooooooooo
o`1@ooooo`?oo`0000?oooooool00?oo00000oooool2ool000;ooooo0ooo00000ol0ol_ooooooooo
o`02ool00003oooooooo:03oo`0000;oo`0000Coooooool00?oo003oo`000oooool2ool00003oooo
ool0ohgooooo00?oo`0000?o0?o6ooooooooB@000_oo0002ooooo`?ok_l000Coooooo`3oQ?nco`3o
/ol00_o^o`001?ooooooo`00o`000?oo0004onko00;oo`000oo^o`02o`0000?o_Ol000Wo0?goo`00
0?l0okKo0000o`3mool0003o08[oo`09ool000000_nno`000ol0oj7o0?lPo`_o0002om3o0008o`3o
Looo7@3ooad0o`_o0?l0of7o02Koo`3mool0R_l2o`3oX@0?oego0?o7o`3o0?mQolOo0?l0oiSo0?nQ
o`1Moooo^P3ooad0o`3mool0D?oo0?n8ofoo0?l;o`3ooad000;o0?m800Co0?oaoeko0?oo^P3o0?nQ
0ol0ROl2o`0000;o08[o00ko00Woo`1Coonlo`3oon80on7o0?l0ohSooad0o`3oa?l0oOoo0?nIof?o
0?nIo`3o07oooolG00?o00001Ol0oa002?l0003o02Koo`000?l0omCooaP0o`29oooo7@3ohol00_l0
ob002_o>o`3o0?n[o`3oZooo7@3ooaT0oolH0?oo7@3o0000o`0Goooo7@02o`0001;ooooo00?oB?l0
oooooom0o`000oooool00olno`3oooooooooo`0Gooooo`03o`000?oooooooooo06Sooooo001joooo
o`;oo`001?ooool2ool00004oooooooo003o0?o;ool000;ooooo0_oo0003ooooo`?oo`0000Cooooo
ool00?oo003oo`000_oo:003ool00004oooooooo003oo`00ool000?ooooo0ooo00001Ooooooo0?n[
ool00?oo003oodT000Cok_l000?o0000ok?o0?nco`000oo^o`03ooooo`05ool00?o^o`3ok_l0onko
0?ooool00_oo0003onko0003ool00?l0003o000000;o000000Oo_Ol0o`000?nmo`3o0000o`09ool0
003o_Ol000?o0?lP00oo0?nQokko0?nno`3o__l0oolM0?l;o`3od?l0olgo0?mMo`3o0?mQo`3moonm
o`3oaol0oolM0?l00Ol00_l0oj401ol09_ooaol0olOo0?oo7@3o0?nHo`1Mool0D?l00_l0oOl00ooo
^P3o027oo`_o0002o`3oB004o`2coomNo`3oood0o`0Vo`;o000000gookX0o`09ool0003o0000o`29
oonko`3ooad0o`09ool0DoooVOl0on7o0?oohP3ooad000;oCOl000goPol0o`000?l0ofCooad0o`3o
a?lTo`3o0?o4o`3^ool0V?oooaL0o`1boooo7@3o000000?o0?oD00?ooaL0o`3o4?lTo`001Ol0oa00
1_l0oj_o0000o`000?oo7@3o0?l@oolH00;ooad000?o0000oolM0?l40?l00_oo7@000ol0003o103o
o`@0o`0@ooooo`03odSo0?oooooo@?l000;ooooo00?o?_l0ooooooooool01oooool5o`38oaKooooo
00?o0000ooooooooool0C_ooool2ool00004oooooooo003oo`00ool000;ooooo0ooo0002ooooo`;o
o`000_ooool01?l0ol_oo`00ool00?oo0002ooooo`;oo`000_ooool2ool000?ooooo0ooo0002oooo
o`09o`3oSOoo003oo`00o`3oZooooooo0?o6ool00?ooB@3ooooo00Cok_l000Soo`00ooooooo^o`3o
k_l0ok?o0?o^o`3oooooo`3oQ0;oo`0000Cok_l0o`000?o^o`3ooooo0_oo0003onko00;oo`0001;o
ooooo`000?l0003o0000onko0?lA0?oo_Ol0o`3moonmo`3o0000oolM0?l0oOoo0000okgo0?l0003o
0?lPo`3mool0oj42okko00?ooad001go0>3oo`2Iool0of7o2ol0oolM0?nmo`3o0?goo`2:ool09_oo
GOl0olOo0?l0of7oaol0oolM0?l0oj7o05goo`3mool0oiOo0?goo`1@ool0ohSo05?oo`_o0?l0odSo
0?goo`1MoomNo`3ooad0oonj0002o`00000Bo`1Qoooo7@3o0000o`000?l0okoo0?3oo`09ool0Dooo
hOl0oooR0?l0oh[o0?n8okco0?n3o`3o0?nIo`3mool0ofCo9?l00_nIo`001Ooo5`3o07;oo`3okOoo
7@3ooaL000;ooad000Co0000o`3oe?l0omCo00001?l0oa001?oo7@3ohol0o`3oZol0oj/3oolM0006
o`000?l0U_oooad0o`000?l40?oooad00_l000000ol40?ooooooooooo`0>ooooo`03odSo0?oooooo
@?l000?ooooo00?o?_l0o`38ool0b?l00_l0b?lFooooo`03o`000?oooooooooo06Sooooo001goooo
o`?oo`000oooool3ool00005oooooooo003oo`00o`3oboooool00ooo0003ooooo`;oo`000_ooool2
ool00003oooooooo:03oobP000;oo`000_ooool2ool000?ooooo00Oooc/0ool00?oo003oooooo`3o
SOooooooo`0000;ok_l000[oodT0onko0?oo003oo`00ooooooo^o`3o/ol0onko0?oo003ooooo0_mn
o`04onko00;ooooo00Coo`00onko0?o^o`3ok_l00ooo00004ooooooo0000o`000?l0oOoo0000oa40
ool0003ocol0o`000?nmo`3o0000o`3o8?l0R_oo0?gooolM0?l0oj7oEOl0okgo0?o<o`000onno`00
8ol0003oGOl0o`_o0?oo7@3o0?goo`3og_o7o`3o007oo`2:ool0of7o0?nQolOo0?o9o`3o0?nQo`1M
ool;o`3o_Ol0o`1@ooo;o`3o0?goo`1Cool;o`3o027ooolM0?mNo`3o0?goo`3olOooo@3o0?nQo`2I
ool0GOoo08[oo`09oooo7@3o08Wo00;ohOl000Ko00Woo`1Coonno`3oVOl0om_o0?oohP04o`000005
o`3mool0oaoo0000o`000?l0k_l00_l0ol@02_l0V?oo0?oDo`3oe?l0omCooaL0oolM0?o<o`3o02Ko
oolG0?lTo`03oolM00;o0?n[00?o0?l@o`000?l000000_oo7@000ol0U_oooad0o`000002oolM0004
oolH0?l40?oo0000oolM00;ooooo1?l40?l;ooooo`03odSo0?oooooo@?l000;ooooo00?o?_l0oooo
ool0b?l02?l0b?l3ooooo`;o00005_ooool00ol0003oooooooooo`1<ooooo`;oo`0000?oooooool0
0?oo00000oooool2ool000;ooooo0ooo0003ooooo`04o`3obooo003oooooooooo`?oo`0000Cooooo
ool00?oo003oo`000oooool2ool000?ooooo0ooo00001_oooooo0?n[ool00?oo003ok_l0oom900;o
k_l00_oo0004onko00;o/ol000?oooooool00?o^o`000oo^o`000ol0ohCo0000onko0003onko00;o
o`000_ooool2onko00;o0000017o0?goonko0?lA0?ook_l0o`3moolF0?oo0000okgo0?l02Ooo0000
okgo0?l0003o_Ol0o`3moooo7@3o0?nQoeGo0003okko00;ooad000So0?mQo`_o0?o7o`3o_Ol0oolM
0?l0oOoo02Kooego00;o0?nQ017oaol0ok;o0?l0oj7obol0o`3oUol0oOoooad0o`1Cool0D?oo0?m8
o`_o0?l0oo7oood0oeko0?l0GOoo0?n:oonj0002o`0000;o08[o00koc?l0o`29oooQo`3ohOl0o`09
ool0DoooPol0odgo0?oohP3ooad0oh?o0?oo7@3o0?nIo`3mo`Co00000_nIo`000ooo7@3o0?o]oolG
0003o`3oe0?o000000CogOl0oolM0?oo5`3ooad00ol0oa02o`00000;oolH0?oo7@3o09KooolI0?l0
003ooad0o`@0ool0003ooad0o`000?ooool01?l40?l9ooooo`;o0<So00?oB?l0o`38oom0o`000ol0
b?l01?lno`3oooooooooooooool2o`0001Oooooo00?o0000ooooooooool0Ioooool007Gooooo0_oo
0004ooooo`;oo`000_ooool2ool00004ooooool0ol_oo`00ool000Cooooo0_oo0002ooooo`;oo`00
0_ooool01Ooo:03oo`00ool00?ooooooof<000;oo`000oooool3ool00003oooooooo>`3oo`0000?o
k_l000?ooooooom90?oo00000oo^o`02ok?o0003ool00?nAo`3ooooo00?ok_l000?oO_l0oooooooo
ool01?o^o`03ool00003ooooooo^o`3ok_l000;ok_l000Ko0000o`3mool0og?o4@3oo`000?l02Ol2
o`000003o`L0ool0003o_Ol000;o_Ol000Go08Woo`3oXOmEo`3ocOl0o`_o0002oolM000;okko0?mM
o`3o2ol0o`3oHOnmo`3o0?gooolM0?o7o`3oooooo`2:oonbo`000ol0oj402?l0GOoo0?mnofoo0?l0
oOoo053oo`1Cool;o`3o0?n80_l000001Ol0oo7o0?goo`3Doonmo`3o0?nQ00;o08[o01;ookX0o`09
oooQo`3o067oo`29ool02Ooo0?3oo`1Coon3o`3ofol0oiWo0?l0003oon80o`3o7ol0ofCo0000of?o
0?l0oOl2o`00000:o`3oYol0omCo0?oDo`3oe?l0003o0?o4oolM0?l0ongooaL0o`0Vo`;ooad00_l0
0002o`3oZ`0:oolM0?oo5`3ooad0on?o0?l0ROoooad0o`2Foooo7@3ooaP0o`0000?ooad000?ooaP0
o`000?l000001_ooool4o`@0o`Gooooo00Co0<SoodSo0?l0b?oo@?l00_l0b?l00olno`3o0<Soo`38
o`0Tooooo`03o`000?oooooooooo04Wooooo0ooo00000oooooooo`00ool00002ooooo`?oo`000_oo
ool2ool000Cooooo00Coo`00o`3obooooooooooo0_oo00001?oo:03oof<0ool00?oo0003ooooo`?o
o`000oooool2ool00003o`3oSOoooooooooo00Cok_l000?oodT0ool00?oo00000oo^o`03ool00003
ok?o0?o^o`3ok_l000;ok_l00oooool2onko0003o`000?l0ohCoo`0000;oo`001?o^o`003?oo003o
k_l0onko0?l0003o0?goool00?lA0?oocol0o`3o8?l0oOoo0000o`09o`Co000000Ko_Ol0o`3mool;
o`3o0?nQo`09oomEo`02oolM00?o__l000Oo2ol0oolM0?o7o`3o_Ol0oolM0?l0oOooGOl000;oaol0
0_l0oj402_l0GOoo0?nQol_o0?l0oOoo05?oo`3oB?l0D?oo0?n8o`_o0?mNo`02o`000007ooom0?l0
GOoookX0o`2:ool0oj7o3?l0o`1Qo`02on7o0004o`29ool0l?oo00Wooh?o00;ooad000Soon80odgo
0?n3o`3o0000o`3oI?l0oaoo0?goof?o00;o00000_l0ol@02?nIo`3o0?oDo`3oe?l0003ooad0o`0V
oonno`3ooaL00ol00002o`3oZ`03olko0?oo7@3ohol000;o000000WooooooolH0?oo7@3o0000oolI
0?oo7@3ooaP0o`000?oo7@001_ooool4o`@0o`Go0<So00CoooooodSo0?oooooo@?l00oooool00oln
o`3oooooooooo`0Kooooo`03o`000?oooooooooo06Oooooo001cooooo`;oo`001?ooool2ool000;o
oooo0_oo0002ooooo`03o`3obooo003ooooo00?ooooo0_oo00001?ooooooo`00ool00?oo0002oooo
o`?oo`0000Coooooool00?oo003oo`000_ooool00oooH`3oo`00ool00002ooooo`Cok_l000Cooc/0
o`3oZooo003oodT00_o^o`001Ol0aOooo`00ok?o0?oooooo000000?ok_l000?oo`00ooooooooool0
0oo^o`02ooooo`;oo`0000Coooooonko0?o^o`3ok_l00_oo0002onko00?o000000Cocol0o`09ool0
_Ooo00000ol0of406Ol0oOoo0;gookgo0?nmo`3o0?nQolgo0?l;o`3o0?n8o`09ooooooooc?l0o`3o
HOmMo`3o2ol0okko0?nmo`3o0?goo`01ooo7o`3o/_l0o`0Vooo7o`3o__l0o`3oXOm_o`000_l00000
1Ol0odSo053oo`2cool;o`3oG_l000;o000000ko027oo`3mool07?oo08[oo`3oXOl09_ooood0oonj
0?l02Ooo05gooolM0?l0HOoo08Woolco00?o000000So0?lOoiWo0?nIo`3o0?mTokko0?l0003oHol0
o`3o30?o0?oD00Go0?mCo`1oool0003o0?o1o`1bo`03o`3oa003oolG0?oo603o0?n[00;o0?n[00Co
okX0oolM0?oo7@3oc_l00_oo7@001ooSo`3o09KooolM0?l0R_oo0000oolM0?oo60000_oo7@02o`00
00Oooooo1?l0b?l4o`@0o`07o`38oom8o`3ooooooooooom0o`3oooooocko000=ooooo`Ko07Wo5?oo
ool00ol0003oooooooooo`17ooooo`;oo`0000Coooooool00?oo003oo`000_ooool2ool000;ooooo
0ooo0003ooooo`?oo`0000Go0?o;ool00?oo003oo`00oolX0003ool000?oof<00_oo0003ooooo`?o
o`0000?oooooo`3oSOo^o`000_o^o`02ooooo`;oodT00oo^o`03ool00005oooooonco`3o/ol0onko
0?mno`000_ooool4onko0004oooooooo003o0000ool000?ok_l00_oo0003onko00;oo`001?l00000
1?o?o`3o5P3oo`2mool02Ol2o`2mo`04o`000?l0of7o0?mQo`0000;o_Ol000Cooad0o`3oXOl0VOoo
EOl00_oo7@02o`3oH@07okko0?l;o`3o__l0okgo0?l0VOoo02Kooego0002olOo0005oolM0?l0GOoo
0?nQo`3oXOm_o`000_l000001Ol0oOooc?l0o`1@oomNo`3ooad000;o000000go02Koo`2:ool0R_oo
okX0o`3oXOoQo`3o067ookgo0?o<o`3o__l0o`29ool02OooPol000?o0?lO0_l000001_l0ofCoCOl0
o`_o0?lTo`3o0?goo`3o30?o0?oD00Go09SooiWo0?nIo`3o0?o4o`0Vo`02oolM0007oonj0?l0003o
0?n[o`3oZooo7@3oc_l0oolG0002oolM0003on?o0?oo7@3o09Ko00;ooad00_l000001?oo7@3o0000
o`000?l00006o`38o`Cooooo1?l40?l01?ooooooB?l0oooooom0o`03ooooo`04ocko0?oooooooooo
ooooo`Ko07Wo5Oooool00ol0003oooooooooo`1Wooooo`00LOooool2ool000Cooooo0_oo00001Ooo
ooooo`00ool00?oo003ooooo00;oo`0000Co0?o;oooooooooooooooo0ooo00000oooooooo`00ool0
0003ooooo`;oo`000_ooool2ool000?ooooo00Coof@0ool00?oo003ooooo0oo^o`000ooo003ooooo
o`3oS@03onko0004oom90?l0olKoo`00ool000;o/ol00_o^o`000ol0003oo`00ooooo`04onko00;o
oooo0_oo0004onko00;oo`000oo^o`02ool0000;o`3oCOl0003o0000o`09ool0003ocol0o`3mool0
003o08[oo`000?l0of400_l00002o`2mo`03o`3oXOl0003o000000Co0;go00GoGOl0o`_o0?l0_Ooo
_Ol0okko0002o`0000;o0;go00Coaol0okko0?m_o`3o0?nQ0_l000002?l0Dooo0?oao`1@oomNo`3o
0?n8o`3mool0ongo073o0_l0R_l01?l07?oo0?nQon7o0?l09_l2ooom0003olco0?l0oaoo067o00;o
000000goPol0okgo0?nno`3ooad0oh?o0?l0ofCoVOl0okko0?l0003o0?l<o`3oe?l0oOoo^ol000;o
COl000Ko0000o`1ooooo7@3o0?o1o`1booooool3o`3oZ`04oolH0?lTo`3ooad0oolG00;oc_l00_l0
U_l2o`000004o`3o0?oo7@3o0000o`3go`;ooad000CooaP0oolM0?l0003o00001ol0b?l8ooooo`Go
103o00Co?_l0oooooooooooooooo2ol0NOl4ooooo`;o00005?ooool00ol0003oooooooooo`15oooo
o`;oo`0000?oooooool00?oo00000oooool2ool000;ooooo0_oo0004ooooo`;oo`000_ooool01?l0
ol_oo`00oooooooo:002ool000?ooooo0ooo0003oomS00;oo`0000?oooooonko0?o^o`000_o^o`00
2?oooooo0?n[ool00?o^o`3oodT0onko0?l0aOoooooo0_oo0003onko0003ok?o0?oooooooooo00Co
k_l000Coo`00ooooooooooooo`000_o^o`000ol0003ok_l0ooooo`04onko00;oo`000_l000000oo^
o`3o0000o`3oC@02o`000005o`3o]_l0003o0000o`000?o?o`000ol000002?l0_Ooo0?mQo`000?l0
003o_Ol0o`3oXOnmo`3o0;go0_l000001_l0_Ooo0?mQo`2mool;o`3o0;gookgo00;o__l000SoGOl0
o`000?o7o`3obOl0o`1Mool0oo7oKol0o`3oX@;o000000Ko__l0o`3moomNo`3o053oolco0?l0oOl2
o`2:o`06o`0Vooooo@3oood0o`3oXOl0okoo067o0ol0oal00ol0ROooPol0o`1Co`03o`00000?oooR
0?l0ofCo0?n:oolM0?l0k_oo0?oDo`3o3?l0omCooad0o`1oool0ol7o__l0o`000?l0V?ooVOl000;o
0?o40_l0oj/01_l0003o9?l0olko0?o>o`3ooad0oolG00Co09Ko00Kooad0oolH0?l0003ooad0o`@0
oooo7@03o`0000kooooo1Ol40?l00ol0NOoo?_l0o`1io`03o`1io`Cooooo0_l0000Eooooo`03o`00
0?oooooooooo06Oooooo001^ooooo`?oo`001?ooool2ool00003oooooooo003oo`0000;ooooo0_oo
00001?oooooo0?o;ooooooooool2ool000;ooooo0_oo0003ooooo`;oo`0000CoobP0ool00?oo003o
o`000oooool2ool000Cok_l000?oo`00oomT0?ooool00oo^o`001?l0oj_ooooooom90?oo0002onko
0003ok?o0?oo>`3oo`0000;oo`0000?o0000onko0?o^o`000_oo00000oooooooTOl0ool00003onko
0003ogko0?oo003ok_l000?ok_l00ooo0002o`3oC@03o`000?l0oOoo0?go00;o000000Ko00WooaH0
ool0003ocol0o`000?o?o`02o`000003o`29oolc0?oo<`3o00;o00000onmo`001_l0of7oGOl0o`_o
0?oo7@3o_Ol0ok;o00;o000000Wo__l0olOo0?nno`3oKol0o`3oB?l0oj7o0;goo`3mool0oj400_mN
o`001?l;o`3o0;goo`2mool0_Ol2o`0000;o0;go00Go0?nQo`2mool0_Ooo0?lOoonj0003o`00000D
o`09ool0ROoo05?oolco0?nmo`3oPol0o`3oe?l0ofCo0?oDoiWo0?l0o`co0>koof?o0?l0e?oo0?go
o`0Lool0003oCOl0o`1ooooo7@03o`3oZ`04olco0?l0V?oo09Soo`3oa0Go09Ko0_oo7@02o`00000:
on?o0?oo7@3o0000oolM0?l40?oooad0o`oo0?oo603ooad0o`0000gooooo00Oo07WoodSo0?l0NOoo
07Wood3o0?l0NOoo?_l000Co103o8_ooool2o`000003ooooool0003ooooo04?ooooo0ooo00000ooo
ooooo`00ool00002ooooo`?oo`0000Coooooool00?oo003oo`000oooool3ool00005oooooooo003o
o`00o`3oboooool00ooo0002ooooo`?oo`000oooI002ool000Cok_l000?oo`00oolk0?l0ohd01?o^
o`000oooB@3oooooool00004onko0003ool00?nco`3o/ol000?ok_l00_oo00000oooooooO_l0onko
0003onko00;ooooo00Co0000onko0?o^o`3ooooo0_oo00000ol0T?oo0?n4onko0002onko00;o0?m=
0ol0oOl01Ol0okKo0000o`000?l0003o0?go00;ocol000?o0000oloo0?l000000_l000000ol0of7o
0000oc<0o`03o`00000@o`3oHOl00Ooo0;Koo`2aool;o`3o_Ol0o`2moonbo`3oGOl0o`000?l0oOoo
__l0o`3oB?m_o`3o05?oo`2mo`;o0?nQ00Co0;gooeko0?l;o`3o053o0_l0R_l2o`00000Aon7o0?l0
9_oookX0o`3oXOooo@3o067oolOo0?l0l?oooad0oh?o0?l0ROoo0000o`0:oooo7@3oPol0o`3oVOl0
of@00ol0om@02_l0o`coCOl0o`3mool09_oo07ooo`3o`Ol0003o07;ooolG0?l0oj/2oiWo00;o0?o4
00?o0000o`2Fool0U_l00ol0U_l03?oo5`3ooad0o`000?l0003ooad0o`@0ool0003ooaP0ooooool?
o`3ooad0o`0000Gooooo2_l0NOl00om8o`3o@?l0ooooo`02ooooo`Co103o6_ooool2o`000003oooo
ool0003ooooo06Sooooo001/ooooo`;oo`001?ooool3ool00003oooooooo003oo`0000;ooooo0_oo
0002ooooo`05o`3oboooooooo`00ool00?ooool00ooo0002ooooo`?oo`0000?oobP0ool00?oo0000
1?ooool01?oo003ok_l0onko0?o^o`03ool00009ooooooo^o`3ok_l0onko0?l0ohgoof@0ooooooo^
o`3oodT000;ok_l00_nco`000ooo003ok_l0onko0002onko0005o`000?oo003ooooooooooooo0000
0oo^o`02ooooo`?ok_l00_ooool2ool00005ooooooo^o`3o0?m=onko0?oo00001Ol000001_l0oOoo
00Woo`09ool0003o08[oo`0000?o<`3o0_o?o`02o`00000;o`09oonmo`3o0?n8okgo0?mMo`3o_Ol0
o`_o0?nbo`3o007ooolM0?l0of400_l000000om_o`3o0?m8okko0002o`1Co`08o`3moomNo`3o0?nQ
o`3oXOl0D?oo0?n8o`2:ooo;o`02o`000005o`3mool0oaoo05goo`3oXOl07?l00_l00004o`2mo`03
o`29ool0_Ooo0?oD00;o0?oD00Co0?mTo`2mool0_Ooo0?l<0_nIo`001OmSo`3o0;goo`3mool0003o
01co00?o0?n[00?o^ol0o`0Vool0U_l01?l0U_l03OlTo`3oc_l0o`3oa?l0olCo08WooolM0?l0o`3o
oad0oolG0?oSo`3o0000oolM0?oo60000ooo7@000ol0003ooad0ooooo`02ooooo`_o07Wo00Kooooo
odSo0?oooooo@?l0oooooolno`05ooooo`Co103o7?ooool4ooom0003ooooool0003ooooo047ooooo
0_oo00001?ooooooo`00ool00?oo0002ooooo`;oo`000_ooool2ool000Cooooo0_oo0002ooooo`;o
o`0000Coooooo`3obooo003oo`000oooool2ool000Cooooo00Coo`00onko0?o^o`3ok_l00ooo0000
2?ooooook_l0onko0?o^o`3oo`00o`3oZoooooooodT00oo^o`03ool000;o/ol00_o^o`02ool00003
oooooonAo`3ok_l000;ok_l000?oooooogko0?ooool00oo^o`001?l0003oo`00ool00?oo0004onko
00;oo`0000Ko0?m=onko0?l0003o0000o`3mool0okH3o`3mo`08o`000?oAo`3o0?goom7o0?l0003o
0?gooc<0ool00003oc<0o`04o`3oXOl0003o0000oeGo00?o_Ol000Oooad0o`_o0?oo7@3o/_l0o`0V
oomMo`3oaol000;o000000GoKol0o`1Coonno`3o0?nQo`3mo`02oeko0005ol_o0?l;o`3o08[oo`1@
ool0_Ol00_l00003o`2mo`04o`3oXOl0_Ooo0;goo`2mo`?o0000013o08Woo`1Coooo7@3oPol0o`3o
e?l0ofCo0?oDoooR0?l0oh[o0?l<okko0?oo7@3oHol0o`3moom=o`3o00000ol0oj/02ooo7@3o09Ko
o`2FoonIo`3o09Koo`000?lTo`3o0?o4oolH0?oo7@3o0?oe00?ooad000?ohol0oolM0?l000000_oo
7@001?oo603o0000oolM0?l00005o`1io`Wooooo00?oB?l0oooooom0o`000_ooool00olno`3ooooo
ooooo`02ooooo`Co103o5Oooool3ooom0003ooooool0003ooooo06Sooooo001[ooooo`03ool00?oo
oooooooo00;ooooo0_oo0002ooooo`;oo`0000Coooooool00?oo003oo`000oooool01?l0ol_oo`00
ool00?ooool2ool000?ooooo0_oo00001?ooooooobP0ool00?oo0003ooooo`Cok_l000?oooooool0
0?oo00001?o^o`000ooo003oooooooooo`03onko0004oom90?l0olKo/ol0ok?o00?ok_l000Gooc/0
ool00?oo003oo`00o`000004onko0003ooooooo^o`3ok_l000;ok_l00_ooool2ool000?ok_l00_l0
odd00ooo003ok_l0onko0003o`00000>olko0?l0003o5P3oo`2:oolc0?oo0000oc<0ool0003o0?go
okgo0?l0ROoo_Ol0oeGo0?l0oj44oloo0004o`3oHOmMo`3o/_l0ok;o00;o_Ol0017oc?l0o`3oV?l0
003o0000o`1Mooo7o`3o05?oo`3oXOnno`3oG_l0okko0?l;o`3obOl0o`3oXOl0D?oo0?n8o`3o7`03
o`3mo`09oolM0?l0003o0?nQo`000?l09_oookX0o`09oomVo`3o00Wo00?o0?oD00kooad0oh?o0?l0
ofCo0?nIo`3oR?l0o`co0>koo`000?oo7@3oVOl0of?o0?l0003o0?goo`3oZ`Go09Ko1Ol0_Ol00olT
o`3o0;goo`2mo`03o`2mo`05o`3oa?oo7@3o103oo`000?oSo`000_oo7@000ooo603ooad0oolM0002
o`0000?o07Wo2oooool00om8o`3ooooood3o0002ooooo`03ocko0?oooooooooo00Oooooo1?l40?lC
ooooo`Goood01_ooool00ol0003oooooooooo`0mooooo`;oo`0000?oooooool00?oo00000_ooool3
ool00004oooooooo003oo`00ool000Cooooo0_oo0002ooooo`;oo`0000Coooooool00?l0ol_oo`00
0_ooool3ool000?ooooo1?o^o`000oooooooo`00ool00004onko0003ool00?oo>`3ooc/000;ok_l0
00?oodT0onko0?l0aOl00_oo0002onko0003ok?o0?ooooooo`0000;oo`001?o^o`000onAo`3ooooo
onko0003onko0004oooooooo003oo`00o`0000?ok_l00_oo0002onko00;o0?m=0_oo0004o`0000;o
c_l000?o0000o`3o]_l0oOl00olc0?l03_l0003o0?goo`000?oAo`3o0?mQooooooo?o`3o0?nQoeGo
0?o?o`3o0?mQo`01oooo7@3o_Ol00_nbo`001?nmo`3oGOl0o`3oB?o7o`02o`000007o`1Cool0of7o
0?gookko0?mNo`3o__l0o`2:o`02o`3oX@04o`3mool0D?oooad0o`3mo`;o073o00Co01cooonj0?l0
oj7ofol00_l000001Oooo@3oPol0o`09ool0_Ooo08Wo00;o0?oD00Ko0?mTo`2mool0k_ooon80o`3o
3?lTo`02o`2mo`04of?o0?l0oOoo0000o`3oZ`Co09Ko00?o0?o]oolM0?l0V?l00_nIo`000olTo`3o
0?l0o`3oa002o`3oa005o`3moooo7@3ooaL0oolM0?l000000ooo7@001?l0003ooaP0o`000?l0000=
ooooo`03odSo0?oooooo@?l000;ooooo00?o?_l0ooooooooool01oooool4o`@0o`cooooo1Oooo@04
ooooo`03o`000?oooooooooo06Oooooo001^ooooo`;oo`0000Goooooool00?oo003oo`00ooooo`02
ool000Cooooo0_l0ol/2ooooo`;oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool01?o^
o`03ooooo`04ool00?o^o`3ok_l0onko00;oo`0000?oooooonko0?o^o`000_o^o`001Ooooooo0?n[
oom90?o^o`3o/ol000;ok_l000Goof@0ool00?oo003oo`00oomS0002onko0003o`000?oo>`3ooc/0
00?ok_l000Goo`00ooooooooooooooooool00003onko0003ogko0?oo003o0?m=00?ok_l000Ooo`00
onko0?l0003o0000onko0?l0oOoo000000;o<`3o00Goc_l0o`000?l0oOoo0000o`3o]P03o`3mo`03
oeGo0?l0of7o0?nQ00;odOl000?o_Ol0oloo0?mMo`000_o?o`005?l;o`3o_Ol0okgo0?m_o`3oaol0
o`3mool0GOoo05?oo`2:ooo7o`3oG_l0o`3moooQo`3o__l0o`_o0?nno`3o053oo`3oXOoo^P3o0?go
0ol000001_l0GOoo0?nQo`0Qool0okoookX0o`3oe0;o000000_o067oofOo0?l0ROooPol0o`3oI?l0
oiWo__l0o`3o3?l0k_oo02Koo`000002o`3oZ`0@oiWo0?l0U_oo0000o`000?l07?oo02Koo`3oYol0
9_oooad0odgo0?l0L_oo0?lPoolG0?o>o`3o9?l0oolG00;o09So00?ooad0oolG0?l0_Ol00_l0_Ol0
0ol0003o0;goo`2mo`04o`2mo`;o000000?o0?oeooooooooool02_ooool00om8o`3ooooood3o0002
ooooo`03ocko0?oooooooooo00cooooo0_l0000<ooooo`Goood01oooool3oooo00;o0000??ooool3
ool00003oooooooo003oo`0000;ooooo0_oo0002ooooo`;oo`001?ooool3ool00005oooooooo003o
o`00ool00?ooool00_oo00000ol0ol_oooooooooo`02ool000;ooooo1?o^o`02ooooo`;oo`000oo^
o`03ool000Cok_l000?ooc/0oom90?oo00001?o^o`02ok?o0003ool00?o^o`3ok_l000;ok_l000?o
o`00ooooooooool00oo^o`001?oo003oooooool00?oo0003onko0003o`000?oo003oo`0000?ok_l0
00?oo`00o`3oCOoo00000_ooool00oo^o`3o0000o`000002o`000003oaH0ool0og?o000000;o<`3o
0_o>o`001Onmo`3o0000o`3mool0003o0?go00?odOl000?oEOl0o`1[ool0of400oo?o`001_nbo`3o
col0o`_o0?nmo`3oGOl0okgo00;oKol000Oo05?ooolM0?l0oaoo0?lOoeko0?l0oOoo08[o00;o__l0
00So2ol0o`3oXOl0oj7o053oo`3mool08Ooo0?n:o`1`o`;o000000Co0?nQoolM0?l0HOooPol00ol0
om@02Ol0ROooPol0o`3oI?nno`3o0>kooolM0?l0o`co9?l0o`3oRP03o`3oZ`?o00002?l0_Ol00ol0
003oVOl0oiWo0004o`2mo`07oolM0?l0olCooaL0o`000?oo7@3ooaP0oolM0003o`0000gooooo00?o
B?l0oooooom0o`000_ooool00olno`3oooooooooo`0<ooooo`;o00001Oooool5ooom00Kooooo0ooo
o`02o`0006Sooooo001]ooooo`04ool00?ooooooo`00ool000;ooooo0_oo0004ooooo`03ool00?l0
ol_ooooo00?oo`000_ooool2ool000;ooooo0_oo00001?ooooook_l0onko0?o^o`02ool000;ooooo
1?o^o`03ool000?ok_l00_oo00001?l0ohgooooooom90?ooB@02ok?o0004oolk0?l0aOooo`00ool0
00Cok_l000?oo`00onko0?l000000_o^o`001Ooo003ooc/0ooooooooooooo`0000?ok_l000?oTOl0
ool00?o^o`000_l0odd00ol0T?ooo`00onko0002onko00;oo`0000?o0000ooooool000000_l00000
1Oo^o`3o0000o`000?l0R_oo000000?oc_l000coEOl0o`3mool0oOoo0?nQo`3mool0003odOl0ok;o
0?mMo`3o0?n8oolM0?l;o`02ofoo00;ocol00_nmo`002oo7o`3oG_l0oeko0?l0oj7o0?goo`2:oooo
oooo2ol0o`3og_nno`3o053o00;o0?nQ00Go0?oNo`3mool0oOoo05goo`3oX@03o`3oe00;o`0Vool0
003o0000o`1Qool0ROoo05?oo`3oI?ooo@3o09Koo`3o3?l0U_l00_l0oj/01?l0003oon80o`000?oo
7@03o`00000>o`0Lool0e?oo02Koo`1ooooo7@3oc?l0o`1boom=o`3oc_l0oolM0?lTo`3od?l0oolG
0?oo7@02o`2Ho`06oolG0?oo7@3o0000oolM0?l0olCohol00_oo7@03o`0000go0>Co00?oB?l0o`3T
oom0o`000_l0i?l00olno`3o0>Coo`3To`04o`3To`Wooooo0_l00007ooooo`Goood01oooool5oooo
00;ooooo0ol0000kooooo`03ool00?ooooooo`0000;oo`000_ooool2ool00004oooooooo003oo`00
ool000Cooooo0_oo0002ooooo`;oo`0000Koooooool00?oo003oo`00oolX0?l0ol/3ool000Cok_l0
0_oo0002ooooo`Cok_l00ooo0003onko00;oo`0000?o0?n[ool00?ooB@000_o^o`02oolk0003oooo
oonco`3ok_l000;ok_l00ooo0004onko00;oo`0000?oooooonko0?o^o`000_o^o`001?ooooooo`00
ool00?l00002onko00;oo`000_l0odd4onko0007ool00?o^o`3o0000onko0?lF0?oo0?n8o`3oL`03
o`000005o`2:ool0og?oc_l0o`000?o>o`000_l00002o`3mo`03oeGo0?l0oOoo0?nQ00;o0?mQ00So
0?n8ok;o0?l0oiSo0?m8oloo0?nmo`3oGOl0ofoo00?o_Ol000Ko0?gookgo0?mNo`3o0?nQo`3mooo9
o`02o`3ogP06o`_o0?nno`3o__l0o`1@ool0GOoooad00_l000000ooo7@3ookX0o`3oX@03o`3oe0;o
000000Ooood0oh?o0?l0ofCo0?n8o`3^ool0U_oo0?l<00?o0?n[00Co0?n:o`3Dool0003oHol00_l0
00001_l09_oo0?lPo`3o`Ol0L_ooCOl0olko00;ooad000Oo08Woo`000?l40?ooVOl0oolG0?oo7@3o
08[o00;o0;go00?o0000o`2mool0_Ol00ol0_Ol2o`0000co0>Co00?oB?l0o`3Toom0o`000_l0i?l0
0olno`3oooooooooo`0=ooooo`;o00001Oooo@06ooooo`Goool00_ooool3o`0006Sooooo001^oooo
o`03ool00?ooooooo`0000;oo`001?ooool2ool00003o`3obooo003oo`0000?ooooo0_oo00000ooo
ooooo`00ool00004onko00?oo`0000Coooooonko0?o^o`3ok_l00_ooool00ooo003ok_l0onko0002
onko00;oo`000_ooool2onko0004oom90?oo003o/ol0o`3oaP;oo`000oo^o`02ool000?ok_l000?o
o`00o`000?oo00000_ooH`04onko00;ooooo0oo^o`000ol0odgoo`00onko0002onko00?oo`0000?o
ooooonko0?l000000_l00002o`2:o`08onko0?l0003o0000o`000?l0oOoo0000o`29oomEo`04olko
0005o`3oXOl0oOoo/_l0o`3moomMo`000_l0odP01Om_o`3o2ol0okgo0?l0oaooaol000;ocol000So
G_l0oloo0?nmo`3o0?nQo`3moonmo`3ooad0o`_o00?o000000Co053ookko0?l0oj7o__l00_l0om@0
1ol0oj7o07ooo`3og_l08OoookX0oh?o0?l02Ol00_l0U_l01?l0ofCo09Koo`29ool0o``2o`3oZ`06
okko0?o=o`3o0000o`000?l;o`3ooaP00_l000003?l09_oooad0o`0Vool0e?oo0?nWo`1oooo<o`3o
07;oolko0?oo603ooaL0obCo00;o103o00?ooaL0oolM0?oo7@000_l000001Ooo7@3o08[oo`oo0?oo
7@3ohol000;o0?o400?ooad0o`000?ooool00oooool2o`3om@Kooooo00KoB?l0oooooooooooo@?l0
oooooolno`07ooooo`go0>Co1Oooo@07o`3To`Goool02Ol0i?l00ol0003oooooooooo`0jooooo`03
ool00?oooooooooo00?oo`0000?oooooool00?oo00001?ooool3ool00005oooooooo003oo`00ool0
0?ooool00_oo00001OooooooobP0oolX0?l0ol_oo`0000?ok_l000?oooooool00?oo00000_ooool3
onko00;ooooo00?oo`00onko0?o^o`000_o^o`02ool00009ooooooo^o`3ok_l0onko0?ooB@3o0?o6
oolk0?l0aOook_l000;o/ol000Cok_l0ool00?oo003oo`000oo^o`03ool00004ooooooo^o`3ok_l0
onko00;ooooo00?oo`00onko0?o^o`000_o^o`001Ol0003oo`00ool00?o^o`3o0?m=00;ok_l00_oo
0003onko00;oo`001?l00002o`2:o`0@o`3mool0R_ood?l0o`3mool0003o00Woo`29ool0003oc_l0
oeGo0?o>o`3o06_oo`3mool0oj7o0?gook;o00;o0?m800GodOl0o`3o7ol;o`3oGOl0olOo0003oloo
00;oG_l000ko_Ol0olco0?l0oOoooad0olWo0?l;o`3o0?n8o`_o0?l0omko0?goo`1@ool0oj7o__l0
omgo00;o0?oD00Co0?nQo`1`oon3o`3o00_o0_l000001?l0U_oo0?mTo`2Fool0ROl2o`3oZ`0Eo`3o
3?oo7@3o9?l0oooR0?l0oh[ooad0o`000?mSo`3o0?nWo`0Vool0Oooooad0o`3o`Ol0L_ooc_l0oonj
0?oo5`3ooad0o`@0ool0003ooaL000;o000000_ooaL0oolM0?l0003o0000oolM0?oo5`3ohol0o`3o
a?l0003ooad0o`00000<ooooo`03odSo0?oooooo@?l000;ooooo00?o?_l0ooooool0i?l02ol0i?l5
ooom00Ko0>Co1Oooo`09o`3To`03o`000?oooooooooo06Kooooo001_ooooo`03ool00?oooooooooo
00;ooooo0ooo00000ooooooo0?o;ool00002ooooo`?oo`0000?oooooool00?o^o`000_o^o`02oooo
o`;oo`001?o^o`000ooo003oooooonko0003onko0004oooooooo003oo`00ooooo`Cok_l000Goo`00
oom90?nco`3o/ol0ool00003onko0003ool00?o^o`3ok_l000;ok_l00ooo00000ooo>`3o0000onko
0002onko00;oof<01?o^o`000ooooooo0?m=o`3oC@02onko00?oo`0000CoO_l0onko0?o^o`3ok_l0
0_oo0003o`000009o`3oLol0R_oocOl0olgo0?l0003o_Ol0o`000?l0ROooEOl000;o00Wo00Cokol0
o`3oHOnbo`3o/_l00oo>o`001omMo`3oKol0o`3mool;o`3o_Ol0om7o0?o7o`000_l000001_l0R_oo
aol0oloo0?o?o`3o0?gooloo00;o000000Co2ol0oolM0?l0ohSo053o0_l0om@2o`000003olco0?l0
oj7o0;7o00?o09Ko00go00Woo`2Fool07?oo0?n[o`3oI?l0oj_o0?l<o`3^oonno`3oood0okko0?oo
603o000000;oon8000cooad0of?o0?l0ohSo0?n:o`0Vool07?oo0?lPo`3oYol0Oooooad0olko0?l0
L_l2o`@0o`0;oolG0?lTo`3oCOl0o`29oooo5`3o0000oolM0?l0003ooaL0oolM0?l000000_oo7@00
1OoSo`3o0000o`000?l0003o0?Oo00Gooooo0ol0ooD2ooooo`06odSo0?oooooooooood3o0?oooooo
?_l04?ooool5ooom00Oooooo1Oooo`0<ooooo`?oo_l0?_ooool00ooo003oooooool00002ool000Co
oooo0_oo0002ooooo`;oo`0000Coooooool00?oo003oo`000_ooool00ooo003ok_l0o`3ob`02onko
0004oooooooo003oo`00ool000Cok_l00_ooool4onko0004oooooooo003oo`00ooooo`?ok_l000?o
o`00o`3oZoooB@000oo^o`02ok?o00;oo`001?o^o`03ool000Cok_l00oooool3onko0006oi7o0?oo
003oo`00ool00?l0003ok_l00_l0odd00ooo003ok_l0onko0002onko00;oo`000oo^o`05o`000008
olgo0?l0R_oocOl0ool00?nmo`3o0?goo`000?l02Ol2o`000004oeGo0?l0okKoc_l0olko00;o/_l0
00?oc_l0o`3mool0oOl00_l0oOl01Om_o`3oGOl0olOo0?l0GOoo08[o00;o00000oo?o`001Ol0oOoo
col0o`2_ool;o`3o0?n800?o000000?o053oo`3oe?l0oj400_l000000ooo^P3o0?nQo`2Fo`02o`2F
o`0Ho`09ool0U_ooPol0o`3oI?l0oj_o08Woolco0?l0o`cooad0obCo0?oo7@3oon80o`_o0?l0003o
_Ol0oolM0?mSo`3o02Koolco0?l0Oooo05goolko0?oo^P3o0?l00_l40?l00ooo7@3o0000oolG0002
o`00000;o`2Hool0003o0000o`000?oo603ooad0oolG0?oSo`3o0000oolM0?l000002oooool00om8
o`3ooooood3o0002ooooo`03ocko0?oooooooooo00Oooooo1Oooo@07ooooo`Coool03?ooool3ooko
06Sooooo001booooo`;oo`0000Coooooool00?oo003o0?o;0_ooool2ool00003ooooooo^o`3ok_l0
00;ok_l000CoobP0oooooooo003oo`000oo^o`02ool00004ooooooo^o`3ok_l0onko00;ooooo0ooo
0003onko00?oo`0000?o0?n=oom90?nco`000oo^o`001Ooo003ok_l0onko0?o^o`3ooooo00?oo`00
00Ooooooonko0?o^o`3ok_l0o`000?oo003ooooo00?ok_l000Ooo`00oomS0?o^o`3ok_l0o`3oCOo^
o`3o093o00;oo`001?o^o`02ool000?ok_l001Ko0000oaH0ool0003o0?n8o`3oLol0R_ook_l0o`00
0?o=o`3o0000oeGo0?o=o`3o0?gookgo0?l02Ooo/_l0om3o0?l0oj7o0?m8o`3oHOm_o`3oGOl00oo>
o`03on7o00;o000000SodOl0olOo0?oo7@3o0000o`3mool0003o_Ol0o`_o00;o000000Co0?oDolco
0?l0D?oo09Ko0_l00002o`3oX@04o`2Foooo7@3oPol0o`09o`?o0?n[00?o0?mTo`0Lool0o``00_l0
00000ol0ohSo0?oNooom0002o`00000Colgo0?l09_ooon80o`2PoomSo`3o0?n:o`0Vool0ob3o01co
oolM0?l0ojOoc_l0o`@0ool0L_oookX0oolM0?l0h_oo9?l0oolM0002o`00000:oolG0?l0003ooad0
oolG0?oo7@3o09Sooc<0oooo7@3ohol0oolG00;o00000_l0olD7ooooo`;o0?oe00GoB?l0oooooom0
o`3oooooocko000<ooooo`Goood01oooool5oooo00cooooo1Oono`000ooooooo0000o`00000ooooo
o`03ool00?oooooooooo00?ooooo0_oo00001Oooooooo`00ool00?oo003ooooo00;oo`000_ooool4
onko0004o`3oboooooooo`00ool000Cok_l00_oo00001?ooooook_l0onko0?o^o`02ooooo`;oo`00
1?o^o`002_oo003oooooooooooo^o`3oodT0onko0?oo003o0<Gook?o0?oo0003onko0004oolk0?oo
003oo`00ool000?ok_l000?oo`00oolk0?ooH`001?o^o`02ooooo`03ool00?o^o`3ok_l000;ok_l0
00?o0000o`3oCOo^o`000_o^o`02ool000Cok_l00_oo00002Ol0K_oo5P3oo`3mool0ohSok_l0o`00
0?l0og?o0?goo`2:o`03olgo0004o`000?o=o`3o0000oeGo00?od?l000Co/_l0o`3oB?l0oj7o0?nf
0oo>o`001?m_o`3o05?ooego0?l0oOl2on7o00;o00000_l0oOl00oo7o`3o0?gooolM0003oloo00;o
00000_l0om@02Ol0D?oo09Koo`000?l0003o09Koo`3oXOn3o`3oB?l0o`09o`02o`3oZ`04o`3oI?l0
k_oo0?n8o`1Mo`;o000000KocOl0obCo0?l09_oooad0o`000?l0ohX2o`3o8005of?o0?l0ojOoc?l0
o`1oooo>o`000ol40?l01_oo7@3ooaL0odgo0?l0003ooad0oolG00;o000000So09Soo`000?oo7@3o
3ol0oolM0?l0003ooad0on?o00;o00000_l0olD8ooooo`03odSo0?oooooo@?l000;ooooo00?o?_l0
ooooooooool00oooool5ooom00Oooooo1Oooo`0;ooooo`Goo_l000?oooooo`000?l00000J?ooool0
077ooooo00Ooo`00oooooooo003oo`00ooooool0ol_ooooo00;oo`000oo^o`03ooooo`03oolX0?o^
o`3ok_l000;ok_l00_oo0004onko0004ool00?ooooooooooool000Cok_l000?oooooool00?oo0000
0_ooool01Oo^o`3o/ol0ok?o0?ooooooo`0000?ok_l00_ooool2ool00004ooooooo^o`3ok_l0onko
00;oo`0000Kok_l0o`000?o^o`3ok_l0ool00?oo>`03onko00;o0?m=0_oo0003onko0003oooooooo
003oo`0000?ok_l00ooo00000ol0003o5P3oo`000002o`000007o`3oLol0R_oo0000okgo0?mEo`3o
0000ooooo`02olgo0009ok;o0?o=o`3o0?m8o`3oXOl0of7oKol0o`3oV?mMo`3o_Ol000;ohOl000Co
_Ol0oeko0?o>o`3oc_l00_l0oOl2o`000003om7o0?l0oOoo0?oD00;o0?oD0_l000000onmo`3ocol0
o`1@o`02oloo0004o`1Moooo7@3o0?nQo`3oX@?o0?n[00Ko00Woo`0Vool0ofCo05?oo`3o3?l0k_l2
o`00000Ao`3oR?l0L?oo0000okko0?l0003o0?oNolgo0?oohP3o0?oNof?o0?l09_oo0?n:okgo0?l0
7?oooad0olko0?l40?l00_oo7@001ol0L_oooad0o`3RoolTo`3o0000oooR0?oo7@000_l000001Ol?
o`3o08[ooolM0?oo603o09So00;ooad000Gohol0o`000?ooooooooooo`3go`02o`3oa@Kooooo00Go
B?l0o`3omOm0o`3oooooocko0008ooooo`Goood02?ooool4oooo00cooooo1Oono`07ooooo`03o`00
0?oooooooooo043ooooo0ooo00001?ooooooo`00ool00?ooool3ool000Cok_l000Goo`00oooooooo
oooo0?o;ool00003onko0003oooooooo003oo`0000Cok_l00_ooool2ool000?ok_l00_oo00000ooo
ooook_l0onko0002onko0003oom90?oo003ooooo00;o/ol00_o^o`02ooooo`03ool00?o^o`3ok_l0
00;ok_l000?oo`00ooooooooI0000oo^o`001?oo003ooc/0oomS0?oo0003onko00;ooooo00Coo`00
o`3oCOl0odgok_l00_oo0003onko00?oo`0000Coooooo`1^ooo^o`3ok_l00_l000001?l0ohSo0000
o`000?o_o`02o`0000;o08[o00Cokol0o`000?l0R_oo00000oo=o`001_nbo`3o0?m8o`3oHOl0oj7o
d?l0o`3o]P;oKol000Ko05?oon7o0?mMo`3ohOl0oeko0?nno`04o`3mo`06om7o0?l0oOoo0000o`00
0?l;o`3o0?oD0_l00002oloo0004o`1@oooo7@3o0?goofKo00;o0?nQ00Wo0?n[o`09ool0oj_o01co
o`3oI?l0k_oo05?oo`3oR?l0o``00_l000006?ooo@3o9?l0o`3og_l0003o0?oNoooR0?l0oh[o02Ko
of?o0?l0oOoo0?nWolko0?l40?oookX0o`1boooo7@3ooaP0o`29oooo5`3o0000odgo0?l0003ooaL0
o`2:o`;o000000?ooaL0oolM0?l000000_oo7@000ooSo`3o0000ooooo`02ooooo`;o0?o51Oooool0
0om8o`3ooooood3o0002ooooo`03ocko0?ooooooood000Coood01oooool5oooo00_ooooo1Oono`07
ooooo`03o`000?oooooooooo06Kooooo001booooo`04ool00?ooooooooooo`3ob`;oo`0000?ok_l0
ool00?oo00000oooool3onko00;ooooo00Coo`00onko0?o^o`3ok_l00_oo0002ooooo`04ool00?o^
o`3ok_l0onko00;ooooo0ooo0003onko00;o/ol01?o^o`02ooooo`?oo`000oo^o`02ool000?ok_l0
00?o0000ool00?oo>`000oo^o`001?oo003ooc/0o`3oCOoo0003onko0003oolk0?oo003oo`0000?o
k_l00ooo00001?ooooook_l0onko0?o^o`04o`000007o`3mool0og?o0?mco`000?mEo`3o0000o`3m
o`02ok;o0005o`3oB?l0003ocOl0olgo0?m_o`000_o=o`001omMo`3ohOl0om3o0?l0DoooG_l0okgo
0?l0okH00ol000002_o>o`3o0?oDo`3oe?l0oOoo0?nQo`_o0?l0U_oo2ol0o`3mool0ohP2o`000006
o`1@ool0oOoocol0o`3oZol0oj7o0?n[0_l0oj400oo;o`3ookX0o`3oI002o`000006o`3^oooo7@3o
08Woo`29ool0ohSooooo0ol00002ooom000>olgo0?oohP3o02Koof?o0?l0omko0?n:o`@0ooo>o`3o
0?oNo`3oYol0OooookX0o`1bool0ol42o`000005o`29oooo5`3o0000oolM0?l000000_m=o`02oolM
0003oolH0?l0V?oooad000;o00000oooool00ol0moooooooo`3oa@02o`3oa@;ooooo00KoB?l0oooo
oom0o`3oooooocko0?l0ooD3ooooo`Goood02?ooool5oooo00_ooooo1Oono`08ooooo`;o00000_oo
ool00ol0003oooooooooo`0oooooo`03ool00?ooooooo`0000;oo`0000?oooooool00?oo00000oo^
o`02ool000?ooooo00Kok_l0o`3oboo^o`3ok_l0oooooooo0004onko00;oo`0000?oooooool00?o^
o`000oo^o`02ool000Cok_l00ooo00001?ooB@3ok_l0onko0?nco`03ooooo`Cok_l00_oo00000ooo
>`3ok_l0onko0002onko0003ool00?oo>`3oof@000Cok_l000?o093ooomS0?o^o`000_o^o`000ol0
odgoo`00o`000003onko00?oo`0000?oooooonko0?o^o`000_o^o`001Ooo003okol0o`000?l0003o
0?go00;o000000?o0?nRo`000?l000000ol0og<01?l0ROoo0000okgo0?l00002ok;o00CocOl000?o
0?nQofoo0?o@o`000_oQo`001?l0okKoGOl0oeko0?oo7@05olko0003o`000?l0oOoo0?oD00;o0?oD
00Co09Koo`3mooo9o`3ookX00_l000001?l0D?oocol0oloo0?o?o`03o`3oX@03o`1Qool0ofCo0>ko
00;o000000Oo0?l<o`1`ool0ROooc?l0o`1MoolTo`3o000000;o0?lP00coon80o`0Vool0omko0?oN
of?o0?o>o`3o0?oNo`1ooooo^P3ooad0o`1bool0h_l4o`0000;ooad000KooaL0o`000?l?o`3ooaL0
oolM0?l0V?l2oolM00;o00001Oooool2o`3oa@;ooooo00KoB?l0oooooom0o`3oooooooom0?lno`02
ooom00Sooooo1?ooo`0;ooooo`Goo_l02?ooool2o`0000;ooooo00?o0000ooooooooool0I_ooool0
07Cooooo00?o0?o;onko0?oo00000_oo00000oooooook_l0onko0002onko00;ooooo1?o^o`03ool0
0003ooooooo^o`3ok_l000;ok_l00oooool2ool000?ok_l00_oo00001_nco`3oodT0onko0?oo003o
ooooo`3oaP;oo`001?o^o`02ool000?ok_l00ooo00001_l0003ok_l0onko0?oo003ooc/0ool000;o
0?m=0_o^o`000oooooooo`00ool00003onko0003oooooooo003oo`0000Cok_l00_oo00001?o_o`3o
0000okgo0?l00003okgo0005o`3mool0003o0?mco`000?nbo`000_l0oOl01?nmo`3o08[oo`000?m_
o`03on7o0008oego0?o=o`3ocOl0oeko0?o7o`3o_Ol0o`000?l0U_l3o`3oe005o`2Fool0003o0?go
olko0?l;o`000_l000003onYo`3o0?n8o`000?l0003o0?n[o`1@ool0oj_obOl0o`3oXOl02Ooo0?3o
oloo0?l0oj7o0?mToloo0002o`000003o`1Qool0[ooo08Wo00?o000000Wo0;7oobCo0?l0003o073o
olco0?ooo@3oon80olOo0?mSo`000_l40?l03?o>o`3o01coolco0?l0GOoo07oooonj0?l0omko0000
o`3o`OlTo`3o0?oNoolM00;o000000?ooad0oolG0?oo60000_oo7@000ooo5`3o0000oolM0002o`00
00?ooooo00?o0?Ooooooooooool00_ooool2o`3oa@04oooooom0o`3oooooocko00Goood02?ooool5
oooo00_ooooo1Oono`0;ooooo`CooOl00_ooool00ol0003oooooooooo`10ooooo`03ool00?oooooo
o`0000Cok_l00_oo0003ooooo`?ok_l000?o0?o;oooooooo00000oo^o`03ool00003ooooooo^o`3o
k_l000;ok_l000?oooooool00?oo00000oo^o`02ooooo`;oo`000_o^o`001OooB@3ok_l0ok?o0?nc
o`3o0<Go00?ok_l000Coooooool00?oo003oo`000oo^o`02ool00003oolk0?ooooook_l000;ok_l0
00?ooooooolk0?ooI0000oo^o`000ooo003o0?m=o`3oC@02onko0005o`000?oo003oo`00ool00?oo
ool00oo^o`02ool000?okol00_oo0003okgo000>o`000?o_o`3oo`00o`2:oooooooo_Ol0onoo0?l0
og?o0000o`3oLol0003o0?goo`2cool0of42o`09o`09o`1[oom_o`3ohOl0on7o0?o=o`3od?l0oeko
0?mMo`3o_Ol000;o0?nf00Ko09Koo`000?l0003o0?oDolko0?l0oOl2olko0005o`_o0?l0003o0000
ojWo0?o9o`000_l000001Ol0D?oo0?n[o`3oUol0oOoo0?nQ00;ocol000?o0?nQoloo0?oo7@000_l0
00001ol0ohSo_Ol0o`29ool0L?oo9?l0o`000?l0GOl00_ooo@002Ooo7@3oon80o`@0ool40?ooHol0
olco0?l0ojOo07oooonj0003o`000006o`3og_l0003o0000oolM0?l0ROoooad00_l000001Om=o`3o
oad0oolM0?lc0?oooad000?o00001oooool2o`3oa@05odSo0?m0o`3oood0ooom0?lno`001_ooool5
oooo00[ooooo1Oono`0<ooooo`?ooOl00oooool00ol0003oooooooooo`1Uooooo`00L_ooool2o`00
0003oooooooo003ooooo00?ok_l00_oo0004onko0005ool00?ooooooo`00ool00?ooool00oo^o`04
ooooo`;oo`000oo^o`000ooo003ok_l0onko0002ok?o0005oom90?oooooo0?n[oooooooo00000oo^
o`000oooooooo`00onko0003onko00;oo`001?o^o`000ol0003oo`00ooooo`02onko0005o`3oCOoo
oooooc/0o`2@oooo00000oo^o`000ooo>`3oo`00ool00003onko0003oolk0?oo003oo`0000?okol0
013oo`00o`000?l0003o0000o`3oR?l0oOoo_Ol0o`3mool0003o_Ol0o`000?l0og?o0?goool00?l0
oOooKol00_oQo`001?l0oiSo0?nQo`09oomMo`02oeko0003o`000?l0omCo_Ol000;o0?oD0_o@o`00
1_l0oOoo0?nfo`3o]_l0oOoo0?nQo`_o00;o000000ooc_l0ojWo0?nYo`3o0?n[o`3mool0D?oo05go
o`09ool0oj7oPol0o`3`ooo<o`3o0?mTo`3mool0o``00_o?o`03o`00000@o`29ool0003o01coo`0L
oolTo`3o_Ol0o`000?l0L?oo02Koo`@0oooohP3oHol0o`1[ooo>o`3o0?n:oolM00?o3ol00_l00004
o`oo000:o`000?l?o`3o0000o`3og_oo7@3ooaL0o`3og_oo7@3oCOl0oolG00;o00001?l0ok`00ooo
oooo0?Ooooooo`02ooooo`06odSo0?ooo@3o0?o5o`3oaOooo@3o?_l00oooool00ol0003o0?oeoooo
o`02ooooo`Goool02oooool5ooko00_ooooo1Oomo`06ooooo`03o`000?oooooooooo047ooooo0_o^
o`001Oooooooo`00ool00?oo003ooooo00Cok_l00_l000001Ol0ol_ok_l0onko0?o^o`3ooooo00;o
o`0000Ooooooonko0?o^o`3ok_l0ool00?ooooooo`0000Cok_l00_ooool2ool000?ok_l000Coo`00
oom90?oooooo/ol00oo^o`000oooooooo`00ool00004onko00;oo`0000?oooooonko0?o^o`000_o^
o`000ooo>`3oooooooooo`03onko0005ool00?oo>`3ok_l0o`3oCOo^o`000_oo>`000ooo003o0000
oomS0003onko0003ool00?o_o`3okol000;okol00_oo00000oooooookol0onoo0002o`000003o`3o
R?l0003o_Ol000Co_Ol000GoEOl0o`3oB?l0003o/_l0o`000002o`3oL`03o`3oHOl00Ooo0?mQ00;o
hOl000Oo0?nQo`3o?_l0od3oG_l0olgo0?mMo`3o_Ol000;o00000ol0om@01_l0oOoo08[oo`3mool0
oj7oc?l0olko00;o000000?oc_l0ojWo0?nYo`000_l0oOl01ol0D?ooPol0o`09ool0oj7ookX0o`3o
I?l0k_l00_l0oj401ol0o`cocol0oloo0?l07?oo08Wookko0?l000000_l0L?l02?l0GOoo103oooom
0?oohP3o0?l0olko0?mSo`3o01co0ol00003o`oo0003o`000?l?o`3o3ol000;o3ol000Oo0000o`oo
0?l0003o0?oNoolM0?m=o`3ooad000?o000000Coooooo`3goooooooooooo1Oooo@001Om8o`3o0?o5
o`3oaOoooooo?_l000;ooooo1Oooo`0;ooooo`Coo_l03?ooool5oogo00Kooooo00?o0000oooooooo
ool0IOooool007;ooooo0_l000000oooooook_l0onko0003ool000;ok_l00_oo00001?ooooooo`00
ool00?oo0003onko0003ool00?oooooooooo00;ooooo1?o^o`002Ooo003ok_l0onko0?o^o`3oo`00
ok?o0?ooooooodT0ooooo`04onko0003ooooool0aOook_l000;ok_l00_ooool01?oo003ok_l0onko
0?o^o`03ool00004onko0?l0003ok_l0onko00;o0?m=00?oo`00onko0?o^o`000_o^o`000ooo>`3o
o`00ool00003onko0003oolk0?oo003oo`0000?okol00_oo00000oooH`3o06koo`000004o`000005
oooooomEo`3o0?m8o`000?l0ROl00ol00002on7o00?o09Ko00?o0?nQo`2FoomMo`000ol0om@01?o7
o`3o0?mQokgo0?l0ocl4olgo0004om3o0?l0oOoo0?nQo`_o00?o0?n[00Co0?n8oolM0?nYo`3oZOl0
0_l000001ol02OooPol0o`3oXOl0R_ooc?l0o`3oI?l0o``00ol00002o`oo0003oloo0?l0003ocol0
00;ocol02?l?o`003?mSo`3o3ol0o`oo0?l?o`3o01cooolG0?l0003o07oooolM0?nmo`3o07;oobCo
00?o000000GooaL0o`000?oo7@3o0?nQoolG0002oolM00?o000000Co06Sooooooooooooooooo0_l0
ok`01Ol0mooo0?nlodSo0?l0okco@?l000;o0?nl0_l0olD:o`3o_0Wooooo1Oono`0;ooooo`GooOl0
2oooool00ol0003oooooooooo`13ooooo`03ool00?ooooook_l000;ok_l00_oo0002onko00;o0000
00Coo`00oooooooo003oo`001?o^o`000ooo003oooooonko0003onko00?ooooo00?oo`00onko0?o^
o`000_o^o`02ool00006ooooooooB@3o/ol0ok?o0?oo003o0<Go0_oo0003onko00?oo`001?o^o`00
0ooo003oooooooooo`04onko0004ool00?o^o`3ok_l0onko00;o0?m=00?ooc/0ool00?oo00000_o^
o`000ol0003ok_l0ool00003onoo00?oo`0000Coooooonoo0?o_o`3okol00_oo00001ol0oj;o0000
onoo0?l0003oo`00o`_o0?l0R_l00_nmo`000omEo`3o_Ol0o`000002o`2:o`?o00000_oQo`002_l0
ok;o05?oo`3oXOl0U_ooG_l0o`2Fooo7o`3oGOl0o`3oe?nmo`04olgo0005o`3mooo@o`3o0?goo`3o
XOl;o`000ol0oj/00ooKo`3oc_l0olko0003ojWo0008o`000?l0L_oo0?nQo`3mool0ofCo0?nIo`0V
ool0Dol2o`000003o`oo0?o?o`3ocol000?ocol01_l?o`03o`0000?o3ol000Oooad0o`000?l0003o
0?o1oooR0?lTo`3ooad000?o000000?ooaP0oolG0?l0omh00_oo7@03o`000003o`3o_?l0mooo0?nl
00Go0?nl00CoB?l0od3o0?l0okco0?nl0ol0olD5o`3o_0Oooooo1Oono`0;ooooo`GooOl02oooool0
0ol0003oooooooooo`1Uooooo`00M_ooool00ooo003ok_l0onko0003ool00003oooooooo003ok_l0
00?ok_l000?oo`00ooooooooool00_ooool3onko0003ooooooo^o`3ok_l000;ok_l00_oo0002ok?o
0006ooooooooB@3ok_l0onko0?l0oj_ooooo1?o^o`02ooooo`05ool00?o^o`3ok_l0onko0?ooool0
0_oo0003onko0004ool00?l0003oooooo`3oC@?ok_l00_ooJ`000ooo003ok_l0onko0002onko0003
oolk0?oo003oo`0000?okol00_oo00000oooI03okol0onoo0002onoo0004ool00?l0003o0000o`00
00;o_Ol00ol000001?nbo`3o0000o`000?l00002o`2Fo`;o_Ol0017o0000o`3oe?mNo`3oGOl0o`3o
?ol02Ooo05goolOo0?l0ocko_Ol0olco0?l09_oooad0o`3mooo7o`3o0?n[o`3mo`02o`3oZ`Oo3ol0
0onYo`000oo>o`3o0?nQo`000003o`00000:o`oo0?l0003o0000o`0Vool0ohSo0000o`3oR?l0ROoo
oad0obCo00Cocol000So0000omgo0?o<o`3oon80of?o0?ooo@3o0;7oo`3oRP;o000000gookX0o`3o
XOl0Oooooad0o`1bool0003o0?o1oooR0?l0003ooad0oolG0?l0R_oooad000;ooaL000Kooad0o`00
0?l0003ooooooc?o0?l0J?l3ooom0008ooooool0moooooooodSo0?oooooo@?l0oooooolno`02oooo
00;o0?o500?oool0ooooooooool01OoooolEo`3o_0CooOl04Oooool00ol0003oooooooooo`12oooo
o`;ok_l00ooo0002onko00;oo`000_ooool01?oo003ok_l0onko0?o^o`02ool00005ooooooo^o`3o
k_l0onko0?oo00000oooool01?oo003ok_l0onko0?o^o`03ool000;ok_l000GoodT0ok?o0?nco`3o
0?o6ool00004onko00?oo`000oo^o`02ool000;ooooo0oo^o`02ool000?ok_l000?oo`00oolk0?l0
odd00_oo0003onko0003o`1Voooo003o000000;okol00ooo0004onoo00;oo`0000Koof/0onoo0?o_
o`3okol0o`000?ooJ`02o`000005o`_o0?l0003o_Ol0okgo0?l0ROl00ol000002?l0oOoo0000o`00
0?l0003oKol0o`2Fool0Dooo0?lo0_mNo`002_l0003o0?oDo`3oe?mMo`3o02Kookgo0?l0ohSoc?l0
olOo0?l0oOl2olgo0004o`3mooo=o`3o2ol0o`3mo`Oo3ol000Ko0000ojWo0?nYo`3o0?nQo`3oI?l0
/ol2o`000007o`3o3?l0003o0000oolM0?l0ROoo0000obCo0002o`@0o`;ocol01?l000003Oooo@3o
0?n:of?o0?oo^P3ooad0o`3oYol0003o0>;oo`1bool0ol7oon80obCo0?l0ROl01Ol000000ooo5`3o
oad0oolM0002o`000004o`1Xooooooooooooo`3go`Cooooo00GoB?l0oooo0?m0o`3oool0ocko0003
ooooo`;o0?o50ooooolEo`3o_0;ooOl01_ooool2o`0000Sooooo00?o0000ooooooooool0IOooool0
07Sooooo00?oo`00oooooooo00000oo^o`03ool000;ooooo1?o^o`001?ooooook_l0onko0?o^o`02
ooooo`;oo`0000Gooooook?o0?o^o`3ok_l0oom90002ooooo`?ok_l000Coo`00ooooool0aOooo`00
0oo^o`000oooooooo`00ool00003onko0004ool00?ooooooooooooooo`;o0?m=00Cok_l0ooooool0
T?oooooo0oo^o`02ooooo`;oo`000oo_o`02ool00004oolk0?o_o`3okol0onoo00?oo`000_o_o`04
o`000007o`3mool0003o0000o`000?oQo`3o0000ofoo0003ok;o00;o0?oD0_mNo`001Ol0oj7oGOl0
o`000?l0003oaol000;o3ol000?o_Ol0o`_o0?l?o`000ol0oj/01?l?o`3o0?goo`_o0?l?o`02o`00
0003okKo0?o=o`3o0;?o00;o0;?o00?o00Woo`2cool000000_l000001?l0ofCo0?l<o`000?l00002
olko0009o`3mool09_oo0000o`2aool0ohSo08WooolM0?lTo`3o103o00;o02Ko01?o01coo`000?l0
003oc_l0olco0?oohP3oHol0ooom0?l0003o0?n:oonj0?l0/Ooo0>;oo`1oool0ojOo08Woo`000?l0
ol7o000000;ooad000Ko0?o]oolG0?oo7@3ooad0o`000?oo7@02o`000004ooom0?oooooo<ol0o`1X
o`Cooooo00KoB?l0oooooom0o`3oool0ocko0?ooo`04ooooo`;o0?o51Oooool5ooko00_ooooo1Oom
o`000ooooooo0?nlo`3o_007o`3o_0;o00000_oko`08ooooo`03o`000?oooooooooo04?ooooo00?o
o`00onko0?o^o`000ooo00000oooooook_l0onko0002onko00;oo`001?o^o`000ooo003ooooooooo
o`02ooooo`?ok_l000?oooooool00?oo00000oo^o`001?oo003oodT0ok?o0?ooool3onko0003oooo
oooo003oo`0000Cok_l00_oo00000oooooook_l0onko0002onko0003ool00?o^o`3ok_l000;ok_l0
00?oo`00ooooooooool00_l0odd3onko0003o`1Vooo_o`3okol000;okol000?o0000ool00?oo0000
0oo_o`03ool000Cokol000Coo`00oooooooooooooooo0_l000001_l0ohSo0?m8o`000?l0003o0?go
okgo00?o000000cohOl0o`000?m_o`3o/_l0o`3mool0Doookol0oeko0?l0omCo0?nQo`3oe?o7o`02
o`000003o`oo0?nmo`3o2ol000;o3ol00_l0oj/00ol0oOoo3ol0o`oo0002olgo00;o000000Go]_l0
o`2cool0/ooo0;?oo`09o`02o`2co`04o`1@oonYo`3oZOl0olko00;o000000Soc_l0oolM0?l0ohSo
0?lPo`000?l0ROoo9?l0o`0Lo`?o000000Sooad0olko0?l0003o0000oooR0?ooo@3oHol0oonj00;o
000000co07ooo`29oonmo`3o07;oo`3o`OlTo`3o0000oolM0?l0003ooaL0oolM0?l00003oolM00;o
000000Go<ol0ooooooooooooool0o`3go`02oooo0005odSo0?oooooo@?l0oooooolno`001_ooool2
o`3oa@?oo_l02oooool5oogo00?ooooo2_l0ok`2o`0000Kooooo00?o0000ooooooooool0IOooool0
07Wooooo0_o^o`03ool000;ooooo0oo^o`02ool000?ok_l000?oo`00oooooooo00000_oo00001_o^
o`3o/ol0ok?o0?o^o`3oo`00oom900?ok_l000?oo`00ooooool0olH01?o^o`000oooooooo`00onko
0003onko00;oo`000_ooool2onko0003o`3oCOl0003ooooo00;o093o0_o^o`02ooooo`03ool00?o_
o`3okol000;okol00ooo0003onoo00?oo`000oo_o`001ooo003o0000o`3oLol0003o09KooeGo0?l0
ohP00ol000000om_o`3o3ol0o`000002o`3oe003o`2:oonbo`3oG_l000?o/_l00ol000001_o7o`3o
0?m0o`09ool0oj_o_Ol0o`3oZ`Co0;?o00?o0?goo`_o0?l0oj400_l000001?oo7@3o]_l0okKo0?o=
o`03o`000003o`3o]_l0D?oo0?nQ00;oZOl000KobOl0o`3oVOoo^P3o0;Koolko0?l00003olko0003
o`29ool40?oo9?l000;o02Ko00?ooaL0okgo0?l000000_l000003ol0oOooon80of?o0?l0003o05go
ooom0?oo^P3ocol0o`3Rool0/Ooo07ooo`000?lTo`3ooad0o`000002okco0008oolM0?l0ongooaL0
oolM0?lc0?oo0000oolM0?l00003ooooo`09oc?o0?ooooooool0oooo0?m8o`3oool0od3o0?oooooo
?_l000Sooooo0_l0olD3ooko00_ooooo1Oomo`0:ooooo`Gonol01?l00008ooooo`03o`000?oooooo
oooo04Gooooo00?oo`00ooooooo^o`000_o^o`000oooooooo`00onko0003onko00;oo`000oooool4
onko0003oooooooo003ok_l000?ok_l00ooo0002ok?o00;ok_l000?o0?o6o`35oooo00000oo^o`03
ool00004ooooooo^o`3ok_l0onko00;oo`000oo^o`02ool00005o`2@ooooooooo`00onko0?l0odd0
0_o^o`001Oooooookol0onoo0?o_o`3ooc/000;oo`0000Cokol0o`000?o_o`3okol00ooo0003onoo
00;oo`0000?o0?nRoomS0?o_o`000_o_o`002Ol0003o0?mco`000?l0odSo09KooeGo0?l0U_oo_Ol0
o`3mo`03o`000003o`oo0?l0003o0?mc00;o08[o00Oo/_l0oeko0?nbo`3o/_l0o`3oO_l0oj7oaol0
00;o00000_nmo`000ol;o`3o0?n[o`3oZ`02o`2co`05o`3mool0/ooo0;?oo`_o0?o<o`000_l00000
2_o=o`3o]_l0okKo0?o=o`3ookX0o`3`oooo7@3o053oo`3oXOoo^P03ojWo0003o`0Vooo>o`3oc_l0
00;oc_l00ol000001Onno`3o02Koolco0?o>o`3o0:oo00;o000000ko05gooooR0?oo^P3oHol0o`2a
oooo7@3o0?nWo`1oooo?o`3o07;oo`3o`Ol0003o0=Coo`2:o`;o00000_oo7@001?oo5`3o0000o`00
0?oo7@02oooo000:oc?o0?ooo`3oooooo`3gooooooooB?l0oooooom0o`3oooooocko00;ooooo1Oon
o`02ooooo`;o0?o51oooool5oogo00[ooooo1Ooko`03ooooo`;o00001_ooool00ol0003ooooooooo
o`1Uooooo`00N_ooool00ooo003oooooooooo`03onko00;oo`000oo^o`000ooo003oooooool00002
ool000?ok_l000Ko/ol0ool00?o^o`3ok_l0oom90?o^o`02ool00007ooooooo^o`3ok_l0onko0?l0
aOooooooool00003onko00?oo`0000?oooooonko0?o^o`000_o^o`02o`3oC@04onko0?l0003o093o
ool000;ooooo00Goo`00onoo0?o_o`3okol0oom/0002ool000Cokol00ooo0003onoo00;oo`000_oo
>`03o`000003oeGo0?l0og?o<Ol000Ko000000Go0?nHo`09ool0oOooG_l0o`3mo`03o`2co`03ok;o
0?mMo`3o0?mQ00;o/_l000Oo0?n[o`2coonmo`3o2ol0oolM0?l0of7oaol000;o0?go00Go2ol0o`3m
ool0oj7o0?goo`2:o`03o`000008okKo0?n3o`3ocOl0olgo0?l0D?oo0?nQolgo0?l0Dol2ojWo0005
oonj0?l0R_oo0000o`000?l0oOl00_o;o`04olko0006o`0Vool0/Oooc_l0olko0?nno`3oc?l00_l0
00001?mSo`3oaol0olgo0?oo^P02ooom000Ao`1`oooo603o0000o`3oYolTo`3o07;oo`000?l0ol7o
col0oolM0?l0ongo0?gooc<0oooo7@3o0000oolM0?l000001?ooo`001olco`3oooooodSo0?oooooo
@?l0o`3goolno`001?ooool5ooko00;ooooo0ol0olD6ooooo`GooOl02Oooool00ol0omSo0000o`00
0003oo_o017ooooo00?o0000ooooooooool0AOooool2onko0003oooooooo003ok_l000;ok_l000Co
ooooool00?oo003oo`000_ooool3onko0003ool00?ooooook_l000?ok_l000Coooooool00?oo003o
o`000_o^o`001?nco`3oo`00ooooooooool4onko0004oooooooo003oo`00ooooo`?ok_l000?oo`00
onko0?o^o`000_o^o`02ool00003ooooool0T?oo093o00;ok_l00_l0odd01OooK03okol0onoo0?o_
o`3o06Ko00;oo`000oo_o`001?ooK03o0000ool00?oo0003onoo00;oo`000_oo>`03onoo0003ool0
0?ooK03okol000Co000000GoEOl0o`2:ool0oOoo08Wooc7o0002o`000004o`09ool0003o0?mQo`00
00;o0?oD00CoG_l0o`2cool0/ooo0;?o1?nbo`001_mMo`3o0?n[o`3oZonmo`3ooad0olOo00;o_Ol0
00Oo0?gookgo0?nmo`3o2ol0omgo0?l0ohSooaP000;ooad000Co00WookKo0?nfo`3o]_l00_o=o`00
1_l0D?oo05?oo`3o3?oo7@3o07;oojWo00Co000000?o9?l0olko0?o>o`000oo>o`001Ooo7@3o2ol0
olWo0?o<o`3ocOl000;o0000013oHol0ooom0?ooo@3o0>;oo`1ooooo7@3oon80o`1bool0003ocol0
o`000?oo7@3o0?goo`000?oo7@3o<`3o0_l000001Ooo7@3ooooooooooooooooo<ol000;ooooo00Go
B?l0oooooom0o`3oo_l0ocko0003ooko00Wooooo0_l0olD5oogo00[ooooo1?oko`000ol0omSo0000
o`00000>ooooo`03o`000?oooooooooo06Gooooo001kooooo`;ok_l00ooo00001_o^o`3oo`00ool0
0?oo003oooooool000Cok_l000?oo`00ok?o0?nco`000_o^o`001?ooooooodT0ool00?ooool3onko
0003ool00?oooooooooo00?ok_l00ooo00001Oooooook_l0onko0?o^o`3oo`0000;ooooo00Go0?m=
onko0?o^o`3o093oo`000002ooooo`?okol000?oooooool00?oo00000oo_o`001?l0I_ooo`00ool0
0?oo0003onoo00;oo`0000Oooc/0onoo0?o_o`3okol0o`3oI?oo003okol000;o000000?o<Ol0o`00
0?l000000ol000001Olc0?oo0000oc<0oolc0?ooG_l000Ko<`3o00?oGOl0oc<0oolc0?l00_lc0?l4
ok;o0005o`3o/_l0of7o0?goo`3mool;o`001?l00002okgo0008o`09ool0003o]_l0okKo0?l0ofCo
0?l<o`1@ool0Dol3olgo00;oZOl00_l000002?l0HOoo0?goo`1bool0ROoo9?l0o`29ool09_ooc_l0
0_l000000onmo`3o__l0o`000002o`00000Bolko0?mSo`3ocOl0oonj0?l0GOoo01coooom0?l0003o
073oo`1ooolTo`3o0000oolM0?l0ol7o08[oo`2aoooo7@3o<`3o0_l000000oooo`3o0000oooo0005
ooooo`06odSo0?oooooo@?l0oooooolno`3o0?Oo1?ono`0:ooooo`;o0?o51?omo`09ooooo`Go0?oH
00?onol0o`000?l000005?ooool00ol0003oooooooooo`17ooooo`;ok_l000Goooooool00?oo003o
o`00ooooo`04onko0003ool00?ooooook_l000;ok_l00oooool2ool000?ok_l00_nco`001_l0oj_o
k_l0onko0?o^o`3oooooo`35o`;oo`001?o^o`001?oo003ok_l0onko0?o^o`03ool000;ooooo00Ko
k_l0o`2@ooo^o`3ok_l0ooooool0odd3onoo0003o`1Voooo003okol000?okol000Go06koool00?oo
003okol0o`000002onoo0003ool00?oo>`3o05oo00Cokol000?oo`00ooooooo_o`000_o_o`000ol0
ofCokol0onoo0003o`0000;o0?mc00Go<Ol0o`000?l0003o0000ofoo0003o`0000;oG_l01olc0?l0
1ol0of7oGOl0oc<0oolc0?oo/_l0o`_o0?o7o`000_l0of43o`3mo`03o`_o0?l0oj7o_Ol000;o_Ol0
00Go00Wooh?o0?l0oOooaol0o`3oI002okKo0003o`1@ool0oj7ocOl000Co00000_nYo`001ol0P?oo
9?l0o`0Qoonmo`3oc_l0okko0?o>o`000_l000002?oo7@3oc?l0o`000?o<o`3oon80of?o0?l07?oo
073o0_ooo@002ooo7@3oon80o`000?lTo`3o0?o1o`000?oo7@3o0?o]oolM0?l0003ooad000;o0000
1Oooool01_lco`3oB?l0ooko0?m0o`3oo_l0ocko00[ooooo1Oomo`02o`3oa@Sooooo1?oko`05o`3o
f004ooooool0003o0000o`0000kooooo00?o0000ooooooooool0I?ooool007cooooo00?oo`00onko
0?oo00000_oo00000oooooooo`00onko0002onko0003oooooooo003ok_l000;o/ol000Gok_l0oooo
oooo003oo`00oom90003onko0003ool00?ooooook_l000?ok_l000Coooooool00?oo003ooooo0oo^
o`001?oo003oooooonko0?o^o`02o`3oC@;oo`0000?o093oooooool000000_o_o`000oooooooo`00
onoo0003onoo0003oooooooo003oo`0000Cokol00_oo00001?ooooookol0onoo0?o_o`02ool00006
o`3oI?o_o`3okol0ool00?l0003o<Ol00_l0/ol05?l0og?o0000o`000?l0003o0?mco`_o0?l0003o
G_l0okgo0?l0003o0?goo`3oZol0R_oo0?n[o`3oHOmMo`3oaol0o`3o?_l0ogko00001_lc0?l3o`00
00Oo<`3o0_l000001Onmo`3o]_l0okKo0?nfo`3o000000?o<`3o00Go0000olgo0?nYo`3oZOl0olgo
0003oc<0o`04obCo0?lc0?oo<`3ooc<0o`;o000000?o<`3oo`000?lc0?l00olc0?l00omSo`3o<`3o
oc<0o`03oc<0o`04o`000?lc0?oo<`3oobCo00Co<`3o0_l000001Ol0ongo0000o`000?oo5`3o0000
00Gooooo00SoB?l0ooko0?m0o`3oo_l0ocko0?ono`3oooooo`3go`Sooooo1Oomo`02ooooo`;o0?o5
1_ooool5o`3of003oo_o0?oooooooooo00Sooooo1?oWo`0=ooooo`03o`000?oooooooooo04Wooooo
00?oo`00ooooooo^o`000_o^o`03ool000?ok_l000Coo`00ooooooooooooo`001?o^o`001?oo003o
0?n=ok?o0?ooB@02onko0004ooooool0olKoo`00ool000?ok_l00_ooool3onko00?oo`000_ooool2
onko00;o093o00Ooooooonoo0?l0odgo0?m=ool00?ooooooo`0000?okol000Coooooo`1^oooo003o
o`000oo_o`001?oo003o0000oooooooo>`03onoo00;oo`001?o_o`001Ooo003okol0o`3oI?o_o`3o
o`0000Go000000?o<Ol0o`3oLol0og<00_l000001?l0oOoo0000o`3oLol00002okgo0003ool00?l0
oOoo08[o00;o0?n[00Koaol0o`3oHOo<o`3oGOl0o`0Voonmo`0?oc<0o`;o000000?o0?mTokgo0?lc
0?l00ol00002oc<0o`CocOl00onYo`04oc<0o`;o000000Oo<`3oo`000?lc0?oo<`3ooooR0?lc0?oo
Hol000Co<`3o00Go0000oc<0oolc0?oo9?l0o`000002oc<0o`;o000000CooaL0o`000?l0003ooooo
1?ono`001Om8o`3o<ol0od3o0?oooooo?_l000Kooooo1Oomo`07ooooo`;o0?o500?ooooooo_o0?ok
o`000_oko`05o`3of0Gooooo1?oWo`0>ooooo`03o`000?oooooooooo06Cooooo001mooooo`03ool0
0?ooooooo`0000?ok_l000?oooooool00?o^o`000_o^o`000onco`3oooooool00002ool00005onko
0?ooB@3ok_l0ool00?ooool00oo^o`000ooo003oooooool00002ool000?ok_l000?oo`00ooooooo^
o`000_o^o`001_oo003o0?m=ool00?ooooookol0o`2@o`;okol000?o0000ool00?o_o`000_o_o`00
1?ooooooof`0ool00?oo0003onoo00?oo`0000Koof`0onoo0?o_o`3okol0ool00?ooK002onoo0004
o`3oI?oo003oo`00onoo00;o<Ol00_l000000ol0oOooO?l0o`3oR002o`3oL`05o`000?mNo`3o0000
onoo0?l0oj/00_nmo`003?l0oOooo`00o`3oHOl0GOooGOl0olOo0?l0ogkoo`00o`000?o<o`3ooooo
okgo00?o000000?o00Woo`3mool;o`001Onbo`002?l0R_ooPol0o`3o/_l0ok;o0?l<o`3^ool0Dooo
00000_nfo`001_nmo`3o0000okgo0?oo^P3ooad0olWo00;oZOl00oo=o`02o`00000Golco0?o@o`3o
0000o`000?nmo`3o__l0o`3mooo<o`3o01coo`000?mSo`3o0;7oolgo0?l0/Ooo0000o`29oonmo`3o
ood0obCo0?l0L?oo07;ooolM0?l0ol400_l000001?oo7@3o0000o`000?l00002o`2Ao`Coo_l000Co
B?l0od3o0?l0J?oo?_l00oooool01?l0moooooooooooooooool5oogo00Wooooo00?o0?o5o`3of?l0
omP00ol0omP00ooko`3oooooooooo`08ooooo`Goiol00_ooool2o`0000gooooo00?o0000oooooooo
ool0BOooool2onko00?oo`000_o^o`02ool000;ooooo00Coo`00onko0?o^o`3ok_l00ooo00001_o^
o`3o/ol0ok?o0?ooB@3oooooo`3oZ`;oo`000oo^o`000oooooook_l0onko0002onko0003oooooooo
003oo`0000;ooooo0oo^o`000ooooooo093oonoo0002onoo0003o`3oCOooooooo`0000?okol000Co
of`0ool00?oo003oo`000oo_o`02ool00003oom/0?o_o`3o000000;okol000?oo`00oolk0?o_o`00
0_o_o`02ool000?okol000Co0?mToi7o0?nAo`3ooc/00ol00002oc7o000;o`29ool0oiSo_Ol0o`3o
Lomlo`3o05?oo`3mool0003oo`00o`000?l0oOl00_nmo`003ol0oOoo08[oo`2:ool0of7o0?n5o`3o
XOmMo`3o02Kookgo0?l0e?oo_Ol0o`_o0?o7o`3o_Ol0o`3mo`04ok;o0005o`3oR?l0ok;o00Wooh?o
0?l0GOl01ol00003okKo0004o`000?l0okKo0?nfo`3mo`;ocOl000Ko083oojWo0?nYo`3o0000oolM
0?nno`02o`00000:o`0Lool0/OoookX0olgo0?oohP3oHol0o`0Lool0GOooooooo`0000;oood000Go
07;oobCo0?l0ol7ooaL0oolM0005o`00000;ooko0?oooooooooooooooom8o`3ooooood3o0?lco`3o
?_l0o`3gooooool01Oomo`0:ooooo`Conol01Ol0omP5ooooo`Goiol04_ooool00ol0003ooooooooo
o`1Tooooo`00O_ooool2onko0003oooooooo003ok_l000;ok_l000?ooooook?o0?nco`000_oo0002
onko0003ool00?ooB@3ooooo00?ok_l000?oo`00oooooooo00000_oo0003onko0003ool00?oooooo
k_l000;ok_l00_oo0002o`3oC@;okol00_l0T?l00oooooooo`00o`000002onoo00;ooooo0_oo0003
onoo00?oo`001?o_o`000ooo003oooooonoo0002onoo0003ool00?l0ofCokol000;okol000?o<Ol0
oolk0?oo>`000_l000004omlo`3o08[oo`3oR?nmo`3okol0o`000?l0oOoo0?n[o`000?nmo`3o03?o
o`3oHOnmo`3o0?mQo`1Mool0R_ooGOl0o`3oXOl0ogh00_l0och3o`000004o`_o0?l0e?oo2ol0olOo
00;o0?go00Go0?mQokgo0?l0oj7o00Woo`0Vo`05ok;o0005o`1Cool0ok;o0?nQo`3oVOoo^P000_nf
o`000ol0e?oo_Ol0okgo0002okgo0004o`20oonYo`3oZOl0ojWo00;o000000Co07;oo`000?oo7@3o
027o0_l0Ool05?nno`3oc?l0olgo0?l07?ooHol0olco0?oo7@3o0000o`2aool0ROoo05gooolM0?l0
003o9?l0o`3oYol0L_oo073oo`3o`Ol0003ooad00ol00002ooko00?o097o00GoB?l0oooooom0o`3o
ooooocko0002oc?o00;ooOl000?o0?Oooogo0?omo`002_ooool5o`3of003ooooool0olGo0?o500So
oooo1OoWo`0Fooooo`03o`000?oooooooooo04[ooooo00?oo`00onko0?o^o`000_oo0002ooooo`Co
k_l00ooo0002onko00;o/ol000?ooooooom90?oo00001?o^o`001_l0aOook_l0onko0?o^o`3oo`00
ooooo`?oo`001?o^o`001_ooooookol0onoo0?l0T?ookol0ool000;o0?m=0oo_o`000ol0I_ooo`00
ool00004onoo00;oo`0000Ooooooonoo0?o_o`3okol0ool00?l0003o05oo00?okol000?oo`00onoo
0?o_o`000_o_o`001?oo003ooc/0o`3oI?oo>`03onoo000Boolk0?oooooo<Ol0o`000?l0oOoo08Wo
oomT0?nmo`3oO?l0o`1Cool0og?oG_l0o`000?l0oOoo0000o`3oHOl0oOoo0?m00_nmo`001ol0of7o
08[oo`3oQOo<o`3oGOl0o`3oLol09_l00_nmo`000ol;o`3o00Woo`09o`02o`3mo`03o`_o0?l0ohSo
00Wo00?o/_l01?l000002?n3o`3o05?oo`3o3?l0ob3o0?nQo`09oooo^P3o00000_nfo`03okgo0004
olko0?l0ROoo083oo`0000;oZOl000Go0000oolM0?o<o`3obol0oonj0002olco000>olgo0?mSo`3o
08Woo`2aool0GOoo0000o`1ooooo5`3oood0obCo0?l0ol7o0:ooo`3moooo7@03o`0000?o097o00Wo
ooooodSo0?oooooo@?l0oogo0?lno`3o<ol0oogo0?l0mol02_ooool5oo_o00Co0?oH0_ooool2o`3o
a@03oooooooWo`3oiol000?oiol05oooool00ol0003oooooooooo`1Tooooo`00P?ooool2onko00?o
oooo00Co/ol0ool00?oo003ok_l00ooo00001OooB@3ok_l0onko0?oo003o0?n[00;oo`001?o^o`00
0ooo003ok_l0onko0002onko0005oooooooo003oo`00ooooool0odd00_o_o`000ooo003o093oonoo
0003onoo0004o`000?ooooooo`00ool000?okol00ooo0003onoo00;oo`0000Coofd0onoo0?o_o`3o
kol00_oo00001oo_o`3o0?mTonoo0?oo003oofd0oc7o0?ooK@000oo_o`001?mlo`3o0?goo`2:ool0
ROl2o`00000<o`3oLol0003o0?goo`000?nmo`3o2ol0oolk0?l0of7o0?gookgo0?l0C?ooGOl01?l0
00001?o<o`3oofd0okgo0?l0ohD2o`_o000=olOo0?l0003o0000o`09ool0of7o00Woo`3oR?oMo`3o
0?n8o`2:ool0o`co0>kooh?o0005ok;o0004oonj0?o7o`3o]_l0okKo00;o0?nb00?o0?n8olWo0?l0
P?l00_l00002ojWo000=o`000?l0okKo0?n8olgo0?l08Ooo_Ol0okko0?l0oOooc?l0oonj0?mSo`3o
on80o`000002olgo0005o`29ool0oh[o05goo`000?lTo`000_ooo@001Ooo7@3o073oo`1`ool0003o
oad000;o00000_l0Sol2ooooo`09odSo0?l0TOoo@?l0o`2Aoolno`3ooOl0o`1Xooomo`3o<ol000;o
oooo00?o0?Ooooooooooool01?ooool5o`3of0Sooooo0_l0olD00oooooooiol0onOo0003onOo01_o
oooo00?o0000ooooooooool0Boooool00ooo003oooooooooo`03onko0004oooooooo003oo`00ool0
00;ok_l00_oo00001?nco`3oooooool00?ooB@02onko0003ooooooo^o`3ok_l000;ok_l000?oo`00
oooooooo00000_oo0003onko00;oo`000oo_o`02o`2@o`04ooooooo_o`3o0?m=onoo00;ooooo0_oo
0003onoo00?oo`001?o_o`02ool000;okol000?o0000onoo0?oo00000oo_o`02ool00004oooooooo
>`3ooc/0o`3oI0;okol00_oo>`02onoo0008oc7o0?l0003o0000o`000?l0ROooo`00ogco0?l0Dol2
o`0000;o0?mc01?o0000o`3mool0003o0?m0o`3mool0GOoo0?mQokgo0?ooK@3o08[oolco0?mMo`3o
0000o`0Vool0e?oo_Ol0oolM0?l;o`3o08[o00;o0?go0_l000001Ol0ohSo0000o`000?l0003o0>ko
00Go/_l000SookX0olOo0?l0oj7o00Woo`000?l0ok;obOl0o`1Qo`;o]_l000Go9?l0okgo0?nmo`3o
0000o`20o`02o`0000?oZOl000Woc?l0oonj0?l07?oo01coolco0?oohP3oHol0o`0Lool000000_l0
GOl01ol0ojOo0000obCo0?ooo@3o073oo`3moooo7@001?l000003?oooooooOl0o`2Aoom8o`3o@?l0
oogo0?lno`3o06Sooooooolco`3oooooo`3go`Cooooo1Ooko`05o`3of0Cooooo1?oWo`02o`3oaA_o
oooo00?o0000ooooooooool0I?ooool008;ooooo00Coo`00ok?o0?nco`3ok_l00ooo0002onko0005
oom90?oo003oo`00oooooooo00000oo^o`02ool000?ok_l00_ooool3ool00005onoo0?l0odgo0?m=
ool00?ooool00_l0T?l01_o_o`3oooooooooooooooooo`00o`0000?okol00ooo0003onoo00;oo`00
00Coooooonoo0?o_o`3okol00_oo0002onoo00;o0?mT00Co05oooooooooooooo<Ol00_o_o`001ooo
003oooooonoo0?mlo`3o0000o`2:ool0ROl00_l000002Ol0og?o0000o`09ool0oOoo0000o`0cool;
o`3o0?mQo`3mo`03o`00000:o`3oO_l0R_oo0?m0oomS0?o<o`3o0?lno`0Voonmo`3o2ol0o`3oH@?o
000000ooc?l0o`09ool0oj7o0?mQoh?o0?l0ohSo0?l<o`3^oon3o`3o05?oo`3moomVo`3o0?nQo`00
0?o<o`001?nbo`02okKo0004o`3oR?l0ok;obOl0o`20o`;o000000?o0?goojWo0?nYo`000ol0okH0
1Ol08Ooo_Ol0okko0?oo5`3ookX000?o000000Woc?l0o`29ooo=o`3o01coo`000?oohP3o9?l0o`3o
9Ol0L_l00_ooo@000ol0ol7o0000o`1`o`02o`0000;ooooo00Ko08ooodSo0?l0Sooo@?l0oogo0?ln
o`03o`2Ao`03o`1Xoooooooo<ol000;ooooo00?o0?Oooo_o0?l0omP00ol0omP:ooooo`Goiol00ol0
olDNooooo`03o`000?oooooooooo04cooooo0_o^o`001Oooooooo`00ool00?oo003ok_l000?oo`00
00?ooooook?o0?nco`000_o^o`000oooB@3oooooonko0002onko00;oo`0000Co0<Goool00?oo003o
o`000oo^o`02ool000?okol00_oo00000ol0T?ookol0onoo0002o`3oC@03oooooooo003oo`0000?o
kol00ooo0003onoo00?oo`000oo_o`02ool00003o`000?o_o`3okol000;oo`000oooK@000oo_o`3o
0?mTo`3oI002oolk00?okol00_lao`002?l0JOoo0000o`3mool0003o08Woogco0?l0Doooo`000_l0
00001?l0<ooo_Ol0o`000?l0og<2o`000004o`3mool0of7o0?goolOo00;o_Ol000[o08[ooego0?l0
oj7o02KooolM0?nmo`3o0?noo`_o0?l0R_oo0?mQ1?l000002Ol0oj7oPol0o`3^ool0ofCo05goo`3m
ool0Dooo0?l<olco0004ok;o00;o000000Co0?n8olWo0?o9o`3oc_l00_nfo`001?l0oOoo0000o`00
0?l0P?l2o`3o]P07okko0?l0OoooZOl0ojWo0?l09_ooaol0o`0Lo`03o`000007o`3oR_oohP3ooad0
o`1Mool0003o9?l0oolM0002ooom000;o`1`ool0003o0000oogo0?l0Sooo0000o`2?oom8o`3o@?l0
oooooolno`000_l0TOl01?l0J?oooooooc?o0?l0mol4oo_o00Go0?oH1?ooool5onOo00Kooooo0_l0
olDIooooo`03o`000?oooooooooo06Cooooo0021ooooo`03ool00?nco`3oo`0000;oo`000_o^o`02
ool00003oom90?ooooooo`0000?ok_l00_oo0003onko00;ooooo0ooo0003onoo0006o`3oCOoooooo
kol0onoo0?l0T?ooo`000_ooool01Ooo003okol0onoo0?o_o`3o000000;oo`001?o_o`02ool000Co
kol00_oo0003onoo0005ool00?l0ofCo05ooo`1Oooo_o`000_lao`000ol0oj;okol0onoo0002onoo
000=ogco0?oo003o0000o`000?l0ROoo?ol0o`3oLooooooo0?nHo`000?l0of7o0000o`3oL`03o`00
0006o`3moooo>`3o0000o`000?l0oj7o08[o1_l0of404ol;o`3o0000o`000?l0oOoo00Wookgo0?l0
2Ooo0?nQo`3oHOl0o`co0?mToh?o0?l0Dooo05goo`3mool0oiWo0000o`3oXOl0ob000_l000001?l0
2Oooaol0oonj0?nbo`02okKo0007obCo0?l0003o083ooolM0?l0oj7o0?goo`3o/P02ojWo0006o`3o
/_l0okKo0?nfo`3o]_oo^P3o07oo0_l000004OoohP3o01coo`29oonmo`3o01coo`000?oohP3o9?l0
o`1Mool0ojOo07;oo`09ool0003o0?o1o`000?l0L?oo05Ko00;ooOl000KoB?l0oooooom0o`3o08oo
ocko0?l0Sol3ooooo`;o097o1Ol0omP9ooooo`Goiol02?ooool2o`3oaAcooooo00?o0000oooooooo
ool0C_ooool00ooo003ok_l0ool00002ool000;ooooo00Kok_l0ok?o0?o^o`3oooooo`3oSOooB@02
onko00;oo`0000?o0?o6ool00?oo00001?o^o`02ool000?okol00_oo00001oo_o`3o093oo`2@oooo
003oooooo`3oCOoo00001?o_o`03ool000?okol00_oo00001?o6o`3okol0onoo0?o_o`02ool000?o
kol000?o0000ool00?ooool00_ooool3onoo0003o`3oI?o_o`3okol000;okol000?ooooooolk0?la
o`000ooo0002o`00000Ao`29ool0003oO?l0okgo0?l0oiSo?ol0o`3oLol0<ooo_Ol0o`000?l;o`3o
0000o`3mool0of7o0?goo`3oHOo7o`000_oo0002o`000003o`2:ool0of7o0?mQ00;o0?mQ1Ol00002
o`09o`0=o`3oXOl0k_oo08[oo`3oI?l0GOooPol0o`3o3?o<o`3ooad0o`09oooo^P3o0?nQo`09o`05
ok;o0003obCo0?l09_oo02Ko00?o]_l000?obol0o`20ool0P?l00ol0okH01?o<o`3oZOl0ojWo0?l0
h_l3o`000006o`0LoooohP3o0?o]o`000?l0GOoo9?l00_l02Ol01?l0ol7o0000o`1`ool00002oooo
o`06o`000?m8o`3o@?l0o`2?oolno`3ooooo0_oko`03o`2Ao`03oc?o0?l0omSo0?oH00;o0?oH1?oo
ool5onOo00gooooo0_l0olDHooooo`03o`000?oooooooooo06?ooooo0020ooooo`;o/ol00ol00_l3
ool00003ooooooooB@3ok_l000;ok_l000?oo`00onko0?o^o`000_o^o`02ooooo`?oo`000oo_o`00
0ooo003o0?m=o`3oC@02onoo0004ool00?l0T?ooooooool000?okol000Coooooool00?oo003o0000
0_o_o`03ool000?okol00ooo0003onoo0004ool00?o6o`3oa_l0o`3oI0?okol000Co<Ol0onoo0?o_
o`3okol00_ooK@001?oo003oO?l0ool00?o_o`02o`000005ocoo0?nmo`3o0?mcool00?l02Ol01?l0
00000oo_o`3o0?mco`3oL`02o`3oH@;o00000_l0of42o`2:o`04o`3o@?l09_oo_Ol0o`3oQ@;o2ol0
01Woaol0o`09ool0oOoo_Ol0olco0?l0oj7o0?l<o`3oI?l0of7o05?oo`2:ool0GOoo0?goo`000?l0
0Ooo0?nQolco0?m8o`3ookX0o`0;ool02OoookX0o`3o0?l09_ooc_l000;o]_l000Oo08Woo`20oonb
o`3o/_l0o`3moonbo`3obol000;oZOl00_l0ok82o`3o]P0=o`000?mSo`3ooad0oooR0?l0ROoo01co
o`000?l07?oo00WoobCo0?l0Oooo00Woo`1bo`05o`0000;o09Co00GoB?l0oooooom0o`3oooooocko
0002oo_o00Go0?oH00Goooooo`2Aool0TOoo097oo`3go`04ooooo`Goiol03oooool2o`3oaA_ooooo
00?o0000ooooooooool0COooool3o`02o`03ooooooo^o`3ok_l000;o/ol00oo^o`001?ooB@3oo`00
ool00?l0oj/2ool000?ok_l00ooo0002onoo00?oo`000oo_o`000ol0T?ooooooooooo`02o`3oC@;o
kol000?o06Koool00?oo00001?o_o`02ool00004ooooooo_o`3okol0onoo00;oo`000oo_o`02ool0
0003olKo0?l0003okol000?okol000Coa_l0onoo0?l0ofCokol01?ooK@001?oo003o<Ol0ool00?l0
JOl2ool000?o000000goO?l0o`000?nmo`3o?ol0o`09ool0og?o0?nHokgo0?l0C?oo0000o`2:ool0
003o0?go00;o0?mc0ol0of42o`000003o`3oHOl0R_oo000000;o000001coaol0o`_o0?l0oOoo2ol0
o`09ool0oOoo0?o1o`09ool0oj7o0?mTo`2:oon3o`3o0?l<ofOo0?o<o`3ohol0on7o0?l0003o0?nQ
o`09ooo7o`3ookX0o`3oR?o>o`3o067oobCo0?nbo`3o00000_nbo`001Ol0oOoo]_l0okKo0?nmo`3o
083o00;o0?nb0ol0okH3ojWo0009oooR0?l07?oo0?n:o`09ool0003o00WoobCo0?l0L_oooad000;o
000000Woood0o`2Dool0U?ooooooodSo0?l0003o@?l0ocko0?oko`000_l0Sol5o`3of0;o097o00?o
ooooonOo0?oWo`000ooWo`0Dooooo`;o0?o55_ooool00ol0003oooooooooo`1Sooooo`00O_ooool2
ok?o00?ooooo0_l06ol3o`02o`03oom90?l00_ooo`0000?ok_l00_ooool01?l0olKoooooool00?oo
0002onoo00?oo`0000Gokol0o`3oCOoo003oo`00ooooo`02o`2@o`?okol000?oooooool00?oo0000
0oo_o`000ol0003oo`00ool00003onoo00?oo`000_o_o`02ool000?ooooo00Ookol0o`3oI?o_o`3o
ooooonoo0?lao`3okol000;ooooo0ooo00001_mlo`3oa_l0o`1Yoooo003o0000ocoo00Oo000000?o
0?mQo`000?l0of400_l0of406ol0og?o0?goo`000?mMo`3o0?mQo`3oXOooooooc?l0o`2:ool09_oo
_Ol0o`3oQOl0oOoo2ol0olOo0?l02Ooo0?goo`@0oon3o`3o0?l<o`3oI?l02Ooo05?oo`3oHOl0R_oo
05goo`000002o`3o8008o`3oXOl00Ooo007oon?o0?oo^P3o00Wooonj0?o7o`02o`000008obCo0?oo
5`3o]_l0okKo0?l0P?oo0?nQo`3oR?l0oOl3ok;o00;oZOl000?o/_l0o`0Qool000000_l000002_oo
hP3o0000o`09ool0003o00Woo`000?lTo`3o07oooolM0?l0of44o`000005omGo0?l0003oB?l0o`1F
oom0o`001Ol0omP3ooooo`?o08oo0_ooool01?lco`3o097oo`3gool0TOl2onOo01Kooooo0_l0olDI
ooooo`03o`000?oooooooooo04oooooo00Cok_l0o`02ool00_oo/ol00_l00_l2ool00003oom90?oo
ooooo`0000Cok_l00ooo0002onoo00?oo`000_o_o`02ool000;o093o00Coo`00onoo0?l0odgokol0
0ooo0003onoo00?oo`001?o_o`02ool000;okol00_oo0003ooooo`;okol000?o0000ooooooooool0
0oo_o`000ol0ofCoa_l0olKo0004ool00005oc7o0?oo003oo`00ool00?o_o`000_oo00001ol0003o
O?l0o`3mool0003o?ol0o`000?l0og<00_oo00001Onmo`3o0?nHo`000?l0of7o000000?o0?mQ0_l0
og<00oooI03o_Ol0o`000002o`00000Lo`2:ool;o`3o_Ol0okgo0?l;o`3o0?goo`_o0?l0ongocOl0
o`3mool0003o0?mTo`09ool0of7o0?l<o`3oVOl00Oooc?l0on7o0?l0003o00Woo`3oXOl02Ooo00[o
oonj0?o>o`3ooad0o`1Qo`;o000000KobOl0o`0Vool=0?oo08[oo`3moonbo`02okKo0003o`20oonb
o`3o0?mQ00;o07oo00?o0?nfo`000?l000000_nYo`001ol02Ooo0000o`2:ool0003o9?l0o`1bool0
GOl00ol000001_oko`3oeOl0odSo0?l0U?oo@?l0o`0000Co0?oH00Coooooo`2?ool0Sooo08oo0_oW
o`000ol0mooo097oo`2Ao`02o`2AoaSooooo0ol0olDCooooo`03o`000?oooooooooo06?ooooo001m
ooooo`03ok?o0?oooooooooo00Gooooo00?ok_l0o`0KooooB@000_l06ol4o`02o`05oooooooo003o
o`00ool00?o_o`000ooo0002onoo00;o0?m=0_ooool01_oo003o093oonoo0?o_o`3oooooool000Co
kol00ooo00000ol0003okol0onoo0003ool000;okol00_oo0002ooooo`Cokol000Ko0?mTonoo0?o_
o`3okol0oc7o0?l0oj83ool000?ooooo00CoO?l0ool00?oo003okol01Ol00003o`3oH@07o`000?l0
ROoo0000o`1Mool0oOoo0?nHool00002o`000003oego0?l0of7oo`0000;o000000Ookol0o`2:oooo
oooo_Ol0o`_o0?l0oOoo00Wo00;o103o00Ko0?goo`3o3?l0ofCo0?nQo`1Cool0of42o`09o`05o`00
0?l0oOoo0?mQo`3oHOl0oj400ol0of402_oo^P3o0?mQo`000?l0003oaol0obCo0?l0of7o067oo`29
ool0of43okKo0006o`3oHOl0oOoo0?mQo`3oHOo;o`3ookX00onYo`02o`00000<ok;o0?oohP3o0000
o`3o]_l0ok;o0000obCo0?l0ok;o07ooo`000?l0L_oooad00_l00005o`3of003ocko0?oooooo09Co
00;o09Co1?ooool2onOo00?o08oo00?o<ol0o`3gooooool00ol0TOlGooooo`;o0?o55oooool00ol0
003oooooooooo`1?ooooo`03o`0Koonco`3o/ol000?oo`0000Ko00;ooom90?l00_oo00;oonko0?oo
ool3ool000;okol00ooo0002onoo00;oo`000_ooool00ol0T?ookol0onoo0002o`3oC@03ool00?o_
o`3okol000;okol00ooo0003onoo00?oo`000_o_o`02ool000?ooooo0oo_o`02ooooo`03o`000?o_
o`3okol000;ooooo00Ko0?mTool00?oo003oo`00onoo0?ooool2oc7o0003ool00?o_o`3oo`0000;o
o`0000Ookol0olKo0?mlo`3o0000o`3moooo003o?ol000?o00001?l0of401?l0003o05goo`000?l;
o`02o`3mo`?o000000CoGOl0o`3o@?l0003o00000_l0R_l03Onmo`3oaol0o`_o0?o<o`3o0?mQo`3^
ool0oOoo0?mTo`3oXOl02Ooo0?l<o`3oHOl0oOl00_l0of401ol0003o0?mQo`3oHOl0oj7ookX0o`09
oooo^P000_o7o`002ol0003o0?mQo`3oHOl0of7o08Woo`0Vool0of7o08Woo`3mool0of7obol000;o
]_l00onbo`001Ol0003o/_l0o`000?l0003oon8000;oZOl000Co0?nbo`000?lTo`3o0?nb1?l00005
o`3of003o`2Dool0003o09Co00Goiol000Koooooo`2?ool0Sooo08ooo`3goolco`02ooooo`?o097o
6?ooool2o`3oaA7ooooo00?o0000ooooooooool0Hoooool007_ooooo0_nco`08ooooo`06o`0Ioooo
B@3o01Woooooool0ohgooooo0ol06ol4o`02o`03ool00?o_o`3okol000;oo`0000Co0?m=ooooooo_
o`3okol00_l0T?l00oooooooo`00onoo0002onoo00?oo`0000Goooooonoo0?o_o`3okol0o`000002
ool000;okol00_oo0002ooooo`?okol000Koo`00ooooooo_o`3o0?mTonoo0?ooool2oc7o00;oo`00
0oooool2ool00003ogco0?o_o`3ooooo00?o000000?okol0o`000?ooool01Ol000001_l0of7o05go
o`000?l0of7o0?goo`3oV0?o000002Ko04coo`3oHOl0003o0000o`_o0?l0of7o08[ookgo0?l;o`3o
0?goolOo0?nmo`3oPol0o`3o3?l0ofCoc?l0o`3oXOl0Dooo05Woolco0?l0003o00Woo`3mool0ojOo
02Koo`3oXOo<o`3o0?l0o`3Doonno`3o0000olko0?oo^P3o007oobCo0?l0R_oo067oo`29o`;ooad0
00Go02Koo`20oonfo`3o]_l0o`3mo`02o`2:o`04ol_o0?l0003o00Wookko00;oZOl000Co08Woo`1o
oooohP3o00000onbo`001Ol0R_oo07ooo`000?l0ok;o07;o00;o000000GoooooodSo0?m0o`3ooooo
ocko0002o`1Fo`03oooooooWo`3oiol000?o09Co00Coiol0oooooooooooo06So0_ooool3o`2?o`?o
oooo0ol0TOlFooooo`;o0?o55Oooool00ol0003oooooooooo`1>ooooo`;o/ol000?oooooo`0Iool0
6ol00_l06ol01?ooB@3o01_ooooooooo0005o`02o`;oo`0000Cokol0ool00?oo003oo`000_ooool2
onoo0004o`2@ooooooooo`00o`3oC@?okol00ooo00001?ooooookol0onoo0?o_o`03ool000;okol0
0_oo0003ooooo`?okol000?oooooonoo0?o_o`000_o_o`001ol0003oooooool00?oo003o0?mTool0
0?ooool00ooo00000olao`3okol0ool00002ool0000<onoo0?ooooooooooool00?mlo`3o04Coo`00
0?l0R_oo?ol0okgo0?l0003o0?mQ1?l000000ol0of7o0000o`1Mo`08o`00000@o`3oQOl0003o0000
o`@0oonno`3o08[oo`09ool;o`3oc?l0o`3^oon3o`3o0?mTo`3o8?l0oj7o0?l<o`3oV@;o00Wo017o
hOl0o`000?l0e?oo00_ookko0?l0oj7ookX0olko0?oo^P3o0?n8o`000?lTo`3ocOl0o`3oR?l0GOoo
08Woo`0Vo`02oolM0005o`3oXOl0oOoookX0ol_o0?l02Ol00onfo`000ol0003o07ooof?o0002ok;o
0006oooR0?l0003oZOl0ojWo0?lTo`3o0?nW0ol000002Ol0omSoB?l0oooooom0o`3o?_l0o`1FoooW
o`3o0000onOo0003o`2Do`Cooooo00?o06Soooooool0Sol00_l0Sol4ooooo`?o097o5oooool2o`3o
a@oooooo00?o0000ooooooooool0Hoooool007[ooooo00?o/ol0ooooooooool02?ooool00oooB@3o
ooooooooo`05o`0Io`;oo`000ol06ol3o`02o`;o0?m=0_o_o`000ooooooo093oool00003onoo00?o
o`0000Coooooonoo0?o_o`3okol00ooo00001?l0003okol0ool00?oo0002ooooo`?okol000?oo`00
ooooooo_o`000_o_o`001Ol0ofCoo`00ool00?lao`3oo`0000;ooooo1?oo00000oo_o`3oO?l0o`00
0002o`000004onoo0?loo`3o04Coool000?o000000So0?goo`000?l0003o0?goo`000?l0GOoo0000
o`3oH@;o000001Wo0?goo`000?l0003o_Ol0o`1<ool0oj7oc?l0o`_o0?l0ogko02Koo`_o0?l0R_oo
0?goo`_o0?o7o`3o0?l<o`3oI?o<o`3o0?lno`1Cool0ohSo0?o]o`3o8?l0003o05go00;o00Wo00Co
Iol0o`3oXOl0o`3oaol00_l000001Oo>o`3ooad0oonj0?o<o`3o9?l000;oaol000Oo08Wookco0?o=
o`3o02Koo`20ooo9o`3o0?nQ00;o]_l000OookX0o`000?o;o`3o_Ol0okko0?mSo`3o027o00;oZOl0
00Soon80o`1oool0003o9?l0olco0?nbo`3o0000ok;o00?o000000Go:03oodSo0?lX0?oo@?l0ocko
0003obP0o`03o`1FoolX0?oooooo00?ooooo0ol0U?l00ooooooo06Soooooo`02ooooo`04oc?o0?l0
Sooo08ooo`2?o`?ooooo0ol0TOlEooooo`;o0?o54oooool00ol0003oooooooooo`1=ooooo`03ok?o
0?oooooooooo00;ooooo00?ok_l0oom90?ooB@000_l06Ol5o`0Ko`03ool00?o_o`3o00;o00?o00;o
00Coooooonoo0?o_o`3okol00_l0T?l01?o_o`3o0?m=o`3oCOo_o`03ool000Cokol00ooo0002onoo
00;oo`000_ooool4onoo0004ooooooo_o`3okol0onoo00?ooooo00Goo`00o`000?oo003okol0o`3o
I003ool000;okol000Co<Ol0ool00?oo003okol00_ooool3ool0000:onoo0?mlo`3o04Coool00?lo
o`3o08[ookgo0?l0ohSo0000o`3oL`Ko000000?o08[oo`000?l0oiP00_l000007Onko`3o0000o`00
0?l40?oo2ol0o`3oXOl0od3o0?gookgo0?l;o`3o0?goo`_o0?n3o`3o0?mTo`3moooo7@3o05?oo`3o
3?l0oiWo05goo`3mool0003o0?mQoolH0?oMo`3o__l0o`3oXOo>o`3o00Wo00;o0000017ooad0obCo
0?o7o`3o0?n8ol_o0?l0ROoooad0o`0Vool0e?oo08Woo`09ool0oOoo00Wool_o0?l0L_oo083oo`00
0002okKo0007of?o0?l0Ooooon80oooR0?l0R_oo01coobCo0003ojWo00;o000000WoB?l0obP0oom0
o`3o?_l0obP0oooEo`3o05Koooooool000000oooool3o`2Do`06ooooool0J?ooooooooooool0mooo
oooo0ol0Sol4ooooo`?o097o5_ooool2o`3oa@gooooo00?o0000ooooooooool0Hoooool007Sooooo
0_nco`0:ooooo`06oom90?oooooooooooooooooo003okol00ooo0005o`0Io`03ooooooo_o`3o0?m=
00;o01_o1?l00_l01?o_o`3oo`00ool00?oo0004onoo00?oo`000_o_o`001?oo003o0000oooooooo
ool3onoo0003ool00?ooooookol000;okol000Ooooooool00?l0ofCoo`00onoo0?lao`3ooooo00?o
o`000_o_o`04o`000006onoo0?ooooooooooocoo0?oo003o04Co0_o_o`002Ol0003o_Ol0o`000?l0
ohSo0?mQool00?l0003o0?gookgo0003o`00000Ro`3mool0R_oo08Woo`3mool0oiSo0?nQo`_o0?l0
C?oo103oo`0Vool;o`3o_Ol0o`2:ool;o`3o0?l<o`3^ool0ofCo0?goo`1Cool0oj7o0?n8o`3o8?l0
003o0?o1o`1Mool0oOoo08[oo`09ool0oj7oc?l0o`000?nno`3oc_l0o`0Vo`;ookX000Go9?l0oolM
0?oo7@3o067oo`29o`02o`01o`06oolM0?l09_oo083oolWo0?l0oj7ooad00_nfo`001ol0R_oobol0
okgo0?mSo`3o08Woo`0Qool000000_nYo`001?lTo`3o0000o`0Looo<o`02o`0000;o0?nf00Oo07;o
odSo0?l0okCo@?l0onOo0?lno`3oeOl000?ooooo00?o05KoobP0oolX0?l01OlX0?l3o`2Do`?o:03o
00?o0?Oooc?o0?lX0?l00ol0Sol3obP0o`?o097o5?ooool3o`3oaA3ooooo00?o0000ooooooooool0
Boooool2ok?o00Gooooo00GoodT0oooooooo003okol0o`3oZ`03ool000;o01Wo1Ol06ol00oo_o`3o
00;oo`02o`03o`02o`03onoo0?l0odgoo`0000;oo`000oo_o`03ool000;okol00ooo0002ooooo`?o
kol00_ooool3onoo00?ooooo0ooo00001_oooooo0000o`3oI?l0ofCoo`00onoo00;oo`000_lao`00
0oo_o`3oooooool00003ool0000;onoo0?oo003oo`00ogco0?l0A?ookol0ocoo0?l0003oo`00okgo
0?l0of401Ol000001_l0of7o05goo`000?l0R_oo0000ok_o00;o000000[o0?goo`3oV?l0C?oo2ol0
o`3oXOoKo`3o0?noo`09oonmo`3o2ol00_l0R_l02_l0ocko0?mToolM0?l0Dooo0?l<o`3oXOl02Ooo
05goo`000?l0R_l2o`09o`0Jokko0?oo7@3o0?nQo`0:ool0003o0?n8oonj0?lTo`3o007oo`1Qooo7
o`3ooad0o`29ool0e?oo00Woo`0Vool02Ooo08Wooonj0?l0oOoo_Ol0ol_o0?l0003o083oo`29ool0
8Ol2okKo0006o`1oool0003o0000obCo0?l0oh[o01co0_l00002ojWo0003o`3o]?m0o`3o?_l000;o
oooo00Go:03oomGo0?l0E_oo05Koo`000005obP0o`?o09Co0_lX0?l01?l0mooo:03ooc?o0?lX0?l3
o`2?o`;o:03o0_ooool3o`2AoaGooooo0_l0olD;ooooo`03o`000?oooooooooo06?ooooo001goooo
o`03ok?o0?oooooooooo00Wooooo00?oodT0ooooooooool00oooool00ooo003okol0ool00002ool0
0004ooooool0aOookol0onoo00;o0?m=0ol06Ol01?l0T?oo01_oo`0Kool06ol5o`02o`?oo`000_o_
o`02ool00003ool_0?oooooo000000;okol000?oo`00ooooooo_o`000_o_o`000oooooooo`00ool0
0002o`3oI003oooooolao`3o<Ol000;oo`000_o_o`03o`000003onoo0?mlo`3ooooo00?oo`0000?o
?ol0onoo0?l0A?l00ooo0004o`000007o`3oR?l0of7o05goo`000?nmo`3o0000ool00002o`3mo`0Q
o`2:oonko`3o08Woo`3mool0oj7o2ol0o`3oV?l0C?oo2ol0o`3oLonmo`3o0?goo`2:ool;o`3o0?mT
okgo0?l0DoooPol0olco0?l0oj7o0000o`3oVOl0okoo05goo`3mool0R_ooIol0o`3oXOl0003o02Ko
olko0?l09_ood?l000;ookX000Ko9?l0olco0?o=o`3oc_l0o`29ooo7o`02o`09o`07o`0Vool00Ooo
083oolWo0?oo^P3o0000o`3mo`02okKo0004ol_o0?mSo`3o08Woo`1bo`?o00000_nYo`02o`000003
olco0?l0oj7o07oo00;o000000Cooooood3o0?l0003o?_l00_l0ok@01OoEo`3o0?ndo`3o]?l0okCo
05Ko00Wooooo0ol0U?l00ooooooo0?Oooc?o0003ooooo`?o08oo0oooool3o`2Ao`Wo:03o2oooool2
o`3oa@kooooo00?o0000ooooooooool0B_ooool00onco`3oooooooooo`04ooooo`04oom90?oooooo
ooooooooo`;oo`0000Goooooool00?oo003oo`00ooooo`03onoo00;o01Wo1?l06ol00ooo003o0?m=
o`3oC@04o`02o`?oo`000_o_o`03ool000;ooooo0oo_o`02ooooo`?okol00_ooool4ool00006oooo
oooo003oo`00ool00?l0ofCokol00ooo00000oo_o`3o<Ol0ooooo`03ool000;okol00ooo00001_o_
o`3oO?l0ool00?l0A?ooo`00ocoo00Oo000000co0?gookgo0?l0GOooo`00o`000?o7o`3o^ol0o`00
0?l40?oo0?goo`@0ool0oOl2o`3oV009o`3oXOl0ogko00Wookko0?l;o`3o_Ol0o`3mool;o`3o08[o
00;o0?ln00ko0?l<o`3oR?l0oj7o00Woo`000?l0oOoo08[oolco0?l0ohSo00Woolko0?l0oj7o0000
o`09o`;ookX0017o9?l0olgo0?l0HOoo00WoolOo0?l0ROoo00WooolM0?l09_oobOl0oonj0?l0oj7o
2ol0o`3mool0R_oo0000ol_o0002o`20o`03of?o0?oohP3o]_l000;o]_l000Co01coolco0?l0003o
07oo0_l000001?ooooooZOl0ojWo0?ooool4o`3o]004omGo0?l0okCo05Koo`0000Oooooo0ol0U?l0
0ol0mooooooooc?o0003ooooo`?o08oo1?lX0?l3o`2Ao`Co:03o4?ooool2o`3oa@[ooooo00?o0000
ooooooooool0H_ooool007Gooooo0_nco`0;ooooo`03oom90?oooooooooo00Gooooo00?oo`00oooo
ooooool00oo_o`02o`3oC@?okol000?oooooo`2@ool06Ol01?l06Ol01?oooooo01_oo`0Kool06ol4
o`02o`;ooooo0oo_o`000ol0003okol0onoo0002onoo0006oooooooo003oo`00ool00?o_o`3o0?mT
0_oo00001?lao`3oo`00onoo0?o_o`03o`0000;okol000Coooooool00?mlo`3oo`000oo_o`000olo
o`3oo`00o`14o`02onoo0003ool00?l0003o000000;o000000go00Woo`1Mool0of7o0000ok_o0?l0
of7o0000o`3moonko`3ok_l0o`2:ool40?oo0?nQ00;o2ol000Oo08Woo`09ool;o`3o04cookgo0?l0
o`co0>ko00;o08[o00Ko05?oo`3mool0od3o0?m0o`000?l0oiT2o`3o?PCo05go00?o0?nQo`1Mool0
GOl00ol0GOl2o`00000AobCo0?l02Ooo00Woo`09ool0ROooC?l0olOo0?m<o`3o2ol0o`0Vool;o`3o
083oo`000?l0h_ooc?l0o`3moom<o`000_nfo`001oo;o`3o0000o`1boolTo`3o027ooooR0?l0R_l0
0_nYo`002?m<o`3oc?l0o`000?l0003ooooood3o0?oooooo?_l01?ooool2omGo00;ooooo00?o05Ko
o`3o]?l0ok@01Ol0ok@01?oooooo06Soooooooooool3o`2Do`03oc?o0?oooooooooo00?ooooo0ol0
Sol3ooooo`?o097o1?ooool2o`0000gooooo0_l0olD00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo04Sooooo0_nco`06ooooo`03oom90?oooooooooo00?ooooo0_oo00001_ooooookol0onoo
0?o_o`3oo`00ooooo`Cokol000Co093oool00?l06Ooo0?m=1?l06ol2ool000Co00;o00?oo`00ool_
0?oo;`000oo_o`000oooooookol0onoo0002onoo00;ooooo0ooo00000oo_o`3oooooool00002ool0
00;okol000?o0?mTo`000?o_o`000_o_o`001Ooo003o<Ol0ool00?oo003okol000Coo`0000Sokol0
ool00?oo003oO?l0ool00?l0A?ookol0ocoo00Go00000_l02Ol01?l0003oo`00okgo0?l0GOl2ok_o
000Po`000?l0R_oo0000o`3moooo^P3o0?mQo`3mool;o`3o08Woo`3oXOl0oiSo00Woo`1<ool;o`3o
_Ol0o`3mool0ofCo2ol0o`2:ool0o`co0?goo`3oR?l0oj7o0000o`1Mool0oOoo0?noo`2:ool09_oo
c_l0o`1Mool0oj46o`1Mo`04o`1Qoom<o`3oC?l0o`29o`;o2ol0013oC?l0o`0Vooo9o`3oC?l0o`3o
XOo<o`3o0000o`2:oonno`3obol0o`1bool0P?oo027oo`000?lTo`3o07oo0_nfo`001ol0003o07oo
o`000?oooooo@?l0ocko0?ooool00onYo`03ooooo`03omGo0?oooooo000000Ko0?nd0_ooool00ol0
J?ooooooo`2Do`02o`2Do`03oc?o0?oooooooooo00?ooooo0ol0Sol4ooooo`?o097o00?o0000oooo
ooooool04?ooool00ol0olGo0000ooooo`07ooooo`03o`000?oooooooooo06;ooooo001cooooo`;o
/ol03?ooool00oooB@3oooooooooo`07ooooo`;okol00_ooool01Ol0odgokol0onoo0?ooooooo`00
00;o093o0oo_o`000oooooooo`00ool00005o`0Io`?o01_o1?l00_l01?l0003okol0ooooooooool3
ool00008onoo0?oo;`3oo`00o`3oI?oo003okol0oc7o0?o_o`03o`0000;okol01?oo00000omlo`3o
kol0ool00002ool00003ocoo0?o_o`3o04Co00?oo`000_o_o`02o`000003ool00?l0003o00Wo00;o
00Wo00Oo0000ok_o0?l0003o0?goool00?l0003o08[o00Go05go00?o2ol0o`1Mool0GOl01?l0GOl2
o`2:o`So05go0_l000001?m<o`3o0?nQolko0?l0of43o`09o`Co0000017ooad0odco0?l0HOoo08Wo
o`_o0?o7o`3ooad0olco0?l09_oo0000o`20ooo9o`3oc?l0o`01ool0oOooon80of?o0002okKo0007
o`3oYolTo`3o07;oo`0Qool0R_oo0000o`0Lo`03ojWo0005o`1ooom0o`3o0?oHocko0?l000001_oo
ool00ooEo`3oooooooooo`02o`1Fo`Gooooo0_l0ok@01Ol0J?oo0?ndo`3o]?l0okCo0?Oo00?o09Co
1_ooool3o`2?o`?ooooo0ol0TOlAooooo`03o`000?l0olGooooo00[ooooo00?o0000ooooooooool0
A_ooool2ok?o00Oooooo00?oodT0ooooooooool01Oooool2onoo0003ool00?ooooookol000;okol0
00Goooooool00?oo003o093oonoo0002o`3oC@05onoo0?oo003oo`00ool00?l06Ol01Ol06ol00ooo
oooo00;oo`02o`03o`02o`;okol00_oo;`04ool00003oooooooo003oo`0000;oo`000_o_o`02ool0
0003o`3oI?o_o`3o000000?oo`0000?o<Ol0onoo0?oo00000_oo00000ol0JOookol0ool00002ool0
00;okol000?oO?l0ooooool000000_l000000ooo003okol0o`000002o`000004o`3mool0ohSo00Wo
o`0000?o00Wo0_l000003ol0R_ooo`00o`000?oooooo0?mQo`_o0?l0oOoo2ol0o`3oXOl02Ooo0?go
o`_o0?l0oiSo_Ol0o`3mo`03o`1Mo`03o`2:ool0GOoo05go00So05go00Ko0?n8o`3oHOl0oj7o02Ko
o`09oooo^P02o`000005oonj0?l0003o0000o`29ooo7o`000_l0ol404Ol09_oo007oolWo0?o9o`3o
0000o`3Rool0oOoo08Wookko0?o;o`3oHol0o`20oolTo`3o08[oo`1booo<o`3o000000;o]_l000?o
0000od3o0?lno`001Oooool2ojWo00;ooooo00?oeOl0ooooool000001Oooool2o`3o]005o`1Xool0
okCo0?ndo`3gool0ok@00ol0U?l6ooooo`?o08oo1?ooool4o`2Ao`oooooo0_l00008ooooo`03o`00
0?oooooooooo06;ooooo001booooo`03ok?o0?oooooooooo00_ooooo00?oodT0ooooooooool02_oo
ool2o`3oC@05oooooooo003oo`00ool00?l0T?l00_o_o`001Oooooooo`00ool00?oo003okol000?o
o`0000?oooooonoo0?o_o`001Ol06Ol2o`0Ko`03o`000?l00_oo00;o00;o00;o00Koooooool00?oo
003oo`00o`3oI?o_o`04o`0000;okol00ooo00001?ooooookol0onoo0?mlo`02ool000;okol000Co
?ol0ool00?oo003o04Co0_o_o`04ool000Co00000_l0GOl01?l0003o05goo`3mool00003o`1Mo`0K
o`2:ool0oj7oc?l0o`3mooo2o`3o2ol0o`0Vool0o`co0>kookgo0?l0oiSoaol0o`_o0?o<o`3o08[o
o`000?nmo`3o0?n8o`3oXOl0od3oI_l0o`000?l0R_oo0?gooolM0?l0oj7o0?n:00;ookX000Co0?mQ
o`09oooo^P3o9?l00_l000001?l02Ooo2ol0o`1Qool0ROl2o`3o_`03olOo0?o<o`3o02Ko00;o0000
00So083oolWo0?oohP3o007oo`3moomSo`3o_Ol0o`0000;o]_l000Koc?l0o`1bool08Ooo0000o`3o
R_l07?l2o`0000;oZOl000?o?_l0o`3of?l0omP01oooool01OoEo`3ooooooooooooooooo05Ko00Oo
oooo00Oo06Soooooooooooooooooo`3gool0okCo<ol000?o09Co0ol0ok@3ooooo`?o08oo0oooool3
o`2Aoa_ooooo00?o0000ooooooooool0AOooool00onco`3oooooooooo`06ooooo`03oom90?oooooo
oooo00Sooooo0_o_o`001?ooooooo`00ool00?oo0002o`2@o`03onoo0?l0odgoo`0000;oo`0000?o
kol0oooooooo00000_oo00001?ooooookol0onoo0?l06Ol5o`0Ko`03ooooool00_oo00;o00;o00;o
00?okol0oooooooo00000_oo0002onoo00?oo`000_o_o`001Ol0ofCoo`00ool00?l0003okol000;o
<Ol00_oo00000oooooooo`00o`1Yo`02ool000?okol000Koooooo`000?l0003o0000ocoo0?o_o`03
ool00005onko0?l0003oo`00o`3moomEo`000ol000001ol0of7o`_l0o`09ooo7o`3o0000o`3mool0
00001Ol0GOl01?l0oj7o05goo`1Mool;o`03o`1Mo`04o`1<ool0o`co2ol0oh?o00;o08[o00_o0000
o`3oXOl0GOoo0?n:o`3mool0003o08[ooooR0?l02Ooo0?n8o`3oX@02o`09o`04obCo0?oo^P3o0?no
o`3o_`;o000000Oo08Wookgo0?o7o`3ocOl0oonj0?l09_oo08Wo00;o000000Wo0>;oo`29ool0oOoo
__l0o`29oomSo`3o0000o`20ool08Ol00_l0ohX3o`0000;o]_l000?o0?oHooooooooool01Oooool2
ojWo0004oooooooEo`3oooooo`0000Oooooo00Oo06Sooooooooooooo0?Ooooooool0okCo<ol000?o
09Co0_l0ok@4ooooo`?o08oo1Oooool3o`2AoaKooooo00?o0000ooooooooool0H_ooool0073ooooo
0_nco`0=ooooo`03oom90?oooooooooo00[ooooo00Co0?m=oooooooo003oo`000_o_o`000ol0T?oo
ooooool00002ool00005onoo0?oo003oo`00ool00?ooool00oo_o`000ooo003oooooonoo0002onoo
0006oooooooo003o01Woo`0Iool0003o01Wo0ol06ol3o`02o`?o000000?o<Ol0onoo0?o_o`000ooo
00000oooooookol0onoo0002ool00003ogco0?o_o`3o06Wo00;oo`0000?o?ol0ooooooo_o`002Oo2
o`05o`000006okgo0?l0003o0?goo`000?o2o`3o03?o0_l02Ol04_l0oj7o00Woo`3mool;o`3o0?go
o`3o3?l0k_oo0?mTokgo0?l0ohGo05?oo`3oV?l;o`3o0000o`2:ool0oOoo0?n8o`3oX@;o000000?o
05gooonj0?oo^P000_oo^P001Ol0oj7ooad0o`0;ool0ohSo0?mQ00;o00Wo00KookX0o`3Dooo>o`3o
00WooolM0?l0ROl2odSo0008o`3o_ol0h_oo0>;oo`3Rool0003o08Woo`20ooo9o`02odSo0005o`3m
ool0003o9?l0okko0?o;o`000_nfo`002?l0003o027oo`1Cool07?oo0000o`3moooooooo?_l00_nY
o`001?l0003o0?oHo`3of?l0omP5ooooo`05omGo0?ooooooooooooooool0E_l01oooool01ol0J?oo
oooooooooooooooo0?Oooooooolco`000_ooool3o`2Do`Ko0?nd0ol0Sol3ooooo`?o097o6?ooool0
0ol0003oooooooooo`13ooooo`;o/ol02?ooool00oooB@3oooooooooo`0:ooooo`;oo`000_o_o`00
1ol0T?ooooooo`3oCOl0odgoo`00onoo0?ooool00ooo00001?ooooookol0onoo0?o_o`02ooooo`?o
kol00_ooool00ol06Ooo01_oo`0Ko`02o`0Ko`03ool00?l00_oo00;o00?o00;o00Coo`00onoo0?o_
o`3okol00_oo00002?l0ofCokol0onoo0?oo003o0000oc7o0?ooooookol00ooo00001?l0JOookol0
onoo0?o2o`04o`0000;o`_l000?o04Coocoo0?o2o`001Oo2o`05o`0000Go05go00?o0000o`3mool0
00000ol02Ol05?oo>`3o0?nQo`0Vool0oOoo2ol0o`1Iool0ofCo0?gookgo0?l0o`co0?nHo`_o0?l0
oiWo0?3oo`000?l0R_oo0?nQo`1Mooo>o`3o00001Ooo^P001Ol0oj7o0?n8o`3oHOl02OoookX000;o
oad000?o067oo`3o_ol0ROl00_l0okl00oo7o`3ookX0odSo0003o`3Ro`0@olWo0?l0ROoo_Ol0o`3m
oonno`3oHol0o`000?l0L_oo083oo`0Qool0003o01coo`_o0?l0003o?_l0ooooo`?o]_l01oooool3
ojWo0003ooooool0003ooooo00Kooooo00?o06Soooooool0mol00oooool2oc?o0004ooooool0U?oo
09Coo`2Do`Ko0?nd0ol0Sol5ooooo`?o097o4oooool00ol0003oooooooooo`1Rooooo`00Koooool0
0onco`3oooooooooo`0<ooooo`03oom90?oooooooooo00Wooooo0_l0odd2ooooo`;okol00_l0T?l2
ool00005onoo0?oo003oo`00ool00?ooool00oo_o`000ooo003oooooonoo0002onoo000:oooooooo
003oo`00ool00?o_o`3oooooool00?l0003oo`00onoo00;o01Wo0ol000000ol06ooo<Ol0o`02o`03
o`02o`So`_l000?oO?l0ol;o0?o2o`000_o2o`001Oloo`3o`_l0ol;o0?l0A?oooooo00Coo`0000?o
k_l0ool00?oo00000_l000003?l0oOoo0000o`000?l0of7o0000o`3mool0of7o0000oonj0?l0<ooo
2ol0o`3oX@;o00Wo00oo2ol0o`3o3?l02OooPol0o`3oI?nmo`3o05?ooh?o0?o7o`3o0000o`3oV?l0
C?oo08[oo`3oR?l000000_oo^P001ol0GOooc_l0o`3mool02Ooo02Koo`3oXOl0och00_l;o`002?l0
ohSo0?mQobCo0?l02OoookX0odSo0?l02Ooo0?o11?l0h_l00ol0003oaol0o`0Vo`02oooR000;o`29
ool0P?oobOl0olWo0?mSo`3o0000okgo0?nno`3o05?ool_o0?l000000onfo`001?l;o`3o0000o`00
0?lno`03ooooo`;oZOl00_ooool2o`3of0Cooooo00GoeOl0ooooooooooooooooo`1Fo`06ooooo`05
o`1Xooooooooooooooooool0mol00_ooool00olco`3oooooooooo`02ooooo`?o09Co1Oooool01?l0
okCo08ooo`2?ool0Sol3o`3o]0?o097o5_ooool00ol0003oooooooooo`11ooooo`03ok?o0?oooooo
oooo00Oooooo00?oodT0ooooooooool02oooool2onoo00;o093o0_l0odd00oo_o`3oooooool00002
ool00005ooooooo_o`3okol0onoo0?ooool01?o_o`000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`001Ol06ol00oo_o`3o00;oo`02o`02o`02o`;o0?mT1?o2o`000olao`3o`_l0ol;o
0005ol;o00?o000000?oo`00onoo0?mlo`000_oo00000ol0A?oo?ol0ool00002ool000;ooooo0_oo
0004o`00000@o`3oR?nmo`3o0000okgo0?o7o`3o0?mQo`3mool0003o08[oo`000?oo003o_Ol0o`09
ool0oj7o0?goo`09o`;o2ol000_o0?mTo`3moonmo`3o0?l<oh?o0?l0oiSo2ol0o`000?l0ohSo0?go
o`2:o`02o`00000:oonj0?l0ocko0?lno`2:ool09_ooB?l0o`3oXOl0ohSo00WoobCo00;o00Wo00Go
027oo`1Qooo=o`3o08Woolco0004o`3Ro`0=o`000?l0ROooc?l0o`3mooo9o`3o_Ol0o`1bool0oOoo
0000o`1Cooo;o`3oc?l0o`20o`02o`000003o`_o0?l0003ooooo00Cooooo0_nfo`000ol0omSooooo
ooooo`05ooooo`;oZOl00_l0E_l5ooooo`04o`1Xooooooooooooo`3go`Cooooo00Co<ol0oooooooo
oooooooo0ol0U?l3ooooo`?o0?nd0ol0Sol2o`3o]0?ooooo0ol0TOl@ooooo`03o`000?oooooooooo
06;ooooo001]ooooo`;o/ol03_ooool00oooB@3oooooooooo`09ooooo`03o`3oCOoooooooooo00?o
oooo00?o093oool00?o_o`000ooo00001_ooooookol0onoo0?o_o`3oo`00ooooo`?okol000?ooooo
ol;o0?o2o`001oo2o`000ol0003o`_l0o`000002o`000004ol;o0?l0ofCo`_l0oc7o00;o01Wo0ol0
6ol4o`02o`?oo`0000?oO?l0o`1Yooo_o`000_oo00002?loo`3ooooooooooooo003o04Coool00?oo
;`3ok_l00ooo0002ooooo`0Lool00?l0003oo`00o`3mool0003o0?mQo`3mool0003o_Ol0o`000?l0
of7oo`00o`_o0?l0oj7oc?l0o`_o0?l0o`co0?gooh?o0?l0ofCo00Woo`3moonmo`3o0?n5o`000?l;
o`3ookX0o`3oV0?o000000oo0?nQolco0?l0GOooIol0o`3mool09_oo0?m0o`3oXOl0R_oo0?lnoolM
0?l0ohSo9?l0oloo0?l0of401?l0h_l05ol0ROoocOl0o`0Qool0003oc?l0oonj0?o7o`3o02Koo`0Q
ool0ROoo2ol0o`20ool0ROoo0000of?o0?l0oOoo_Ol0okko0?oohP3o0000o`2:ool00Ooo2ol000;o
]_l00_l00003ooooo`04o`000?ooooooZOl0ojWo00;ooooo0ol0omP2ooooo`04omGo0?oooooooooo
ooooo`;o05Ko1Oooool01Ol0J?oooooooooooooooooo0?Oo00;ooooo0_lco`05ooooo`?o09Co1_oo
ool3o`2?o`03ooooool0okCo0?nd00?o097o0ol0ok@@ooooo`03o`000?oooooooooo03oooooo0_nc
o`09ooooo`03oom90?oooooooooo00gooooo00Co093oool00?l0odgooooo0ooo00001Oooooookol0
onoo0?o_o`3ooooo00?okol000?ooooool;o0?o2o`004?o2o`04o`0Ko`03o`3oI?l00_oo00;o00;o
00;o0_lao`000ol0003oooooonoo0002onoo00?o000000Kokol0ool00?oo003oo`00ogco0?oo;`02
ool00004ocoo0?oo003oooooooooo`?oo`000_ooool07Ooo003o0000o`000?l0oOoo0?n8o`3oHOnm
o`3o0000olOo0?l09_oo0?goo`000?l0R_oo0000ooooool02Ooo0?mQo`3oXOl0oOoo2ol0o`3oQOl0
ofCo00Woo`3moonmo`3ookX0oh?o0?oo^P3o2ol000;o0?nH017o0?goo`000?l0003o0?m0o`3mooo<
o`3o00_oo`3o?_l0R_oo00[oo`3oXOl0ohSo9?l0o`09ool0of7ookX0o`09o`04o`3Ro`0Ao`3oYooo
^P3oon80o`000?o7o`3o02Koolco0?l0ROoo0?nQolWo0?lTo`3o0?noo`000?oohP3o08[ool_o0?l0
00000_l0P?l00ol0003oooooooooo`06ooooo`;o]_l00_l0omP5ooooo`04omGo0?nYo`3oZOl0o`1F
o`Gooooo00Co06Sooooooooooooo0?Oo1?ooool00olco`3oooooooooo`03ooooo`?o09Co1_ooool3
o`2?o`Go0?nd0ol0TOl=ooooo`03o`000?oooooooooo06;ooooo001/ooooo`03ok?o0?oooooooooo
00gooooo00?oodT0ooooooooool02?ooool2o`3oC@?ooooo00?o`_l0o`2@ool0T?l04?o2o`000oo_
o`3oooooool00002ool000;okol01?l00002onoo00;o0?mT00Cooooooc7o0?o_o`3okol00ooo0003
o`0Io`;o01_o0_l00_l01_mlo`3o00;oo`02oooo003oooooocoo00?oo`0000?o04Coool00?oo0000
0_oo00000oooooooo`00ool00002ool000;oobl001Ko0000o`3mool0ohSo0000o`3mool0003o08[o
o`0Vool0003o2ol0o`09ool0oj7oc?l0o`_o0?l0k_oo0?goo`3oI?oo^P3o05?oo`3moonmo`3o0000
0_l02Ol00ol;o`3o0000o`09o`02o`00000<o`3oXOo>o`3o05goo`_o0?l0oOoo02Kookko0?l0oj7o
bol0o`2:ool0ocko0?n80ol0h_l01Ol0of7ookX0o`09ool02Ooo08Wo00;oA_l000Go0000oonj0?m6
o`3oA_l0o`0Vo`03o`1Co`0;odKo0?l0P?oo0000of?o0?m6o`3o0?gookko0?l0003o08[ool_o0?l;
o`000ol00002okKo0003o`000?l0ooOo0?og00?o0?og00?oooooojWo0?nYo`000oooool3o`3of003
omGo0?oooooooooo00;ooooo00?o05Koooooooooool00oooool01Ol0J?oooooooooooooooooo0?Oo
00?ooooo00?o<ol0ooooooooool01Oooool3o`2Do`Kooooo0ol0Sol3ooooo`?o097o2?l0ok@8oooo
o`03o`000?oooooooooo03kooooo00?o/ol0ooooooooool02?ooool00oooB@3oooooooooo`0;oooo
o`;o`_l000?o093oo`3oCOl0odd03_o2o`000ooo003okol0ooooo`03ool000?okol000?oo`00onoo
0?o_o`000_o_o`02ool00003onoo0?oo003oo`0000;oo`0000?o0?mTool00?l06ol00_l06ol01Ola
o`3o01_oo`02ool0003o00;o00?o000000Cokol0ool00?oo003oo`000_ooool01Ooo003oO?l0ool0
0?oo;`3o?ol000Coo`0000?oooooool00?oo00000_oo0002ooooo`0Co`000?l0oOoo0?mco`3oR?nm
o`3oaol0o`000?nmo`3o0?goo`000?l;o`3o0?goo`000?o<o`3o0>koo`3oXOl0003o2ol0o`3oI002
oonj0007o`3o3?l;o`3o_Ol0o`09ool0003o2ol0o`09o`04o`00000;o`29ool0oOoo0?m0ol_o0?l0
9_oobol0o`2:ool0oj7o0?n8obCo0?l02Ol00ol0h_l2o`09o`03o`29oom6o`3ookX000;oA_l0017o
0000o`1Cool09_oo05?oo`29oom6o`3o0?nQolWo0?l0003oHol0o`3mool0R_oo0000ol_o0?l0ohSo
0000o`20o`0:o`3om`;o]_l00ol0omP3ooooo`03omGo0?l0003oZOl000;oZOl01?ooool00ol0J?oo
ooooo`3go`05ooooo`03oc?o0?oooooooooo00Gooooo0ol0U?l6ooooo`?o08oo0oooool2o`3o]0?o
097o0_l0ok@3ooooo`;o00001?ooool00ol0003oooooooooo`1Qooooo`00J_ooool2ok?o00oooooo
00?oodT0ooooooooool01?ooool4ol;o0003o`3oCOo2o`3o`_l000?o`_l000?o093oooooooooool0
0_ooool2onoo0003ool00?ooooookol000;okol000Goooooool00?oo003oo`00onoo0004ool000;o
kol00ol00003onoo0004ool00?l0003o0?mTooooo`;o<Ol00ooo00001?o_o`3oo`00ool00?oo0003
ooooo`03ool00?l06OooO?l000?o01_o00Co00;oocoo0?l00_oo00;o0_oo00000ol0A?oooooooooo
o`03ool000;ooooo1?oo0004o`00000EolOo0?l0oOoo0000o`2:ool0003o00Woo`3oXOl0of7o2ol0
o`3moooo^P3o0?mTo`3mool0Dooo0?nQo`3moonmo`3o2ol0olOo0?l0003o2ol000Go00Wo0_l00000
1Ol0ROoo0?goo`29ool0003o0?nQ00Co0>;o00Go9?l0o`3o?_l0ohSookX0o`3oH@02ol_o0005o`09
ooo;o`3o0000o`1Coooo^P000_l0Dol02Oo;o`3o02KoolOo0?o;o`3o08Woo`000?l0P?ooHol0olWo
0003o`000006o`2:ool0ohSobol0o`000?l0oj7o00000_ooool2okKo0004ooooool0003ooooooooo
o`?o0?og0_nYo`0<o`3om`Cooooo00Go06Soooooooooooooooooo`3go`03ooooo`03oc?o0?oooooo
oooo00Oooooo0ol0U?l6ooooo`?o08oo0oooool3o`2Ao`Gooooo1?l0ok@4ooooo`03o`000?oooooo
oooo03cooooo0_nco`0:ooooo`03oom90?oooooooooo00;ooooo2_o2o`02o`2@o`04o`3oCOoooooo
ooooooooo`;okol000Goooooonoo0?o_o`3okol0ooooo`03ool00003onoo0?ooooooo`0000?oo`00
0_o_o`02ool000?okol00_oo00000oo_o`3oo`00ool00002ool000;ooooo00Coo`00o`3oI?oo003o
kol00_ooool00olao`3okol0o`000003o`000003o`0Kool00_oo00;o00?o00;o0ooo00001Omlo`3o
ooooool00?oo003o?ol000;ooooo0ooo0002ool_00Coo`000ol000000ol0ohSo_Ol0olOo0002o`00
000Do`3mool;o`3o0000o`09ool0003o0>koo`3oXOl0oOoo2ol0o`3oI?l0oOoo0?n5o`3o3?l0oOoo
Pol0okgo0?l0003o0?3oo`3oLol;o`04o`09o`08o`3oV?l0003o0000o`0Vool0od3oA_l0o`000?l0
oj43o`3Ro`0:o`3oR?oo^P3o0?mQol_o0?l0HOoo00Woo`1Coooo^P3o05?oo`0000?obol000So02Ko
o`29ooo;o`3o9?l0o`3oXOl0003oHol0okko00;o000000Go0?n8ol_o0?l0003o0?nQo`20o`09oooo
o`;o0?og0onfo`05o`3om`03o`000?l0ooOo0?og00;oZOl02?l0ooL3ooooo`03oc?o0?oooooooooo
00Oooooo0ol0U?l6ooooo`?o08oo1Oooool3o`2Ao`?o0?nd00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1Qooooo`00J?ooool2ok?o013ooooo00?oodT0ooooooooool01oooool2o`3oC@Go
oooo00?o093oooooooooool01Oooool2onoo0005oooooooo003oo`00ool00?o_o`000ooo00000ooo
ooookol0onoo0003o`0000?okol00_oo0002ooooo`06o`3oI?l0003o<Ol0ool00?ooooookol00ooo
0002ooooo`Coo`0000Soooooool00?mlo`3o06Woool00?oooooo01Woocoo00;o01_o1Ol00_l2oooo
o`?oo`000_ooool3ool000?o000001[o0?goo`000?l0003ookX0o`09ool0003o0?nQo`3o3?l;o`3o
_Ol0o`3oI?mEo`3o02Koo`3moon3o`3o0?gookko0?nmo`3o0000o`3oVOnmo`3o2ol0o`3oLol0R_oo
0?goo`3oX@;o000000?o0?n^o`3Rool0h_l00_l000002Ol0ROooon80o`2:oolTo`3ogol0oloo0?l0
ockookX0on;o0002o`3oH@0@o`29ool0003o00Wooonj0?l0of7oc?l0o`3oR_l0L_ooc?l0o`0Vooo7
o`3o9?l0o`000?l0Oooo083ool_o00;o00000_l;o`02o`000003ol_o0?l0003ooooo00Cooooo0_nf
o`000ol0003oooooooooo`04ooooo`?oZOl00oooool2omGo0004o`3of?ooooooooooo`1Foa;o0?og
1oooool3o`2Do`Kooooo0ol0Sol3ooooo`?o097o0_l00002ooooo`;o00001?ooool00ol0003ooooo
ooooo`0jooooo`;o/ol02oooool00oooB@3oooooooooo`0<ooooo`03o`2@ool0odgo0?m=00Gooooo
0_o_o`001_ooooooo`00ool00?oo003okol0ooooo`?oo`000oo_o`02ool000?okol00_oo00001?o_
o`3oo`00ool00?oo0002ooooo`Coo`0000Go0?mTooooooo_o`3okol0ool00003o`000006onoo0?oo
003o0000ool00?l0JOoooooo1?l06ol2o`02o`05ogco0?l00_ooo`00ooooooloo`000ooo00000ooo
ooooo`00ool00002ool000;ooooo0ooo0002o`000003o`3oHOl0ohSoaol000;o0000017o0?goo`_o
0?l0003o08[oo`3^ool0003o0?nQo`3oHOl;o`3o02Koo`09ool0o`co__l0o`3moon3o`3o_Ol0o`_o
0002o`000006o`_o0?l0ohSo0=Coo`3moooo7@3o00Wo0_l000000ol0ojko0>;oo`3Ro`02o`000006
obCo0?l0ocko00Woon;o0?oo^P3ooad00_l0of401?l0ROoo00Woo`09ool00002o`1bo`0:o`3mooo<
o`3o08Woo`0VoolTo`3o0?goo`000?nmo`3oHol0o`2:o`;o000000Ko2ol0o`000?o;o`3o0000oooo
ool0P?l=ooooo`;o]_l00ol0omP01Ol0003oooooooooool0E_oooooo00;oZOl000Koooooo`1Xoooo
ooooooooo`3gooooool@o`3om`?o09Co1?l0ooL2ooooo`?o08oo1Oooool2o`0000Kooooo00?o0000
ooooooooool0HOooool006Oooooo00?o/ol0ooooooooool03oooool00oooB@3oooooooooo`07oooo
o`03o`3oCOoooooooooo00Cooooo00?o093oooooooooool01oooool2ool00005onoo0?oo003oo`00
ool00?ooool00_o_o`03o`0000?okol000[oo`00ooooooooooooooooonoo0?oo003o0?mTool00?la
o`3o00000ooo0002ooooo`?oo`0000?okol0oooooooo00000_oo00000omlo`3o06Woool00002ool0
0004ocoo0?ooooooo`00ool000;o01Wo0ol06ol4o`02o`?oo`000_ooool07Ooo003o0000o`000?o7
o`3o0?goo`000?o7o`3o0000ool00?l0003o0?l<o`_o0?l0oOoo0?mTokgo0?l02Ooo05?oo`3mool0
003o0?goo`000?nmo`3oc?l0olOo0?nmo`3o2ol0olWo0?o>o`3o0?go00Co0>;o0_l0ojh01?l02Ooo
0?nQo`09ool0ROl2o`0000;o0?m000ko05?ooonj0?l0ohSookX0oooR0?l0003o067oo`0Vool02Ooo
cOl0olco0?l0L_oocOl0olco00;o000000Coaol0o`000?l;o`3o083o0_l;o`000ol0003o0?n8o`00
0004o`0000Kooooo00?o0000okKo0?nfo`002?ooool2ojWo00?ooooo00GoeOl0o`3of?l0omSooooo
o`1Fo`04ooooo`05o`1Xooooooooooooooooool0mol01?ooool01?lco`3oooooooooooooool:o`3o
m`?o09Co1?l0ooL2ooooo`?o08oo0oooool2o`0000Sooooo00?o0000ooooooooool0>Oooool00onc
o`3oooooooooo`0:ooooo`03oom90?oooooooooo00cooooo00?o093oo`3oCOooool01oooool2ool0
0003onoo0?ooooooo`0000;oo`000oo_o`000ooo003oooooonoo0002onoo0003ool00?ooooooo`00
00?oo`000_ooool3ool000;okol000Coooooo`3oI?o_o`3oo`000ol00004ool00005oooooooo003o
0000o`1Yoooo00000_ooool2ool00006o`0Koomlo`3o01_oo`0Kool00_oo?ol00ol00_l2ool000;o
oooo1?oo0002ooooo`0Oool00?l0003o0000o`000?o7o`3o0000oonj0?l0oOoo0000o`09ool09_oo
0000o`2:ool0003o0?nQo`_o0?n3o`3o02Koo`3o3?l0oOoo__l0o`3mool0003o_Ol0o`000?l;o`3o
c_l0o`3oLol;o`3ofol0o`3mo`04o`3Ro`03omgo0?l0ojko0?n^00?o00Wo0_l000002_l0ockookX0
o`3oR?oo^P3o067oo`3oHOoo^P3o07;oo`000?l0oj42olOo0003olco0?l0ROoo02Ko00?o000000Go
2ol0of?o0?l;o`3o0000ooooo`04o`0000;ooooo00?o083oooooooooool03?ooool2okKo0006oooo
ool0omSo0000o`3of?oooooo05Ko0_ooool3ojWo0003ooooool0mooooooo00Gooooo00?o<ol0oooo
ooooool02oooool3o`2Do`03ooooool0ooOo0?og00So0?og0_l00006ooooo`03o`000?oooooooooo
067ooooo001Uooooo`;o/ol04Oooool00oooB@3oooooooooo`06ooooo`;o0?m=4_ooool2ool00003
ooooooo_o`3okol000?o00000oo_o`001Ooo003oooooooooooooooookol000?oo`0000Ko0?mTool0
0?lao`3oo`00ooooool00004ool00003onoo0?oo003oo`0000;oo`0000Sokol0ool00?mlo`3o06Wo
ool00?ooooooo`00ocoo00;oo`000_ooool00ol0A?ooo`00ool00002ooooo`;o01Wo0_l06ol4o`02
o`03ool00?oooooooooo00Co000000co00Woo`000?o7o`3o0000o`3oXOl;o`3o0?goo`3oI?l0of7o
05?oo`0Vool00002o`3mo`07okko0?nmo`3o0?nIolOo0?l;o`3o0>;oo`_o0002o`3Ro`06olWo0?l0
oj7o05gookgo0?l0oOoo__l00_l0ojh01?l0ogko00Woo`000?l00002o`29o`03o`3o@?l02OoookX0
00;o0?n800Co0000o`3oHOl02OoookX00_l02Ol00ol0003ocOl0o`_o0003o`00000<o`_o0?o<o`3o
Hol0o`20ool0003oooooolWo0?nmo`3o0?nQo`000?oooooo00001oooool01?l0003ooooookKo0?nf
o`08ooooo`;oZOl00_ooool01?oEo`3oooooo`3of?l0omP2o`1Fo`?ooooo00Go06Sooooooooooooo
ooooo`3go`04ooooo`03oc?o0?oooooooooo00gooooo0ol0U?l00ooooooo0?ogo`3om`03o`3om`?o
08oo0_l00008ooooo`03o`000?oooooooooo03Oooooo0_nco`0<ooooo`03oom90?oooooooooo00co
oooo0_l0odd;ooooo`;oo`000oo_o`000ooo003oooooonoo0002onoo0003ool00?o_o`3oo`0000;o
o`000_ooool4ool00005onoo0?ooooooooooonoo0?oo00001?l000000olao`3oo`00ool00002oooo
o`?oo`0000?ok_l0o`1Yool000000ooo00001oooooooo`00ool00?mlo`3oo`00ooooooloo`001?l0
6ol4o`02o`;ooooo1?oo0002ooooo`;o0000013oaol0o`000?l0003o0000o`09ool0003o0>koo`00
0?l0R_oo0?goo`000?l;o`3oPol0o`3o3?l0003oc?l00_l0oOl2o`000005okgo0?o>o`3o2ol0o`3R
ool;o`000_l0h_l01?l0oOoo0?nQo`3mool02Ol2o`3oOP04olWo0?l0ojko0?n^o`3o[P;o000000Wo
00Woo`3oR_oo^P3o0?n8oonj0?l0HOoo0?mQo`000?o=o`000_l02Ol01?l0Ooooc?l0obCo0?l;o`02
o`00000:o`3mool0oj7oHol0o`000?o9o`3o__l0o`3oXOl0003oooooo`0000?ooooo00?o083ooooo
ooooool03Oooool3okKo0003o`000?l0omSo0?oH00;o05Ko0oooool2ojWo0003o`3goooooooooooo
00Cooooo00?o<ol0ooooooooool03Oooool3o`2Do`Kooooo0_l0Sol2o`0000Kooooo00?o0000oooo
ooooool0HOooool006Cooooo00?o/ol0ooooooooool06Oooool00ol0odgoooooooooo`0Cooooo`04
onoo0?l0003o0000o`0000?okol01?ooool4ool00003oooooooo003o0?mT00;o<Ol000Koooooool0
0?oo003oo`00o`000?o_o`03ool000;okol00ooo00000omlo`3o06Woool00002ool00003ocoo0?oo
ooooo`0000?oo`0000?o04Coool00?oo00000_oo0002ooooo`?oo`0000?o01Woo`0Kool06ol01?l0
0_l5o`000008o`3o3?l0k_oo0000o`3mool0ofCo08[oo`1Cooo7o`03o`000003o`3moonno`3o_Ol0
00?o0>;o0_l;o`002_l0R_oo0?n8o`3mool0oj7o05gookgo0?l0oOoo05?oo`3oXOl0Dol3o`3o[P0<
o`3oO_l0R_oogOl0o`29ool02OoookX0olWo0?l0003o0?n8o`29ool0of7o00Wo0_l;o`003ol02Ooo
2ol0olco0?lTo`3o08Woo`000?o9o`3oaol0of?o0?l0ohSo083oo`2:ool0003obOl0o`3mo`02o`00
00Sooooo0_l00002ooooo`;o]_l01oooool2o`0000;ooooo00OoeOl0ooooooooooooooooo`3of?l0
E_oo0?oH00;ooooo00Co06Sooooooooooooo0?Oo1Oooool00olco`3oooooooooo`0?ooooo`?o09Co
1Oooool3o`0000Sooooo00?o0000ooooooooool0=_ooool00onco`3oooooooooo`0;ooooo`03oom9
0?oooooooooo00cooooo00?o0?m=ooooooooool02oooool2onoo0003ool00?ooooookol000;okol0
00?oooooool00?oo00000_oo0002ooooo`?oo`000_o_o`02ooooo`03onoo0?oo003o000000;o0000
0ooo00000olao`3oooooool00003ool00007onko0?ooooooo`00o`1Yoooo003oooooo`000003ool0
0007oooooomlo`3oo`00ool00?loo`3oooooo`14o`03ool00004ooooool06ooo01_oo`0Ko`Go00;o
0ooo00000ooo?P3o0000okgo0003o`00000AolOo0?l0k_oo0000olOo0?l0003o0?goo`000?n3o`3o
0?l<o`0Vool0of7oc?l0o`000?l0oOoooad0o`3Roonmo`000_l0h_l2o`_o0005o`2:ool0GOoo0?go
o`3oXOl0oOl00ol0Dol01?l0ogko0?nQobCo0?l0R_l2o`3o[P08o`09ool0ROoookX0o`29ool0ohSo
067oo`000?l0of42olco0004o`_o0?l02Ooo2ol0o`_o00;obOl000_o0000olOo0?l0ohSoHol0o`00
0?oooooobOl0o`3mool0003oooooo`000004ooooo`03o`20oooooooooooo00oooooo0_nfo`001?oo
oooo0?oHo`3of?l0E_l2ooooo`04o`1Xool0003o0000o`3go`Kooooo00?o<ol0ooooooooool03ooo
ool3o`2Do`Gooooo0_l00006ooooo`03o`000?oooooooooo067ooooo001Sooooo`03ok?o0?oooooo
oooo01Sooooo0_l0oddCooooo`Co000000?oooooonoo0?o_o`001?ooool3ool00003oooooooo003o
o`0000;oo`0000?o0?mToc7o0?oo00000_oo0002onoo00;oo`0000?o0000onoo0?o_o`000ooo0000
1_o^o`3oo`00ool00?mlo`3o06Woooooo`;oo`0000?o?ol0ool00?ooool00ooo00000ol0A?oooooo
ooooo`04ool00003oooooooo003oo`0000;oo`000_ooool03ooo003o01Woo`0Kool0003o00Woo`00
0?l;o`3o0?l<o`000?l;o`3o0000o`3oI?o<o`3o05?oo`2:o`02o`00000Go`3oHOl0h_oo0?goo`3R
ooo7o`3o_Ol0olOo0?o>o`3o_Ol0o`_o0?l0R_oo0?n8o`3mool0Dooo0?nQo`1Coonmo`3o0?goo`3o
XOoohP3o00Woom_o0?lTo`000_l0ojh01_oohP3ogOl0omgo0?oo^P3o0000o`29o`?o2ol00_l0of40
4?o<o`3o0000o`09oolTo`3o0?goo`000?l;o`3oRol0o`3oR?mSo`3o0000olWo0?l0P?oo0?nQo`00
0?o9o`02o`0000Sooooo00?o0000ooooool000000oooool3okKo00Cooooo0_l00003ooooo`03omGo
0?oooooooooo00;ooooo00Co05Koo`3of?l0omSo06So0oooool00ol0moooooooooooo`03ooooo`03
oc?o0?oooooooooo017ooooo0ol0U?l2ooooo`;o00002Oooool00ol0003oooooooooo`0dooooo`;o
/ol03Oooool00oooB@3oooooooooo`0;ooooo`;o0?m=4?ooool2onoo0004oooooooo003oo`00ool0
00;ooooo1?oo0002onoo00;ooooo00?oo`00o`000?l000000_l000001?l0ofCoo`00ool00?ooool2
oc7o00;oo`000_o^o`04ool00003o`1Yoooo003oo`0000;oo`0000[o0000ool00?oo003oO?l0ool0
0?ooooooo`00ocoo0?l0A?ooo`000_ooool3ool000;ooooo0_oo0003o`0Ko`Co00;o0ol000001?l0
2Ooo0?goo`3^ool;o`03o`00000No`3oXOl0003oaol0o`3o3?l0of7oaol0o`000?l0h_oo0?goo`3R
ooo>o`3o_Ol0oolM0?mWo`3o08[oo`3oR?l;o`3o05goo`3mool09_oo0?nQom_o0?l02Oooaol0o`0:
ool0oj7o9?l0omgo0?l0R_oo0?n80_l0ojh01?oo^P3oc?l0o`29ool00002o`_o0006o`3oHOl;o`3o
01coobCo0?l02Ooo00000_l0ROl01?l0003o0?n8olOo0?mSo`02o`3oX@05o`3mooo9o`3o0000oooo
ool000001Oooool2o`20oa3ooooo00?o0000okKo0?nfo`000_ooool00ol0E_oo0?oHo`3of002o`00
0003o`3goooooooooooo00Gooooo00?o<ol0ooooooooool04Oooool3o`2Do`;ooooo0_l00007oooo
o`03o`000?oooooooooo063ooooo001mooooo`03o`3oCOoooooooooo013ooooo0ol00008ooooo`?o
o`0000Woooooool00?oo003oo`00onoo0?ooooooo`00o`3oI?lao`000oo_o`03ool000;okol000?o
o`00o`000?o^o`001?oo00000oooooooO?l0o`1Yo`02ool00003ooooooloo`3oo`0000;oo`000_oo
ool01Ol0A?ooo`00ool00?oo003ooooo00Coo`000_ooool4ool00004oooooooo?P3ooch0ooln00;o
000000Wo0?l<o`3^ool0003o2ol0o`3oXOl0003o08[oo`1Cool000000_l0h_l01_n3o`3o0000o`00
0?l0oOooc?l0okgo00Coaol000oo2ol0o`3oR?l0of7o0?goo`3oXOl0003o__l0o`3mool0oj7oon80
o`0;ool02Ooo9?l0om_o0?oohP000_l0ojh02_l;o`3o0000o`_o0?l;o`3o0?m0o`29ool0ohSo08Wo
o`09ool0of42o`000005olgo0?l0ROoo0000o`3oHOl0ohP00_l000001?o7o`3o__l0o`3oXOl0P?l4
o`0000Sooooo00Co0000oooooooooooo00001Oooool2okKo00Sooooo00?oeOl0ooooooooool00_oo
ool01Ol0E_ooooooo`3of?l0J?oo0?oH00;ooooo00?o0?Ooooooooooool00oooool2oc?o01Cooooo
0ol0U?l:ooooo`03o`000?oooooooooo03?ooooo00?o/ol0ooooooooool06_ooool00ol0odgooooo
ooooo`0Aooooo`;oo`000_ooool3ool000?okol00_ooool01?oo003o0000o`000?l00003ool00005
o`3oI?ooooooo`00ool00?lao`000_o^o`04ool00006oooooooo003oo`00o`1Yoooo003ooooo1?oo
00000ol0003oO?l0ool00002ool00003ocoo0?oooooo04Co00?oo`000_ooool3ool000;ooch01?oo
0004o`0Ko`;o000000?o0?n8o`000?l000000_oo0002o`000003o`_o0?n3o`3o000000;o0>;o00Co
0000o`3Roon3o`3oPol00_l000001Oo7o`3o_Ol0o`3oHOl0of7o0?n800;o2ol000Go02Koo`3mool0
oj7oc?l0o`09o`02om_o0007o`3oXOlTo`3o0?mno`3oO_l0R_oo00Woolco0003o`3o[P04o`000?l0
ROoo08Woo`29o`;o0?mQ00?oh_l0o`000?l000000_l000001?l0ohSoooooo`000?l00002o`3oX@05
o`3mool0003o0000ooooool000001oooool00ol0P?ooooooooooo`0>ooooo`0;o`000?oEo`3o]_l0
okKo0?oooooo05Koooooool0omSo06Soo`3of?l0mol01oooool00olco`3oooooooooo`0Cooooo`;o
09Co0_l00007ooooo`03o`000?oooooooooo063ooooo001kooooo`;o0?m=4?ooool3o`0000Wooooo
0_oo00001Oooooooo`00ool00?oo003okol000?oo`000_l0of@01?lao`3okol0ool00?oo0003onoo
00;oo`0000?ok_l0ool00?oo00000_l000001_ooooooo`00ool00?mlo`3o06Woooooo`;oo`0000Co
?ol0ool00?oooooooooo0ooo00000ol0A?ooooooool00002ool000;ooooo1?oo0002ooooo`;ooch0
1?oo00001?l0003o0?l<o`3oR?nmo`02o`000003o`3Rool0003oPol000CoPol00ol000004?l0of7o
0?gookgo0?l0Doooaol0okgo0?l0003o2ol0o`3oR?o7o`3o0?goo`3oXOo7o`3o0?mQo`3mool0oj42
o`3oH@03o`3oR?lTo`3o2ol000;o2ol000Co08[oo`3o[_l0ojkookX00_oMo`000ol0ROoo067oo`3o
R002o`29o`07o`3oHOo<o`3oh_l0o`29ool0003o0?n8okko0002o`000005okko0?o7o`3o08[oo`3o
XOl0P?l00_l00009ooooo`05o`000?ooooooooooooooool000001_ooool2okKo00Oooooo00?oeOl0
ooooooooool00_ooool2o`1Fo`05ooooool0J?oo0?oHo`3of?l0mol01oooool00olco`3ooooooooo
o`0Cooooo`;o00002Oooool00ol0003oooooooooo`0Rooooo`CoD_l02oooool2ok?o01_ooooo0_l0
oddFooooo`;oo`000oo_o`000oooooooo`00ool00003o`0000?oo`0000?oooooool00?l0of@00_oo
00000oo^o`3o<Ol0ool00002ool000;ooooo0ooo00000ooooooo06Woool00002ool000;ooooo0_oo
00001omlo`3o0000oooooooo003o?ol0ool00?l0A?l00_ooool4ool000;ooch00ooo0002ooooo`Co
o`000_ooool2o`000006o`3^ool0ohSo0?n8o`3mool00_oo0?mT0_l000000ol0o`co0000oh?o0003
oh?o0006o`3oHOl0003o0000o`000?o7o`3o_Ol00_o7o`001ol0ohSoaol0o`_o0?l;o`3o0?goo`3o
XOnmo`000_o<o`001Ol0oj7o0?n8obCo0?oKo`3o02Ko00?o2ol000?ookX0o`1oool000000_l0ojh0
2Ol0ohSo02Koo`29ool0ROoo0?mQo`29ool0oOoo0?n8o`000002okko00;o000000Coaol0o`3mool0
003o00000_ooool00ol0003oooooooooo`06ooooo`03o`20oooooooooooo00kooooo00?o0000omGo
0?ooool00onfo`001Ooooooo06Soooooool0omSo0?Oo00Oooooo0_lco`0Eooooo`;o00001oooool0
0ol0003oooooooooo`1Pooooo`00Foooool4oe;o01_ooooo00?o0?m=ooooooooool03Oooool3o`00
00gooooo0_oo00001oo_o`3oo`00ool00?oo003oooooonoo0?l0of@00_lao`001_oo003okol0onoo
0?o_o`3oo`00onko00Coo`0000Soooooool00?oo003oo`00o`000?ooooooO?l0o`1Yo`;oo`0000?o
ooooocoo0?oo00000ooo00000oooooooo`00o`14o`02ool00003oooooooo003oo`0000;oo`000_oo
ool2ooln00Coo`000_ooool2ool00003o`3o3?l0003o000000?o000000?oPol0o`000?l000000_l;
o`02o`3`o`;o00004ol;o`000ol0003o0?mQo`3oH@02o`3oH@03o`2:ool0003o00Wo00;o0?n^00Oo
okX0o`29ool0HOoo0?m0o`3oR?lTo`3o0?ln00;o0?mQ00go0000okko0?nno`3o2ol0o`000?mSo`3o
0?nQo`2:ooo7o`3o0?goo`000?l0P?oo000000Wooooo00Go0000ooooooooooooooooo`000008oooo
o`;o]_l01_ooool2omGo00Cooooo00?o05Koo`1Xooooool00_ooool00ol0mooo0?oHooooo`05oooo
o`03oc?o0?oooooooooo01;ooooo0_l0000:ooooo`03o`000?oooooooooo02Gooooo1omBo`02oooo
o`;o/ol07?ooool00ol0odgoooooooooo`0Fooooo`;okol000?oooooool00?l000000ol00003ool0
0006oooooooo003oo`00ool00?l0ofCok_l00_oo00000olao`3oo`00ooooo`04ool00006oooooooo
003oo`00o`1Yoooo003ooooo1?oo00002Oooooooo`00ogco0?oo003o0000ocoo0?ooooooo`00o`14
o`02ool000;ooch01?oo0002ooooo`?oo`000oooool4ool000;o00000_nmo`000ol0ohSo0000o`00
0002o`000003oh?o0?l0003o000000;o2ol00_l0l?l2o`0001?o2ol000So0?mQo`09ool0ogko0=Co
o`000?oo^P3o01coo`29o`;o0?n^00ko9?l0o`3o?_l0ocko0?mQo`29ool0003oh_l0o`29oonmo`3o
0000o`3oXOl0oOooaol0o`0000?ooooo00?o0000ooooooooool01oooool00ol0P?ooooooooooo`0>
ooooo`03o`000?oEo`3oeOl000;ooooo0_nfo`000ol0J?ooooooo`3go`03o`3of0Kooooo00?o<ol0
ooooooooool06oooool00ol0003oooooooooo`1Pooooo`00Goooool7oe;o01;ooooo0_l0odd=oooo
o`?o00004Oooool2ool00006ooooooo_o`3okol0onoo0?l0ofCo<Ol00oo_o`000ooo003ok_l0ool0
0002ool000;ooooo0ooo0002ooooo`;oo`0000?oO?l0o`1Yooooool00_oo00000oloo`3oo`00oooo
o`04ool00003ooooool0A?ooo`0000;oo`000oooool2ooln00?oo`000oooool3ool00004ooooool0
o`coo`00o`3on0Go000000Wo_Ol0o`000?n3o`3o0?3oo`2:ool09_oo05?oo`3oVOl0oOl00_l0oj40
0ol0oOoo_Ol0olOo0003o`3oX@09o`_o0?l0oj7o0000o`000?l0oj7o0000o`3oXOo<o`3o_Ol000;o
00001?o7o`001Ol0003o08[oo`09oooo^P3o0?mn00?o0?n^00Co067oomgo0?l0ohSo0?m00_l0ohP0
3Ol0003o08Woo`29oonmo`3o0000o`3oXOl0ROoo08[ooooR0?o7o`3o0000ooooool0P?l02Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`03omGo0?oooooo
oooo00;ooooo00?o05Koo`1Xooooool00_ooool01?l0mooo0?oHo`3of?l0omP4ooooo`03oc?o0?oo
oooooooo01gooooo00?o0000ooooooooool0;?ooool7oe;o01Oooooo0_l0oddJooooo`?o00000ooo
00000oo_o`3oo`00ool00002ool00003ooooooo^o`3o0?mT00;oo`000_lao`03ool00003oooooooo
003oo`0000;oo`0000?oooooo`1Yoooo00000_oo0002ooooo`?oo`0000SoO?l0oooooooo003oo`00
ocoo0?oo003o04Coooln00Coo`000_ooool4ool000;ooooo1ooo00001_oo@P3o0?oho`000?oo;03o
0000okgo00Go000000_o0?goo`000?n3o`3o0?3oolko0?l0<ooo0?goo`3oXOl0of7o0?gookgo0002
o`3oX@04o`3oR?l0oj7o05goo`_o00;o000000Go0?nQokgo0?o7o`3o0?nQobCo0002o`000006o`3o
HOl0Oooo08[oo`09ool0ogko00000_l0of400ol0ROoookX0o`3o@003o`3o[P03o`3oR?l0of7o0000
00;o08Wo00Ko0000o`3oXOoohP3o0?goo`000?o7o`04ooooo`03o`000?oooooooooo00Oooooo00?o
083oooooooooool03_ooool00ol0003oooooomGo0002ooooo`;o000000?o06Soooooool0mol00_oo
ool3o`3of0Cooooo00?o<ol0ooooooooool06_ooool00ol0003oooooooooo`1Pooooo`00I_ooool6
oe;o00_ooooo00?o0?m=ooooooooool02Oooool4o`0001Gooooo0_o_o`001_oo003oooooo`3oI?la
o`3okol0ooooo`Coo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool000;ooooo
00KoO?l0o`000?oo003oooooool00?loo`02ool000;ooooo0_oo00000ol0A?ooo`00ooooo`02oooo
o`03ooln0?oo003oo`0000;oo`000_ooool4ool000;ooooo00Koo`00o`3o3?oo003oob`0o`3on?oo
;002o`000003o`3oXOl0003o0?nQ00;o0?3o00co0?nQo`2:ool0oj7o02Koo`3mool0oj7o0?mQokko
0?l0oOoo_Ol0olOo0?l09_l2olco000@o`3oR?l;o`3o0000o`000?l0oj7o02Koo`3oXOl09_oo00_o
okgo0?lTo`3o00Woo`1boomEo`3o0000o`3oR0Goaol000So08Woo`3oO_l0ojko0?n^o`3oHOl0ohSo
0?mQo`0000;o0?mQ00OoEOl0o`000?l0oj7o08Woon;o0?l0R_oo0?go00?o000000?oooooo`20oooo
ool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0_l00008ooooo`03
omGo0?oooooooooo00;ooooo00Go05Koo`1Xooooooooooooo`3go`03ooooo`;o0?oH0oooool00olc
o`3oooooooooo`0Looooo`03o`000?oooooooooo02cooooo00?o/ol0ooooooooool01?ooool6oe;o
013ooooo00?o0?m=ooooooooool05oooool3o`000004oooooooo003oo`00onoo00?oo`000_ooool2
ool000;o0?mT00?oooooool00?lao`000_oo00001?ooooooo`00ool00?oo0002ooooo`;oo`0000?o
06Woooooooooool01?oo0002ooooo`07ogco0?oo003oo`00ooooooloo`3oo`00o`000002ool000;o
oooo1?oo0002ooooo`Ooo`001Ooo;0001ol0ooSoo`00o`000?l0003o0?nQo`3oW_l000000_l0oj40
1?l0003o08[oo`3`ool0l?l3o`3oX@04o`3mooo<o`3oc?l0o`3mo`;o_Ol000Go0000o`3oR?nno`3o
05goo`_o0002o`000007o`3oXOl0L_oo_Ol0o`3oXOlTo`3o0?goo`1oo`04olOo0006o`000?o7o`3o
0?mno`3oO_l0ROoookX00_l0of42o`3oR0;o0?n^00Co0?mQo`3o?_l0003o00000ol0ROl2o`0000Co
oooo00?o0000ooooooooool02?ooool00ol0P?ooooooooooo`0=ooooo`05o`000?ooooooooooomGo
0?ooool00_l000001?l0E_oo06Soooooool0mol4ooooo`?o0?oH0_ooool00olco`3oooooooooo`0I
ooooo`03o`000?oooooooooo063ooooo001/ooooo`OoD_l00_ooool2o`3oC@Wooooo0ol0000Koooo
o`03onoo0?l0ofCo<Ol000?oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool0
00;ooooo0ooo00001omlo`3o06Woool00?l0003oo`00ocoo0?ooool01?oo0002ooooo`03o`14oooo
?P3oo`0000?oo`000_ooool4ool000;ooooo1?oo;0001?l0o`coob`0ool/0?l0ooP2oom200Go0000
00go0?nQo`0Vool0003o_Ol0o`2:ool09_oo0?goo`000?nmo`3o0?mQolco0?l0oOoo_Ol000;o0?mQ
01Ko08[oo`3oR?l;o`3o05goo`3oF?l0oj7o00;oo`3oXOo<o`3o0000obCo0?l0ohSo00[oo`09oooo
oooo0000o`1ooomEo`3o08[oo`09oooo^P3o__l01?o7o`02o`3o[P03o`3oR?l0003o0?m000;o0?mQ
00?o0000o`3oHOl0of400_l0ROl4o`0000;ooooo00?o083oooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00oooooo00?oeOl0ooooooooool00_ooool01Ol0E_oo06So
oooooooooooo0?Oo00Cooooo0ol0omP00ooooooo<ol0ooooo`0Looooo`03o`000?oooooooooo03Wo
oooo1omBo`07ooooo`;o0?m=5_ooool4o`0000Gooooo0_oo0002ooooo`?oo`0000?oooooo`3oI?oo
00000_oo00000olao`3oo`00ool00002ool00003oooooooo003oo`0000;oo`0000?oooooo`1Yoooo
00000_oo0002ooooo`?oo`0000WoO?l0ooln0?oo003oo`00ocoo0?oo003oooooo`14ool000000ooo
0002ooooo`Coo`001ooo;0001ooo@P3oo`00ool00?oooooo0?ohoooooooo?P000ol000000ol0o`co
0000o`3oX@03o`00000Fo`3oVOl09_oo0000o`3oHOoooooo0?gookgo0?l09_ooaol0o`3moonmo`3o
02Koo`3oR?l09_oo05goo`_o0?l0003o0?goo`3oF?l02_oo0?nQobCo00;o07oo00Oo0000o`0Loonn
o`3o__l0o`000?l0R_oookX000Koaol000Co08Woo`3oR?l0od3o00000_l0ojh2o`000005oooR0?l0
oOoo0000o`000?oNo`001?ooool00ol0003oooooooooo`09ooooo`;o00003_ooool01?l0003ooooo
oooooooEo`03ooooo`03o`1Foooooooo0?Oo00Oooooo0_l0omP00ooooooo<ol0ooooo`0Iooooo`03
o`000?oooooooooo063ooooo001cooooo`03oe;o0?l0odgoD_l000?oD_l01?ooool3o`0001kooooo
0_lao`000ooo003oooooool00002ool000;ooooo0ooo0002ooooo`Coo`0000Soooooool00?mlo`3o
06Woool00?ooooooo`00ocoo00;oo`001?ooool2ool00004o`14oooo003oooooooooo`Coo`001_oo
;003ool00008o`3o3?oooooood80oom20?l0ooSoo`00ool/0?l0oih5o`000003o`0Vool0oj7o0000
00;o_Ol00ol0oOl00ol0of7o0?goo`0Vo`02okgo0007o`0Vool0of7o0?n8omCo0?l;o`3o__l0o`3o
F002o`3oX@07olco0?l0L_oo9?l0okgo0?l0003o00Woo`000003okko0006o`3oR?l02OoookX0okgo
0?l0ROoo9?l00_l000001?l0ogkoaol0o`3o[_l0ojh2olOo00?o000000?o0?lno`2:ool0oOl01?l0
0002ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o
eOl0ooooooooool00_ooool2o`1Fo`;ooooo00?o0?Ooooooooooool01?ooool2o`3of003oc?o0?oo
oooooooo01[ooooo00?o0000ooooooooool0@?ooool6oe;o0003o`3oCOoooooooooo01?ooooo0ol0
000;ooooo`;oo`0000Koooooool00?oo003o0?mToooooooo0002oc7o0003ool00?ooooooo`0000?o
o`0000?oooooool00?oo00000_oo00000ol0JOooooooool00003ool00007oooooooo003oo`00ogco
0?oo003oooooocoo0002ool00005o`14oooo003oooooo`000?oo00001ooo;002ooooo`;oo`000_oo
@P02ooooo`04o`0Wooooooooob`0o`3on0?oob`000Co0000o`3oW_l0o`co00000_l0oOl3o`00000F
o`0Vool0oOoo0000ooooool0oOoo03?ookgo0?l09_ooaol0okgo0?l0of7o0?n8o`2:ool0GOoo0000
o`_o0?l0oOoo0?nQo`3oF?l0oj7o9?l0o`09o`?o__l000WoEOl0o`000?l02Ooo08[ookgo0?oo^P3o
9?l0o`29ool0HOl00_l00003olOo0003o`000?o7o`3o000000?o0?n^00Go0?mQo`000?l0003ooooo
omko0003ooooo`03o`000?oooooooooo00Wooooo0_l0000?ooooo`04o`000?ooooooooooomGo00?o
oooo00?o05Koooooool0mol02?ooool2o`3of003oc?o0?oooooooooo01Sooooo00?o0000oooooooo
ool0Goooool007;ooooo0_l0odd5ooooo`04oe;o0?l0003o0000o`0000?oD_l07Oooool00olao`3o
ooooooooo`02ool00003oooooooo003oo`0000;oo`000_ooool3ool00003oooooooo003oo`0000;o
o`0000?oO?l0o`1Yoooo00000_oo00000oloo`3oooooo`000002ooooo`?oo`0000?oooooo`14oooo
00001ooo;002ool00004oooooooo003oo`00ool000;ooooo00Go0?l<ool/0?oo;03oob`0o`3on002
ool/0003ooooool0oiko000000;o000000ooR_l0o`3mool0003o0?goo`000?l0oOoo08[oo`3mool0
R_oo0?goo`3oHOnmo`3o02Kookgo0?o7o`000_l0R_l01Ol0ohSo0?goo`_o0?l0oOoo0?mH00;o0?nQ
0_l0oOl01olTo`3oc?l0okgo0?l0003o__l0o`0Lool0ohP00_nmo`000oo<o`3ookX0olco0002olco
00;o000000Cofol0o`3oO_l0003o00Wo0_l0ojh2o`000003olOo0?oOo`3o0?go00;o000000?og_l0
o`000?ooool00_ooool2o`0000Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?
ooooo`03omGo0?oooooooooo00;ooooo00Co06Soo`1Foooooooo0?Oo2Oooool00olco`3o0?oHoooo
o`0Iooooo`03o`000?oooooooooo04Cooooo0_l0odd7oe;o00cooooo0ol0000?ooooo`;oo`0000Ko
ooooo`3oI?oo003oo`00oc7o0?ooool3ool00003oooooooo003oo`0000;oo`000_ooool01Ooo003o
06Woool00?oo003ooooo00Coo`0000?oooooogco0?oo00000_oo00001?loo`3oob`0ool/0?l0A?l3
ool/0004o`000?oo003oo`00ool000;ooooo0ooo0003oom200Koob`000Oo0?ohoooooooooooooooo
omOo0?l0003o0?l<00?o000001_oobT0o`3oR?n:o`3o0000o`3mool09_oo0000o`3mool0003o__l0
o`0coonmo`3oaol0okgo0?nno`3o0?mQo`2:ool0GOoo0?goo`_o0?o<o`3o0?goo`3oF?l0oj7o9?l0
okgo0?l0R_l00onmo`000ol0003o00Wooonj0005olco00;o000000Ko0?mnolco0?l0003o0?n8omgo
0?l00002olOo0003o`3mool0ojko0?n^00?ooooo00Cog_l0oooooooooooo00007Oooool01?l0003o
oooooooooooEo`03ooooo`03o`1Foooooooo0?Oo00[ooooo00?o<ol0o`3of?l0omP05oooool00ol0
003oooooooooo`1Oooooo`00LOooool00ol0odgoooooooooo`03ooooo`?o00001_ooool6oe;o01Go
oooo00?o0?mToc7o0?ooool00oooool2ool000;ooooo1?oo00001?ooooooo`00ool00?oo0002oooo
o`;oo`0000?oO?l0ooooooooool00_ooool01?loo`3oo`00ool00?l00005ool/0003o`14oooo;03o
oooo00Coo`0000?oooooool00?oo00001_oo;0000ol0o`cood80ooooo`02ooooo`06o`3on?oooooo
och0ooln0?l0oikooooo0_l000001_n:o`3oooooo`000?l0003o0?goo`0000;o0?go0_nmo`004?nn
o`3o02Kookgo0?nmo`3o0?goo`0cool0003o0?n8o`3oHOl;o`3ooooooonj0?l0oeSo0?goolco0?lT
o`02olco0003o`000?o<o`3oc?l000Coc?l000go00Wooonj0?l0ohSo9?l0o`29ool0e?oo067ooonj
0?o<o`3o0000o`3oO_l0oj7o000000;o0?n^0_l0od001Ol0oOoo0000o`000?l0003og_l000_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03omGo0?oooooooooo00;ooooo
00Co06Soo`1Foooooooo0?Oo2Oooool2oc?o00;o0?oH5oooool00ol0003oooooooooo`13ooooo`03
o`3oCOoooooooooo00Oooooo1omBo`000ooooooo0000o`000002o`0001?ooooo00Goo`00o`3oI?oo
ooooo`00oc7o0002ool00004oooooooo003oo`00ool000;ooooo1?oo00000ol0JOoooch0ool00002
ool000;ooooo0_oo00002?mlo`3oob`0ool/0?oo;03o?ol0ool/0?oo003o04Co1?oo00000ooooooo
0000ool00002ool000Ooob`00_ooool3ooln0008o`3on?oooooooooooooooooGo`3oooooo`3o3?l0
oih2o`000006olco0?l0003oc_l0oh[o0?l0R_oo00000_l0oOl2o`000007okko0?l0003o03?oolOo
0?l09_oo_Ol0o`3oR002o`3oH@;o__l000Co2ol0o`3mool0oj7o0?mH1Oo<o`004Ol0003oc?l0olco
0?o<o`3o08[ooonj0?l0ohSo08Woo`1Qoon=o`3o08Wooonj0?l0ogko0000o`3mool0003o02Ko00;o
0?m000?oon80o`000?l000000_l0ojh01Oo4o`3oooooomko0?oooooo000001gooooo00Go0000oooo
ooooooooooooomGo0002ooooo`03o`1Xool0E_oo0?Oo00_ooooo00?o<ol0ooooool0omP00_l0omPD
ooooo`03o`000?oooooooooo05oooooo001_ooooo`;o0?m=0oooool3o`0000oooooo1omBo`0=oooo
o`03o`3oI?lao`3ooooo00Kooooo0_oo00000oooooooo`00ool00002ool00003oooooooo003oo`00
00;oo`0000Ooooooogco0?l0JOooooooool00?oo;03o?ol000Coob`000Go0000ool00?oooooooooo
o`14o`03ool000Ooob`01?oo00000ooo@P3o0?l<ooooo`03ooooo`03o`3on?oo?P3ooch000;ooooo
00Go0?nNooooool09ooo0000oh[o0002olco0004o`000?o<o`3oc?l0o`0000?o0?go1?o<o`001?nm
o`3o0?goolco0?o<o`02o`00000No`_o0?o<o`3o0?mHo`3oXOo<o`3o9?l0o`3oR?nmo`3o0000okgo
0?l02Ooo08[oo`3oR?l;o`3ookX0o`3oR?oo^P3o08[oo`3mool0ROoo0?goo`1Qoooo^P3o0000o`29
ool0oj7o0000o`3oO_l0ohSoHol00ol0ojh01Oo2o`3o0000olCo0?o4o`3og_l000[ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03omGo0?oooooooooo00;ooooo00Co06So
o`1Foooooooo0?Oo2_ooool01?lco`3oooooo`3of?l0omPEooooo`03o`000?oooooooooo047ooooo
0_l0odd?ooooo`?o00001OmBo`0Booooo`04o`3oI?oo003oo`00oc7o00Coo`000_ooool3ool000;o
oooo00Coo`00o`1Yoooo003oo`001_oo;0001Omlo`3oo`00ool00?oo003o?ol000?oo`0000Co04Co
ooooooooooooo`000ooo;0000ol0003oob`0ool/0002oom200Gooooo0_oo?P03ooooo`08o`3on?oo
oooooooooooooooGo`3o0?l<ooooool0oih3o`0000;oc?l000OoR_l0o`3oR?o<o`3o0000olco0?l0
oOoo000000;o0?go0oo<o`000onmo`3o0?goolco0002olco00;o000000Co0?goo`3oXOl0oeSo0?n8
0_nmo`005?l0ohSo0000o`_o0?l0oOoookX0o`09ool0oOoookX0o`3mool0ROoo067oo`3mool0ROoo
okX0o`000?oKo`3o0?nQo`000?l0ohSo0?nQ0_l000001?o2o`3o0000ooooooooool3o`3o[P03omko
0?l0003ooooo01gooooo00Go0000ooooooooooooooooomGo0002ooooo`03o`1Xool0E_oo0?Oo00_o
oooo00Co<ol0oooooooooooooooo0_l0omPBooooo`03o`000?oooooooooo05oooooo001^ooooo`03
o`3oCOoooooo000000?o00006Oooool6oe;o00Kooooo0_lao`09ooooo`;oo`0000?oooooool00?oo
00000_oo0002ooooo`;oob`000?oO?l0ool/0?oo;0000_oo;0001?loo`3oo`00ool00?oo0002oooo
o`05ool00?l0003o0000ool/0?l0A?l00ooo;0000ooo003oooooooooo`04ool000;ooooo0_oo@P00
1?l0o`coooooooooooooool2ooln0003o`3on?oooooooooo00;ooooo00So0?nNo`0Woooooooo0000
oh[o0?l0003oooooo`0000?o02Ko00Co0000o`3mool0003o00000_l0oOl2okgo0003o`3mool0R_oo
c?l000;o000000Co2ol0olco0?l0oj7o0?mH0oo<o`000ol0003oc?l0olco0006olco00;o000000go
02Koo`29ool09_oo067oolco0?l0003o0?nQo`0Vool0003o00Woo`3oO_l0ohSo0?go00;o00000_l0
ojh00oo2o`3oooooolCo0002olCo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0?ooooo`;oeOl00_ooool01?l0J?ooooooo`1Fool0mol;ooooo`03oc?o0?oooooooooo00?o0?oH
4_ooool00ol0003oooooooooo`10ooooo`03o`3oCOoooooooooo00_ooooo1?l00008ooooo`OoD_l0
2_ooool01Ol0ofCooooooc7o0?lao`3oo`0000;ooooo1?oo00000oooooooo`00ool/0006ool/0003
ool00?ooooooo`0000;oo`0000WoO?l0oooooooo003oo`00ocoo0?oo003oooooool/0?l0A?l01?oo
;003ooooo`03oom20?l0003ood8000Gooooo0_oo?P001Ol09ooooooooooooooooooo0?oh00?ooooo
00Koeol0o`3o3?oo:@3oe_l0o`3oW_o^o`02o`000003omGo0?ooooooR_l000?o000000Coc?l0o`3m
ool0003o_Ol00_l00002o`3mo`03okgo0?l0oOoo0?n800;oc?l00_l000001?l;o`3o0?nQolco0?l0
oeP:olco00;o000000Oo0?n8o`1Qool0ROooc?l0o`000?l0oj7o000000;o0?mn00Co0?n8o`000?l0
003o00000oo2o`03ooooo`;o0?n^00?oa?l0ooooooooool07?ooool01Ol0003ooooooooooooooooo
eOl000;ooooo00?o06Soo`1Fool0mol02oooool00olco`3oooooooooo`02ooooo`?o0?oH3oooool0
0ol0003oooooooooo`1Oooooo`00K?ooool01?l0odgo0000o`000?l0000Sooooo`GoD_l000?o<Ol0
oe;o0?ooool02_ooool2ool000Koob`000Coo`00ogco0?l0JOoooch00_oo00000oloo`3oo`00ool/
0006ool/0003ool00?l0003o04Co00;ooooo1?oo0003ooooo`?ood8000Coooooo`3o3?oooooooooo
0_oo?P000ooooooo0?ohooooo`04ooooo`06o`3oW_ooooooooooonko0?n:o`3oobT01?l000000ol0
9_oo0000o`000003o`000003o`2:ool0oOoo_Ol000;o000000Go0?n8o`0cool0GOoookX0o`_o0002
o`3oX@08o`3oF?l0ohSo0000okgo0?ooooooc?l0o`29oonmo`02o`3oR007oonj0?lTo`3o0000o`00
0?l0R_oo08Woo`3oH@02o`000006o`3oXOl0of7o0000o`3oHOl0oOoo0?nQ0_l000001?o[o`3o0?mQ
o`000?l00002o`3o[P03ol;o0?oNo`3ooooo00;oa?l01_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo013ooooo00CoeOl0oooooooooooo06So0_ooool00ol0moooooooooooo`09oooo
o`03oc?o0?oooooooooo00;ooooo0ol0omP?ooooo`03o`000?oooooooooo03kooooo0_l0odd;oooo
o`?o00004oooool7oe;o0005ooooool0ofCo0?mToooooolao`000oooool2ool000Koob`00_oo0000
0ol0JOooo`00ooooo`04ool00004oooooooo003oo`00ogco00?oob`000Go?ol0ool/0?oo;03ooooo
o`14o`05ooooo`;ood800_ooool00ol0003oooooooooo`03ooln0003ooooool09ooooooo00?ooooo
00oo0?ohooooooooooooooooo`3o3?ooooooobT0omKo0?l0oikoe_l0oolY0?oooooo0000oooooon:
o`000_l00003o`0Vo`Co00000_nmo`002?l0oOoo_Ol0o`000?l0003o0?n5okgo0?l0of7o2ol00_l0
oj402Ooooooo0?mHo`09ool0003o_Ol0o`3oHOlTo`3o0?mQo`09o`04o`000003o`3oHOl0HOooc?l0
00Co000000?o0?nQo`3mool000000ol00003ooooo`;o`_l00_ooool01?l0003o0?n^o`3o[_o4o`0M
ooooo`05o`000?oooooooooooooooooEo`000_ooool00ol0J?oo0?Ooo`1Fo`0;ooooo`03oc?o0?oo
oooooooo00Cooooo0ol0omP<ooooo`03o`000?oooooooooo05oooooo001Zooooo`?o0000:_ooool0
0olao`3oooooooooo`06oe;o00Ooob`000?oooooool00?oo00000_oo00000oooooooo`00ogco0004
ool/0004ocoo0?oo;03oo`00ooooo`Coo`000_ooool01?l0A?oo0000ool00?oo0005ooooo`;ood80
0oooool01?l0o`coooooooln0?oo?P03ooooo`03o`3on?oooooooooo00;ooooo00So0?nNooooooo^
o`3ok_l0oooooon:o`3oobT0omOo00?o000000Ko0?n8o`000?l0003oooooo`3mooo<o`03oi_o00;o
000000_o0?goo`000?l0GOoookX0o`_o0?l0oj7o0000o`3oF?l0ohSo0000okgo0006o`0Vo`;o0000
00Go00Wooonj0?l0R_oo08Woooooo`05o`000003o`3oR?l0oj7o00Wo00?o00000_o[o`02o`000003
oh_o0?l0ojko0?n^00;o`_l000?oooooolCo0?o4o`001?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo013ooooo00CoeOl0oooooooooooo06So0_ooool00ol0moooooooooooo`09oooo
o`03oc?o0?oooooooooo00Cooooo0_l0omP=ooooo`03o`000?oooooooooo03gooooo00?o0?m=oooo
ooooool02?ooool3o`0001gooooo00Co0?mToe;o0?mBo`3o<Ol00_mBo`04ool/0003ool00?oooooo
o`0000?oo`0000?oooooo`1Yoooo00000_oo00000oooooooob`0ool/0003ool/0005ogco0?oo;03o
o`00ool00?loo`000oooool00ol0A?ooooooooooo`02ooooo`;ood801Oooool00ol0003ooch0oooo
o`02ooooo`03o`0Woooooooooooo00;ooooo013o0?ohooooooooooooooooo`3o3?ooooooobT0onko
0?l0oikoobT0omKo0?oo:@3oeOl0ooooool0003oR_l00_ooool00ol0R_ooooooo`000003o`000003
o`3oHOl0003o_Ol000;oVol00_l000001Ooooooo0?n5o`3oQOl;o`3o0?nQ00;o000000?o0?mHo`00
0?l09_l01Ol09_l2o`000005oonj0?l0ROoo0000olco0?l0ROl00ol000000ol0oj7oHol0o`3mo`02
o`0000?ojol01?ooool2ol;o0003o`000?oooooog_l000?o0?n^00?oa?l0ooooooooool06?ooool0
0ol0003oooooooooo`02ooooo`06omGo0?oooooo06Soooooool0mooo05Ko2oooool2oc?o00Oooooo
0_l0omP:ooooo`03o`000?oooooooooo05oooooo001Wooooo`?o000000?o0?m=ooooooooool0:?oo
ool2oc7o00;ooooo1ooo;007oe;o0003ool00?oo;03oob`000?oob`000?oO?l0ool00?oo00000_oo
00000oloo`3oooooool00002ool000;ooooo1?oo00000ol0A?ooooooo`000004ooooo`;ood800ooo
ool2o`0000;ooch01?ooool00ol0ooSoooooooooo`02ooooo`03o`0Wool0oikok_l000?ooooo00?o
R_l0omOo0?ooool02OnKo`02o`2:o`04o`0Vool0003o0000o`3mo`?o0?mc00Go02Koo`_o0?l0003o
0000o`3oF002o`0Vo`06oooooonno`3o0?n8olco0?nmo`3ookX00_l000000ol02OoookX0oonj0002
olco000=o`3oXOl0003o0000o`000?l0ROoo0?nQof?o0?l0003o0?goo`2:ool;o`3o0000olgo0003
on_o0004oh_o0?oooooo0?n^o`3o[P;o`_l000KoooooolCo0?o4o`3oa?l0ooooool0000>ooooo`03
o`000?oooooooooo013ooooo00CoeOl0oooooooooooo06So0_ooool00ol0moooooooooooo`09oooo
o`03oc?o0?oooooooooo00Gooooo0ol0omP;ooooo`03o`000?oooooooooo03[ooooo0_l0odd7oooo
o`Co00007?ooool3ool/0004o`3oI?oo;03o<Ol0oc7o00?ooooo1omBo`03ool000Koob`000Gooooo
ool00?oo003oo`00ogco0003ooooo`03ocoo0?oooooooooo00;ooooo00?o04Cooooooooo@P000_oo
@P05ooooo`;ooch000Goooooo`000?ooooooooooo`0Wo`05ooooo`03o`3on?oooooooooo00;o0000
00Ooooooonko0?oFo`3o0?nNomKo0?ooooooobT000?ooooo00OoR_l0o`000?oDo`3o08[oooooool0
003o0?n800GoVol000Co0?mcokgo0?l0003o00000ol0og<00ol0oj7o2ol0o`000002o`00000:o`3o
F?l02Oooc?l0obCo0?l0R_oo0?n8o`3mool02Ooooooooonj00;oc?l00_oo^P03o`000005ohco0?l0
oOoo08[oolco0?l000000oooool2on_o00Cooooo0oo2o`000ooNo`3oooooooooo`02o`3o[P03olCo
0?oooooooooo01Oooooo00?o0000ooooooooool00_ooool01_oEo`3oooooo`1Xoooooooo0?Ooo`1F
o`cooooo00?o<ol0ooooooooool01_ooool3o`3of0Sooooo00?o0000ooooooooool0G_ooool006Co
oooo0ol000000ooooooo0?m=ooooo`0Zooooo`03oc7o0?l0ofCoob`000;oob`02?ooool6ool/00Go
D_l000KoO?l0o`1Yooooooooooooool00?loo`02ool00003oooooooo003oo`0000;oo`000oooool0
1_l0A?oooooooooooooooooo0000ooooo`;ood801Oooool2o`0000Kooooo00Ko0?ohoooooooooooo
ooooo`0Wooo^o`04oi_o000=oh[o0?nKo`3oVol0oi_o0?oFo`3oobT0o`000?l09_oo0000o`3oR?l0
og?o0000o`2:o`03o`3oL`04okgo0?oooooo0?mQo`3mo`;o_Ol000Oo0?nQo`_o0?l0oj7o0000o`3o
R?l0oeSo0?mQ00;o0?n800Coooooolco0?oo^P3o_Ol00ooo^P004?l02Oooc?l0o`29ool0R_oo0000
o`1Qoooooooo0000o`3oXOl;o`3oHol0o`3mool02Ooo08[oo`000?oohP02o`0000;ooooo0_o[o`00
0ooooooog_l0o`3o[P02o`3o[P03ol;o0?oooooooooo00;oa?l03_ooool00ol0003oooooooooo`0A
ooooo`03omGo0?oooooo06So00;ooooo00?o0?Ooo`1Fooooool02_ooool00olco`3oooooooooo`07
ooooo`;o0?oH2Oooool00ol0003oooooooooo`0iooooo`03o`3oCOoooooooooo00Cooooo0ol0000M
ooooo`?oob`00_ooool00ol0ofCooooooc7o0009ooooo`?oob`01_mBo`04ool000;ooooo00GoO?l0
ooooooooooooooooocoo0004ooooo`03o`14oooo@P3ood8000Kooooo0_oo?P04ooooo`03o`000?l0
9ooooooo00Cooooo00Co0?ohoooooooooooooooo0_l000001oo^o`3oe_l0ooooool0oikooooooolY
0?oEo`000_ooool00ooEo`3oR_l0o`000005oi_o0003o`3oR?l0og?o000000;o0?mc017o0?mQokgo
0?nmo`3o_Ol0o`3mool0oj7o0000o`3oXOl;o`3o0?nQo`3oHOl0003o08Woo`3oF?lTo`3ookX0okgo
0002oonj000=o`09ooo<o`3oc?l0o`29ool0R_oo08Woo`000?o=o`3o0000o`3moomSo`3o0?goo`2:
o`02o`0000Gooooo0oo[o`001?oooooo0000ooooooooool2ol;o00?ooooo0_l0ojh00oo4o`3ooooo
ooooo`0Fooooo`03o`000?oooooooooo00;ooooo00KoeOl0ooooool0J?oo0?Ooooooool0E_l<oooo
o`03oc?o0?oooooooooo00Sooooo0ol0omP5ooooo`03o`000?oooooooooo05kooooo001Qooooo`?o
00000_ooool2o`3oCB_ooooo00?o<Ol0o`3oI?ooool01?ooool7ool/00Oooooo0_oo00000ooooooo
O?l0o`1Yo`03oe;o0003ocoo0?mBo`3oD_l000;oo`001oooool01_l0A?oooooooooooooooooood80
o`0000Gooooo0_oo?P07ooooo`04o`3on?oooooo0000o`0000?oVol000[o0?nNoooooooooooooooo
oh[o0?oo:@3ooooooolY0?oFo`3oobT01?l000005?l0R_oo0?goo`000?oooooo0?goomCo0?nmo`3o
08[oooooool0ohSo0?goo`3oHOl0oj7o_Ol0o`_o0?l0oj7o0?n8o`3oF?l0ohSo0?mQ1Ooo^P002onm
o`3o0000olco0?o<o`3ookX0o`29ool0R_oo0000o`29ool0003o0?nQ00;o0=Co00CoHol0o`3mooo<
o`3o08[o1?l000001?n<o`3ooooooooooon;o`02on_o0003omko0?oooooooooo00;o0?n^00?o`_l0
ooooool000000_o4o`0=ooooo`03o`000?oooooooooo017ooooo00?oeOl0ooooool0J?l00_ooool0
0ol0mooo05Koo`1Fo`0:ooooo`03oc?o0?oooooooooo00Sooooo0ol0omP6ooooo`03o`000?oooooo
oooo03Oooooo0_l0odd4ooooo`?o00009?ooool00ol0ofCooooooc7o0003ooooo`Ooob`00_ooool2
ool00003o`1Yoooo003oo`0000;oo`001_mBo`001Omlo`3ooooooooooooooooo?ol000?ooooo00?o
od80o`14ooooool01?ooool3ooln00Kooooo00?o02Ooo`000?ooool01?ooool02Ol0ooSooooooooo
oooGo`3ok_l0oooooooo:@3ooooooolY0002o`000003oolY0?ooooooVol000;oVol000CoR_l0oi_o
0?l0003o0?mc0_l000003?l0oOoo0000o`2:ool0oOoo0000o`3moooooooo0000okgo0?l0GOoo_Ol0
o`3mo`;o0?nQ00Ko0?n8o`_o0?l0oj7o_Ol0o`3oHOl0oeP3oonj0003o`3oR?l0003oc?l000;o0000
00KookX0o`29ool0R_oo0000o`3oXOl00002o`3mo`04olco0?l0R_oo0000o`0000Sooooo0_o[o`04
ooooo`;o`_l00oooool3o`3o[P03olCo0?oooooooooo01Cooooo00?o0000ooooooooool00_ooool0
1_oEo`3o06Soooooool0moooooooo`1Fo`cooooo00?o<ol0ooooooooool02_ooool3o`3of0;ooooo
00?o0000ooooooooool0G_ooool005gooooo1?l00004ooooo`03o`3oCOoooooooooo02[ooooo00?o
<Ol0ooooooooool00_ooool3ool/013ooooo00?oo`00ogco0?ooool00_oo00001?loo`3oo`00oooo
ooooool7oe;o0004ooooool0A?ooooooooooo`;ood800_ooool00ol0003oooooooooo`02ooln00Wo
oooo00Go0?ohooooool0003o0000o`0Wo`02ooooo`0:o`3oW_oooooooooooooooon:o`3oeol0oooo
oooo:@3ooooooolY00Go000000?o0?n8o`000?l0oOl00ol0oOl04_nmo`3o0?goo`3mool0oOoo_Ol0
o`3oXOoooooo2ol0okgo0?l0oj7ookX0o`3oF?oo^P3o0?mQokgo0?oo^P3oc?l0o`09o`;oc?l000?o
ooooo`3oXOl0oj400_l000002Ol0R_oo0?nQo`000?l0003oc?l0of?o0?l0oOoo0000o`2:o`02o`00
0007o`_o0?l0003ooooooooooon<o`3ooooooh_o0002ooooo`;ojol00oooool2o`3o[P03ol;o0?oo
oooooooo00;oa?l03?ooool00ol0003oooooooooo`0Aooooo`03omGo0?oooooo06So00;ooooo00?o
0?Ooooooool0E_l02_ooool2oc?o00_ooooo0ol0omP3ooooo`03o`000?oooooooooo03Kooooo00?o
0?m=ooooooooool01?l0000Vooooo`03o`3oI?oo;03o<Ol000Coob`02_ooool00ol0JOooo`00oooo
o`08ooooo`05ogco0?ooooooD_l0oe;o0?loo`001?mBo`000ol0A?ooooooooooo`02ooooo`;ooch0
2?ooool01?l09oooooooooooool00003ooooo`03o`3on?oooooooooo00;ok_l00_ooool00ooo:@3o
oooooolY0002o`0000;oVol000GoooooomGo0?ooooooR_l0omCo0006o`000004o`2:ool0ohSo08[o
o`0000;o0?go00?o_Ol0o`3mool0oOl00_l0oOl02Ol0oj7o0?goo`_o0?l0oOoookX0obCo0?l0of7o
0?mHokko0003olco0003o`09oooooooo000000;o0?nQ00Oo0000o`1Qool0003o2ol0of?o0?l0oOoo
08[o00;o000000?oRol0o`000?l000002?ooool2on_o00?ooooo00Cog_l0ol;o0?o2o`3o`_l00ooo
ool2o`3o[P03olCo0?oooooooooo01;ooooo00?o0000ooooooooool00oooool01OoEo`3o06Sooooo
ool0mooooooo00;o05Ko2oooool00olco`3oooooooooo`0;ooooo`;o000000?oooooo`000?ooool0
Goooool005[ooooo0ol00006ooooo`;o0?m=:oooool2oc7o01Sooooo00?oO?l0ool00?oo00000_oo
ool00oloo`3oooooooooo`08ooooo`KoD_l00_ooool00ooo?P3o0000ooln000:ooooo`05o`3on?oo
ooook_l0onko0?l09ol00oooool03?l0oikoooooooooooooooooR_l0oooooooo:@3oe_l0oolY0?oo
ooooe_l0ooooo`Co000000Ko0?n8o`000?oDo`3oooooolOo0?nmo`03o`2:o`?o0?go00Ko2ol0o`3m
ool0oOoo0?goo`3oF?nno`02o`000004o`3oHOnmo`3oc?l0o`09o`;o0?nQ00[o00Woo`000?l0003o
0000o`29ool0003o067oo`000?l02Ooo0?go0_l02Ol01Ol0R_oo0000o`000?l;o`3o000000;ooooo
00CoS?l0ooooool0003oRol00_ooool00ooNo`3ojol0on_o0003ooooo`;o0?n^00?o`_l0oooooooo
ool00oo4o`0:ooooo`03o`000?oooooooooo017ooooo0_oEo`000ol0J?ooooooo`3go`02ooooo`03
o`1Foooooooooooo00Wooooo00?o<ol0ooooooooool02oooool2o`000003ooooool0003ooooo03Go
oooo0_l0odd3o`0002Sooooo0_l0of@2oc7o00oooooo00?o06Woooooooooool01oooool01Omlo`3o
oooooooooooooooo?ol000;ood800oooool6oe;o00Sooooo00?o02Ooooooooooool00_ooool01ol0
003oooooooooool0ooSoooooonko0?oGo`000_ooool01_oo:@3ooooooolY0?oFo`3o0?nNoolY00;o
oooo00CoeOl0ooooooooooooR_l01?ooool2o`000005ooooool0003oooooo`3oR?l000000_l0R_l0
2Onmo`3o08[oo`2:oooo^P3o0?goobCo0?nmo`3o0000o`_o0003o`3mo`06o`000?l0oeSo0000olco
0?nmo`3o00Wo0_l0oj44o`0000;o00Wo00?o0?goo`09ool0R_l00_l000000oooooooRol0o`000008
ooooo`03o`000?oooooojol000;ojol000Coooooomko0?oooooooooo0_o2o`03ooooo`;o0?n^0_o4
o`0Booooo`03o`000?oooooooooo00?ooooo00CoeOl0o`1Xoooooooo0?Oo0_ooool00ol0E_oooooo
ooooo`09ooooo`03oc?o0?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`1Oooooo`00Eooo
ool3o`0000Sooooo00?o0?m=ooooooooool0:_ooool00olao`3o0?mTooooo`0Gooooo`03ogco0?l0
JOoooooo00;ooooo00?o?ol0ooooooooool02?ooool2oom20003o`14oooooooooooo00;ooooo1omB
o`08ooooo`04o`3on?o^o`3oooooo`0Wo`?ooooo00?o0?nNooooooooool00_ooool02_n:o`3ooooo
oolY0?ooooooobT0oooooooFo`3oooooomGo0?ooool3o`000003o`3oR?l0003ooooo00;o_Ol01?nn
o`001Ol0oOoo__l0okko0?l;o`3o0?nQ00;o0?go00?o0?mHo`000?l000000_o<o`02o`3oX@05o`2:
oonmo`3o00Wooonj0?l000000_l0ROl01?l0003o067oo`09oonmo`02o`3mo`03ooooool0R_oo0000
00;o000000GoSOl0oooooooooooo0000ohco0002o`0000?ooooo00?og_l0ooooooo[o`000_o[o`00
1?l0003oooooo`3o[_l0ojh2ol;o00;ooooo0_o4o`09ooooo`03o`000?oooooooooo01;ooooo00Co
06Sooooooooooooo0?Oo0_ooool00ol0E_ooooooooooo`09ooooo`03oc?o0?oooooooooo00[ooooo
0_l000000ooooooo0000ooooo`0cooooo`Co0000:_ooool00ol0ofCooooooc7o000@ooooo`03o`1Y
oooooooooooo00Oooooo00KoO?l0ooooooooooooooooocoo0?oo@P04ooooo`04o`14oooo?P3ooch0
ooln00?ooooo1omBo`000ol09oooooooooooo`04ooooo`05o`000?l0ooSok_l0onko0?oGo`000ooo
ool01_oo:@3ooooooolY0?l0oikooooooolY00;ooooo00CoeOl0oooooooDo`3oR_l01Oooool2o`00
0007okko0?l0003oooooo`3oR?l0003o__l0okgo0003okko0006o`3oXOl0oOoo__l0okko0?l;o`3o
0?nQ0_l0of401?l0003o0?mHo`000?o<o`02o`3oX@03oi7o0?l0oOoookX000?o000000Go067oof?o
0?l0oOoo0000o`2:o`02o`0000_ooooo00?o0000ooooooooool00_ooool2on_o0004omko0?oooooo
ooooooooo`?o`_l00_ooool3o`3o[P03olCo0?oooooooooo00oooooo00?o0000ooooooooool00ooo
ool00ooEo`3o06Soo`3go`03ooooo`03o`1Foooooooooooo00Wooooo00?o<ol0ooooooooool03?oo
ool00ol0003oooooooooo`1Nooooo`00E?ooool3o`0000Wooooo0_l0odd/ooooo`03oc7o0?l0ofCo
oooo01Oooooo00?oO?l0o`1Yooooool00_ooool00oloo`3oooooooooo`07ooooo`;ood8000?ooooo
o`14ooooool00_ooool2ooln00Kooooo00?o0000oe;o0?mBo`001?mBo`001Oooooook_l0onko0?oo
oooo02Oo00Cooooo00_o0?nNoooooooooooooooooolY0?n:o`3ooooooolY0?ooooooobT0omKo0002
ooooo`03omGo0?ooooooeOl000;o000001?o__l0o`3oR?l0003o__l0olOo0?nmo`3o0?n8o`1Mool0
oj7o0?goobCo0?l0003o2ol0o`3oXOl0oOoo08[ookgo0?l0oeSoc?l000;o0?nQ0oo7o`000ol0GOoo
0000o`000003o`000008ooooool0R_oo067oo`3moonmo`3o0?goo`2:oooohP04o`000004ohgo0?oo
oooo0000o`0000Kooooo00Cog_l0oooooooooooooooo0_o[o`02ooooo`?o0?n^00?o`_l0oooooooo
ool00_o4o`08ooooo`03o`000?oooooooooo01;ooooo00Co06Sooooooooooooo0?Oo0_ooool2o`1F
o`[ooooo00?o<ol0ooooooooool03?ooool00ol0003oooooooooo`0_ooooo`?o000000?o0?m=oooo
ooooool0:_ooool00ol0ofCooooooc7o000@ooooo`03o`1Yoooooooooooo00Oooooo00?oO?l0oooo
oooo@P000_oo@P000oloo`3oooooooooo`02ooooo`03ooln0?l0A?oooooo00_ooooo00?o02Oooe;o
0?mBo`001OmBo`001Oooooook_l0ooooooooooooeol000;ooooo00KoobT0ooooooooooooobT0o`3o
W_oo:@02ooooo`05omGo0?ooooooooooomCo0?n:o`001_ooool00ol0003o__l0o`000002okko0007
o`3oR?l0003o0?n8okgo0?l0003oooooo`3oX@02o`3mo`09obCo0?l;o`3o0?nQokgo0?o<o`3o08[o
olOo0?l0oeSo0?nQ00;oaol000?o05goo`000?l000000ol000001_l0R_oo0?goo`3mool0R_ooSOl0
o`0000cooooo00?o0000ooooooooool01?ooool3on_o00Cooooo0_o2o`03ooooo`;o0?n^0_o4o`0?
ooooo`03o`000?oooooooooo00?ooooo00?o06Soooooool0mol00oooool00ol0E_ooooooooooo`09
ooooo`03oc?o0?oooooooooo00cooooo00?o0000ooooooooool0GOooool0057ooooo0ol0000;oooo
o`03o`3oCOoooooooooo02_ooooo00?o<Ol0o`3oI?ooool06?ooool01Omlo`3ooooooooooooooooo
?ol000Sooooo0_oo@P03ooooo`04o`14oooooooooch0ooln00Wooooo00?o0000ooooooooool00ooo
ool7oe;o00;ooooo00go0?nNoooooooooooooooooolY0?n:o`3oobT0oooooooo:@3oooooomKo0?oo
ooooeOl000;ooooo00GoeOl0o`000?l0003o0000ooooo`02o`000004olOo0?nmo`3o0?n8o`3oR0;o
000000_o0?goolOo0?l0003o2ol0o`3oXOo7o`3oc?l0o`3oF?l0oj7o_Ol0o`1Mo`02o`000003o`1M
ool0ohSo000000Co000000_oooooo`2:ool0HOoo0?gookgo0?l0oOoo08[oo`000?oooooo0000ohoo
0002o`0000Wooooo00Kog_l0ooooooooooooooooo`000?ooool2on_o00?ooooo0_l0ojh00oo2o`3o
ooooooooo`03olCo00Kooooo00?o0000ooooooooool04_ooool00ol0J?ooooooo`3go`04ooooo`03
o`1Foooooooooooo00Sooooo00?o<ol0ooooooooool02oooool00ol0003oooooooooo`0/ooooo`?o
000000?oooooo`3oCOooool0;?ooool00ol0ofCo<Ol0oc7o000@ooooo`03o`1Yoooooooooooo00So
oooo00GoO?l0oom20?ooooooooooocoo0003ooooo`;ooch000?o04Coooooooooool02_ooool00ol0
9oooooooooooo`05ooooo`03onko0?mBo`3oD_l000CoD_l000Ooe_l0oolY0?ooooooobT0ooooool0
oikoobT000;ooooo00GoeOl0oooooooDo`3ooooooh[o0006ooooo`Go000000Koaol0o`3oR?l0003o
_Ol0olOo0?l0ohP5o`000003o`_o0?o<o`3o0?n800;o0?nQ00Go0?mHo`1Mool0003o0000o`3oR005
o`000005o`1Qool0R_ooon80o`2:ool000003Oooool00ol0003oooooooooo`06ooooo`03omko0?o[
o`3ojol000Cooooo0_o2o`03ooooo`;o0?n^0_o4o`0=ooooo`03o`000?oooooooooo00Cooooo00?o
06Soooooool0mol00oooool00ol0E_ooooooooooo`09ooooo`03oc?o0?oooooooooo00_ooooo00?o
0000ooooooooool0GOooool004gooooo1?l0000=ooooo`03o`3oCOoooooooooo02[ooooo0_lao`00
0ol0ofCoooooooooo`0Gooooo`03ogco0?oooooooooo00;ooooo00?o?ol0ooooooooool01?ooool2
oom200Cooooo00?o04Coooln0?oo?P003?ooool00ol0003oooooooooo`02onko0003o`3on?oooooo
02Oo00Cooooo0_mBo`002_l0oikoD_l0oe;o0?mBo`3oobT0oh[o0?oo:@3ooooooolY0?oFo`02oooo
o`07omGo0?ooooooooooomGo0?ooooooe?l0o`000002ooooo`;o000000?o_Ol0o`3oR?l000001_l0
00001ol0oj7o_Ol0okgo0?l0003o0?mHo`1Moonmo`000_l000000oo<o`3o0000o`000003o`0000?o
oooo00Go08[oof?o0?nmo`3oon80o`2:o`04o`0000cooooo00Cog_l0oooooooooooo00000oooool2
on_o00?ooooo0_l0ojh01?o2o`3oooooooooooooool2olCo00Gooooo00?o0000ooooooooool04_oo
ool00ol0J?ooooooo`3go`04ooooo`03o`1Foooooooooooo00Sooooo00?o<ol0ooooooooool02_oo
ool00ol0003oooooooooo`0Xooooo`Co00000_ooool2o`3oCBgooooo00?o0?mToc7o0?ooool04?oo
ool00ol0JOooooooooooo`07ooooo`03oom20?mlo`3ooooo00;ooooo00?o?ol0ooooooooool00_oo
?P02ooooo`03o`14oooooooooooo00Wooooo00?o02Ooooooooooool01Oooool00oo^o`3o0?ohoooo
o`02ooooo`03o`000?oooooooooo00GoD_l000Co0?nNoe;o0?ooooooeOl00_ooool00ooDo`3ooooo
oh[o0009ooooo`Go000000?o_Ol0o`3oR?l0oj401_l00002okgo00;o000000Go_Ol0o`3oF?l0003o
0000o`2:o`04o`000006oi3o0?l0003o0000o`000?l0R_oo00003Oooool00ol0003oooooooooo`07
ooooo`03omko0?oooooojol000;ojol00oooool3ol;o00;ooooo0ol0ojh2olCo00_ooooo00?o0000
ooooooooool01?ooool00ol0J?oo0?Ooooooo`03ooooo`03o`1Foooooooooooo00Wooooo00?o<ol0
ooooooooool02_ooool00ol0003oooooooooo`1Mooooo`00B_ooool3o`0003gooooo00?o<Ol0oooo
ool0of@06Oooool00omlo`3oooooooooo`02ooooo`03ocoo0?oooooooooo00;ooooo0ooo@P05oooo
o`03ooln0?l0A?oooooo00kooooo00Ko0000onko0?ooooooooooo`3on?l09ol7ooooo`06o`3oW_oo
oooooooooolY0?mBo`3oR_l01OmBo`001?ooooooeOl0oooooooEo`02ooooo`04omCo0?oooooo0000
ooooo`?o00000_nmo`001?l0oj7o_Ol0o`000?l00002okgo0003o`3oXOl0oOoooooo00;o000000Go
0?mHo`000?l0R_oo_Ol0oonj0004o`000003o`29ool0oOoo0?go00Co000000Co0?goo`000?l0003o
00003oooool00ooNo`3oooooo`000005ooooo`;ojol00oooool2o`3o[P04ol;o0?oooooooooooooo
o`;oa?l01?ooool00ol0003oooooooooo`0Aooooo`04o`1XoooEo`3oooooo`3go`Cooooo00?o05Ko
ooooooooool02?ooool00olco`3oooooooooo`09ooooo`03o`000?oooooooooo02Gooooo0ol00005
ooooo`03o`3oCOoooooooooo02cooooo00?o0?mToc7o0?ooool04?ooool00ol0JOooooooooooo`05
ooooo`?ood8000GoO?l0ooooooooooooooooocoo0003ooln00?ooooo00?o04Coooooooooool02Ooo
ool00ol09ooo0000ooooo`04ooooo`;ok_l000ooooooo`3on?ooooooooooomOo0?oooooo0000omKo
0?oo:@3ooooooolY0?ooooooeOl0o`3oW_ooool01_mBo`000oooooooR_l0ooooo`08ooooo`Go0000
00?o_Ol0o`3oXOnmo`001?nmo`02o`3oX@Go000000Co0?mHoonj0?l02Ooo_Ol00_l00002o`3mo`Co
00003_ooool00ol0003oooooooooo`08ooooo`04omko0?ooooooooooooooo`;ojol01?ooool2ol;o
00?ooooo0_l0ojh2olCo00[ooooo00?o0000ooooooooool00oooool00ol0J?ooeOl0o`3go`04oooo
o`;o05Ko2_ooool00olco`3o0000ooooo`09ooooo`03o`000?oooooooooo05gooooo0017ooooo`?o
0000?oooool00olao`3o0?mTo`3oI00Iooooo`03ogco0?l0JOoooooo00;ooooo00Co?ol0oooooooo
oooooooo0_oo@P06ooooo`;ooch000?o04Coooooooooool03Oooool2onko0003o`000?oooooo0?oh
00;o00001oooool02ol0oikooooooooooooo:@3ooooooh[o0?ooooooobT0oooooooFo`3ooooo00Ko
D_l00oooool5o`000005o`3mool0oj7o9?l0o`1Mool;o`000_l0oj401ooooooo0?nQoonj0?oooooo
03?oo`3oF?l000000_oo^P02okgo00?o000000?o0?goo`2:ool0oj401?l000000ol0R_oo0000o`00
000@ooooo`03omko0?oooooo000000Oooooo0oo[o`02ooooo`;o0?n^00Co`_l0oooooooooooooooo
0_o4o`03ooooo`03o`000?oooooooooo017ooooo00?o06SoomGo0?l0mol01Oooool00ol0E_oooooo
ooooo`08ooooo`03oc?o0?l0003ooooo00Sooooo00?o0000ooooooooool08_ooool3o`0000Kooooo
0_l0odd^ooooo`03o`3oI?lao`3ooooo013ooooo00?o06Woooooooooool01?ooool2oom200;ooooo
00KoO?l0ooooooooooooooooooln0?loo`06ooooo`03o`14oooooooooooo00Wooooo0_l00004oooo
o`04onko0?ooooooooooo`3on0;ooooo00ooeol0ooooooooooooooooo`000?oo:@3oe_l0oolY0?oo
ooooeOl0o`3oW_ooooooeOl0oooooooDo`000oooool00omBo`3oR_l0oe;o0004oe;o00Gooooo00?o
0000okgo0?nmo`000ol00002o`1Mo`06o`_o0?l0oj7o0?nQoonj0?l0oj7ooooo0_l0ohP2o`000003
o`3oF?nmo`3o_Ol000;o000000Oo0?goo`2:ool0oOoo0000o`1Qool0R_oo000000kooooo00?o0000
ooooooooool02Oooool00ooNo`3oooooooooo`02ooooo`?ojol00oooool3ol;o00;ooooo0_l0ojh3
olCo00Sooooo00?o0000ooooooooool00oooool00ol0J?ooeOl0o`3go`05ooooo`03o`1Foooooooo
oooo00Oooooo00?o0000oc?o0?ooool02Oooool00ol0003oooooooooo`1Mooooo`00A?ooool3o`00
047ooooo00?o<Ol0o`3oI?ooool06Oooool00omlo`3o06Woooooo`02ooooo`03ocoo0?oooooooooo
00;ood801Oooool3ooln00;ooooo00?o04Coooooooooool03?ooool01_o^o`3ooooooooooooooooo
0000o`3on0Sooooo00Co0?nNooooooooooooobT00_ooool01?n:o`3ooooooolY0?oFo`02ooooo`03
omGo0?ooooooeOl000;ooooo00?oe?l0oe;o0?mBo`000_mBo`002_l0003oD_l0o`000?l0003o0?nQ
obCo0?o<o`3o2ol0o`3oXOooool2o`3mo`06o`3oXOl0oOoo0?n8o`3oR?o<o`3o0?mH0oo<o`03o`00
0009o`09ool0ROoo0000o`3moonmo`3o0000o`1Qool0oj7o08[o00;o00004Oooool00ooNo`3o0000
ooooo`09ooooo`;ojol00_ooool2o`3o[P;o`_l00_ooool3olCo0003ooooool0003ooooo01;ooooo
00?o06SoomGo0?l0mol01Oooool2o`1Fo`Sooooo00?o0000oc?o0?ooool02Oooool00ol0003ooooo
ooooo`0Mooooo`Co00002?ooool00ol0odgoooooooooo`0/ooooo`03o`3oI?lao`3o<Ol0017ooooo
00?o06Woooooooooool01?ooool00ooo@P3oooooooooo`02ooooo`05ogco0?oooooooch0ooln0?lo
o`001_ooool00ol0A?ooooooooooo`0>ooooo`;ok_l00oooool01?l0ooSooooooooooooGo`02oooo
o`09omKo0?oo:@3o0000omKo0?oo:@3oeOl0o`3oW_ooooooeOl000;ooooo00?oe?l0ooooooooool0
0_ooool00on:o`3oooooooooo`03ooooo`KoD_l01_l000001ol;o`3o0?nQo`3moooo^P3o0?n8o`3o
XOl0ohP00_oo^P03olco0009o`3oF?l0003o0000o`000?l0ROoo0?gooooR0?l0003o067o00;o0000
3_ooool00ol0003oooooooooo`0:ooooo`03omko0?oooooooooo00Cooooo0_o[o`04ooooo`;o`_l0
0_ooool3o`3o[P;oa?l01oooool00ol0003oooooooooo`03ooooo`03o`1Xool0mooooooo00Gooooo
00?o05Koooooooooool04_ooool00ol0003oooooooooo`1Mooooo`00@Oooool3o`0004;ooooo0_la
o`000ol0ofCoooooooooo`0Iooooo`03ogco0?oooooooooo00;ooooo00?o?ol0oooooooo@P001Ooo
ool2ooln00Gooooo00?o04Coooooooooool02_ooool2onko00Cooooo00?o0?oho`000?ooool01ooo
ool03?l0oikooooooooooooo:@3oooooomKo0?n:o`3ooooooolY0?oFo`3oooooomGo00;ooooo00Co
eOl0oooooooDo`3o00001Oooool3o`0000;o0?nQ00Wo2ol0ooooool0003o0000olco0?l0ohSo0?nQ
o`3mooo<o`000_oo^P001?l0oeSoooooo`000?l0<ol3o`000004o`09ool0ROoo_Ol0o`3mo`Ko0000
4oooool00ooNo`3oooooooooo`0:ooooo`;ojol00_ooool3o`3o[P04ol;o0?ooooooooooooooo`;o
a?l000?o0000ooooooooool04Oooool00ol0J?ooeOl0o`3go`06ooooo`03o`1Foooooooooooo017o
oooo00?o0000ooooooooool06_ooool3o`0000[ooooo0_l0odd^ooooo`03o`3oI?lao`3ooooo017o
oooo00?o06Woooooooooool02Oooool01Omlo`3ooch0ooln0?oooooo?ol000Oooooo00?o04Cooooo
ooooool03Oooool00oo^o`3oooooooooo`02ooooo`04o`3on?ooooooooooomOo00?ooooo00_oe_l0
oolY0?oFo`3o0000omGo0?oooooo0?nNoooooooEo`3o0000omCo0005ooooo`03oh[o0?oooooooooo
00?ooooo0_lco`05ooooo`;o00000_l0oj400ol;o`3o0000o`000002o`3oR005olco0?l0oj7o0?go
ooooool000001?l0<ol02Ol0oeSo0000o`2:ool0ROoo0?goo`3oQOl0003o02coo`00000?ooooo`03
o`000?oooooooooo00_ooooo00?og_l0ooooooooool01Oooool3on_o00?ooooo0_o2o`03ooooo`;o
0?n^0oo4o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000o`1Xool0mol01_ooool00ol0E_oo
ooooooooo`0Aooooo`03o`000?oooooooooo05gooooo000nooooo`?o0000A?ooool00olao`3ooooo
o`3oI00Kooooo`03ogco0?oooooooooo00;ooooo00?o?ol0ooooooooool01?ooool2ooln00Kooooo
00?o04Coooooooooool02Oooool2onko00Kooooo00?o0?ohooooool000001oooool02Ol0oikooooo
omOo0?oo:@3ooooooolY0?n:o`3oobT0omKo0002ooooo`03omGo0?l0003oeOl000;ooooo0_l00004
ooooo`08oc?o0?l0003o0000o`000?l0oj7o2ol0ooooool00003o`3oR003ooooool0003o0?nQ00;o
0?go0_ooool00ol0oeSo0?goooooo`02o`000004o`29ool02Ooo03?oo`29o`?o03?o00Co08[oo`0/
ool0003o00004oooool00ooNo`3oooooooooo`0<ooooo`;ojol00oooool2o`3o[P06ol;o0?oooooo
ooooooooool0003oa?l04_ooool00ol0J?ooooooo`3go`07ooooo`03o`1Foooooooooooo013ooooo
00?o0000ooooooooool05oooool3o`0000cooooo00?o0?m=ooooooooool0;Oooool00ol0ofCo<Ol0
ooooo`0Aooooo`03o`1Yoooooooooooo00Sooooo00?ooch0ogco0?ooool00_ooool00oloo`3ooooo
ooooo`05ooooo`03o`14oooooooooooo00cooooo0_o^o`05ooooo`04o`3on?ooooooooooomOo00;o
oooo00[oe_l0oolY0?oFo`3ooooooolY0?l0003oobT0o`3oW_oEo`3ooooo0_l00005ooooo`04oh[o
0?ooooooooooooooo`;o<ol01oooool2o`000003o`3oXOl0003o000000;o0?n800oo0000oonj0?oo
^P3o0000o`3oXOoooooo0?nQooooool0oOooooooo`000?l0oeSo0000o`0cool0ROl00_l0<ol2o`2:
o`03o`0/oooooooooooo00gooooo00?o0000ooooooooool03?ooool00ooNo`3oooooooooo`07oooo
o`;ojol00oooool3ol;o00;ooooo0_l0ojh00oooooooa?l0olCo0003ooooo`03o`000?oooooooooo
00?ooooo00?o06Soooooool0mol01_ooool00ol0E_ooooooooooo`0Aooooo`03o`000?oooooooooo
05cooooo000looooo`;o0000A_ooool00olao`3oooooo`3oI00Kooooo`03ogco0?oooooooooo00;o
oooo00?o?ol0ooooooooool00oooool2ooln00Sooooo00?o04Coooooooooool02?ooool00oo^o`3o
ooooooooo`05ooooo`04o`3on?ooooooooooooooo`;o00001Oooool03?l0oikooooooolY0?oooooo
e_l0oolY0?n:o`3oobT0omKo0?l0003oeOl0ooooo`;o00001_ooool2oc?o00?ooooo2_l000000ol0
oj7o0?goooooo`03o`3mo`09o`3oF?oooooo0000o`000?l0ROoo00Woooooool0ROoo_Ol000;ooooo
0_l000000ol0;?ooooooooooo`0Booooo`03o`000?oNo`3ooooo00kooooo0_o[o`03ooooo`;o0?n^
00Co`_l0oooooooooooo00000oo4o`0@ooooo`03o`1Xoooooooo0?Oo00Oooooo00?o05Kooooooooo
ool03oooool00ol0003oooooooooo`0Cooooo`Co00003_ooool00ol0odgoooooooooo`0]ooooo`;o
<Ol07Oooool00ooo?P3oO?l0ooooo`03ooooo`03ocoo0?oooooooooo00Gooooo00?o04Cooooooooo
ool02oooool00oo^o`3oooooooooo`04ooooo`04o`3on?ooooooooooomOo00;ooooo00Koe_l0oooo
oooo:@3oe_l0oolY0?oEo`02o`000003o`3oW_l0003ooooo00Oooooo00CoR_l0oc?o0?lco`3o<ol0
2oooool4o`000003ooooool0003o000000;o000000Ko0?nQo`3moooooooo0?goooooool0ROl2o`00
0006o`3oF?oooooo08Wookgo0?l0003o03?o0_l000000ol0;?ooooooooooo`0<ooooo`03o`000?oo
oooooooo00gooooo00?og_l0ooooooooool02?ooool2on_o00Cooooo0_o2o`02ooooo`?o0?n^0oo4
o`000ooooooo0000ooooo`04ooooo`03o`1Xool0mooooooo00Kooooo00?o05Koo`000?ooool04?oo
ool00ol0003oooooooooo`1Looooo`00Poooool00olao`3oooooo`3oI00Kooooo`03ogco0?oooooo
oooo00;ooooo00?o?ol0ooooooooool00oooool00ooo?P3oooooooooo`07ooooo`03o`14oooooooo
oooo00Oooooo0_o^o`08ooooo`03o`3on?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
2Ol0oikoeol0oolY0?ooooooe_l0oolY0?n:o`3oobT0ooooo`02o`0000Oooooo0_lco`08ooooo`?o
000000Koooooo`000?l0003oooooo`3oXOl0oOl3ooooo`03o`3mool0oeSo000000?o000000Go00Wo
o`3mool0ROoooooookgo0004o`000003o`0/oooooooooooo017ooooo00?o0000oooooooNo`004?oo
ool3on_o00;ooooo0_l0ojh00oo2o`3oooooo`000002ooooo`;oa?l03oooool00ol0J?ooooooo`3g
o`06ooooo`03o`000?l0E_oooooo00oooooo00?o0000ooooooooool04?ooool3o`00047ooooo00?o
<Ol0ooooooooool07Oooool00omlo`3oooooooooo`02ooooo`03ocoo0?oooooooooo00Gooooo00?o
04Coooooooooool02_ooool2onko00Oooooo00?o0?ohoooooooGo`000oooool01OoFo`3o0000oolY
0?ooooooobT000;o000000?oobT0o`3oW_ooool01oooool00olco`3oR_l0ooooo`0?ooooo`Go0000
00?oooooo`000?l0oj400ol0oOl02?oooooo0000o`000?oon`3o00Woo`3oF?l0ROoooooo0_nmo`02
o`000003ooooool0;?oooooo00cooooo00?o0000ooooooooool03_ooool00ooNo`3oooooooooo`09
ooooo`?ojol00oooool2ol;o00?ooooo0_l0ojh01?ooooooa?l0olCo0?l00004ooooo`03o`000?l0
J?oo0?Oo00Kooooo00?o0000o`1Fooooool04?ooool00ol0003oooooooooo`1Looooo`00POooool2
oc7o0003ooooool0ofCooooo01_ooooo00GoO?l0ooooooooooooooooocoo000@ooooo`03o`14oooo
oooooooo00Kooooo00?ok_l0ooooooooool01oooool00ol0ooSoooooooooo`05ooooo`0<o`000?oo
ooooooooooooool0oikoeol0oolY0?oFo`3oobT0oooooon:o`3o00002?ooool2oc?o00gooooo0ol0
00001_l0oj7o0000o`000?l0003oooooo`3mo`;ooooo00Go0?mHooooool0003o0000o`3mo`03o`00
0007ooooool0003o0000o`000?l0ok[oooooo`0/o`0Booooo`03o`000?oooooog_l001?ooooo0_o[
o`02ooooo`;o0?n^00?o`_l0o`000?ooool00_ooool2olCo00gooooo00Co0000o`1Xoooooooo0?Oo
1Oooool2o`00013ooooo00?o0000ooooooooool03?ooool4o`0004?ooooo00?o<Ol0ooooooooool0
7_ooool01Omlo`3ooooooooooooooooo?ol000Sooooo00?o04Coooooooooool02Oooool00oo^o`3o
ooooooooo`06ooooo`0Ao`3on?ooooooooooomOo0?oooooo0000omKo0?ooooooobT0o`000?oooooo
obT0oooooooo:@3oooooo`3oW_l000001?ooool3oc?o0003oooooon:o`3ooooo01;ooooo00Co0000
ooooool0003o0?nQ0ol000002Ooooooo0?goo`3mool0003o08Woo`3mool0oeSo0000ooooo`02o`00
0005ooooool0ok[oooooooooool0;?l03?ooool00ol0003oooooooooo`0?ooooo`03omko0?oooooo
oooo00_ooooo0_o[o`03ooooo`?o`_l00_ooool2o`3o[P03ooooool0003oa?l000?ooooo0_l00000
0ooooooo0?Ooooooo`0Gooooo`03o`000?oooooooooo05cooooo0020ooooo`04oc7o0?oooooo0?mT
o`3oI1cooooo00?oO?l0ooooooooool00_ooool00oloo`3oooooooooo`0=ooooo`03o`14oooooooo
oooo00Gooooo0_o^o`0:ooooo`03o`3on?oooooooooo00Kooooo00[o0000ooooool0oikoeol0oolY
0?oooooo0000oolY0?ooooooR_l01oooool2oc?o013ooooo00?o0000o`3oXOl000000ol000000ol0
oOooooooooooo`02o`000004o`3oF?l0oOoo0000o`29o`Ko00000_ooool00ol0ok[oooooo`0/o`0A
ooooo`04o`000?ooooooooooomko01Cooooo0_o[o`02ooooo`?o0?n^00Co`_l0oooooooooooooooo
0_o4o`0;ooooo`;o000000?oooooo`3gooooool05_ooool00ol0003oooooooooo`09ooooo`?o0000
AOooool00ol0ofCo<Ol0ooooo`0Oooooo`05ogco0?ooooooooooooooooloo`002?ooool00ol0A?oo
ooooooooo`08ooooo`;ok_l02Oooool01Ol0ooSoooooomOo0?l0003ooooo00;o000000CooooooolY
0?ooooooobT00_ooool01_oo:@3o0?nNoooooooooooo0000ooooo`;o<ol01?ooool00on:o`3ooooo
ooooo`0Booooo`04o`000?l0oj7o0000ooooo`;o000000Sooooooook0?l0003o0?goooooool0ROoo
0000o`3oF0?o00000_ooool01?l0ok[oooooooooool0;?l<ooooo`03o`000?oooooooooo00oooooo
0_l0000=ooooo`?ojol00oooool2ol;o00;ooooo0ol0ojh3olCo00?ooooo00?o0?Ooooooooooool0
5_ooool00ol0003oooooooooo`1Looooo`00Ooooool00olao`3oooooo`3oI00Mooooo`03ogco0?oo
oooooooo00;ooooo00?o?ol0ooooooooool03_ooool00ol0A?ooooooooooo`04ooooo`03onko0?oo
oooooooo00Wooooo00?o0?ohooooooooool02?ooool02Ol0003o0?nNo`000?oo:@3ooooooolY0?oo
ooooR_l0oolY0004ooooo`?o<ol04_ooool2o`000003ooooool0003o0?go00;o00000_ooool00ol0
003ooo/0o`3oF003o`000003o`09ool0003o000000Kooooo00?o0?njooooool0;?l04?ooool01?l0
003oooooooooooooool2o`0001Cooooo0_o[o`03ooooo`;o0?n^00Co`_l0oooooooooooooooo0oo4
o`0<ooooo`03o`3goooooooooooo01Cooooo00?o0000ooooooooool01_ooool3o`0004Oooooo0_la
o`0Pooooo`03ogco0?oooooooooo00;ooooo00?o?ol0ooooooooool01_ooool00ol0A?oooooooooo
o`07ooooo`03onko0?oooooooooo00Sooooo00?o0?ohooooooooool00_l00003ooooo`08oolY0?oo
oooooooooolY0?ooooooobT0ooooool0oih2ooooo`03o`000?lco`3ooooo00Gooooo00?oR_l0oooo
ooooool04_ooool3o`0000;o0?go00?oooooo`000?ooool01?l000000ol02Ooo0?mHooooo`05oooo
o`04o`3o^_ooooooooooo`0/o`_ooooo00?o0000ooooooooool03oooool2o`00013ooooo0_o[o`03
ooooo`?o`_l00_ooool2o`3o[P03ooooooo4o`3oa?l000;ooooo00?o0?Ooooooooooool05Oooool0
0ol0003oooooooooo`1Looooo`00O_ooool00olao`3oooooo`3oI00Mooooo`03ogco0?oooooooooo
00;ooooo00?o?ol0ooooooooool03oooool00ol0A?ooooooooooo`02ooooo`;ok_l03?ooool00ol0
ooSoooooooooo`09ooooo`07o`3oW_ooooooobT0oooooooo:@3ooooooh[o0003ooooo`;o<ol06?oo
ool3o`000003ooooool0003o000000?o000000Co0?mHo`000?l0003o00002?ooool01?l0ok[ooooo
ooooool0;?l?ooooo`04o`000?ooooooooooooooo`;o00005_ooool2on_o00;ooooo00Co0000o`3o
[_l0003o00001?ooool2olCo00_ooooo00?o0?Ooooooooooool04oooool00ol0003oooooooooo`04
ooooo`;o0000BOooool00olao`3oooooooooo`0Oooooo`03ogco0?oooooooooo00;ooooo00?o?ol0
ooooooooool01_ooool00ol0A?ooooooooooo`06ooooo`;ok_l02oooool00ol0ooSoooooooooo`05
ooooo`03oolY0?ooooooobT000;ooooo00?oobT0ooooool0oih00_lco`000ooooooo0000ooooo`05
ooooo`03oh[o0?oooooooooo01Cooooo0_l00002oook00?o000000Koooooo`000?l0003o0000oooo
ool0oeP6ooooo`04o`3o^_ooooooooooo`0/o`[ooooo00?o0000ooooooooool08oooool3on_o00?o
oooo0_o2o`000ooooooo0000o`000002ooooo`?oa?l000?o0?Ooooooooooool05?ooool00ol0003o
ooooooooo`1Looooo`00O?ooool2oc7o0003ooooool0ofCooooo01gooooo00GoO?l0oooooooooooo
ooooocoo000Aooooo`03o`14oooooooooooo00;ooooo00?ok_l0ooooooooool02oooool00ol0ooSo
ooooooooo`0:ooooo`08o`3oW_l0003ooooooooooooo:@3ooooooh[o0?ooool2oc?o01[ooooo0_l0
00000ooooooo0000o`000002o`0000;ooooo00?o0?mHo`3dooooool02_ooool01?l0ok[ooooooooo
ool0;?l>ooooo`03o`000?oooooooooo01_ooooo0oo[o`03o`0000;o`_l01?ooool2olCo00Wooooo
00?o0?Ooooooooooool04oooool00ol0003oooooooooo`1>ooooo`03oc7o0?oooooooooo023ooooo
00GoO?l0ooooooooooooooooocoo0009ooooo`03o`14oooooooooooo00Gooooo00?ok_l0oooooooo
ool02_ooool00ol0ooSoooooooooo`06ooooo`05oolY0?ooooooobT0oooooooo:@000_lco`000ol0
oikoooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?oR_l0ooooooooool05?ooool4o`00
00Cooooo00?o08Ooo`3dooooool00_ooool00ol0oeSoooooooooo`03ooooo`05o`3o^_oooooooooo
ooooool0;?l02Oooool00ol0003oooooooooo`0Vooooo`;ojol00oooool00oo2o`3o0000o`000005
ooooo`;oa?l05_ooool00ol0003oooooooooo`1Kooooo`00Noooool01?lao`3oooooooooool0of@N
ooooo`03ogco0?oooooooooo00;ooooo00?o?ol0ooooooooool03oooool00ol0A?ooooooooooo`02
onko00kooooo00?o0?ohooooooooool02_ooool01?l0oikoobT0o`000?oo:@02ooooo`03oh[o0?lc
o`3ooooo01gooooo0_oon`05ooooo`03o`000?l0oeSooooo00_ooooo00Co0?njoooooooooooo02co
3Oooool00ol0003oooooooooo`0Nooooo`03on_o0?l0003ooooo00;ooooo0_o2o`04ooooo`?oa?l0
1oooool00ol0moooooooooooo`0Booooo`03o`000?oooooooooo04cooooo0_lao`0Rooooo`05ogco
0?ooooooooooooooooloo`002Oooool00ol0A?ooooooooooo`04ooooo`;ok_l03?ooool00ol0ooSo
ooooooooo`06ooooo`03oolY0?ooooooobT000;o<ol000CoobT0oooooooooooo0?nN1Oooool00ol0
003oooooooooo`02ooooo`03oh[o0?oooooooooo01Cooooo00?ooo/0ooooooooool01Oooool2o`00
00?ooooo00?o0?mHooooooooool01?ooool01Ol0ok[ooooooooooooooooo02co00Sooooo00?o0000
ooooooooool0:?ooool3on_o00;ooooo00?o0000ol;o0?o2o`001?ooool01?l0moooa?l0olCo0?o4
o`0Cooooo`03o`000?oooooooooo05_ooooo001jooooo`04oc7o0?ooooooooooo`3oI1kooooo00?o
O?l0ooooooooool00_ooool00oloo`3oooooooooo`0?ooooo`04o`14ooooooooooooonko00oooooo
00?o0?ohooooooooool02oooool00ol0oikoobT0ooooo`02o`000003oolY0?n:o`3ooooo01gooooo
00?ooo/0ooooooooool01Oooool2o`000003o`3oF?oooooooooo00Wooooo00Go0?njoooooooooooo
ooooo`0/o`0<ooooo`03o`000?oooooooooo023ooooo00?o0000on_o0?ooool00_ooool2ol;o00Go
oooo0_o4o`05ooooo`03o`000?l0mooooooo01?ooooo00?o0000ooooooooool0B_ooool00olao`3o
0?mTooooo`0Qooooo`05ogco0?ooooooooooooooooloo`002_ooool00ol0A?ooooooooooo`03oooo
o`03onko0?oooooooooo00cooooo00?o0?ohooooooooool01_ooool00ooo:@3o<ol0oolY0002oooo
o`04oolY0?ooooooooooo`3oWPKooooo00Go0000oooooooooooooooooh[o000Dooooo`;ooo/02?oo
ool2o`0000Cooooo00?o0?mHooooooooool01?ooool01Ol0ok[ooooooooooooooooo02co00Oooooo
00?o0000ooooooooool0:oooool2on_o0003ooooool0003ooooo00;o`_l00_ooool00ol0003o0?Oo
ooooo`02o`0001;ooooo00?o0000ooooooooool0Foooool007Wooooo00Co<Ol0oooooooooooo0?mT
7_ooool00omlo`3oooooooooo`02ooooo`03ocoo0?oooooooooo013ooooo00?o04Coonko0?o^o`00
4?ooool00ol0ooSoooooooooo`0:ooooo`08o`3oW_oo:@3ooooooc?o0?oo:@3oooooo`000?n:o`0L
ooooo`;ooo/02Oooool00ol0Qooo0?mHooooo`0;ooooo`05o`3o^_ooooooooooooooool0;?l02ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?o[o`3ojol000?ooooo0oo2o`04ooooo`;o00000ooo
ool2o`0001Cooooo00?o0000ooooooooool0BOooool00olao`3o0?mTooooo`0Qooooo`03ogco0?oo
oooooooo00;ooooo00?o?ol0ooooooooool01oooool00ol0A?ooooooooooo`02ooooo`;ok_l03_oo
ool00ol0ooSoooooooooo`06ooooo`06oolY0?lco`3ooooooolY0?ooooooobT00_ooool00ol0oiko
ooooooooo`06ooooo`04o`000?oooooooooooh[o01?ooooo00?ooo/0ooooooooool02Oooool00ol0
Qoooooooooooo`03ooooo`03o`3oF?oooooooooo00Cooooo00Go0?njooooooooooooooooo`0/o`06
ooooo`03o`000?oooooooooo02gooooo0_o[o`000ol0003oooooooooo`02ol;o00?ooooo0_l0000B
ooooo`03o`000?oooooooooo05_ooooo001gooooo`;o<Ol00_ooool00ol0ofCoooooooooo`0Moooo
o`05ogco0?ooooooooooooooooloo`004_ooool2onko017ooooo00?o0?ohooooooooool02oooool0
1?l0oikoobT0oc?o0?oo:@02ooooo`03oolY0?n:o`3ooooo01[ooooo00?ooo/0ooooooooool02_oo
ool00ol0Qooo0?mHooooo`0;ooooo`05o`3o^_ooooooooooooooool0;?l02_ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00;ojol01?ooool2ol;o00;ooooo0_l0000Iooooo`03o`00
0?oooooooooo04Sooooo00?o<Ol0o`3oI?ooool08Oooool00omlo`3oooooooooo`02ooooo`03ocoo
0?oooooooooo00Sooooo00Go04Coooooooooooooooooonko000@ooooo`03o`3on?oooooooooo00?o
oooo0olco`000ooo:@3ooooooolY0002ooooo`04oolY0?ooooooooooo`3oWPWooooo00?o0000oooo
oon:o`004_ooool00ooon`3oooooooooo`0:ooooo`03o`27oooooooooooo00?ooooo00?o0?mHoooo
ooooool01Oooool01Ol0ok[ooooooooooooooooo02co00Gooooo00?o0000ooooooooool0;oooool0
0ol0003ojol0on_o0002ooooo`?o`_l00_l0000Booooo`03o`000?oooooooooo05_ooooo001foooo
o`03oc7o0?oooooooooo00;o0?mT7oooool00omlo`3oooooooooo`02ooooo`03ocoo0?oooooooooo
00oooooo00?ok_l0o`14ooooool04Oooool00ol0ooSoooooooooo`09ooooo`;o<ol000Oo0?nNoooo
ooooooooobT0oooooooo:@3ooooo00;o00006?ooool2oook00gooooo00?o08Ooo`3oF?ooool03?oo
ool01Ol0ok[ooooooooooooooooo02co00[ooooo00?o0000ooooooooool08Oooool01?l0003ooooo
ooooooooool3on_o00?ooooo00?o`_l0o`000?l000006_ooool00ol0003oooooooooo`16ooooo`;o
<Ol09?ooool01Omlo`3ooooooooooooooooo?ol000[ooooo00?o04Coooooooooool00_o^o`0@oooo
o`03o`3on?oooooooooo00;ooooo0_lco`02ooooo`06oolY0?oooooooooooolY0?ooooooobT00ooo
ool00ol0oikoooooooooo`08ooooo`;o00004Oooool00ooon`3oooooooooo`0;ooooo`03o`27oooo
oooooooo00Cooooo00?o0?mHooooooooool01?ooool00ol0ok[oooooooooo`02ooooo`03o`0/oooo
oooooooo00;ooooo00?o0000ooooooooool0<?ooool01?l0003oooooon_o0?o[o`03ooooo`;o0000
4_ooool00ol0003oooooooooo`1Kooooo`00MOooool01?lao`3oooooooooool0of@Pooooo`03ogco
0?oooooooooo00;ooooo00?o?ol0ooooooooool03_ooool2onko0003ooooool0A?oooooo013ooooo
00?o0?ohooooooooool02?ooool2oc?o00;ooooo00Oo0?nNooooooooooooobT0oooooooo:@3ooooo
00?o00005_ooool00ooon`3oooooooooo`0=ooooo`03o`27oooooooo0?mH00cooooo00?o0?njoooo
ooooool00_ooool00ol0;?ooooooooooo`07ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool00oooool2on_o00;ooooo0_l0000Jooooo`03o`000?oooooooooo04Gooooo00?o<Ol0o`3o
I?ooool08oooool01Omlo`3ooooooooooooooooo?ol000_ooooo00?o04Coonko0?o^o`004_ooool0
0ol0ooSoooooooooo`02oc?o00Cooooo00?oobT0oooooooo:@000_ooool01Ooo:@3ooooooooooooo
oooo0?nN00[ooooo0_l0000?ooooo`;ooo/03oooool00ol0Qoooooooooooo`03ooooo`03o`3oF?oo
oooooooo00Gooooo00?o0?njooooooooool00_ooool01Ol0;?oooooooooooooooooo000003?ooooo
00?o0000ooooooooool00oo[o`0Eooooo`03o`000?oooooooooo05[ooooo001cooooo`;o<Ol00_oo
ool00ol0ofCoooooooooo`0Nooooo`03ogco0?oooooooooo00;ooooo00?o?ol0ooooooooool03_oo
ool01?o^o`3oooooooooool0A?lBooooo`03o`3on?oooooooooo00Kooooo0_lco`04ooooo`03o`3o
W_ooooooobT000;ooooo00?oobT0ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`;ooo/0
4?ooool01?l0Qoooooooooooool0oeP<ooooo`05o`3o^_ooooooooooooooool0;?l02Oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo00Cooooo0_o[o`0Looooo`03o`000?oooooooooo
04Cooooo00?o<Ol0o`3oI?ooool08oooool00omlo`3oooooooooo`02ooooo`03ocoo0?oooooooooo
00Sooooo00?o04Coonko0?ooool04_ooool01?l0ooSo<ol0oc?o0?lco`06ooooo`03oolY0?oooooo
obT000;ooooo00GoobT0ooooooooooooooooo`3oWP0<ooooo`03o`000?oooooooooo00_ooooo00?o
oo/0ooooooooool03oooool00ol0Qoooooooooooo`04ooooo`03o`3oF?oooooooooo00Gooooo00?o
0?njooooooooool00_ooool01?l0;?ooooooooooool0000dooooo`04o`000?ooooooooooooooo`;o
00005?ooool00ol0003oooooooooo`1Jooooo`00L_ooool01Olao`3ooooooooooooooooo0?mT023o
oooo00?oO?l0ooooooooool00_ooool00oloo`3oooooooooo`0=ooooo`;ok_l00oooool00ol0A?oo
ooooooooo`0?ooooo`03o`3on?oooooooooo00Kooooo00?o<ol0o`000?ooool00oooool01_oo:@3o
0?nNoooooooo:@3ooooooolY00Kooooo00?o0000ooooooooool03oooool00ooon`3oooooooooo`0A
ooooo`03o`27oooooooo0?mH00gooooo00Go0?njooooooooooooooooo`0/o`08ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool01?ooool2o`0001_ooooo00?o0000ooooooooool0@_oo
ool2oc7o0003o`3oI?oooooooooo02;ooooo00?oO?l0ooooooooool00_ooool00oloo`3ooooooooo
o`08ooooo`;ok_l04oooool00ol0003o0?ohooooo`07ooooo`06oolY0?oooooooooooolY0?oooooo
obT01?ooool00ol0oikoooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?ooo/0oooooooo
ool04?ooool00ol0Qoooooooooooo`05ooooo`03o`3oF?oooooooooo00Gooooo00?o0?njoooooooo
ool00_ooool00ol0;?ooooooo`00000dooooo`04o`000?ooooooooooooooo`;o00005?ooool00ol0
003oooooooooo`1Jooooo`00LOooool01Olao`3ooooooooooooooooo0?mT027ooooo00?oO?l0oooo
ooooool00_ooool00oloo`3oooooooooo`0<ooooo`03onko0?oooooooooo00;ooooo00?o04Cooooo
ooooool04?ooool00ol0ooSoooooooooo`06ooooo`;o00001?ooool01_l0oikooooooooooooo:@3o
oooooolY00Oooooo00?o0000ooooooooool03?ooool2oook01Cooooo00Co08Oooooooooooooo0?mH
3Oooool01Ol0ok[ooooooooooooooooo02co00Oooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`03ooooo`;o00006oooool00ol0003oooooooooo`11ooooo`03oc7o0?oooooo0?mT02Go
oooo00GoO?l0ooooooooooooooooocoo000:ooooo`03onko0?l0A?oooooo01?ooooo00?o0?oho`00
0?ooool01oooool00ooo:@3ooooooolY0002ooooo`03oolY0?oooooooooo00;ooooo00?o0?nNoooo
ooooool03?ooool00ol0003oooooooooo`06ooooo`;ooo/04oooool00ol0Qoooooooooooo`05oooo
o`03o`3oF?oooooooooo00Kooooo00?o0?njooooooooool00_ooool00ol0;?oo0000ooooo`0doooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0F_ooool0073ooooo00Go<Ol0oooooooo
ooooooooo`3oI00Qooooo`03ogco0?oooooooooo00;ooooo00?o?ol0ooooooooool02oooool2onko
00Gooooo00?o04Coooooooooool03oooool00ol0ooSoooooooooo`0=ooooo`03o`3oW_ooooooobT0
00;ooooo00?oobT0ooooooooool01_ooool2o`0000_ooooo00?ooo/0ooooooooool05?ooool01Ol0
Qooooooooooooooooooo0?mH00cooooo00?o0?njooooooooool00_ooool00ol0;?ooooooooooo`04
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`10
ooooo`03oc7o0?l0ofCo0?mT02Gooooo00GoO?l0ooooooooooooooooocoo0009ooooo`;ok_l000?o
ooooo`14ooooool04oooool00ol0ooSoooooooooo`06ooooo`06oolY0?oooooooooooolY0?oooooo
obT01?ooool00ol0oikoooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?ooo/0oooooooo
ool05?ooool00ol0Qoooooooooooo`05ooooo`03o`3oF?oooooooooo00Gooooo00?o0?njoooooooo
ool00oooool00ol0;?oo0000ooooo`0dooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0F_ooool006kooooo0_lao`03ooooo`03o`3oI?oooooooooo01oooooo00?oO?l0ooooooooool0
0_ooool00oloo`3oooooooooo`0;ooooo`03onko0?oooooooooo00Gooooo00?o04Coooooooooool0
3oooool00ol0ooSoooooooooo`0<ooooo`06oolY0?l0oikooooooolY0?ooooooobT02oooool00ol0
003oooooooooo`06ooooo`;ooo/05oooool01Ol0Qooooooooooooooooooo0?mH00gooooo00?o0?nj
ooooooooool00_ooool00ol0;?ooooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03oc7o0?l0ofCooooo02Gooooo00?oO?l0
ooooooooool00_ooool00oloo`3oooooooooo`06ooooo`04onko0?ooooooooooo`14oaCooooo00?o
0?ohooooooooool01oooool00ooo:@3ooooooolY0002ooooo`03oolY0?oooooooooo00;ooooo00?o
0?nNooooooooool03oooool00ol0003oooooooooo`02ooooo`03oook0?oooooooooo01Gooooo00?o
08Ooooooooooool01_ooool00ol0oeSoooooooooo`05ooooo`03o`3o^_oooooooooo00?ooooo00?o
02coooooooooool0=?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05[ooooo001]
ooooo`03oc7o0?oooooooooo00;ooooo00?o0?mTooooooooool07oooool00omlo`3oooooooooo`02
ooooo`03ocoo0?oooooooooo00[ooooo0_o^o`07ooooo`03o`14oooooooooooo00oooooo00?o0?oh
ooooooooool03Oooool01_oo:@3o0?nNoooooooo:@3ooooooolY00cooooo00?o0000ooooooooool0
1?ooool00ooon`3oooooooooo`0Gooooo`03o`27oooooooooooo00;ooooo00?o0?mHooooooooool0
2oooool00ol0ok[oooooooooo`02ooooo`03o`0/oooooooooooo00;ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03gooooo0_lao`000ol0ofCooooo
ooooo`0Tooooo`03ogco0?oooooooooo00;ooooo00?o?ol0ooooooooool01Oooool2onko00;ooooo
00?o04Coooooooooool04oooool00ol0ooSoooooooooo`07ooooo`03oolY0?ooooooobT000;ooooo
00?oobT0ooooooooool00_ooool00ol0oikoooooooooo`0@ooooo`04o`000?oooooooooooook01So
oooo00?o08Ooooooooooool01_ooool00ol0oeSoooooooooo`06ooooo`03o`3o^_oooooooooo00;o
oooo00?o0000o`0/ooooool0=?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05[o
oooo001/ooooo`03oc7o0?oooooooooo02Gooooo00GoO?l0ooooooooooooooooocoo000<ooooo`03
onko0?oooooooooo00Oooooo00?o04Coooooooooool03oooool00ol0ooSoooooooooo`0=ooooo`03
oolY0?l0oikoobT000;ooooo00?oobT0ooooooooool02oooool00ol0003oooooooooo`02ooooo`03
oook0?oooooooooo01Wooooo00Go08Ooooooooooooooooooo`3oF00=ooooo`03o`3o^_oooooooooo
00?ooooo00Go02coooooooooooooooooo`00000[ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0>oooool00olao`3oooooo`3oI00Vooooo`03ogco0?oooooooooo00;ooooo00?o?ol0
ooooooooool01Oooool00oo^o`3oooooooooo`02ooooo`03o`14oooooooooooo01;ooooo00?o0?oh
ooooooooool01oooool01_oo:@3ooooooooooooo:@3ooooooolY00Gooooo00?o0?nNooooooooool0
4Oooool2oook01Wooooo00?o08Ooooooooooool01oooool00ol0oeSoooooooooo`06ooooo`07o`3o
^_ooooooooooooooool0003oooooo`0/o`0eooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0FOooool006_ooooo00?o<Ol0ooooooooool09Oooool00omlo`3oooooooooo`02ooooo`03
ocoo0?oooooooooo00Sooooo0_o^o`09ooooo`03o`14oooooooooooo00oooooo00?o0?ohoooooooo
ool03Oooool01_oo:@3oooooo`3oW_oo:@3ooooooolY00oooooo00Co0000oooooooon`3ooo/07?oo
ool00ol0Qoooooooooooo`02ooooo`03o`3oF?oooooooooo00_ooooo00?o0?njooooooooool00ooo
ool01?l0;?ooooooooooool0000/ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
>_ooool00olao`3oooooo`3oI00Wooooo`05ogco0?ooooooooooooooooloo`001_ooool2onko00Co
oooo00?o04Coooooooooool04_ooool00ol0ooSoooooooooo`08ooooo`03oolY0?ooooooobT000;o
oooo00?oobT0ooooooooool00oooool00ol0oikoooooooooo`0@ooooo`03oook0?oooooo000001[o
oooo00?o08Ooooooooooool01oooool00ol0oeSoooooooooo`06ooooo`04o`3o^_ooooooooooo`00
00;ooooo00?o02coooooooooool0<oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
05Wooooo001Yooooo`;o<Ol09oooool00omlo`3oooooooooo`02ooooo`03ocoo0?oooooooooo00So
oooo00?ok_l0ooooooooool02Oooool00ol0A?ooooooooooo`0?ooooo`03o`3on?oooooooooo00go
oooo00KoobT0o`3oW_ooooooobT0oooooooo:@0@ooooo`03o`000?oooooooooo01cooooo00?o08Oo
ooooooooool00oooool00ol0oeSoooooooooo`0;ooooo`03o`3o^_oooooooooo00?ooooo00?o02co
ooooool00000;Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03Sooooo0_lao`00
0ooooooo0?mTooooo`0Vooooo`03ogco0?oooooooooo00;ooooo00?o?ol0ooooooooool00oooool0
0oo^o`3oooooooooo`04ooooo`03o`14oooooooooooo01;ooooo00?o0?ohooooooooool01oooool0
1_oo:@3ooooooooooooo:@3ooooooolY00Kooooo00?o0?nNooooooooool03oooool01Ooon`3ooooo
oooooooooooo000001Wooooo00?o08Ooooooooooool01oooool00ol0oeSoooooooooo`06ooooo`04
o`3o^_ooooooooooo`0000?ooooo00?o02coooooooooool0<oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo05Wooooo001Xooooo`03oc7o0?oooooooooo02Gooooo0_l00004ooooo`03
ocoo0?oooooooooo00Oooooo0_o^o`0;ooooo`03o`14oooooooooooo00oooooo00?o0?ohoooooooo
ool03_ooool00ooo:@3o0?nNoolY0002ooooo`03oolY0?oooooooooo00cooooo0_oon`000ooooooo
0000ooooo`0Looooo`03o`27oooooooooooo00?ooooo00?o0?mHooooooooool03?ooool00ol0ok[o
ooooooooo`03ooooo`03o`0/ool0003ooooo02cooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0gooooo`04oc7o0?ooooooooooo`3oI2Oooooo00?oO?l0ooooooooool00_ooool00olo
o`3oooooooooo`02ooooo`;ok_l01_ooool00ol0A?ooooooooooo`0Booooo`03o`3on?oooooooooo
00Sooooo00?oobT0oooooooo:@000_ooool00ooo:@3oooooooooo`03ooooo`03o`3oW_oooooooooo
00kooooo0_oon`05ooooo`03o`000?oooooooooo01Kooooo00?o08Ooooooooooool02?ooool00ol0
oeSoooooooooo`06ooooo`03o`3o^_oooooo000000Cooooo00?o02coooooooooool0<oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo05Wooooo001Wooooo`03oc7o0?oooooooooo02Ko
oooo0_l00002ooooo`;o00002?ooool2onko00gooooo00?o04Coooooooooool03oooool00ol0ooSo
ooooooooo`0=ooooo`06oolY0?oooooo0?nNoolY0?ooooooobT03_ooool00ooon`3oooooooooo`02
ooooo`03o`000?oooooooooo01[ooooo00?o08Ooooooooooool01?ooool00ol0oeSoooooooooo`0;
ooooo`03o`3o^_oooooooooo00Cooooo00?o02coooooooooool0;?ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo03Kooooo00Co<Ol0oooooooooooo0?mT9oooool2o`0000?ooooo00?o
?ol0ooooooooool00_ooool00oo^o`3oooooooooo`06ooooo`03o`14oooooooooooo01;ooooo00?o
0?ohooooooooool01oooool01?oo:@3ooooooooooooo:@02ooooo`03oolY0?oooooooooo00?ooooo
00?o0?nNooooooooool03Oooool00ooon`3oooooooooo`06ooooo`03o`000?oooooooooo01Gooooo
00?o08Ooooooooooool02?ooool00ol0oeSoooooooooo`07ooooo`03o`3o^_l0003ooooo00Cooooo
00?o02coooooooooool0<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05Wooooo
001Vooooo`03oc7o0?oooooooooo02_ooooo0_l00007ooooo`03onko0?oooooooooo00gooooo00?o
04Coooooooooool03_ooool00ol0ooSoooooooooo`0>ooooo`06oolY0?oooooo0?nNoolY0?oooooo
obT03?ooool2oook00Kooooo00?o0000ooooooooool06_ooool00ol0Qoooooooooooo`04ooooo`03
o`3oF?oooooooooo00_ooooo00?o0?njooooooooool00oooool00ol0003o02coooooo`0]ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0=Oooool00olao`3oooooooooo`0Yooooo`;o
000000?oooooo`000?l000000oooool2onko00Sooooo00?o04Coooooooooool04_ooool00ol0ooSo
ooooooooo`08ooooo`03oolY0?ooooooobT000;ooooo00?oobT0ooooooooool01?ooool00ol0oiko
ooooooooo`0<ooooo`03oook0?oooooooooo00Sooooo00?o0000ooooooooool05Oooool00ol0Qooo
ooooooooo`08ooooo`03o`3oF?oooooooooo00Oooooo00?o0?njooooooooool01?ooool00ol0;?oo
ooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0FOooool006Gooooo
00?o<Ol0ooooooooool0<oooool2onko00oooooo00?o04Coooooooooool03_ooool00ol0ooSooooo
ooooo`0?ooooo`03oolY0?oooooo0?nN00;ooooo00?oobT0ooooooooool02Oooool00ooon`3ooooo
ooooo`07ooooo`;o00006_ooool2o`0000Gooooo00?o0?mHooooooooool03?ooool00ol0ok[ooooo
ooooo`02ooooo`03o`000?oooooo02co02kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0cooooo`;o<Ol0;oooool2o`0000;ooooo00?ok_l0ooooooooool02?ooool00ol0A?oooooo
ooooo`0Booooo`03o`3on?oooooooooo00Sooooo00?oobT0oooooooo:@000_ooool00ooo:@3ooooo
ooooo`04ooooo`03o`3oW_oooooooooo00_ooooo00?ooo/0ooooooooool02_ooool00ol0003ooooo
ooooo`0Dooooo`;o00002_ooool00ol0oeSoooooooooo`06ooooo`03o`000?l0ok[ooooo00Gooooo
00?o02coooooooooool0<_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Wooooo
002Jooooo`03onko0?oooooooooo00oooooo00?o04Coooooooooool03_ooool00ol0ooSooooooooo
o`0>ooooo`06oolY0?ooooooooooo`3oW_ooooooobT02_ooool2oook00cooooo00?o0000oooooooo
ool05oooool2o`0000Kooooo00?o0?mHooooooooool03?ooool01Ol0ok[ooooooooooooooooo0000
00;ooooo00?o02coooooooooool0;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
03;ooooo00?o<Ol0ooooooooool0<Oooool2onko00[ooooo00?o04Coooooooooool04_ooool00ol0
ooSoooooooooo`08ooooo`06oolY0?oooooooooooolY0?ooooooobT01oooool00ol0oikooooooooo
o`09ooooo`;ooo/03_ooool00ol0003oooooooooo`0Cooooo`;o00002_ooool00ol0oeSooooooooo
o`06ooooo`03o`000?l0ok[ooooo00Kooooo00?o02coooooooooool0<_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo05Sooooo002Hooooo`;ok_l04Oooool00ol0A?ooooooooooo`0>
ooooo`03o`3on?oooooooooo00oooooo00KoobT0ooooool0oikoobT0oooooooo:@09ooooo`03oook
0?oooooooooo00gooooo00?o0000ooooooooool07_ooool00ol0oeSoooooooooo`0<ooooo`05o`3o
^_ooooooooooooooool000000oooool00ol0;?ooooooooooo`0/ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0<Oooool00olao`3oooooooooo`0aooooo`03onko0?oooooooooo00[o
oooo00?o04Coooooooooool04_ooool00ol0ooSoooooooooo`08ooooo`03oolY0?ooooooobT000;o
oooo00?oobT0ooooooooool01Oooool00ol0oikoooooooooo`08ooooo`03oook0?oooooooooo00oo
oooo00?o0000ooooooooool07oooool00ol0oeSoooooooooo`05ooooo`03o`000?oooooo0?nj00Oo
oooo00?o02coooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05So
oooo002Gooooo`03onko0?oooooooooo017ooooo00?o04Coooooooooool03_ooool00ol0ooSooooo
ooooo`0>ooooo`04oolY0?ooooooooooo`3oWP;ooooo00?oobT0ooooooooool01Oooool2oook017o
oooo00?o0000ooooooooool07_ooool00ol0oeSoooooooooo`0<ooooo`04o`3o^_ooooooooooo`00
00?ooooo00?o02coooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
02oooooo0_lao`0booooo`;ok_l03?ooool00ol0A?ooooooooooo`0Booooo`03o`3on?oooooooooo
00Sooooo00CoobT0ooooooooooooobT00_ooool00ooo:@3oooooooooo`04ooooo`03o`3oW_oooooo
oooo00Sooooo00?ooo/0ooooooooool04Oooool00ol0003oooooooooo`0Oooooo`03o`3oF?oooooo
oooo00Cooooo00Co0000oooooooooooo0?nj1_ooool00ol0;?ooooooooooo`0booooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0F?ooool009Gooooo0_o^o`0Cooooo`03o`14oooooooo
oooo00kooooo00?o0?ohooooooooool03oooool01_oo:@3oooooooooool0oikooooooolY00Oooooo
00?ooo/0ooooooooool04_ooool00ol0003oooooooooo`0Nooooo`03o`3oF?oooooooooo00cooooo
00?o0?njooooool000001?ooool00ol0;?ooooooooooo`0]ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0;_ooool00olao`3oooooooooo`0aooooo`03onko0?oooooooooo00cooooo
00?o04Coooooooooool04_ooool00ol0ooSoooooooooo`08ooooo`03oolY0?ooooooobT000;ooooo
00?oobT0ooooooooool01Oooool00ol0oikoooooooooo`06ooooo`;ooo/05Oooool00ol0003ooooo
ooooo`0Nooooo`03o`3oF?oooooooooo00Gooooo00Co0000oooooooooooo0?nj1_ooool00ol0;?oo
ooooooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0F?ooool009Cooooo
00?ok_l0ooooooooool04oooool00ol0A?ooooooooooo`0>ooooo`03o`3on?oooooooooo00oooooo
00KoobT0oooooooooooo0?nNoooooooo:@05ooooo`;ooo/05_ooool00ol0003oooooooooo`0Moooo
o`03o`3oF?oooooooooo00cooooo00?o0?njooooool000001Oooool00ol0;?ooooooooooo`0]oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;?ooool00olao`3oooooooooo`0`oooo
o`;ok_l03_ooool00ol0A?ooooooooooo`0Booooo`03o`3on?oooooooooo00Wooooo00?oobT0oooo
oooo:@000_ooool00ooo:@3oooooooooo`05ooooo`03o`3oW_oooooooooo00Gooooo00?ooo/0oooo
ooooool05_ooool00ol0003oooooooooo`0Nooooo`03o`3oF?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`3o^P06ooooo`03o`0/oooooooooooo03;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`1Hooooo`00T_ooool2onko01Kooooo00?o04Coooooooooool03Oooool00ol0
ooSoooooooooo`0?ooooo`07oolY0?oooooooooooolY0?l0oikooooooolY0004ooooo`03oook0?oo
oooooooo01Oooooo00?o0000ooooooooool07Oooool00ol0oeSoooooooooo`0<ooooo`03o`3o^_l0
003ooooo00Gooooo00?o02coooooooooool0;Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo02_ooooo00?o<Ol0ooooooooool0<?ooool00oo^o`3oooooooooo`0>ooooo`03o`14oooo
oooooooo01;ooooo00?o0?ohooooooooool02?ooool01_oo:@3ooooooooooooo:@3ooooooolY00So
oooo00?o0?nNooooooooool01?ooool00ooon`3oooooooooo`0Hooooo`03o`000?oooooooooo01ko
oooo00?o0?mHooooooooool00oooool01Ol0003ooooooooooooooooo0?nj00Oooooo00?o02cooooo
ooooool0<Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Sooooo002Aooooo`03
onko0?oooooooooo01Gooooo00?o04Coooooooooool03_ooool00ol0ooSoooooooooo`0?ooooo`06
oolY0?oooooooooooolY0?l0oikoobT00oooool2oook01_ooooo00?o0000ooooooooool07Oooool0
0ol0oeSoooooooooo`0<ooooo`03o`3o^_oooooooooo00Gooooo00?o02coooooooooool0;Oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo02[ooooo00?o<Ol0ooooooooool0;oooool2
onko013ooooo00?o04Coooooooooool04_ooool00ol0ooSoooooooooo`09ooooo`03oolY0?oooooo
obT000;ooooo00?oobT0ooooooooool01_ooool00ol0oikoooooooooo`03ooooo`03oook0?oooooo
oooo01[ooooo00?o0000ooooooooool07Oooool00ol0oeSoooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0?njooooooooool01Oooool00ol0;?ooooooooooo`0aooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0F?ooool008oooooo0_o^o`0Hooooo`03o`14oooooooooooo
00gooooo00?o0?ohooooooooool04?ooool01_oo:@3oooooooooool0oikooooooolY00;ooooo00?o
oo/0ooooooooool07?ooool2o`0001gooooo00?o0?mHooooooooool03?ooool00ol0003o0?njoooo
o`06ooooo`03o`0/oooooooooooo02gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1Kooooo`03onko0?oooooooooo013ooooo00?o04Coooooooooool04Oooool00ol0ooSooooooooo
o`09ooooo`04oolY0?oooooooooooolY00;ooooo00?oobT0ooooooooool01_ooool01?l0oikooooo
ooooooooool2oook01kooooo00?o0000ooooooooool07Oooool00ol0oeSoooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0?njooooooooool01Oooool00ol0;?ooooooooooo`0aooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0Eoooool008gooooo0_o^o`0Iooooo`03o`14
oooooooooooo00kooooo00?o0?ohooooooooool03oooool01ooo:@3ooooooooooooo:@3o0?nNoooo
oooo:@000_oon`0Qooooo`03o`000?oooooooooo01_ooooo00?o0?mHooooooooool02oooool00ol0
003o0?njooooo`07ooooo`03o`0/oooooooooooo02cooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Iooooo`;ok_l04_ooool00ol0A?ooooooooooo`0Booooo`03o`3on?oooooooooo
00Wooooo00?oobT0oooooooo:@000_ooool00ooo:@3oooooooooo`06ooooo`05o`3oW_oooooooooo
oooooooon`008Oooool00ol0003oooooooooo`0Looooo`03o`3oF?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0ok[oooooooooo`05ooooo`03o`0/oooooooooooo037ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1Gooooo`00S?ooool00oo^o`3oooooooooo`0Ioooo
o`03o`14oooooooooooo00gooooo00?o0?ohooooooooool04?ooool01ooo:@3ooooooooooooo:@3o
0?nNoolY0?oon`009?ooool00ol0003oooooooooo`0Jooooo`03o`3oF?oooooooooo00_ooooo00?o
0000ooooool0okX02?ooool00ol0;?ooooooooooo`0/ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0F?ooool00oo^o`3oooooooooo`0Booooo`03o`14oooooooooooo017ooooo00?o
0?ohooooooooool02_ooool00ooo:@3ooooooolY0002ooooo`03oolY0?oooooooooo00Kooooo00Co
0?nNoooooooooooooo/08oooool00ol0003oooooooooo`0Looooo`05o`3oF?ooooooooooooooool0
00001oooool00ol0ok[oooooooooo`05ooooo`03o`0/oooooooooooo033ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Gooooo`00R_ooool2onko01_ooooo00?o04Coooooooooool0
3_ooool00ol0ooSoooooooooo`0@ooooo`05oolY0?oooooooooooolY0?l0oih00_l0000Uooooo`03
o`000?oooooooooo01[ooooo00?o0?mHo`000?ooool02_ooool01?l0003oooooooooool0okX8oooo
o`03o`0/oooooooooooo02cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Foooo
o`;ok_l05?ooool00ol0A?ooooooooooo`0Booooo`03o`3on?oooooooooo00Wooooo00KoobT0oooo
ooooooooobT0oooooooo:@09ooooo`03o`3oW_l0003o000002Gooooo00?o0000ooooooooool06ooo
ool01Ol0003o0?mHoooooooooooo000000Oooooo00?o0?njooooooooool01_ooool00ol0;?oooooo
ooooo`0`ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Eoooool008Wooooo00?o
k_l0ooooooooool06oooool00ol0A?ooooooooooo`0=ooooo`03o`3on?oooooooooo013ooooo00Ko
obT0ooooooooooooobT0ooooool0oih2o`0002Kooooo00?o0000ooooooooool06Oooool00ol0003o
0?mHooooo`0:ooooo`04o`000?ooooooooooo`3o^PWooooo00?o02coooooooooool0;?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo05Gooooo00?ok_l0ooooooooool05?ooool00ol0
A?ooooooooooo`0Aooooo`03o`3on?oooooooooo00[ooooo00?oobT0oooooooo:@000_ooool00ooo
:@3oooooooooo`07ooooo`03o`3oW_l0003o000002Kooooo00?o0000ooooooooool06_ooool2o`00
00;ooooo00?o0000ooooooooool01_ooool00ol0ok[oooooooooo`06ooooo`03o`0/oooooooooooo
033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Gooooo`00Qoooool2onko01ko
oooo00?o04Coooooooooool03Oooool00ol0ooSoooooooooo`0@ooooo`06oolY0?oooooooooooolY
0?oooooo0?nN:Oooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool0okX02Ooo
ool00ol0;?ooooooooooo`0/ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Dooo
ool2onko01Kooooo00?o04Coooooooooool04_ooool00ol0ooSoooooooooo`09ooooo`04oolY0?oo
oooooooooolY00;ooooo00?oobT0ooooooooool01oooool00ol0oikoooooooooo`0Wooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0ok[oooooooooo`06ooooo`03o`0/
oooooooooooo033ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Gooooo`00Q_oo
ool00oo^o`3oooooooooo`0Mooooo`03o`14oooooooooooo00gooooo00?o0?ohooooooooool04Ooo
ool01_oo:@3ooooooooooooo:@3o0?nNoolY02[ooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`02ooooo`03o`3o^_oooooooooo00Oooooo00?o02coooooooooool0;?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo05;ooooo00?ok_l0ooooooooool0:_ooool00ol0ooSo
ooooooooo`0:ooooo`03oolY0?ooooooobT000;ooooo00?oobT0ooooooooool02?ooool00ol0oiko
ooooooooo`0Wooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool00ol0ok[o
ooooooooo`06ooooo`03o`0/oooooooooooo02oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1Fooooo`00QOooool00oo^o`3oooooooooo`0^ooooo`03o`3on?oooooooooo013ooooo
00OoobT0ooooooooooooobT0ooooool0oikoobT002_ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`03ooooo`03o`3o^_oooooooooo00Oooooo00?o02coooooooooool0;?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo053ooooo0_o^o`0]ooooo`03o`3on?oooooooooo
00Wooooo00CoobT0ooooooooooooobT00_ooool00ooo:@3oooooooooo`07ooooo`03o`3oW_oooooo
oooo02Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`09ooooo`03o`3o^_oooooo
oooo00Kooooo00?o02coooooooooool0;oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05Kooooo002eooooo`03o`3on?oooooooooo017ooooo00KoobT0ooooooooooooobT0o`000?l0
oih]ooooo`;o00008oooool00ol0003oooooooooo`03ooooo`03o`3o^_oooooooooo00Sooooo00?o
02coooooooooool0;?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04kooooo00?o
k_l0ooooooooool0;?ooool00ol0ooSoooooooooo`0:ooooo`03oolY0?ooooooobT000;ooooo00?o
obT0ooooooooool01oooool00ol0003o0?nNooooo`0[ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool02Oooool00ol0ok[oooooooooo`07ooooo`03o`0/oooooooooooo02oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1Fooooo`00]Oooool00ol0ooSoooooooooo`0A
ooooo`04oolY0?oooooooooooolY00;o0000;oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00Cooooo00?o0?njooooooooool02?ooool00ol0;?ooooooooooo`0/ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0C?ooool2onko02oooooo00?o0?ohooooooooool02_oo
ool00ooo:@3ooooooolY0002ooooo`03oolY0?oooooooooo00Oooooo00?o0000o`3oW_ooool0;?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0?njooooooooool01ooo
ool00ol0;?ooooooooooo`0_ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_oo
ool00;Cooooo00?o0?ohooooooooool04Oooool01?oo:@3o0000o`000?oo:@02ooooo`03oolY0?oo
oooooooo02kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`05ooooo`03o`3o^_oo
oooooooo00Oooooo00?o02coooooooooool0;Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo04_ooooo00?ok_l0ooooooooool0;_ooool00ol0ooSoooooooooo`09ooooo`05o`000?oo
:@3ooooooooooooo:@000_ooool00ooo:@3oooooooooo`0gooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool02_ooool00ol0ok[oooooooooo`07ooooo`03o`0/oooooooooooo02kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Fooooo`00]?ooool00ol0ooSooooooooo
o`0Aooooo`Go000000?oobT0ooooooooool0<?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00Kooooo00?o0?njooooooooool01oooool00ol0;?ooooooooooo`0]ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0B_ooool00oo^o`3oooooooooo`0_ooooo`03o`3on?oo
oooooooo00Wooooo0_l000001OooooooobT0o`000?l0003oobT003_ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0;ooooo`03o`3o^_oooooooooo00Oooooo00?o02coooooooooool0
;_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Kooooo002cooooo`03o`3on?oo
oooooooo01Kooooo0_l0000cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_oo
ool00ol0ok[oooooooooo`08ooooo`03o`0/oooooooooooo02gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1kooooo`03o`3on?oooooooooo00gooooo1?l0000looooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool03?ooool00ol0ok[oooooooooo`07ooooo`03o`0/oooo
oooooooo02kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Fooooo`00/oooool0
0ol0ooSoooooooooo`1<ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool0
0ol0ok[oooooooooo`08ooooo`03o`0/oooooooooooo02cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1jooooo`03o`3on?oooooooooo04oooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0<ooooo`03o`3o^_oooooooooo00Sooooo00?o02coooooooooool0;_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Gooooo002booooo`03o`3on?oooooooooo
04kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`03o`3o^_oooooooooo
00Sooooo00?o02coooooooooool0;?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
07[ooooo00?o0?ohooooooooool0D?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00gooooo00?o0?njooooooooool02?ooool00ol0;?ooooooooooo`0^ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0EOooool00;;ooooo00?o0?ohooooooooool0Coooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo00?o0?njooooooooool02Oooool00ol0;?oo
ooooooooo`0/ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0NOooool00ol0ooSo
ooooooooo`1Booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03_ooool00ol0ok[o
ooooooooo`08ooooo`03o`0/oooooooooooo02gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Eooooo`00/Oooool00ol0ooSoooooooooo`1Aooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool02Oooool00ol0ok[oooooooooo`09ooooo`03o`0/oooooooooooo02cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`03o`3on?oooooooooo05?ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`03o`3o^_oooooooooo00Sooooo
00?o02coooooooooool0;Oooool01Ol0003ooooooooooooooooo000005Oooooo002aooooo`03o`3o
n?oooooooooo05;ooooo0_l0000Iooooo`03o`000?oooooooooo00[ooooo00?o0?njooooooooool0
2Oooool00ol0;?ooooooooooo`0/ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
N?ooool00ol0ooSoooooooooo`1Eooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
3oooool2o`0000[ooooo00?o02coooooooooool0;Oooool01?l0003oooooooooool0001Gooooo`00
/?ooool00ol0ooSoooooooooo`1Eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
2_ooool2o`0000_ooooo00?o02coooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo07Sooooo00?o0?ohooooooooool0E_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00oooooo0_l0000;ooooo`03o`0/oooooooooooo02gooooo00?o0000ooooool00000
Eoooool00;3ooooo00?o0?ohooooooooool0E_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00[ooooo0_l0000<ooooo`03o`0/oooooooooooo02cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1fooooo`03o`3on?oooooooooo05Sooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Mooooo`03o`0/oooooooooooo02cooooo00?o0000ooooool00000Eooo
ool00:oooooo00?o0?ohooooooooool0F?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01Wooooo00?o02coooooooooool0;?ooool01Ol0003ooooooooooooooooo000007Sooooo00?o
0?ohooooooooool0FOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01kooooo00?o
02coooooooooool0;?ooool00ol0003oooooo`00001Fooooo`00[oooool00ol0ooSoooooooooo`1I
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06Oooool00ol0;?ooooooooooo`0/
ooooo`04o`000?ooooooooooo`0007Oooooo00?o0?ohooooooooool0Foooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01oooooo00?o02coooooooooool0;?ooool2o`0005Kooooo002^
ooooo`03o`3on?oooooooooo05_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0J
ooooo`03o`0/oooooooooooo02cooooo00?o0000ooooool00000Moooool00ol0ooSoooooooooo`1L
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07oooool2o`0002_ooooo0ol0001F
ooooo`00[_ooool00ol0ooSoooooooooo`1Looooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool06oooool00ol0;?ooooooooooo`0/ooooo`;o0000M_ooool00ol0ooSoooooooooo`1Noooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool07oooool2o`0002Oooooo1?l0001Ioooo
o`00[Oooool00ol0ooSoooooooooo`1Nooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool07?ooool2o`0002_ooooo0ol0001fooooo`03o`3on?oooooooooo05oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`13ooooo`Go0000GOooool00:gooooo00?o0?ohooooooooool0
Goooool2o`00017ooooo00?o0000ooooooooool07?ooool2o`0002Kooooo1Ol0001hooooo`03o`3o
n?oooooooooo067ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0oooooo`Co0000
H_ooool00:cooooo00?o0?ohooooooooool0H_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo043ooooo1?l0001looooo`03o`3on?oooooooooo06?ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0kooooo`Co0000I_ooool00:cooooo00?o0?ohooooooooool0Hoooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03cooooo1?l00020ooooo`03o`3on?oooooo
oooo06Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0gooooo`Co0000J_ooool0
0:_ooooo00?o0?ohooooooooool0IOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
03Oooooo1Ol00023ooooo`03o`3on?oooooooooo06Kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0cooooo`Co0000K_ooool00:_ooooo00?o0?ohooooooooool0I_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03?ooooo1?l00028ooooo`03o`3on?oooooooooo06Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0^ooooo`Go0000L_ooool00:[ooooo
00?o0?ohooooooooool0J?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02oooooo
1?l0002;ooooo`03o`3on?oooooooooo06Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Zooooo`Co0000Moooool00:[ooooo00?o0?ohooooooooool0JOooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02[ooooo1Ol0002?ooooo`03o`3on?oooooooooo06[ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Vooooo`Co0000Noooool00:Wooooo00?o0?oh
ooooooooool0Joooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Kooooo1?l0002C
ooooo`03o`3on?oooooooooo06cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0R
ooooo`Co0000Ooooool00:Wooooo00?o0?ohooooooooool0K?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo02;ooooo1?l0002Gooooo`03o`3on?oooooooooo06gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Nooooo`Co0000Poooool00:Sooooo00?o0?ohoooooooo
ool0K_ooool2o`0000Oooooo00?o0000ooooooooool07Oooool5o`0009[ooooo00?o0?ohoooooooo
ool0Koooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo1Ol00027ooooo`00
Z?ooool00ol0ooSoooooooooo`1`ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
6Oooool4o`0009oooooo00?o0?ohooooooooool0L?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01Cooooo1?l0002<ooooo`00Yoooool00ol0ooSoooooooooo`1booooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool05Oooool4o`000:;ooooo00?o0?ohooooooooool0L_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo1?l0002@ooooo`00Yoooool0
0ol0ooSoooooooooo`1cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool5
o`000:Kooooo00?o0?ohooooooooool0Loooool01Ol0003ooooooooooooooooo000000kooooo1?l0
002Dooooo`00Y_ooool00ol0ooSoooooooooo`1eooooo`05o`000?ooooooooooooooool000003_oo
ool4o`000:[ooooo00?o0?ohooooooooool0MOooool01?l0003oooooooooool0000:ooooo`Co0000
V?ooool00:Kooooo00?o0?ohooooooooool0M_ooool01?l0003oooooooooool0000:ooooo`Co0000
[Oooool00ol0ooSoooooooooo`1gooooo`03o`000?oooooo000000Gooooo1Ol0002Looooo`00YOoo
ool00ol0ooSoooooooooo`1hooooo`03o`000?oooooo000000Gooooo1Ol0002aooooo`03o`3on?oo
oooooooo07Sooooo0_l000000ooooooo0000o`000002o`000:7ooooo002Sooooo`;o000000?o0?oh
ooooooooool0NOooool2o`000003ooooool0003o000000;o0000]Oooool00ol0ooSoooooooooo`1h
ooooo`Co0000YOooool00:?ooooo00?o0000o`3on?ooool0N_ooool4o`000;Wooooo00?o0?ohoooo
ooooool0M?ooool4o`000:Wooooo003ooooooacooooo1Ol0002looooo`03o`3on?l0003ooooo073o
oooo1Ol0002]ooooo`00oooooolHooooo`Co0000`Oooool2o`0006gooooo1?l0002booooo`00oooo
oolCooooo`Go0000oooooolaooooo`Co0000]_ooool00?oooooo3oooool4o`000?oooooo<_ooool4
o`000;[ooooo003oooooo`_ooooo1?l0003ooooooc7ooooo1Ol0002nooooo`00ooooool6ooooo`Go
0000oooooolaooooo`Co0000`oooool00?oooooo0_ooool4o`000?oooooo<_ooool4o`000<Oooooo
003looooo`Go0000oooooolbooooo`Co0000boooool00?Sooooo1?l0003ooooooc;ooooo1Ol0003?
ooooo`00loooool5o`000?oooooo<_ooool4o`000=Cooooo003_ooooo`Co0000oooooolcooooo`Co
0000f?ooool00>_ooooo1?l0003ooooooc?ooooo1?l0003Looooo`00i_ooool5o`000?oooooo<_oo
ool5o`000>3ooooo003Rooooo`Co0000oooooolcooooo`Co0000iOooool00=gooooo1Ol0003ooooo
oc?ooooo1?l0003Yooooo`00fOooool4o`000?oooooo=?ooool4o`000>gooooo003Dooooo`Go0000
oooooolcooooo`Go0000lOooool00=3ooooo1?l0003oooooocCooooo1?l0003fooooo`00c?ooool4
o`000?oooooo=?ooool4o`000?[ooooo0037ooooo`Go0000ooooooldooooo`Co0000o_ooool00<?o
oooo1?l0003oooooocCooooo1Ol0003oooooo`?ooooo002nooooo`Go0000ooooooldooooo`Co0000
ooooool8ooooo`00_?ooool2o`000?oooooo=oooool2o`000?oooooo3?ooool00?oooooooooooooo
ooooo`Cooooo003oooooooooooooooooool4ooooo`00oooooooooooooooooooo1?ooool00?oooooo
ooooooooooooo`Cooooo003oooooooooooooooooool4ooooo`00oooooooooooooooooooo1?ooool0
0?ooooooooooooooooooo`Cooooo003oooooooooooooooooool4ooooo`00oooooooooooooooooooo
1?ooool00?ooooooooooooooooooo`Cooooo003oooooooooooooooooool4ooooo`00oooooooooooo
oooooooo1?ooool00?ooooooooooooooooooo`Cooooo003oooooooooooooooooool4ooooo`00oooo
oooooooooooooooo1?ooool00?ooooooooooooooooooo`Cooooo003oooooooooooooooooool4oooo
o`00oooooooooooooooooooo1?ooool00?ooooooooooooooooooo`Cooooo003ooooooooooooooooo
ool4ooooo`00oooooooooooooooooooo1?ooool00?ooooooooooooooooooo`Cooooo003ooooooooo
ooooooooool4ooooo`00oooooooooooooooooooo1?ooool00?ooooooooooooooooooo`Cooooo003o
ooooooooooooooooool4ooooo`00oooooooooooooooooooo1?ooool00?ooooooooooooooooooo`Co
oooo003oooooooooooooooooool4ooooo`00oooooooooooooooooooo1?ooool00?oooooooooooooo
ooooo`Cooooo003oooooooooooooooooool4ooooo`00oooooooooooooooooooo1?ooool00?oooooo
ooooooooooooo`Cooooo003oooooooooooooooooool4ooooo`00oooooooooooooooooooo1?ooool0
0?ooooooooooooooooooo`Cooooo003oooooooooooooooooool4ooooo`00oooooooooooooooooooo
1?ooool00?ooooooooooooooooooo`Cooooo003oooooooooooooooooool4ooooo`00oooooooooooo
oooooooo1?ooool00?ooooooooooooooooooo`Cooooo003oooooooooooooooooool4ooooo`00oooo
oooooooooooooooo1?ooool00?ooooooooooooooooooo`Cooooo003oooooooooooooooooool4oooo
o`00oooooooooooooooooooo1?ooool00?ooooooooooooooooooo`Cooooo003ooooooooooooooooo
ool4ooooo`00oooooooooooooooooooo1?ooool00?ooooooooooooooooooo`Cooooo003ooooooooo
ooooooooool4ooooo`00\
\>"],
  ImageRangeCache->{{{0, 768.875}, {438.938, 0}} -> {-0.051017, -0.0285774, \
0.00273391, 0.00273391}, {{18.625, 436.688}, {428.438, 10.4375}} -> \
{-0.0446376, -0.0251249, 0.00239237, 0.00239237}, {{332.125, 750.188}, \
{428.438, 10.4375}} -> {-0.794645, -0.0251249, 0.00239237, 0.00239237}},
  CellTags->"Solitaire Diamond Example"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[sol,ColorView->Log[Intensity],CreateStereoView->Crossed,\
ViewPoint->{-3.384, -0.024, -0.026}, PlotType->Full3D, PlotRange->Automatic];\
\
\>", "Input",
  CellTags->"Solitaire Diamond Example"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .57143 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0136054 0.47619 [
[ 0 0 0 0 ]
[ 1 .57143 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .57143 L
0 .57143 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0136054 0.568027 0.557823 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.24072 .76247 m
.27427 .73649 L
s
.27427 .73649 m
.75307 .73956 L
s
.27368 .25984 m
.27427 .73649 L
s
0 0 0 r
2.5 Mabswid
.29159 .5838 Mdot
0 1 .846 r
.5 Mabswid
.34026 .49452 m
.29159 .5838 L
s
0 0 0 r
2.5 Mabswid
.27648 .42601 Mdot
.996 1 0 r
.5 Mabswid
.34584 .47362 m
.27648 .42601 L
s
0 0 0 r
2.5 Mabswid
.28119 .42502 Mdot
0 .892 1 r
.5 Mabswid
.37524 .44012 m
.28119 .42502 L
s
0 0 0 r
2.5 Mabswid
.28413 .42306 Mdot
1 .998 0 r
.5 Mabswid
.35202 .46908 m
.28413 .42306 L
s
0 0 0 r
2.5 Mabswid
.29182 .42013 Mdot
1 .991 0 r
.5 Mabswid
.35822 .46457 m
.29182 .42013 L
s
0 g
.27368 .25984 m
.24 .23648 L
s
.75339 .25677 m
.27368 .25984 L
s
0 0 0 r
2.5 Mabswid
.33576 .55699 Mdot
0 1 .968 r
.5 Mabswid
.3772 .54117 m
.33576 .55699 L
s
0 0 0 r
2.5 Mabswid
.33541 .55372 Mdot
0 .57 1 r
.5 Mabswid
.39271 .50039 m
.33541 .55372 L
s
0 0 0 r
2.5 Mabswid
.3378 .56206 Mdot
0 .559 1 r
.5 Mabswid
.3949 .50893 m
.3378 .56206 L
s
0 0 0 r
2.5 Mabswid
.34019 .57041 Mdot
0 .581 1 r
.5 Mabswid
.39709 .51746 m
.34019 .57041 L
s
0 0 0 r
2.5 Mabswid
.34269 .49054 Mdot
0 1 .735 r
.5 Mabswid
.3876 .47579 m
.34269 .49054 L
s
0 0 0 r
2.5 Mabswid
.35406 .54427 Mdot
0 1 .772 r
.5 Mabswid
.4557 .51879 m
.35406 .54427 L
s
0 0 0 r
2.5 Mabswid
.33268 .30821 Mdot
0 1 .44 r
.5 Mabswid
.41601 .44059 m
.33268 .30821 L
s
0 0 0 r
2.5 Mabswid
.33502 .29885 Mdot
0 1 .692 r
.5 Mabswid
.41922 .43298 m
.33502 .29885 L
s
0 0 0 r
2.5 Mabswid
.42535 .70226 Mdot
.769 1 0 r
.5 Mabswid
.40886 .60011 m
.42535 .70226 L
s
0 0 0 r
2.5 Mabswid
.42963 .71059 Mdot
.76 1 0 r
.5 Mabswid
.41276 .60651 m
.42963 .71059 L
s
0 0 0 r
2.5 Mabswid
.40462 .5342 Mdot
0 1 .846 r
.5 Mabswid
.4262 .54962 m
.40462 .5342 L
s
0 0 0 r
2.5 Mabswid
.43393 .71894 Mdot
.918 1 0 r
.5 Mabswid
.41667 .61293 m
.43393 .71894 L
s
0 0 0 r
2.5 Mabswid
.38215 .31728 Mdot
0 .244 1 r
.5 Mabswid
.48659 .43176 m
.38215 .31728 L
s
0 0 0 r
2.5 Mabswid
.44821 .52918 Mdot
.019 0 1 r
.5 Mabswid
.48011 .5118 m
.44821 .52918 L
s
0 0 0 r
2.5 Mabswid
.27239 .43142 Mdot
.989 1 0 r
.5 Mabswid
.33969 .47819 m
.27239 .43142 L
s
0 0 0 r
2.5 Mabswid
.49916 .73453 Mdot
0 1 .68 r
.5 Mabswid
.54712 .64423 m
.49916 .73453 L
s
0 0 0 r
2.5 Mabswid
.48126 .52104 Mdot
.243 1 0 r
.5 Mabswid
.39385 .55426 m
.48126 .52104 L
s
0 0 0 r
2.5 Mabswid
.48402 .51687 Mdot
.251 1 0 r
.5 Mabswid
.39838 .54946 m
.48402 .51687 L
s
0 0 0 r
2.5 Mabswid
.48675 .51271 Mdot
.282 1 0 r
.5 Mabswid
.40289 .54468 m
.48675 .51271 L
s
0 0 0 r
2.5 Mabswid
.48583 .49557 Mdot
0 .31 1 r
.5 Mabswid
.48678 .46109 m
.48583 .49557 L
s
0 0 0 r
2.5 Mabswid
.27199 .50931 Mdot
0 1 .704 r
.5 Mabswid
.43452 .56031 m
.27199 .50931 L
s
0 0 0 r
2.5 Mabswid
.42857 .25857 Mdot
0 .123 1 r
.5 Mabswid
.45104 .41528 m
.42857 .25857 L
s
0 0 0 r
2.5 Mabswid
.51283 .49904 Mdot
.235 1 0 r
.5 Mabswid
.60639 .45782 m
.51283 .49904 L
s
0 0 0 r
2.5 Mabswid
.51652 .49452 Mdot
.254 1 0 r
.5 Mabswid
.61051 .45306 m
.51652 .49452 L
s
0 0 0 r
2.5 Mabswid
.52005 .49005 Mdot
.266 1 0 r
.5 Mabswid
.61465 .44828 m
.52005 .49005 L
s
0 0 0 r
2.5 Mabswid
.49917 .34916 Mdot
0 1 .497 r
.5 Mabswid
.55246 .48781 m
.49917 .34916 L
s
0 0 0 r
2.5 Mabswid
.52346 .48563 Mdot
.317 1 0 r
.5 Mabswid
.6188 .44348 m
.52346 .48563 L
s
0 0 0 r
2.5 Mabswid
.51666 .2842 Mdot
0 1 .255 r
.5 Mabswid
.45971 .36554 m
.51666 .2842 L
s
0 0 0 r
2.5 Mabswid
.58346 .71784 Mdot
.713 1 0 r
.5 Mabswid
.59303 .60979 m
.58346 .71784 L
s
0 0 0 r
2.5 Mabswid
.58798 .70946 Mdot
.664 1 0 r
.5 Mabswid
.59729 .60338 m
.58798 .70946 L
s
0 0 0 r
2.5 Mabswid
.60871 .44579 Mdot
0 1 .989 r
.5 Mabswid
.58521 .45202 m
.60871 .44579 L
s
0 0 0 r
2.5 Mabswid
.67095 .57452 Mdot
0 .473 1 r
.5 Mabswid
.60877 .52062 m
.67095 .57452 L
s
0 0 0 r
2.5 Mabswid
.67344 .56615 Mdot
0 .521 1 r
.5 Mabswid
.61098 .51205 m
.67344 .56615 L
s
0 0 0 r
2.5 Mabswid
.6564 .37236 Mdot
.417 1 0 r
.5 Mabswid
.5025 .34429 m
.6564 .37236 L
s
0 0 0 r
2.5 Mabswid
.66727 .42066 Mdot
.595 1 0 r
.5 Mabswid
.56724 .49542 m
.66727 .42066 L
s
0 0 0 r
2.5 Mabswid
.67411 .40003 Mdot
0 .547 1 r
.5 Mabswid
.61145 .42477 m
.67411 .40003 L
s
0 0 0 r
2.5 Mabswid
.73569 .71956 Mdot
.599 1 0 r
.5 Mabswid
.66902 .51312 m
.73569 .71956 L
s
0 0 0 r
2.5 Mabswid
.67487 .28811 Mdot
0 1 .36 r
.5 Mabswid
.58598 .42559 m
.67487 .28811 L
s
0 0 0 r
2.5 Mabswid
.67728 .29763 Mdot
0 1 .37 r
.5 Mabswid
.58932 .43323 m
.67728 .29763 L
s
0 0 0 r
2.5 Mabswid
.67969 .30713 Mdot
0 .881 1 r
.5 Mabswid
.59265 .44085 m
.67969 .30713 L
s
0 0 0 r
2.5 Mabswid
.27012 .43816 Mdot
.983 1 0 r
.5 Mabswid
.33357 .4828 m
.27012 .43816 L
s
0 g
.75307 .73956 m
.76927 .76623 L
s
.75307 .73956 m
.75339 .25677 L
s
0 0 0 r
2.5 Mabswid
.73406 .4931 Mdot
0 .852 1 r
.5 Mabswid
.66934 .43519 m
.73406 .4931 L
s
0 0 0 r
2.5 Mabswid
.26994 .58463 Mdot
.201 1 0 r
.5 Mabswid
.4304 .51443 m
.26994 .58463 L
s
0 0 0 r
2.5 Mabswid
.74892 .42015 Mdot
1 .921 0 r
.5 Mabswid
.65967 .46808 m
.74892 .42015 L
s
0 0 0 r
2.5 Mabswid
.7493 .37301 Mdot
.265 1 0 r
.5 Mabswid
.58084 .4887 m
.7493 .37301 L
s
0 g
.76966 .23275 m
.75339 .25677 L
s
0 0 0 r
2.5 Mabswid
.75372 .42478 Mdot
.92 1 0 r
.5 Mabswid
.6653 .47276 m
.75372 .42478 L
s
0 0 0 r
2.5 Mabswid
.26785 .44498 Mdot
.903 1 0 r
.5 Mabswid
.32747 .48745 m
.26785 .44498 L
s
0 0 0 r
2.5 Mabswid
.64254 .2556 Mdot
.852 1 0 r
.5 Mabswid
.59682 .35131 m
.64254 .2556 L
s
0 0 0 r
2.5 Mabswid
.7544 .42268 Mdot
0 1 .91 r
.5 Mabswid
.64531 .43884 m
.7544 .42268 L
s
0 0 0 r
2.5 Mabswid
.26716 .59381 Mdot
0 .339 1 r
.5 Mabswid
.41929 .53521 m
.26716 .59381 L
s
0 0 0 r
2.5 Mabswid
.624 .74208 Mdot
0 .502 1 r
.5 Mabswid
.55864 .59931 m
.624 .74208 L
s
0 0 0 r
2.5 Mabswid
.75465 .41473 Mdot
.235 1 0 r
.5 Mabswid
.58467 .48411 m
.75465 .41473 L
s
0 0 0 r
2.5 Mabswid
.7547 .40137 Mdot
0 1 .874 r
.5 Mabswid
.64809 .43202 m
.7547 .40137 L
s
0 0 0 r
2.5 Mabswid
.75475 .43152 Mdot
.912 1 0 r
.5 Mabswid
.67091 .47749 m
.75475 .43152 L
s
0 g
.50883 .49864 m
.50934 .4974 L
s
.45535 .49891 m
.50883 .49864 L
s
.50934 .49985 m
.50883 .49861 L
s
.50883 .49861 m
.45538 .4989 L
s
.47097 .53666 m
.50934 .49985 L
s
.51056 .50034 m
.50932 .49983 L
s
.50932 .49983 m
.47098 .53663 L
s
.5088 .49863 m
.50931 .49739 L
s
.50931 .49986 m
.5088 .49863 L
s
.50932 .49742 m
.51056 .49691 L
s
.47093 .46115 m
.50932 .49742 L
s
.50934 .4974 m
.47096 .46116 L
s
.51055 .50037 m
.50931 .49986 L
s
.50931 .49739 m
.51054 .49688 L
s
.50868 .55235 m
.51056 .50034 L
s
.51177 .49983 m
.51054 .50034 L
s
.51054 .50034 m
.50867 .55232 L
s
.51178 .49986 m
.51055 .50037 L
s
.51054 .49691 m
.51177 .49742 L
s
.50865 .44545 m
.51054 .49691 L
s
.51056 .49691 m
.50866 .44548 L
s
.51054 .49688 m
.51178 .49739 L
s
.54646 .53674 m
.51177 .49983 L
s
.51226 .49861 m
.51175 .49985 L
s
.51175 .49985 m
.54643 .53672 L
s
.51175 .4974 m
.51226 .49864 L
s
.54645 .46108 m
.51175 .4974 L
s
.51177 .49742 m
.54644 .4611 L
s
.51229 .49863 m
.51178 .49986 L
s
.56213 .49891 m
.51226 .49861 L
s
.51226 .49864 m
.5621 .49892 L
s
.51178 .49739 m
.51229 .49863 L
s
1 .116 0 r
.50757 .49863 m
.51355 .49617 L
s
0 0 0 r
2.5 Mabswid
.50757 .49863 Mdot
1 .116 0 r
.5 Mabswid
.49476 .50026 m
.50757 .49863 L
s
.51394 .49863 m
.50665 .50165 L
s
0 0 0 r
2.5 Mabswid
.51394 .49863 Mdot
1 .116 0 r
.5 Mabswid
.50159 .50026 m
.51394 .49863 L
s
.51355 .49617 m
.56841 .47132 L
s
0 0 0 r
2.5 Mabswid
.51355 .49617 Mdot
.26574 .61009 Mdot
0 .968 1 r
.5 Mabswid
.42442 .46311 m
.26574 .61009 L
s
1 .116 0 r
.50665 .50165 m
.42791 .53239 L
s
0 0 0 r
2.5 Mabswid
.50665 .50165 Mdot
.75537 .39538 Mdot
0 1 .858 r
.5 Mabswid
.6506 .42513 m
.75537 .39538 L
s
1 .116 0 r
.5009 .49867 m
.52005 .49077 L
s
0 0 0 r
2.5 Mabswid
.5009 .49867 Mdot
1 .116 0 r
.5 Mabswid
.48794 .50026 m
.5009 .49867 L
s
.52007 .49867 m
.49932 .50729 L
s
0 0 0 r
2.5 Mabswid
.52007 .49867 Mdot
1 .116 0 r
.5 Mabswid
.50842 .50026 m
.52007 .49867 L
s
.806 1 0 r
.50134 .49322 m
.46834 .61681 L
s
0 0 0 r
2.5 Mabswid
.50134 .49322 Mdot
.806 1 0 r
.5 Mabswid
.52476 .49001 m
.50134 .49322 L
s
0 1 .832 r
.49862 .49647 m
.6081 .45159 L
s
0 0 0 r
2.5 Mabswid
.49862 .49647 Mdot
0 1 .832 r
.5 Mabswid
.54317 .54611 m
.49862 .49647 L
s
0 0 0 r
2.5 Mabswid
.26464 .37886 Mdot
0 .475 1 r
.5 Mabswid
.34356 .41087 m
.26464 .37886 L
s
1 .116 0 r
.49932 .50729 m
.42229 .53782 L
s
0 0 0 r
2.5 Mabswid
.49932 .50729 Mdot
1 .116 0 r
.5 Mabswid
.52005 .49077 m
.57406 .46588 L
s
0 0 0 r
2.5 Mabswid
.52005 .49077 Mdot
.75578 .43834 Mdot
.905 1 0 r
.5 Mabswid
.6765 .48227 m
.75578 .43834 L
s
.813 1 0 r
.52286 .50132 m
.51651 .44554 L
s
0 0 0 r
2.5 Mabswid
.52286 .50132 Mdot
.813 1 0 r
.5 Mabswid
.48622 .49579 m
.52286 .50132 L
s
1 .116 0 r
.49421 .4987 m
.52663 .48531 L
s
0 0 0 r
2.5 Mabswid
.49421 .4987 Mdot
1 .116 0 r
.5 Mabswid
.48112 .50026 m
.49421 .4987 L
s
0 0 0 r
2.5 Mabswid
.53439 .74426 Mdot
.871 1 0 r
.5 Mabswid
.40514 .59305 m
.53439 .74426 L
s
0 1 .67 r
.49543 .50624 m
.49939 .46159 L
s
0 0 0 r
2.5 Mabswid
.49543 .50624 Mdot
0 1 .67 r
.5 Mabswid
.53233 .54744 m
.49543 .50624 L
s
1 .116 0 r
.52622 .49871 m
.49189 .51299 L
s
0 0 0 r
2.5 Mabswid
.52622 .49871 Mdot
1 .116 0 r
.5 Mabswid
.51525 .50026 m
.52622 .49871 L
s
0 0 0 r
2.5 Mabswid
.26379 .36868 Mdot
0 .785 1 r
.5 Mabswid
.3473 .4072 m
.26379 .36868 L
s
0 0 0 r
2.5 Mabswid
.52476 .49001 Mdot
.806 1 0 r
.5 Mabswid
.61977 .51067 m
.52476 .49001 L
s
1 .116 0 r
.48751 .49874 m
.53329 .47978 L
s
0 0 0 r
2.5 Mabswid
.48751 .49874 Mdot
1 .116 0 r
.5 Mabswid
.47431 .50026 m
.48751 .49874 L
s
0 0 0 r
2.5 Mabswid
.2635 .59111 Mdot
0 .409 1 r
.5 Mabswid
.44018 .51693 m
.2635 .59111 L
s
1 .116 0 r
.49189 .51299 m
.41665 .54325 L
s
0 0 0 r
2.5 Mabswid
.49189 .51299 Mdot
0 .272 1 r
.5 Mabswid
.52457 .51486 m
.37876 .48085 L
s
0 0 0 r
2.5 Mabswid
.52457 .51486 Mdot
0 .272 1 r
.5 Mabswid
.53554 .43138 m
.52457 .51486 L
s
0 0 0 r
2.5 Mabswid
.48622 .49579 Mdot
.813 1 0 r
.5 Mabswid
.37828 .51364 m
.48622 .49579 L
s
1 .116 0 r
.52663 .48531 m
.57972 .46044 L
s
0 0 0 r
2.5 Mabswid
.52663 .48531 Mdot
1 .116 0 r
.5 Mabswid
.5324 .49874 m
.48438 .51875 L
s
0 0 0 r
2.5 Mabswid
.5324 .49874 Mdot
1 .116 0 r
.5 Mabswid
.52209 .50026 m
.5324 .49874 L
s
0 0 0 r
2.5 Mabswid
.26283 .57783 Mdot
.834 1 0 r
.5 Mabswid
.45431 .56218 m
.26283 .57783 L
s
1 .116 0 r
.48078 .49877 m
.54003 .47418 L
s
0 0 0 r
2.5 Mabswid
.48078 .49877 Mdot
1 .116 0 r
.5 Mabswid
.46749 .50026 m
.48078 .49877 L
s
0 0 0 r
2.5 Mabswid
.75675 .37487 Mdot
0 .918 1 r
.5 Mabswid
.65567 .41558 m
.75675 .37487 L
s
1 .116 0 r
.53859 .49878 m
.47678 .52459 L
s
0 0 0 r
2.5 Mabswid
.53859 .49878 Mdot
1 .116 0 r
.5 Mabswid
.52893 .50026 m
.53859 .49878 L
s
.48438 .51875 m
.41122 .54861 L
s
0 0 0 r
2.5 Mabswid
.48438 .51875 Mdot
.26207 .46985 Mdot
.16 0 1 r
.5 Mabswid
.36244 .50521 m
.26207 .46985 L
s
0 1 .003 r
.47574 .49666 m
.55118 .50261 L
s
0 0 0 r
2.5 Mabswid
.47574 .49666 Mdot
0 1 .003 r
.5 Mabswid
.42703 .55625 m
.47574 .49666 L
s
0 0 0 r
2.5 Mabswid
.48011 .5118 Mdot
0 .092 1 r
.5 Mabswid
.6081 .45159 m
.48011 .5118 L
s
1 .116 0 r
.47404 .49881 m
.54686 .46851 L
s
0 0 0 r
2.5 Mabswid
.47404 .49881 Mdot
1 .116 0 r
.5 Mabswid
.46068 .50026 m
.47404 .49881 L
s
0 1 .128 r
.47888 .48776 m
.55043 .49326 L
s
0 0 0 r
2.5 Mabswid
.47888 .48776 Mdot
0 1 .128 r
.5 Mabswid
.43051 .54657 m
.47888 .48776 L
s
0 .588 1 r
.47618 .49336 m
.50732 .39542 L
s
0 0 0 r
2.5 Mabswid
.47618 .49336 Mdot
0 .588 1 r
.5 Mabswid
.51584 .54324 m
.47618 .49336 L
s
.018 0 1 r
.48868 .52517 m
.47842 .56254 L
s
0 0 0 r
2.5 Mabswid
.48868 .52517 Mdot
.018 0 1 r
.5 Mabswid
.50953 .46348 m
.48868 .52517 L
s
1 .116 0 r
.53329 .47978 m
.58538 .45499 L
s
0 0 0 r
2.5 Mabswid
.53329 .47978 Mdot
.50953 .46348 Mdot
.018 0 1 r
.5 Mabswid
.49923 .42606 m
.50953 .46348 L
s
1 .116 0 r
.54481 .49881 m
.46909 .5305 L
s
0 0 0 r
2.5 Mabswid
.54481 .49881 Mdot
1 .116 0 r
.5 Mabswid
.53577 .50026 m
.54481 .49881 L
s
0 1 .284 r
.50514 .46255 m
.55664 .50458 L
s
0 0 0 r
2.5 Mabswid
.50514 .46255 Mdot
0 1 .284 r
.5 Mabswid
.39697 .50349 m
.50514 .46255 L
s
1 .116 0 r
.46728 .49885 m
.55377 .46276 L
s
0 0 0 r
2.5 Mabswid
.46728 .49885 Mdot
1 .116 0 r
.5 Mabswid
.45388 .50026 m
.46728 .49885 L
s
0 0 0 r
2.5 Mabswid
.54151 .51232 Mdot
0 .627 1 r
.5 Mabswid
.36879 .50137 m
.54151 .51232 L
s
1 .094 0 r
.47267 .51312 m
.43268 .47583 L
s
0 0 0 r
2.5 Mabswid
.47267 .51312 Mdot
1 .094 0 r
.5 Mabswid
.56254 .49891 m
.47267 .51312 L
s
1 .116 0 r
.47678 .52459 m
.40669 .55359 L
s
0 0 0 r
2.5 Mabswid
.47678 .52459 Mdot
0 1 .67 r
.5 Mabswid
.49939 .46159 m
.53599 .33318 L
s
0 0 0 r
2.5 Mabswid
.49939 .46159 Mdot
1 .116 0 r
.5 Mabswid
.54003 .47418 m
.5906 .44975 L
s
0 0 0 r
2.5 Mabswid
.54003 .47418 Mdot
1 .098 0 r
.5 Mabswid
.54455 .51277 m
.5639 .4729 L
s
0 0 0 r
2.5 Mabswid
.54455 .51277 Mdot
1 .098 0 r
.5 Mabswid
.45453 .49891 m
.54455 .51277 L
s
0 .739 1 r
.48384 .5344 m
.45185 .44594 L
s
0 0 0 r
2.5 Mabswid
.48384 .5344 Mdot
0 .739 1 r
.5 Mabswid
.62261 .56047 m
.48384 .5344 L
s
0 0 0 r
2.5 Mabswid
.75769 .4292 Mdot
.103 1 0 r
.5 Mabswid
.55901 .44172 m
.75769 .4292 L
s
1 .116 0 r
.55106 .49885 m
.4613 .53648 L
s
0 0 0 r
2.5 Mabswid
.55106 .49885 Mdot
1 .116 0 r
.5 Mabswid
.54262 .50027 m
.55106 .49885 L
s
0 1 .063 r
.52113 .53844 m
.45284 .48316 L
s
0 0 0 r
2.5 Mabswid
.52113 .53844 Mdot
0 1 .063 r
.5 Mabswid
.60633 .49998 m
.52113 .53844 L
s
1 .116 0 r
.4605 .49888 m
.5606 .45702 L
s
0 0 0 r
2.5 Mabswid
.4605 .49888 Mdot
1 .116 0 r
.5 Mabswid
.44707 .50026 m
.4605 .49888 L
s
0 .149 1 r
.48678 .46109 m
.54341 .67758 L
s
0 0 0 r
2.5 Mabswid
.48678 .46109 Mdot
0 1 .943 r
.5 Mabswid
.52005 .51537 m
.48678 .46109 L
s
0 0 0 r
2.5 Mabswid
.75781 .37712 Mdot
0 .42 1 r
.5 Mabswid
.66254 .41571 m
.75781 .37712 L
s
0 1 .003 r
.55118 .50261 m
.61469 .46423 L
s
0 0 0 r
2.5 Mabswid
.55118 .50261 Mdot
0 1 .128 r
.5 Mabswid
.55043 .49326 m
.62261 .56047 L
s
0 0 0 r
2.5 Mabswid
.55043 .49326 Mdot
.51584 .54324 Mdot
0 .588 1 r
.5 Mabswid
.58319 .58043 m
.51584 .54324 L
s
.88 1 0 r
.47598 .46332 m
.61749 .60168 L
s
0 0 0 r
2.5 Mabswid
.47598 .46332 Mdot
.88 1 0 r
.5 Mabswid
.41122 .54861 m
.47598 .46332 L
s
1 .094 0 r
.46534 .51573 m
.4258 .48014 L
s
0 0 0 r
2.5 Mabswid
.46534 .51573 Mdot
1 .094 0 r
.5 Mabswid
.57122 .49897 m
.46534 .51573 L
s
.865 1 0 r
.47032 .46983 m
.55095 .46282 L
s
0 0 0 r
2.5 Mabswid
.47032 .46983 Mdot
.865 1 0 r
.5 Mabswid
.40669 .55359 m
.47032 .46983 L
s
1 .116 0 r
.46909 .5305 m
.40238 .55847 L
s
0 0 0 r
2.5 Mabswid
.46909 .5305 Mdot
0 g
.5 Mabswid
.32949 .42772 m
.45535 .49891 L
s
.32953 .42772 m
.45542 .49892 L
s
.45542 .49892 m
.31537 .49975 L
s
.31537 .49972 m
.45542 .4989 L
s
.45542 .4989 m
.32968 .57171 L
s
.45538 .4989 m
.32963 .57171 L
s
.32963 .57171 m
.47097 .53666 L
s
.37028 .6328 m
.47101 .5366 L
s
.47101 .5366 m
.4312 .67387 L
s
.32967 .57168 m
.47102 .53662 L
s
.47102 .53662 m
.3703 .63282 L
s
.47098 .53663 m
.43116 .67391 L
s
0 0 0 r
2.5 Mabswid
.45453 .49891 Mdot
1 .098 0 r
.5 Mabswid
.39962 .50024 m
.45453 .49891 L
s
.865 1 0 r
.54152 .53471 m
.38875 .39921 L
s
0 0 0 r
2.5 Mabswid
.54152 .53471 Mdot
.865 1 0 r
.5 Mabswid
.5906 .44975 m
.54152 .53471 L
s
0 0 0 r
2.5 Mabswid
.55246 .48781 Mdot
0 1 .599 r
.5 Mabswid
.46834 .61681 m
.55246 .48781 L
s
.514 1 0 r
.53375 .45999 m
.56479 .67434 L
s
0 0 0 r
2.5 Mabswid
.53375 .45999 Mdot
.514 1 0 r
.5 Mabswid
.39237 .50279 m
.53375 .45999 L
s
0 g
.43095 .32533 m
.47093 .46115 L
s
.43098 .32537 m
.47097 .46121 L
s
.47097 .46121 m
.37006 .36653 L
s
0 .932 1 r
.54824 .52184 m
.50488 .61805 L
s
0 0 0 r
2.5 Mabswid
.54824 .52184 Mdot
0 .932 1 r
.5 Mabswid
.48458 .44277 m
.54824 .52184 L
s
0 g
.37008 .36651 m
.47099 .46119 L
s
.47099 .46119 m
.32952 .42775 L
s
.47096 .46116 m
.32949 .42772 L
s
1 .116 0 r
.45369 .49892 m
.56942 .52237 L
s
0 0 0 r
2.5 Mabswid
.45369 .49892 Mdot
1 .116 0 r
.5 Mabswid
.44027 .50026 m
.45369 .49892 L
s
1 .115 0 r
.55732 .49888 m
.45384 .54235 L
s
0 0 0 r
2.5 Mabswid
.55732 .49888 Mdot
1 .115 0 r
.5 Mabswid
.54947 .50027 m
.55732 .49888 L
s
1 .097 0 r
.55113 .51531 m
.57073 .47718 L
s
0 0 0 r
2.5 Mabswid
.55113 .51531 Mdot
1 .097 0 r
.5 Mabswid
.44513 .49897 m
.55113 .51531 L
s
.89 1 0 r
.5471 .52823 m
.46749 .53609 L
s
0 0 0 r
2.5 Mabswid
.5471 .52823 Mdot
.89 1 0 r
.5 Mabswid
.59547 .44468 m
.5471 .52823 L
s
.142 1 0 r
.55642 .49418 m
.4748 .5785 L
s
0 0 0 r
2.5 Mabswid
.55642 .49418 Mdot
.142 1 0 r
.5 Mabswid
.4923 .43052 m
.55642 .49418 L
s
0 g
.43116 .67391 m
.50868 .55235 L
s
.50321 .68857 m
.50867 .55228 L
s
.50867 .55228 m
.57555 .67454 L
s
.43117 .67386 m
.50869 .55228 L
s
.50869 .55228 m
.50324 .68857 L
s
.50867 .55232 m
.57555 .67459 L
s
0 1 .284 r
.55664 .50458 m
.58319 .58043 L
s
0 0 0 r
2.5 Mabswid
.55664 .50458 Mdot
.06 1 0 r
.5 Mabswid
.45225 .49735 m
.46866 .36511 L
s
0 0 0 r
2.5 Mabswid
.45225 .49735 Mdot
.06 1 0 r
.5 Mabswid
.50377 .56317 m
.45225 .49735 L
s
1 .116 0 r
.54686 .46851 m
.59547 .44468 L
s
0 0 0 r
2.5 Mabswid
.54686 .46851 Mdot
.89 1 0 r
.5 Mabswid
.46749 .53609 m
.39697 .50349 L
s
0 0 0 r
2.5 Mabswid
.46749 .53609 Mdot
0 g
.5 Mabswid
.57554 .32466 m
.50865 .44545 L
s
.57554 .32471 m
.50864 .44552 L
s
.50864 .44552 m
.50309 .31063 L
s
.50312 .31063 m
.50866 .44552 L
s
.50866 .44552 m
.43096 .32538 L
s
.50866 .44548 m
.43095 .32533 L
s
1 .094 0 r
.45791 .51836 m
.41889 .48447 L
s
0 0 0 r
2.5 Mabswid
.45791 .51836 Mdot
1 .094 0 r
.5 Mabswid
.57997 .49903 m
.45791 .51836 L
s
0 0 0 r
2.5 Mabswid
.3044 .74849 Mdot
0 .175 1 r
.5 Mabswid
.39566 .63271 m
.3044 .74849 L
s
0 g
.57555 .67459 m
.54646 .53674 L
s
.63706 .63378 m
.5464 .53669 L
s
.5464 .53669 m
.67833 .57237 L
s
.57552 .67455 m
.54642 .53668 L
s
.54642 .53668 m
.63708 .63377 L
s
.54643 .53672 m
.67837 .5724 L
s
.67839 .42709 m
.54639 .46112 L
s
.54639 .46112 m
.63712 .36557 L
s
.67842 .42706 m
.54645 .46108 L
s
.63714 .36559 m
.54641 .46113 L
s
.54641 .46113 m
.57551 .3247 L
s
.54644 .4611 m
.57554 .32466 L
s
.69286 .49977 m
.56206 .49892 L
s
.56206 .49892 m
.67838 .42706 L
s
.67832 .5724 m
.56206 .4989 L
s
.56206 .4989 m
.69286 .49974 L
s
.67837 .5724 m
.56213 .49891 L
s
.5621 .49892 m
.67842 .42706 L
s
0 0 0 r
2.5 Mabswid
.4557 .51879 Mdot
0 1 .766 r
.5 Mabswid
.61469 .46423 m
.4557 .51879 L
s
0 0 0 r
2.5 Mabswid
.75855 .35774 Mdot
0 .016 1 r
.5 Mabswid
.67804 .43288 m
.75855 .35774 L
s
0 0 0 r
2.5 Mabswid
.56254 .49891 Mdot
1 .094 0 r
.5 Mabswid
.59764 .50026 m
.56254 .49891 L
s
.371 1 0 r
.53656 .45521 m
.605 .5755 L
s
0 0 0 r
2.5 Mabswid
.53656 .45521 Mdot
.371 1 0 r
.5 Mabswid
.34501 .45715 m
.53656 .45521 L
s
.514 1 0 r
.53824 .45584 m
.5695 .66796 L
s
0 0 0 r
2.5 Mabswid
.53824 .45584 Mdot
.514 1 0 r
.5 Mabswid
.39866 .49794 m
.53824 .45584 L
s
1 .116 0 r
.44683 .49896 m
.57754 .52551 L
s
0 0 0 r
2.5 Mabswid
.44683 .49896 Mdot
1 .116 0 r
.5 Mabswid
.43346 .50026 m
.44683 .49896 L
s
0 1 .063 r
.45284 .48316 m
.41004 .41312 L
s
0 0 0 r
2.5 Mabswid
.45284 .48316 Mdot
1 .115 0 r
.5 Mabswid
.5636 .49892 m
.4444 .52316 L
s
0 0 0 r
2.5 Mabswid
.5636 .49892 Mdot
1 .115 0 r
.5 Mabswid
.55633 .50027 m
.5636 .49892 L
s
1 .116 0 r
.4613 .53648 m
.3984 .56319 L
s
0 0 0 r
2.5 Mabswid
.4613 .53648 Mdot
.53233 .54744 Mdot
0 1 .67 r
.5 Mabswid
.6211 .63166 m
.53233 .54744 L
s
1 .728 0 r
.47543 .45105 m
.43015 .65725 L
s
0 0 0 r
2.5 Mabswid
.47543 .45105 Mdot
1 .728 0 r
.5 Mabswid
.5981 .49462 m
.47543 .45105 L
s
0 1 .394 r
.51341 .44183 m
.56349 .53635 L
s
0 0 0 r
2.5 Mabswid
.51341 .44183 Mdot
0 1 .394 r
.5 Mabswid
.36882 .3792 m
.51341 .44183 L
s
1 .097 0 r
.55779 .51788 m
.57757 .48148 L
s
0 0 0 r
2.5 Mabswid
.55779 .51788 Mdot
1 .097 0 r
.5 Mabswid
.43567 .49902 m
.55779 .51788 L
s
0 0 0 r
2.5 Mabswid
.44513 .49897 Mdot
1 .097 0 r
.5 Mabswid
.39303 .50022 m
.44513 .49897 L
s
.865 1 0 r
.55095 .46282 m
.60633 .49998 L
s
0 0 0 r
2.5 Mabswid
.55095 .46282 Mdot
.142 1 0 r
.5 Mabswid
.5609 .48725 m
.41155 .4121 L
s
0 0 0 r
2.5 Mabswid
.5609 .48725 Mdot
.142 1 0 r
.5 Mabswid
.45939 .66649 m
.5609 .48725 L
s
0 .538 1 r
.46822 .45069 m
.38629 .63711 L
s
0 0 0 r
2.5 Mabswid
.46822 .45069 Mdot
0 .538 1 r
.5 Mabswid
.62763 .48454 m
.46822 .45069 L
s
1 .093 0 r
.45041 .52103 m
.41197 .4888 L
s
0 0 0 r
2.5 Mabswid
.45041 .52103 Mdot
1 .093 0 r
.5 Mabswid
.58879 .49908 m
.45041 .52103 L
s
0 0 0 r
2.5 Mabswid
.54317 .54611 Mdot
0 1 .832 r
.5 Mabswid
.6297 .62774 m
.54317 .54611 L
s
1 .116 0 r
.55377 .46276 m
.60003 .43978 L
s
0 0 0 r
2.5 Mabswid
.55377 .46276 Mdot
0 1 .749 r
.5 Mabswid
.56724 .49542 m
.44016 .5262 L
s
0 0 0 r
2.5 Mabswid
.56724 .49542 Mdot
.746 1 0 r
.5 Mabswid
.40386 .58619 m
.56724 .49542 L
s
.435 1 0 r
.5406 .45015 m
.61636 .5825 L
s
0 0 0 r
2.5 Mabswid
.5406 .45015 Mdot
.435 1 0 r
.5 Mabswid
.35179 .45191 m
.5406 .45015 L
s
0 0 0 r
2.5 Mabswid
.48458 .44277 Mdot
0 .932 1 r
.5 Mabswid
.41004 .41312 m
.48458 .44277 L
s
1 .116 0 r
.43995 .499 m
.58576 .52868 L
s
0 0 0 r
2.5 Mabswid
.43995 .499 Mdot
1 .116 0 r
.5 Mabswid
.42667 .50026 m
.43995 .499 L
s
0 0 0 r
2.5 Mabswid
.50377 .56317 Mdot
.06 1 0 r
.5 Mabswid
.63413 .62432 m
.50377 .56317 L
s
0 .542 1 r
.45067 .46908 m
.36355 .62271 L
s
0 0 0 r
2.5 Mabswid
.45067 .46908 Mdot
0 .542 1 r
.5 Mabswid
.50193 .4314 m
.45067 .46908 L
s
1 .115 0 r
.56989 .49896 m
.43539 .52636 L
s
0 0 0 r
2.5 Mabswid
.56989 .49896 Mdot
1 .115 0 r
.5 Mabswid
.56319 .50027 m
.56989 .49896 L
s
0 0 0 r
2.5 Mabswid
.57122 .49897 Mdot
1 .094 0 r
.5 Mabswid
.60474 .50024 m
.57122 .49897 L
s
1 .115 0 r
.45384 .54235 m
.38784 .54513 L
s
0 0 0 r
2.5 Mabswid
.45384 .54235 Mdot
1 .097 0 r
.5 Mabswid
.56452 .52048 m
.58444 .48578 L
s
0 0 0 r
2.5 Mabswid
.56452 .52048 Mdot
1 .097 0 r
.5 Mabswid
.42615 .49908 m
.56452 .52048 L
s
0 0 0 r
2.5 Mabswid
.75928 .40905 Mdot
.152 0 1 r
.5 Mabswid
.57907 .48138 m
.75928 .40905 L
s
1 .115 0 r
.4444 .52316 m
.37828 .51364 L
s
0 0 0 r
2.5 Mabswid
.4444 .52316 Mdot
.43567 .49902 Mdot
1 .097 0 r
.5 Mabswid
.38644 .5002 m
.43567 .49902 L
s
0 0 0 r
2.5 Mabswid
.44018 .51693 Mdot
0 .595 1 r
.5 Mabswid
.62772 .43658 m
.44018 .51693 L
s
0 0 0 r
2.5 Mabswid
.50193 .4314 Mdot
0 .542 1 r
.5 Mabswid
.56168 .41477 m
.50193 .4314 L
s
1 .093 0 r
.44281 .52372 m
.40504 .49314 L
s
0 0 0 r
2.5 Mabswid
.44281 .52372 Mdot
1 .093 0 r
.5 Mabswid
.59768 .49914 m
.44281 .52372 L
s
1 .886 0 r
.47015 .44133 m
.37192 .59324 L
s
0 0 0 r
2.5 Mabswid
.47015 .44133 Mdot
1 .886 0 r
.5 Mabswid
.6441 .44309 m
.47015 .44133 L
s
.699 1 0 r
.54466 .44506 m
.62792 .58963 L
s
0 0 0 r
2.5 Mabswid
.54466 .44506 Mdot
.699 1 0 r
.5 Mabswid
.35861 .44666 m
.54466 .44506 L
s
1 .116 0 r
.43305 .49904 m
.59409 .53189 L
s
0 0 0 r
2.5 Mabswid
.43305 .49904 Mdot
1 .116 0 r
.5 Mabswid
.41987 .50026 m
.43305 .49904 L
s
.2 0 1 r
.47613 .56229 m
.57825 .61178 L
s
0 0 0 r
2.5 Mabswid
.47613 .56229 Mdot
.2 0 1 r
.5 Mabswid
.43722 .5201 m
.47613 .56229 L
s
1 .116 0 r
.5606 .45702 m
.61174 .4588 L
s
0 0 0 r
2.5 Mabswid
.5606 .45702 Mdot
0 1 .394 r
.5 Mabswid
.56349 .53635 m
.55073 .65499 L
s
0 0 0 r
2.5 Mabswid
.56349 .53635 Mdot
1 .115 0 r
.5 Mabswid
.57621 .499 m
.42628 .52959 L
s
0 0 0 r
2.5 Mabswid
.57621 .499 Mdot
1 .115 0 r
.5 Mabswid
.57006 .50027 m
.57621 .499 L
s
0 0 0 r
2.5 Mabswid
.43722 .5201 Mdot
.2 0 1 r
.5 Mabswid
.41621 .48303 m
.43722 .5201 L
s
1 .116 0 r
.56942 .52237 m
.61977 .51067 L
s
0 0 0 r
2.5 Mabswid
.56942 .52237 Mdot
.48659 .43176 Mdot
0 .702 1 r
.5 Mabswid
.57564 .58366 m
.48659 .43176 L
s
.803 1 0 r
.51397 .42765 m
.61028 .57094 L
s
0 0 0 r
2.5 Mabswid
.51397 .42765 Mdot
.803 1 0 r
.5 Mabswid
.35567 .53504 m
.51397 .42765 L
s
0 .739 1 r
.45185 .44594 m
.4486 .33666 L
s
0 0 0 r
2.5 Mabswid
.45185 .44594 Mdot
1 .096 0 r
.5 Mabswid
.57134 .52311 m
.59133 .4901 L
s
0 0 0 r
2.5 Mabswid
.57134 .52311 Mdot
1 .096 0 r
.5 Mabswid
.41657 .49914 m
.57134 .52311 L
s
0 0 0 r
2.5 Mabswid
.75985 .4125 Mdot
.149 0 1 r
.5 Mabswid
.58599 .48204 m
.75985 .4125 L
s
0 1 .871 r
.4304 .51443 m
.50286 .48201 L
s
0 0 0 r
2.5 Mabswid
.4304 .51443 Mdot
.303 1 0 r
.5 Mabswid
.60003 .43978 m
.4304 .51443 L
s
1 .115 0 r
.43539 .52636 m
.37356 .51795 L
s
0 0 0 r
2.5 Mabswid
.43539 .52636 Mdot
1 .092 0 r
.5 Mabswid
.43513 .52645 m
.39866 .49794 L
s
0 0 0 r
2.5 Mabswid
.43513 .52645 Mdot
1 .092 0 r
.5 Mabswid
.60665 .4992 m
.43513 .52645 L
s
0 0 0 r
2.5 Mabswid
.57997 .49903 Mdot
1 .094 0 r
.5 Mabswid
.61184 .50022 m
.57997 .49903 L
s
0 0 0 r
2.5 Mabswid
.42615 .49908 Mdot
1 .097 0 r
.5 Mabswid
.37985 .50018 m
.42615 .49908 L
s
1 .116 0 r
.42612 .49908 m
.60252 .53515 L
s
0 0 0 r
2.5 Mabswid
.42612 .49908 Mdot
1 .116 0 r
.5 Mabswid
.41307 .50026 m
.42612 .49908 L
s
1 .886 0 r
.49641 .42373 m
.38741 .55916 L
s
0 0 0 r
2.5 Mabswid
.49641 .42373 Mdot
1 .886 0 r
.5 Mabswid
.64538 .53246 m
.49641 .42373 L
s
0 .884 1 r
.44249 .45165 m
.49848 .3705 L
s
0 0 0 r
2.5 Mabswid
.44249 .45165 Mdot
0 .884 1 r
.5 Mabswid
.50242 .6117 m
.44249 .45165 L
s
0 0 0 r
2.5 Mabswid
.53554 .43138 Mdot
0 .272 1 r
.5 Mabswid
.53599 .33318 m
.53554 .43138 L
s
0 .149 1 r
.4561 .43749 m
.42152 .58786 L
s
0 0 0 r
2.5 Mabswid
.4561 .43749 Mdot
0 .149 1 r
.5 Mabswid
.63456 .50192 m
.4561 .43749 L
s
.806 1 0 r
.51844 .42342 m
.61269 .56227 L
s
0 0 0 r
2.5 Mabswid
.51844 .42342 Mdot
.806 1 0 r
.5 Mabswid
.36011 .5308 m
.51844 .42342 L
s
1 .115 0 r
.58255 .49904 m
.41705 .53287 L
s
0 0 0 r
2.5 Mabswid
.58255 .49904 Mdot
1 .115 0 r
.5 Mabswid
.57693 .50027 m
.58255 .49904 L
s
0 1 .592 r
.58084 .4887 m
.46093 .48103 L
s
0 0 0 r
2.5 Mabswid
.58084 .4887 Mdot
.406 1 0 r
.5 Mabswid
.3984 .56319 m
.58084 .4887 L
s
0 1 .145 r
.45431 .56218 m
.44796 .44302 L
s
0 0 0 r
2.5 Mabswid
.45431 .56218 Mdot
1 .99 0 r
.5 Mabswid
.61174 .4588 m
.45431 .56218 L
s
0 0 0 r
2.5 Mabswid
.57907 .48138 Mdot
0 .042 1 r
.5 Mabswid
.37618 .56314 m
.57907 .48138 L
s
0 .538 1 r
.47257 .42768 m
.40876 .47393 L
s
0 0 0 r
2.5 Mabswid
.47257 .42768 Mdot
0 .538 1 r
.5 Mabswid
.57234 .40596 m
.47257 .42768 L
s
0 1 .595 r
.55901 .44172 m
.54858 .57253 L
s
0 0 0 r
2.5 Mabswid
.55901 .44172 Mdot
.282 1 0 r
.5 Mabswid
.38784 .54513 m
.55901 .44172 L
s
1 .116 0 r
.57754 .52551 m
.62538 .51497 L
s
0 0 0 r
2.5 Mabswid
.57754 .52551 Mdot
0 1 .049 r
.5 Mabswid
.56116 .55724 m
.67568 .76265 L
s
0 1 .124 r
.56116 .55724 m
.52005 .51537 L
s
0 0 0 r
2.5 Mabswid
.56116 .55724 Mdot
.514 1 0 r
.5 Mabswid
.42812 .35267 m
.56116 .55724 L
s
.857 1 0 r
.49155 .41949 m
.43642 .53913 L
s
0 0 0 r
2.5 Mabswid
.49155 .41949 Mdot
.857 1 0 r
.5 Mabswid
.64042 .52812 m
.49155 .41949 L
s
1 .096 0 r
.57823 .52577 m
.5981 .49462 L
s
0 0 0 r
2.5 Mabswid
.57823 .52577 Mdot
1 .096 0 r
.5 Mabswid
.40692 .49919 m
.57823 .52577 L
s
1 .116 0 r
.41918 .49912 m
.61106 .53844 L
s
0 0 0 r
2.5 Mabswid
.41918 .49912 Mdot
1 .116 0 r
.5 Mabswid
.40628 .50026 m
.41918 .49912 L
s
0 .989 1 r
.54757 .56724 m
.62002 .49003 L
s
0 0 0 r
2.5 Mabswid
.54757 .56724 Mdot
0 .989 1 r
.5 Mabswid
.35027 .60366 m
.54757 .56724 L
s
1 .092 0 r
.42736 .52921 m
.39237 .50279 L
s
0 0 0 r
2.5 Mabswid
.42736 .52921 Mdot
1 .092 0 r
.5 Mabswid
.61569 .49926 m
.42736 .52921 L
s
0 .989 1 r
.43155 .46 m
.40714 .5492 L
s
0 0 0 r
2.5 Mabswid
.43155 .46 Mdot
0 .989 1 r
.5 Mabswid
.46384 .41131 m
.43155 .46 L
s
1 .115 0 r
.42628 .52959 m
.36905 .52226 L
s
0 0 0 r
2.5 Mabswid
.42628 .52959 Mdot
.81 1 0 r
.5 Mabswid
.52293 .41916 m
.61509 .55361 L
s
0 0 0 r
2.5 Mabswid
.52293 .41916 Mdot
.81 1 0 r
.5 Mabswid
.36456 .52654 m
.52293 .41916 L
s
0 0 0 r
2.5 Mabswid
.76053 .57264 Mdot
0 .407 1 r
.5 Mabswid
.63775 .55176 m
.76053 .57264 L
s
0 1 .699 r
.58467 .48411 m
.49364 .52118 L
s
0 0 0 r
2.5 Mabswid
.58467 .48411 Mdot
.4 1 0 r
.5 Mabswid
.40238 .55847 m
.58467 .48411 L
s
0 0 0 r
2.5 Mabswid
.34545 .75204 Mdot
0 1 .727 r
.5 Mabswid
.37379 .62866 m
.34545 .75204 L
s
0 0 0 r
2.5 Mabswid
.41657 .49914 Mdot
1 .096 0 r
.5 Mabswid
.37326 .50015 m
.41657 .49914 L
s
0 0 0 r
2.5 Mabswid
.58879 .49908 Mdot
1 .093 0 r
.5 Mabswid
.61895 .5002 m
.58879 .49908 L
s
.142 1 0 r
.4748 .5785 m
.39943 .61855 L
s
0 0 0 r
2.5 Mabswid
.4748 .5785 Mdot
1 .115 0 r
.5 Mabswid
.58892 .49908 m
.40771 .53618 L
s
0 0 0 r
2.5 Mabswid
.58892 .49908 Mdot
1 .115 0 r
.5 Mabswid
.58381 .50027 m
.58892 .49908 L
s
0 0 0 r
2.5 Mabswid
.58599 .48204 Mdot
0 .046 1 r
.5 Mabswid
.38348 .56373 m
.58599 .48204 L
s
.045 1 0 r
.57635 .54336 m
.3376 .58062 L
s
0 0 0 r
2.5 Mabswid
.57635 .54336 Mdot
.045 1 0 r
.5 Mabswid
.57081 .4463 m
.57635 .54336 L
s
.866 1 0 r
.48681 .41533 m
.43288 .53063 L
s
0 0 0 r
2.5 Mabswid
.48681 .41533 Mdot
.866 1 0 r
.5 Mabswid
.63544 .52376 m
.48681 .41533 L
s
.388 1 0 r
.57227 .5512 m
.65267 .42232 L
s
0 0 0 r
2.5 Mabswid
.57227 .5512 Mdot
.388 1 0 r
.5 Mabswid
.5093 .58944 m
.57227 .5512 L
s
.699 1 0 r
.45315 .57193 m
.38543 .50188 L
s
0 0 0 r
2.5 Mabswid
.45315 .57193 Mdot
.699 1 0 r
.5 Mabswid
.55704 .61302 m
.45315 .57193 L
s
0 0 0 r
2.5 Mabswid
.42442 .46311 Mdot
0 .989 1 r
.5 Mabswid
.58109 .44288 m
.42442 .46311 L
s
0 0 0 r
2.5 Mabswid
.41621 .48303 Mdot
.2 0 1 r
.5 Mabswid
.37223 .36467 m
.41621 .48303 L
s
0 0 0 r
2.5 Mabswid
.5093 .58944 Mdot
.388 1 0 r
.5 Mabswid
.50091 .59223 m
.5093 .58944 L
s
.814 1 0 r
.5273 .41497 m
.56366 .53221 L
s
0 0 0 r
2.5 Mabswid
.5273 .41497 Mdot
.814 1 0 r
.5 Mabswid
.36905 .52226 m
.5273 .41497 L
s
0 1 .928 r
.41784 .52666 m
.60525 .44822 L
s
0 0 0 r
2.5 Mabswid
.41784 .52666 Mdot
0 1 .928 r
.5 Mabswid
.39402 .53457 m
.41784 .52666 L
s
.8 1 0 r
.46761 .41886 m
.45307 .63538 L
s
0 0 0 r
2.5 Mabswid
.46761 .41886 Mdot
.8 1 0 r
.5 Mabswid
.5271 .39824 m
.46761 .41886 L
s
1 .116 0 r
.58576 .52868 m
.63042 .51938 L
s
0 0 0 r
2.5 Mabswid
.58576 .52868 Mdot
.43452 .56031 Mdot
0 1 .711 r
.5 Mabswid
.57965 .53353 m
.43452 .56031 L
s
0 .327 1 r
.58898 .52185 m
.56871 .59934 L
s
0 0 0 r
2.5 Mabswid
.58898 .52185 Mdot
0 .327 1 r
.5 Mabswid
.48856 .40325 m
.58898 .52185 L
s
0 .364 1 r
.4262 .54962 m
.56875 .4203 L
s
0 0 0 r
2.5 Mabswid
.4262 .54962 Mdot
0 1 .699 r
.5 Mabswid
.49364 .52118 m
.4262 .54962 L
s
0 0 0 r
2.5 Mabswid
.41929 .53521 Mdot
0 .439 1 r
.5 Mabswid
.57992 .46979 m
.41929 .53521 L
s
0 1 .532 r
.52428 .41162 m
.45723 .6713 L
s
0 0 0 r
2.5 Mabswid
.52428 .41162 Mdot
0 1 .532 r
.5 Mabswid
.51651 .44554 m
.52428 .41162 L
s
.8 1 0 r
.42602 .44868 m
.66366 .57963 L
s
0 0 0 r
2.5 Mabswid
.42602 .44868 Mdot
.8 1 0 r
.5 Mabswid
.43268 .47583 m
.42602 .44868 L
s
.874 1 0 r
.48205 .41115 m
.42935 .52214 L
s
0 0 0 r
2.5 Mabswid
.48205 .41115 Mdot
.874 1 0 r
.5 Mabswid
.63042 .51938 m
.48205 .41115 L
s
1 .115 0 r
.41705 .53287 m
.36456 .52654 L
s
0 0 0 r
2.5 Mabswid
.41705 .53287 Mdot
.50091 .59223 Mdot
.388 1 0 r
.5 Mabswid
.44667 .60596 m
.50091 .59223 L
s
1 .115 0 r
.59532 .49913 m
.39826 .53954 L
s
0 0 0 r
2.5 Mabswid
.59532 .49913 Mdot
1 .115 0 r
.5 Mabswid
.5907 .50027 m
.59532 .49913 L
s
1 .886 0 r
.47471 .58683 m
.62876 .48365 L
s
0 0 0 r
2.5 Mabswid
.47471 .58683 Mdot
1 .886 0 r
.5 Mabswid
.38741 .55916 m
.47471 .58683 L
s
0 0 0 r
2.5 Mabswid
.52123 .24533 Mdot
0 .305 1 r
.5 Mabswid
.63462 .36655 m
.52123 .24533 L
s
0 .938 1 r
.50608 .40625 m
.49923 .42606 L
s
0 0 0 r
2.5 Mabswid
.50608 .40625 Mdot
0 .938 1 r
.5 Mabswid
.56335 .66668 m
.50608 .40625 L
s
0 1 .632 r
.44171 .42834 m
.66302 .42503 L
s
0 0 0 r
2.5 Mabswid
.44171 .42834 Mdot
0 1 .632 r
.5 Mabswid
.33833 .53968 m
.44171 .42834 L
s
0 .038 1 r
.41394 .52797 m
.44144 .35235 L
s
0 0 0 r
2.5 Mabswid
.41394 .52797 Mdot
0 .038 1 r
.5 Mabswid
.54205 .63694 m
.41394 .52797 L
s
0 0 0 r
2.5 Mabswid
.40692 .49919 Mdot
1 .096 0 r
.5 Mabswid
.36667 .50013 m
.40692 .49919 L
s
.81 1 0 r
.53628 .585 m
.38368 .48628 L
s
0 0 0 r
2.5 Mabswid
.53628 .585 Mdot
.81 1 0 r
.5 Mabswid
.61509 .55361 m
.53628 .585 L
s
0 0 0 r
2.5 Mabswid
.76123 .63863 Mdot
.364 1 0 r
.5 Mabswid
.60419 .64366 m
.76123 .63863 L
s
0 0 0 r
2.5 Mabswid
.59768 .49914 Mdot
1 .093 0 r
.5 Mabswid
.62606 .50018 m
.59768 .49914 L
s
.819 1 0 r
.53165 .4108 m
.56733 .52368 L
s
0 0 0 r
2.5 Mabswid
.53165 .4108 Mdot
.819 1 0 r
.5 Mabswid
.37356 .51795 m
.53165 .4108 L
s
.746 1 0 r
.4196 .45333 m
.67083 .52009 L
s
0 0 0 r
2.5 Mabswid
.4196 .45333 Mdot
.746 1 0 r
.5 Mabswid
.4258 .48014 m
.4196 .45333 L
s
0 0 0 r
2.5 Mabswid
.25247 .39383 Mdot
0 1 .96 r
.5 Mabswid
.3632 .37669 m
.25247 .39383 L
s
0 .449 1 r
.59286 .47504 m
.41765 .54909 L
s
0 0 0 r
2.5 Mabswid
.59286 .47504 Mdot
0 .449 1 r
.5 Mabswid
.60475 .46763 m
.59286 .47504 L
s
0 .038 1 r
.56168 .42586 m
.57857 .58101 L
s
0 0 0 r
2.5 Mabswid
.56168 .42586 Mdot
0 .038 1 r
.5 Mabswid
.46866 .36511 m
.56168 .42586 L
s
0 .538 1 r
.40876 .47393 m
.34097 .56589 L
s
0 0 0 r
2.5 Mabswid
.40876 .47393 Mdot
0 1 .754 r
.5 Mabswid
.41129 .53247 m
.6153 .44726 L
s
0 0 0 r
2.5 Mabswid
.41129 .53247 Mdot
0 1 .754 r
.5 Mabswid
.38919 .53998 m
.41129 .53247 L
s
0 .13 1 r
.58521 .45202 m
.40404 .52502 L
s
0 0 0 r
2.5 Mabswid
.58521 .45202 Mdot
0 1 .871 r
.5 Mabswid
.50286 .48201 m
.58521 .45202 L
s
0 .449 1 r
.41765 .54909 m
.38348 .56373 L
s
0 0 0 r
2.5 Mabswid
.41765 .54909 Mdot
.884 1 0 r
.5 Mabswid
.47726 .40694 m
.42583 .51367 L
s
0 0 0 r
2.5 Mabswid
.47726 .40694 Mdot
.884 1 0 r
.5 Mabswid
.62538 .51497 m
.47726 .40694 L
s
0 0 0 r
2.5 Mabswid
.46384 .41131 Mdot
0 .989 1 r
.5 Mabswid
.56279 .32193 m
.46384 .41131 L
s
0 0 0 r
2.5 Mabswid
.48856 .40325 Mdot
0 .327 1 r
.5 Mabswid
.41035 .39015 m
.48856 .40325 L
s
.741 1 0 r
.41317 .45806 m
.66502 .52567 L
s
0 0 0 r
2.5 Mabswid
.41317 .45806 Mdot
.741 1 0 r
.5 Mabswid
.41889 .48447 m
.41317 .45806 L
s
0 0 0 r
2.5 Mabswid
.45104 .41528 Mdot
0 .298 1 r
.5 Mabswid
.50173 .55338 m
.45104 .41528 L
s
0 1 .381 r
.50859 .40015 m
.40575 .42528 L
s
0 0 0 r
2.5 Mabswid
.50859 .40015 Mdot
0 1 .381 r
.5 Mabswid
.60316 .63248 m
.50859 .40015 L
s
1 .116 0 r
.59409 .53189 m
.63544 .52376 L
s
0 0 0 r
2.5 Mabswid
.59409 .53189 Mdot
.806 1 0 r
.5 Mabswid
.53772 .59182 m
.37398 .48618 L
s
0 0 0 r
2.5 Mabswid
.53772 .59182 Mdot
.806 1 0 r
.5 Mabswid
.61269 .56227 m
.53772 .59182 L
s
.801 1 0 r
.58381 .44408 m
.33626 .5707 L
s
0 0 0 r
2.5 Mabswid
.58381 .44408 Mdot
.801 1 0 r
.5 Mabswid
.5639 .4729 m
.58381 .44408 L
s
0 .989 1 r
.43923 .42039 m
.33412 .4994 L
s
0 0 0 r
2.5 Mabswid
.43923 .42039 Mdot
0 .989 1 r
.5 Mabswid
.56712 .39449 m
.43923 .42039 L
s
1 .115 0 r
.40771 .53618 m
.36011 .5308 L
s
0 0 0 r
2.5 Mabswid
.40771 .53618 Mdot
.737 1 0 r
.5 Mabswid
.4067 .46281 m
.65919 .53128 L
s
0 0 0 r
2.5 Mabswid
.4067 .46281 Mdot
.737 1 0 r
.5 Mabswid
.41197 .4888 m
.4067 .46281 L
s
0 .542 1 r
.58475 .55804 m
.54697 .56205 L
s
0 0 0 r
2.5 Mabswid
.58475 .55804 Mdot
0 .542 1 r
.5 Mabswid
.37183 .3749 m
.58475 .55804 L
s
0 1 .632 r
.40048 .47814 m
.42214 .34962 L
s
0 0 0 r
2.5 Mabswid
.40048 .47814 Mdot
0 1 .632 r
.5 Mabswid
.41761 .57099 m
.40048 .47814 L
s
0 .364 1 r
.59303 .45606 m
.57632 .63352 L
s
0 0 0 r
2.5 Mabswid
.59303 .45606 Mdot
0 .364 1 r
.5 Mabswid
.44048 .3443 m
.59303 .45606 L
s
.797 1 0 r
.59001 .44861 m
.3423 .57601 L
s
0 0 0 r
2.5 Mabswid
.59001 .44861 Mdot
.797 1 0 r
.5 Mabswid
.57073 .47718 m
.59001 .44861 L
s
0 .498 1 r
.59891 .46921 m
.40721 .55011 L
s
0 0 0 r
2.5 Mabswid
.59891 .46921 Mdot
0 .498 1 r
.5 Mabswid
.61012 .46213 m
.59891 .46921 L
s
0 1 .653 r
.40472 .53831 m
.62548 .44629 L
s
0 0 0 r
2.5 Mabswid
.40472 .53831 Mdot
0 1 .653 r
.5 Mabswid
.38437 .54536 m
.40472 .53831 L
s
0 .601 1 r
.41601 .44059 m
.50468 .47966 L
s
0 0 0 r
2.5 Mabswid
.41601 .44059 Mdot
0 1 .326 r
.5 Mabswid
.50896 .53765 m
.41601 .44059 L
s
0 .538 1 r
.56374 .58219 m
.64367 .46952 L
s
0 0 0 r
2.5 Mabswid
.56374 .58219 Mdot
0 .538 1 r
.5 Mabswid
.39693 .64777 m
.56374 .58219 L
s
0 .327 1 r
.5567 .41271 m
.56833 .5884 L
s
0 0 0 r
2.5 Mabswid
.5567 .41271 Mdot
0 .327 1 r
.5 Mabswid
.49848 .3705 m
.5567 .41271 L
s
0 0 0 r
2.5 Mabswid
.60665 .4992 Mdot
1 .092 0 r
.5 Mabswid
.63318 .50015 m
.60665 .4992 L
s
0 1 .381 r
.39924 .52469 m
.60817 .63925 L
s
0 0 0 r
2.5 Mabswid
.39924 .52469 Mdot
0 1 .381 r
.5 Mabswid
.40575 .42528 m
.39924 .52469 L
s
0 0 0 r
2.5 Mabswid
.39709 .51746 Mdot
0 .692 1 r
.5 Mabswid
.48476 .47975 m
.39709 .51746 L
s
.732 1 0 r
.40021 .46758 m
.65205 .53657 L
s
0 0 0 r
2.5 Mabswid
.40021 .46758 Mdot
.732 1 0 r
.5 Mabswid
.40504 .49314 m
.40021 .46758 L
s
0 0 0 r
2.5 Mabswid
.56168 .41477 Mdot
0 .542 1 r
.5 Mabswid
.65992 .40318 m
.56168 .41477 L
s
0 .989 1 r
.40714 .5492 m
.40196 .65454 L
s
0 0 0 r
2.5 Mabswid
.40714 .5492 Mdot
.3949 .50893 Mdot
0 .685 1 r
.5 Mabswid
.4822 .47095 m
.3949 .50893 L
s
0 .877 1 r
.41922 .43298 m
.50732 .47087 L
s
0 0 0 r
2.5 Mabswid
.41922 .43298 Mdot
0 1 .247 r
.5 Mabswid
.5114 .52881 m
.41922 .43298 L
s
0 .498 1 r
.40721 .55011 m
.37618 .56314 L
s
0 0 0 r
2.5 Mabswid
.40721 .55011 Mdot
.39271 .50039 Mdot
0 .695 1 r
.5 Mabswid
.47964 .46215 m
.39271 .50039 L
s
0 .989 1 r
.45531 .5958 m
.67283 .48926 L
s
0 0 0 r
2.5 Mabswid
.45531 .5958 Mdot
0 .989 1 r
.5 Mabswid
.37295 .53497 m
.45531 .5958 L
s
.803 1 0 r
.53917 .59868 m
.36418 .48608 L
s
0 0 0 r
2.5 Mabswid
.53917 .59868 Mdot
.803 1 0 r
.5 Mabswid
.61028 .57094 m
.53917 .59868 L
s
.045 1 0 r
.40374 .54595 m
.36771 .47752 L
s
0 0 0 r
2.5 Mabswid
.40374 .54595 Mdot
.045 1 0 r
.5 Mabswid
.43801 .58777 m
.40374 .54595 L
s
.793 1 0 r
.59614 .45329 m
.33438 .51581 L
s
0 0 0 r
2.5 Mabswid
.59614 .45329 Mdot
.793 1 0 r
.5 Mabswid
.57757 .48148 m
.59614 .45329 L
s
.045 1 0 r
.52354 .396 m
.54417 .40167 L
s
0 0 0 r
2.5 Mabswid
.52354 .396 Mdot
.045 1 0 r
.5 Mabswid
.5012 .39168 m
.52354 .396 L
s
0 .111 1 r
.40289 .54468 m
.61546 .45665 L
s
0 0 0 r
2.5 Mabswid
.40289 .54468 Mdot
.298 1 0 r
.5 Mabswid
.42791 .53239 m
.40289 .54468 L
s
0 0 0 r
2.5 Mabswid
.43801 .58777 Mdot
.045 1 0 r
.5 Mabswid
.51959 .64736 m
.43801 .58777 L
s
0 0 0 r
2.5 Mabswid
.5012 .39168 Mdot
.045 1 0 r
.5 Mabswid
.37601 .39898 m
.5012 .39168 L
s
0 .364 1 r
.40562 .44772 m
.41013 .38527 L
s
0 0 0 r
2.5 Mabswid
.40562 .44772 Mdot
0 .364 1 r
.5 Mabswid
.53587 .62225 m
.40562 .44772 L
s
.8 1 0 r
.60879 .50717 m
.5271 .39824 L
s
0 0 0 r
2.5 Mabswid
.60879 .50717 Mdot
.8 1 0 r
.5 Mabswid
.43403 .58653 m
.60879 .50717 L
s
0 0 0 r
2.5 Mabswid
.41761 .57099 Mdot
0 1 .632 r
.5 Mabswid
.45426 .64698 m
.41761 .57099 L
s
.045 1 0 r
.54417 .40167 m
.57366 .41268 L
s
0 0 0 r
2.5 Mabswid
.54417 .40167 Mdot
1 .116 0 r
.5 Mabswid
.60252 .53515 m
.64042 .52812 L
s
0 0 0 r
2.5 Mabswid
.60252 .53515 Mdot
0 .829 1 r
.5 Mabswid
.38993 .49505 m
.40031 .55126 L
s
0 0 0 r
2.5 Mabswid
.38993 .49505 Mdot
0 .829 1 r
.5 Mabswid
.6423 .44338 m
.38993 .49505 L
s
1 .115 0 r
.39826 .53954 m
.35567 .53504 L
s
0 0 0 r
2.5 Mabswid
.39826 .53954 Mdot
.797 1 0 r
.5 Mabswid
.4011 .54655 m
.68461 .46339 L
s
0 0 0 r
2.5 Mabswid
.4011 .54655 Mdot
.797 1 0 r
.5 Mabswid
.38906 .53673 m
.4011 .54655 L
s
.793 1 0 r
.42013 .57745 m
.43051 .54657 L
s
0 0 0 r
2.5 Mabswid
.42013 .57745 Mdot
.793 1 0 r
.5 Mabswid
.6411 .47254 m
.42013 .57745 L
s
0 .692 1 r
.59265 .44085 m
.48476 .47975 L
s
0 0 0 r
2.5 Mabswid
.59265 .44085 Mdot
0 1 .495 r
.5 Mabswid
.48557 .5424 m
.59265 .44085 L
s
.045 1 0 r
.39178 .52076 m
.46414 .38849 L
s
0 0 0 r
2.5 Mabswid
.39178 .52076 Mdot
.045 1 0 r
.5 Mabswid
.50737 .6151 m
.39178 .52076 L
s
0 0 0 r
2.5 Mabswid
.50242 .6117 Mdot
0 .884 1 r
.5 Mabswid
.55073 .65499 m
.50242 .6117 L
s
.741 1 0 r
.53992 .60297 m
.57853 .56085 L
s
0 0 0 r
2.5 Mabswid
.53992 .60297 Mdot
.741 1 0 r
.5 Mabswid
.35156 .4329 m
.53992 .60297 L
s
.801 1 0 r
.396 .53874 m
.6837 .45355 L
s
0 0 0 r
2.5 Mabswid
.396 .53874 Mdot
.801 1 0 r
.5 Mabswid
.38401 .52879 m
.396 .53874 L
s
0 0 0 r
2.5 Mabswid
.60877 .52062 Mdot
0 .601 1 r
.5 Mabswid
.50468 .47966 m
.60877 .52062 L
s
0 1 .542 r
.39813 .54418 m
.63579 .44531 L
s
0 0 0 r
2.5 Mabswid
.39813 .54418 Mdot
0 1 .542 r
.5 Mabswid
.37958 .55073 m
.39813 .54418 L
s
0 1 .532 r
.40664 .55989 m
.50135 .67943 L
s
0 0 0 r
2.5 Mabswid
.40664 .55989 Mdot
0 1 .532 r
.5 Mabswid
.37692 .46061 m
.40664 .55989 L
s
.45694 .398 m
.36715 .57139 L
s
0 0 0 r
2.5 Mabswid
.45694 .398 Mdot
0 1 .532 r
.5 Mabswid
.58308 .40474 m
.45694 .398 L
s
.789 1 0 r
.60228 .45803 m
.33965 .52133 L
s
0 0 0 r
2.5 Mabswid
.60228 .45803 Mdot
.789 1 0 r
.5 Mabswid
.58444 .48578 m
.60228 .45803 L
s
.052 0 1 r
.61098 .51205 m
.46241 .50964 L
s
0 0 0 r
2.5 Mabswid
.61098 .51205 Mdot
0 .877 1 r
.5 Mabswid
.50732 .47087 m
.61098 .51205 L
s
0 .685 1 r
.58932 .43323 m
.4822 .47095 L
s
0 0 0 r
2.5 Mabswid
.58932 .43323 Mdot
0 1 .253 r
.5 Mabswid
.48315 .53353 m
.58932 .43323 L
s
0 .538 1 r
.59102 .56482 m
.62763 .48454 L
s
0 0 0 r
2.5 Mabswid
.59102 .56482 Mdot
0 .538 1 r
.5 Mabswid
.37138 .57765 m
.59102 .56482 L
s
0 .111 1 r
.60498 .46336 m
.39665 .55113 L
s
0 0 0 r
2.5 Mabswid
.60498 .46336 Mdot
0 .111 1 r
.5 Mabswid
.61546 .45665 m
.60498 .46336 L
s
0 .327 1 r
.56833 .5884 m
.52269 .64322 L
s
0 0 0 r
2.5 Mabswid
.56833 .5884 Mdot
0 .038 1 r
.5 Mabswid
.57857 .58101 m
.54205 .63694 L
s
0 0 0 r
2.5 Mabswid
.57857 .58101 Mdot
0 .498 1 r
.5 Mabswid
.39838 .54946 m
.61012 .46213 L
s
0 0 0 r
2.5 Mabswid
.39838 .54946 Mdot
.284 1 0 r
.5 Mabswid
.42229 .53782 m
.39838 .54946 L
s
.699 1 0 r
.38543 .50188 m
.37665 .48882 L
s
0 0 0 r
2.5 Mabswid
.38543 .50188 Mdot
.741 1 0 r
.5 Mabswid
.54916 .39952 m
.43337 .45269 L
s
0 0 0 r
2.5 Mabswid
.54916 .39952 Mdot
.741 1 0 r
.5 Mabswid
.57853 .56085 m
.54916 .39952 L
s
0 1 .381 r
.4081 .43521 m
.58891 .62465 L
s
0 0 0 r
2.5 Mabswid
.4081 .43521 Mdot
0 1 .381 r
.5 Mabswid
.41155 .4121 m
.4081 .43521 L
s
0 .327 1 r
.39624 .54532 m
.41035 .39015 L
s
0 0 0 r
2.5 Mabswid
.39624 .54532 Mdot
0 .327 1 r
.5 Mabswid
.52269 .64322 m
.39624 .54532 L
s
0 .695 1 r
.58598 .42559 m
.47964 .46215 L
s
0 0 0 r
2.5 Mabswid
.58598 .42559 Mdot
0 1 .243 r
.5 Mabswid
.48074 .52465 m
.58598 .42559 L
s
0 0 0 r
2.5 Mabswid
.42585 .75552 Mdot
0 1 .347 r
.5 Mabswid
.53318 .65685 m
.42585 .75552 L
s
0 .13 1 r
.4039 .56079 m
.64303 .46629 L
s
0 0 0 r
2.5 Mabswid
.4039 .56079 Mdot
0 .13 1 r
.5 Mabswid
.40404 .52502 m
.4039 .56079 L
s
.737 1 0 r
.38476 .49485 m
.36879 .50137 L
s
0 0 0 r
2.5 Mabswid
.38476 .49485 Mdot
.737 1 0 r
.5 Mabswid
.64549 .53132 m
.38476 .49485 L
s
1 .992 0 r
.46123 .39318 m
.45578 .24229 L
s
.142 1 0 r
.46123 .39318 m
.4923 .43052 L
s
0 0 0 r
2.5 Mabswid
.46123 .39318 Mdot
1 .728 0 r
.5 Mabswid
.49937 .59766 m
.46123 .39318 L
s
0 0 0 r
2.5 Mabswid
.61569 .49926 Mdot
1 .092 0 r
.5 Mabswid
.64031 .50013 m
.61569 .49926 L
s
0 1 .632 r
.56534 .5934 m
.38892 .57256 L
s
0 0 0 r
2.5 Mabswid
.56534 .5934 Mdot
0 1 .632 r
.5 Mabswid
.65327 .52753 m
.56534 .5934 L
s
0 .111 1 r
.39665 .55113 m
.36893 .56255 L
s
0 0 0 r
2.5 Mabswid
.39665 .55113 Mdot
.045 1 0 r
.5 Mabswid
.57366 .41268 m
.59098 .42075 L
s
0 0 0 r
2.5 Mabswid
.57366 .41268 Mdot
0 .418 1 r
.5 Mabswid
.3876 .47579 m
.51664 .51828 L
s
0 0 0 r
2.5 Mabswid
.3876 .47579 Mdot
0 1 .592 r
.5 Mabswid
.46093 .48103 m
.3876 .47579 L
s
.8 1 0 r
.40701 .56785 m
.43403 .58653 L
s
0 0 0 r
2.5 Mabswid
.40701 .56785 Mdot
.8 1 0 r
.5 Mabswid
.58009 .35941 m
.40701 .56785 L
s
0 .149 1 r
.47531 .61276 m
.63378 .38575 L
s
0 0 0 r
2.5 Mabswid
.47531 .61276 Mdot
0 .149 1 r
.5 Mabswid
.42152 .58786 m
.47531 .61276 L
s
0 0 0 r
2.5 Mabswid
.55864 .59931 Mdot
0 .711 1 r
.5 Mabswid
.49838 .46993 m
.55864 .59931 L
s
0 1 .542 r
.60639 .45782 m
.37958 .55073 L
s
0 0 0 r
2.5 Mabswid
.60639 .45782 Mdot
.385 1 0 r
.5 Mabswid
.56841 .47132 m
.60639 .45782 L
s
.778 1 0 r
.60844 .4628 m
.34495 .52688 L
s
0 0 0 r
2.5 Mabswid
.60844 .4628 Mdot
.778 1 0 r
.5 Mabswid
.59133 .4901 m
.60844 .4628 L
s
.789 1 0 r
.41736 .58509 m
.42703 .55625 L
s
0 0 0 r
2.5 Mabswid
.41736 .58509 Mdot
.789 1 0 r
.5 Mabswid
.63716 .48086 m
.41736 .58509 L
s
.81 1 0 r
.38368 .48628 m
.35861 .44666 L
s
0 0 0 r
2.5 Mabswid
.38368 .48628 Mdot
.045 1 0 r
.5 Mabswid
.61373 .47942 m
.59074 .62597 L
s
0 0 0 r
2.5 Mabswid
.61373 .47942 Mdot
.045 1 0 r
.5 Mabswid
.54091 .31784 m
.61373 .47942 L
s
0 .449 1 r
.39385 .55426 m
.60475 .46763 L
s
0 0 0 r
2.5 Mabswid
.39385 .55426 Mdot
.274 1 0 r
.5 Mabswid
.41665 .54325 m
.39385 .55426 L
s
0 1 .928 r
.60525 .44822 m
.62772 .43658 L
s
0 0 0 r
2.5 Mabswid
.60525 .44822 Mdot
.44667 .60596 Mdot
.388 1 0 r
.5 Mabswid
.36184 .61581 m
.44667 .60596 L
s
1 .116 0 r
.61106 .53844 m
.64538 .53246 L
s
0 0 0 r
2.5 Mabswid
.61106 .53844 Mdot
0 1 .632 r
.5 Mabswid
.59729 .56756 m
.53593 .63842 L
s
0 0 0 r
2.5 Mabswid
.59729 .56756 Mdot
0 1 .632 r
.5 Mabswid
.63424 .46409 m
.59729 .56756 L
s
.741 1 0 r
.38009 .48744 m
.36502 .49295 L
s
0 0 0 r
2.5 Mabswid
.38009 .48744 Mdot
.741 1 0 r
.5 Mabswid
.65326 .52582 m
.38009 .48744 L
s
0 0 0 r
2.5 Mabswid
.57234 .40596 Mdot
0 .538 1 r
.5 Mabswid
.65849 .41401 m
.57234 .40596 L
s
0 .702 1 r
.56891 .59717 m
.57564 .58366 L
s
0 0 0 r
2.5 Mabswid
.56891 .59717 Mdot
0 .702 1 r
.5 Mabswid
.3632 .37669 m
.56891 .59717 L
s
.045 1 0 r
.59098 .42075 m
.6904 .49938 L
s
0 0 0 r
2.5 Mabswid
.59098 .42075 Mdot
.45578 .24229 Mdot
0 .989 1 r
.5 Mabswid
.62002 .49003 m
.64677 .41848 L
s
0 0 0 r
2.5 Mabswid
.62002 .49003 Mdot
0 1 .653 r
.5 Mabswid
.61051 .45306 m
.38437 .54536 L
s
0 0 0 r
2.5 Mabswid
.61051 .45306 Mdot
.378 1 0 r
.5 Mabswid
.57406 .46588 m
.61051 .45306 L
s
.699 1 0 r
.37665 .48882 m
.3341 .42045 L
s
0 0 0 r
2.5 Mabswid
.37665 .48882 Mdot
0 .038 1 r
.5 Mabswid
.47908 .62051 m
.34673 .52579 L
s
0 0 0 r
2.5 Mabswid
.47908 .62051 Mdot
0 .038 1 r
.5 Mabswid
.63701 .57799 m
.47908 .62051 L
s
.778 1 0 r
.41498 .59259 m
.37766 .53645 L
s
0 0 0 r
2.5 Mabswid
.41498 .59259 Mdot
.778 1 0 r
.5 Mabswid
.63319 .48924 m
.41498 .59259 L
s
0 .989 1 r
.44359 .39084 m
.37295 .53497 L
s
0 0 0 r
2.5 Mabswid
.44359 .39084 Mdot
0 .989 1 r
.5 Mabswid
.59406 .38691 m
.44359 .39084 L
s
.746 1 0 r
.39661 .57007 m
.40386 .58619 L
s
0 0 0 r
2.5 Mabswid
.39661 .57007 Mdot
.746 1 0 r
.5 Mabswid
.61176 .35302 m
.39661 .57007 L
s
0 .989 1 r
.62423 .49499 m
.58109 .44288 L
s
0 0 0 r
2.5 Mabswid
.62423 .49499 Mdot
0 .989 1 r
.5 Mabswid
.42427 .64626 m
.62423 .49499 L
s
1 .728 0 r
.52821 .62087 m
.49937 .59766 L
s
0 0 0 r
2.5 Mabswid
.52821 .62087 Mdot
1 .728 0 r
.5 Mabswid
.51142 .36512 m
.52821 .62087 L
s
.746 1 0 r
.37539 .48 m
.36156 .48449 L
s
0 0 0 r
2.5 Mabswid
.37539 .48 Mdot
.746 1 0 r
.5 Mabswid
.66105 .5203 m
.37539 .48 L
s
.806 1 0 r
.37398 .48618 m
.35179 .45191 L
s
0 0 0 r
2.5 Mabswid
.37398 .48618 Mdot
0 .364 1 r
.5 Mabswid
.59166 .41342 m
.4576 .66224 L
s
0 0 0 r
2.5 Mabswid
.59166 .41342 Mdot
0 .364 1 r
.5 Mabswid
.56875 .4203 m
.59166 .41342 L
s
0 .989 1 r
.37807 .46383 m
.36326 .47487 L
s
0 0 0 r
2.5 Mabswid
.37807 .46383 Mdot
0 .989 1 r
.5 Mabswid
.66117 .47937 m
.37807 .46383 L
s
0 .542 1 r
.38212 .55168 m
.66656 .53154 L
s
0 0 0 r
2.5 Mabswid
.38212 .55168 Mdot
0 .542 1 r
.5 Mabswid
.36817 .52461 m
.38212 .55168 L
s
0 0 0 r
2.5 Mabswid
.56712 .39449 Mdot
0 .989 1 r
.5 Mabswid
.64677 .41848 m
.56712 .39449 L
s
0 0 0 r
2.5 Mabswid
.55704 .61302 Mdot
.699 1 0 r
.5 Mabswid
.63782 .62229 m
.55704 .61302 L
s
0 .005 1 r
.3772 .54117 m
.49642 .52223 L
s
0 0 0 r
2.5 Mabswid
.3772 .54117 Mdot
0 1 .749 r
.5 Mabswid
.44016 .5262 m
.3772 .54117 L
s
0 1 .754 r
.61465 .44828 m
.38919 .53998 L
s
0 0 0 r
2.5 Mabswid
.61465 .44828 Mdot
.37 1 0 r
.5 Mabswid
.57972 .46044 m
.61465 .44828 L
s
.746 1 0 r
.58957 .5907 m
.61963 .53004 L
s
0 0 0 r
2.5 Mabswid
.58957 .5907 Mdot
.746 1 0 r
.5 Mabswid
.36156 .48449 m
.58957 .5907 L
s
0 0 0 r
2.5 Mabswid
.37692 .46061 Mdot
0 1 .532 r
.5 Mabswid
.37062 .36593 m
.37692 .46061 L
s
0 0 0 r
2.5 Mabswid
.76374 .56431 Mdot
0 .313 1 r
.5 Mabswid
.56823 .60884 m
.76374 .56431 L
s
0 0 0 r
2.5 Mabswid
.53587 .62225 Mdot
0 .364 1 r
.5 Mabswid
.57632 .63352 m
.53587 .62225 L
s
0 1 .381 r
.43956 .61394 m
.65544 .60092 L
s
0 0 0 r
2.5 Mabswid
.43956 .61394 Mdot
0 1 .381 r
.5 Mabswid
.35957 .54977 m
.43956 .61394 L
s
0 1 .754 r
.6153 .44726 m
.63553 .43706 L
s
0 0 0 r
2.5 Mabswid
.6153 .44726 Mdot
0 .989 1 r
.5 Mabswid
.59939 .58096 m
.54617 .35371 L
s
0 0 0 r
2.5 Mabswid
.59939 .58096 Mdot
0 .989 1 r
.5 Mabswid
.51603 .63962 m
.59939 .58096 L
s
0 .542 1 r
.61629 .44851 m
.45299 .33066 L
s
0 0 0 r
2.5 Mabswid
.61629 .44851 Mdot
0 .542 1 r
.5 Mabswid
.62884 .58648 m
.61629 .44851 L
s
0 0 0 r
2.5 Mabswid
.56823 .60884 Mdot
0 .348 1 r
.5 Mabswid
.42836 .5461 m
.56823 .60884 L
s
.778 1 0 r
.6271 .51293 m
.54243 .63013 L
s
0 0 0 r
2.5 Mabswid
.6271 .51293 Mdot
.778 1 0 r
.5 Mabswid
.5501 .34525 m
.6271 .51293 L
s
0 .538 1 r
.40514 .59305 m
.54813 .58154 L
s
0 0 0 r
2.5 Mabswid
.40514 .59305 Mdot
.884 1 0 r
.5 Mabswid
.42583 .51367 m
.40514 .59305 L
s
.778 1 0 r
.43066 .61091 m
.36821 .44834 L
s
0 0 0 r
2.5 Mabswid
.43066 .61091 Mdot
.778 1 0 r
.5 Mabswid
.54243 .63013 m
.43066 .61091 L
s
.62764 .48529 m
.63319 .48924 L
s
0 0 0 r
2.5 Mabswid
.62764 .48529 Mdot
.778 1 0 r
.5 Mabswid
.36418 .52612 m
.62764 .48529 L
s
0 1 .381 r
.39038 .42782 m
.35957 .54977 L
s
0 0 0 r
2.5 Mabswid
.39038 .42782 Mdot
0 1 .381 r
.5 Mabswid
.54394 .35112 m
.39038 .42782 L
s
0 .038 1 r
.37941 .44457 m
.58601 .33159 L
s
0 0 0 r
2.5 Mabswid
.37941 .44457 Mdot
0 .038 1 r
.5 Mabswid
.34673 .52579 m
.37941 .44457 L
s
.371 1 0 r
.605 .5755 m
.6211 .63166 L
s
0 0 0 r
2.5 Mabswid
.605 .5755 Mdot
.741 1 0 r
.5 Mabswid
.38617 .56855 m
.39182 .58235 L
s
0 0 0 r
2.5 Mabswid
.38617 .56855 Mdot
.741 1 0 r
.5 Mabswid
.59977 .35309 m
.38617 .56855 L
s
0 .989 1 r
.58202 .60061 m
.60469 .55064 L
s
0 0 0 r
2.5 Mabswid
.58202 .60061 Mdot
0 .989 1 r
.5 Mabswid
.36326 .47487 m
.58202 .60061 L
s
0 1 .632 r
.38892 .57256 m
.33833 .53968 L
s
0 0 0 r
2.5 Mabswid
.38892 .57256 Mdot
0 1 .532 r
.5 Mabswid
.62625 .47253 m
.58308 .40474 L
s
0 0 0 r
2.5 Mabswid
.62625 .47253 Mdot
0 1 .532 r
.5 Mabswid
.45104 .65348 m
.62625 .47253 L
s
.045 1 0 r
.59774 .41246 m
.55884 .55556 L
s
0 0 0 r
2.5 Mabswid
.59774 .41246 Mdot
.045 1 0 r
.5 Mabswid
.46414 .38849 m
.59774 .41246 L
s
0 1 .243 r
.40886 .60011 m
.48074 .52465 L
s
0 0 0 r
2.5 Mabswid
.40886 .60011 Mdot
.874 1 0 r
.5 Mabswid
.42935 .52214 m
.40886 .60011 L
s
1 .886 0 r
.62876 .48365 m
.6441 .44309 L
s
0 0 0 r
2.5 Mabswid
.62876 .48365 Mdot
.045 1 0 r
.5 Mabswid
.36771 .47752 m
.346 .40709 L
s
0 0 0 r
2.5 Mabswid
.36771 .47752 Mdot
0 .149 1 r
.5 Mabswid
.36591 .51809 m
.37148 .54328 L
s
0 0 0 r
2.5 Mabswid
.36591 .51809 Mdot
0 .149 1 r
.5 Mabswid
.61291 .37646 m
.36591 .51809 L
s
0 .038 1 r
.39786 .41253 m
.67572 .43787 L
s
0 0 0 r
2.5 Mabswid
.39786 .41253 Mdot
0 .038 1 r
.5 Mabswid
.37164 .45094 m
.39786 .41253 L
s
0 1 .928 r
.6188 .44348 m
.39402 .53457 L
s
0 0 0 r
2.5 Mabswid
.6188 .44348 Mdot
.364 1 0 r
.5 Mabswid
.58538 .45499 m
.6188 .44348 L
s
0 0 0 r
2.5 Mabswid
.36244 .50521 Mdot
.052 0 1 r
.5 Mabswid
.46241 .50964 m
.36244 .50521 L
s
.803 1 0 r
.36418 .48608 m
.34501 .45715 L
s
0 0 0 r
2.5 Mabswid
.36418 .48608 Mdot
.741 1 0 r
.5 Mabswid
.59084 .59808 m
.6185 .54298 L
s
0 0 0 r
2.5 Mabswid
.59084 .59808 Mdot
.741 1 0 r
.5 Mabswid
.36502 .49295 m
.59084 .59808 L
s
.778 1 0 r
.42559 .38728 m
.64315 .42778 L
s
0 0 0 r
2.5 Mabswid
.42559 .38728 Mdot
.778 1 0 r
.5 Mabswid
.36821 .44834 m
.42559 .38728 L
s
0 1 .253 r
.41276 .60651 m
.48315 .53353 L
s
0 0 0 r
2.5 Mabswid
.41276 .60651 Mdot
.866 1 0 r
.5 Mabswid
.43288 .53063 m
.41276 .60651 L
s
.741 1 0 r
.36025 .49758 m
.44778 .59336 L
s
0 0 0 r
2.5 Mabswid
.36025 .49758 Mdot
.741 1 0 r
.5 Mabswid
.43337 .45269 m
.36025 .49758 L
s
.55681 .37859 m
.39042 .37103 L
s
0 0 0 r
2.5 Mabswid
.55681 .37859 Mdot
.741 1 0 r
.5 Mabswid
.67349 .48606 m
.55681 .37859 L
s
0 0 0 r
2.5 Mabswid
.37524 .44012 Mdot
0 1 .797 r
.5 Mabswid
.4404 .42131 m
.37524 .44012 L
s
.797 1 0 r
.47052 .63323 m
.53607 .36539 L
s
0 0 0 r
2.5 Mabswid
.47052 .63323 Mdot
.797 1 0 r
.5 Mabswid
.46268 .62149 m
.47052 .63323 L
s
0 0 0 r
2.5 Mabswid
.63514 .49774 Mdot
0 .005 1 r
.5 Mabswid
.49642 .52223 m
.63514 .49774 L
s
0 0 0 r
2.5 Mabswid
.36418 .52612 Mdot
.778 1 0 r
.5 Mabswid
.34495 .52688 m
.36418 .52612 L
s
0 1 .381 r
.3898 .58374 m
.50883 .60374 L
s
0 0 0 r
2.5 Mabswid
.3898 .58374 Mdot
0 1 .381 r
.5 Mabswid
.40677 .47234 m
.3898 .58374 L
s
.789 1 0 r
.63186 .47778 m
.63716 .48086 L
s
0 0 0 r
2.5 Mabswid
.63186 .47778 Mdot
.789 1 0 r
.5 Mabswid
.35614 .52078 m
.63186 .47778 L
s
.741 1 0 r
.37791 .43274 m
.4562 .57495 L
s
0 0 0 r
2.5 Mabswid
.37791 .43274 Mdot
.741 1 0 r
.5 Mabswid
.43788 .42441 m
.37791 .43274 L
s
0 .38 1 r
.61145 .42477 m
.39566 .63271 L
s
0 0 0 r
2.5 Mabswid
.61145 .42477 Mdot
0 1 .65 r
.5 Mabswid
.60007 .40769 m
.61145 .42477 L
s
0 1 .632 r
.38639 .58115 m
.35409 .46237 L
s
0 0 0 r
2.5 Mabswid
.38639 .58115 Mdot
0 1 .632 r
.5 Mabswid
.45105 .67772 m
.38639 .58115 L
s
0 1 .381 r
.6316 .47126 m
.52674 .41033 L
s
0 0 0 r
2.5 Mabswid
.6316 .47126 Mdot
0 1 .381 r
.5 Mabswid
.52839 .58439 m
.6316 .47126 L
s
0 .989 1 r
.62418 .55619 m
.62969 .38534 L
s
0 0 0 r
2.5 Mabswid
.62418 .55619 Mdot
0 .989 1 r
.5 Mabswid
.51994 .67274 m
.62418 .55619 L
s
.2 0 1 r
.57825 .61178 m
.63163 .62705 L
s
0 0 0 r
2.5 Mabswid
.57825 .61178 Mdot
0 1 .632 r
.5 Mabswid
.58146 .39154 m
.66739 .47441 L
s
0 0 0 r
2.5 Mabswid
.58146 .39154 Mdot
0 1 .632 r
.5 Mabswid
.36546 .37293 m
.58146 .39154 L
s
.045 1 0 r
.59892 .59668 m
.50737 .6151 L
s
0 0 0 r
2.5 Mabswid
.59892 .59668 Mdot
.045 1 0 r
.5 Mabswid
.61759 .39413 m
.59892 .59668 L
s
0 1 .495 r
.41667 .61293 m
.48557 .5424 L
s
0 0 0 r
2.5 Mabswid
.41667 .61293 Mdot
.857 1 0 r
.5 Mabswid
.43642 .53913 m
.41667 .61293 L
s
0 1 .653 r
.62548 .44629 m
.64329 .43755 L
s
0 0 0 r
2.5 Mabswid
.62548 .44629 Mdot
.797 1 0 r
.5 Mabswid
.35923 .52 m
.63668 .5424 L
s
0 0 0 r
2.5 Mabswid
.35923 .52 Mdot
.797 1 0 r
.5 Mabswid
.35792 .49799 m
.35923 .52 L
s
0 .711 1 r
.45971 .36554 m
.49838 .46993 L
s
0 0 0 r
2.5 Mabswid
.45971 .36554 Mdot
0 1 .145 r
.5 Mabswid
.44796 .44302 m
.45971 .36554 L
s
1 .728 0 r
.44451 .63124 m
.4267 .62502 L
s
0 0 0 r
2.5 Mabswid
.44451 .63124 Mdot
1 .728 0 r
.5 Mabswid
.61062 .38702 m
.44451 .63124 L
s
0 1 .532 r
.40763 .60929 m
.64708 .53499 L
s
0 0 0 r
2.5 Mabswid
.40763 .60929 Mdot
0 1 .532 r
.5 Mabswid
.36715 .57139 m
.40763 .60929 L
s
0 1 .2 r
.56994 .38081 m
.76944 .35788 L
s
.045 1 0 r
.56994 .38081 m
.57081 .4463 L
s
0 0 0 r
2.5 Mabswid
.56994 .38081 Mdot
.333 1 0 r
.5 Mabswid
.41175 .48485 m
.56994 .38081 L
s
0 .038 1 r
.52423 .63797 m
.37164 .45094 L
s
0 0 0 r
2.5 Mabswid
.52423 .63797 Mdot
0 .038 1 r
.5 Mabswid
.55958 .61235 m
.52423 .63797 L
s
.8 1 0 r
.45307 .63538 m
.45939 .66649 L
s
0 0 0 r
2.5 Mabswid
.45307 .63538 Mdot
.37214 .43322 Mdot
0 .282 1 r
.5 Mabswid
.43182 .41593 m
.37214 .43322 L
s
1 .728 0 r
.47998 .36041 m
.51142 .36512 L
s
0 0 0 r
2.5 Mabswid
.47998 .36041 Mdot
1 .728 0 r
.5 Mabswid
.4267 .62502 m
.47998 .36041 L
s
0 0 0 r
2.5 Mabswid
.63424 .46409 Mdot
0 1 .632 r
.5 Mabswid
.63839 .37018 m
.63424 .46409 L
s
0 0 0 r
2.5 Mabswid
.35614 .52078 Mdot
.789 1 0 r
.5 Mabswid
.33965 .52133 m
.35614 .52078 L
s
.797 1 0 r
.38099 .41889 m
.51202 .67173 L
s
0 0 0 r
2.5 Mabswid
.38099 .41889 Mdot
.797 1 0 r
.5 Mabswid
.3995 .38931 m
.38099 .41889 L
s
.045 1 0 r
.35783 .47022 m
.37424 .40489 L
s
0 0 0 r
2.5 Mabswid
.35783 .47022 Mdot
.045 1 0 r
.5 Mabswid
.4659 .67276 m
.35783 .47022 L
s
.793 1 0 r
.63611 .47023 m
.6411 .47254 L
s
0 0 0 r
2.5 Mabswid
.63611 .47023 Mdot
.793 1 0 r
.5 Mabswid
.34808 .51545 m
.63611 .47023 L
s
0 1 .247 r
.59729 .60338 m
.5114 .52881 L
s
0 0 0 r
2.5 Mabswid
.59729 .60338 Mdot
.819 1 0 r
.5 Mabswid
.56733 .52368 m
.59729 .60338 L
s
.056 1 0 r
.35822 .46457 m
.60007 .40769 L
s
0 0 0 r
2.5 Mabswid
.35822 .46457 Mdot
1 .85 0 r
.5 Mabswid
.36013 .5001 m
.35822 .46457 L
s
0 1 .632 r
.53593 .63842 m
.47744 .67962 L
s
0 0 0 r
2.5 Mabswid
.53593 .63842 Mdot
.797 1 0 r
.5 Mabswid
.53127 .36107 m
.43445 .65212 L
s
0 0 0 r
2.5 Mabswid
.53127 .36107 Mdot
.797 1 0 r
.5 Mabswid
.53607 .36539 m
.53127 .36107 L
s
0 1 .381 r
.44285 .36497 m
.40677 .47234 L
s
0 0 0 r
2.5 Mabswid
.44285 .36497 Mdot
0 1 .381 r
.5 Mabswid
.52674 .41033 m
.44285 .36497 L
s
0 .038 1 r
.48531 .35666 m
.64082 .52362 L
s
0 0 0 r
2.5 Mabswid
.48531 .35666 Mdot
0 .038 1 r
.5 Mabswid
.44144 .35235 m
.48531 .35666 L
s
.8 1 0 r
.47399 .64325 m
.50871 .6466 L
s
0 0 0 r
2.5 Mabswid
.47399 .64325 Mdot
.8 1 0 r
.5 Mabswid
.39291 .3789 m
.47399 .64325 L
s
.435 1 0 r
.61636 .5825 m
.6297 .62774 L
s
0 0 0 r
2.5 Mabswid
.61636 .5825 Mdot
0 1 .532 r
.5 Mabswid
.50968 .35468 m
.50378 .34727 L
s
0 0 0 r
2.5 Mabswid
.50968 .35468 Mdot
0 1 .532 r
.5 Mabswid
.45903 .66426 m
.50968 .35468 L
s
0 1 .326 r
.59303 .60979 m
.50896 .53765 L
s
0 0 0 r
2.5 Mabswid
.59303 .60979 Mdot
.814 1 0 r
.5 Mabswid
.56366 .53221 m
.59303 .60979 L
s
0 .038 1 r
.64082 .52362 m
.63701 .57799 L
s
0 0 0 r
2.5 Mabswid
.64082 .52362 Mdot
.37138 .57765 Mdot
0 .538 1 r
.5 Mabswid
.34097 .56589 m
.37138 .57765 L
s
0 .038 1 r
.60331 .39713 m
.39438 .64933 L
s
0 0 0 r
2.5 Mabswid
.60331 .39713 Mdot
0 .038 1 r
.5 Mabswid
.60917 .39975 m
.60331 .39713 L
s
0 1 .632 r
.39983 .38757 m
.44314 .35657 L
s
0 0 0 r
2.5 Mabswid
.39983 .38757 Mdot
0 1 .632 r
.5 Mabswid
.35708 .61309 m
.39983 .38757 L
s
.865 1 0 r
.38875 .39921 m
.36882 .3792 L
s
0 0 0 r
2.5 Mabswid
.38875 .39921 Mdot
0 1 .632 r
.5 Mabswid
.35409 .46237 m
.35443 .39256 L
s
0 0 0 r
2.5 Mabswid
.35409 .46237 Mdot
.047 1 0 r
.5 Mabswid
.35202 .46908 m
.59096 .41292 L
s
0 0 0 r
2.5 Mabswid
.35202 .46908 Mdot
1 .857 0 r
.5 Mabswid
.35377 .50006 m
.35202 .46908 L
s
0 0 0 r
2.5 Mabswid
.51959 .64736 Mdot
.045 1 0 r
.5 Mabswid
.56818 .66665 m
.51959 .64736 L
s
0 0 0 r
2.5 Mabswid
.34808 .51545 Mdot
.793 1 0 r
.5 Mabswid
.33438 .51581 m
.34808 .51545 L
s
0 .149 1 r
.47485 .64736 m
.48327 .64621 L
s
0 0 0 r
2.5 Mabswid
.47485 .64736 Mdot
0 .149 1 r
.5 Mabswid
.48019 .35439 m
.47485 .64736 L
s
0 1 .542 r
.63579 .44531 m
.65101 .43803 L
s
0 0 0 r
2.5 Mabswid
.63579 .44531 Mdot
0 .542 1 r
.5 Mabswid
.34554 .492 m
.40884 .58529 L
s
0 0 0 r
2.5 Mabswid
.34554 .492 Mdot
0 .542 1 r
.5 Mabswid
.40831 .43786 m
.34554 .492 L
s
0 0 0 r
2.5 Mabswid
.63775 .55176 Mdot
0 .418 1 r
.5 Mabswid
.51664 .51828 m
.63775 .55176 L
s
0 1 .632 r
.62713 .42855 m
.65327 .52753 L
s
0 0 0 r
2.5 Mabswid
.62713 .42855 Mdot
0 1 .632 r
.5 Mabswid
.44314 .35657 m
.62713 .42855 L
s
0 1 .381 r
.59274 .3864 m
.54394 .35112 L
s
0 0 0 r
2.5 Mabswid
.59274 .3864 Mdot
0 1 .381 r
.5 Mabswid
.61893 .62179 m
.59274 .3864 L
s
0 .13 1 r
.64305 .4678 m
.32239 .53639 L
s
0 0 0 r
2.5 Mabswid
.64305 .4678 Mdot
0 .13 1 r
.5 Mabswid
.64303 .46629 m
.64305 .4678 L
s
.8 1 0 r
.41365 .37479 m
.39291 .3789 L
s
0 0 0 r
2.5 Mabswid
.41365 .37479 Mdot
.8 1 0 r
.5 Mabswid
.66113 .57466 m
.41365 .37479 L
s
0 .538 1 r
.64367 .46952 m
.65849 .41401 L
s
0 0 0 r
2.5 Mabswid
.64367 .46952 Mdot
0 1 .632 r
.5 Mabswid
.6095 .39804 m
.65694 .4932 L
s
0 0 0 r
2.5 Mabswid
.6095 .39804 Mdot
0 1 .632 r
.5 Mabswid
.44769 .32792 m
.6095 .39804 L
s
0 0 0 r
2.5 Mabswid
.45426 .64698 Mdot
0 1 .632 r
.5 Mabswid
.47744 .67962 m
.45426 .64698 L
s
.63872 .5559 m
.46249 .67565 L
s
0 0 0 r
2.5 Mabswid
.63872 .5559 Mdot
0 1 .632 r
.5 Mabswid
.66739 .47441 m
.63872 .5559 L
s
0 .149 1 r
.64564 .52597 m
.63456 .50192 L
s
0 0 0 r
2.5 Mabswid
.64564 .52597 Mdot
0 .149 1 r
.5 Mabswid
.37148 .54328 m
.64564 .52597 L
s
0 .298 1 r
.54712 .64423 m
.50173 .55338 L
s
0 0 0 r
2.5 Mabswid
.54712 .64423 Mdot
0 1 .595 r
.5 Mabswid
.54858 .57253 m
.54712 .64423 L
s
0 .989 1 r
.36572 .5801 m
.51603 .63962 L
s
0 0 0 r
2.5 Mabswid
.36572 .5801 Mdot
0 .989 1 r
.5 Mabswid
.34545 .51043 m
.36572 .5801 L
s
.039 1 0 r
.34584 .47362 m
.58114 .41835 L
s
0 0 0 r
2.5 Mabswid
.34584 .47362 Mdot
1 .864 0 r
.5 Mabswid
.3474 .50001 m
.34584 .47362 L
s
0 0 0 r
2.5 Mabswid
.64549 .53132 Mdot
.737 1 0 r
.5 Mabswid
.65919 .53128 m
.64549 .53132 L
s
0 .542 1 r
.62139 .4135 m
.40831 .43786 L
s
0 0 0 r
2.5 Mabswid
.62139 .4135 Mdot
0 .542 1 r
.5 Mabswid
.61645 .46751 m
.62139 .4135 L
s
1 .728 0 r
.60887 .39411 m
.61062 .38702 L
s
0 0 0 r
2.5 Mabswid
.60887 .39411 Mdot
1 .728 0 r
.5 Mabswid
.4428 .6498 m
.60887 .39411 L
s
0 .364 1 r
.4254 .36511 m
.44048 .3443 L
s
0 0 0 r
2.5 Mabswid
.4254 .36511 Mdot
0 .364 1 r
.5 Mabswid
.44954 .65125 m
.4254 .36511 L
s
0 1 .532 r
.43712 .64389 m
.45104 .65348 L
s
0 0 0 r
2.5 Mabswid
.43712 .64389 Mdot
0 1 .532 r
.5 Mabswid
.50378 .34727 m
.43712 .64389 L
s
0 .348 1 r
.34026 .49452 m
.42836 .5461 L
s
0 0 0 r
2.5 Mabswid
.34026 .49452 Mdot
0 1 .522 r
.5 Mabswid
.38576 .48466 m
.34026 .49452 L
s
0 1 .453 r
.49635 .34637 m
.59014 .5243 L
s
0 0 0 r
2.5 Mabswid
.49635 .34637 Mdot
0 1 .453 r
.5 Mabswid
.47451 .37543 m
.49635 .34637 L
s
0 .989 1 r
.51018 .3464 m
.32377 .53381 L
s
0 0 0 r
2.5 Mabswid
.51018 .3464 Mdot
0 .989 1 r
.5 Mabswid
.54617 .35371 m
.51018 .3464 L
s
.778 1 0 r
.43515 .64359 m
.47902 .38676 L
s
0 0 0 r
2.5 Mabswid
.43515 .64359 Mdot
.778 1 0 r
.5 Mabswid
.45544 .64966 m
.43515 .64359 L
s
.514 1 0 r
.42747 .36248 m
.42812 .35267 L
s
0 0 0 r
2.5 Mabswid
.42747 .36248 Mdot
.514 1 0 r
.5 Mabswid
.56392 .66372 m
.42747 .36248 L
s
1 .886 0 r
.37192 .59324 m
.36184 .61581 L
s
0 0 0 r
2.5 Mabswid
.37192 .59324 Mdot
.741 1 0 r
.5 Mabswid
.49396 .34552 m
.46766 .36333 L
s
0 0 0 r
2.5 Mabswid
.49396 .34552 Mdot
.741 1 0 r
.5 Mabswid
.6185 .54298 m
.49396 .34552 L
s
.333 1 0 r
.5025 .34429 m
.57955 .48167 L
s
0 0 0 r
2.5 Mabswid
.5025 .34429 Mdot
.778 1 0 r
.5 Mabswid
.47902 .38676 m
.5025 .34429 L
s
0 .989 1 r
.45443 .35101 m
.42559 .36773 L
s
0 0 0 r
2.5 Mabswid
.45443 .35101 Mdot
0 .989 1 r
.5 Mabswid
.60469 .55064 m
.45443 .35101 L
s
0 .542 1 r
.558 .64403 m
.62884 .58648 L
s
0 0 0 r
2.5 Mabswid
.558 .64403 Mdot
0 .542 1 r
.5 Mabswid
.40884 .58529 m
.558 .64403 L
s
0 1 .381 r
.36017 .57717 m
.43406 .60511 L
s
0 0 0 r
2.5 Mabswid
.36017 .57717 Mdot
0 1 .381 r
.5 Mabswid
.37306 .47682 m
.36017 .57717 L
s
.58891 .62465 m
.60316 .63248 L
s
0 0 0 r
2.5 Mabswid
.58891 .62465 Mdot
.741 1 0 r
.5 Mabswid
.36234 .42008 m
.35156 .4329 L
s
0 0 0 r
2.5 Mabswid
.36234 .42008 Mdot
.741 1 0 r
.5 Mabswid
.66022 .49498 m
.36234 .42008 L
s
0 0 0 r
2.5 Mabswid
.44954 .65125 Mdot
0 .364 1 r
.5 Mabswid
.4576 .66224 m
.44954 .65125 L
s
0 0 0 r
2.5 Mabswid
.4428 .6498 Mdot
1 .728 0 r
.5 Mabswid
.43015 .65725 m
.4428 .6498 L
s
0 .542 1 r
.36204 .41923 m
.51733 .67486 L
s
0 0 0 r
2.5 Mabswid
.36204 .41923 Mdot
0 .542 1 r
.5 Mabswid
.36826 .40251 m
.36204 .41923 L
s
.741 1 0 r
.36433 .41567 m
.37082 .6332 L
s
0 0 0 r
2.5 Mabswid
.36433 .41567 Mdot
.741 1 0 r
.5 Mabswid
.39042 .37103 m
.36433 .41567 L
s
.797 1 0 r
.65079 .52187 m
.3995 .38931 L
s
0 0 0 r
2.5 Mabswid
.65079 .52187 Mdot
.797 1 0 r
.5 Mabswid
.63668 .5424 m
.65079 .52187 L
s
0 0 0 r
2.5 Mabswid
.37601 .39898 Mdot
.045 1 0 r
.5 Mabswid
.346 .40709 m
.37601 .39898 L
s
0 1 .8 r
.33533 .49885 m
.32538 .23706 L
s
0 1 .643 r
.33533 .49885 m
.39082 .46885 L
s
0 0 0 r
2.5 Mabswid
.33533 .49885 Mdot
0 1 .453 r
.5 Mabswid
.39046 .55812 m
.33533 .49885 L
s
.88 1 0 r
.61749 .60168 m
.63413 .62432 L
s
0 0 0 r
2.5 Mabswid
.61749 .60168 Mdot
.031 1 0 r
.5 Mabswid
.33969 .47819 m
.57144 .42381 L
s
0 0 0 r
2.5 Mabswid
.33969 .47819 Mdot
1 .871 0 r
.5 Mabswid
.34103 .49997 m
.33969 .47819 L
s
0 .829 1 r
.64672 .45572 m
.6423 .44338 L
s
0 0 0 r
2.5 Mabswid
.64672 .45572 Mdot
0 .829 1 r
.5 Mabswid
.34657 .57536 m
.64672 .45572 L
s
.778 1 0 r
.50364 .34134 m
.5501 .34525 L
s
0 0 0 r
2.5 Mabswid
.50364 .34134 Mdot
.778 1 0 r
.5 Mabswid
.37766 .53645 m
.50364 .34134 L
s
0 .038 1 r
.37218 .59904 m
.60917 .39975 L
s
0 0 0 r
2.5 Mabswid
.37218 .59904 Mdot
0 .038 1 r
.5 Mabswid
.37269 .60295 m
.37218 .59904 L
s
0 .989 1 r
.62398 .59197 m
.66715 .51474 L
s
0 0 0 r
2.5 Mabswid
.62398 .59197 Mdot
0 .989 1 r
.5 Mabswid
.45038 .67472 m
.62398 .59197 L
s
.045 1 0 r
.59074 .62597 m
.56818 .66665 L
s
0 0 0 r
2.5 Mabswid
.59074 .62597 Mdot
0 .989 1 r
.5 Mabswid
.33412 .4994 m
.3334 .50007 L
s
0 0 0 r
2.5 Mabswid
.33412 .4994 Mdot
0 .149 1 r
.5 Mabswid
.35442 .5753 m
.54737 .48979 L
s
0 0 0 r
2.5 Mabswid
.35442 .5753 Mdot
0 .149 1 r
.5 Mabswid
.35469 .56498 m
.35442 .5753 L
s
.801 1 0 r
.61983 .40205 m
.38401 .52879 L
s
0 0 0 r
2.5 Mabswid
.61983 .40205 Mdot
.801 1 0 r
.5 Mabswid
.60969 .41397 m
.61983 .40205 L
s
0 .149 1 r
.5074 .34094 m
.48019 .35439 L
s
0 0 0 r
2.5 Mabswid
.5074 .34094 Mdot
0 .149 1 r
.5 Mabswid
.52713 .54932 m
.5074 .34094 L
s
0 .542 1 r
.44656 .65365 m
.47195 .64072 L
s
0 0 0 r
2.5 Mabswid
.44656 .65365 Mdot
0 .542 1 r
.5 Mabswid
.39844 .48206 m
.44656 .65365 L
s
0 .989 1 r
.3334 .50007 m
.31821 .51525 L
s
0 0 0 r
2.5 Mabswid
.3334 .50007 Mdot
0 .2 1 r
.5 Mabswid
.34469 .44769 m
.4956 .52726 L
s
0 0 0 r
2.5 Mabswid
.34469 .44769 Mdot
0 .2 1 r
.5 Mabswid
.35697 .43856 m
.34469 .44769 L
s
.045 1 0 r
.55965 .3538 m
.61759 .39413 L
s
0 0 0 r
2.5 Mabswid
.55965 .3538 Mdot
.045 1 0 r
.5 Mabswid
.37424 .40489 m
.55965 .3538 L
s
0 .989 1 r
.33333 .50309 m
.40192 .58524 L
s
0 0 0 r
2.5 Mabswid
.33333 .50309 Mdot
0 .989 1 r
.5 Mabswid
.35259 .4404 m
.33333 .50309 L
s
.797 1 0 r
.62549 .40884 m
.38906 .53673 L
s
0 0 0 r
2.5 Mabswid
.62549 .40884 Mdot
.797 1 0 r
.5 Mabswid
.61591 .42047 m
.62549 .40884 L
s
.699 1 0 r
.62792 .58963 m
.63782 .62229 L
s
0 0 0 r
2.5 Mabswid
.62792 .58963 Mdot
0 1 .381 r
.5 Mabswid
.5433 .34858 m
.37306 .47682 L
s
0 0 0 r
2.5 Mabswid
.5433 .34858 Mdot
0 1 .381 r
.5 Mabswid
.58755 .37609 m
.5433 .34858 L
s
0 .989 1 r
.40796 .63473 m
.42427 .64626 L
s
0 0 0 r
2.5 Mabswid
.40796 .63473 Mdot
0 .989 1 r
.5 Mabswid
.42559 .36773 m
.40796 .63473 L
s
0 .542 1 r
.40022 .63008 m
.6664 .46571 L
s
0 0 0 r
2.5 Mabswid
.40022 .63008 Mdot
0 .542 1 r
.5 Mabswid
.38325 .6225 m
.40022 .63008 L
s
0 0 0 r
2.5 Mabswid
.65326 .52582 Mdot
.741 1 0 r
.5 Mabswid
.66502 .52567 m
.65326 .52582 L
s
.03 0 1 r
.64531 .43884 m
.56805 .52499 L
s
0 0 0 r
2.5 Mabswid
.64531 .43884 Mdot
0 1 .665 r
.5 Mabswid
.57144 .42381 m
.64531 .43884 L
s
0 1 .632 r
.53318 .65685 m
.48067 .61057 L
s
0 0 0 r
2.5 Mabswid
.53318 .65685 Mdot
.045 1 0 r
.5 Mabswid
.55884 .55556 m
.53318 .65685 L
s
.746 1 0 r
.49864 .33836 m
.47614 .35344 L
s
0 0 0 r
2.5 Mabswid
.49864 .33836 Mdot
.746 1 0 r
.5 Mabswid
.61963 .53004 m
.49864 .33836 L
s
.732 1 0 r
.65405 .52857 m
.3435 .42851 L
s
0 0 0 r
2.5 Mabswid
.65405 .52857 Mdot
.732 1 0 r
.5 Mabswid
.65205 .53657 m
.65405 .52857 L
s
0 .989 1 r
.51673 .34018 m
.41221 .49474 L
s
0 0 0 r
2.5 Mabswid
.51673 .34018 Mdot
0 .989 1 r
.5 Mabswid
.53292 .36684 m
.51673 .34018 L
s
.022 1 0 r
.33357 .4828 m
.55968 .42978 L
s
0 0 0 r
2.5 Mabswid
.33357 .4828 Mdot
1 .878 0 r
.5 Mabswid
.33467 .49992 m
.33357 .4828 L
s
0 1 .381 r
.65344 .53343 m
.61817 .46833 L
s
0 0 0 r
2.5 Mabswid
.65344 .53343 Mdot
0 1 .381 r
.5 Mabswid
.50883 .60374 m
.65344 .53343 L
s
.746 1 0 r
.47981 .66187 m
.48623 .66398 L
s
0 0 0 r
2.5 Mabswid
.47981 .66187 Mdot
.746 1 0 r
.5 Mabswid
.47614 .35344 m
.47981 .66187 L
s
0 .989 1 r
.47638 .66142 m
.51994 .67274 L
s
0 0 0 r
2.5 Mabswid
.47638 .66142 Mdot
0 .989 1 r
.5 Mabswid
.31779 .48654 m
.47638 .66142 L
s
0 1 .381 r
.45868 .65891 m
.52839 .58439 L
s
0 0 0 r
2.5 Mabswid
.45868 .65891 Mdot
0 1 .381 r
.5 Mabswid
.42631 .60892 m
.45868 .65891 L
s
.797 1 0 r
.4378 .65595 m
.5474 .43697 L
s
0 0 0 r
2.5 Mabswid
.4378 .65595 Mdot
.797 1 0 r
.5 Mabswid
.43445 .65212 m
.4378 .65595 L
s
0 1 .453 r
.50807 .66573 m
.49371 .65507 L
s
0 0 0 r
2.5 Mabswid
.50807 .66573 Mdot
0 1 .453 r
.5 Mabswid
.49752 .47305 m
.50807 .66573 L
s
0 .542 1 r
.57128 .35461 m
.36817 .52461 L
s
0 0 0 r
2.5 Mabswid
.57128 .35461 Mdot
0 .542 1 r
.5 Mabswid
.57792 .36794 m
.57128 .35461 L
s
.741 1 0 r
.43705 .65694 m
.50985 .61927 L
s
0 0 0 r
2.5 Mabswid
.43705 .65694 Mdot
.741 1 0 r
.5 Mabswid
.40879 .59834 m
.43705 .65694 L
s
0 0 0 r
2.5 Mabswid
.39566 .63271 Mdot
0 1 .632 r
.5 Mabswid
.38535 .37524 m
.62314 .36325 L
s
0 0 0 r
2.5 Mabswid
.38535 .37524 Mdot
0 1 .632 r
.5 Mabswid
.35443 .39256 m
.38535 .37524 L
s
0 .542 1 r
.43162 .3463 m
.38325 .6225 L
s
0 0 0 r
2.5 Mabswid
.43162 .3463 Mdot
0 .542 1 r
.5 Mabswid
.45299 .33066 m
.43162 .3463 L
s
.778 1 0 r
.6555 .46023 m
.45544 .64966 L
s
0 0 0 r
2.5 Mabswid
.6555 .46023 Mdot
.778 1 0 r
.5 Mabswid
.64315 .42778 m
.6555 .46023 L
s
0 .829 1 r
.34468 .57592 m
.34657 .57536 L
s
0 0 0 r
2.5 Mabswid
.34468 .57592 Mdot
0 .829 1 r
.5 Mabswid
.52959 .43136 m
.34468 .57592 L
s
.49736 .33359 m
.47492 .3387 L
s
0 0 0 r
2.5 Mabswid
.49736 .33359 Mdot
0 .829 1 r
.5 Mabswid
.65574 .54043 m
.49736 .33359 L
s
.045 1 0 r
.32747 .48745 m
.53808 .43811 L
s
0 0 0 r
2.5 Mabswid
.32747 .48745 Mdot
1 .866 0 r
.5 Mabswid
.3283 .49987 m
.32747 .48745 L
s
.797 1 0 r
.34484 .57702 m
.61591 .42047 L
s
0 0 0 r
2.5 Mabswid
.34484 .57702 Mdot
.797 1 0 r
.5 Mabswid
.3423 .57601 m
.34484 .57702 L
s
.089 0 1 r
.64809 .43202 m
.58785 .55958 L
s
0 0 0 r
2.5 Mabswid
.64809 .43202 Mdot
0 1 .653 r
.5 Mabswid
.58114 .41835 m
.64809 .43202 L
s
.741 1 0 r
.43249 .34436 m
.41207 .38411 L
s
0 0 0 r
2.5 Mabswid
.43249 .34436 Mdot
.741 1 0 r
.5 Mabswid
.54993 .3853 m
.43249 .34436 L
s
.732 1 0 r
.34078 .42883 m
.51448 .58654 L
s
0 0 0 r
2.5 Mabswid
.34078 .42883 Mdot
.732 1 0 r
.5 Mabswid
.3435 .42851 m
.34078 .42883 L
s
0 0 0 r
2.5 Mabswid
.45903 .66426 Mdot
0 1 .532 r
.5 Mabswid
.45723 .6713 m
.45903 .66426 L
s
0 0 0 r
2.5 Mabswid
.66105 .5203 Mdot
.746 1 0 r
.5 Mabswid
.67083 .52009 m
.66105 .5203 L
s
0 1 .632 r
.42214 .34962 m
.42983 .3258 L
s
0 0 0 r
2.5 Mabswid
.42214 .34962 Mdot
.797 1 0 r
.5 Mabswid
.52373 .66603 m
.55585 .32905 L
s
0 0 0 r
2.5 Mabswid
.52373 .66603 Mdot
.797 1 0 r
.5 Mabswid
.51202 .67173 m
.52373 .66603 L
s
.741 1 0 r
.47119 .6667 m
.47573 .66835 L
s
0 0 0 r
2.5 Mabswid
.47119 .6667 Mdot
.741 1 0 r
.5 Mabswid
.46766 .36333 m
.47119 .6667 L
s
0 0 0 r
2.5 Mabswid
.66117 .47937 Mdot
0 .989 1 r
.5 Mabswid
.67283 .48926 m
.66117 .47937 L
s
0 .542 1 r
.37829 .37545 m
.37183 .3749 L
s
0 0 0 r
2.5 Mabswid
.37829 .37545 Mdot
0 .542 1 r
.5 Mabswid
.6647 .51835 m
.37829 .37545 L
s
.801 1 0 r
.3383 .57153 m
.60969 .41397 L
s
0 0 0 r
2.5 Mabswid
.3383 .57153 Mdot
.801 1 0 r
.5 Mabswid
.33626 .5707 m
.3383 .57153 L
s
0 .989 1 r
.32598 .51876 m
.3497 .57912 L
s
0 0 0 r
2.5 Mabswid
.32598 .51876 Mdot
0 .989 1 r
.5 Mabswid
.33328 .44592 m
.32598 .51876 L
s
0 1 .598 r
.65967 .46808 m
.43182 .41593 L
s
0 0 0 r
2.5 Mabswid
.65967 .46808 Mdot
1 .992 0 r
.5 Mabswid
.64766 .50009 m
.65967 .46808 L
s
0 .989 1 r
.62283 .38859 m
.53792 .32106 L
s
0 0 0 r
2.5 Mabswid
.62283 .38859 Mdot
0 .989 1 r
.5 Mabswid
.66715 .51474 m
.62283 .38859 L
s
0 1 .532 r
.66452 .49119 m
.49038 .41607 L
s
0 0 0 r
2.5 Mabswid
.66452 .49119 Mdot
0 1 .532 r
.5 Mabswid
.64708 .53499 m
.66452 .49119 L
s
0 .829 1 r
.65072 .56894 m
.65574 .54043 L
s
0 0 0 r
2.5 Mabswid
.65072 .56894 Mdot
0 .829 1 r
.5 Mabswid
.40031 .55126 m
.65072 .56894 L
s
.8 1 0 r
.59535 .36551 m
.58009 .35941 L
s
0 0 0 r
2.5 Mabswid
.59535 .36551 Mdot
.8 1 0 r
.5 Mabswid
.50871 .6466 m
.59535 .36551 L
s
.741 1 0 r
.66296 .51961 m
.66022 .49498 L
s
0 0 0 r
2.5 Mabswid
.66296 .51961 Mdot
.741 1 0 r
.5 Mabswid
.39182 .58235 m
.66296 .51961 L
s
0 0 0 r
2.5 Mabswid
.32538 .23706 Mdot
0 g
.5 Mabswid
.76927 .76623 m
.24072 .76247 L
s
.24072 .76247 m
.24 .23648 L
s
.17573 .81281 m
.24072 .76247 L
s
0 0 0 r
2.5 Mabswid
.6647 .51835 Mdot
0 .542 1 r
.5 Mabswid
.66656 .53154 m
.6647 .51835 L
s
0 .989 1 r
.35447 .40198 m
.35058 .42745 L
s
0 0 0 r
2.5 Mabswid
.35447 .40198 Mdot
0 .989 1 r
.5 Mabswid
.46581 .38191 m
.35447 .40198 L
s
.045 1 0 r
.48707 .67282 m
.4659 .67276 L
s
0 0 0 r
2.5 Mabswid
.48707 .67282 Mdot
.045 1 0 r
.5 Mabswid
.68538 .5132 m
.48707 .67282 L
s
0 0 0 r
2.5 Mabswid
.61893 .62179 Mdot
0 1 .381 r
.5 Mabswid
.60817 .63925 m
.61893 .62179 L
s
0 .149 1 r
.62932 .39376 m
.61291 .37646 L
s
0 0 0 r
2.5 Mabswid
.62932 .39376 Mdot
0 .149 1 r
.5 Mabswid
.48327 .64621 m
.62932 .39376 L
s
0 .2 1 r
.37379 .62866 m
.39323 .62596 L
s
0 0 0 r
2.5 Mabswid
.37379 .62866 Mdot
0 1 .522 r
.5 Mabswid
.40971 .57742 m
.37379 .62866 L
s
0 .989 1 r
.32655 .54041 m
.5786 .65002 L
s
0 0 0 r
2.5 Mabswid
.32655 .54041 Mdot
0 .989 1 r
.5 Mabswid
.32377 .53381 m
.32655 .54041 L
s
.58797 .35685 m
.3717 .36482 L
s
0 0 0 r
2.5 Mabswid
.58797 .35685 Mdot
0 .989 1 r
.5 Mabswid
.62969 .38534 m
.58797 .35685 L
s
0 .542 1 r
.42939 .33907 m
.39844 .48206 L
s
0 0 0 r
2.5 Mabswid
.42939 .33907 Mdot
0 .542 1 r
.5 Mabswid
.45686 .33578 m
.42939 .33907 L
s
.741 1 0 r
.66958 .49903 m
.43788 .42441 L
s
0 0 0 r
2.5 Mabswid
.66958 .49903 Mdot
.741 1 0 r
.5 Mabswid
.6622 .52725 m
.66958 .49903 L
s
.66313 .53763 m
.67349 .48606 L
s
0 0 0 r
2.5 Mabswid
.66313 .53763 Mdot
.741 1 0 r
.5 Mabswid
.50148 .68669 m
.66313 .53763 L
s
.069 0 1 r
.6506 .42513 m
.59334 .54689 L
s
0 0 0 r
2.5 Mabswid
.6506 .42513 Mdot
0 1 .64 r
.5 Mabswid
.59096 .41292 m
.6506 .42513 L
s
0 0 0 r
2.5 Mabswid
.67568 .76265 Mdot
.741 1 0 r
.5 Mabswid
.3652 .38393 m
.35962 .39298 L
s
0 0 0 r
2.5 Mabswid
.3652 .38393 Mdot
.741 1 0 r
.5 Mabswid
.58632 .38646 m
.3652 .38393 L
s
.045 1 0 r
.3376 .58062 m
.33526 .58042 L
s
0 0 0 r
2.5 Mabswid
.3376 .58062 Mdot
0 1 .056 r
.5 Mabswid
.6653 .47276 m
.4404 .42131 L
s
0 0 0 r
2.5 Mabswid
.6653 .47276 Mdot
1 .946 0 r
.5 Mabswid
.65503 .50004 m
.6653 .47276 L
s
.333 1 0 r
.32637 .54962 m
.41175 .48485 L
s
0 0 0 r
2.5 Mabswid
.32637 .54962 Mdot
.333 1 0 r
.5 Mabswid
.33215 .55403 m
.32637 .54962 L
s
0 1 .632 r
.59945 .63883 m
.54525 .65788 L
s
0 0 0 r
2.5 Mabswid
.59945 .63883 Mdot
0 1 .632 r
.5 Mabswid
.65694 .4932 m
.59945 .63883 L
s
0 0 0 r
2.5 Mabswid
.3473 .4072 Mdot
0 .931 1 r
.5 Mabswid
.3773 .41116 m
.3473 .4072 L
s
0 .989 1 r
.49054 .67618 m
.63744 .55593 L
s
0 0 0 r
2.5 Mabswid
.49054 .67618 Mdot
0 .989 1 r
.5 Mabswid
.47073 .66995 m
.49054 .67618 L
s
0 .542 1 r
.52806 .67182 m
.57792 .36794 L
s
0 0 0 r
2.5 Mabswid
.52806 .67182 Mdot
0 .542 1 r
.5 Mabswid
.51733 .67486 m
.52806 .67182 L
s
0 g
.3154 .49975 m
.31456 .49979 L
s
.32956 .42773 m
.3154 .49975 L
s
.3154 .49972 m
.3297 .5717 L
s
.31456 .49976 m
.3154 .49972 L
s
.31537 .49975 m
.32953 .42772 L
s
.32968 .57171 m
.31537 .49972 L
s
0 1 .711 r
.66902 .51312 m
.57965 .53353 L
s
0 0 0 r
2.5 Mabswid
.66902 .51312 Mdot
.699 1 0 r
.5 Mabswid
.61284 .47107 m
.66902 .51312 L
s
.741 1 0 r
.35509 .6075 m
.36281 .61193 L
s
0 0 0 r
2.5 Mabswid
.35509 .6075 Mdot
.741 1 0 r
.5 Mabswid
.3983 .48217 m
.35509 .6075 L
s
0 g
.32969 .57167 m
.37032 .63281 L
s
.3289 .57192 m
.32969 .57167 L
s
.3297 .5717 m
.32891 .57196 L
s
.3703 .63282 m
.32967 .57168 L
s
0 0 0 r
2.5 Mabswid
.34356 .41087 Mdot
0 .686 1 r
.5 Mabswid
.35621 .41011 m
.34356 .41087 L
s
0 .989 1 r
.50152 .324 m
.35259 .4404 L
s
0 0 0 r
2.5 Mabswid
.50152 .324 Mdot
0 .989 1 r
.5 Mabswid
.53792 .32106 m
.50152 .324 L
s
0 .149 1 r
.6229 .37904 m
.35469 .56498 L
s
0 0 0 r
2.5 Mabswid
.6229 .37904 Mdot
0 .149 1 r
.5 Mabswid
.63378 .38575 m
.6229 .37904 L
s
0 g
.24 .23648 m
.76966 .23275 L
s
.17471 .19118 m
.24 .23648 L
s
0 0 0 r
2.5 Mabswid
.56392 .66372 Mdot
.514 1 0 r
.5 Mabswid
.5695 .66796 m
.56392 .66372 L
s
0 0 0 r
2.5 Mabswid
.39693 .64777 Mdot
0 .538 1 r
.5 Mabswid
.39311 .64841 m
.39693 .64777 L
s
.608 1 0 r
.52564 .67401 m
.61011 .72733 L
s
0 .989 1 r
.52564 .67401 m
.53393 .65465 L
s
0 0 0 r
2.5 Mabswid
.52564 .67401 Mdot
.741 1 0 r
.5 Mabswid
.4562 .57495 m
.52564 .67401 L
s
0 1 .532 r
.50135 .67943 m
.51001 .68728 L
s
0 0 0 r
2.5 Mabswid
.50135 .67943 Mdot
0 .989 1 r
.5 Mabswid
.66634 .46744 m
.59406 .38691 L
s
0 0 0 r
2.5 Mabswid
.66634 .46744 Mdot
0 .989 1 r
.5 Mabswid
.63744 .55593 m
.66634 .46744 L
s
0 g
.32954 .42776 m
.32875 .42759 L
s
.3701 .36652 m
.32954 .42776 L
s
.32876 .42756 m
.32956 .42773 L
s
.32952 .42775 m
.37008 .36651 L
s
0 0 0 r
2.5 Mabswid
.31779 .48654 Mdot
0 .989 1 r
.5 Mabswid
.58272 .35664 m
.31779 .48654 L
s
.388 1 0 r
.65267 .42232 m
.65992 .40318 L
s
0 0 0 r
2.5 Mabswid
.65267 .42232 Mdot
0 g
.5 Mabswid
.3703 .63278 m
.43121 .67385 L
s
.36963 .63322 m
.3703 .63278 L
s
.37032 .63281 m
.36965 .63324 L
s
.4312 .67387 m
.37028 .6328 L
s
0 .542 1 r
.66393 .45162 m
.36826 .40251 L
s
0 0 0 r
2.5 Mabswid
.66393 .45162 Mdot
0 .542 1 r
.5 Mabswid
.6664 .46571 m
.66393 .45162 L
s
0 .989 1 r
.31821 .51525 m
.33925 .52778 L
s
0 0 0 r
2.5 Mabswid
.31821 .51525 Mdot
.045 1 0 r
.5 Mabswid
.33526 .58042 m
.33544 .57546 L
s
0 0 0 r
2.5 Mabswid
.33526 .58042 Mdot
0 .542 1 r
.5 Mabswid
.36355 .62271 m
.42915 .62013 L
s
0 0 0 r
2.5 Mabswid
.36355 .62271 Mdot
.114 0 1 r
.5 Mabswid
.32239 .53639 m
.32079 .53677 L
s
0 0 0 r
2.5 Mabswid
.32239 .53639 Mdot
.35708 .61309 Mdot
0 1 .632 r
.5 Mabswid
.54525 .65788 m
.35708 .61309 L
s
.741 1 0 r
.37082 .6332 m
.6622 .52725 L
s
0 0 0 r
2.5 Mabswid
.37082 .6332 Mdot
0 .538 1 r
.5 Mabswid
.66185 .56459 m
.64295 .52716 L
s
0 0 0 r
2.5 Mabswid
.66185 .56459 Mdot
0 .538 1 r
.5 Mabswid
.54813 .58154 m
.66185 .56459 L
s
0 0 0 r
2.5 Mabswid
.32079 .53677 Mdot
0 1 .632 r
.5 Mabswid
.46249 .67565 m
.45105 .67772 L
s
0 0 0 r
2.5 Mabswid
.46249 .67565 Mdot
.30726 .40437 Mdot
.8 1 0 r
.5 Mabswid
.3283 .49987 m
.30726 .40437 L
s
0 0 0 r
2.5 Mabswid
.30582 .3688 Mdot
.765 1 0 r
.5 Mabswid
.33467 .49992 m
.30582 .3688 L
s
0 0 0 r
2.5 Mabswid
.56335 .66668 Mdot
0 .938 1 r
.5 Mabswid
.56479 .67434 m
.56335 .66668 L
s
0 0 0 r
2.5 Mabswid
.45038 .67472 Mdot
0 .989 1 r
.5 Mabswid
.43853 .67596 m
.45038 .67472 L
s
.741 1 0 r
.60921 .63683 m
.6246 .60806 L
s
0 0 0 r
2.5 Mabswid
.60921 .63683 Mdot
.741 1 0 r
.5 Mabswid
.44778 .59336 m
.60921 .63683 L
s
0 0 0 r
2.5 Mabswid
.30439 .33316 Mdot
.766 1 0 r
.5 Mabswid
.34103 .49997 m
.30439 .33316 L
s
0 0 0 r
2.5 Mabswid
.44769 .32792 Mdot
0 1 .632 r
.5 Mabswid
.42983 .3258 m
.44769 .32792 L
s
.699 1 0 r
.3341 .42045 m
.42292 .42815 L
s
0 0 0 r
2.5 Mabswid
.3341 .42045 Mdot
.30297 .29745 Mdot
.767 1 0 r
.5 Mabswid
.3474 .50001 m
.30297 .29745 L
s
0 1 .066 r
.67091 .47749 m
.45733 .42865 L
s
0 0 0 r
2.5 Mabswid
.67091 .47749 Mdot
1 .954 0 r
.5 Mabswid
.6624 .49999 m
.67091 .47749 L
s
0 0 0 r
2.5 Mabswid
.30156 .26167 Mdot
.768 1 0 r
.5 Mabswid
.35377 .50006 m
.30156 .26167 L
s
0 .538 1 r
.43513 .32929 m
.41651 .35618 L
s
0 0 0 r
2.5 Mabswid
.43513 .32929 Mdot
0 .538 1 r
.5 Mabswid
.4711 .35502 m
.43513 .32929 L
s
0 g
.37007 .36655 m
.3694 .3662 L
s
.431 .32539 m
.37007 .36655 L
s
.36942 .36617 m
.3701 .36652 L
s
.37006 .36653 m
.43098 .32537 L
s
0 0 0 r
2.5 Mabswid
.37953 .69945 Mdot
0 .531 1 r
.5 Mabswid
.38629 .63711 m
.37953 .69945 L
s
0 0 0 r
2.5 Mabswid
.39311 .64841 Mdot
0 .538 1 r
.5 Mabswid
.38975 .64104 m
.39311 .64841 L
s
0 0 0 r
2.5 Mabswid
.3632 .37669 Mdot
0 1 .381 r
.5 Mabswid
.61817 .46833 m
.3632 .37669 L
s
0 g
.43118 .67384 m
.50324 .68854 L
s
.43068 .67439 m
.43118 .67384 L
s
.43121 .67385 m
.43072 .67441 L
s
.50324 .68857 m
.43117 .67386 L
s
.333 1 0 r
.64564 .59703 m
.61103 .60513 L
s
0 0 0 r
2.5 Mabswid
.64564 .59703 Mdot
.333 1 0 r
.5 Mabswid
.57955 .48167 m
.64564 .59703 L
s
0 .137 1 r
.39438 .64933 m
.39327 .65031 L
s
0 0 0 r
2.5 Mabswid
.39438 .64933 Mdot
0 1 .381 r
.5 Mabswid
.41162 .34028 m
.40408 .36717 L
s
0 0 0 r
2.5 Mabswid
.41162 .34028 Mdot
0 1 .381 r
.5 Mabswid
.44156 .34739 m
.41162 .34028 L
s
0 0 0 r
2.5 Mabswid
.35027 .60366 Mdot
0 .989 1 r
.5 Mabswid
.41221 .49474 m
.35027 .60366 L
s
0 0 0 r
2.5 Mabswid
.39327 .65031 Mdot
0 1 .453 r
.5 Mabswid
.60419 .64366 m
.59624 .58893 L
s
0 0 0 r
2.5 Mabswid
.60419 .64366 Mdot
.732 1 0 r
.5 Mabswid
.54692 .61353 m
.60419 .64366 L
s
0 0 0 r
2.5 Mabswid
.30234 .23582 Mdot
.77 1 0 r
.5 Mabswid
.36013 .5001 m
.30234 .23582 L
s
0 0 0 r
2.5 Mabswid
.40104 .66239 Mdot
0 .957 1 r
.5 Mabswid
.39662 .65123 m
.40104 .66239 L
s
0 g
.31456 .49979 m
.32876 .42755 L
s
.36175 .50013 m
.31456 .49979 L
s
.31456 .49976 m
.36175 .5001 L
s
.32891 .57196 m
.31456 .49976 L
s
.31456 .49979 m
.32876 .42756 L
s
.32891 .57196 m
.31456 .49976 L
s
0 0 0 r
2.5 Mabswid
.37062 .36593 Mdot
0 1 .532 r
.5 Mabswid
.49038 .41607 m
.37062 .36593 L
s
.741 1 0 r
.60384 .35777 m
.59977 .35309 L
s
0 0 0 r
2.5 Mabswid
.60384 .35777 Mdot
.741 1 0 r
.5 Mabswid
.47573 .66835 m
.60384 .35777 L
s
0 g
.32889 .57195 m
.40252 .59851 L
s
.36173 .50009 m
.32889 .57195 L
s
.32889 .57192 m
.40241 .59854 L
s
.36964 .63324 m
.32889 .57192 L
s
.36175 .5001 m
.32891 .57196 L
s
.36965 .63324 m
.3289 .57192 L
s
0 .989 1 r
.40196 .65454 m
.44328 .63964 L
s
0 0 0 r
2.5 Mabswid
.40196 .65454 Mdot
.36546 .37293 Mdot
0 1 .632 r
.5 Mabswid
.48067 .61057 m
.36546 .37293 L
s
0 .989 1 r
.44176 .32544 m
.42505 .34063 L
s
0 0 0 r
2.5 Mabswid
.44176 .32544 Mdot
0 .989 1 r
.5 Mabswid
.50812 .35973 m
.44176 .32544 L
s
0 0 0 r
2.5 Mabswid
.66113 .57466 Mdot
.8 1 0 r
.5 Mabswid
.66366 .57963 m
.66113 .57466 L
s
.2 0 1 r
.64638 .59909 m
.63907 .59049 L
s
0 0 0 r
2.5 Mabswid
.64638 .59909 Mdot
0 .2 1 r
.5 Mabswid
.4956 .52726 m
.64638 .59909 L
s
0 1 .522 r
.59682 .35131 m
.5511 .4059 L
s
0 0 0 r
2.5 Mabswid
.59682 .35131 Mdot
.797 1 0 r
.5 Mabswid
.57194 .39067 m
.59682 .35131 L
s
0 g
.32874 .42757 m
.36185 .50018 L
s
.40226 .40159 m
.32874 .42757 L
s
.32874 .42759 m
.36941 .36617 L
s
.40227 .40162 m
.32874 .42759 L
s
.32876 .42755 m
.36175 .50013 L
s
0 0 0 r
2.5 Mabswid
.37223 .36467 Mdot
.2 0 1 r
.5 Mabswid
.43772 .42081 m
.37223 .36467 L
s
0 g
.32875 .42759 m
.36942 .36617 L
s
0 0 0 r
2.5 Mabswid
.50148 .68669 Mdot
.741 1 0 r
.5 Mabswid
.49604 .68771 m
.50148 .68669 L
s
0 .989 1 r
.60789 .64331 m
.63605 .50181 L
s
0 0 0 r
2.5 Mabswid
.60789 .64331 Mdot
0 .989 1 r
.5 Mabswid
.5786 .65002 m
.60789 .64331 L
s
.797 1 0 r
.55472 .32855 m
.46268 .62149 L
s
0 0 0 r
2.5 Mabswid
.55472 .32855 Mdot
.797 1 0 r
.5 Mabswid
.55585 .32905 m
.55472 .32855 L
s
0 g
.43096 .3254 m
.43047 .32493 L
s
.50312 .31066 m
.43096 .3254 L
s
.4305 .32491 m
.431 .32539 L
s
.43096 .32538 m
.50312 .31063 L
s
.136 0 1 r
.65567 .41558 m
.61006 .48381 L
s
0 0 0 r
2.5 Mabswid
.65567 .41558 Mdot
0 1 .935 r
.5 Mabswid
.6015 .42093 m
.65567 .41558 L
s
0 g
.36963 .63323 m
.40239 .59852 L
s
.43071 .67442 m
.36963 .63323 L
s
.40241 .59854 m
.36964 .63324 L
s
.43072 .67441 m
.36963 .63322 L
s
0 0 0 r
2.5 Mabswid
.39662 .65123 Mdot
0 .829 1 r
.5 Mabswid
.47492 .3387 m
.39662 .65123 L
s
0 1 .075 r
.6765 .48227 m
.4761 .43646 L
s
0 0 0 r
2.5 Mabswid
.6765 .48227 Mdot
1 .962 0 r
.5 Mabswid
.66979 .49995 m
.6765 .48227 L
s
0 .149 1 r
.54341 .67758 m
.54424 .68075 L
s
0 0 0 r
2.5 Mabswid
.54341 .67758 Mdot
.32377 .53381 Mdot
0 1 .453 r
.5 Mabswid
.49611 .31519 m
.49752 .47305 L
s
0 0 0 r
2.5 Mabswid
.49611 .31519 Mdot
0 1 .453 r
.5 Mabswid
.49857 .31816 m
.49611 .31519 L
s
0 g
.50321 .68854 m
.57555 .67452 L
s
.50293 .68915 m
.50321 .68854 L
s
.50324 .68854 m
.50296 .68915 L
s
.57555 .67454 m
.50321 .68857 L
s
0 .989 1 r
.61483 .36229 m
.58272 .35664 L
s
0 0 0 r
2.5 Mabswid
.61483 .36229 Mdot
0 .989 1 r
.5 Mabswid
.63605 .50181 m
.61483 .36229 L
s
.3717 .36482 m
.33328 .44592 L
s
0 0 0 r
2.5 Mabswid
.3717 .36482 Mdot
0 1 .632 r
.5 Mabswid
.66302 .42503 m
.67724 .42988 L
s
0 0 0 r
2.5 Mabswid
.66302 .42503 Mdot
0 1 .532 r
.5 Mabswid
.51001 .68728 m
.53749 .63999 L
s
0 0 0 r
2.5 Mabswid
.51001 .68728 Mdot
0 g
.5 Mabswid
.3694 .36619 m
.4305 .32491 L
s
.40225 .40164 m
.3694 .36619 L
s
.36941 .36617 m
.40227 .40162 L
s
.3694 .3662 m
.4305 .32491 L
s
.045 1 0 r
.33544 .57546 m
.42322 .4216 L
s
0 0 0 r
2.5 Mabswid
.33544 .57546 Mdot
0 .439 1 r
.5 Mabswid
.66934 .43519 m
.57992 .46979 L
s
0 0 0 r
2.5 Mabswid
.66934 .43519 Mdot
0 1 .643 r
.5 Mabswid
.64425 .43269 m
.66934 .43519 L
s
.741 1 0 r
.54161 .32156 m
.46141 .38595 L
s
0 0 0 r
2.5 Mabswid
.54161 .32156 Mdot
.741 1 0 r
.5 Mabswid
.55377 .33499 m
.54161 .32156 L
s
1 .984 0 r
.36184 .61581 m
.48852 .77565 L
s
0 0 0 r
2.5 Mabswid
.36184 .61581 Mdot
0 g
.5 Mabswid
.43069 .67442 m
.50078 .63955 L
s
.40237 .59853 m
.43069 .67442 L
s
.43068 .6744 m
.50072 .63964 L
s
.50296 .68915 m
.43068 .6744 L
s
.40239 .59852 m
.43071 .67442 L
s
.50296 .68915 m
.43068 .67439 L
s
0 .542 1 r
.68191 .50438 m
.67261 .47788 L
s
0 0 0 r
2.5 Mabswid
.68191 .50438 Mdot
0 .542 1 r
.5 Mabswid
.55474 .58383 m
.68191 .50438 L
s
0 0 0 r
2.5 Mabswid
.43853 .67596 Mdot
0 .989 1 r
.5 Mabswid
.43803 .67578 m
.43853 .67596 L
s
0 0 0 r
2.5 Mabswid
.35443 .39256 Mdot
0 .989 1 r
.5 Mabswid
.6089 .64767 m
.62307 .60753 L
s
0 0 0 r
2.5 Mabswid
.6089 .64767 Mdot
0 .989 1 r
.5 Mabswid
.55793 .64485 m
.6089 .64767 L
s
0 0 0 r
2.5 Mabswid
.43803 .67578 Mdot
0 .989 1 r
.5 Mabswid
.3497 .57912 m
.43803 .67578 L
s
0 0 0 r
2.5 Mabswid
.346 .40709 Mdot
0 g
.5 Mabswid
.50309 .31066 m
.5028 .31014 L
s
.57553 .32473 m
.50309 .31066 L
s
.50284 .31014 m
.50312 .31066 L
s
.50309 .31063 m
.57554 .32471 L
s
0 0 0 r
2.5 Mabswid
.33626 .5707 Mdot
0 1 .632 r
.5 Mabswid
.62314 .36325 m
.63839 .37018 L
s
0 0 0 r
2.5 Mabswid
.62314 .36325 Mdot
0 g
.5 Mabswid
.57551 .67453 m
.63707 .63375 L
s
.57544 .67509 m
.57551 .67453 L
s
.57555 .67452 m
.57548 .67508 L
s
.63708 .63377 m
.57552 .67455 L
s
0 0 0 r
2.5 Mabswid
.45105 .67772 Mdot
0 .149 1 r
.5 Mabswid
.54424 .68075 m
.54364 .67563 L
s
0 0 0 r
2.5 Mabswid
.54424 .68075 Mdot
0 .989 1 r
.5 Mabswid
.66187 .5865 m
.65673 .56499 L
s
0 0 0 r
2.5 Mabswid
.66187 .5865 Mdot
0 .989 1 r
.5 Mabswid
.55954 .58651 m
.66187 .5865 L
s
0 0 0 r
2.5 Mabswid
.33215 .55403 Mdot
.333 1 0 r
.5 Mabswid
.51269 .58947 m
.33215 .55403 L
s
0 .029 1 r
.66254 .41571 m
.63 .46485 L
s
0 0 0 r
2.5 Mabswid
.66254 .41571 Mdot
0 1 .975 r
.5 Mabswid
.626 .41943 m
.66254 .41571 L
s
.746 1 0 r
.61376 .35544 m
.61176 .35302 L
s
0 0 0 r
2.5 Mabswid
.61376 .35544 Mdot
.746 1 0 r
.5 Mabswid
.48623 .66398 m
.61376 .35544 L
s
0 g
.43048 .3249 m
.40228 .40174 L
s
.50064 .36043 m
.43048 .3249 L
s
.43046 .32492 m
.50283 .31013 L
s
.50062 .36045 m
.43046 .32492 L
s
.4305 .32491 m
.40225 .40164 L
s
.43047 .32493 m
.50284 .31014 L
s
0 0 0 r
2.5 Mabswid
.38975 .64104 Mdot
0 .538 1 r
.5 Mabswid
.38197 .49809 m
.38975 .64104 L
s
.741 1 0 r
.36281 .61193 m
.55663 .60732 L
s
0 0 0 r
2.5 Mabswid
.36281 .61193 Mdot
.42983 .3258 Mdot
.49604 .68771 Mdot
.741 1 0 r
.5 Mabswid
.49585 .68765 m
.49604 .68771 L
s
0 1 .453 r
.63975 .62497 m
.60039 .62668 L
s
0 0 0 r
2.5 Mabswid
.63975 .62497 Mdot
0 1 .453 r
.5 Mabswid
.63095 .59942 m
.63975 .62497 L
s
0 0 0 r
2.5 Mabswid
.49585 .68765 Mdot
.741 1 0 r
.5 Mabswid
.35962 .39298 m
.49585 .68765 L
s
0 g
.50293 .68915 m
.50069 .63964 L
s
.57548 .67508 m
.50293 .68915 L
s
.50072 .63964 m
.50296 .68915 L
s
.57548 .67508 m
.50293 .68915 L
s
0 0 0 r
2.5 Mabswid
.38629 .63711 Mdot
0 1 .381 r
.5 Mabswid
.65544 .60092 m
.66179 .59754 L
s
0 0 0 r
2.5 Mabswid
.65544 .60092 Mdot
.57636 .7649 Mdot
.54 1 0 r
.5 Mabswid
.56479 .67434 m
.57636 .7649 L
s
0 .038 1 r
.67584 .44256 m
.37269 .60295 L
s
0 0 0 r
2.5 Mabswid
.67584 .44256 Mdot
0 .038 1 r
.5 Mabswid
.67572 .43787 m
.67584 .44256 L
s
.741 1 0 r
.68003 .53947 m
.67505 .52188 L
s
0 0 0 r
2.5 Mabswid
.68003 .53947 Mdot
.741 1 0 r
.5 Mabswid
.55663 .60732 m
.68003 .53947 L
s
0 g
.5755 .32472 m
.57543 .32424 L
s
.63713 .36561 m
.5755 .32472 L
s
.57547 .32426 m
.57553 .32473 L
s
0 0 0 r
2.5 Mabswid
.33328 .44592 Mdot
0 g
.5 Mabswid
.57551 .3247 m
.63714 .36559 L
s
0 0 0 r
2.5 Mabswid
.3423 .57601 Mdot
.68538 .5132 Mdot
.045 1 0 r
.5 Mabswid
.6904 .49938 m
.68538 .5132 L
s
0 0 0 r
2.5 Mabswid
.54091 .31784 Mdot
.045 1 0 r
.5 Mabswid
.42322 .4216 m
.54091 .31784 L
s
0 0 0 r
2.5 Mabswid
.35962 .39298 Mdot
0 g
.5 Mabswid
.63704 .63377 m
.67831 .57236 L
s
.63716 .63421 m
.63704 .63377 L
s
.63707 .63375 m
.63718 .63419 L
s
0 1 .381 r
.68523 .51804 m
.56987 .41193 L
s
0 0 0 r
2.5 Mabswid
.68523 .51804 Mdot
0 1 .381 r
.5 Mabswid
.67762 .52709 m
.68523 .51804 L
s
0 g
.67833 .57237 m
.63706 .63378 L
s
0 .829 1 r
.63462 .36655 m
.58677 .38915 L
s
0 0 0 r
2.5 Mabswid
.63462 .36655 Mdot
0 1 .532 r
.5 Mabswid
.63424 .3832 m
.63462 .36655 L
s
.785 1 0 r
.3287 .21248 m
.36882 .3792 L
s
0 0 0 r
2.5 Mabswid
.36882 .3792 Mdot
.61011 .72733 Mdot
0 .989 1 r
.5 Mabswid
.67951 .45089 m
.63682 .42508 L
s
0 0 0 r
2.5 Mabswid
.67951 .45089 Mdot
0 .989 1 r
.5 Mabswid
.66136 .48101 m
.67951 .45089 L
s
0 0 0 r
2.5 Mabswid
.37183 .3749 Mdot
0 .038 1 r
.5 Mabswid
.58601 .33159 m
.55958 .61235 L
s
0 0 0 r
2.5 Mabswid
.58601 .33159 Mdot
.47744 .67962 Mdot
0 g
.5 Mabswid
.50281 .31013 m
.57547 .32425 L
s
.5006 .36045 m
.50281 .31013 L
s
.50283 .31013 m
.50062 .36045 L
s
.5028 .31014 m
.57547 .32426 L
s
0 0 0 r
2.5 Mabswid
.34097 .56589 Mdot
0 g
.5 Mabswid
.6371 .36558 m
.63722 .36523 L
s
.67837 .4271 m
.6371 .36558 L
s
.63724 .36525 m
.63713 .36561 L
s
.63712 .36557 m
.67839 .42709 L
s
.57547 .6751 m
.59949 .59895 L
s
.50068 .63966 m
.57547 .6751 L
s
.57545 .6751 m
.5995 .59905 L
s
.63719 .6342 m
.57545 .6751 L
s
.50069 .63964 m
.57548 .67508 L
s
.63718 .63419 m
.57544 .67509 L
s
.741 1 0 r
.67833 .4348 m
.58632 .38646 L
s
0 0 0 r
2.5 Mabswid
.67833 .4348 Mdot
.741 1 0 r
.5 Mabswid
.67521 .44512 m
.67833 .4348 L
s
0 0 0 r
2.5 Mabswid
.67804 .43288 Mdot
0 .149 1 r
.5 Mabswid
.66043 .44056 m
.67804 .43288 L
s
0 0 0 r
2.5 Mabswid
.56279 .32193 Mdot
0 .989 1 r
.5 Mabswid
.57336 .34099 m
.56279 .32193 L
s
0 g
.6783 .57239 m
.69284 .49973 L
s
.67854 .57265 m
.6783 .57239 L
s
.67831 .57236 m
.67855 .57262 L
s
.69286 .49974 m
.67832 .5724 L
s
0 0 0 r
2.5 Mabswid
.34657 .57536 Mdot
.797 1 0 r
.5 Mabswid
.68461 .46339 m
.6856 .4629 L
s
0 0 0 r
2.5 Mabswid
.68461 .46339 Mdot
.3435 .42851 Mdot
0 .2 1 r
.5 Mabswid
.6858 .46865 m
.68354 .4664 L
s
0 0 0 r
2.5 Mabswid
.6858 .46865 Mdot
0 .2 1 r
.5 Mabswid
.50488 .56678 m
.6858 .46865 L
s
0 g
.67835 .42707 m
.67859 .4269 L
s
.69284 .49977 m
.67835 .42707 L
s
.6786 .42693 m
.67837 .4271 L
s
.67838 .42706 m
.69286 .49977 L
s
0 0 0 r
2.5 Mabswid
.3283 .49987 Mdot
.8 1 0 r
.5 Mabswid
.3283 .49987 m
.3283 .49987 L
s
0 0 0 r
2.5 Mabswid
.3283 .49987 Mdot
.8 1 0 r
.5 Mabswid
.3283 .49987 m
.3283 .49987 L
s
.3283 .49987 m
.3283 .49987 L
s
0 0 0 r
2.5 Mabswid
.3283 .49987 Mdot
.8 1 0 r
.5 Mabswid
.3283 .49987 m
.3283 .49987 L
s
.3283 .49987 m
.3283 .49987 L
s
0 0 0 r
2.5 Mabswid
.3283 .49987 Mdot
1 .058 0 r
.5 Mabswid
.3283 .49987 m
.3283 .49987 L
s
0 0 0 r
2.5 Mabswid
.3283 .49987 Mdot
.3283 .49987 Mdot
.544 1 0 r
.5 Mabswid
.3283 .49987 m
.23553 .51693 L
s
0 0 0 r
2.5 Mabswid
.3283 .49987 Mdot
1 0 0 r
.5 Mabswid
.3052 .50234 m
.3283 .49987 L
s
0 g
.69312 .49981 m
.69284 .49977 L
s
.69284 .49973 m
.69312 .49978 L
s
0 0 0 r
2.5 Mabswid
.45723 .6713 Mdot
.3497 .57912 Mdot
.56479 .67434 Mdot
.4659 .67276 Mdot
0 g
.5 Mabswid
.57546 .32423 m
.50055 .36054 L
s
.59954 .40112 m
.57546 .32423 L
s
.57543 .32423 m
.63724 .36525 L
s
.59952 .40113 m
.57543 .32423 L
s
.57547 .32425 m
.5006 .36045 L
s
.57543 .32424 m
.63724 .36525 L
s
.659 1 0 r
.6837 .45355 m
.6853 .4528 L
s
0 1 .522 r
.6837 .45355 m
.38576 .48466 L
s
0 0 0 r
2.5 Mabswid
.6837 .45355 Mdot
0 1 .827 r
.5 Mabswid
.35621 .41011 m
.22375 .35033 L
s
0 0 0 r
2.5 Mabswid
.35621 .41011 Mdot
0 1 .693 r
.5 Mabswid
.4761 .43646 m
.35621 .41011 L
s
0 .149 1 r
.54364 .67563 m
.52713 .54932 L
s
0 0 0 r
2.5 Mabswid
.54364 .67563 Mdot
0 g
.5 Mabswid
.63717 .63421 m
.59949 .59907 L
s
.67856 .57262 m
.63717 .63421 L
s
.5995 .59905 m
.63719 .6342 L
s
.67855 .57262 m
.63716 .63421 L
s
.797 1 0 r
.6856 .4629 m
.68434 .4627 L
s
0 0 0 r
2.5 Mabswid
.6856 .4629 Mdot
.33833 .53968 Mdot
0 .989 1 r
.5 Mabswid
.42505 .34063 m
.34545 .51043 L
s
0 0 0 r
2.5 Mabswid
.42505 .34063 Mdot
.6853 .4528 Mdot
.53792 .32106 Mdot
.43015 .65725 Mdot
.33438 .51581 Mdot
0 1 .381 r
.5 Mabswid
.66179 .59754 m
.66183 .59739 L
s
0 0 0 r
2.5 Mabswid
.66179 .59754 Mdot
0 1 .381 r
.5 Mabswid
.66183 .59739 m
.58755 .37609 L
s
0 0 0 r
2.5 Mabswid
.66183 .59739 Mdot
.49857 .31816 Mdot
0 1 .453 r
.5 Mabswid
.59624 .58893 m
.49857 .31816 L
s
0 g
.63723 .36523 m
.67861 .42693 L
s
.5995 .40111 m
.63723 .36523 L
s
.63724 .36525 m
.59952 .40113 L
s
.63722 .36523 m
.6786 .42693 L
s
0 0 0 r
2.5 Mabswid
.70252 .36843 Mdot
.756 1 0 r
.5 Mabswid
.66979 .49994 m
.70252 .36843 L
s
0 0 0 r
2.5 Mabswid
.45299 .33066 Mdot
0 .989 1 r
.5 Mabswid
.35058 .42745 m
.47073 .66995 L
s
0 0 0 r
2.5 Mabswid
.35058 .42745 Mdot
.70402 .33251 Mdot
.757 1 0 r
.5 Mabswid
.6624 .49999 m
.70402 .33251 L
s
0 g
.76927 .76623 m
.76966 .23275 L
s
.79793 .81342 m
.76927 .76623 L
s
.67856 .57264 m
.64052 .50006 L
s
.59949 .59909 m
.67856 .57264 L
s
.67854 .57266 m
.6406 .50012 L
s
.69313 .49978 m
.67854 .57266 L
s
.59949 .59907 m
.67856 .57262 L
s
.69312 .49978 m
.67854 .57265 L
s
0 0 0 r
2.5 Mabswid
.47073 .66995 Mdot
.38325 .6225 Mdot
.5695 .66796 Mdot
.70551 .29657 Mdot
.757 1 0 r
.5 Mabswid
.65503 .50004 m
.70551 .29657 L
s
0 0 0 r
2.5 Mabswid
.23553 .51693 Mdot
.321 1 0 r
.5 Mabswid
.69355 .67562 m
.45939 .66649 L
s
0 0 0 r
2.5 Mabswid
.45939 .66649 Mdot
.707 .26058 Mdot
.782 1 0 r
.5 Mabswid
.64766 .50009 m
.707 .26058 L
s
0 .989 1 r
.33925 .52778 m
.35993 .53733 L
s
0 0 0 r
2.5 Mabswid
.33925 .52778 Mdot
.63839 .37018 Mdot
0 g
.5 Mabswid
.67862 .42691 m
.59941 .40113 L
s
.64062 .50016 m
.67862 .42691 L
s
.6786 .42689 m
.69313 .49981 L
s
.6406 .50014 m
.6786 .42689 L
s
.67861 .42693 m
.5995 .40111 L
s
.67859 .4269 m
.69312 .49981 L
s
0 0 0 r
2.5 Mabswid
.51733 .67486 Mdot
0 g
.5 Mabswid
.69313 .49981 m
.6406 .50014 L
s
.6406 .50012 m
.69313 .49978 L
s
0 0 0 r
2.5 Mabswid
.56818 .66665 Mdot
.39042 .37103 Mdot
.76944 .35788 Mdot
.61176 .35302 Mdot
.33467 .49992 Mdot
.765 1 0 r
.5 Mabswid
.33467 .49992 m
.33467 .49992 L
s
0 0 0 r
2.5 Mabswid
.33467 .49992 Mdot
.765 1 0 r
.5 Mabswid
.33467 .49992 m
.33467 .49992 L
s
.33467 .49992 m
.33467 .49992 L
s
0 0 0 r
2.5 Mabswid
.33467 .49992 Mdot
.765 1 0 r
.5 Mabswid
.33467 .49992 m
.33467 .49992 L
s
.33467 .49992 m
.33467 .49992 L
s
0 0 0 r
2.5 Mabswid
.33467 .49992 Mdot
1 .059 0 r
.5 Mabswid
.33467 .49992 m
.33467 .49992 L
s
0 0 0 r
2.5 Mabswid
.33467 .49992 Mdot
.33467 .49992 Mdot
.549 1 0 r
.5 Mabswid
.33467 .49992 m
.23419 .51846 L
s
0 0 0 r
2.5 Mabswid
.33467 .49992 Mdot
1 0 0 r
.5 Mabswid
.31202 .50234 m
.33467 .49992 L
s
0 0 0 r
2.5 Mabswid
.35156 .4329 Mdot
.797 1 0 r
.5 Mabswid
.68434 .4627 m
.35792 .49799 L
s
0 0 0 r
2.5 Mabswid
.68434 .4627 Mdot
.479 1 0 r
.5 Mabswid
.65992 .40318 m
.54054 .2208 L
s
0 0 0 r
2.5 Mabswid
.65992 .40318 Mdot
.37269 .60295 Mdot
0 1 .795 r
.5 Mabswid
.67724 .42988 m
.78336 .66844 L
s
0 0 0 r
2.5 Mabswid
.67724 .42988 Mdot
.33965 .52133 Mdot
.47573 .66835 Mdot
.51994 .67274 Mdot
.63782 .62229 Mdot
0 .2 1 r
.5 Mabswid
.39323 .62596 m
.50488 .56678 L
s
0 0 0 r
2.5 Mabswid
.39323 .62596 Mdot
.55585 .32905 Mdot
0 .072 1 r
.5 Mabswid
.4486 .33666 m
.50444 .22484 L
s
0 0 0 r
2.5 Mabswid
.4486 .33666 Mdot
.6904 .49938 Mdot
.43445 .65212 Mdot
.36826 .40251 Mdot
0 .2 1 r
.5 Mabswid
.68354 .4664 m
.35697 .43856 L
s
0 0 0 r
2.5 Mabswid
.68354 .4664 Mdot
.35469 .56498 Mdot
.389 1 0 r
.5 Mabswid
.34501 .45715 m
.63226 .20213 L
s
0 0 0 r
2.5 Mabswid
.34501 .45715 Mdot
0 g
.5 Mabswid
.79846 .19024 m
.76966 .23275 L
s
0 0 0 r
2.5 Mabswid
.4576 .66224 Mdot
.42427 .64626 Mdot
.194 1 0 r
.5 Mabswid
.62862 .797 m
.63413 .62432 L
s
0 0 0 r
2.5 Mabswid
.63413 .62432 Mdot
.51202 .67173 Mdot
.63163 .62705 Mdot
.35259 .4404 Mdot
.45686 .33578 Mdot
0 .542 1 r
.5 Mabswid
.67261 .47788 m
.45686 .33578 L
s
0 .538 1 r
.41651 .35618 m
.38197 .49809 L
s
0 0 0 r
2.5 Mabswid
.41651 .35618 Mdot
.67572 .43787 Mdot
.486 1 0 r
.5 Mabswid
.6297 .62774 m
.61162 .79142 L
s
0 0 0 r
2.5 Mabswid
.6297 .62774 Mdot
.44048 .3443 Mdot
0 1 .381 r
.5 Mabswid
.40408 .36717 m
.39937 .4393 L
s
0 0 0 r
2.5 Mabswid
.40408 .36717 Mdot
.249 1 0 r
.5 Mabswid
.6211 .63166 m
.60203 .79078 L
s
0 0 0 r
2.5 Mabswid
.6211 .63166 Mdot
.60817 .63925 Mdot
.66366 .57963 Mdot
.67521 .44512 Mdot
.741 1 0 r
.5 Mabswid
.50985 .61927 m
.67521 .44512 L
s
0 0 0 r
2.5 Mabswid
.34495 .52688 Mdot
.59977 .35309 Mdot
.42812 .35267 Mdot
.327 1 0 r
.5 Mabswid
.35179 .45191 m
.64168 .2033 L
s
0 0 0 r
2.5 Mabswid
.35179 .45191 Mdot
.23419 .51846 Mdot
.35697 .43856 Mdot
.57336 .34099 Mdot
0 .989 1 r
.5 Mabswid
.60905 .42563 m
.57336 .34099 L
s
0 0 0 r
2.5 Mabswid
.45104 .65348 Mdot
.44156 .34739 Mdot
0 1 .381 r
.5 Mabswid
.56987 .41193 m
.44156 .34739 L
s
0 0 0 r
2.5 Mabswid
.34103 .49997 Mdot
.766 1 0 r
.5 Mabswid
.34103 .49997 m
.34103 .49997 L
s
0 0 0 r
2.5 Mabswid
.34103 .49997 Mdot
.766 1 0 r
.5 Mabswid
.34103 .49997 m
.34103 .49997 L
s
.34103 .49997 m
.34103 .49997 L
s
0 0 0 r
2.5 Mabswid
.34103 .49997 Mdot
.766 1 0 r
.5 Mabswid
.34103 .49997 m
.34103 .49997 L
s
.34103 .49997 m
.34103 .49997 L
s
0 0 0 r
2.5 Mabswid
.34103 .49997 Mdot
1 .059 0 r
.5 Mabswid
.34103 .49997 m
.34103 .49997 L
s
0 0 0 r
2.5 Mabswid
.34103 .49997 Mdot
.34103 .49997 Mdot
.554 1 0 r
.5 Mabswid
.34103 .49997 m
.23283 .52 L
s
0 0 0 r
2.5 Mabswid
.34103 .49997 Mdot
1 0 0 r
.5 Mabswid
.31885 .50234 m
.34103 .49997 L
s
0 0 0 r
2.5 Mabswid
.55377 .33499 Mdot
.741 1 0 r
.5 Mabswid
.6246 .60806 m
.55377 .33499 L
s
0 0 0 r
2.5 Mabswid
.65849 .41401 Mdot
.34673 .52579 Mdot
.67762 .52709 Mdot
0 1 .381 r
.5 Mabswid
.43406 .60511 m
.67762 .52709 L
s
0 0 0 r
2.5 Mabswid
.39291 .3789 Mdot
0 1 .779 r
.5 Mabswid
.53599 .33318 m
.5939 .21551 L
s
0 0 0 r
2.5 Mabswid
.53599 .33318 Mdot
.48623 .66398 Mdot
.37424 .40489 Mdot
.63424 .3832 Mdot
0 1 .532 r
.5 Mabswid
.57138 .54989 m
.63424 .3832 L
s
0 0 0 r
2.5 Mabswid
.5786 .65002 Mdot
.34545 .51043 Mdot
0 1 .37 r
.5 Mabswid
.35861 .44666 m
.65301 .20468 L
s
0 0 0 r
2.5 Mabswid
.35861 .44666 Mdot
.36715 .57139 Mdot
.44144 .35235 Mdot
.63378 .38575 Mdot
.47492 .3387 Mdot
.741 1 0 r
.5 Mabswid
.67505 .52188 m
.54993 .3853 L
s
0 0 0 r
2.5 Mabswid
.67505 .52188 Mdot
.35957 .54977 Mdot
.45544 .64966 Mdot
.54525 .65788 Mdot
.203 1 0 r
.5 Mabswid
.39943 .61855 m
.1864 .53414 L
s
0 0 0 r
2.5 Mabswid
.39943 .61855 Mdot
0 1 .62 r
.5 Mabswid
.55073 .65499 m
.46819 .77817 L
s
0 0 0 r
2.5 Mabswid
.55073 .65499 Mdot
1 .232 0 r
.5 Mabswid
.37958 .33182 m
.35567 .53504 L
s
0 0 0 r
2.5 Mabswid
.35567 .53504 Mdot
.60316 .63248 Mdot
.62969 .38534 Mdot
.67261 .47788 Mdot
.3474 .50001 Mdot
.767 1 0 r
.5 Mabswid
.3474 .50001 m
.3474 .50001 L
s
0 0 0 r
2.5 Mabswid
.3474 .50001 Mdot
.767 1 0 r
.5 Mabswid
.3474 .50001 m
.3474 .50001 L
s
.3474 .50001 m
.3474 .50001 L
s
0 0 0 r
2.5 Mabswid
.3474 .50001 Mdot
.767 1 0 r
.5 Mabswid
.3474 .50001 m
.3474 .50001 L
s
.3474 .50001 m
.3474 .50001 L
s
0 0 0 r
2.5 Mabswid
.3474 .50001 Mdot
1 .06 0 r
.5 Mabswid
.3474 .50001 m
.3474 .50001 L
s
0 0 0 r
2.5 Mabswid
.3474 .50001 Mdot
.3474 .50001 Mdot
.559 1 0 r
.5 Mabswid
.3474 .50001 m
.23147 .52156 L
s
0 0 0 r
2.5 Mabswid
.3474 .50001 Mdot
1 0 0 r
.5 Mabswid
.32568 .50234 m
.3474 .50001 L
s
0 0 0 r
2.5 Mabswid
.67349 .48606 Mdot
.23283 .52 Mdot
.44314 .35657 Mdot
0 .989 1 r
.5 Mabswid
.44328 .63964 m
.5151 .60372 L
s
0 0 0 r
2.5 Mabswid
.44328 .63964 Mdot
0 .989 1 r
.5 Mabswid
.65673 .56499 m
.50812 .35973 L
s
0 0 0 r
2.5 Mabswid
.65673 .56499 Mdot
0 .101 1 r
.5 Mabswid
.51676 .5045 m
.36893 .56255 L
s
0 0 0 r
2.5 Mabswid
.36893 .56255 Mdot
0 1 .922 r
.5 Mabswid
.3773 .41116 m
.2152 .35862 L
s
0 0 0 r
2.5 Mabswid
.3773 .41116 Mdot
0 1 .676 r
.5 Mabswid
.45733 .42865 m
.3773 .41116 L
s
0 0 0 r
2.5 Mabswid
.67083 .52009 Mdot
.66043 .44056 Mdot
0 .149 1 r
.5 Mabswid
.54737 .48979 m
.66043 .44056 L
s
0 0 0 r
2.5 Mabswid
.67283 .48926 Mdot
.5501 .34525 Mdot
0 .989 1 r
.5 Mabswid
.35993 .53733 m
.41865 .55978 L
s
0 0 0 r
2.5 Mabswid
.35993 .53733 Mdot
.58272 .35664 Mdot
.42559 .36773 Mdot
.66656 .53154 Mdot
.6664 .46571 Mdot
0 .989 1 r
.5 Mabswid
.53393 .65465 m
.53292 .36684 L
s
0 0 0 r
2.5 Mabswid
.53393 .65465 Mdot
.66739 .47441 Mdot
.2 0 1 r
.5 Mabswid
.63907 .59049 m
.44575 .42771 L
s
0 0 0 r
2.5 Mabswid
.63907 .59049 Mdot
.64677 .41848 Mdot
.61291 .37646 Mdot
1 .233 0 r
.5 Mabswid
.38649 .32852 m
.36011 .5308 L
s
0 0 0 r
2.5 Mabswid
.36011 .5308 Mdot
.55793 .64485 Mdot
0 .989 1 r
.5 Mabswid
.42354 .59853 m
.55793 .64485 L
s
0 0 0 r
2.5 Mabswid
.58009 .35941 Mdot
.63095 .59942 Mdot
0 1 .453 r
.5 Mabswid
.59014 .5243 m
.63095 .59942 L
s
0 0 0 r
2.5 Mabswid
.36821 .44834 Mdot
.6246 .60806 Mdot
0 1 .453 r
.5 Mabswid
.49371 .65507 m
.47451 .37543 L
s
0 0 0 r
2.5 Mabswid
.49371 .65507 Mdot
.66502 .52567 Mdot
0 1 .453 r
.5 Mabswid
.60039 .62668 m
.50237 .60591 L
s
0 0 0 r
2.5 Mabswid
.60039 .62668 Mdot
.66715 .51474 Mdot
.4267 .62502 Mdot
.756 1 0 r
.5 Mabswid
.66979 .49994 m
.66979 .49994 L
s
0 0 0 r
2.5 Mabswid
.66979 .49994 Mdot
.756 1 0 r
.5 Mabswid
.66979 .49994 m
.66979 .49994 L
s
0 0 0 r
2.5 Mabswid
.66979 .49994 Mdot
.756 1 0 r
.5 Mabswid
.66979 .49994 m
.66979 .49994 L
s
0 0 0 r
2.5 Mabswid
.66979 .49994 Mdot
.756 1 0 r
.5 Mabswid
.66979 .49995 m
.66979 .49994 L
s
.66979 .49995 m
.66979 .49995 L
s
0 0 0 r
2.5 Mabswid
.66979 .49995 Mdot
1 .053 0 r
.5 Mabswid
.66979 .49995 m
.66979 .49995 L
s
0 0 0 r
2.5 Mabswid
.66979 .49994 Mdot
.66979 .49995 Mdot
.488 1 0 r
.5 Mabswid
.66979 .49995 m
.77217 .5181 L
s
0 0 0 r
2.5 Mabswid
.66979 .49995 Mdot
1 0 0 r
.5 Mabswid
.64906 .50225 m
.66979 .49995 L
s
0 .989 1 r
.62307 .60753 m
.60905 .42563 L
s
0 0 0 r
2.5 Mabswid
.62307 .60753 Mdot
0 1 .553 r
.5 Mabswid
.5007 .49596 m
.65101 .43803 L
s
0 0 0 r
2.5 Mabswid
.65101 .43803 Mdot
.3995 .38931 Mdot
0 .108 1 r
.5 Mabswid
.52545 .50551 m
.37618 .56314 L
s
0 0 0 r
2.5 Mabswid
.37618 .56314 Mdot
.23171 .36559 Mdot
0 1 .862 r
.5 Mabswid
.41155 .4121 m
.23171 .36559 L
s
0 0 0 r
2.5 Mabswid
.35377 .50006 Mdot
.768 1 0 r
.5 Mabswid
.35377 .50006 m
.35377 .50006 L
s
0 0 0 r
2.5 Mabswid
.35377 .50006 Mdot
.768 1 0 r
.5 Mabswid
.35377 .50006 m
.35377 .50006 L
s
.35377 .50006 m
.35377 .50006 L
s
0 0 0 r
2.5 Mabswid
.35377 .50006 Mdot
.768 1 0 r
.5 Mabswid
.35377 .50006 m
.35377 .50006 L
s
.35377 .50006 m
.35377 .50006 L
s
0 0 0 r
2.5 Mabswid
.35377 .50006 Mdot
1 .06 0 r
.5 Mabswid
.35377 .50006 m
.35377 .50006 L
s
0 0 0 r
2.5 Mabswid
.35377 .50006 Mdot
.35377 .50006 Mdot
.564 1 0 r
.5 Mabswid
.35377 .50006 m
.23009 .52313 L
s
0 0 0 r
2.5 Mabswid
.35377 .50006 Mdot
1 0 0 r
.5 Mabswid
.33251 .50234 m
.35377 .50006 L
s
0 0 0 r
2.5 Mabswid
.6622 .52725 Mdot
.54394 .35112 Mdot
.57632 .63352 Mdot
.23147 .52156 Mdot
.37164 .45094 Mdot
.54617 .35371 Mdot
.36326 .47487 Mdot
.64315 .42778 Mdot
.65574 .54043 Mdot
.65919 .53128 Mdot
1 .233 0 r
.5 Mabswid
.39337 .32525 m
.36456 .52654 L
s
0 0 0 r
2.5 Mabswid
.36456 .52654 Mdot
.741 1 0 r
.5 Mabswid
.41207 .38411 m
.40043 .53126 L
s
0 0 0 r
2.5 Mabswid
.41207 .38411 Mdot
0 .332 1 r
.5 Mabswid
.66777 .24004 m
.41013 .38527 L
s
0 0 0 r
2.5 Mabswid
.41013 .38527 Mdot
.37148 .54328 Mdot
.64425 .43269 Mdot
0 1 .643 r
.5 Mabswid
.42856 .46319 m
.64425 .43269 L
s
0 0 0 r
2.5 Mabswid
.4711 .35502 Mdot
0 .538 1 r
.5 Mabswid
.52153 .40085 m
.4711 .35502 L
s
0 0 0 r
2.5 Mabswid
.63701 .57799 Mdot
.66136 .48101 Mdot
0 .989 1 r
.5 Mabswid
.61622 .53004 m
.66136 .48101 L
s
0 0 0 r
2.5 Mabswid
.36156 .48449 Mdot
.47614 .35344 Mdot
0 .542 1 r
.5 Mabswid
.42915 .62013 m
.55474 .58383 L
s
0 0 0 r
2.5 Mabswid
.42915 .62013 Mdot
0 .542 1 r
.5 Mabswid
.47195 .64072 m
.61645 .46751 L
s
0 0 0 r
2.5 Mabswid
.47195 .64072 Mdot
.48327 .64621 Mdot
.35792 .49799 Mdot
.57792 .36794 Mdot
0 1 .668 r
.5 Mabswid
.49167 .49503 m
.64329 .43755 L
s
0 0 0 r
2.5 Mabswid
.64329 .43755 Mdot
.50378 .34727 Mdot
0 .989 1 r
.5 Mabswid
.63682 .42508 m
.54456 .39162 L
s
0 0 0 r
2.5 Mabswid
.63682 .42508 Mdot
.757 1 0 r
.5 Mabswid
.6624 .49999 m
.6624 .49999 L
s
0 0 0 r
2.5 Mabswid
.6624 .49999 Mdot
.757 1 0 r
.5 Mabswid
.6624 .49999 m
.6624 .49999 L
s
0 0 0 r
2.5 Mabswid
.6624 .49999 Mdot
.757 1 0 r
.5 Mabswid
.6624 .49999 m
.6624 .49999 L
s
0 0 0 r
2.5 Mabswid
.6624 .49999 Mdot
.757 1 0 r
.5 Mabswid
.6624 .49999 m
.6624 .49999 L
s
.6624 .49999 m
.6624 .49999 L
s
0 0 0 r
2.5 Mabswid
.6624 .49999 Mdot
1 .053 0 r
.5 Mabswid
.6624 .49999 m
.6624 .49999 L
s
0 0 0 r
2.5 Mabswid
.6624 .49999 Mdot
.6624 .49999 Mdot
.494 1 0 r
.5 Mabswid
.6624 .49999 m
.77283 .51966 L
s
0 0 0 r
2.5 Mabswid
.6624 .49999 Mdot
1 0 0 r
.5 Mabswid
.64207 .50225 m
.6624 .49999 L
s
0 .008 1 r
.53411 .50653 m
.38348 .56373 L
s
0 0 0 r
2.5 Mabswid
.38348 .56373 Mdot
.65205 .53657 Mdot
.48019 .35439 Mdot
.6441 .44309 Mdot
.62884 .58648 Mdot
.36817 .52461 Mdot
0 1 .532 r
.5 Mabswid
.53749 .63999 m
.57138 .54989 L
s
0 0 0 r
2.5 Mabswid
.53749 .63999 Mdot
.41035 .39015 Mdot
.61759 .39413 Mdot
.39182 .58235 Mdot
.37295 .53497 Mdot
.66022 .49498 Mdot
.61062 .38702 Mdot
.37958 .55073 Mdot
.36013 .5001 Mdot
.77 1 0 r
.5 Mabswid
.36013 .5001 m
.36013 .5001 L
s
0 0 0 r
2.5 Mabswid
.36013 .5001 Mdot
.77 1 0 r
.5 Mabswid
.36013 .5001 m
.36013 .5001 L
s
.36013 .5001 m
.36013 .5001 L
s
0 0 0 r
2.5 Mabswid
.36013 .5001 Mdot
.77 1 0 r
.5 Mabswid
.36013 .5001 m
.36013 .5001 L
s
.36013 .5001 m
.36013 .5001 L
s
0 0 0 r
2.5 Mabswid
.36013 .5001 Mdot
1 .061 0 r
.5 Mabswid
.36013 .5001 m
.36013 .5001 L
s
0 0 0 r
2.5 Mabswid
.36013 .5001 Mdot
.36013 .5001 Mdot
.569 1 0 r
.5 Mabswid
.36013 .5001 m
.2287 .52471 L
s
0 0 0 r
2.5 Mabswid
.36013 .5001 Mdot
1 0 0 r
.5 Mabswid
.33934 .50234 m
.36013 .5001 L
s
0 0 0 r
2.5 Mabswid
.6423 .44338 Mdot
.54205 .63694 Mdot
.52269 .64322 Mdot
1 .234 0 r
.5 Mabswid
.40023 .322 m
.36905 .52226 L
s
0 0 0 r
2.5 Mabswid
.36905 .52226 Mdot
.50871 .6466 Mdot
.65327 .52753 Mdot
.46766 .36333 Mdot
.58755 .37609 Mdot
0 g
.5 Mabswid
.36185 .50018 m
.40425 .46066 L
s
.36173 .50011 m
.4043 .53987 L
s
.40424 .46063 m
.36173 .50011 L
s
.40431 .53984 m
.36173 .50009 L
s
0 0 0 r
2.5 Mabswid
.36502 .49295 Mdot
.65694 .4932 Mdot
.23009 .52313 Mdot
0 1 .017 r
.5 Mabswid
.46866 .36511 m
.63952 .21631 L
s
0 0 0 r
2.5 Mabswid
.46866 .36511 Mdot
.63744 .55593 Mdot
.64708 .53499 Mdot
.333 1 0 r
.5 Mabswid
.61103 .60513 m
.51269 .58947 L
s
0 0 0 r
2.5 Mabswid
.61103 .60513 Mdot
0 1 .774 r
.5 Mabswid
.48268 .49409 m
.63553 .43706 L
s
0 0 0 r
2.5 Mabswid
.63553 .43706 Mdot
.37766 .53645 Mdot
0 g
.5 Mabswid
.40252 .59851 m
.40431 .53984 L
s
.40238 .59855 m
.4602 .59597 L
s
.40429 .53983 m
.40238 .59855 L
s
.46019 .59595 m
.40237 .59853 L
s
0 0 0 r
2.5 Mabswid
.38741 .55916 Mdot
.37306 .47682 Mdot
0 .645 1 r
.5 Mabswid
.626 .41943 m
.78202 .3655 L
s
0 0 0 r
2.5 Mabswid
.626 .41943 Mdot
0 1 .403 r
.5 Mabswid
.53808 .43811 m
.626 .41943 L
s
0 0 0 r
2.5 Mabswid
.42631 .60892 Mdot
0 1 .381 r
.5 Mabswid
.40727 .49683 m
.42631 .60892 L
s
.831 1 0 r
.36667 .50013 m
.20459 .50119 L
s
0 0 0 r
2.5 Mabswid
.36667 .50013 Mdot
1 0 0 r
.5 Mabswid
.34616 .50233 m
.36667 .50013 L
s
1 .356 0 r
.56683 .31325 m
.64538 .53246 L
s
0 0 0 r
2.5 Mabswid
.64538 .53246 Mdot
.51603 .63962 Mdot
0 g
.5 Mabswid
.40228 .40174 m
.46009 .4045 L
s
.40224 .40161 m
.40423 .46067 L
s
.4601 .40448 m
.40224 .40161 L
s
.40425 .46066 m
.40226 .40159 L
s
.757 1 0 r
.65503 .50004 m
.65503 .50004 L
s
0 0 0 r
2.5 Mabswid
.65503 .50004 Mdot
.757 1 0 r
.5 Mabswid
.65503 .50004 m
.65503 .50004 L
s
0 0 0 r
2.5 Mabswid
.65503 .50004 Mdot
.757 1 0 r
.5 Mabswid
.65503 .50004 m
.65503 .50004 L
s
0 0 0 r
2.5 Mabswid
.65503 .50004 Mdot
.757 1 0 r
.5 Mabswid
.65503 .50004 m
.65503 .50004 L
s
.65503 .50004 m
.65503 .50004 L
s
0 0 0 r
2.5 Mabswid
.65503 .50004 Mdot
1 .054 0 r
.5 Mabswid
.65503 .50004 m
.65503 .50004 L
s
0 0 0 r
2.5 Mabswid
.65503 .50004 Mdot
.65503 .50004 Mdot
.5 1 0 r
.5 Mabswid
.65503 .50004 m
.77348 .52123 L
s
0 0 0 r
2.5 Mabswid
.65503 .50004 Mdot
1 0 0 r
.5 Mabswid
.63508 .50226 m
.65503 .50004 L
s
0 0 0 r
2.5 Mabswid
.54243 .63013 Mdot
.761 1 0 r
.5 Mabswid
.5254 .54787 m
.36879 .50137 L
s
0 0 0 r
2.5 Mabswid
.36879 .50137 Mdot
.38437 .54536 Mdot
1 .234 0 r
.5 Mabswid
.40705 .31877 m
.37356 .51795 L
s
0 0 0 r
2.5 Mabswid
.37356 .51795 Mdot
.53607 .36539 Mdot
.40879 .59834 Mdot
.741 1 0 r
.5 Mabswid
.4083 .59515 m
.40879 .59834 L
s
0 0 0 r
2.5 Mabswid
.77217 .5181 Mdot
.64303 .46629 Mdot
.39046 .55812 Mdot
0 1 .453 r
.5 Mabswid
.50237 .60591 m
.39046 .55812 L
s
0 0 0 r
2.5 Mabswid
.4083 .59515 Mdot
.741 1 0 r
.5 Mabswid
.4029 .55787 m
.4083 .59515 L
s
0 .989 1 r
.40192 .58524 m
.42354 .59853 L
s
0 0 0 r
2.5 Mabswid
.40192 .58524 Mdot
.63668 .5424 Mdot
.59406 .38691 Mdot
.53292 .36684 Mdot
0 .538 1 r
.5 Mabswid
.64295 .52716 m
.52753 .40709 L
s
0 0 0 r
2.5 Mabswid
.64295 .52716 Mdot
0 .77 1 r
.5 Mabswid
.47373 .49315 m
.62772 .43658 L
s
0 0 0 r
2.5 Mabswid
.62772 .43658 Mdot
.833 1 0 r
.5 Mabswid
.37326 .50015 m
.20232 .50128 L
s
0 0 0 r
2.5 Mabswid
.37326 .50015 Mdot
1 0 0 r
.5 Mabswid
.35299 .50233 m
.37326 .50015 L
s
0 0 0 r
2.5 Mabswid
.40386 .58619 Mdot
.46268 .62149 Mdot
.50812 .35973 Mdot
0 g
.5 Mabswid
.50078 .63955 m
.46019 .59595 L
s
0 0 0 r
2.5 Mabswid
.60917 .39975 Mdot
0 g
.5 Mabswid
.5007 .63967 m
.53946 .59616 L
s
.46016 .59595 m
.5007 .63967 L
s
.53944 .59615 m
.50068 .63966 L
s
1 .184 0 r
.38815 .43304 m
.38784 .54513 L
s
0 0 0 r
2.5 Mabswid
.38784 .54513 Mdot
.58632 .38646 Mdot
1 .24 0 r
.5 Mabswid
.55965 .3093 m
.64042 .52812 L
s
0 0 0 r
2.5 Mabswid
.64042 .52812 Mdot
.6411 .47254 Mdot
0 .156 1 r
.5 Mabswid
.37876 .48085 m
.18689 .46567 L
s
0 0 0 r
2.5 Mabswid
.37876 .48085 Mdot
.43406 .60511 Mdot
.40884 .58529 Mdot
.2287 .52471 Mdot
1 .245 0 r
.5 Mabswid
.28039 .46462 m
.37828 .51364 L
s
0 0 0 r
2.5 Mabswid
.37828 .51364 Mdot
0 .829 1 r
.5 Mabswid
.58677 .38915 m
.52959 .43136 L
s
0 0 0 r
2.5 Mabswid
.58677 .38915 Mdot
0 g
.5 Mabswid
.50055 .36054 m
.5394 .4043 L
s
0 0 0 r
2.5 Mabswid
.38401 .52879 Mdot
.61591 .42047 Mdot
0 g
.5 Mabswid
.50061 .36042 m
.46007 .40449 L
s
.53943 .4043 m
.50061 .36042 L
s
.46009 .4045 m
.50064 .36043 L
s
0 1 .303 r
.66988 .72445 m
.62261 .56047 L
s
0 0 0 r
2.5 Mabswid
.62261 .56047 Mdot
.42354 .59853 Mdot
1 .173 0 r
.5 Mabswid
.4114 .56066 m
.3984 .56319 L
s
0 0 0 r
2.5 Mabswid
.3984 .56319 Mdot
.834 1 0 r
.5 Mabswid
.37985 .50018 m
.2 .50138 L
s
0 0 0 r
2.5 Mabswid
.37985 .50018 Mdot
1 0 0 r
.5 Mabswid
.35982 .50233 m
.37985 .50018 L
s
0 0 0 r
2.5 Mabswid
.38919 .53998 Mdot
.51142 .36512 Mdot
.782 1 0 r
.5 Mabswid
.64766 .50009 m
.64766 .50009 L
s
0 0 0 r
2.5 Mabswid
.64766 .50009 Mdot
.782 1 0 r
.5 Mabswid
.64766 .50009 m
.64766 .50009 L
s
0 0 0 r
2.5 Mabswid
.64766 .50009 Mdot
.782 1 0 r
.5 Mabswid
.64766 .50009 m
.64766 .50009 L
s
0 0 0 r
2.5 Mabswid
.64766 .50009 Mdot
.782 1 0 r
.5 Mabswid
.64766 .50009 m
.64766 .50009 L
s
.64766 .50009 m
.64766 .50009 L
s
0 0 0 r
2.5 Mabswid
.64766 .50009 Mdot
1 .056 0 r
.5 Mabswid
.64766 .50009 m
.64766 .50009 L
s
0 0 0 r
2.5 Mabswid
.64766 .50009 Mdot
.64766 .50009 Mdot
.508 1 0 r
.5 Mabswid
.64766 .50009 m
.77415 .52281 L
s
0 0 0 r
2.5 Mabswid
.64766 .50009 Mdot
1 0 0 r
.5 Mabswid
.6281 .50226 m
.64766 .50009 L
s
0 1 .202 r
.3809 .22994 m
.41004 .41312 L
s
0 0 0 r
2.5 Mabswid
.41004 .41312 Mdot
.41155 .4121 Mdot
.47451 .37543 Mdot
.38906 .53673 Mdot
.38197 .49809 Mdot
.60969 .41397 Mdot
.40971 .57742 Mdot
0 1 .522 r
.5 Mabswid
.5511 .4059 m
.40971 .57742 L
s
1 .242 0 r
.55248 .30534 m
.63544 .52376 L
s
0 0 0 r
2.5 Mabswid
.63544 .52376 Mdot
.93 1 0 r
.5 Mabswid
.47927 .76953 m
.46834 .61681 L
s
0 0 0 r
2.5 Mabswid
.46834 .61681 Mdot
.46581 .38191 Mdot
0 .989 1 r
.5 Mabswid
.54456 .39162 m
.46581 .38191 L
s
0 0 0 r
2.5 Mabswid
.77283 .51966 Mdot
.40575 .42528 Mdot
0 1 .381 r
.5 Mabswid
.39937 .4393 m
.40727 .49683 L
s
0 0 0 r
2.5 Mabswid
.39937 .4393 Mdot
.55958 .61235 Mdot
0 g
.5 Mabswid
.59949 .59895 m
.53944 .59615 L
s
0 0 0 r
2.5 Mabswid
.42152 .58786 Mdot
.63716 .48086 Mdot
.63 .46485 Mdot
0 g
.5 Mabswid
.59952 .59908 m
.5957 .54004 L
s
.53942 .59618 m
.59952 .59908 L
s
.59568 .54006 m
.59949 .59909 L
s
0 0 0 r
2.5 Mabswid
.38576 .48466 Mdot
.836 1 0 r
.5 Mabswid
.38644 .5002 m
.19764 .50147 L
s
0 0 0 r
2.5 Mabswid
.38644 .5002 Mdot
1 0 0 r
.5 Mabswid
.36664 .50233 m
.38644 .5002 L
s
.741 1 0 r
.46141 .38595 m
.3983 .48217 L
s
0 0 0 r
2.5 Mabswid
.46141 .38595 Mdot
0 .585 1 r
.5 Mabswid
.49848 .3705 m
.78081 .25804 L
s
0 0 0 r
2.5 Mabswid
.49848 .3705 Mdot
.57194 .39067 Mdot
.797 1 0 r
.5 Mabswid
.5474 .43697 m
.57194 .39067 L
s
0 0 0 r
2.5 Mabswid
.61028 .57094 Mdot
0 1 .643 r
.5 Mabswid
.39082 .46885 m
.42856 .46319 L
s
0 0 0 r
2.5 Mabswid
.39082 .46885 Mdot
0 g
.5 Mabswid
.59941 .40113 m
.59568 .46047 L
s
.59953 .4011 m
.53939 .40428 L
s
.59571 .46048 m
.59953 .4011 L
s
.5394 .4043 m
.59954 .40112 L
s
1 .173 0 r
.41667 .55452 m
.40238 .55847 L
s
0 0 0 r
2.5 Mabswid
.40238 .55847 Mdot
.54692 .61353 Mdot
.732 1 0 r
.5 Mabswid
.51448 .58654 m
.54692 .61353 L
s
0 0 0 r
2.5 Mabswid
.54993 .3853 Mdot
.60905 .42563 Mdot
.4029 .55787 Mdot
.741 1 0 r
.5 Mabswid
.40043 .53126 m
.4029 .55787 L
s
0 0 0 r
2.5 Mabswid
.40031 .55126 Mdot
.61269 .56227 Mdot
.39402 .53457 Mdot
0 .939 1 r
.5 Mabswid
.60007 .40769 m
.78966 .34115 L
s
0 0 0 r
2.5 Mabswid
.60007 .40769 Mdot
0 g
.5 Mabswid
.64052 .50006 m
.59568 .54006 L
s
.64063 .50013 m
.59569 .46044 L
s
.59569 .54008 m
.64063 .50013 L
s
.59568 .46047 m
.64062 .50016 L
s
.807 1 0 r
.64031 .50013 m
.78503 .5011 L
s
0 0 0 r
2.5 Mabswid
.64031 .50013 Mdot
1 0 0 r
.5 Mabswid
.62113 .50226 m
.64031 .50013 L
s
1 .392 0 r
.4503 .35763 m
.39237 .50279 L
s
0 0 0 r
2.5 Mabswid
.39237 .50279 Mdot
.46414 .38849 Mdot
.61509 .55361 Mdot
1 .244 0 r
.5 Mabswid
.54531 .30139 m
.63042 .51938 L
s
0 0 0 r
2.5 Mabswid
.63042 .51938 Mdot
.838 1 0 r
.5 Mabswid
.39303 .50022 m
.19524 .50157 L
s
0 0 0 r
2.5 Mabswid
.39303 .50022 Mdot
1 0 0 r
.5 Mabswid
.37347 .50233 m
.39303 .50022 L
s
0 0 0 r
2.5 Mabswid
.50985 .61927 Mdot
.59624 .58893 Mdot
.55663 .60732 Mdot
.40831 .43786 Mdot
0 1 .969 r
.5 Mabswid
.50488 .61805 m
.34105 .8091 L
s
0 0 0 r
2.5 Mabswid
.50488 .61805 Mdot
.6185 .54298 Mdot
.63319 .48924 Mdot
.63605 .50181 Mdot
.42322 .4216 Mdot
.43403 .58653 Mdot
.63456 .50192 Mdot
1 .243 0 r
.5 Mabswid
.29439 .53745 m
.40669 .55359 L
s
0 0 0 r
2.5 Mabswid
.40669 .55359 Mdot
.774 1 0 r
.5 Mabswid
.32037 .36264 m
.39697 .50349 L
s
0 0 0 r
2.5 Mabswid
.39697 .50349 Mdot
0 1 .72 r
.5 Mabswid
.6015 .42093 m
.78535 .35695 L
s
0 0 0 r
2.5 Mabswid
.6015 .42093 Mdot
0 1 .517 r
.5 Mabswid
.55968 .42978 m
.6015 .42093 L
s
0 0 0 r
2.5 Mabswid
.50737 .6151 Mdot
.809 1 0 r
.5 Mabswid
.63318 .50015 m
.78607 .50118 L
s
0 0 0 r
2.5 Mabswid
.63318 .50015 Mdot
1 0 0 r
.5 Mabswid
.61417 .50226 m
.63318 .50015 L
s
0 1 .635 r
.20986 .31174 m
.43182 .41593 L
s
0 0 0 r
2.5 Mabswid
.43182 .41593 Mdot
.48067 .61057 Mdot
.3983 .48217 Mdot
1 .388 0 r
.5 Mabswid
.45808 .35302 m
.39866 .49794 L
s
0 0 0 r
2.5 Mabswid
.39866 .49794 Mdot
.39844 .48206 Mdot
.47902 .38676 Mdot
.699 1 0 r
.5 Mabswid
.42292 .42815 m
.48573 .4423 L
s
0 0 0 r
2.5 Mabswid
.42292 .42815 Mdot
.61546 .45665 Mdot
.58308 .40474 Mdot
0 .267 1 r
.5 Mabswid
.31164 .68388 m
.56871 .59934 L
s
0 0 0 r
2.5 Mabswid
.56871 .59934 Mdot
.62763 .48454 Mdot
.84 1 0 r
.5 Mabswid
.39962 .50024 m
.19278 .50167 L
s
0 0 0 r
2.5 Mabswid
.39962 .50024 Mdot
1 0 0 r
.5 Mabswid
.3803 .50232 m
.39962 .50024 L
s
0 0 0 r
2.5 Mabswid
.77348 .52123 Mdot
.40043 .53126 Mdot
0 .599 1 r
.5 Mabswid
.78201 .31164 m
.59096 .41292 L
s
0 0 0 r
2.5 Mabswid
.59096 .41292 Mdot
.61963 .53004 Mdot
.54456 .39162 Mdot
.44778 .59336 Mdot
0 .989 1 r
.5 Mabswid
.41865 .55978 m
.55954 .58651 L
s
0 0 0 r
2.5 Mabswid
.41865 .55978 Mdot
1 .246 0 r
.5 Mabswid
.53815 .29742 m
.62538 .51497 L
s
0 0 0 r
2.5 Mabswid
.62538 .51497 Mdot
.61817 .46833 Mdot
.811 1 0 r
.5 Mabswid
.62606 .50018 m
.78713 .50127 L
s
0 0 0 r
2.5 Mabswid
.62606 .50018 Mdot
1 0 0 r
.5 Mabswid
.60721 .50226 m
.62606 .50018 L
s
1 .26 0 r
.30173 .53129 m
.41122 .54861 L
s
0 0 0 r
2.5 Mabswid
.41122 .54861 Mdot
.40404 .52502 Mdot
0 g
.5 Mabswid
.40425 .53986 m
.40419 .46063 L
s
.46016 .596 m
.40425 .53986 L
s
.4602 .59597 m
.40429 .53983 L
s
.4043 .53987 m
.40424 .46063 L
s
0 0 0 r
2.5 Mabswid
.61645 .46751 Mdot
0 .709 1 r
.5 Mabswid
.6226 .42142 m
.61469 .46423 L
s
0 0 0 r
2.5 Mabswid
.61469 .46423 Mdot
1 .429 0 r
.5 Mabswid
.27005 .34053 m
.40504 .49314 L
s
0 0 0 r
2.5 Mabswid
.40504 .49314 Mdot
.933 1 0 r
.5 Mabswid
.37229 .50233 m
.40628 .50026 L
s
0 0 0 r
2.5 Mabswid
.40628 .50026 Mdot
1 0 0 r
.5 Mabswid
.38713 .50232 m
.40628 .50026 L
s
0 0 0 r
2.5 Mabswid
.61622 .53004 Mdot
0 .989 1 r
.5 Mabswid
.56878 .56804 m
.61622 .53004 L
s
0 0 0 r
2.5 Mabswid
.40727 .49683 Mdot
.50237 .60591 Mdot
0 g
.5 Mabswid
.40419 .46063 m
.46007 .40443 L
s
.40423 .46067 m
.4601 .40448 L
s
1 .161 0 r
.41665 .54325 m
.188 .63924 L
s
0 0 0 r
2.5 Mabswid
.41665 .54325 Mdot
1 .286 0 r
.5 Mabswid
.57083 .58667 m
.61174 .4588 L
s
0 0 0 r
2.5 Mabswid
.61174 .4588 Mdot
.40677 .47234 Mdot
.41221 .49474 Mdot
.934 1 0 r
.5 Mabswid
.38099 .50232 m
.41307 .50026 L
s
0 0 0 r
2.5 Mabswid
.41307 .50026 Mdot
1 0 0 r
.5 Mabswid
.39396 .50232 m
.41307 .50026 L
s
1 .427 0 r
.27902 .33526 m
.41197 .4888 L
s
0 0 0 r
2.5 Mabswid
.41197 .4888 Mdot
.41175 .48485 Mdot
.43772 .42081 Mdot
.2 0 1 r
.5 Mabswid
.44575 .42771 m
.43772 .42081 L
s
0 1 .391 r
.57528 .74839 m
.58319 .58043 L
s
0 0 0 r
2.5 Mabswid
.58319 .58043 Mdot
0 1 .953 r
.5 Mabswid
.73105 .40838 m
.6081 .45159 L
s
0 0 0 r
2.5 Mabswid
.6081 .45159 Mdot
1 .162 0 r
.5 Mabswid
.42229 .53782 m
.18628 .6361 L
s
0 0 0 r
2.5 Mabswid
.42229 .53782 Mdot
.57 1 0 r
.5 Mabswid
.56129 .30708 m
.42703 .55625 L
s
0 0 0 r
2.5 Mabswid
.42703 .55625 Mdot
.934 1 0 r
.5 Mabswid
.38969 .50232 m
.41987 .50026 L
s
0 0 0 r
2.5 Mabswid
.41987 .50026 Mdot
1 0 0 r
.5 Mabswid
.4008 .50232 m
.41987 .50026 L
s
1 .424 0 r
.28797 .33001 m
.41889 .48447 L
s
0 0 0 r
2.5 Mabswid
.41889 .48447 Mdot
.42836 .5461 Mdot
1 .163 0 r
.5 Mabswid
.42791 .53239 m
.18451 .63292 L
s
0 0 0 r
2.5 Mabswid
.42791 .53239 Mdot
.493 1 0 r
.5 Mabswid
.56639 .29366 m
.43051 .54657 L
s
0 0 0 r
2.5 Mabswid
.43051 .54657 Mdot
.42583 .51367 Mdot
.42935 .52214 Mdot
.934 1 0 r
.5 Mabswid
.39839 .50232 m
.42667 .50026 L
s
0 0 0 r
2.5 Mabswid
.42667 .50026 Mdot
1 0 0 r
.5 Mabswid
.40763 .50232 m
.42667 .50026 L
s
0 0 0 r
2.5 Mabswid
.43288 .53063 Mdot
1 .422 0 r
.5 Mabswid
.2969 .32477 m
.4258 .48014 L
s
0 0 0 r
2.5 Mabswid
.4258 .48014 Mdot
1 .228 0 r
.5 Mabswid
.67622 .4571 m
.61977 .51067 L
s
0 0 0 r
2.5 Mabswid
.61977 .51067 Mdot
.43642 .53913 Mdot
.60469 .55064 Mdot
.57564 .58366 Mdot
.50883 .60374 Mdot
.934 1 0 r
.5 Mabswid
.40708 .50232 m
.43346 .50026 L
s
0 0 0 r
2.5 Mabswid
.43346 .50026 Mdot
1 0 0 r
.5 Mabswid
.41447 .50231 m
.43346 .50026 L
s
0 0 0 r
2.5 Mabswid
.42856 .46319 Mdot
0 .375 1 r
.5 Mabswid
.22434 .32001 m
.4404 .42131 L
s
0 0 0 r
2.5 Mabswid
.4404 .42131 Mdot
.43788 .42441 Mdot
.44016 .5262 Mdot
1 .421 0 r
.5 Mabswid
.30581 .31954 m
.43268 .47583 L
s
0 0 0 r
2.5 Mabswid
.43268 .47583 Mdot
.813 1 0 r
.5 Mabswid
.61895 .5002 m
.7882 .50137 L
s
0 0 0 r
2.5 Mabswid
.61895 .5002 Mdot
1 0 0 r
.5 Mabswid
.60026 .50227 m
.61895 .5002 L
s
0 .989 1 r
.5151 .60372 m
.56878 .56804 L
s
0 0 0 r
2.5 Mabswid
.5151 .60372 Mdot
.934 1 0 r
.5 Mabswid
.41577 .50231 m
.44027 .50026 L
s
0 0 0 r
2.5 Mabswid
.44027 .50026 Mdot
1 0 0 r
.5 Mabswid
.4213 .50231 m
.44027 .50026 L
s
0 .58 1 r
.76724 .31968 m
.58114 .41835 L
s
0 0 0 r
2.5 Mabswid
.58114 .41835 Mdot
.43337 .45269 Mdot
.4562 .57495 Mdot
0 g
.5 Mabswid
.46016 .596 m
.46016 .596 L
s
.53946 .59621 m
.46016 .596 L
s
.53946 .59616 m
.46016 .59595 L
s
0 0 0 r
2.5 Mabswid
.61012 .46213 Mdot
.934 1 0 r
.5 Mabswid
.42446 .50231 m
.44707 .50026 L
s
0 0 0 r
2.5 Mabswid
.44707 .50026 Mdot
1 0 0 r
.5 Mabswid
.42814 .50231 m
.44707 .50026 L
s
1 .16 0 r
.54876 .45565 m
.60003 .43978 L
s
0 0 0 r
2.5 Mabswid
.60003 .43978 Mdot
0 .502 1 r
.5 Mabswid
.65745 .21445 m
.50732 .39542 L
s
0 0 0 r
2.5 Mabswid
.50732 .39542 Mdot
.934 1 0 r
.5 Mabswid
.43315 .50231 m
.45388 .50026 L
s
0 0 0 r
2.5 Mabswid
.45388 .50026 Mdot
1 0 0 r
.5 Mabswid
.43499 .50231 m
.45388 .50026 L
s
0 0 0 r
2.5 Mabswid
.44796 .44302 Mdot
.44575 .42771 Mdot
.56987 .41193 Mdot
.61284 .47107 Mdot
.699 1 0 r
.5 Mabswid
.48573 .4423 m
.61284 .47107 L
s
.934 1 0 r
.44183 .50231 m
.46068 .50026 L
s
0 0 0 r
2.5 Mabswid
.46068 .50026 Mdot
.46241 .50964 Mdot
.46093 .48103 Mdot
.934 1 0 r
.5 Mabswid
.45051 .50231 m
.46749 .50026 L
s
0 0 0 r
2.5 Mabswid
.46749 .50026 Mdot
1 0 0 r
.5 Mabswid
.44868 .50231 m
.46749 .50026 L
s
0 .43 1 r
.32885 .39642 m
.45733 .42865 L
s
0 0 0 r
2.5 Mabswid
.45733 .42865 Mdot
.47842 .56254 Mdot
.49937 .59766 Mdot
.934 1 0 r
.5 Mabswid
.45919 .5023 m
.47431 .50026 L
s
0 0 0 r
2.5 Mabswid
.47431 .50026 Mdot
1 0 0 r
.5 Mabswid
.45552 .5023 m
.47431 .50026 L
s
0 g
.46007 .40443 m
.53943 .40423 L
s
.46007 .40449 m
.53943 .4043 L
s
0 0 0 r
2.5 Mabswid
.48074 .52465 Mdot
.48315 .53353 Mdot
.48557 .5424 Mdot
.934 1 0 r
.5 Mabswid
.46787 .5023 m
.48112 .50026 L
s
0 0 0 r
2.5 Mabswid
.48112 .50026 Mdot
1 0 0 r
.5 Mabswid
.46238 .5023 m
.48112 .50026 L
s
0 0 0 r
2.5 Mabswid
.47964 .46215 Mdot
0 .402 1 r
.5 Mabswid
.35085 .4054 m
.4761 .43646 L
s
0 0 0 r
2.5 Mabswid
.4761 .43646 Mdot
.815 1 0 r
.5 Mabswid
.61184 .50022 m
.7893 .50146 L
s
0 0 0 r
2.5 Mabswid
.61184 .50022 Mdot
1 0 0 r
.5 Mabswid
.59332 .50227 m
.61184 .50022 L
s
0 0 0 r
2.5 Mabswid
.4822 .47095 Mdot
.48476 .47975 Mdot
.934 1 0 r
.5 Mabswid
.47654 .5023 m
.48794 .50026 L
s
0 0 0 r
2.5 Mabswid
.48794 .50026 Mdot
1 0 0 r
.5 Mabswid
.46923 .5023 m
.48794 .50026 L
s
0 0 0 r
2.5 Mabswid
.55954 .58651 Mdot
.49364 .52118 Mdot
.4956 .52726 Mdot
.49642 .52223 Mdot
.50173 .55338 Mdot
.5271 .39824 Mdot
.48573 .4423 Mdot
.934 1 0 r
.5 Mabswid
.48522 .5023 m
.49476 .50026 L
s
0 0 0 r
2.5 Mabswid
.49476 .50026 Mdot
1 0 0 r
.5 Mabswid
.47609 .5023 m
.49476 .50026 L
s
0 0 0 r
2.5 Mabswid
.50488 .56678 Mdot
.51269 .58947 Mdot
.61006 .48381 Mdot
.49752 .47305 Mdot
.934 1 0 r
.5 Mabswid
.49389 .50229 m
.50159 .50026 L
s
0 0 0 r
2.5 Mabswid
.50159 .50026 Mdot
1 0 0 r
.5 Mabswid
.48295 .5023 m
.50159 .50026 L
s
0 0 0 r
2.5 Mabswid
.51448 .58654 Mdot
.4923 .43052 Mdot
.49838 .46993 Mdot
.49038 .41607 Mdot
.50896 .53765 Mdot
.77415 .52281 Mdot
.50286 .48201 Mdot
.56875 .4203 Mdot
.5114 .52881 Mdot
.50468 .47966 Mdot
.934 1 0 r
.5 Mabswid
.50257 .50229 m
.50842 .50026 L
s
0 0 0 r
2.5 Mabswid
.50842 .50026 Mdot
1 0 0 r
.5 Mabswid
.48981 .50229 m
.50842 .50026 L
s
0 0 0 r
2.5 Mabswid
.52153 .40085 Mdot
0 .538 1 r
.5 Mabswid
.52753 .40709 m
.52153 .40085 L
s
0 0 0 r
2.5 Mabswid
.5511 .4059 Mdot
0 .565 1 r
.5 Mabswid
.48819 .53407 m
.49923 .42606 L
s
0 0 0 r
2.5 Mabswid
.49923 .42606 Mdot
.50732 .47087 Mdot
0 .56 1 r
.5 Mabswid
.75267 .32769 m
.57144 .42381 L
s
0 0 0 r
2.5 Mabswid
.57144 .42381 Mdot
.58785 .55958 Mdot
.51664 .51828 Mdot
.933 1 0 r
.5 Mabswid
.51124 .50229 m
.51525 .50026 L
s
0 0 0 r
2.5 Mabswid
.51525 .50026 Mdot
1 0 0 r
.5 Mabswid
.49668 .50229 m
.51525 .50026 L
s
0 0 0 r
2.5 Mabswid
.52839 .58439 Mdot
1 .247 0 r
.5 Mabswid
.66882 .47023 m
.59547 .44468 L
s
0 0 0 r
2.5 Mabswid
.59547 .44468 Mdot
0 1 .516 r
.5 Mabswid
.25169 .19291 m
.52005 .51537 L
s
0 0 0 r
2.5 Mabswid
.52005 .51537 Mdot
.52713 .54932 Mdot
.933 1 0 r
.5 Mabswid
.51991 .50229 m
.52209 .50026 L
s
0 0 0 r
2.5 Mabswid
.52209 .50026 Mdot
1 0 0 r
.5 Mabswid
.50356 .50229 m
.52209 .50026 L
s
.703 1 0 r
.66043 .64807 m
.60633 .49998 L
s
0 0 0 r
2.5 Mabswid
.60633 .49998 Mdot
.761 1 0 r
.5 Mabswid
.51399 .24435 m
.51651 .44554 L
s
0 0 0 r
2.5 Mabswid
.51651 .44554 Mdot
0 g
.5 Mabswid
.59575 .54008 m
.53946 .59621 L
s
.5957 .54004 m
.53942 .59618 L
s
0 0 0 r
2.5 Mabswid
.55474 .58383 Mdot
.933 1 0 r
.5 Mabswid
.52858 .50228 m
.52893 .50026 L
s
0 0 0 r
2.5 Mabswid
.52893 .50026 Mdot
1 0 0 r
.5 Mabswid
.51043 .50229 m
.52893 .50026 L
s
.817 1 0 r
.60474 .50024 m
.79041 .50155 L
s
0 0 0 r
2.5 Mabswid
.60474 .50024 Mdot
1 0 0 r
.5 Mabswid
.58638 .50227 m
.60474 .50024 L
s
0 0 0 r
2.5 Mabswid
.60475 .46763 Mdot
.933 1 0 r
.5 Mabswid
.53725 .50228 m
.53577 .50026 L
s
0 0 0 r
2.5 Mabswid
.53577 .50026 Mdot
1 0 0 r
.5 Mabswid
.51731 .50229 m
.53577 .50026 L
s
0 0 0 r
2.5 Mabswid
.54813 .58154 Mdot
0 .414 1 r
.5 Mabswid
.34835 .56433 m
.54697 .56205 L
s
0 0 0 r
2.5 Mabswid
.54697 .56205 Mdot
.54858 .57253 Mdot
.52959 .43136 Mdot
.52674 .41033 Mdot
.52753 .40709 Mdot
.933 1 0 r
.5 Mabswid
.54593 .50228 m
.54262 .50027 L
s
0 0 0 r
2.5 Mabswid
.54262 .50027 Mdot
1 0 0 r
.5 Mabswid
.5242 .50229 m
.54262 .50027 L
s
0 1 .067 r
.63554 .40831 m
.53808 .43811 L
s
0 0 0 r
2.5 Mabswid
.53808 .43811 Mdot
.54737 .48979 Mdot
.57853 .56085 Mdot
.933 1 0 r
.5 Mabswid
.5546 .50228 m
.54947 .50027 L
s
0 0 0 r
2.5 Mabswid
.54947 .50027 Mdot
1 0 0 r
.5 Mabswid
.53109 .50228 m
.54947 .50027 L
s
0 0 0 r
2.5 Mabswid
.55884 .55556 Mdot
.56878 .56804 Mdot
0 g
.5 Mabswid
.53943 .40423 m
.59575 .46044 L
s
.53939 .40428 m
.59571 .46048 L
s
.933 1 0 r
.56327 .50228 m
.55633 .50027 L
s
0 0 0 r
2.5 Mabswid
.55633 .50027 Mdot
1 0 0 r
.5 Mabswid
.53798 .50228 m
.55633 .50027 L
s
0 0 0 r
2.5 Mabswid
.5474 .43697 Mdot
.56366 .53221 Mdot
.59334 .54689 Mdot
.932 1 0 r
.5 Mabswid
.57195 .50227 m
.56319 .50027 L
s
0 0 0 r
2.5 Mabswid
.56319 .50027 Mdot
1 0 0 r
.5 Mabswid
.54488 .50228 m
.56319 .50027 L
s
0 0 0 r
2.5 Mabswid
.56733 .52368 Mdot
.57138 .54989 Mdot
.56805 .52499 Mdot
1 .242 0 r
.5 Mabswid
.66177 .47636 m
.5906 .44975 L
s
0 0 0 r
2.5 Mabswid
.5906 .44975 Mdot
1 .396 0 r
.5 Mabswid
.65042 .31554 m
.5639 .4729 L
s
0 0 0 r
2.5 Mabswid
.5639 .4729 Mdot
.932 1 0 r
.5 Mabswid
.58062 .50227 m
.57006 .50027 L
s
0 0 0 r
2.5 Mabswid
.57006 .50027 Mdot
1 0 0 r
.5 Mabswid
.55178 .50228 m
.57006 .50027 L
s
0 .668 1 r
.65985 .39897 m
.55968 .42978 L
s
0 0 0 r
2.5 Mabswid
.55968 .42978 Mdot
1 .17 0 r
.5 Mabswid
.78886 .37944 m
.56841 .47132 L
s
0 0 0 r
2.5 Mabswid
.56841 .47132 Mdot
.58109 .44288 Mdot
1 .398 0 r
.5 Mabswid
.6589 .32118 m
.57073 .47718 L
s
0 0 0 r
2.5 Mabswid
.57073 .47718 Mdot
.57965 .53353 Mdot
.932 1 0 r
.5 Mabswid
.5893 .50227 m
.57693 .50027 L
s
0 0 0 r
2.5 Mabswid
.57693 .50027 Mdot
1 0 0 r
.5 Mabswid
.55869 .50228 m
.57693 .50027 L
s
0 0 0 r
2.5 Mabswid
.57081 .4463 Mdot
1 .169 0 r
.5 Mabswid
.79674 .37217 m
.57406 .46588 L
s
0 0 0 r
2.5 Mabswid
.57406 .46588 Mdot
.261 1 0 r
.5 Mabswid
.4973 .33791 m
.5981 .49462 L
s
0 0 0 r
2.5 Mabswid
.5981 .49462 Mdot
1 .401 0 r
.5 Mabswid
.66739 .32682 m
.57757 .48148 L
s
0 0 0 r
2.5 Mabswid
.57757 .48148 Mdot
.57955 .48167 Mdot
.819 1 0 r
.5 Mabswid
.59764 .50026 m
.79155 .50165 L
s
0 0 0 r
2.5 Mabswid
.59764 .50026 Mdot
1 0 0 r
.5 Mabswid
.57945 .50227 m
.59764 .50026 L
s
.932 1 0 r
.59798 .50227 m
.58381 .50027 L
s
0 0 0 r
2.5 Mabswid
.58381 .50027 Mdot
1 0 0 r
.5 Mabswid
.5656 .50227 m
.58381 .50027 L
s
0 0 0 r
2.5 Mabswid
.57992 .46979 Mdot
1 .168 0 r
.5 Mabswid
.57972 .46044 m
.79756 .3679 L
s
0 0 0 r
2.5 Mabswid
.57972 .46044 Mdot
.59014 .5243 Mdot
1 .403 0 r
.5 Mabswid
.6759 .33246 m
.58444 .48578 L
s
0 0 0 r
2.5 Mabswid
.58444 .48578 Mdot
0 g
.5 Mabswid
.59575 .46044 m
.59575 .54008 L
s
.59569 .46044 m
.59569 .54008 L
s
.932 1 0 r
.60666 .50226 m
.5907 .50027 L
s
0 0 0 r
2.5 Mabswid
.5907 .50027 Mdot
1 0 0 r
.5 Mabswid
.57252 .50227 m
.5907 .50027 L
s
1 .168 0 r
.58538 .45499 m
.79666 .36442 L
s
0 0 0 r
2.5 Mabswid
.58538 .45499 Mdot
1 .397 0 r
.5 Mabswid
.68442 .33812 m
.59133 .4901 L
s
0 0 0 r
2.5 Mabswid
.59133 .4901 Mdot
.22375 .35033 Mdot
.48852 .77565 Mdot
.50444 .22484 Mdot
.46819 .77817 Mdot
.54054 .2208 Mdot
.2152 .35862 Mdot
.78081 .25804 Mdot
.63952 .21631 Mdot
.5939 .21551 Mdot
.78202 .3655 Mdot
.78336 .66844 Mdot
.20459 .50119 Mdot
.60203 .79078 Mdot
.61162 .79142 Mdot
.20232 .50128 Mdot
.78503 .5011 Mdot
.78535 .35695 Mdot
.2 .50138 Mdot
.78607 .50118 Mdot
.78713 .50127 Mdot
.19764 .50147 Mdot
.7882 .50137 Mdot
.19524 .50157 Mdot
.65301 .20468 Mdot
.7893 .50146 Mdot
.19278 .50167 Mdot
.64168 .2033 Mdot
.78966 .34115 Mdot
.79041 .50155 Mdot
.63226 .20213 Mdot
.79155 .50165 Mdot
.188 .63924 Mdot
.18689 .46567 Mdot
.1864 .53414 Mdot
.18628 .6361 Mdot
.18451 .63292 Mdot
.34105 .8091 Mdot
.79666 .36442 Mdot
.79756 .3679 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.431973 0.0136054 0.97619 0.557823 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.72956 .73729 m
.76077 .76342 L
s
.24983 .73947 m
.72956 .73729 L
s
.72956 .73729 m
.73015 .2591 L
s
0 0 0 r
2.5 Mabswid
.71253 .71765 Mdot
.599 1 0 r
.5 Mabswid
.66072 .51305 m
.71253 .71765 L
s
0 0 0 r
2.5 Mabswid
.71105 .49316 Mdot
0 .852 1 r
.5 Mabswid
.66184 .43559 m
.71105 .49316 L
s
0 0 0 r
2.5 Mabswid
.72568 .4209 Mdot
1 .921 0 r
.5 Mabswid
.6511 .46826 m
.72568 .4209 L
s
0 0 0 r
2.5 Mabswid
.72608 .37421 Mdot
.265 1 0 r
.5 Mabswid
.56693 .48872 m
.72608 .37421 L
s
0 g
.7615 .2356 m
.73015 .2591 L
s
.73015 .2591 m
.24951 .25682 L
s
0 0 0 r
2.5 Mabswid
.65134 .56576 Mdot
0 .521 1 r
.5 Mabswid
.59909 .51201 m
.65134 .56576 L
s
0 0 0 r
2.5 Mabswid
.64887 .57409 Mdot
0 .473 1 r
.5 Mabswid
.59685 .52056 m
.64887 .57409 L
s
0 0 0 r
2.5 Mabswid
.65209 .40063 Mdot
0 .547 1 r
.5 Mabswid
.60134 .42503 m
.65209 .40063 L
s
0 0 0 r
2.5 Mabswid
.64533 .42111 Mdot
.595 1 0 r
.5 Mabswid
.5523 .49543 m
.64533 .42111 L
s
0 0 0 r
2.5 Mabswid
.65765 .30834 Mdot
0 .881 1 r
.5 Mabswid
.58086 .441 m
.65765 .30834 L
s
0 0 0 r
2.5 Mabswid
.65528 .29887 Mdot
0 1 .37 r
.5 Mabswid
.57766 .43339 m
.65528 .29887 L
s
0 0 0 r
2.5 Mabswid
.56655 .70905 Mdot
.664 1 0 r
.5 Mabswid
.58774 .6031 m
.56655 .70905 L
s
0 0 0 r
2.5 Mabswid
.6529 .28938 Mdot
0 1 .36 r
.5 Mabswid
.57445 .42575 m
.6529 .28938 L
s
0 0 0 r
2.5 Mabswid
.63461 .37302 Mdot
.417 1 0 r
.5 Mabswid
.49439 .34404 m
.63461 .37302 L
s
0 0 0 r
2.5 Mabswid
.56205 .71745 Mdot
.713 1 0 r
.5 Mabswid
.58372 .60952 m
.56205 .71745 L
s
0 0 0 r
2.5 Mabswid
.58731 .44596 Mdot
0 1 .989 r
.5 Mabswid
.57255 .45213 m
.58731 .44596 L
s
0 0 0 r
2.5 Mabswid
.7308 .42551 Mdot
.92 1 0 r
.5 Mabswid
.657 .47293 m
.7308 .42551 L
s
0 0 0 r
2.5 Mabswid
.4778 .73502 Mdot
0 1 .68 r
.5 Mabswid
.53866 .64418 m
.4778 .73502 L
s
0 0 0 r
2.5 Mabswid
.50229 .48562 Mdot
.317 1 0 r
.5 Mabswid
.60832 .4437 m
.50229 .48562 L
s
0 0 0 r
2.5 Mabswid
.49887 .49005 Mdot
.266 1 0 r
.5 Mabswid
.6038 .44847 m
.49887 .49005 L
s
0 0 0 r
2.5 Mabswid
.49534 .49451 Mdot
.254 1 0 r
.5 Mabswid
.5993 .45322 m
.49534 .49451 L
s
0 0 0 r
2.5 Mabswid
.49164 .49905 Mdot
.235 1 0 r
.5 Mabswid
.59482 .45795 m
.49164 .49905 L
s
0 0 0 r
2.5 Mabswid
.46547 .51275 Mdot
.282 1 0 r
.5 Mabswid
.39115 .54497 m
.46547 .51275 L
s
0 0 0 r
2.5 Mabswid
.46273 .51692 Mdot
.251 1 0 r
.5 Mabswid
.38698 .54979 m
.46273 .51692 L
s
0 0 0 r
2.5 Mabswid
.45995 .52111 Mdot
.243 1 0 r
.5 Mabswid
.38279 .55463 m
.45995 .52111 L
s
0 0 0 r
2.5 Mabswid
.46455 .49556 Mdot
0 .31 1 r
.5 Mabswid
.47099 .461 m
.46455 .49556 L
s
0 0 0 r
2.5 Mabswid
.41218 .72007 Mdot
.918 1 0 r
.5 Mabswid
.40723 .61357 m
.41218 .72007 L
s
0 0 0 r
2.5 Mabswid
.40784 .71171 Mdot
.76 1 0 r
.5 Mabswid
.40306 .60713 m
.40784 .71171 L
s
0 0 0 r
2.5 Mabswid
.4956 .28393 Mdot
0 1 .255 r
.5 Mabswid
.45053 .36506 m
.4956 .28393 L
s
0 0 0 r
2.5 Mabswid
.47804 .34885 Mdot
0 1 .497 r
.5 Mabswid
.53681 .48782 m
.47804 .34885 L
s
0 0 0 r
2.5 Mabswid
.40353 .70338 Mdot
.769 1 0 r
.5 Mabswid
.3989 .60071 m
.40353 .70338 L
s
0 0 0 r
2.5 Mabswid
.42669 .52932 Mdot
.019 0 1 r
.5 Mabswid
.4635 .51184 m
.42669 .52932 L
s
0 0 0 r
2.5 Mabswid
.38266 .53443 Mdot
0 1 .846 r
.5 Mabswid
.41343 .54989 m
.38266 .53443 L
s
0 0 0 r
2.5 Mabswid
.73211 .42342 Mdot
0 1 .91 r
.5 Mabswid
.63642 .43915 m
.73211 .42342 L
s
0 0 0 r
2.5 Mabswid
.33137 .54466 Mdot
0 1 .772 r
.5 Mabswid
.44059 .51887 m
.33137 .54466 L
s
0 0 0 r
2.5 Mabswid
.31725 .57109 Mdot
0 .581 1 r
.5 Mabswid
.38514 .51759 m
.31725 .57109 L
s
0 0 0 r
2.5 Mabswid
.31482 .56266 Mdot
0 .559 1 r
.5 Mabswid
.38296 .50899 m
.31482 .56266 L
s
0 0 0 r
2.5 Mabswid
.31275 .55754 Mdot
0 1 .968 r
.5 Mabswid
.36665 .54148 m
.31275 .55754 L
s
0 0 0 r
2.5 Mabswid
.31239 .55424 Mdot
0 .57 1 r
.5 Mabswid
.38079 .5004 m
.31239 .55424 L
s
0 0 0 r
2.5 Mabswid
.36003 .31592 Mdot
0 .244 1 r
.5 Mabswid
.47266 .4316 m
.36003 .31592 L
s
0 0 0 r
2.5 Mabswid
.31983 .49046 Mdot
0 1 .735 r
.5 Mabswid
.37628 .47563 m
.31983 .49046 L
s
0 g
.23112 .7661 m
.24983 .73947 L
s
.24951 .25682 m
.24983 .73947 L
s
0 0 0 r
2.5 Mabswid
.40722 .25729 Mdot
0 .123 1 r
.5 Mabswid
.43895 .41494 m
.40722 .25729 L
s
0 0 0 r
2.5 Mabswid
.26765 .58479 Mdot
0 1 .846 r
.5 Mabswid
.33118 .49447 m
.26765 .58479 L
s
0 0 0 r
2.5 Mabswid
.31214 .29691 Mdot
0 1 .692 r
.5 Mabswid
.40747 .43262 m
.31214 .29691 L
s
0 0 0 r
2.5 Mabswid
.30975 .30633 Mdot
0 1 .44 r
.5 Mabswid
.40411 .44026 m
.30975 .30633 L
s
0 0 0 r
2.5 Mabswid
.73259 .41556 Mdot
.235 1 0 r
.5 Mabswid
.5711 .48415 m
.73259 .41556 L
s
0 0 0 r
2.5 Mabswid
.26798 .4192 Mdot
1 .991 0 r
.5 Mabswid
.34864 .46428 m
.26798 .4192 L
s
0 0 0 r
2.5 Mabswid
.73269 .40232 Mdot
0 1 .874 r
.5 Mabswid
.63957 .43237 m
.73269 .40232 L
s
0 0 0 r
2.5 Mabswid
.26011 .42213 Mdot
1 .998 0 r
.5 Mabswid
.3427 .46882 m
.26011 .42213 L
s
0 0 0 r
2.5 Mabswid
.2571 .42411 Mdot
0 .892 1 r
.5 Mabswid
.36525 .43967 m
.2571 .42411 L
s
0 0 0 r
2.5 Mabswid
.25228 .42509 Mdot
.996 1 0 r
.5 Mabswid
.33677 .47339 m
.25228 .42509 L
s
0 0 0 r
2.5 Mabswid
.73278 .43218 Mdot
.912 1 0 r
.5 Mabswid
.66287 .47764 m
.73278 .43218 L
s
0 g
.24951 .25682 m
.23073 .23284 L
s
0 0 0 r
2.5 Mabswid
.62218 .25672 Mdot
.852 1 0 r
.5 Mabswid
.59009 .35173 m
.62218 .25672 L
s
0 0 0 r
2.5 Mabswid
.73397 .39639 Mdot
0 1 .858 r
.5 Mabswid
.6425 .42553 m
.73397 .39639 L
s
0 0 0 r
2.5 Mabswid
.24879 .43056 Mdot
.989 1 0 r
.5 Mabswid
.33087 .478 m
.24879 .43056 L
s
0 0 0 r
2.5 Mabswid
.60427 .74119 Mdot
0 .502 1 r
.5 Mabswid
.5475 .59922 m
.60427 .74119 L
s
0 0 0 r
2.5 Mabswid
.24856 .50944 Mdot
0 1 .704 r
.5 Mabswid
.42175 .56061 m
.24856 .50944 L
s
0 0 0 r
2.5 Mabswid
.73476 .43894 Mdot
.905 1 0 r
.5 Mabswid
.66871 .48239 m
.73476 .43894 L
s
0 0 0 r
2.5 Mabswid
.24752 .43738 Mdot
.983 1 0 r
.5 Mabswid
.32499 .48265 m
.24752 .43738 L
s
0 0 0 r
2.5 Mabswid
.24742 .58571 Mdot
.201 1 0 r
.5 Mabswid
.41653 .51451 m
.24742 .58571 L
s
0 g
.49369 .49862 m
.49318 .49985 L
s
.54677 .49892 m
.49369 .49862 L
s
.49318 .4974 m
.49369 .49864 L
s
.49369 .49864 m
.54675 .49893 L
s
.4932 .49984 m
.49196 .50035 L
s
.53111 .53673 m
.4932 .49984 L
s
.49318 .49985 m
.53109 .53672 L
s
.49372 .49863 m
.49321 .49986 L
s
.49321 .49739 m
.49372 .49863 L
s
.53115 .46109 m
.49318 .4974 L
s
.49196 .49691 m
.4932 .49742 L
s
.4932 .49742 m
.53114 .46112 L
s
.49321 .49986 m
.49197 .50038 L
s
.49198 .50035 m
.49075 .49984 L
s
.49331 .55243 m
.49198 .50035 L
s
.49197 .49688 m
.49321 .49739 L
s
.49196 .50035 m
.4933 .5524 L
s
.49197 .50038 m
.49074 .49986 L
s
.49335 .44538 m
.49196 .49691 L
s
.49075 .49742 m
.49198 .49691 L
s
.49198 .49691 m
.49336 .44541 L
s
.49076 .49985 m
.49025 .49862 L
s
.45547 .53678 m
.49076 .49985 L
s
.49075 .49984 m
.45548 .53676 L
s
.49074 .49739 m
.49197 .49688 L
s
.45548 .46103 m
.49075 .49742 L
s
.49025 .49864 m
.49076 .4974 L
s
.49076 .4974 m
.45551 .46104 L
s
.49074 .49986 m
.49023 .49863 L
s
.43978 .49891 m
.49025 .49864 L
s
.49025 .49862 m
.43981 .4989 L
s
.49023 .49863 m
.49074 .49739 L
s
0 0 0 r
2.5 Mabswid
.73664 .3761 Mdot
0 .918 1 r
.5 Mabswid
.64821 .41604 m
.73664 .3761 L
s
1 .116 0 r
.48907 .49864 m
.49513 .49618 L
s
0 0 0 r
2.5 Mabswid
.48907 .49864 Mdot
1 .116 0 r
.5 Mabswid
.49479 .50027 m
.48907 .49864 L
s
.49548 .49864 m
.48828 .50166 L
s
0 0 0 r
2.5 Mabswid
.49548 .49864 Mdot
1 .116 0 r
.5 Mabswid
.50163 .50027 m
.49548 .49864 L
s
.49513 .49618 m
.5684 .47137 L
s
0 0 0 r
2.5 Mabswid
.49513 .49618 Mdot
1 .116 0 r
.5 Mabswid
.48828 .50166 m
.42753 .53256 L
s
0 0 0 r
2.5 Mabswid
.48828 .50166 Mdot
1 .116 0 r
.5 Mabswid
.50202 .49868 m
.4815 .50731 L
s
0 0 0 r
2.5 Mabswid
.50202 .49868 Mdot
1 .116 0 r
.5 Mabswid
.50847 .50027 m
.50202 .49868 L
s
.48279 .49867 m
.50221 .49077 L
s
0 0 0 r
2.5 Mabswid
.48279 .49867 Mdot
1 .116 0 r
.5 Mabswid
.48794 .50027 m
.48279 .49867 L
s
.806 1 0 r
.48334 .49322 m
.46713 .61717 L
s
0 0 0 r
2.5 Mabswid
.48334 .49322 Mdot
.806 1 0 r
.5 Mabswid
.50726 .49001 m
.48334 .49322 L
s
1 .116 0 r
.50221 .49077 m
.57403 .46595 L
s
0 0 0 r
2.5 Mabswid
.50221 .49077 Mdot
0 1 .832 r
.5 Mabswid
.48069 .49647 m
.60696 .45176 L
s
0 0 0 r
2.5 Mabswid
.48069 .49647 Mdot
0 1 .832 r
.5 Mabswid
.52833 .54611 m
.48069 .49647 L
s
.813 1 0 r
.50507 .50133 m
.51661 .4455 L
s
0 0 0 r
2.5 Mabswid
.50507 .50133 Mdot
.813 1 0 r
.5 Mabswid
.46901 .49578 m
.50507 .50133 L
s
0 0 0 r
2.5 Mabswid
.51667 .74436 Mdot
.871 1 0 r
.5 Mabswid
.39501 .59363 m
.51667 .74436 L
s
1 .116 0 r
.4815 .50731 m
.42185 .53802 L
s
0 0 0 r
2.5 Mabswid
.4815 .50731 Mdot
1 .116 0 r
.5 Mabswid
.50858 .49871 m
.47464 .51302 L
s
0 0 0 r
2.5 Mabswid
.50858 .49871 Mdot
1 .116 0 r
.5 Mabswid
.51531 .50027 m
.50858 .49871 L
s
0 0 0 r
2.5 Mabswid
.73845 .4299 Mdot
.103 1 0 r
.5 Mabswid
.54539 .44177 m
.73845 .4299 L
s
1 .116 0 r
.47648 .49871 m
.50938 .4853 L
s
0 0 0 r
2.5 Mabswid
.47648 .49871 Mdot
1 .116 0 r
.5 Mabswid
.4811 .50027 m
.47648 .49871 L
s
0 0 0 r
2.5 Mabswid
.24626 .44428 Mdot
.903 1 0 r
.5 Mabswid
.31913 .48734 m
.24626 .44428 L
s
0 0 0 r
2.5 Mabswid
.50726 .49001 Mdot
.806 1 0 r
.5 Mabswid
.61855 .51063 m
.50726 .49001 L
s
0 0 0 r
2.5 Mabswid
.73869 .37833 Mdot
0 .42 1 r
.5 Mabswid
.65541 .4162 m
.73869 .37833 L
s
0 1 .67 r
.47782 .50626 m
.4833 .46152 L
s
0 0 0 r
2.5 Mabswid
.47782 .50626 Mdot
0 1 .67 r
.5 Mabswid
.5173 .54746 m
.47782 .50626 L
s
0 .272 1 r
.50729 .51488 m
.37681 .48072 L
s
0 0 0 r
2.5 Mabswid
.50729 .51488 Mdot
0 .272 1 r
.5 Mabswid
.52188 .43137 m
.50729 .51488 L
s
1 .116 0 r
.51516 .49875 m
.4677 .51881 L
s
0 0 0 r
2.5 Mabswid
.51516 .49875 Mdot
1 .116 0 r
.5 Mabswid
.52215 .50027 m
.51516 .49875 L
s
0 0 0 r
2.5 Mabswid
.24587 .59502 Mdot
0 .339 1 r
.5 Mabswid
.4065 .53542 m
.24587 .59502 L
s
1 .116 0 r
.50938 .4853 m
.57966 .46053 L
s
0 0 0 r
2.5 Mabswid
.50938 .4853 Mdot
1 .116 0 r
.5 Mabswid
.47016 .49874 m
.51663 .47977 L
s
0 0 0 r
2.5 Mabswid
.47016 .49874 Mdot
1 .116 0 r
.5 Mabswid
.47426 .50027 m
.47016 .49874 L
s
.47464 .51302 m
.41616 .5435 L
s
0 0 0 r
2.5 Mabswid
.47464 .51302 Mdot
.46901 .49578 Mdot
.813 1 0 r
.5 Mabswid
.37638 .51375 m
.46901 .49578 L
s
1 .116 0 r
.52175 .49878 m
.46067 .52467 L
s
0 0 0 r
2.5 Mabswid
.52175 .49878 Mdot
1 .116 0 r
.5 Mabswid
.52899 .50027 m
.52175 .49878 L
s
0 0 0 r
2.5 Mabswid
.7401 .35915 Mdot
0 .016 1 r
.5 Mabswid
.67108 .43332 m
.7401 .35915 L
s
1 .116 0 r
.46381 .49878 m
.52396 .47418 L
s
0 0 0 r
2.5 Mabswid
.46381 .49878 Mdot
1 .116 0 r
.5 Mabswid
.46741 .50027 m
.46381 .49878 L
s
.51663 .47977 m
.58529 .4551 L
s
0 0 0 r
2.5 Mabswid
.51663 .47977 Mdot
.24508 .61152 Mdot
0 .968 1 r
.5 Mabswid
.4114 .46292 m
.24508 .61152 L
s
1 .116 0 r
.52837 .49882 m
.45354 .53061 L
s
0 0 0 r
2.5 Mabswid
.52837 .49882 Mdot
1 .116 0 r
.5 Mabswid
.53582 .50027 m
.52837 .49882 L
s
.4677 .51881 m
.41062 .54889 L
s
0 0 0 r
2.5 Mabswid
.4677 .51881 Mdot
.018 0 1 r
.5 Mabswid
.47212 .52523 m
.47835 .56271 L
s
0 0 0 r
2.5 Mabswid
.47212 .52523 Mdot
.018 0 1 r
.5 Mabswid
.49309 .46343 m
.47212 .52523 L
s
0 0 0 r
2.5 Mabswid
.49309 .46343 Mdot
.018 0 1 r
.5 Mabswid
.49932 .42595 m
.49309 .46343 L
s
0 0 0 r
2.5 Mabswid
.4635 .51184 Mdot
0 .092 1 r
.5 Mabswid
.60696 .45176 m
.4635 .51184 L
s
0 1 .003 r
.4591 .49666 m
.53524 .50262 L
s
0 0 0 r
2.5 Mabswid
.4591 .49666 Mdot
0 1 .003 r
.5 Mabswid
.42662 .55654 m
.4591 .49666 L
s
0 0 0 r
2.5 Mabswid
.52521 .51232 Mdot
0 .627 1 r
.5 Mabswid
.36641 .50139 m
.52521 .51232 L
s
0 1 .128 r
.4623 .48773 m
.5345 .49327 L
s
0 0 0 r
2.5 Mabswid
.4623 .48773 Mdot
0 1 .128 r
.5 Mabswid
.43014 .5468 m
.4623 .48773 L
s
1 .116 0 r
.45745 .49881 m
.53138 .46852 L
s
0 0 0 r
2.5 Mabswid
.45745 .49881 Mdot
1 .116 0 r
.5 Mabswid
.46056 .50027 m
.45745 .49881 L
s
0 .588 1 r
.4596 .49335 m
.50711 .3953 L
s
0 0 0 r
2.5 Mabswid
.4596 .49335 Mdot
0 .588 1 r
.5 Mabswid
.50011 .5433 m
.4596 .49335 L
s
0 1 .284 r
.48885 .46249 m
.54109 .50458 L
s
0 0 0 r
2.5 Mabswid
.48885 .46249 Mdot
0 1 .284 r
.5 Mabswid
.39601 .50352 m
.48885 .46249 L
s
1 .098 0 r
.52845 .51277 m
.5639 .47295 L
s
0 0 0 r
2.5 Mabswid
.52845 .51277 Mdot
1 .098 0 r
.5 Mabswid
.43901 .49892 m
.52845 .51277 L
s
1 .116 0 r
.52396 .47418 m
.59035 .44989 L
s
0 0 0 r
2.5 Mabswid
.52396 .47418 Mdot
1 .116 0 r
.5 Mabswid
.53501 .49886 m
.44633 .53662 L
s
0 0 0 r
2.5 Mabswid
.53501 .49886 Mdot
1 .116 0 r
.5 Mabswid
.54266 .50027 m
.53501 .49886 L
s
0 0 0 r
2.5 Mabswid
.74151 .40995 Mdot
.152 0 1 r
.5 Mabswid
.56523 .48142 m
.74151 .40995 L
s
0 0 0 r
2.5 Mabswid
.24447 .37731 Mdot
0 .475 1 r
.5 Mabswid
.33606 .41008 m
.24447 .37731 L
s
0 1 .003 r
.53524 .50262 m
.61342 .46436 L
s
0 0 0 r
2.5 Mabswid
.53524 .50262 Mdot
0 1 .128 r
.5 Mabswid
.5345 .49327 m
.6202 .56024 L
s
0 0 0 r
2.5 Mabswid
.5345 .49327 Mdot
0 1 .67 r
.5 Mabswid
.4833 .46152 m
.53199 .33319 L
s
0 0 0 r
2.5 Mabswid
.4833 .46152 Mdot
0 1 .063 r
.5 Mabswid
.50524 .53848 m
.43781 .4831 L
s
0 0 0 r
2.5 Mabswid
.50524 .53848 Mdot
0 1 .063 r
.5 Mabswid
.6057 .49998 m
.50524 .53848 L
s
1 .116 0 r
.45106 .49885 m
.53888 .46279 L
s
0 0 0 r
2.5 Mabswid
.45106 .49885 Mdot
1 .116 0 r
.5 Mabswid
.45371 .50027 m
.45106 .49885 L
s
1 .094 0 r
.4565 .51317 m
.43238 .47573 L
s
0 0 0 r
2.5 Mabswid
.4565 .51317 Mdot
1 .094 0 r
.5 Mabswid
.54722 .49892 m
.4565 .51317 L
s
1 .116 0 r
.46067 .52467 m
.40579 .55391 L
s
0 0 0 r
2.5 Mabswid
.46067 .52467 Mdot
1 .115 0 r
.5 Mabswid
.54167 .49889 m
.43944 .54253 L
s
0 0 0 r
2.5 Mabswid
.54167 .49889 Mdot
1 .115 0 r
.5 Mabswid
.5495 .50027 m
.54167 .49889 L
s
0 0 0 r
2.5 Mabswid
.53681 .48782 Mdot
0 1 .599 r
.5 Mabswid
.46713 .61717 m
.53681 .48782 L
s
0 0 0 r
2.5 Mabswid
.50011 .5433 Mdot
0 .588 1 r
.5 Mabswid
.58234 .58025 m
.50011 .5433 L
s
0 .932 1 r
.53262 .52184 m
.50404 .61821 L
s
0 0 0 r
2.5 Mabswid
.53262 .52184 Mdot
0 .932 1 r
.5 Mabswid
.46999 .44263 m
.53262 .52184 L
s
0 .739 1 r
.46794 .5345 m
.43797 .44572 L
s
0 0 0 r
2.5 Mabswid
.46794 .5345 Mdot
0 .739 1 r
.5 Mabswid
.6202 .56024 m
.46794 .5345 L
s
0 0 0 r
2.5 Mabswid
.244 .36699 Mdot
0 .785 1 r
.5 Mabswid
.33979 .40639 m
.244 .36699 L
s
1 .097 0 r
.53552 .51531 m
.5707 .47723 L
s
0 0 0 r
2.5 Mabswid
.53552 .51531 Mdot
1 .097 0 r
.5 Mabswid
.43018 .49897 m
.53552 .51531 L
s
.142 1 0 r
.54084 .49419 m
.46178 .57875 L
s
0 0 0 r
2.5 Mabswid
.54084 .49419 Mdot
.142 1 0 r
.5 Mabswid
.49236 .4304 m
.54084 .49419 L
s
.865 1 0 r
.52592 .53471 m
.37974 .39852 L
s
0 0 0 r
2.5 Mabswid
.52592 .53471 Mdot
.865 1 0 r
.5 Mabswid
.59035 .44989 m
.52592 .53471 L
s
0 1 .284 r
.54109 .50458 m
.58234 .58025 L
s
0 0 0 r
2.5 Mabswid
.54109 .50458 Mdot
.89 1 0 r
.5 Mabswid
.53157 .52823 m
.45216 .53622 L
s
0 0 0 r
2.5 Mabswid
.53157 .52823 Mdot
.89 1 0 r
.5 Mabswid
.59494 .44485 m
.53157 .52823 L
s
0 .149 1 r
.47099 .461 m
.53722 .67753 L
s
0 0 0 r
2.5 Mabswid
.47099 .461 Mdot
0 1 .943 r
.5 Mabswid
.5201 .51538 m
.47099 .461 L
s
.514 1 0 r
.5182 .45999 m
.55946 .67412 L
s
0 0 0 r
2.5 Mabswid
.5182 .45999 Mdot
.514 1 0 r
.5 Mabswid
.39118 .50281 m
.5182 .45999 L
s
0 0 0 r
2.5 Mabswid
.24383 .5923 Mdot
0 .409 1 r
.5 Mabswid
.42586 .51701 m
.24383 .5923 L
s
1 .116 0 r
.53138 .46852 m
.59494 .44485 L
s
0 0 0 r
2.5 Mabswid
.53138 .46852 Mdot
.74262 .41338 Mdot
.149 0 1 r
.5 Mabswid
.57255 .48209 m
.74262 .41338 L
s
1 .116 0 r
.44465 .49888 m
.54631 .45707 L
s
0 0 0 r
2.5 Mabswid
.44465 .49888 Mdot
1 .116 0 r
.5 Mabswid
.44686 .50027 m
.44465 .49888 L
s
0 g
.67142 .57194 m
.54677 .49892 L
s
.68575 .49977 m
.5467 .49893 L
s
.5467 .49893 m
.67152 .42754 L
s
.67137 .57193 m
.5467 .49891 L
s
.5467 .49891 m
.68575 .49975 L
s
.54675 .49893 m
.67157 .42754 L
s
.88 1 0 r
.46028 .46321 m
.60871 .60131 L
s
0 0 0 r
2.5 Mabswid
.46028 .46321 Mdot
.88 1 0 r
.5 Mabswid
.41062 .54889 m
.46028 .46321 L
s
0 g
.56949 .67428 m
.53111 .53673 L
s
.56946 .67425 m
.53107 .53668 L
s
.53107 .53668 m
.63059 .63316 L
s
.63057 .63317 m
.53106 .53669 L
s
.53106 .53669 m
.67139 .57191 L
s
.53109 .53672 m
.67142 .57194 L
s
0 0 0 r
2.5 Mabswid
.54722 .49892 Mdot
1 .094 0 r
.5 Mabswid
.59738 .50027 m
.54722 .49892 L
s
0 g
.67157 .42754 m
.53115 .46109 L
s
.63082 .36622 m
.53111 .46115 L
s
.53111 .46115 m
.56967 .32502 L
s
.67153 .42757 m
.53109 .46113 L
s
.53109 .46113 m
.6308 .3662 L
s
.53114 .46112 m
.5697 .32499 L
s
1 .094 0 r
.44963 .51579 m
.42543 .48005 L
s
0 0 0 r
2.5 Mabswid
.44963 .51579 Mdot
1 .094 0 r
.5 Mabswid
.5565 .49898 m
.44963 .51579 L
s
1 .115 0 r
.54835 .49893 m
.43001 .52327 L
s
0 0 0 r
2.5 Mabswid
.54835 .49893 Mdot
1 .115 0 r
.5 Mabswid
.55634 .50027 m
.54835 .49893 L
s
.865 1 0 r
.45468 .46974 m
.53589 .46285 L
s
0 0 0 r
2.5 Mabswid
.45468 .46974 Mdot
.865 1 0 r
.5 Mabswid
.40579 .55391 m
.45468 .46974 L
s
0 g
.42479 .67476 m
.49331 .55243 L
s
.42479 .67471 m
.49332 .55236 L
s
.49332 .55236 m
.49725 .68886 L
s
.49722 .68886 m
.4933 .55236 L
s
.4933 .55236 m
.56949 .67423 L
s
.4933 .5524 m
.56949 .67428 L
s
0 0 0 r
2.5 Mabswid
.24346 .57885 Mdot
.834 1 0 r
.5 Mabswid
.44082 .56243 m
.24346 .57885 L
s
0 g
.5697 .32499 m
.49335 .44538 L
s
.49737 .31035 m
.49336 .44545 L
s
.49336 .44545 m
.42481 .32453 L
s
.5697 .32503 m
.49333 .44545 L
s
.49333 .44545 m
.49735 .31035 L
s
.49336 .44541 m
.42481 .32449 L
s
.514 1 0 r
.52307 .45584 m
.5645 .66771 L
s
0 0 0 r
2.5 Mabswid
.52307 .45584 Mdot
.514 1 0 r
.5 Mabswid
.3978 .49793 m
.52307 .45584 L
s
1 .116 0 r
.45354 .53061 m
.40113 .55883 L
s
0 0 0 r
2.5 Mabswid
.45354 .53061 Mdot
.371 1 0 r
.5 Mabswid
.52139 .45521 m
.59452 .57527 L
s
0 0 0 r
2.5 Mabswid
.52139 .45521 Mdot
.371 1 0 r
.5 Mabswid
.3399 .45678 m
.52139 .45521 L
s
1 .097 0 r
.54266 .51787 m
.57751 .48152 L
s
0 0 0 r
2.5 Mabswid
.54266 .51787 Mdot
1 .097 0 r
.5 Mabswid
.42128 .49903 m
.54266 .51787 L
s
.142 1 0 r
.54579 .48726 m
.41001 .41161 L
s
0 0 0 r
2.5 Mabswid
.54579 .48726 Mdot
.142 1 0 r
.5 Mabswid
.4548 .66708 m
.54579 .48726 L
s
0 g
.32195 .57241 m
.45547 .53678 L
s
.32198 .57238 m
.45552 .53674 L
s
.45552 .53674 m
.36325 .63385 L
s
.36323 .63383 m
.45551 .53673 L
s
.45551 .53673 m
.42482 .67473 L
s
.45548 .53676 m
.42479 .67476 L
s
.42481 .32449 m
.45548 .46103 L
s
.36319 .36549 m
.45554 .46107 L
s
.45554 .46107 m
.32193 .42706 L
s
.42484 .32452 m
.45552 .46109 L
s
.45552 .46109 m
.36317 .36551 L
s
.45551 .46104 m
.3219 .42703 L
s
.865 1 0 r
.53589 .46285 m
.6057 .49998 L
s
0 0 0 r
2.5 Mabswid
.53589 .46285 Mdot
0 g
.5 Mabswid
.3219 .42703 m
.43978 .49891 L
s
.32194 .42703 m
.43985 .49892 L
s
.43985 .49892 m
.30746 .49975 L
s
.30746 .49973 m
.43985 .4989 L
s
.43985 .4989 m
.322 .5724 L
s
.43981 .4989 m
.32195 .57241 L
s
0 0 0 r
2.5 Mabswid
.5173 .54746 Mdot
0 1 .67 r
.5 Mabswid
.61608 .63115 m
.5173 .54746 L
s
0 0 0 r
2.5 Mabswid
.43901 .49892 Mdot
1 .098 0 r
.5 Mabswid
.3988 .50025 m
.43901 .49892 L
s
0 1 .749 r
.5523 .49543 m
.43988 .52632 L
s
0 0 0 r
2.5 Mabswid
.5523 .49543 Mdot
.746 1 0 r
.5 Mabswid
.40197 .58672 m
.5523 .49543 L
s
1 .116 0 r
.43822 .49892 m
.55513 .52235 L
s
0 0 0 r
2.5 Mabswid
.43822 .49892 Mdot
1 .116 0 r
.5 Mabswid
.44001 .50027 m
.43822 .49892 L
s
.89 1 0 r
.45216 .53622 m
.39601 .50352 L
s
0 0 0 r
2.5 Mabswid
.45216 .53622 Mdot
1 .116 0 r
.5 Mabswid
.53888 .46279 m
.59914 .43997 L
s
0 0 0 r
2.5 Mabswid
.53888 .46279 Mdot
.52833 .54611 Mdot
0 1 .832 r
.5 Mabswid
.62449 .6272 m
.52833 .54611 L
s
0 1 .394 r
.49848 .44177 m
.5492 .53632 L
s
0 0 0 r
2.5 Mabswid
.49848 .44177 Mdot
0 1 .394 r
.5 Mabswid
.36295 .37827 m
.49848 .44177 L
s
0 0 0 r
2.5 Mabswid
.74393 .57192 Mdot
0 .407 1 r
.5 Mabswid
.62816 .55153 m
.74393 .57192 L
s
1 .115 0 r
.55508 .49897 m
.42155 .52649 L
s
0 0 0 r
2.5 Mabswid
.55508 .49897 Mdot
1 .115 0 r
.5 Mabswid
.56318 .50027 m
.55508 .49897 L
s
0 0 0 r
2.5 Mabswid
.24303 .46946 Mdot
.16 0 1 r
.5 Mabswid
.35221 .50526 m
.24303 .46946 L
s
.06 1 0 r
.43689 .49734 m
.46656 .36471 L
s
0 0 0 r
2.5 Mabswid
.43689 .49734 Mdot
.06 1 0 r
.5 Mabswid
.4892 .56328 m
.43689 .49734 L
s
1 .094 0 r
.44268 .51844 m
.41846 .48439 L
s
0 0 0 r
2.5 Mabswid
.44268 .51844 Mdot
1 .094 0 r
.5 Mabswid
.56585 .49903 m
.44268 .51844 L
s
0 0 0 r
2.5 Mabswid
.5565 .49898 Mdot
1 .094 0 r
.5 Mabswid
.60418 .50025 m
.5565 .49898 L
s
.435 1 0 r
.52586 .45016 m
.60676 .58221 L
s
0 0 0 r
2.5 Mabswid
.52586 .45016 Mdot
.435 1 0 r
.5 Mabswid
.34708 .45151 m
.52586 .45016 L
s
1 .097 0 r
.54988 .52046 m
.58434 .48582 L
s
0 0 0 r
2.5 Mabswid
.54988 .52046 Mdot
1 .097 0 r
.5 Mabswid
.41232 .49908 m
.54988 .52046 L
s
0 0 0 r
2.5 Mabswid
.44059 .51887 Mdot
0 1 .766 r
.5 Mabswid
.61342 .46436 m
.44059 .51887 L
s
1 .728 0 r
.46052 .45091 m
.42528 .65802 L
s
0 0 0 r
2.5 Mabswid
.46052 .45091 Mdot
1 .728 0 r
.5 Mabswid
.59783 .49464 m
.46052 .45091 L
s
1 .116 0 r
.44633 .53662 m
.39674 .5636 L
s
0 0 0 r
2.5 Mabswid
.44633 .53662 Mdot
0 1 .063 r
.5 Mabswid
.43781 .4831 m
.40847 .41263 L
s
0 0 0 r
2.5 Mabswid
.43781 .4831 Mdot
1 .116 0 r
.5 Mabswid
.43178 .49896 m
.56382 .52547 L
s
0 0 0 r
2.5 Mabswid
.43178 .49896 Mdot
1 .116 0 r
.5 Mabswid
.43315 .50027 m
.43178 .49896 L
s
0 0 0 r
2.5 Mabswid
.4892 .56328 Mdot
.06 1 0 r
.5 Mabswid
.62876 .62377 m
.4892 .56328 L
s
1 .115 0 r
.56183 .49901 m
.41299 .52976 L
s
0 0 0 r
2.5 Mabswid
.56183 .49901 Mdot
1 .115 0 r
.5 Mabswid
.57002 .50027 m
.56183 .49901 L
s
0 .538 1 r
.45347 .45053 m
.38043 .63806 L
s
0 0 0 r
2.5 Mabswid
.45347 .45053 Mdot
0 .538 1 r
.5 Mabswid
.62599 .48461 m
.45347 .45053 L
s
0 0 0 r
2.5 Mabswid
.43018 .49897 Mdot
1 .097 0 r
.5 Mabswid
.39188 .50023 m
.43018 .49897 L
s
0 0 0 r
2.5 Mabswid
.46999 .44263 Mdot
0 .932 1 r
.5 Mabswid
.40847 .41263 m
.46999 .44263 L
s
.699 1 0 r
.53035 .44508 m
.61921 .58927 L
s
0 0 0 r
2.5 Mabswid
.53035 .44508 Mdot
.699 1 0 r
.5 Mabswid
.3543 .44623 m
.53035 .44508 L
s
1 .116 0 r
.55513 .52235 m
.61855 .51063 L
s
0 0 0 r
2.5 Mabswid
.55513 .52235 Mdot
0 1 .394 r
.5 Mabswid
.5492 .53632 m
.547 .65488 L
s
0 0 0 r
2.5 Mabswid
.5492 .53632 Mdot
1 .116 0 r
.5 Mabswid
.54631 .45707 m
.61054 .45896 L
s
0 0 0 r
2.5 Mabswid
.54631 .45707 Mdot
1 .093 0 r
.5 Mabswid
.43564 .52112 m
.41147 .48874 L
s
0 0 0 r
2.5 Mabswid
.43564 .52112 Mdot
1 .093 0 r
.5 Mabswid
.57526 .49909 m
.43564 .52112 L
s
1 .096 0 r
.55718 .52308 m
.59118 .49013 L
s
0 0 0 r
2.5 Mabswid
.55718 .52308 Mdot
1 .096 0 r
.5 Mabswid
.40329 .49914 m
.55718 .52308 L
s
0 0 0 r
2.5 Mabswid
.7453 .63724 Mdot
.364 1 0 r
.5 Mabswid
.59726 .64322 m
.7453 .63724 L
s
0 0 0 r
2.5 Mabswid
.56585 .49903 Mdot
1 .094 0 r
.5 Mabswid
.61097 .50022 m
.56585 .49903 L
s
0 .542 1 r
.4877 .43129 m
.43612 .46896 L
s
0 0 0 r
2.5 Mabswid
.4877 .43129 Mdot
0 .542 1 r
.5 Mabswid
.54981 .41486 m
.4877 .43129 L
s
.43612 .46896 m
.35643 .6237 L
s
0 0 0 r
2.5 Mabswid
.43612 .46896 Mdot
1 .116 0 r
.5 Mabswid
.42531 .499 m
.57262 .52863 L
s
0 0 0 r
2.5 Mabswid
.42531 .499 Mdot
1 .116 0 r
.5 Mabswid
.42629 .50027 m
.42531 .499 L
s
1 .115 0 r
.5686 .49905 m
.40431 .53306 L
s
0 0 0 r
2.5 Mabswid
.5686 .49905 Mdot
1 .115 0 r
.5 Mabswid
.57686 .50027 m
.5686 .49905 L
s
0 1 .592 r
.56693 .48872 m
.46082 .48098 L
s
0 0 0 r
2.5 Mabswid
.56693 .48872 Mdot
.406 1 0 r
.5 Mabswid
.39674 .5636 m
.56693 .48872 L
s
1 .115 0 r
.43944 .54253 m
.38588 .54545 L
s
0 0 0 r
2.5 Mabswid
.43944 .54253 Mdot
.803 1 0 r
.5 Mabswid
.50003 .42757 m
.60842 .5707 L
s
0 0 0 r
2.5 Mabswid
.50003 .42757 Mdot
.803 1 0 r
.5 Mabswid
.35154 .53534 m
.50003 .42757 L
s
0 0 0 r
2.5 Mabswid
.56523 .48142 Mdot
0 .042 1 r
.5 Mabswid
.37287 .56361 m
.56523 .48142 L
s
1 .886 0 r
.45595 .44115 m
.36329 .59397 L
s
0 0 0 r
2.5 Mabswid
.45595 .44115 Mdot
1 .886 0 r
.5 Mabswid
.64043 .44338 m
.45595 .44115 L
s
1 .115 0 r
.43001 .52327 m
.37638 .51375 L
s
0 0 0 r
2.5 Mabswid
.43001 .52327 Mdot
1 .116 0 r
.5 Mabswid
.56382 .52547 m
.62387 .51491 L
s
0 0 0 r
2.5 Mabswid
.56382 .52547 Mdot
.2 0 1 r
.5 Mabswid
.46209 .56248 m
.56855 .61158 L
s
0 0 0 r
2.5 Mabswid
.46209 .56248 Mdot
.2 0 1 r
.5 Mabswid
.42313 .52021 m
.46209 .56248 L
s
0 0 0 r
2.5 Mabswid
.47266 .4316 Mdot
0 .702 1 r
.5 Mabswid
.57492 .58351 m
.47266 .4316 L
s
1 .096 0 r
.56456 .52573 m
.59783 .49464 L
s
0 0 0 r
2.5 Mabswid
.56456 .52573 Mdot
1 .096 0 r
.5 Mabswid
.39419 .4992 m
.56456 .52573 L
s
0 0 0 r
2.5 Mabswid
.42128 .49903 Mdot
1 .097 0 r
.5 Mabswid
.38496 .50021 m
.42128 .49903 L
s
1 .093 0 r
.42852 .52384 m
.40446 .4931 L
s
0 0 0 r
2.5 Mabswid
.42852 .52384 Mdot
1 .093 0 r
.5 Mabswid
.58474 .49915 m
.42852 .52384 L
s
0 0 0 r
2.5 Mabswid
.42586 .51701 Mdot
0 .595 1 r
.5 Mabswid
.62498 .43685 m
.42586 .51701 L
s
0 0 0 r
2.5 Mabswid
.52188 .43137 Mdot
0 .272 1 r
.5 Mabswid
.53199 .33319 m
.52188 .43137 L
s
0 1 .595 r
.54539 .44177 m
.54856 .57249 L
s
0 0 0 r
2.5 Mabswid
.54539 .44177 Mdot
.282 1 0 r
.5 Mabswid
.38588 .54545 m
.54539 .44177 L
s
0 0 0 r
2.5 Mabswid
.28769 .75123 Mdot
0 .175 1 r
.5 Mabswid
.38795 .63359 m
.28769 .75123 L
s
0 1 .049 r
.5476 .55719 m
.66716 .761 L
s
0 1 .124 r
.5476 .55719 m
.5201 .51538 L
s
0 0 0 r
2.5 Mabswid
.5476 .55719 Mdot
.514 1 0 r
.5 Mabswid
.424 .35195 m
.5476 .55719 L
s
0 1 .699 r
.5711 .48415 m
.49365 .52122 L
s
0 0 0 r
2.5 Mabswid
.5711 .48415 Mdot
.4 1 0 r
.5 Mabswid
.40113 .55883 m
.5711 .48415 L
s
0 0 0 r
2.5 Mabswid
.57526 .49909 Mdot
1 .093 0 r
.5 Mabswid
.61777 .5002 m
.57526 .49909 L
s
1 .115 0 r
.5754 .49909 m
.39552 .53641 L
s
0 0 0 r
2.5 Mabswid
.5754 .49909 Mdot
1 .115 0 r
.5 Mabswid
.58371 .50027 m
.5754 .49909 L
s
.806 1 0 r
.50487 .42335 m
.61087 .56205 L
s
0 0 0 r
2.5 Mabswid
.50487 .42335 Mdot
.806 1 0 r
.5 Mabswid
.35643 .53106 m
.50487 .42335 L
s
1 .116 0 r
.41881 .49904 m
.58152 .53182 L
s
0 0 0 r
2.5 Mabswid
.41881 .49904 Mdot
1 .116 0 r
.5 Mabswid
.41943 .50027 m
.41881 .49904 L
s
1 .886 0 r
.48278 .42358 m
.38505 .55957 L
s
0 0 0 r
2.5 Mabswid
.48278 .42358 Mdot
1 .886 0 r
.5 Mabswid
.64213 .5323 m
.48278 .42358 L
s
0 0 0 r
2.5 Mabswid
.57255 .48209 Mdot
0 .046 1 r
.5 Mabswid
.3807 .56418 m
.57255 .48209 L
s
0 .989 1 r
.53416 .56723 m
.60867 .49007 L
s
0 0 0 r
2.5 Mabswid
.53416 .56723 Mdot
0 .989 1 r
.5 Mabswid
.34327 .60456 m
.53416 .56723 L
s
0 0 0 r
2.5 Mabswid
.42313 .52021 Mdot
.2 0 1 r
.5 Mabswid
.40317 .48294 m
.42313 .52021 L
s
.045 1 0 r
.56303 .5433 m
.32994 .58138 L
s
0 0 0 r
2.5 Mabswid
.56303 .5433 Mdot
.045 1 0 r
.5 Mabswid
.57081 .4464 m
.56303 .5433 L
s
0 .739 1 r
.43797 .44572 m
.44422 .33601 L
s
0 0 0 r
2.5 Mabswid
.43797 .44572 Mdot
.388 1 0 r
.5 Mabswid
.55901 .55113 m
.64478 .42274 L
s
0 0 0 r
2.5 Mabswid
.55901 .55113 Mdot
.388 1 0 r
.5 Mabswid
.49652 .58957 m
.55901 .55113 L
s
.81 1 0 r
.50973 .4191 m
.61333 .55342 L
s
0 0 0 r
2.5 Mabswid
.50973 .4191 Mdot
.81 1 0 r
.5 Mabswid
.36134 .52676 m
.50973 .4191 L
s
1 .116 0 r
.57262 .52863 m
.62848 .5193 L
s
0 0 0 r
2.5 Mabswid
.57262 .52863 Mdot
0 .327 1 r
.5 Mabswid
.57584 .52181 m
.56773 .59919 L
s
0 0 0 r
2.5 Mabswid
.57584 .52181 Mdot
0 .327 1 r
.5 Mabswid
.47646 .40303 m
.57584 .52181 L
s
1 .115 0 r
.42155 .52649 m
.37124 .51809 L
s
0 0 0 r
2.5 Mabswid
.42155 .52649 Mdot
1 .092 0 r
.5 Mabswid
.42131 .52659 m
.3978 .49793 L
s
0 0 0 r
2.5 Mabswid
.42131 .52659 Mdot
1 .092 0 r
.5 Mabswid
.5943 .49921 m
.42131 .52659 L
s
0 1 .871 r
.41653 .51451 m
.50291 .48199 L
s
0 0 0 r
2.5 Mabswid
.41653 .51451 Mdot
.303 1 0 r
.5 Mabswid
.59914 .43997 m
.41653 .51451 L
s
1 .115 0 r
.58222 .49913 m
.38662 .5398 L
s
0 0 0 r
2.5 Mabswid
.58222 .49913 Mdot
1 .115 0 r
.5 Mabswid
.59055 .50027 m
.58222 .49913 L
s
.857 1 0 r
.47828 .41931 m
.43611 .53932 L
s
0 0 0 r
2.5 Mabswid
.47828 .41931 Mdot
.857 1 0 r
.5 Mabswid
.63761 .52799 m
.47828 .41931 L
s
0 .149 1 r
.44254 .43726 m
.42023 .58832 L
s
0 0 0 r
2.5 Mabswid
.44254 .43726 Mdot
0 .149 1 r
.5 Mabswid
.63269 .50191 m
.44254 .43726 L
s
0 .538 1 r
.45919 .42746 m
.39628 .47378 L
s
0 0 0 r
2.5 Mabswid
.45919 .42746 Mdot
0 .538 1 r
.5 Mabswid
.5614 .40611 m
.45919 .42746 L
s
0 0 0 r
2.5 Mabswid
.41232 .49908 Mdot
1 .097 0 r
.5 Mabswid
.37803 .50018 m
.41232 .49908 L
s
1 .116 0 r
.41229 .49908 m
.59052 .53505 L
s
0 0 0 r
2.5 Mabswid
.41229 .49908 Mdot
1 .116 0 r
.5 Mabswid
.41257 .50027 m
.41229 .49908 L
s
0 .884 1 r
.42887 .45144 m
.49737 .37029 L
s
0 0 0 r
2.5 Mabswid
.42887 .45144 Mdot
0 .884 1 r
.5 Mabswid
.49119 .6119 m
.42887 .45144 L
s
0 1 .145 r
.44082 .56243 m
.4478 .4428 L
s
0 0 0 r
2.5 Mabswid
.44082 .56243 Mdot
1 .99 0 r
.5 Mabswid
.61054 .45896 m
.44082 .56243 L
s
0 0 0 r
2.5 Mabswid
.58474 .49915 Mdot
1 .093 0 r
.5 Mabswid
.62457 .50018 m
.58474 .49915 L
s
0 .449 1 r
.58003 .47511 m
.40528 .54938 L
s
0 0 0 r
2.5 Mabswid
.58003 .47511 Mdot
0 .449 1 r
.5 Mabswid
.60419 .46774 m
.58003 .47511 L
s
.814 1 0 r
.51449 .41493 m
.56363 .53217 L
s
0 0 0 r
2.5 Mabswid
.51449 .41493 Mdot
.814 1 0 r
.5 Mabswid
.36627 .52243 m
.51449 .41493 L
s
.142 1 0 r
.46178 .57875 m
.39561 .6193 L
s
0 0 0 r
2.5 Mabswid
.46178 .57875 Mdot
.49652 .58957 Mdot
.388 1 0 r
.5 Mabswid
.48836 .5924 m
.49652 .58957 L
s
.866 1 0 r
.47391 .41513 m
.43254 .53078 L
s
0 0 0 r
2.5 Mabswid
.47391 .41513 Mdot
.866 1 0 r
.5 Mabswid
.63306 .52366 m
.47391 .41513 L
s
0 .13 1 r
.57255 .45213 m
.40341 .52518 L
s
0 0 0 r
2.5 Mabswid
.57255 .45213 Mdot
0 1 .871 r
.5 Mabswid
.50291 .48199 m
.57255 .45213 L
s
0 1 .532 r
.51164 .41157 m
.45221 .67193 L
s
0 0 0 r
2.5 Mabswid
.51164 .41157 Mdot
0 1 .532 r
.5 Mabswid
.51661 .4455 m
.51164 .41157 L
s
0 .038 1 r
.54913 .42595 m
.56705 .58087 L
s
0 0 0 r
2.5 Mabswid
.54913 .42595 Mdot
0 .038 1 r
.5 Mabswid
.46656 .36471 m
.54913 .42595 L
s
.81 1 0 r
.5237 .58502 m
.37242 .48619 L
s
0 0 0 r
2.5 Mabswid
.5237 .58502 Mdot
.81 1 0 r
.5 Mabswid
.61333 .55342 m
.5237 .58502 L
s
1 .116 0 r
.58152 .53182 m
.63306 .52366 L
s
0 0 0 r
2.5 Mabswid
.58152 .53182 Mdot
1 .092 0 r
.5 Mabswid
.414 .52937 m
.39118 .50281 L
s
0 0 0 r
2.5 Mabswid
.414 .52937 Mdot
1 .092 0 r
.5 Mabswid
.60392 .49927 m
.414 .52937 L
s
0 .989 1 r
.41825 .45981 m
.3953 .54951 L
s
0 0 0 r
2.5 Mabswid
.41825 .45981 Mdot
0 .989 1 r
.5 Mabswid
.45167 .411 m
.41825 .45981 L
s
0 0 0 r
2.5 Mabswid
.50866 .24512 Mdot
0 .305 1 r
.5 Mabswid
.62817 .36716 m
.50866 .24512 L
s
1 .116 0 r
.40574 .49912 m
.59963 .53832 L
s
0 0 0 r
2.5 Mabswid
.40574 .49912 Mdot
1 .116 0 r
.5 Mabswid
.4057 .50027 m
.40574 .49912 L
s
1 .115 0 r
.41299 .52976 m
.36627 .52243 L
s
0 0 0 r
2.5 Mabswid
.41299 .52976 Mdot
.801 1 0 r
.5 Mabswid
.57139 .4442 m
.32967 .57136 L
s
0 0 0 r
2.5 Mabswid
.57139 .4442 Mdot
.801 1 0 r
.5 Mabswid
.5639 .47295 m
.57139 .4442 L
s
.819 1 0 r
.51922 .41077 m
.56729 .52365 L
s
0 0 0 r
2.5 Mabswid
.51922 .41077 Mdot
.819 1 0 r
.5 Mabswid
.37124 .51809 m
.51922 .41077 L
s
0 0 0 r
2.5 Mabswid
.48836 .5924 Mdot
.388 1 0 r
.5 Mabswid
.43593 .60642 m
.48836 .5924 L
s
0 .938 1 r
.49357 .40611 m
.49932 .42595 L
s
0 0 0 r
2.5 Mabswid
.49357 .40611 Mdot
0 .938 1 r
.5 Mabswid
.55662 .66649 m
.49357 .40611 L
s
.699 1 0 r
.44025 .57223 m
.37393 .5019 L
s
0 0 0 r
2.5 Mabswid
.44025 .57223 Mdot
.699 1 0 r
.5 Mabswid
.54671 .61293 m
.44025 .57223 L
s
.8 1 0 r
.45488 .4186 m
.44395 .63592 L
s
0 0 0 r
2.5 Mabswid
.45488 .4186 Mdot
.8 1 0 r
.5 Mabswid
.52701 .39822 m
.45488 .4186 L
s
0 0 0 r
2.5 Mabswid
.40329 .49914 Mdot
1 .096 0 r
.5 Mabswid
.37111 .50016 m
.40329 .49914 L
s
0 .364 1 r
.58072 .45618 m
.57313 .63327 L
s
0 0 0 r
2.5 Mabswid
.58072 .45618 Mdot
0 .364 1 r
.5 Mabswid
.43628 .34362 m
.58072 .45618 L
s
0 .498 1 r
.58659 .4693 m
.39538 .55042 L
s
0 0 0 r
2.5 Mabswid
.58659 .4693 Mdot
0 .498 1 r
.5 Mabswid
.60909 .46227 m
.58659 .4693 L
s
0 0 0 r
2.5 Mabswid
.5943 .49921 Mdot
1 .092 0 r
.5 Mabswid
.63137 .50016 m
.5943 .49921 L
s
0 .542 1 r
.57246 .55793 m
.54697 .56202 L
s
0 0 0 r
2.5 Mabswid
.57246 .55793 Mdot
0 .542 1 r
.5 Mabswid
.36602 .37396 m
.57246 .55793 L
s
.874 1 0 r
.46951 .41092 m
.42899 .52225 L
s
0 0 0 r
2.5 Mabswid
.46951 .41092 Mdot
.874 1 0 r
.5 Mabswid
.62848 .5193 m
.46951 .41092 L
s
.797 1 0 r
.57775 .44874 m
.33604 .5767 L
s
0 0 0 r
2.5 Mabswid
.57775 .44874 Mdot
.797 1 0 r
.5 Mabswid
.5707 .47723 m
.57775 .44874 L
s
1 .886 0 r
.4622 .5871 m
.61806 .48372 L
s
0 0 0 r
2.5 Mabswid
.4622 .5871 Mdot
1 .886 0 r
.5 Mabswid
.38505 .55957 m
.4622 .5871 L
s
0 0 0 r
2.5 Mabswid
.4114 .46292 Mdot
0 .989 1 r
.5 Mabswid
.58096 .44301 m
.4114 .46292 L
s
.806 1 0 r
.52561 .59183 m
.36326 .48608 L
s
0 0 0 r
2.5 Mabswid
.52561 .59183 Mdot
.806 1 0 r
.5 Mabswid
.61087 .56205 m
.52561 .59183 L
s
0 0 0 r
2.5 Mabswid
.40317 .48294 Mdot
.2 0 1 r
.5 Mabswid
.36563 .36365 m
.40317 .48294 L
s
0 0 0 r
2.5 Mabswid
.42175 .56061 Mdot
0 1 .711 r
.5 Mabswid
.57955 .53347 m
.42175 .56061 L
s
.8 1 0 r
.59669 .50715 m
.52701 .39822 L
s
0 0 0 r
2.5 Mabswid
.59669 .50715 Mdot
.8 1 0 r
.5 Mabswid
.43322 .58694 m
.59669 .50715 L
s
.793 1 0 r
.58409 .45342 m
.32867 .51597 L
s
0 0 0 r
2.5 Mabswid
.58409 .45342 Mdot
.793 1 0 r
.5 Mabswid
.57751 .48152 m
.58409 .45342 L
s
0 .538 1 r
.55176 .58211 m
.63411 .46968 L
s
0 0 0 r
2.5 Mabswid
.55176 .58211 Mdot
0 .538 1 r
.5 Mabswid
.39004 .64874 m
.55176 .58211 L
s
0 1 .928 r
.40491 .52681 m
.59386 .44838 L
s
0 0 0 r
2.5 Mabswid
.40491 .52681 Mdot
0 1 .928 r
.5 Mabswid
.39278 .5348 m
.40491 .52681 L
s
0 .327 1 r
.54477 .41279 m
.55689 .58829 L
s
0 0 0 r
2.5 Mabswid
.54477 .41279 Mdot
0 .327 1 r
.5 Mabswid
.49737 .37029 m
.54477 .41279 L
s
0 1 .381 r
.49653 .40001 m
.40433 .42484 L
s
0 0 0 r
2.5 Mabswid
.49653 .40001 Mdot
0 1 .381 r
.5 Mabswid
.59898 .63207 m
.49653 .40001 L
s
1 .116 0 r
.59052 .53505 m
.63761 .52799 L
s
0 0 0 r
2.5 Mabswid
.59052 .53505 Mdot
0 .364 1 r
.5 Mabswid
.41343 .54989 m
.56844 .42044 L
s
0 0 0 r
2.5 Mabswid
.41343 .54989 Mdot
0 1 .699 r
.5 Mabswid
.49365 .52122 m
.41343 .54989 L
s
0 1 .632 r
.42915 .42802 m
.65553 .42547 L
s
0 0 0 r
2.5 Mabswid
.42915 .42802 Mdot
0 1 .632 r
.5 Mabswid
.33261 .54005 m
.42915 .42802 L
s
0 0 0 r
2.5 Mabswid
.54981 .41486 Mdot
0 .542 1 r
.5 Mabswid
.65397 .40373 m
.54981 .41486 L
s
0 0 0 r
2.5 Mabswid
.47646 .40303 Mdot
0 .327 1 r
.5 Mabswid
.4078 .38953 m
.47646 .40303 L
s
0 0 0 r
2.5 Mabswid
.4065 .53542 Mdot
0 .439 1 r
.5 Mabswid
.57985 .46986 m
.4065 .53542 L
s
.884 1 0 r
.46509 .40668 m
.42544 .51374 L
s
0 0 0 r
2.5 Mabswid
.46509 .40668 Mdot
.884 1 0 r
.5 Mabswid
.62387 .51491 m
.46509 .40668 L
s
.8 1 0 r
.41332 .44841 m
.65802 .57917 L
s
0 0 0 r
2.5 Mabswid
.41332 .44841 Mdot
.8 1 0 r
.5 Mabswid
.43238 .47573 m
.41332 .44841 L
s
0 0 0 r
2.5 Mabswid
.59685 .52056 Mdot
0 .601 1 r
.5 Mabswid
.50473 .47964 m
.59685 .52056 L
s
0 0 0 r
2.5 Mabswid
.33148 .75432 Mdot
0 1 .727 r
.5 Mabswid
.36642 .62964 m
.33148 .75432 L
s
.052 0 1 r
.59909 .51201 m
.46229 .50967 L
s
0 0 0 r
2.5 Mabswid
.59909 .51201 Mdot
0 .877 1 r
.5 Mabswid
.50739 .47084 m
.59909 .51201 L
s
0 0 0 r
2.5 Mabswid
.75013 .56366 Mdot
0 .313 1 r
.5 Mabswid
.558 .6087 m
.75013 .56366 L
s
1 .115 0 r
.40431 .53306 m
.36134 .52676 L
s
0 0 0 r
2.5 Mabswid
.40431 .53306 Mdot
0 .692 1 r
.5 Mabswid
.58086 .441 m
.48477 .47971 L
s
0 0 0 r
2.5 Mabswid
.58086 .441 Mdot
0 1 .495 r
.5 Mabswid
.48553 .5425 m
.58086 .441 L
s
.789 1 0 r
.59045 .45816 m
.33437 .52153 L
s
0 0 0 r
2.5 Mabswid
.59045 .45816 Mdot
.789 1 0 r
.5 Mabswid
.58434 .48582 m
.59045 .45816 L
s
0 .111 1 r
.59317 .46348 m
.38537 .55148 L
s
0 0 0 r
2.5 Mabswid
.59317 .46348 Mdot
0 .111 1 r
.5 Mabswid
.61397 .45682 m
.59317 .46348 L
s
0 0 0 r
2.5 Mabswid
.45167 .411 Mdot
0 .989 1 r
.5 Mabswid
.55734 .32216 m
.45167 .411 L
s
0 .038 1 r
.40124 .52814 m
.43774 .35172 L
s
0 0 0 r
2.5 Mabswid
.40124 .52814 Mdot
0 .038 1 r
.5 Mabswid
.53959 .6369 m
.40124 .52814 L
s
0 0 0 r
2.5 Mabswid
.60392 .49927 Mdot
1 .092 0 r
.5 Mabswid
.63818 .50014 m
.60392 .49927 L
s
0 .538 1 r
.57935 .56468 m
.62599 .48461 L
s
0 0 0 r
2.5 Mabswid
.57935 .56468 Mdot
0 .538 1 r
.5 Mabswid
.36219 .57826 m
.57935 .56468 L
s
0 .685 1 r
.57766 .43339 m
.4822 .47089 L
s
0 0 0 r
2.5 Mabswid
.57766 .43339 Mdot
0 1 .253 r
.5 Mabswid
.48312 .53361 m
.57766 .43339 L
s
.803 1 0 r
.52752 .59868 m
.35398 .48597 L
s
0 0 0 r
2.5 Mabswid
.52752 .59868 Mdot
.803 1 0 r
.5 Mabswid
.60842 .5707 m
.52752 .59868 L
s
0 0 0 r
2.5 Mabswid
.39419 .4992 Mdot
1 .096 0 r
.5 Mabswid
.36418 .50014 m
.39419 .4992 L
s
.746 1 0 r
.40709 .45308 m
.66582 .51997 L
s
0 0 0 r
2.5 Mabswid
.40709 .45308 Mdot
.746 1 0 r
.5 Mabswid
.42543 .48005 m
.40709 .45308 L
s
0 0 0 r
2.5 Mabswid
.43895 .41494 Mdot
0 .298 1 r
.5 Mabswid
.50173 .55347 m
.43895 .41494 L
s
.045 1 0 r
.53265 .4017 m
.56236 .41282 L
s
0 0 0 r
2.5 Mabswid
.53265 .4017 Mdot
.045 1 0 r
.5 Mabswid
.512 .39593 m
.53265 .4017 L
s
0 .038 1 r
.56705 .58087 m
.53959 .6369 L
s
0 0 0 r
2.5 Mabswid
.56705 .58087 Mdot
0 .695 1 r
.5 Mabswid
.57445 .42575 m
.47964 .46206 L
s
0 0 0 r
2.5 Mabswid
.57445 .42575 Mdot
0 1 .243 r
.5 Mabswid
.4807 .52472 m
.57445 .42575 L
s
.778 1 0 r
.59684 .46292 m
.34011 .52713 L
s
0 0 0 r
2.5 Mabswid
.59684 .46292 Mdot
.778 1 0 r
.5 Mabswid
.59118 .49013 m
.59684 .46292 L
s
0 1 .542 r
.59482 .45795 m
.37685 .5511 L
s
0 0 0 r
2.5 Mabswid
.59482 .45795 Mdot
.385 1 0 r
.5 Mabswid
.5684 .47137 m
.59482 .45795 L
s
.045 1 0 r
.60213 .4795 m
.58231 .62567 L
s
0 0 0 r
2.5 Mabswid
.60213 .4795 Mdot
.045 1 0 r
.5 Mabswid
.53534 .31789 m
.60213 .4795 L
s
0 0 0 r
2.5 Mabswid
.512 .39593 Mdot
.045 1 0 r
.5 Mabswid
.48977 .3915 m
.512 .39593 L
s
0 .327 1 r
.55689 .58829 m
.52033 .64331 L
s
0 0 0 r
2.5 Mabswid
.55689 .58829 Mdot
0 .449 1 r
.5 Mabswid
.40528 .54938 m
.3807 .56418 L
s
0 0 0 r
2.5 Mabswid
.40528 .54938 Mdot
0 1 .754 r
.5 Mabswid
.39883 .53267 m
.60452 .44745 L
s
0 0 0 r
2.5 Mabswid
.39883 .53267 Mdot
0 1 .754 r
.5 Mabswid
.38745 .54025 m
.39883 .53267 L
s
0 .538 1 r
.39628 .47378 m
.33488 .56649 L
s
0 0 0 r
2.5 Mabswid
.39628 .47378 Mdot
.741 1 0 r
.5 Mabswid
.52856 .60297 m
.57832 .56073 L
s
0 0 0 r
2.5 Mabswid
.52856 .60297 Mdot
.741 1 0 r
.5 Mabswid
.34637 .43234 m
.52856 .60297 L
s
0 .989 1 r
.42721 .42003 m
.32528 .49941 L
s
0 0 0 r
2.5 Mabswid
.42721 .42003 Mdot
0 .989 1 r
.5 Mabswid
.5567 .39463 m
.42721 .42003 L
s
1 .116 0 r
.59963 .53832 m
.64213 .5323 L
s
0 0 0 r
2.5 Mabswid
.59963 .53832 Mdot
0 1 .928 r
.5 Mabswid
.59386 .44838 m
.62498 .43685 L
s
0 0 0 r
2.5 Mabswid
.59386 .44838 Mdot
.045 1 0 r
.5 Mabswid
.56236 .41282 m
.57993 .42094 L
s
0 0 0 r
2.5 Mabswid
.56236 .41282 Mdot
.741 1 0 r
.5 Mabswid
.40086 .45782 m
.66043 .52553 L
s
0 0 0 r
2.5 Mabswid
.40086 .45782 Mdot
.741 1 0 r
.5 Mabswid
.41846 .48439 m
.40086 .45782 L
s
0 1 .632 r
.55409 .59329 m
.37876 .57307 L
s
0 0 0 r
2.5 Mabswid
.55409 .59329 Mdot
0 1 .632 r
.5 Mabswid
.6496 .52738 m
.55409 .59329 L
s
.741 1 0 r
.5379 .39958 m
.43309 .45248 L
s
0 0 0 r
2.5 Mabswid
.5379 .39958 Mdot
.741 1 0 r
.5 Mabswid
.57832 .56073 m
.5379 .39958 L
s
0 0 0 r
2.5 Mabswid
.48977 .3915 Mdot
.045 1 0 r
.5 Mabswid
.36759 .39824 m
.48977 .3915 L
s
0 .989 1 r
.60867 .49007 m
.64237 .4189 L
s
0 0 0 r
2.5 Mabswid
.60867 .49007 Mdot
0 1 .632 r
.5 Mabswid
.58607 .56739 m
.52694 .63844 L
s
0 0 0 r
2.5 Mabswid
.58607 .56739 Mdot
0 1 .632 r
.5 Mabswid
.62418 .46426 m
.58607 .56739 L
s
0 0 0 r
2.5 Mabswid
.5475 .59922 Mdot
0 .711 1 r
.5 Mabswid
.49843 .46988 m
.5475 .59922 L
s
0 1 .653 r
.5993 .45322 m
.38214 .54569 L
s
0 0 0 r
2.5 Mabswid
.5993 .45322 Mdot
.378 1 0 r
.5 Mabswid
.57403 .46595 m
.5993 .45322 L
s
1 .115 0 r
.39552 .53641 m
.35643 .53106 L
s
0 0 0 r
2.5 Mabswid
.39552 .53641 Mdot
.49119 .6119 Mdot
0 .884 1 r
.5 Mabswid
.547 .65488 m
.49119 .6119 L
s
0 .989 1 r
.44373 .59617 m
.66781 .48934 L
s
0 0 0 r
2.5 Mabswid
.44373 .59617 Mdot
0 .989 1 r
.5 Mabswid
.37014 .53524 m
.44373 .59617 L
s
.045 1 0 r
.57993 .42094 m
.684 .49939 L
s
0 0 0 r
2.5 Mabswid
.57993 .42094 Mdot
.737 1 0 r
.5 Mabswid
.3946 .46259 m
.655 .53111 L
s
0 0 0 r
2.5 Mabswid
.3946 .46259 Mdot
.737 1 0 r
.5 Mabswid
.41147 .48874 m
.3946 .46259 L
s
0 .989 1 r
.61307 .49501 m
.58096 .44301 L
s
0 0 0 r
2.5 Mabswid
.61307 .49501 Mdot
0 .989 1 r
.5 Mabswid
.41987 .64702 m
.61307 .49501 L
s
0 0 0 r
2.5 Mabswid
.5614 .40611 Mdot
0 .538 1 r
.5 Mabswid
.65309 .41449 m
.5614 .40611 L
s
0 .601 1 r
.40411 .44026 m
.50473 .47964 L
s
0 0 0 r
2.5 Mabswid
.40411 .44026 Mdot
0 1 .326 r
.5 Mabswid
.50898 .53769 m
.40411 .44026 L
s
0 .702 1 r
.558 .59704 m
.57492 .58351 L
s
0 0 0 r
2.5 Mabswid
.558 .59704 Mdot
0 .702 1 r
.5 Mabswid
.35629 .37571 m
.558 .59704 L
s
0 1 .632 r
.38841 .47801 m
.41482 .34882 L
s
0 0 0 r
2.5 Mabswid
.38841 .47801 Mdot
0 1 .632 r
.5 Mabswid
.40606 .57139 m
.38841 .47801 L
s
0 1 .653 r
.39273 .53856 m
.6153 .44651 L
s
0 0 0 r
2.5 Mabswid
.39273 .53856 Mdot
0 1 .653 r
.5 Mabswid
.38214 .54569 m
.39273 .53856 L
s
0 .877 1 r
.40747 .43262 m
.50739 .47084 L
s
0 0 0 r
2.5 Mabswid
.40747 .43262 Mdot
0 1 .247 r
.5 Mabswid
.51144 .52885 m
.40747 .43262 L
s
.045 1 0 r
.42649 .58819 m
.39199 .54625 L
s
0 0 0 r
2.5 Mabswid
.42649 .58819 Mdot
.045 1 0 r
.5 Mabswid
.51099 .64749 m
.42649 .58819 L
s
0 1 .381 r
.38727 .52486 m
.60331 .63879 L
s
0 0 0 r
2.5 Mabswid
.38727 .52486 Mdot
0 1 .381 r
.5 Mabswid
.40433 .42484 m
.38727 .52486 L
s
0 .989 1 r
.3953 .54951 m
.39553 .65551 L
s
0 0 0 r
2.5 Mabswid
.3953 .54951 Mdot
0 1 .754 r
.5 Mabswid
.6038 .44847 m
.38745 .54025 L
s
0 0 0 r
2.5 Mabswid
.6038 .44847 Mdot
.37 1 0 r
.5 Mabswid
.57966 .46053 m
.6038 .44847 L
s
0 .498 1 r
.39538 .55042 m
.37287 .56361 L
s
0 0 0 r
2.5 Mabswid
.39538 .55042 Mdot
.732 1 0 r
.5 Mabswid
.3883 .46738 m
.64825 .53638 L
s
0 0 0 r
2.5 Mabswid
.3883 .46738 Mdot
.732 1 0 r
.5 Mabswid
.40446 .4931 m
.3883 .46738 L
s
0 1 .532 r
.44574 .39763 m
.36294 .57196 L
s
0 0 0 r
2.5 Mabswid
.44574 .39763 Mdot
0 1 .532 r
.5 Mabswid
.58196 .40496 m
.44574 .39763 L
s
0 0 0 r
2.5 Mabswid
.38514 .51759 Mdot
0 .692 1 r
.5 Mabswid
.48477 .47971 m
.38514 .51759 L
s
0 .364 1 r
.58096 .41363 m
.45331 .66283 L
s
0 0 0 r
2.5 Mabswid
.58096 .41363 Mdot
0 .364 1 r
.5 Mabswid
.56844 .42044 m
.58096 .41363 L
s
.778 1 0 r
.61625 .51288 m
.54035 .63009 L
s
0 0 0 r
2.5 Mabswid
.61625 .51288 Mdot
.778 1 0 r
.5 Mabswid
.54661 .34536 m
.61625 .51288 L
s
0 1 .754 r
.60452 .44745 m
.63229 .43736 L
s
0 0 0 r
2.5 Mabswid
.60452 .44745 Mdot
.38296 .50899 Mdot
0 .685 1 r
.5 Mabswid
.4822 .47089 m
.38296 .50899 L
s
0 .542 1 r
.60553 .4487 m
.4483 .33002 L
s
0 0 0 r
2.5 Mabswid
.60553 .4487 Mdot
0 .542 1 r
.5 Mabswid
.6254 .58611 m
.60553 .4487 L
s
.778 1 0 r
.61685 .48536 m
.63128 .4893 L
s
0 0 0 r
2.5 Mabswid
.61685 .48536 Mdot
.778 1 0 r
.5 Mabswid
.35414 .52633 m
.61685 .48536 L
s
0 0 0 r
2.5 Mabswid
.38079 .5004 Mdot
0 .695 1 r
.5 Mabswid
.47964 .46206 m
.38079 .5004 L
s
.045 1 0 r
.39199 .54625 m
.35744 .47735 L
s
0 0 0 r
2.5 Mabswid
.39199 .54625 Mdot
.40606 .57139 Mdot
0 1 .632 r
.5 Mabswid
.44589 .64755 m
.40606 .57139 L
s
0 .111 1 r
.39115 .54497 m
.61397 .45682 L
s
0 0 0 r
2.5 Mabswid
.39115 .54497 Mdot
.298 1 0 r
.5 Mabswid
.42753 .53256 m
.39115 .54497 L
s
0 .149 1 r
.46443 .6131 m
.62902 .38627 L
s
0 0 0 r
2.5 Mabswid
.46443 .6131 Mdot
0 .149 1 r
.5 Mabswid
.42023 .58832 m
.46443 .6131 L
s
0 .364 1 r
.39396 .4474 m
.40729 .38462 L
s
0 0 0 r
2.5 Mabswid
.39396 .4474 Mdot
0 .364 1 r
.5 Mabswid
.52575 .62227 m
.39396 .4474 L
s
.746 1 0 r
.57901 .59049 m
.61814 .52992 L
s
0 0 0 r
2.5 Mabswid
.57901 .59049 Mdot
.746 1 0 r
.5 Mabswid
.35839 .48438 m
.57901 .59049 L
s
1 .992 0 r
.45025 .3928 m
.44526 .24132 L
s
.142 1 0 r
.45025 .3928 m
.49236 .4304 L
s
0 0 0 r
2.5 Mabswid
.45025 .3928 Mdot
1 .728 0 r
.5 Mabswid
.49928 .59782 m
.45025 .3928 L
s
0 1 .532 r
.61556 .47265 m
.58196 .40496 L
s
0 0 0 r
2.5 Mabswid
.61556 .47265 Mdot
0 1 .532 r
.5 Mabswid
.44708 .65408 m
.61556 .47265 L
s
0 .989 1 r
.58883 .58074 m
.54325 .35379 L
s
0 0 0 r
2.5 Mabswid
.58883 .58074 Mdot
0 .989 1 r
.5 Mabswid
.51405 .63975 m
.58883 .58074 L
s
1 .886 0 r
.61806 .48372 m
.64043 .44338 L
s
0 0 0 r
2.5 Mabswid
.61806 .48372 Mdot
.793 1 0 r
.5 Mabswid
.4087 .57788 m
.43014 .5468 L
s
0 0 0 r
2.5 Mabswid
.4087 .57788 Mdot
.793 1 0 r
.5 Mabswid
.6383 .47268 m
.4087 .57788 L
s
0 0 0 r
2.5 Mabswid
.5567 .39463 Mdot
0 .989 1 r
.5 Mabswid
.64237 .4189 m
.5567 .39463 L
s
.797 1 0 r
.3895 .54686 m
.67757 .46364 L
s
0 0 0 r
2.5 Mabswid
.3895 .54686 Mdot
.797 1 0 r
.5 Mabswid
.38741 .53698 m
.3895 .54686 L
s
1 .115 0 r
.38662 .5398 m
.35154 .53534 L
s
0 0 0 r
2.5 Mabswid
.38662 .5398 Mdot
.371 1 0 r
.5 Mabswid
.59452 .57527 m
.61608 .63115 L
s
0 0 0 r
2.5 Mabswid
.59452 .57527 Mdot
0 .829 1 r
.5 Mabswid
.37821 .49502 m
.3991 .55159 L
s
0 0 0 r
2.5 Mabswid
.37821 .49502 Mdot
0 .829 1 r
.5 Mabswid
.63876 .44366 m
.37821 .49502 L
s
0 1 .532 r
.39519 .56026 m
.49476 .67973 L
s
0 0 0 r
2.5 Mabswid
.39519 .56026 Mdot
0 1 .532 r
.5 Mabswid
.36639 .46032 m
.39519 .56026 L
s
0 1 .928 r
.60832 .4437 m
.39278 .5348 L
s
0 0 0 r
2.5 Mabswid
.60832 .4437 Mdot
.364 1 0 r
.5 Mabswid
.58529 .4551 m
.60832 .4437 L
s
0 0 0 r
2.5 Mabswid
.54671 .61293 Mdot
.699 1 0 r
.5 Mabswid
.63227 .62172 m
.54671 .61293 L
s
0 0 0 r
2.5 Mabswid
.23768 .39242 Mdot
0 1 .96 r
.5 Mabswid
.35629 .37571 m
.23768 .39242 L
s
0 0 0 r
2.5 Mabswid
.41469 .75686 Mdot
0 1 .347 r
.5 Mabswid
.52542 .65689 m
.41469 .75686 L
s
.045 1 0 r
.5874 .41271 m
.55881 .5555 L
s
0 0 0 r
2.5 Mabswid
.5874 .41271 Mdot
.045 1 0 r
.5 Mabswid
.46327 .38814 m
.5874 .41271 L
s
0 1 .542 r
.38661 .54447 m
.6262 .44556 L
s
0 0 0 r
2.5 Mabswid
.38661 .54447 Mdot
0 1 .542 r
.5 Mabswid
.37685 .5511 m
.38661 .54447 L
s
.801 1 0 r
.38445 .53901 m
.67689 .45387 L
s
0 0 0 r
2.5 Mabswid
.38445 .53901 Mdot
.801 1 0 r
.5 Mabswid
.38218 .529 m
.38445 .53901 L
s
1 .728 0 r
.51789 .62094 m
.49928 .59782 L
s
0 0 0 r
2.5 Mabswid
.51789 .62094 Mdot
1 .728 0 r
.5 Mabswid
.50998 .36498 m
.51789 .62094 L
s
.045 1 0 r
.38017 .52091 m
.46327 .38814 L
s
0 0 0 r
2.5 Mabswid
.38017 .52091 Mdot
.045 1 0 r
.5 Mabswid
.50665 .61524 m
.38017 .52091 L
s
0 0 0 r
2.5 Mabswid
.62462 .49776 Mdot
0 .005 1 r
.5 Mabswid
.49644 .52228 m
.62462 .49776 L
s
0 0 0 r
2.5 Mabswid
.558 .6087 Mdot
0 .348 1 r
.5 Mabswid
.42797 .54633 m
.558 .6087 L
s
0 1 .381 r
.39678 .43482 m
.58034 .62436 L
s
0 0 0 r
2.5 Mabswid
.39678 .43482 Mdot
0 1 .381 r
.5 Mabswid
.41001 .41161 m
.39678 .43482 L
s
0 .989 1 r
.57179 .60042 m
.60366 .55048 L
s
0 0 0 r
2.5 Mabswid
.57179 .60042 Mdot
0 .989 1 r
.5 Mabswid
.35999 .47467 m
.57179 .60042 L
s
.789 1 0 r
.62145 .47788 m
.6348 .48095 L
s
0 0 0 r
2.5 Mabswid
.62145 .47788 Mdot
.789 1 0 r
.5 Mabswid
.34644 .52097 m
.62145 .47788 L
s
0 .498 1 r
.38698 .54979 m
.60909 .46227 L
s
0 0 0 r
2.5 Mabswid
.38698 .54979 Mdot
.284 1 0 r
.5 Mabswid
.42185 .53802 m
.38698 .54979 L
s
0 .13 1 r
.3926 .56118 m
.63996 .46646 L
s
0 0 0 r
2.5 Mabswid
.3926 .56118 Mdot
0 .13 1 r
.5 Mabswid
.40341 .52518 m
.3926 .56118 L
s
0 0 0 r
2.5 Mabswid
.43593 .60642 Mdot
.388 1 0 r
.5 Mabswid
.35542 .61675 m
.43593 .60642 L
s
0 .327 1 r
.38484 .54563 m
.4078 .38953 L
s
0 0 0 r
2.5 Mabswid
.38484 .54563 Mdot
0 .327 1 r
.5 Mabswid
.52033 .64331 m
.38484 .54563 L
s
0 1 .381 r
.62127 .47139 m
.52686 .41031 L
s
0 0 0 r
2.5 Mabswid
.62127 .47139 Mdot
0 1 .381 r
.5 Mabswid
.5284 .58442 m
.62127 .47139 L
s
0 0 0 r
2.5 Mabswid
.52575 .62227 Mdot
0 .364 1 r
.5 Mabswid
.57313 .63327 m
.52575 .62227 L
s
0 .038 1 r
.46869 .62085 m
.34208 .52603 L
s
0 0 0 r
2.5 Mabswid
.46869 .62085 Mdot
0 .038 1 r
.5 Mabswid
.63324 .57763 m
.46869 .62085 L
s
.8 1 0 r
.39584 .56827 m
.43322 .58694 L
s
0 0 0 r
2.5 Mabswid
.39584 .56827 Mdot
.8 1 0 r
.5 Mabswid
.57658 .35971 m
.39584 .56827 L
s
.699 1 0 r
.37393 .5019 m
.36574 .48874 L
s
0 0 0 r
2.5 Mabswid
.37393 .5019 Mdot
0 .989 1 r
.5 Mabswid
.61396 .55598 m
.62521 .38584 L
s
0 0 0 r
2.5 Mabswid
.61396 .55598 Mdot
0 .989 1 r
.5 Mabswid
.51548 .67287 m
.61396 .55598 L
s
.741 1 0 r
.58076 .59785 m
.61677 .54282 L
s
0 0 0 r
2.5 Mabswid
.58076 .59785 Mdot
.741 1 0 r
.5 Mabswid
.36232 .4929 m
.58076 .59785 L
s
.789 1 0 r
.40635 .58557 m
.42662 .55654 L
s
0 0 0 r
2.5 Mabswid
.40635 .58557 Mdot
.789 1 0 r
.5 Mabswid
.6348 .48095 m
.40635 .58557 L
s
0 .111 1 r
.38537 .55148 m
.36509 .56304 L
s
0 0 0 r
2.5 Mabswid
.38537 .55148 Mdot
.44526 .24132 Mdot
0 1 .653 r
.5 Mabswid
.6153 .44651 m
.63955 .43786 L
s
0 0 0 r
2.5 Mabswid
.6153 .44651 Mdot
0 .38 1 r
.5 Mabswid
.60134 .42503 m
.38795 .63359 L
s
0 0 0 r
2.5 Mabswid
.60134 .42503 Mdot
0 1 .65 r
.5 Mabswid
.59844 .40798 m
.60134 .42503 L
s
.737 1 0 r
.37333 .49482 m
.36641 .50139 L
s
0 0 0 r
2.5 Mabswid
.37333 .49482 Mdot
.737 1 0 r
.5 Mabswid
.63603 .53117 m
.37333 .49482 L
s
0 .418 1 r
.37628 .47563 m
.51668 .5183 L
s
0 0 0 r
2.5 Mabswid
.37628 .47563 Mdot
0 1 .592 r
.5 Mabswid
.46082 .48098 m
.37628 .47563 L
s
.045 1 0 r
.58903 .59642 m
.50665 .61524 L
s
0 0 0 r
2.5 Mabswid
.58903 .59642 Mdot
.045 1 0 r
.5 Mabswid
.61433 .39454 m
.58903 .59642 L
s
0 0 0 r
2.5 Mabswid
.62418 .46426 Mdot
0 1 .632 r
.5 Mabswid
.63267 .37079 m
.62418 .46426 L
s
.793 1 0 r
.62607 .47037 m
.6383 .47268 L
s
0 0 0 r
2.5 Mabswid
.62607 .47037 Mdot
.793 1 0 r
.5 Mabswid
.33874 .51559 m
.62607 .47037 L
s
.81 1 0 r
.37242 .48619 m
.3543 .44623 L
s
0 0 0 r
2.5 Mabswid
.37242 .48619 Mdot
0 .989 1 r
.5 Mabswid
.43318 .39037 m
.37014 .53524 L
s
0 0 0 r
2.5 Mabswid
.43318 .39037 Mdot
0 .989 1 r
.5 Mabswid
.5917 .38723 m
.43318 .39037 L
s
0 .449 1 r
.38279 .55463 m
.60419 .46774 L
s
0 0 0 r
2.5 Mabswid
.38279 .55463 Mdot
.274 1 0 r
.5 Mabswid
.41616 .5435 m
.38279 .55463 L
s
.741 1 0 r
.54708 .37869 m
.38557 .37017 L
s
0 0 0 r
2.5 Mabswid
.54708 .37869 Mdot
.741 1 0 r
.5 Mabswid
.66837 .48615 m
.54708 .37869 L
s
0 1 .632 r
.57173 .39176 m
.66263 .47457 L
s
0 0 0 r
2.5 Mabswid
.57173 .39176 Mdot
0 1 .632 r
.5 Mabswid
.35871 .37193 m
.57173 .39176 L
s
.2 0 1 r
.56855 .61158 m
.62632 .62649 L
s
0 0 0 r
2.5 Mabswid
.56855 .61158 Mdot
0 .038 1 r
.5 Mabswid
.63097 .52351 m
.63324 .57763 L
s
0 0 0 r
2.5 Mabswid
.63097 .52351 Mdot
0 .038 1 r
.5 Mabswid
.47653 .35631 m
.63097 .52351 L
s
.778 1 0 r
.40442 .59312 m
.37517 .53672 L
s
0 0 0 r
2.5 Mabswid
.40442 .59312 Mdot
.778 1 0 r
.5 Mabswid
.63128 .4893 m
.40442 .59312 L
s
.741 1 0 r
.36901 .48736 m
.36232 .4929 L
s
0 0 0 r
2.5 Mabswid
.36901 .48736 Mdot
.741 1 0 r
.5 Mabswid
.6442 .52569 m
.36901 .48736 L
s
0 1 .247 r
.58774 .6031 m
.51144 .52885 L
s
0 0 0 r
2.5 Mabswid
.58774 .6031 Mdot
.819 1 0 r
.5 Mabswid
.56729 .52365 m
.58774 .6031 L
s
0 1 .2 r
.56046 .38099 m
.76108 .3594 L
s
.045 1 0 r
.56046 .38099 m
.57081 .4464 L
s
0 0 0 r
2.5 Mabswid
.56046 .38099 Mdot
.333 1 0 r
.5 Mabswid
.41125 .48477 m
.56046 .38099 L
s
.435 1 0 r
.60676 .58221 m
.62449 .6272 L
s
0 0 0 r
2.5 Mabswid
.60676 .58221 Mdot
0 1 .381 r
.5 Mabswid
.42949 .61447 m
.64855 .60037 L
s
0 0 0 r
2.5 Mabswid
.42949 .61447 Mdot
0 1 .381 r
.5 Mabswid
.35535 .55018 m
.42949 .61447 L
s
.746 1 0 r
.38601 .57054 m
.40197 .58672 L
s
0 0 0 r
2.5 Mabswid
.38601 .57054 Mdot
.746 1 0 r
.5 Mabswid
.60646 .35354 m
.38601 .57054 L
s
0 1 .542 r
.6262 .44556 m
.64677 .43836 L
s
0 0 0 r
2.5 Mabswid
.6262 .44556 Mdot
.62816 .55153 Mdot
0 .418 1 r
.5 Mabswid
.51668 .5183 m
.62816 .55153 L
s
.699 1 0 r
.36574 .48874 m
.32675 .41971 L
s
0 0 0 r
2.5 Mabswid
.36574 .48874 Mdot
0 .13 1 r
.5 Mabswid
.63348 .46796 m
.31476 .53676 L
s
0 0 0 r
2.5 Mabswid
.63348 .46796 Mdot
0 .13 1 r
.5 Mabswid
.63996 .46646 m
.63348 .46796 L
s
0 1 .326 r
.58372 .60952 m
.50898 .53769 L
s
0 0 0 r
2.5 Mabswid
.58372 .60952 Mdot
.814 1 0 r
.5 Mabswid
.56363 .53217 m
.58372 .60952 L
s
0 .538 1 r
.63411 .46968 m
.65309 .41449 L
s
0 0 0 r
2.5 Mabswid
.63411 .46968 Mdot
0 1 .632 r
.5 Mabswid
.6177 .42885 m
.6496 .52738 L
s
0 0 0 r
2.5 Mabswid
.6177 .42885 Mdot
0 1 .632 r
.5 Mabswid
.43975 .35597 m
.6177 .42885 L
s
0 .038 1 r
.59399 .39745 m
.3878 .65032 L
s
0 0 0 r
2.5 Mabswid
.59399 .39745 Mdot
0 .038 1 r
.5 Mabswid
.60672 .4001 m
.59399 .39745 L
s
0 .149 1 r
.63611 .52585 m
.63269 .50191 L
s
0 0 0 r
2.5 Mabswid
.63611 .52585 Mdot
0 .149 1 r
.5 Mabswid
.36833 .54362 m
.63611 .52585 L
s
.778 1 0 r
.4207 .61147 m
.36467 .44795 L
s
0 0 0 r
2.5 Mabswid
.4207 .61147 Mdot
.778 1 0 r
.5 Mabswid
.54035 .63009 m
.4207 .61147 L
s
0 1 .632 r
.62929 .55564 m
.45603 .67625 L
s
0 0 0 r
2.5 Mabswid
.62929 .55564 Mdot
0 1 .632 r
.5 Mabswid
.66263 .47457 m
.62929 .55564 L
s
0 0 0 r
2.5 Mabswid
.63603 .53117 Mdot
.737 1 0 r
.5 Mabswid
.655 .53111 m
.63603 .53117 L
s
0 .038 1 r
.51504 .63807 m
.36843 .45058 L
s
0 0 0 r
2.5 Mabswid
.51504 .63807 Mdot
0 .038 1 r
.5 Mabswid
.55809 .61223 m
.51504 .63807 L
s
.746 1 0 r
.36467 .47986 m
.35839 .48438 L
s
0 0 0 r
2.5 Mabswid
.36467 .47986 Mdot
.746 1 0 r
.5 Mabswid
.65237 .52019 m
.36467 .47986 L
s
.806 1 0 r
.36326 .48608 m
.34708 .45151 L
s
0 0 0 r
2.5 Mabswid
.36326 .48608 Mdot
0 .989 1 r
.5 Mabswid
.36744 .46357 m
.35999 .47467 L
s
0 0 0 r
2.5 Mabswid
.36744 .46357 Mdot
0 .989 1 r
.5 Mabswid
.65252 .4795 m
.36744 .46357 L
s
0 .542 1 r
.37156 .55206 m
.66174 .53136 L
s
0 0 0 r
2.5 Mabswid
.37156 .55206 Mdot
0 .542 1 r
.5 Mabswid
.36527 .52481 m
.37156 .55206 L
s
.797 1 0 r
.46108 .63365 m
.53407 .36541 L
s
0 0 0 r
2.5 Mabswid
.46108 .63365 Mdot
.797 1 0 r
.5 Mabswid
.46102 .6219 m
.46108 .63365 L
s
0 .538 1 r
.39501 .59363 m
.54811 .58149 L
s
0 0 0 r
2.5 Mabswid
.39501 .59363 Mdot
.884 1 0 r
.5 Mabswid
.42544 .51374 m
.39501 .59363 L
s
0 1 .632 r
.6004 .39838 m
.65333 .49325 L
s
0 0 0 r
2.5 Mabswid
.6004 .39838 Mdot
0 1 .632 r
.5 Mabswid
.44126 .32722 m
.6004 .39838 L
s
0 .005 1 r
.36665 .54148 m
.49644 .52228 L
s
0 0 0 r
2.5 Mabswid
.36665 .54148 Mdot
0 1 .749 r
.5 Mabswid
.43988 .52632 m
.36665 .54148 L
s
0 1 .381 r
.58372 .38669 m
.54093 .35119 L
s
0 0 0 r
2.5 Mabswid
.58372 .38669 Mdot
0 1 .381 r
.5 Mabswid
.61118 .62134 m
.58372 .38669 L
s
0 1 .632 r
.52694 .63844 m
.47219 .68011 L
s
0 0 0 r
2.5 Mabswid
.52694 .63844 Mdot
0 .542 1 r
.5 Mabswid
.61228 .41384 m
.40731 .43751 L
s
0 0 0 r
2.5 Mabswid
.61228 .41384 Mdot
0 .542 1 r
.5 Mabswid
.61515 .46764 m
.61228 .41384 L
s
0 0 0 r
2.5 Mabswid
.36639 .46032 Mdot
0 1 .532 r
.5 Mabswid
.36389 .36491 m
.36639 .46032 L
s
.797 1 0 r
.64152 .52177 m
.39638 .38863 L
s
0 0 0 r
2.5 Mabswid
.64152 .52177 Mdot
.797 1 0 r
.5 Mabswid
.63377 .54221 m
.64152 .52177 L
s
.52234 .36104 m
.43003 .65284 L
s
0 0 0 r
2.5 Mabswid
.52234 .36104 Mdot
.797 1 0 r
.5 Mabswid
.53407 .36541 m
.52234 .36104 L
s
0 1 .243 r
.3989 .60071 m
.4807 .52472 L
s
0 0 0 r
2.5 Mabswid
.3989 .60071 Mdot
.874 1 0 r
.5 Mabswid
.42899 .52225 m
.3989 .60071 L
s
0 1 .381 r
.38018 .42734 m
.35535 .55018 L
s
0 0 0 r
2.5 Mabswid
.38018 .42734 Mdot
0 1 .381 r
.5 Mabswid
.54093 .35119 m
.38018 .42734 L
s
1 .728 0 r
.59992 .39446 m
.60748 .38742 L
s
0 0 0 r
2.5 Mabswid
.59992 .39446 Mdot
1 .728 0 r
.5 Mabswid
.43475 .65046 m
.59992 .39446 L
s
0 .829 1 r
.63755 .45595 m
.63876 .44366 L
s
0 0 0 r
2.5 Mabswid
.63755 .45595 Mdot
0 .829 1 r
.5 Mabswid
.34067 .57603 m
.63755 .45595 L
s
.778 1 0 r
.41595 .3867 m
.6392 .42814 L
s
0 0 0 r
2.5 Mabswid
.41595 .3867 Mdot
.778 1 0 r
.5 Mabswid
.36467 .44795 m
.41595 .3867 L
s
0 1 .632 r
.37876 .57307 m
.33261 .54005 L
s
0 0 0 r
2.5 Mabswid
.37876 .57307 Mdot
.741 1 0 r
.5 Mabswid
.37598 .56904 m
.38917 .5829 L
s
0 0 0 r
2.5 Mabswid
.37598 .56904 Mdot
.741 1 0 r
.5 Mabswid
.59505 .35353 m
.37598 .56904 L
s
0 .038 1 r
.36911 .44417 m
.58022 .33198 L
s
0 0 0 r
2.5 Mabswid
.36911 .44417 Mdot
0 .038 1 r
.5 Mabswid
.34208 .52603 m
.36911 .44417 L
s
.38791 .41196 m
.66975 .43827 L
s
0 0 0 r
2.5 Mabswid
.38791 .41196 Mdot
0 .038 1 r
.5 Mabswid
.36843 .45058 m
.38791 .41196 L
s
0 .711 1 r
.45053 .36506 m
.49843 .46988 L
s
0 0 0 r
2.5 Mabswid
.45053 .36506 Mdot
0 1 .145 r
.5 Mabswid
.4478 .4428 m
.45053 .36506 L
s
1 .728 0 r
.47099 .36004 m
.50998 .36498 L
s
0 0 0 r
2.5 Mabswid
.47099 .36004 Mdot
1 .728 0 r
.5 Mabswid
.42366 .62566 m
.47099 .36004 L
s
0 0 0 r
2.5 Mabswid
.6442 .52569 Mdot
.741 1 0 r
.5 Mabswid
.66043 .52553 m
.6442 .52569 L
s
0 1 .253 r
.40306 .60713 m
.48312 .53361 L
s
0 0 0 r
2.5 Mabswid
.40306 .60713 Mdot
.866 1 0 r
.5 Mabswid
.43254 .53078 m
.40306 .60713 L
s
0 1 .532 r
.50089 .35449 m
.5013 .34705 L
s
0 0 0 r
2.5 Mabswid
.50089 .35449 Mdot
0 1 .532 r
.5 Mabswid
.45181 .66486 m
.50089 .35449 L
s
0 .989 1 r
.61515 .59161 m
.66254 .51465 L
s
0 0 0 r
2.5 Mabswid
.61515 .59161 Mdot
0 .989 1 r
.5 Mabswid
.44395 .67543 m
.61515 .59161 L
s
.88 1 0 r
.60871 .60131 m
.62876 .62377 L
s
0 0 0 r
2.5 Mabswid
.60871 .60131 Mdot
.732 1 0 r
.5 Mabswid
.64507 .52842 m
.33757 .42788 L
s
0 0 0 r
2.5 Mabswid
.64507 .52842 Mdot
.732 1 0 r
.5 Mabswid
.64825 .53638 m
.64507 .52842 L
s
1 .728 0 r
.4353 .63181 m
.42366 .62566 L
s
0 0 0 r
2.5 Mabswid
.4353 .63181 Mdot
1 .728 0 r
.5 Mabswid
.60748 .38742 m
.4353 .63181 L
s
.8 1 0 r
.44395 .63592 m
.4548 .66708 L
s
0 0 0 r
2.5 Mabswid
.44395 .63592 Mdot
.03 0 1 r
.5 Mabswid
.63642 .43915 m
.568 .52496 L
s
0 0 0 r
2.5 Mabswid
.63642 .43915 Mdot
0 1 .665 r
.5 Mabswid
.57113 .42394 m
.63642 .43915 L
s
.801 1 0 r
.61111 .40242 m
.38218 .529 L
s
0 0 0 r
2.5 Mabswid
.61111 .40242 Mdot
.801 1 0 r
.5 Mabswid
.6076 .41428 m
.61111 .40242 L
s
0 1 .381 r
.64449 .53326 m
.61677 .46846 L
s
0 0 0 r
2.5 Mabswid
.64449 .53326 Mdot
0 1 .381 r
.5 Mabswid
.50853 .60386 m
.64449 .53326 L
s
.58034 .62436 m
.59898 .63207 L
s
0 0 0 r
2.5 Mabswid
.58034 .62436 Mdot
.045 1 0 r
.5 Mabswid
.35744 .47735 m
.33945 .40628 L
s
0 0 0 r
2.5 Mabswid
.35744 .47735 Mdot
.51099 .64749 Mdot
.045 1 0 r
.5 Mabswid
.56329 .6664 m
.51099 .64749 L
s
.797 1 0 r
.61678 .40921 m
.38741 .53698 L
s
0 0 0 r
2.5 Mabswid
.61678 .40921 Mdot
.797 1 0 r
.5 Mabswid
.61357 .42077 m
.61678 .40921 L
s
0 0 0 r
2.5 Mabswid
.47653 .35631 Mdot
0 .038 1 r
.5 Mabswid
.43774 .35172 m
.47653 .35631 L
s
.699 1 0 r
.61921 .58927 m
.63227 .62172 L
s
0 0 0 r
2.5 Mabswid
.61921 .58927 Mdot
0 1 .495 r
.5 Mabswid
.40723 .61357 m
.48553 .5425 L
s
0 0 0 r
2.5 Mabswid
.40723 .61357 Mdot
.857 1 0 r
.5 Mabswid
.43611 .53932 m
.40723 .61357 L
s
0 .149 1 r
.35566 .51824 m
.36833 .54362 L
s
0 0 0 r
2.5 Mabswid
.35566 .51824 Mdot
0 .149 1 r
.5 Mabswid
.609 .3769 m
.35566 .51824 L
s
0 .298 1 r
.53866 .64418 m
.50173 .55347 L
s
0 0 0 r
2.5 Mabswid
.53866 .64418 Mdot
0 1 .595 r
.5 Mabswid
.54856 .57249 m
.53866 .64418 L
s
.8 1 0 r
.46521 .64367 m
.50643 .64678 L
s
0 0 0 r
2.5 Mabswid
.46521 .64367 Mdot
.8 1 0 r
.5 Mabswid
.38872 .37811 m
.46521 .64367 L
s
0 1 .381 r
.38002 .58433 m
.50853 .60386 L
s
0 0 0 r
2.5 Mabswid
.38002 .58433 Mdot
0 1 .381 r
.5 Mabswid
.40622 .47219 m
.38002 .58433 L
s
.803 1 0 r
.35398 .48597 m
.3399 .45678 L
s
0 0 0 r
2.5 Mabswid
.35398 .48597 Mdot
.35221 .50526 Mdot
.052 0 1 r
.5 Mabswid
.46229 .50967 m
.35221 .50526 L
s
.045 1 0 r
.58231 .62567 m
.56329 .6664 L
s
0 0 0 r
2.5 Mabswid
.58231 .62567 Mdot
.36525 .43967 Mdot
0 1 .797 r
.5 Mabswid
.44012 .42098 m
.36525 .43967 L
s
0 .542 1 r
.54965 .6439 m
.6254 .58611 L
s
0 0 0 r
2.5 Mabswid
.54965 .6439 Mdot
0 .542 1 r
.5 Mabswid
.40716 .58579 m
.54965 .6439 L
s
0 1 .632 r
.37666 .58173 m
.34475 .46205 L
s
0 0 0 r
2.5 Mabswid
.37666 .58173 Mdot
0 1 .632 r
.5 Mabswid
.44538 .67843 m
.37666 .58173 L
s
0 1 .532 r
.39823 .60996 m
.64366 .53481 L
s
0 0 0 r
2.5 Mabswid
.39823 .60996 Mdot
0 1 .532 r
.5 Mabswid
.36294 .57196 m
.39823 .60996 L
s
.778 1 0 r
.64679 .46045 m
.45185 .65022 L
s
0 0 0 r
2.5 Mabswid
.64679 .46045 Mdot
.778 1 0 r
.5 Mabswid
.6392 .42814 m
.64679 .46045 L
s
.741 1 0 r
.35009 .49757 m
.44725 .59374 L
s
0 0 0 r
2.5 Mabswid
.35009 .49757 Mdot
.741 1 0 r
.5 Mabswid
.43309 .45248 m
.35009 .49757 L
s
.36807 .43225 m
.456 .57522 L
s
0 0 0 r
2.5 Mabswid
.36807 .43225 Mdot
.741 1 0 r
.5 Mabswid
.43759 .42408 m
.36807 .43225 L
s
0 0 0 r
2.5 Mabswid
.35414 .52633 Mdot
.778 1 0 r
.5 Mabswid
.34011 .52713 m
.35414 .52633 L
s
0 0 0 r
2.5 Mabswid
.65237 .52019 Mdot
.746 1 0 r
.5 Mabswid
.66582 .51997 m
.65237 .52019 L
s
0 1 .381 r
.43399 .36438 m
.40622 .47219 L
s
0 0 0 r
2.5 Mabswid
.43399 .36438 Mdot
0 1 .381 r
.5 Mabswid
.52686 .41031 m
.43399 .36438 L
s
0 0 0 r
2.5 Mabswid
.65252 .4795 Mdot
0 .989 1 r
.5 Mabswid
.66781 .48934 m
.65252 .4795 L
s
.089 0 1 r
.63957 .43237 m
.58738 .55944 L
s
0 0 0 r
2.5 Mabswid
.63957 .43237 Mdot
0 1 .653 r
.5 Mabswid
.58042 .41854 m
.63957 .43237 L
s
0 .149 1 r
.46634 .64779 m
.48073 .64656 L
s
0 0 0 r
2.5 Mabswid
.46634 .64779 Mdot
0 .149 1 r
.5 Mabswid
.47781 .35403 m
.46634 .64779 L
s
0 1 .532 r
.6559 .49124 m
.49045 .41591 L
s
0 0 0 r
2.5 Mabswid
.6559 .49124 Mdot
0 1 .532 r
.5 Mabswid
.64366 .53481 m
.6559 .49124 L
s
0 1 .598 r
.6511 .46826 m
.4311 .41554 L
s
0 0 0 r
2.5 Mabswid
.6511 .46826 Mdot
1 .992 0 r
.5 Mabswid
.64493 .50009 m
.6511 .46826 L
s
.741 1 0 r
.65439 .5195 m
.65635 .49501 L
s
0 0 0 r
2.5 Mabswid
.65439 .5195 Mdot
.741 1 0 r
.5 Mabswid
.38917 .5829 m
.65439 .5195 L
s
0 .989 1 r
.50199 .34621 m
.31669 .53415 L
s
0 0 0 r
2.5 Mabswid
.50199 .34621 Mdot
0 .989 1 r
.5 Mabswid
.54325 .35379 m
.50199 .34621 L
s
.045 1 0 r
.55158 .35396 m
.61433 .39454 L
s
0 0 0 r
2.5 Mabswid
.55158 .35396 Mdot
.045 1 0 r
.5 Mabswid
.36997 .40419 m
.55158 .35396 L
s
0 .829 1 r
.64232 .56859 m
.6516 .54021 L
s
0 0 0 r
2.5 Mabswid
.64232 .56859 Mdot
0 .829 1 r
.5 Mabswid
.3991 .55159 m
.64232 .56859 L
s
0 .542 1 r
.65622 .51825 m
.37069 .37455 L
s
0 0 0 r
2.5 Mabswid
.65622 .51825 Mdot
0 .542 1 r
.5 Mabswid
.66174 .53136 m
.65622 .51825 L
s
0 1 .453 r
.48817 .34608 m
.58998 .52424 L
s
0 0 0 r
2.5 Mabswid
.48817 .34608 Mdot
0 1 .453 r
.5 Mabswid
.47318 .3751 m
.48817 .34608 L
s
.797 1 0 r
.34937 .52017 m
.63377 .54221 L
s
0 0 0 r
2.5 Mabswid
.34937 .52017 Mdot
.797 1 0 r
.5 Mabswid
.35477 .49798 m
.34937 .52017 L
s
.333 1 0 r
.49439 .34404 m
.57948 .48171 L
s
0 0 0 r
2.5 Mabswid
.49439 .34404 Mdot
.778 1 0 r
.5 Mabswid
.47842 .38648 m
.49439 .34404 L
s
0 0 0 r
2.5 Mabswid
.36254 .43272 Mdot
0 .282 1 r
.5 Mabswid
.4311 .41554 m
.36254 .43272 L
s
0 0 0 r
2.5 Mabswid
.66716 .761 Mdot
.797 1 0 r
.5 Mabswid
.37156 .41831 m
.50775 .67192 L
s
0 0 0 r
2.5 Mabswid
.37156 .41831 Mdot
.797 1 0 r
.5 Mabswid
.39638 .38863 m
.37156 .41831 L
s
.741 1 0 r
.66114 .49904 m
.43759 .42408 L
s
0 0 0 r
2.5 Mabswid
.66114 .49904 Mdot
.741 1 0 r
.5 Mabswid
.65782 .5271 m
.66114 .49904 L
s
.48587 .34522 m
.46543 .36291 L
s
0 0 0 r
2.5 Mabswid
.48587 .34522 Mdot
.741 1 0 r
.5 Mabswid
.61677 .54282 m
.48587 .34522 L
s
0 1 .381 r
.53541 .34863 m
.37059 .47665 L
s
0 0 0 r
2.5 Mabswid
.53541 .34863 Mdot
0 1 .381 r
.5 Mabswid
.58477 .3764 m
.53541 .34863 L
s
.741 1 0 r
.65482 .53741 m
.66837 .48615 L
s
0 0 0 r
2.5 Mabswid
.65482 .53741 Mdot
.741 1 0 r
.5 Mabswid
.49538 .687 m
.65482 .53741 L
s
0 0 0 r
2.5 Mabswid
.44589 .64755 Mdot
0 1 .632 r
.5 Mabswid
.47219 .68011 m
.44589 .64755 L
s
0 .989 1 r
.61482 .38903 m
.53298 .32108 L
s
0 0 0 r
2.5 Mabswid
.61482 .38903 Mdot
0 .989 1 r
.5 Mabswid
.66254 .51465 m
.61482 .38903 L
s
0 .542 1 r
.56346 .35484 m
.36527 .52481 L
s
0 0 0 r
2.5 Mabswid
.56346 .35484 Mdot
0 .542 1 r
.5 Mabswid
.57496 .36821 m
.56346 .35484 L
s
0 1 .056 r
.657 .47293 m
.44012 .42098 L
s
0 0 0 r
2.5 Mabswid
.657 .47293 Mdot
1 .946 0 r
.5 Mabswid
.65167 .50004 m
.657 .47293 L
s
0 1 .711 r
.66072 .51305 m
.57955 .53347 L
s
0 0 0 r
2.5 Mabswid
.66072 .51305 Mdot
.699 1 0 r
.5 Mabswid
.61185 .47118 m
.66072 .51305 L
s
.778 1 0 r
.49573 .3411 m
.54661 .34536 L
s
0 0 0 r
2.5 Mabswid
.49573 .3411 Mdot
.778 1 0 r
.5 Mabswid
.37517 .53672 m
.49573 .3411 L
s
.069 0 1 r
.6425 .42553 m
.59304 .54677 L
s
0 0 0 r
2.5 Mabswid
.6425 .42553 Mdot
0 1 .64 r
.5 Mabswid
.5898 .41315 m
.6425 .42553 L
s
0 0 0 r
2.5 Mabswid
.34644 .52097 Mdot
.789 1 0 r
.5 Mabswid
.33437 .52153 m
.34644 .52097 L
s
0 1 .632 r
.52542 .65689 m
.48004 .61085 L
s
0 0 0 r
2.5 Mabswid
.52542 .65689 Mdot
.045 1 0 r
.5 Mabswid
.55881 .5555 m
.52542 .65689 L
s
.34819 .46998 m
.36997 .40419 L
s
0 0 0 r
2.5 Mabswid
.34819 .46998 Mdot
.045 1 0 r
.5 Mabswid
.46095 .67333 m
.34819 .46998 L
s
0 1 .632 r
.39091 .38686 m
.43975 .35597 L
s
0 0 0 r
2.5 Mabswid
.39091 .38686 Mdot
0 1 .632 r
.5 Mabswid
.34991 .61404 m
.39091 .38686 L
s
0 .149 1 r
.49955 .34073 m
.47781 .35403 L
s
0 0 0 r
2.5 Mabswid
.49955 .34073 Mdot
0 .149 1 r
.5 Mabswid
.52716 .54934 m
.49955 .34073 L
s
.056 1 0 r
.34864 .46428 m
.59844 .40798 L
s
0 0 0 r
2.5 Mabswid
.34864 .46428 Mdot
1 .85 0 r
.5 Mabswid
.35723 .50011 m
.34864 .46428 L
s
0 .149 1 r
.62143 .39421 m
.609 .3769 L
s
0 0 0 r
2.5 Mabswid
.62143 .39421 Mdot
0 .149 1 r
.5 Mabswid
.48073 .64656 m
.62143 .39421 L
s
0 .989 1 r
.65818 .46764 m
.5917 .38723 L
s
0 0 0 r
2.5 Mabswid
.65818 .46764 Mdot
0 .989 1 r
.5 Mabswid
.63416 .55568 m
.65818 .46764 L
s
.865 1 0 r
.37974 .39852 m
.36295 .37827 L
s
0 0 0 r
2.5 Mabswid
.37974 .39852 Mdot
.61118 .62134 Mdot
0 1 .381 r
.5 Mabswid
.60331 .63879 m
.61118 .62134 L
s
.8 1 0 r
.5877 .36587 m
.57658 .35971 L
s
0 0 0 r
2.5 Mabswid
.5877 .36587 Mdot
.8 1 0 r
.5 Mabswid
.50643 .64678 m
.5877 .36587 L
s
0 .542 1 r
.65586 .45191 m
.36339 .40177 L
s
0 0 0 r
2.5 Mabswid
.65586 .45191 Mdot
0 .542 1 r
.5 Mabswid
.66161 .46592 m
.65586 .45191 L
s
0 .989 1 r
.44632 .35044 m
.42226 .36707 L
s
0 0 0 r
2.5 Mabswid
.44632 .35044 Mdot
0 .989 1 r
.5 Mabswid
.60366 .55048 m
.44632 .35044 L
s
0 1 .532 r
.42885 .64457 m
.44708 .65408 L
s
0 0 0 r
2.5 Mabswid
.42885 .64457 Mdot
0 1 .532 r
.5 Mabswid
.5013 .34705 m
.42885 .64457 L
s
0 .989 1 r
.50908 .34003 m
.4117 .49472 L
s
0 0 0 r
2.5 Mabswid
.50908 .34003 Mdot
0 .989 1 r
.5 Mabswid
.53108 .36684 m
.50908 .34003 L
s
.8 1 0 r
.40509 .37408 m
.38872 .37811 L
s
0 0 0 r
2.5 Mabswid
.40509 .37408 Mdot
.8 1 0 r
.5 Mabswid
.65347 .57424 m
.40509 .37408 L
s
0 0 0 r
2.5 Mabswid
.36219 .57826 Mdot
0 .538 1 r
.5 Mabswid
.33488 .56649 m
.36219 .57826 L
s
.65386 .56423 m
.63999 .52703 L
s
0 0 0 r
2.5 Mabswid
.65386 .56423 Mdot
0 .538 1 r
.5 Mabswid
.54811 .58149 m
.65386 .56423 L
s
.388 1 0 r
.64478 .42274 m
.65397 .40373 L
s
0 0 0 r
2.5 Mabswid
.64478 .42274 Mdot
.778 1 0 r
.5 Mabswid
.42692 .64427 m
.47842 .38648 L
s
0 0 0 r
2.5 Mabswid
.42692 .64427 Mdot
.778 1 0 r
.5 Mabswid
.45185 .65022 m
.42692 .64427 L
s
0 1 .066 r
.66287 .47764 m
.45723 .4284 L
s
0 0 0 r
2.5 Mabswid
.66287 .47764 Mdot
1 .954 0 r
.5 Mabswid
.65842 .5 m
.66287 .47764 L
s
0 .364 1 r
.41707 .36441 m
.43628 .34362 L
s
0 0 0 r
2.5 Mabswid
.41707 .36441 Mdot
0 .364 1 r
.5 Mabswid
.4415 .65187 m
.41707 .36441 L
s
0 0 0 r
2.5 Mabswid
.4415 .65187 Mdot
0 .364 1 r
.5 Mabswid
.45331 .66283 m
.4415 .65187 L
s
.746 1 0 r
.491 .33808 m
.47358 .35305 L
s
0 0 0 r
2.5 Mabswid
.491 .33808 Mdot
.746 1 0 r
.5 Mabswid
.61814 .52992 m
.491 .33808 L
s
.514 1 0 r
.41923 .36179 m
.424 .35195 L
s
0 0 0 r
2.5 Mabswid
.41923 .36179 Mdot
.514 1 0 r
.5 Mabswid
.557 .66352 m
.41923 .36179 L
s
0 0 0 r
2.5 Mabswid
.43475 .65046 Mdot
1 .728 0 r
.5 Mabswid
.42528 .65802 m
.43475 .65046 L
s
0 .149 1 r
.61533 .37952 m
.3497 .56553 L
s
0 0 0 r
2.5 Mabswid
.61533 .37952 Mdot
0 .149 1 r
.5 Mabswid
.62902 .38627 m
.61533 .37952 L
s
0 1 .453 r
.50057 .66596 m
.49072 .65537 L
s
0 0 0 r
2.5 Mabswid
.50057 .66596 Mdot
0 1 .453 r
.5 Mabswid
.49757 .47301 m
.50057 .66596 L
s
0 1 .632 r
.34475 .46205 m
.34795 .39166 L
s
0 0 0 r
2.5 Mabswid
.34475 .46205 Mdot
0 .989 1 r
.5 Mabswid
.5806 .35719 m
.36522 .3638 L
s
0 0 0 r
2.5 Mabswid
.5806 .35719 Mdot
0 .989 1 r
.5 Mabswid
.62521 .38584 m
.5806 .35719 L
s
0 1 .632 r
.59208 .63844 m
.54148 .65781 L
s
0 0 0 r
2.5 Mabswid
.59208 .63844 Mdot
0 1 .632 r
.5 Mabswid
.65333 .49325 m
.59208 .63844 L
s
.047 1 0 r
.3427 .46882 m
.5898 .41315 L
s
0 0 0 r
2.5 Mabswid
.3427 .46882 Mdot
1 .857 0 r
.5 Mabswid
.35024 .50007 m
.3427 .46882 L
s
.746 1 0 r
.47225 .66231 m
.48239 .66436 L
s
0 0 0 r
2.5 Mabswid
.47225 .66231 Mdot
.746 1 0 r
.5 Mabswid
.47358 .35305 m
.47225 .66231 L
s
0 .542 1 r
.43871 .65431 m
.46941 .64114 L
s
0 0 0 r
2.5 Mabswid
.43871 .65431 Mdot
0 .542 1 r
.5 Mabswid
.39757 .48195 m
.43871 .65431 L
s
0 0 0 r
2.5 Mabswid
.33874 .51559 Mdot
.793 1 0 r
.5 Mabswid
.32867 .51597 m
.33874 .51559 L
s
0 .989 1 r
.46882 .66188 m
.51548 .67287 L
s
0 0 0 r
2.5 Mabswid
.46882 .66188 Mdot
0 .989 1 r
.5 Mabswid
.31006 .48641 m
.46882 .66188 L
s
0 0 0 r
2.5 Mabswid
.65347 .57424 Mdot
.8 1 0 r
.5 Mabswid
.65802 .57917 m
.65347 .57424 L
s
.333 1 0 r
.63811 .59656 m
.60811 .60476 L
s
0 0 0 r
2.5 Mabswid
.63811 .59656 Mdot
.333 1 0 r
.5 Mabswid
.57948 .48171 m
.63811 .59656 L
s
.797 1 0 r
.51648 .66614 m
.55121 .32922 L
s
0 0 0 r
2.5 Mabswid
.51648 .66614 Mdot
.797 1 0 r
.5 Mabswid
.50775 .67192 m
.51648 .66614 L
s
0 1 .075 r
.66871 .48239 m
.4761 .4363 L
s
0 0 0 r
2.5 Mabswid
.66871 .48239 Mdot
1 .962 0 r
.5 Mabswid
.66518 .49995 m
.66871 .48239 L
s
0 .542 1 r
.33622 .49193 m
.40716 .58579 L
s
0 0 0 r
2.5 Mabswid
.33622 .49193 Mdot
0 .542 1 r
.5 Mabswid
.40731 .43751 m
.33622 .49193 L
s
0 .829 1 r
.49007 .33329 m
.47131 .33825 L
s
0 0 0 r
2.5 Mabswid
.49007 .33329 Mdot
0 .829 1 r
.5 Mabswid
.6516 .54021 m
.49007 .33329 L
s
0 1 .381 r
.4511 .6595 m
.5284 .58442 L
s
0 0 0 r
2.5 Mabswid
.4511 .6595 Mdot
0 1 .381 r
.5 Mabswid
.42424 .60947 m
.4511 .6595 L
s
0 .989 1 r
.35686 .58074 m
.51405 .63975 L
s
0 0 0 r
2.5 Mabswid
.35686 .58074 Mdot
0 .989 1 r
.5 Mabswid
.34093 .51053 m
.35686 .58074 L
s
.2 0 1 r
.63897 .5986 m
.63478 .59006 L
s
0 0 0 r
2.5 Mabswid
.63897 .5986 Mdot
0 .2 1 r
.5 Mabswid
.49561 .52731 m
.63897 .5986 L
s
.741 1 0 r
.60204 .63639 m
.6206 .60762 L
s
0 0 0 r
2.5 Mabswid
.60204 .63639 Mdot
.741 1 0 r
.5 Mabswid
.44725 .59374 m
.60204 .63639 L
s
.136 0 1 r
.64821 .41604 m
.60928 .48387 L
s
0 0 0 r
2.5 Mabswid
.64821 .41604 Mdot
0 1 .935 r
.5 Mabswid
.60008 .42118 m
.64821 .41604 L
s
0 1 .632 r
.65553 .42547 m
.67102 .43034 L
s
0 0 0 r
2.5 Mabswid
.65553 .42547 Mdot
0 .542 1 r
.5 Mabswid
.67424 .50436 m
.66745 .47803 L
s
0 0 0 r
2.5 Mabswid
.67424 .50436 Mdot
0 .542 1 r
.5 Mabswid
.55463 .58376 m
.67424 .50436 L
s
1 .886 0 r
.36329 .59397 m
.35542 .61675 L
s
0 0 0 r
2.5 Mabswid
.36329 .59397 Mdot
0 .439 1 r
.5 Mabswid
.66184 .43559 m
.57985 .46986 L
s
0 0 0 r
2.5 Mabswid
.66184 .43559 Mdot
0 1 .643 r
.5 Mabswid
.64034 .43303 m
.66184 .43559 L
s
0 0 0 r
2.5 Mabswid
.557 .66352 Mdot
.514 1 0 r
.5 Mabswid
.5645 .66771 m
.557 .66352 L
s
.039 1 0 r
.33677 .47339 m
.58042 .41854 L
s
0 0 0 r
2.5 Mabswid
.33677 .47339 Mdot
1 .864 0 r
.5 Mabswid
.34325 .50002 m
.33677 .47339 L
s
.797 1 0 r
.43022 .65667 m
.54748 .43701 L
s
0 0 0 r
2.5 Mabswid
.43022 .65667 Mdot
.797 1 0 r
.5 Mabswid
.43003 .65284 m
.43022 .65667 L
s
0 1 .381 r
.35144 .57782 m
.43248 .6056 L
s
0 0 0 r
2.5 Mabswid
.35144 .57782 Mdot
0 1 .381 r
.5 Mabswid
.37059 .47665 m
.35144 .57782 L
s
0 .989 1 r
.40002 .63554 m
.41987 .64702 L
s
0 0 0 r
2.5 Mabswid
.40002 .63554 Mdot
0 .989 1 r
.5 Mabswid
.42226 .36707 m
.40002 .63554 L
s
0 1 .453 r
.59726 .64322 m
.59475 .58868 L
s
0 0 0 r
2.5 Mabswid
.59726 .64322 Mdot
.732 1 0 r
.5 Mabswid
.5457 .61347 m
.59726 .64322 L
s
0 0 0 r
2.5 Mabswid
.36759 .39824 Mdot
.045 1 0 r
.5 Mabswid
.33945 .40628 m
.36759 .39824 L
s
.741 1 0 r
.35368 .41944 m
.34637 .43234 L
s
0 0 0 r
2.5 Mabswid
.35368 .41944 Mdot
.741 1 0 r
.5 Mabswid
.65635 .49501 m
.35368 .41944 L
s
0 .348 1 r
.33118 .49447 m
.42797 .54633 L
s
0 0 0 r
2.5 Mabswid
.33118 .49447 Mdot
0 1 .522 r
.5 Mabswid
.38426 .48457 m
.33118 .49447 L
s
.741 1 0 r
.59695 .35821 m
.59505 .35353 L
s
0 0 0 r
2.5 Mabswid
.59695 .35821 Mdot
.741 1 0 r
.5 Mabswid
.47134 .66882 m
.59695 .35821 L
s
.42954 .65767 m
.50898 .61941 L
s
0 0 0 r
2.5 Mabswid
.42954 .65767 Mdot
.741 1 0 r
.5 Mabswid
.40675 .59892 m
.42954 .65767 L
s
0 .542 1 r
.39223 .63091 m
.66161 .46592 L
s
0 0 0 r
2.5 Mabswid
.39223 .63091 Mdot
0 .542 1 r
.5 Mabswid
.37822 .62337 m
.39223 .63091 L
s
.741 1 0 r
.46404 .66721 m
.47134 .66882 L
s
0 0 0 r
2.5 Mabswid
.46404 .66721 Mdot
.741 1 0 r
.5 Mabswid
.46543 .36291 m
.46404 .66721 L
s
.35576 .41501 m
.3638 .63423 L
s
0 0 0 r
2.5 Mabswid
.35576 .41501 Mdot
.741 1 0 r
.5 Mabswid
.38557 .37017 m
.35576 .41501 L
s
0 .542 1 r
.35343 .41858 m
.51273 .67501 L
s
0 0 0 r
2.5 Mabswid
.35343 .41858 Mdot
0 .542 1 r
.5 Mabswid
.36339 .40177 m
.35343 .41858 L
s
0 .038 1 r
.36376 .59981 m
.60672 .4001 L
s
0 0 0 r
2.5 Mabswid
.36376 .59981 Mdot
0 .038 1 r
.5 Mabswid
.36778 .60373 m
.36376 .59981 L
s
0 .542 1 r
.52127 .6719 m
.57496 .36821 L
s
0 0 0 r
2.5 Mabswid
.52127 .6719 Mdot
0 .542 1 r
.5 Mabswid
.51273 .67501 m
.52127 .6719 L
s
0 0 0 r
2.5 Mabswid
.45181 .66486 Mdot
0 1 .532 r
.5 Mabswid
.45221 .67193 m
.45181 .66486 L
s
0 0 0 r
2.5 Mabswid
.55662 .66649 Mdot
0 .938 1 r
.5 Mabswid
.55946 .67412 m
.55662 .66649 L
s
0 .989 1 r
.60107 .64285 m
.63412 .50181 L
s
0 0 0 r
2.5 Mabswid
.60107 .64285 Mdot
0 .989 1 r
.5 Mabswid
.57439 .64973 m
.60107 .64285 L
s
.65471 .58601 m
.65194 .56464 L
s
0 0 0 r
2.5 Mabswid
.65471 .58601 Mdot
0 .989 1 r
.5 Mabswid
.55922 .58641 m
.65471 .58601 L
s
.60802 .36279 m
.57898 .35696 L
s
0 0 0 r
2.5 Mabswid
.60802 .36279 Mdot
0 .989 1 r
.5 Mabswid
.63412 .50181 m
.60802 .36279 L
s
0 1 .522 r
.59009 .35173 m
.55094 .40598 L
s
0 0 0 r
2.5 Mabswid
.59009 .35173 Mdot
.797 1 0 r
.5 Mabswid
.57043 .39087 m
.59009 .35173 L
s
0 .029 1 r
.65541 .4162 m
.62776 .465 L
s
0 0 0 r
2.5 Mabswid
.65541 .4162 Mdot
0 1 .975 r
.5 Mabswid
.62299 .41977 m
.65541 .4162 L
s
.741 1 0 r
.67274 .53922 m
.66966 .52174 L
s
0 0 0 r
2.5 Mabswid
.67274 .53922 Mdot
.741 1 0 r
.5 Mabswid
.55552 .60722 m
.67274 .53922 L
s
.045 1 0 r
.67803 .51312 m
.48019 .67322 L
s
0 0 0 r
2.5 Mabswid
.67803 .51312 Mdot
.045 1 0 r
.5 Mabswid
.684 .49939 m
.67803 .51312 L
s
.48019 .67322 m
.46095 .67333 L
s
0 0 0 r
2.5 Mabswid
.48019 .67322 Mdot
0 .542 1 r
.5 Mabswid
.42421 .34556 m
.37822 .62337 L
s
0 0 0 r
2.5 Mabswid
.42421 .34556 Mdot
0 .542 1 r
.5 Mabswid
.4483 .33002 m
.42421 .34556 L
s
0 .038 1 r
.66861 .44293 m
.36778 .60373 L
s
0 0 0 r
2.5 Mabswid
.66861 .44293 Mdot
0 .038 1 r
.5 Mabswid
.66975 .43827 m
.66861 .44293 L
s
.608 1 0 r
.51897 .67411 m
.60401 .72657 L
s
0 .989 1 r
.51897 .67411 m
.53063 .65467 L
s
0 0 0 r
2.5 Mabswid
.51897 .67411 Mdot
.741 1 0 r
.5 Mabswid
.456 .57522 m
.51897 .67411 L
s
0 1 .381 r
.67793 .51793 m
.56932 .41208 L
s
0 0 0 r
2.5 Mabswid
.67793 .51793 Mdot
0 1 .381 r
.5 Mabswid
.67192 .52692 m
.67793 .51793 L
s
0 .149 1 r
.34586 .57594 m
.54742 .4898 L
s
0 0 0 r
2.5 Mabswid
.34586 .57594 Mdot
0 .149 1 r
.5 Mabswid
.3497 .56553 m
.34586 .57594 L
s
.741 1 0 r
.42518 .34362 m
.40923 .38346 L
s
0 0 0 r
2.5 Mabswid
.42518 .34362 Mdot
.741 1 0 r
.5 Mabswid
.54871 .38539 m
.42518 .34362 L
s
.031 1 0 r
.33087 .478 m
.57113 .42394 L
s
0 0 0 r
2.5 Mabswid
.33087 .478 Mdot
1 .871 0 r
.5 Mabswid
.33625 .49997 m
.33087 .478 L
s
0 1 .8 r
.32644 .49884 m
.31726 .23449 L
s
0 1 .643 r
.32644 .49884 m
.38947 .46865 L
s
0 0 0 r
2.5 Mabswid
.32644 .49884 Mdot
0 1 .453 r
.5 Mabswid
.38835 .55851 m
.32644 .49884 L
s
0 g
.76077 .76342 m
.23112 .7661 L
s
.76077 .76342 m
.7615 .2356 L
s
.82089 .81373 m
.76077 .76342 L
s
0 .989 1 r
.49486 .32372 m
.34767 .43991 L
s
0 0 0 r
2.5 Mabswid
.49486 .32372 Mdot
0 .989 1 r
.5 Mabswid
.53298 .32108 m
.49486 .32372 L
s
.67236 .45122 m
.63323 .42544 L
s
0 0 0 r
2.5 Mabswid
.67236 .45122 Mdot
0 .989 1 r
.5 Mabswid
.6572 .48112 m
.67236 .45122 L
s
0 1 .381 r
.64855 .60037 m
.65552 .59699 L
s
0 0 0 r
2.5 Mabswid
.64855 .60037 Mdot
0 .2 1 r
.5 Mabswid
.33605 .44723 m
.49561 .52731 L
s
0 0 0 r
2.5 Mabswid
.33605 .44723 Mdot
0 .2 1 r
.5 Mabswid
.35233 .43806 m
.33605 .44723 L
s
0 .989 1 r
.48385 .67657 m
.63416 .55568 L
s
0 0 0 r
2.5 Mabswid
.48385 .67657 Mdot
0 .989 1 r
.5 Mabswid
.46611 .67047 m
.48385 .67657 L
s
0 0 0 r
2.5 Mabswid
.38795 .63359 Mdot
0 .989 1 r
.5 Mabswid
.32528 .49941 m
.3246 .50008 L
s
0 0 0 r
2.5 Mabswid
.32528 .49941 Mdot
0 .989 1 r
.5 Mabswid
.60236 .64719 m
.6192 .6071 L
s
0 0 0 r
2.5 Mabswid
.60236 .64719 Mdot
0 .989 1 r
.5 Mabswid
.55459 .6447 m
.60236 .64719 L
s
0 1 .532 r
.49476 .67973 m
.50408 .68751 L
s
0 0 0 r
2.5 Mabswid
.49476 .67973 Mdot
0 1 .632 r
.5 Mabswid
.61654 .3638 m
.63267 .37079 L
s
0 0 0 r
2.5 Mabswid
.61654 .3638 Mdot
0 1 .632 r
.5 Mabswid
.37755 .37437 m
.61654 .3638 L
s
0 1 .453 r
.63304 .62438 m
.59673 .62631 L
s
0 0 0 r
2.5 Mabswid
.63304 .62438 Mdot
0 1 .453 r
.5 Mabswid
.62687 .59899 m
.63304 .62438 L
s
0 1 .632 r
.41482 .34882 m
.42419 .32495 L
s
0 0 0 r
2.5 Mabswid
.41482 .34882 Mdot
0 .989 1 r
.5 Mabswid
.3246 .50008 m
.31051 .51541 L
s
0 0 0 r
2.5 Mabswid
.3246 .50008 Mdot
.76108 .3594 Mdot
.37755 .37437 Mdot
0 1 .632 r
.5 Mabswid
.34795 .39166 m
.37755 .37437 L
s
0 .989 1 r
.32458 .50313 m
.39994 .58577 L
s
0 0 0 r
2.5 Mabswid
.32458 .50313 Mdot
0 .989 1 r
.5 Mabswid
.34767 .43991 m
.32458 .50313 L
s
.741 1 0 r
.67135 .43523 m
.58417 .38674 L
s
0 0 0 r
2.5 Mabswid
.67135 .43523 Mdot
.741 1 0 r
.5 Mabswid
.66938 .44547 m
.67135 .43523 L
s
.797 1 0 r
.67757 .46364 m
.6788 .46316 L
s
0 0 0 r
2.5 Mabswid
.67757 .46364 Mdot
0 .2 1 r
.5 Mabswid
.67875 .46887 m
.67728 .46663 L
s
0 0 0 r
2.5 Mabswid
.67875 .46887 Mdot
0 .2 1 r
.5 Mabswid
.50488 .56688 m
.67875 .46887 L
s
0 0 0 r
2.5 Mabswid
.67108 .43332 Mdot
0 .149 1 r
.5 Mabswid
.6556 .44091 m
.67108 .43332 L
s
.797 1 0 r
.54839 .3287 m
.46102 .6219 L
s
0 0 0 r
2.5 Mabswid
.54839 .3287 Mdot
.797 1 0 r
.5 Mabswid
.55121 .32922 m
.54839 .3287 L
s
0 g
.67137 .57189 m
.67208 .57215 L
s
.63055 .63316 m
.67137 .57189 L
s
.67135 .57193 m
.68573 .49974 L
s
.67207 .57218 m
.67135 .57193 L
s
.68573 .49978 m
.6715 .42755 L
s
.68649 .49982 m
.68573 .49978 L
s
.68573 .49974 m
.68649 .49978 L
s
.67139 .57191 m
.63057 .63317 L
s
.68575 .49975 m
.67137 .57193 L
s
.67152 .42754 m
.68575 .49977 L
s
.746 1 0 r
.60734 .35596 m
.60646 .35354 L
s
0 0 0 r
2.5 Mabswid
.60734 .35596 Mdot
.746 1 0 r
.5 Mabswid
.48239 .66436 m
.60734 .35596 L
s
0 g
.63058 .63314 m
.63117 .63357 L
s
.56945 .67422 m
.63058 .63314 L
s
.63115 .6336 m
.63055 .63316 L
s
.63059 .63316 m
.56946 .67425 L
s
.67151 .42758 m
.63078 .36621 L
s
.67223 .42741 m
.67151 .42758 L
s
.6715 .42755 m
.67222 .42738 L
s
.6308 .3662 m
.67153 .42757 L
s
0 .829 1 r
.62817 .36716 m
.58476 .38943 L
s
0 0 0 r
2.5 Mabswid
.62817 .36716 Mdot
0 1 .532 r
.5 Mabswid
.62935 .38373 m
.62817 .36716 L
s
0 .149 1 r
.53722 .67753 m
.53841 .68069 L
s
0 0 0 r
2.5 Mabswid
.53722 .67753 Mdot
0 g
.5 Mabswid
.23073 .23284 m
.7615 .2356 L
s
.82189 .19032 m
.7615 .2356 L
s
.022 1 0 r
.32499 .48265 m
.55973 .42987 L
s
0 0 0 r
2.5 Mabswid
.32499 .48265 Mdot
1 .878 0 r
.5 Mabswid
.32926 .49993 m
.32499 .48265 L
s
.659 1 0 r
.67689 .45387 m
.67853 .45312 L
s
0 1 .522 r
.67689 .45387 m
.38426 .48457 L
s
0 0 0 r
2.5 Mabswid
.67689 .45387 Mdot
0 .542 1 r
.5 Mabswid
.42248 .33827 m
.39757 .48195 L
s
0 0 0 r
2.5 Mabswid
.42248 .33827 Mdot
0 .542 1 r
.5 Mabswid
.45264 .33519 m
.42248 .33827 L
s
.797 1 0 r
.6788 .46316 m
.67796 .46296 L
s
0 0 0 r
2.5 Mabswid
.6788 .46316 Mdot
0 g
.5 Mabswid
.56948 .67421 m
.5699 .67477 L
s
.49722 .68884 m
.56948 .67421 L
s
.56986 .67478 m
.56945 .67422 L
s
.56949 .67423 m
.49722 .68886 L
s
0 .542 1 r
.37069 .37455 m
.36602 .37396 L
s
0 0 0 r
2.5 Mabswid
.37069 .37455 Mdot
0 g
.5 Mabswid
.63081 .36624 m
.56966 .32504 L
s
.6314 .36588 m
.63081 .36624 L
s
.63078 .36621 m
.63138 .36586 L
s
.56967 .32502 m
.63082 .36622 L
s
0 0 0 r
2.5 Mabswid
.67853 .45312 Mdot
.69555 .36943 Mdot
.756 1 0 r
.5 Mabswid
.66518 .49995 m
.69555 .36943 L
s
0 0 0 r
2.5 Mabswid
.69705 .3338 Mdot
.757 1 0 r
.5 Mabswid
.65842 .5 m
.69705 .3338 L
s
0 1 .632 r
.45603 .67625 m
.44538 .67843 L
s
0 0 0 r
2.5 Mabswid
.45603 .67625 Mdot
.69854 .29814 Mdot
.757 1 0 r
.5 Mabswid
.65167 .50004 m
.69854 .29814 L
s
0 0 0 r
2.5 Mabswid
.70002 .26245 Mdot
.782 1 0 r
.5 Mabswid
.64493 .50009 m
.70002 .26245 L
s
0 0 0 r
2.5 Mabswid
.60401 .72657 Mdot
.741 1 0 r
.5 Mabswid
.53563 .32161 m
.46031 .38558 L
s
0 0 0 r
2.5 Mabswid
.53563 .32161 Mdot
.741 1 0 r
.5 Mabswid
.5496 .33514 m
.53563 .32161 L
s
0 .829 1 r
.33655 .57661 m
.34067 .57603 L
s
0 0 0 r
2.5 Mabswid
.33655 .57661 Mdot
0 .829 1 r
.5 Mabswid
.52969 .43135 m
.33655 .57661 L
s
0 0 0 r
2.5 Mabswid
.49538 .687 Mdot
.741 1 0 r
.5 Mabswid
.4905 .68806 m
.49538 .687 L
s
.797 1 0 r
.33674 .57772 m
.61357 .42077 L
s
0 0 0 r
2.5 Mabswid
.33674 .57772 Mdot
.797 1 0 r
.5 Mabswid
.33604 .5767 m
.33674 .57772 L
s
0 0 0 r
2.5 Mabswid
.57046 .76442 Mdot
.54 1 0 r
.5 Mabswid
.55946 .67412 m
.57046 .76442 L
s
0 0 0 r
2.5 Mabswid
.44395 .67543 Mdot
0 .989 1 r
.5 Mabswid
.43268 .67677 m
.44395 .67543 L
s
.732 1 0 r
.33269 .42819 m
.51448 .58663 L
s
0 0 0 r
2.5 Mabswid
.33269 .42819 Mdot
.732 1 0 r
.5 Mabswid
.33757 .42788 m
.33269 .42819 L
s
0 0 0 r
2.5 Mabswid
.44126 .32722 Mdot
0 1 .632 r
.5 Mabswid
.42419 .32495 m
.44126 .32722 L
s
0 g
.49725 .68884 m
.49746 .68944 L
s
.4248 .67469 m
.49725 .68884 L
s
.49742 .68944 m
.49722 .68884 L
s
.49725 .68886 m
.42479 .67471 L
s
.67209 .57217 m
.63836 .50007 L
s
.59764 .5988 m
.67209 .57217 L
s
.67209 .57215 m
.63116 .6336 L
s
.59764 .59878 m
.67209 .57215 L
s
.67207 .57219 m
.63846 .50012 L
s
.68649 .49979 m
.67207 .57219 L
s
.67208 .57215 m
.63115 .6336 L
s
.68649 .49978 m
.67207 .57218 L
s
.68649 .49981 m
.63846 .50015 L
s
.67222 .42737 m
.68649 .49981 L
s
.63846 .50012 m
.68649 .49979 L
s
.67222 .42738 m
.68649 .49982 L
s
.56969 .32505 m
.49734 .31037 L
s
.57011 .32458 m
.56969 .32505 L
s
.56966 .32504 m
.57008 .32457 L
s
.49735 .31035 m
.5697 .32503 L
s
0 .149 1 r
.53841 .68069 m
.53859 .67558 L
s
0 0 0 r
2.5 Mabswid
.53841 .68069 Mdot
0 1 .532 r
.5 Mabswid
.50408 .68751 m
.53496 .63998 L
s
0 0 0 r
2.5 Mabswid
.50408 .68751 Mdot
0 1 .381 r
.5 Mabswid
.65552 .59699 m
.65557 .59683 L
s
0 0 0 r
2.5 Mabswid
.65552 .59699 Mdot
.045 1 0 r
.5 Mabswid
.31913 .48734 m
.53818 .43813 L
s
0 0 0 r
2.5 Mabswid
.31913 .48734 Mdot
1 .866 0 r
.5 Mabswid
.32225 .49988 m
.31913 .48734 L
s
0 1 .381 r
.65557 .59683 m
.58477 .3764 L
s
0 0 0 r
2.5 Mabswid
.65557 .59683 Mdot
0 1 .453 r
.5 Mabswid
.49012 .31485 m
.49757 .47301 L
s
0 0 0 r
2.5 Mabswid
.49012 .31485 Mdot
0 1 .453 r
.5 Mabswid
.49384 .31786 m
.49012 .31485 L
s
0 .038 1 r
.58022 .33198 m
.55809 .61223 L
s
0 0 0 r
2.5 Mabswid
.58022 .33198 Mdot
0 .2 1 r
.5 Mabswid
.36642 .62964 m
.38855 .6268 L
s
0 0 0 r
2.5 Mabswid
.36642 .62964 Mdot
0 1 .522 r
.5 Mabswid
.40828 .57788 m
.36642 .62964 L
s
0 g
.63117 .63358 m
.56986 .67479 L
s
.59766 .59876 m
.63117 .63358 L
s
.63116 .6336 m
.59764 .59878 L
s
.63117 .63357 m
.56986 .67478 L
s
.67224 .42739 m
.59768 .40144 L
s
.63848 .50016 m
.67224 .42739 L
s
.67224 .42741 m
.59778 .40141 L
s
.63139 .36586 m
.67224 .42741 L
s
.63846 .50015 m
.67222 .42737 L
s
.63138 .36586 m
.67223 .42741 L
s
.801 1 0 r
.33026 .5722 m
.6076 .41428 L
s
0 0 0 r
2.5 Mabswid
.33026 .5722 Mdot
.801 1 0 r
.5 Mabswid
.32967 .57136 m
.33026 .5722 L
s
0 .538 1 r
.42868 .32849 m
.41215 .35539 L
s
0 0 0 r
2.5 Mabswid
.42868 .32849 Mdot
0 .538 1 r
.5 Mabswid
.46849 .3546 m
.42868 .32849 L
s
.797 1 0 r
.67796 .46296 m
.35477 .49798 L
s
0 0 0 r
2.5 Mabswid
.67796 .46296 Mdot
.39004 .64874 Mdot
0 .538 1 r
.5 Mabswid
.38648 .6494 m
.39004 .64874 L
s
0 0 0 r
2.5 Mabswid
.684 .49939 Mdot
0 .989 1 r
.5 Mabswid
.34686 .40116 m
.34518 .42684 L
s
0 0 0 r
2.5 Mabswid
.34686 .40116 Mdot
0 .989 1 r
.5 Mabswid
.46461 .38155 m
.34686 .40116 L
s
.3178 .51895 m
.34395 .57981 L
s
0 0 0 r
2.5 Mabswid
.3178 .51895 Mdot
0 .989 1 r
.5 Mabswid
.3269 .44542 m
.3178 .51895 L
s
0 g
.42483 .6747 m
.42482 .67527 L
s
.36324 .63381 m
.42483 .6747 L
s
.42479 .67525 m
.4248 .67469 L
s
.42482 .67473 m
.36323 .63383 L
s
0 1 .795 r
.67102 .43034 m
.78787 .6665 L
s
0 0 0 r
2.5 Mabswid
.67102 .43034 Mdot
0 g
.5 Mabswid
.49738 .31037 m
.42481 .32456 L
s
.49758 .30986 m
.49738 .31037 L
s
.49734 .31037 m
.49754 .30986 L
s
.42481 .32453 m
.49737 .31035 L
s
.741 1 0 r
.35784 .38302 m
.3536 .39211 L
s
0 0 0 r
2.5 Mabswid
.35784 .38302 Mdot
.741 1 0 r
.5 Mabswid
.58417 .38674 m
.35784 .38302 L
s
0 g
.56989 .67479 m
.59763 .59866 L
s
.49903 .63989 m
.56989 .67479 L
s
.5699 .67477 m
.49743 .68945 L
s
.49905 .63987 m
.5699 .67477 L
s
.56986 .67479 m
.59766 .59876 L
s
.5699 .67477 m
.49742 .68944 L
s
.6314 .36587 m
.5978 .40143 L
s
.57008 .32456 m
.6314 .36587 L
s
.59778 .40141 m
.63139 .36586 L
s
.57008 .32457 m
.6314 .36588 L
s
0 .2 1 r
.67728 .46663 m
.35233 .43806 L
s
0 0 0 r
2.5 Mabswid
.67728 .46663 Mdot
0 .989 1 r
.5 Mabswid
.43554 .32468 m
.42012 .33983 L
s
0 0 0 r
2.5 Mabswid
.43554 .32468 Mdot
0 .989 1 r
.5 Mabswid
.50644 .35957 m
.43554 .32468 L
s
0 0 0 r
2.5 Mabswid
.53534 .31789 Mdot
.045 1 0 r
.5 Mabswid
.42234 .42121 m
.53534 .31789 L
s
0 0 0 r
2.5 Mabswid
.31726 .23449 Mdot
.479 1 0 r
.5 Mabswid
.65397 .40373 m
.54394 .22092 L
s
0 0 0 r
2.5 Mabswid
.65397 .40373 Mdot
.55734 .32216 Mdot
0 .989 1 r
.5 Mabswid
.56901 .34127 m
.55734 .32216 L
s
0 0 0 r
2.5 Mabswid
.63267 .37079 Mdot
0 1 .381 r
.5 Mabswid
.40516 .33936 m
.39975 .36637 L
s
0 0 0 r
2.5 Mabswid
.40516 .33936 Mdot
0 1 .381 r
.5 Mabswid
.43757 .34674 m
.40516 .33936 L
s
.741 1 0 r
.34773 .60841 m
.35665 .61283 L
s
0 0 0 r
2.5 Mabswid
.34773 .60841 Mdot
.741 1 0 r
.5 Mabswid
.39742 .48207 m
.34773 .60841 L
s
0 0 0 r
2.5 Mabswid
.33979 .40639 Mdot
0 .931 1 r
.5 Mabswid
.37354 .41052 m
.33979 .40639 L
s
0 .989 1 r
.31861 .54082 m
.57439 .64973 L
s
0 0 0 r
2.5 Mabswid
.31861 .54082 Mdot
0 .989 1 r
.5 Mabswid
.31669 .53415 m
.31861 .54082 L
s
0 g
.36327 .63384 m
.36307 .63428 L
s
.322 .57236 m
.36327 .63384 L
s
.36305 .63425 m
.36324 .63381 L
s
.36325 .63385 m
.32198 .57238 L
s
.42485 .32454 m
.36318 .36553 L
s
.42484 .32407 m
.42485 .32454 L
s
.42481 .32456 m
.4248 .32408 L
s
0 0 0 r
2.5 Mabswid
.66975 .43827 Mdot
0 g
.5 Mabswid
.36317 .36551 m
.42484 .32452 L
s
.49745 .68945 m
.42478 .67526 L
s
.49907 .63987 m
.49745 .68945 L
s
.49743 .68945 m
.49905 .63987 L
s
.49746 .68944 m
.42479 .67525 L
s
.045 1 0 r
.32994 .58138 m
.3278 .58118 L
s
0 0 0 r
2.5 Mabswid
.32994 .58138 Mdot
.4905 .68806 Mdot
.741 1 0 r
.5 Mabswid
.49033 .688 m
.4905 .68806 L
s
0 g
.5701 .32455 m
.49908 .36033 L
s
.59782 .40143 m
.5701 .32455 L
s
.57012 .32457 m
.49914 .36024 L
s
.49755 .30985 m
.57012 .32457 L
s
.5978 .40143 m
.57008 .32456 L
s
.49754 .30986 m
.57011 .32458 L
s
.741 1 0 r
.3638 .63423 m
.65782 .5271 L
s
0 0 0 r
2.5 Mabswid
.3638 .63423 Mdot
.38648 .6494 Mdot
0 .538 1 r
.5 Mabswid
.38383 .642 m
.38648 .6494 L
s
0 0 0 r
2.5 Mabswid
.49033 .688 Mdot
.741 1 0 r
.5 Mabswid
.3536 .39211 m
.49033 .688 L
s
0 0 0 r
2.5 Mabswid
.55946 .67412 Mdot
0 .542 1 r
.5 Mabswid
.35643 .6237 m
.42649 .62072 L
s
0 0 0 r
2.5 Mabswid
.35643 .6237 Mdot
.33606 .41008 Mdot
0 .686 1 r
.5 Mabswid
.35067 .40937 m
.33606 .41008 L
s
0 .137 1 r
.3878 .65032 m
.38673 .65131 L
s
0 0 0 r
2.5 Mabswid
.3878 .65032 Mdot
.39458 .66342 Mdot
0 .957 1 r
.5 Mabswid
.39029 .65221 m
.39458 .66342 L
s
0 0 0 r
2.5 Mabswid
.63227 .62172 Mdot
0 .989 1 r
.5 Mabswid
.39553 .65551 m
.43992 .64024 L
s
0 0 0 r
2.5 Mabswid
.39553 .65551 Mdot
.333 1 0 r
.5 Mabswid
.31857 .55011 m
.41125 .48477 L
s
0 0 0 r
2.5 Mabswid
.31857 .55011 Mdot
.333 1 0 r
.5 Mabswid
.32557 .55455 m
.31857 .55011 L
s
0 0 0 r
2.5 Mabswid
.38673 .65131 Mdot
.34991 .61404 Mdot
0 1 .632 r
.5 Mabswid
.54148 .65781 m
.34991 .61404 L
s
0 0 0 r
2.5 Mabswid
.37277 .70091 Mdot
0 .531 1 r
.5 Mabswid
.38043 .63806 m
.37277 .70091 L
s
0 0 0 r
2.5 Mabswid
.66938 .44547 Mdot
.741 1 0 r
.5 Mabswid
.50898 .61941 m
.66938 .44547 L
s
0 g
.32202 .5724 m
.3217 .57266 L
s
.30749 .49972 m
.32202 .5724 L
s
.32169 .57262 m
.322 .57236 L
s
.322 .5724 m
.30746 .49973 L
s
.36321 .3655 m
.32195 .42707 L
s
.36302 .36515 m
.36321 .3655 L
s
.36318 .36553 m
.36299 .36517 L
s
.32193 .42706 m
.36319 .36549 L
s
0 0 0 r
2.5 Mabswid
.60646 .35354 Mdot
.43268 .67677 Mdot
0 .989 1 r
.5 Mabswid
.4322 .67658 m
.43268 .67677 L
s
0 0 0 r
2.5 Mabswid
.65802 .57917 Mdot
.4322 .67658 Mdot
0 .989 1 r
.5 Mabswid
.34395 .57981 m
.4322 .67658 L
s
.194 1 0 r
.65115 .8021 m
.62876 .62377 L
s
0 0 0 r
2.5 Mabswid
.62876 .62377 Mdot
.44538 .67843 Mdot
0 g
.5 Mabswid
.4248 .67528 m
.49912 .63978 L
s
.40009 .59913 m
.4248 .67528 L
s
.42482 .67527 m
.36305 .63426 L
s
.40012 .59913 m
.42482 .67527 L
s
.42478 .67526 m
.49907 .63987 L
s
.42482 .67527 m
.36305 .63425 L
s
.30749 .49976 m
.30713 .4998 L
s
.32196 .42704 m
.30749 .49976 L
s
.30713 .49976 m
.30749 .49972 L
s
.32165 .42687 m
.32196 .42704 L
s
.32195 .42707 m
.32163 .4269 L
s
.30746 .49975 m
.32194 .42703 L
s
.49757 .30985 m
.49917 .36024 L
s
.4248 .32407 m
.49757 .30985 L
s
.045 1 0 r
.3278 .58118 m
.32863 .57617 L
s
0 0 0 r
2.5 Mabswid
.3278 .58118 Mdot
0 g
.5 Mabswid
.49914 .36024 m
.49755 .30985 L
s
.4248 .32408 m
.49758 .30986 L
s
0 0 0 r
2.5 Mabswid
.35629 .37571 Mdot
0 1 .381 r
.5 Mabswid
.61677 .46846 m
.35629 .37571 L
s
0 0 0 r
2.5 Mabswid
.39029 .65221 Mdot
0 .829 1 r
.5 Mabswid
.47131 .33825 m
.39029 .65221 L
s
0 0 0 r
2.5 Mabswid
.62632 .62649 Mdot
.67192 .52692 Mdot
0 1 .381 r
.5 Mabswid
.43248 .6056 m
.67192 .52692 L
s
0 0 0 r
2.5 Mabswid
.36389 .36491 Mdot
0 1 .532 r
.5 Mabswid
.49045 .41591 m
.36389 .36491 L
s
0 .149 1 r
.53859 .67558 m
.52716 .54934 L
s
0 0 0 r
2.5 Mabswid
.53859 .67558 Mdot
.5645 .66771 Mdot
.31006 .48641 Mdot
0 .989 1 r
.5 Mabswid
.57898 .35696 m
.31006 .48641 L
s
.486 1 0 r
.62449 .6272 m
.62084 .79031 L
s
0 0 0 r
2.5 Mabswid
.62449 .6272 Mdot
.114 0 1 r
.5 Mabswid
.31476 .53676 m
.31317 .53714 L
s
0 0 0 r
2.5 Mabswid
.31476 .53676 Mdot
.35871 .37193 Mdot
0 1 .632 r
.5 Mabswid
.48004 .61085 m
.35871 .37193 L
s
0 .989 1 r
.31051 .51541 m
.33382 .52804 L
s
0 0 0 r
2.5 Mabswid
.31051 .51541 Mdot
.699 1 0 r
.5 Mabswid
.32675 .41971 m
.4222 .42779 L
s
0 0 0 r
2.5 Mabswid
.32675 .41971 Mdot
.65309 .41449 Mdot
.36563 .36365 Mdot
.2 0 1 r
.5 Mabswid
.43733 .42047 m
.36563 .36365 L
s
0 0 0 r
2.5 Mabswid
.34327 .60456 Mdot
0 .989 1 r
.5 Mabswid
.4117 .49472 m
.34327 .60456 L
s
0 0 0 r
2.5 Mabswid
.31317 .53714 Mdot
.47219 .68011 Mdot
.53298 .32108 Mdot
0 g
.5 Mabswid
.36306 .63428 m
.32168 .57262 L
s
.40013 .59915 m
.36306 .63428 L
s
.36305 .63426 m
.40012 .59913 L
s
.36307 .63428 m
.32169 .57262 L
s
0 0 0 r
2.5 Mabswid
.56329 .6664 Mdot
0 g
.5 Mabswid
.42481 .32405 m
.40012 .40114 L
s
.49918 .36022 m
.42481 .32405 L
s
.42484 .32406 m
.4001 .40104 L
s
.36299 .36516 m
.42484 .32406 L
s
.49917 .36024 m
.4248 .32407 L
s
.36299 .36517 m
.42484 .32407 L
s
.249 1 0 r
.61608 .63115 m
.611 .78981 L
s
0 0 0 r
2.5 Mabswid
.61608 .63115 Mdot
.42419 .32495 Mdot
0 g
.5 Mabswid
.23112 .7661 m
.23073 .23284 L
s
.19827 .81284 m
.23112 .7661 L
s
0 .989 1 r
.36522 .3638 m
.3269 .44542 L
s
0 0 0 r
2.5 Mabswid
.36522 .3638 Mdot
.29946 .40336 Mdot
.8 1 0 r
.5 Mabswid
.32225 .49988 m
.29946 .40336 L
s
.741 1 0 r
.66966 .52174 m
.54871 .38539 L
s
0 0 0 r
2.5 Mabswid
.66966 .52174 Mdot
.29801 .3674 Mdot
.765 1 0 r
.5 Mabswid
.32926 .49993 m
.29801 .3674 L
s
0 0 0 r
2.5 Mabswid
.29658 .33136 Mdot
.766 1 0 r
.5 Mabswid
.33625 .49997 m
.29658 .33136 L
s
0 0 0 r
2.5 Mabswid
.60331 .63879 Mdot
.29515 .29526 Mdot
.767 1 0 r
.5 Mabswid
.34325 .50002 m
.29515 .29526 L
s
0 g
.32167 .57265 m
.40023 .59912 L
s
.35899 .5001 m
.32167 .57265 L
s
.32169 .57266 m
.30712 .49977 L
s
.35901 .50011 m
.32169 .57266 L
s
.32168 .57262 m
.40013 .59915 L
s
.3217 .57266 m
.30713 .49976 L
s
.36301 .36515 m
.40012 .40103 L
s
.32162 .4269 m
.36301 .36515 L
s
.4001 .40104 m
.36299 .36516 L
s
.32163 .4269 m
.36302 .36515 L
s
0 0 0 r
2.5 Mabswid
.29374 .25908 Mdot
.768 1 0 r
.5 Mabswid
.35024 .50007 m
.29374 .25908 L
s
0 0 0 r
2.5 Mabswid
.59505 .35353 Mdot
.62935 .38373 Mdot
0 1 .532 r
.5 Mabswid
.5713 .54981 m
.62935 .38373 L
s
0 0 0 r
2.5 Mabswid
.55121 .32922 Mdot
0 g
.5 Mabswid
.30712 .49979 m
.32164 .42686 L
s
.35901 .50014 m
.30712 .49979 L
s
.30712 .49977 m
.35901 .50011 L
s
.32162 .42688 m
.35909 .50019 L
s
.40012 .401 m
.32162 .42688 L
s
.30713 .4998 m
.32165 .42687 L
s
.32164 .42686 m
.35901 .50014 L
s
.40012 .40103 m
.32162 .4269 L
s
1 .984 0 r
.35542 .61675 m
.48937 .77622 L
s
0 0 0 r
2.5 Mabswid
.35542 .61675 Mdot
0 .542 1 r
.5 Mabswid
.66745 .47803 m
.45264 .33519 L
s
0 0 0 r
2.5 Mabswid
.66745 .47803 Mdot
.38383 .642 Mdot
0 .538 1 r
.5 Mabswid
.38027 .49808 m
.38383 .642 L
s
0 0 0 r
2.5 Mabswid
.49384 .31786 Mdot
0 1 .453 r
.5 Mabswid
.59475 .58868 m
.49384 .31786 L
s
0 0 0 r
2.5 Mabswid
.2947 .23295 Mdot
.77 1 0 r
.5 Mabswid
.35723 .50011 m
.2947 .23295 L
s
0 0 0 r
2.5 Mabswid
.66837 .48615 Mdot
.46095 .67333 Mdot
.45221 .67193 Mdot
.34795 .39166 Mdot
.51273 .67501 Mdot
.62902 .38627 Mdot
0 g
.5 Mabswid
.19773 .19073 m
.23073 .23284 L
s
0 0 0 r
2.5 Mabswid
.31669 .53415 Mdot
.045 1 0 r
.5 Mabswid
.32863 .57617 m
.42234 .42121 L
s
0 0 0 r
2.5 Mabswid
.32863 .57617 Mdot
.38043 .63806 Mdot
.66582 .51997 Mdot
.66781 .48934 Mdot
.33945 .40628 Mdot
.51548 .67287 Mdot
0 .989 1 r
.5 Mabswid
.65194 .56464 m
.50644 .35957 L
s
0 0 0 r
2.5 Mabswid
.65194 .56464 Mdot
.6556 .44091 Mdot
0 .149 1 r
.5 Mabswid
.54742 .4898 m
.6556 .44091 L
s
.741 1 0 r
.35665 .61283 m
.55552 .60722 L
s
0 0 0 r
2.5 Mabswid
.35665 .61283 Mdot
.56901 .34127 Mdot
0 .989 1 r
.5 Mabswid
.60726 .42589 m
.56901 .34127 L
s
0 0 0 r
2.5 Mabswid
.66174 .53136 Mdot
.66161 .46592 Mdot
.62521 .38584 Mdot
.32967 .57136 Mdot
.46611 .67047 Mdot
0 .989 1 r
.5 Mabswid
.34518 .42684 m
.46611 .67047 L
s
0 0 0 r
2.5 Mabswid
.66263 .47457 Mdot
.57439 .64973 Mdot
.50775 .67192 Mdot
.785 1 0 r
.5 Mabswid
.35187 .21923 m
.36295 .37827 L
s
0 0 0 r
2.5 Mabswid
.36295 .37827 Mdot
.5496 .33514 Mdot
.741 1 0 r
.5 Mabswid
.6206 .60762 m
.5496 .33514 L
s
0 0 0 r
2.5 Mabswid
.36602 .37396 Mdot
.4483 .33002 Mdot
.32557 .55455 Mdot
.333 1 0 r
.5 Mabswid
.51269 .58957 m
.32557 .55455 L
s
0 0 0 r
2.5 Mabswid
.3536 .39211 Mdot
.321 1 0 r
.5 Mabswid
.73043 .6747 m
.4548 .66708 L
s
0 0 0 r
2.5 Mabswid
.4548 .66708 Mdot
.66043 .52553 Mdot
.59898 .63207 Mdot
.42528 .65802 Mdot
.66254 .51465 Mdot
0 .989 1 r
.5 Mabswid
.42012 .33983 m
.34093 .51053 L
s
0 0 0 r
2.5 Mabswid
.42012 .33983 Mdot
.66518 .49995 Mdot
.756 1 0 r
.5 Mabswid
.66518 .49995 m
.66518 .49995 L
s
0 0 0 r
2.5 Mabswid
.66518 .49995 Mdot
.756 1 0 r
.5 Mabswid
.66518 .49995 m
.66518 .49995 L
s
.66518 .49995 m
.66518 .49995 L
s
0 0 0 r
2.5 Mabswid
.66518 .49995 Mdot
.756 1 0 r
.5 Mabswid
.66518 .49995 m
.66518 .49995 L
s
.66518 .49995 m
.66518 .49995 L
s
0 0 0 r
2.5 Mabswid
.66518 .49995 Mdot
1 .053 0 r
.5 Mabswid
.66518 .49995 m
.66518 .49995 L
s
0 0 0 r
2.5 Mabswid
.66518 .49995 Mdot
.66518 .49995 Mdot
.488 1 0 r
.5 Mabswid
.66518 .49995 m
.76635 .51791 L
s
0 0 0 r
2.5 Mabswid
.66518 .49995 Mdot
1 0 0 r
.5 Mabswid
.67093 .50235 m
.66518 .49995 L
s
0 0 0 r
2.5 Mabswid
.47134 .66882 Mdot
.64237 .4189 Mdot
.33604 .5767 Mdot
.2 0 1 r
.5 Mabswid
.63478 .59006 m
.44558 .42743 L
s
0 0 0 r
2.5 Mabswid
.63478 .59006 Mdot
.3269 .44542 Mdot
0 1 .779 r
.5 Mabswid
.53199 .33319 m
.60027 .21635 L
s
0 0 0 r
2.5 Mabswid
.53199 .33319 Mdot
.65782 .5271 Mdot
0 1 .553 r
.5 Mabswid
.52416 .4958 m
.64677 .43836 L
s
0 0 0 r
2.5 Mabswid
.64677 .43836 Mdot
.33488 .56649 Mdot
.62687 .59899 Mdot
0 1 .453 r
.5 Mabswid
.58998 .52424 m
.62687 .59899 L
s
0 0 0 r
2.5 Mabswid
.45331 .66283 Mdot
.6206 .60762 Mdot
0 .072 1 r
.5 Mabswid
.44422 .33601 m
.50537 .22449 L
s
0 0 0 r
2.5 Mabswid
.44422 .33601 Mdot
.609 .3769 Mdot
.34067 .57603 Mdot
.76635 .51791 Mdot
.54148 .65781 Mdot
.33757 .42788 Mdot
0 1 .62 r
.5 Mabswid
.547 .65488 m
.47054 .779 L
s
0 0 0 r
2.5 Mabswid
.547 .65488 Mdot
.655 .53111 Mdot
.45264 .33519 Mdot
.6516 .54021 Mdot
.57898 .35696 Mdot
.34395 .57981 Mdot
0 .989 1 r
.5 Mabswid
.6192 .6071 m
.60726 .42589 L
s
0 0 0 r
2.5 Mabswid
.6192 .6071 Mdot
.6572 .48112 Mdot
0 .989 1 r
.5 Mabswid
.61495 .52993 m
.6572 .48112 L
s
0 0 0 r
2.5 Mabswid
.43003 .65284 Mdot
.6392 .42814 Mdot
0 1 .827 r
.5 Mabswid
.35067 .40937 m
.22164 .34819 L
s
0 0 0 r
2.5 Mabswid
.35067 .40937 Mdot
0 1 .693 r
.5 Mabswid
.4761 .4363 m
.35067 .40937 L
s
0 1 .453 r
.59673 .62631 m
.50198 .60607 L
s
0 0 0 r
2.5 Mabswid
.59673 .62631 Mdot
.64034 .43303 Mdot
0 1 .643 r
.5 Mabswid
.42823 .46302 m
.64034 .43303 L
s
0 0 0 r
2.5 Mabswid
.48239 .66436 Mdot
.37822 .62337 Mdot
.41987 .64702 Mdot
.8 1 0 r
.5 Mabswid
.32225 .49988 m
.32225 .49988 L
s
0 0 0 r
2.5 Mabswid
.32225 .49988 Mdot
.8 1 0 r
.5 Mabswid
.32225 .49988 m
.32225 .49988 L
s
0 0 0 r
2.5 Mabswid
.32225 .49988 Mdot
.8 1 0 r
.5 Mabswid
.32225 .49988 m
.32225 .49988 L
s
0 0 0 r
2.5 Mabswid
.32225 .49988 Mdot
.8 1 0 r
.5 Mabswid
.32225 .49988 m
.32225 .49988 L
s
.32225 .49988 m
.32225 .49988 L
s
0 0 0 r
2.5 Mabswid
.32225 .49988 Mdot
1 .058 0 r
.5 Mabswid
.32225 .49988 m
.32225 .49988 L
s
0 0 0 r
2.5 Mabswid
.32225 .49988 Mdot
.32225 .49988 Mdot
.544 1 0 r
.5 Mabswid
.32225 .49988 m
.22822 .51717 L
s
0 0 0 r
2.5 Mabswid
.32225 .49988 Mdot
1 0 0 r
.5 Mabswid
.32685 .50222 m
.32225 .49988 L
s
0 0 0 r
2.5 Mabswid
.43628 .34362 Mdot
.38557 .37017 Mdot
.63324 .57763 Mdot
.65842 .5 Mdot
.757 1 0 r
.5 Mabswid
.65842 .5 m
.65842 .5 L
s
0 0 0 r
2.5 Mabswid
.65842 .5 Mdot
.757 1 0 r
.5 Mabswid
.65842 .5 m
.65842 .5 L
s
.65842 .5 m
.65842 .5 L
s
0 0 0 r
2.5 Mabswid
.65842 .5 Mdot
.757 1 0 r
.5 Mabswid
.65842 .5 m
.65842 .5 L
s
.65842 .5 m
.65842 .5 L
s
0 0 0 r
2.5 Mabswid
.65842 .5 Mdot
1 .053 0 r
.5 Mabswid
.65842 .5 m
.65842 .5 L
s
0 0 0 r
2.5 Mabswid
.65842 .5 Mdot
.65842 .5 Mdot
.494 1 0 r
.5 Mabswid
.65842 .5 m
.76761 .51945 L
s
0 0 0 r
2.5 Mabswid
.65842 .5 Mdot
1 0 0 r
.5 Mabswid
.66404 .50235 m
.65842 .5 L
s
0 0 0 r
2.5 Mabswid
.54661 .34536 Mdot
.57658 .35971 Mdot
.33261 .54005 Mdot
0 1 .668 r
.5 Mabswid
.51554 .49469 m
.63955 .43786 L
s
0 0 0 r
2.5 Mabswid
.63955 .43786 Mdot
.64825 .53638 Mdot
.44708 .65408 Mdot
.65635 .49501 Mdot
0 .538 1 r
.5 Mabswid
.41215 .35539 m
.38027 .49808 L
s
0 0 0 r
2.5 Mabswid
.41215 .35539 Mdot
0 .2 1 r
.5 Mabswid
.38855 .6268 m
.50488 .56688 L
s
0 0 0 r
2.5 Mabswid
.38855 .6268 Mdot
.34518 .42684 Mdot
.64043 .44338 Mdot
.32867 .51597 Mdot
.55459 .6447 Mdot
0 .989 1 r
.5 Mabswid
.422 .59904 m
.55459 .6447 L
s
0 0 0 r
2.5 Mabswid
.43757 .34674 Mdot
0 1 .381 r
.5 Mabswid
.56932 .41208 m
.43757 .34674 L
s
0 .989 1 r
.63323 .42544 m
.54383 .39168 L
s
0 0 0 r
2.5 Mabswid
.63323 .42544 Mdot
.424 .35195 Mdot
.36778 .60373 Mdot
.47131 .33825 Mdot
.6496 .52738 Mdot
0 .989 1 r
.5 Mabswid
.53063 .65467 m
.53108 .36684 L
s
0 0 0 r
2.5 Mabswid
.53063 .65467 Mdot
.63876 .44366 Mdot
.6254 .58611 Mdot
0 1 .381 r
.5 Mabswid
.39975 .36637 m
.39792 .43893 L
s
0 0 0 r
2.5 Mabswid
.39975 .36637 Mdot
.65333 .49325 Mdot
.57313 .63327 Mdot
.34637 .43234 Mdot
.36339 .40177 Mdot
0 .989 1 r
.5 Mabswid
.33382 .52804 m
.35607 .53764 L
s
0 0 0 r
2.5 Mabswid
.33382 .52804 Mdot
.76761 .51945 Mdot
.61433 .39454 Mdot
.45185 .65022 Mdot
.64366 .53481 Mdot
.765 1 0 r
.5 Mabswid
.32926 .49993 m
.32926 .49993 L
s
0 0 0 r
2.5 Mabswid
.32926 .49993 Mdot
.765 1 0 r
.5 Mabswid
.32926 .49993 m
.32926 .49993 L
s
0 0 0 r
2.5 Mabswid
.32926 .49993 Mdot
.765 1 0 r
.5 Mabswid
.32926 .49993 m
.32926 .49993 L
s
0 0 0 r
2.5 Mabswid
.32926 .49993 Mdot
.765 1 0 r
.5 Mabswid
.32926 .49993 m
.32926 .49993 L
s
.32926 .49993 m
.32926 .49993 L
s
0 0 0 r
2.5 Mabswid
.32926 .49993 Mdot
1 .059 0 r
.5 Mabswid
.32926 .49993 m
.32926 .49993 L
s
0 0 0 r
2.5 Mabswid
.32926 .49993 Mdot
.32926 .49993 Mdot
.549 1 0 r
.5 Mabswid
.32926 .49993 m
.22747 .51873 L
s
0 0 0 r
2.5 Mabswid
.32926 .49993 Mdot
1 0 0 r
.5 Mabswid
.33379 .50222 m
.32926 .49993 L
s
0 0 0 r
2.5 Mabswid
.43774 .35172 Mdot
.3497 .56553 Mdot
.60748 .38742 Mdot
.33437 .52153 Mdot
.63416 .55568 Mdot
.54093 .35119 Mdot
0 1 .774 r
.5 Mabswid
.50697 .49358 m
.63229 .43736 L
s
0 0 0 r
2.5 Mabswid
.63229 .43736 Mdot
.389 1 0 r
.5 Mabswid
.3399 .45678 m
.64681 .20359 L
s
0 0 0 r
2.5 Mabswid
.3399 .45678 Mdot
.57496 .36821 Mdot
.65167 .50004 Mdot
.757 1 0 r
.5 Mabswid
.65167 .50004 m
.65167 .50004 L
s
0 0 0 r
2.5 Mabswid
.65167 .50004 Mdot
.757 1 0 r
.5 Mabswid
.65167 .50004 m
.65167 .50004 L
s
.65167 .50004 m
.65167 .50004 L
s
0 0 0 r
2.5 Mabswid
.65167 .50004 Mdot
.757 1 0 r
.5 Mabswid
.65167 .50004 m
.65167 .50004 L
s
.65167 .50004 m
.65167 .50004 L
s
0 0 0 r
2.5 Mabswid
.65167 .50004 Mdot
1 .054 0 r
.5 Mabswid
.65167 .50004 m
.65167 .50004 L
s
0 0 0 r
2.5 Mabswid
.65167 .50004 Mdot
.65167 .50004 Mdot
.5 1 0 r
.5 Mabswid
.65167 .50004 m
.76887 .521 L
s
0 0 0 r
2.5 Mabswid
.65167 .50004 Mdot
1 0 0 r
.5 Mabswid
.65715 .50235 m
.65167 .50004 L
s
0 0 0 r
2.5 Mabswid
.34767 .43991 Mdot
1 .356 0 r
.5 Mabswid
.58863 .30938 m
.64213 .5323 L
s
0 0 0 r
2.5 Mabswid
.64213 .5323 Mdot
.54325 .35379 Mdot
.38872 .37811 Mdot
0 .645 1 r
.5 Mabswid
.62299 .41977 m
.78527 .36705 L
s
0 0 0 r
2.5 Mabswid
.62299 .41977 Mdot
0 1 .403 r
.5 Mabswid
.53818 .43813 m
.62299 .41977 L
s
.333 1 0 r
.60811 .60476 m
.51269 .58957 L
s
0 0 0 r
2.5 Mabswid
.60811 .60476 Mdot
0 1 .453 r
.5 Mabswid
.49072 .65537 m
.47318 .3751 L
s
0 0 0 r
2.5 Mabswid
.49072 .65537 Mdot
.43975 .35597 Mdot
.63996 .46646 Mdot
.58477 .3764 Mdot
0 .989 1 r
.5 Mabswid
.43992 .64024 m
.51481 .60382 L
s
0 0 0 r
2.5 Mabswid
.43992 .64024 Mdot
.35233 .43806 Mdot
.34011 .52713 Mdot
.327 1 0 r
.5 Mabswid
.34708 .45151 m
.65532 .20487 L
s
0 0 0 r
2.5 Mabswid
.34708 .45151 Mdot
.36997 .40419 Mdot
0 .538 1 r
.5 Mabswid
.63999 .52703 m
.52765 .40707 L
s
0 0 0 r
2.5 Mabswid
.63999 .52703 Mdot
.63377 .54221 Mdot
.203 1 0 r
.5 Mabswid
.39561 .6193 m
.20072 .53468 L
s
0 0 0 r
2.5 Mabswid
.39561 .6193 Mdot
.766 1 0 r
.5 Mabswid
.33625 .49997 m
.33625 .49997 L
s
0 0 0 r
2.5 Mabswid
.33625 .49997 Mdot
.766 1 0 r
.5 Mabswid
.33625 .49997 m
.33625 .49997 L
s
0 0 0 r
2.5 Mabswid
.33625 .49997 Mdot
.766 1 0 r
.5 Mabswid
.33625 .49997 m
.33625 .49997 L
s
0 0 0 r
2.5 Mabswid
.33625 .49997 Mdot
.766 1 0 r
.5 Mabswid
.33625 .49997 m
.33625 .49997 L
s
.33625 .49997 m
.33625 .49997 L
s
0 0 0 r
2.5 Mabswid
.33625 .49997 Mdot
1 .059 0 r
.5 Mabswid
.33625 .49997 m
.33625 .49997 L
s
0 0 0 r
2.5 Mabswid
.33625 .49997 Mdot
.33625 .49997 Mdot
.554 1 0 r
.5 Mabswid
.33625 .49997 m
.22671 .52029 L
s
0 0 0 r
2.5 Mabswid
.33625 .49997 Mdot
1 0 0 r
.5 Mabswid
.34072 .50222 m
.33625 .49997 L
s
0 0 0 r
2.5 Mabswid
.34208 .52603 Mdot
.76887 .521 Mdot
0 .77 1 r
.5 Mabswid
.49844 .49246 m
.62498 .43685 L
s
0 0 0 r
2.5 Mabswid
.62498 .43685 Mdot
1 .24 0 r
.5 Mabswid
.5816 .30586 m
.63761 .52799 L
s
0 0 0 r
2.5 Mabswid
.63761 .52799 Mdot
0 1 .532 r
.5 Mabswid
.53496 .63998 m
.5713 .54981 L
s
0 0 0 r
2.5 Mabswid
.53496 .63998 Mdot
.6383 .47268 Mdot
.42226 .36707 Mdot
.36294 .57196 Mdot
.53959 .6369 Mdot
0 1 .37 r
.5 Mabswid
.3543 .44623 m
.66556 .20639 L
s
0 0 0 r
2.5 Mabswid
.3543 .44623 Mdot
.22822 .51717 Mdot
.34093 .51053 Mdot
.64493 .50009 Mdot
.782 1 0 r
.5 Mabswid
.64493 .50009 m
.64493 .50009 L
s
0 0 0 r
2.5 Mabswid
.64493 .50009 Mdot
.782 1 0 r
.5 Mabswid
.64493 .50009 m
.64493 .50009 L
s
.64493 .50009 m
.64493 .50009 L
s
0 0 0 r
2.5 Mabswid
.64493 .50009 Mdot
.782 1 0 r
.5 Mabswid
.64493 .50009 m
.64493 .50009 L
s
.64493 .50009 m
.64493 .50009 L
s
0 0 0 r
2.5 Mabswid
.64493 .50009 Mdot
1 .056 0 r
.5 Mabswid
.64493 .50009 m
.64493 .50009 L
s
0 0 0 r
2.5 Mabswid
.64493 .50009 Mdot
.64493 .50009 Mdot
.508 1 0 r
.5 Mabswid
.64493 .50009 m
.77015 .52257 L
s
0 0 0 r
2.5 Mabswid
.64493 .50009 Mdot
1 0 0 r
.5 Mabswid
.65026 .50234 m
.64493 .50009 L
s
0 0 0 r
2.5 Mabswid
.35535 .55018 Mdot
.5013 .34705 Mdot
.60672 .4001 Mdot
.5917 .38723 Mdot
.52033 .64331 Mdot
.48073 .64656 Mdot
.46849 .3546 Mdot
0 .538 1 r
.5 Mabswid
.52153 .4008 m
.46849 .3546 L
s
0 1 .303 r
.69507 .73238 m
.6202 .56024 L
s
0 0 0 r
2.5 Mabswid
.6202 .56024 Mdot
.47358 .35305 Mdot
.42366 .62566 Mdot
0 1 .922 r
.5 Mabswid
.37354 .41052 m
.21686 .35654 L
s
0 0 0 r
2.5 Mabswid
.37354 .41052 Mdot
0 1 .676 r
.5 Mabswid
.45723 .4284 m
.37354 .41052 L
s
1 .232 0 r
.4003 .33963 m
.35154 .53534 L
s
0 0 0 r
2.5 Mabswid
.35154 .53534 Mdot
.61357 .42077 Mdot
0 .542 1 r
.5 Mabswid
.46941 .64114 m
.61515 .46764 L
s
0 0 0 r
2.5 Mabswid
.46941 .64114 Mdot
.50643 .64678 Mdot
0 .101 1 r
.5 Mabswid
.54021 .50436 m
.36509 .56304 L
s
0 0 0 r
2.5 Mabswid
.36509 .56304 Mdot
.58417 .38674 Mdot
1 .242 0 r
.5 Mabswid
.57458 .30236 m
.63306 .52366 L
s
0 0 0 r
2.5 Mabswid
.63306 .52366 Mdot
.47781 .35403 Mdot
.6348 .48095 Mdot
.54035 .63009 Mdot
.767 1 0 r
.5 Mabswid
.34325 .50002 m
.34325 .50002 L
s
0 0 0 r
2.5 Mabswid
.34325 .50002 Mdot
.767 1 0 r
.5 Mabswid
.34325 .50002 m
.34325 .50002 L
s
0 0 0 r
2.5 Mabswid
.34325 .50002 Mdot
.767 1 0 r
.5 Mabswid
.34325 .50002 m
.34325 .50002 L
s
0 0 0 r
2.5 Mabswid
.34325 .50002 Mdot
.767 1 0 r
.5 Mabswid
.34325 .50002 m
.34325 .50002 L
s
.34325 .50002 m
.34325 .50002 L
s
0 0 0 r
2.5 Mabswid
.34325 .50002 Mdot
1 .06 0 r
.5 Mabswid
.34325 .50002 m
.34325 .50002 L
s
0 0 0 r
2.5 Mabswid
.34325 .50002 Mdot
.34325 .50002 Mdot
.559 1 0 r
.5 Mabswid
.34325 .50002 m
.22595 .52187 L
s
0 0 0 r
2.5 Mabswid
.34325 .50002 Mdot
1 0 0 r
.5 Mabswid
.34765 .50222 m
.34325 .50002 L
s
0 0 0 r
2.5 Mabswid
.62776 .465 Mdot
0 .989 1 r
.5 Mabswid
.35607 .53764 m
.41802 .5601 L
s
0 0 0 r
2.5 Mabswid
.35607 .53764 Mdot
0 .829 1 r
.5 Mabswid
.58476 .38943 m
.52969 .43135 L
s
0 0 0 r
2.5 Mabswid
.58476 .38943 Mdot
.53407 .36541 Mdot
.6076 .41428 Mdot
.39638 .38863 Mdot
.77015 .52257 Mdot
.51405 .63975 Mdot
0 .542 1 r
.5 Mabswid
.42649 .62072 m
.55463 .58376 L
s
0 0 0 r
2.5 Mabswid
.42649 .62072 Mdot
0 g
.5 Mabswid
.63836 .50007 m
.59548 .53995 L
s
.63848 .50014 m
.59554 .46056 L
s
.59548 .53997 m
.63848 .50014 L
s
.59553 .46059 m
.63848 .50016 L
s
0 0 0 r
2.5 Mabswid
.46543 .36291 Mdot
.36467 .44795 Mdot
.807 1 0 r
.5 Mabswid
.63818 .50014 m
.79107 .50109 L
s
0 0 0 r
2.5 Mabswid
.63818 .50014 Mdot
1 0 0 r
.5 Mabswid
.64338 .50234 m
.63818 .50014 L
s
.741 1 0 r
.40923 .38346 m
.39963 .53146 L
s
0 0 0 r
2.5 Mabswid
.40923 .38346 Mdot
1 .233 0 r
.5 Mabswid
.40727 .33599 m
.35643 .53106 L
s
0 0 0 r
2.5 Mabswid
.35643 .53106 Mdot
.53108 .36684 Mdot
0 .332 1 r
.5 Mabswid
.70569 .23345 m
.40729 .38462 L
s
0 0 0 r
2.5 Mabswid
.40729 .38462 Mdot
0 g
.5 Mabswid
.59763 .59866 m
.53942 .59613 L
s
.59767 .59879 m
.5955 .53993 L
s
.53941 .59616 m
.59767 .59879 L
s
.59548 .53995 m
.59764 .5988 L
s
0 0 0 r
2.5 Mabswid
.22747 .51873 Mdot
.60842 .5707 Mdot
0 .108 1 r
.5 Mabswid
.54941 .5052 m
.37287 .56361 L
s
0 0 0 r
2.5 Mabswid
.37287 .56361 Mdot
1 .244 0 r
.5 Mabswid
.56757 .29885 m
.62848 .5193 L
s
0 0 0 r
2.5 Mabswid
.62848 .5193 Mdot
0 1 .017 r
.5 Mabswid
.46656 .36471 m
.64475 .21773 L
s
0 0 0 r
2.5 Mabswid
.46656 .36471 Mdot
.61087 .56205 Mdot
.60726 .42589 Mdot
.63412 .50181 Mdot
0 g
.5 Mabswid
.59768 .40144 m
.59553 .46059 L
s
0 0 0 r
2.5 Mabswid
.63128 .4893 Mdot
0 g
.5 Mabswid
.59781 .4014 m
.5395 .40431 L
s
.59556 .4606 m
.59781 .4014 L
s
.53952 .40434 m
.59782 .40143 L
s
0 0 0 r
2.5 Mabswid
.61333 .55342 Mdot
.63269 .50191 Mdot
.36843 .45058 Mdot
.61677 .54282 Mdot
.809 1 0 r
.5 Mabswid
.63137 .50016 m
.79306 .50118 L
s
0 0 0 r
2.5 Mabswid
.63137 .50016 Mdot
1 0 0 r
.5 Mabswid
.6365 .50234 m
.63137 .50016 L
s
0 0 0 r
2.5 Mabswid
.50644 .35957 Mdot
.768 1 0 r
.5 Mabswid
.35024 .50007 m
.35024 .50007 L
s
0 0 0 r
2.5 Mabswid
.35024 .50007 Mdot
.768 1 0 r
.5 Mabswid
.35024 .50007 m
.35024 .50007 L
s
0 0 0 r
2.5 Mabswid
.35024 .50007 Mdot
.768 1 0 r
.5 Mabswid
.35024 .50007 m
.35024 .50007 L
s
0 0 0 r
2.5 Mabswid
.35024 .50007 Mdot
.768 1 0 r
.5 Mabswid
.35024 .50007 m
.35024 .50007 L
s
.35024 .50007 m
.35024 .50007 L
s
0 0 0 r
2.5 Mabswid
.35024 .50007 Mdot
1 .06 0 r
.5 Mabswid
.35024 .50007 m
.35024 .50007 L
s
0 0 0 r
2.5 Mabswid
.35024 .50007 Mdot
.35024 .50007 Mdot
.564 1 0 r
.5 Mabswid
.35024 .50007 m
.22518 .52346 L
s
0 0 0 r
2.5 Mabswid
.35024 .50007 Mdot
1 0 0 r
.5 Mabswid
.35457 .50223 m
.35024 .50007 L
s
0 .939 1 r
.59844 .40798 m
.79994 .34306 L
s
0 0 0 r
2.5 Mabswid
.59844 .40798 Mdot
.4078 .38953 Mdot
.57043 .39087 Mdot
.797 1 0 r
.5 Mabswid
.54748 .43701 m
.57043 .39087 L
s
0 0 0 r
2.5 Mabswid
.36833 .54362 Mdot
0 g
.5 Mabswid
.49912 .63978 m
.46 .59628 L
s
0 0 0 r
2.5 Mabswid
.55809 .61223 Mdot
0 g
.5 Mabswid
.49906 .63989 m
.53945 .59614 L
s
.45997 .59629 m
.49906 .63989 L
s
.53942 .59613 m
.49903 .63989 L
s
0 0 0 r
2.5 Mabswid
.35999 .47467 Mdot
1 .233 0 r
.5 Mabswid
.41421 .33236 m
.36134 .52676 L
s
0 0 0 r
2.5 Mabswid
.36134 .52676 Mdot
.62599 .48461 Mdot
.59475 .58868 Mdot
.61397 .45682 Mdot
.38917 .5829 Mdot
.35839 .48438 Mdot
.50998 .36498 Mdot
0 .008 1 r
.5 Mabswid
.5586 .50603 m
.3807 .56418 L
s
0 0 0 r
2.5 Mabswid
.3807 .56418 Mdot
0 1 .72 r
.5 Mabswid
.60008 .42118 m
.79168 .35862 L
s
0 0 0 r
2.5 Mabswid
.60008 .42118 Mdot
0 1 .517 r
.5 Mabswid
.55973 .42987 m
.60008 .42118 L
s
0 0 0 r
2.5 Mabswid
.61814 .52992 Mdot
1 .246 0 r
.5 Mabswid
.56058 .29536 m
.62387 .51491 L
s
0 0 0 r
2.5 Mabswid
.62387 .51491 Mdot
0 g
.5 Mabswid
.49908 .36033 m
.53952 .40434 L
s
.49915 .36021 m
.46 .40418 L
s
.53954 .40433 m
.49915 .36021 L
s
.46003 .40419 m
.49918 .36022 L
s
.811 1 0 r
.62457 .50018 m
.79509 .50126 L
s
0 0 0 r
2.5 Mabswid
.62457 .50018 Mdot
1 0 0 r
.5 Mabswid
.62962 .50234 m
.62457 .50018 L
s
0 0 0 r
2.5 Mabswid
.35477 .49798 Mdot
.42424 .60947 Mdot
0 1 .381 r
.5 Mabswid
.40671 .49681 m
.42424 .60947 L
s
0 0 0 r
2.5 Mabswid
.61677 .46846 Mdot
.46102 .6219 Mdot
.37685 .5511 Mdot
.54871 .38539 Mdot
.5457 .61347 Mdot
.732 1 0 r
.5 Mabswid
.51448 .58663 m
.5457 .61347 L
s
0 0 0 r
2.5 Mabswid
.36527 .52481 Mdot
.37014 .53524 Mdot
.61515 .46764 Mdot
0 g
.5 Mabswid
.40023 .59912 m
.40369 .54009 L
s
.4001 .59916 m
.46001 .5963 L
s
.40366 .54007 m
.4001 .59916 L
s
.46 .59628 m
.40009 .59913 L
s
0 0 0 r
2.5 Mabswid
.22671 .52029 Mdot
0 .709 1 r
.5 Mabswid
.646 .42 m
.61342 .46436 L
s
0 0 0 r
2.5 Mabswid
.61342 .46436 Mdot
.61495 .52993 Mdot
0 .989 1 r
.5 Mabswid
.56868 .56794 m
.61495 .52993 L
s
0 0 0 r
2.5 Mabswid
.55552 .60722 Mdot
0 .599 1 r
.5 Mabswid
.5898 .41315 m
.82127 .30421 L
s
0 0 0 r
2.5 Mabswid
.5898 .41315 Mdot
.58196 .40496 Mdot
1 .234 0 r
.5 Mabswid
.42113 .32875 m
.36627 .52243 L
s
0 0 0 r
2.5 Mabswid
.36627 .52243 Mdot
1 .286 0 r
.5 Mabswid
.59303 .58934 m
.61054 .45896 L
s
0 0 0 r
2.5 Mabswid
.61054 .45896 Mdot
.77 1 0 r
.5 Mabswid
.35723 .50011 m
.35723 .50011 L
s
0 0 0 r
2.5 Mabswid
.35723 .50011 Mdot
.77 1 0 r
.5 Mabswid
.35723 .50011 m
.35723 .50011 L
s
0 0 0 r
2.5 Mabswid
.35723 .50011 Mdot
.77 1 0 r
.5 Mabswid
.35723 .50011 m
.35723 .50011 L
s
0 0 0 r
2.5 Mabswid
.35723 .50011 Mdot
.77 1 0 r
.5 Mabswid
.35723 .50011 m
.35723 .50011 L
s
.35723 .50011 m
.35723 .50011 L
s
0 0 0 r
2.5 Mabswid
.35723 .50011 Mdot
1 .061 0 r
.5 Mabswid
.35723 .50011 m
.35723 .50011 L
s
0 0 0 r
2.5 Mabswid
.35723 .50011 Mdot
.35723 .50011 Mdot
.569 1 0 r
.5 Mabswid
.35723 .50011 m
.22441 .52507 L
s
0 0 0 r
2.5 Mabswid
.35723 .50011 Mdot
1 0 0 r
.5 Mabswid
.36149 .50223 m
.35723 .50011 L
s
1 .228 0 r
.70239 .45403 m
.61855 .51063 L
s
0 0 0 r
2.5 Mabswid
.61855 .51063 Mdot
0 1 .953 r
.5 Mabswid
.76344 .4056 m
.60696 .45176 L
s
0 0 0 r
2.5 Mabswid
.60696 .45176 Mdot
0 g
.5 Mabswid
.40012 .40114 m
.46003 .40419 L
s
.813 1 0 r
.61777 .5002 m
.79716 .50135 L
s
0 0 0 r
2.5 Mabswid
.61777 .5002 Mdot
1 0 0 r
.5 Mabswid
.62275 .50233 m
.61777 .5002 L
s
0 g
.40009 .40101 m
.40366 .46045 L
s
.46004 .40416 m
.40009 .40101 L
s
.40368 .46043 m
.40012 .401 L
s
0 0 0 r
2.5 Mabswid
.38505 .55957 Mdot
.47318 .3751 Mdot
.40675 .59892 Mdot
.741 1 0 r
.5 Mabswid
.40634 .59571 m
.40675 .59892 L
s
0 .267 1 r
.34946 .67982 m
.56773 .59919 L
s
0 0 0 r
2.5 Mabswid
.56773 .59919 Mdot
.37517 .53672 Mdot
0 g
.5 Mabswid
.35909 .50019 m
.40368 .46043 L
s
0 0 0 r
2.5 Mabswid
.36232 .4929 Mdot
0 g
.5 Mabswid
.35898 .50012 m
.40368 .54011 L
s
.40367 .46041 m
.35898 .50012 L
s
0 .585 1 r
.49737 .37029 m
.78295 .26079 L
s
0 0 0 r
2.5 Mabswid
.49737 .37029 Mdot
0 g
.5 Mabswid
.40369 .54009 m
.35899 .5001 L
s
0 0 0 r
2.5 Mabswid
.60366 .55048 Mdot
.40634 .59571 Mdot
.741 1 0 r
.5 Mabswid
.4017 .55823 m
.40634 .59571 L
s
0 0 0 r
2.5 Mabswid
.60909 .46227 Mdot
.37059 .47665 Mdot
.61185 .47118 Mdot
.699 1 0 r
.5 Mabswid
.48576 .44218 m
.61185 .47118 L
s
0 0 0 r
2.5 Mabswid
.43248 .6056 Mdot
0 .989 1 r
.5 Mabswid
.39994 .58577 m
.422 .59904 L
s
0 0 0 r
2.5 Mabswid
.39994 .58577 Mdot
0 1 .391 r
.5 Mabswid
.59807 .75188 m
.58234 .58025 L
s
0 0 0 r
2.5 Mabswid
.58234 .58025 Mdot
.93 1 0 r
.5 Mabswid
.50183 .76837 m
.46713 .61717 L
s
0 0 0 r
2.5 Mabswid
.46713 .61717 Mdot
1 .16 0 r
.5 Mabswid
.57124 .45593 m
.59914 .43997 L
s
0 0 0 r
2.5 Mabswid
.59914 .43997 Mdot
.38214 .54569 Mdot
.46461 .38155 Mdot
0 .989 1 r
.5 Mabswid
.54383 .39168 m
.46461 .38155 L
s
0 0 0 r
2.5 Mabswid
.38835 .55851 Mdot
0 1 .453 r
.5 Mabswid
.50198 .60607 m
.38835 .55851 L
s
0 0 0 r
2.5 Mabswid
.40197 .58672 Mdot
.831 1 0 r
.5 Mabswid
.36418 .50014 m
.21092 .50122 L
s
0 0 0 r
2.5 Mabswid
.36418 .50014 Mdot
1 0 0 r
.5 Mabswid
.36841 .50223 m
.36418 .50014 L
s
0 0 0 r
2.5 Mabswid
.50898 .61941 Mdot
.815 1 0 r
.5 Mabswid
.61097 .50022 m
.79926 .50145 L
s
0 0 0 r
2.5 Mabswid
.61097 .50022 Mdot
1 0 0 r
.5 Mabswid
.61587 .50233 m
.61097 .50022 L
s
0 0 0 r
2.5 Mabswid
.54383 .39168 Mdot
1 .234 0 r
.5 Mabswid
.42803 .32516 m
.37124 .51809 L
s
0 0 0 r
2.5 Mabswid
.37124 .51809 Mdot
0 .58 1 r
.5 Mabswid
.80754 .31175 m
.58042 .41854 L
s
0 0 0 r
2.5 Mabswid
.58042 .41854 Mdot
.57492 .58351 Mdot
0 1 .969 r
.5 Mabswid
.50404 .61821 m
.36095 .81172 L
s
0 0 0 r
2.5 Mabswid
.50404 .61821 Mdot
.761 1 0 r
.5 Mabswid
.54941 .54814 m
.36641 .50139 L
s
0 0 0 r
2.5 Mabswid
.36641 .50139 Mdot
.422 .59904 Mdot
.60928 .48387 Mdot
.741 1 0 r
.5 Mabswid
.46031 .38558 m
.39742 .48207 L
s
0 0 0 r
2.5 Mabswid
.46031 .38558 Mdot
.40716 .58579 Mdot
1 .184 0 r
.5 Mabswid
.40999 .43753 m
.38588 .54545 L
s
0 0 0 r
2.5 Mabswid
.38588 .54545 Mdot
.22609 .3637 Mdot
0 1 .862 r
.5 Mabswid
.41001 .41161 m
.22609 .3637 L
s
0 0 0 r
2.5 Mabswid
.50665 .61524 Mdot
.56932 .41208 Mdot
.833 1 0 r
.5 Mabswid
.37111 .50016 m
.20964 .50131 L
s
0 0 0 r
2.5 Mabswid
.37111 .50016 Mdot
1 0 0 r
.5 Mabswid
.37532 .50224 m
.37111 .50016 L
s
0 1 .202 r
.40415 .23663 m
.40847 .41263 L
s
0 0 0 r
2.5 Mabswid
.40847 .41263 Mdot
.703 1 0 r
.5 Mabswid
.68618 .65574 m
.6057 .49998 L
s
0 0 0 r
2.5 Mabswid
.6057 .49998 Mdot
.41001 .41161 Mdot
.22595 .52187 Mdot
1 .247 0 r
.5 Mabswid
.69601 .47202 m
.59494 .44485 L
s
0 0 0 r
2.5 Mabswid
.59494 .44485 Mdot
.817 1 0 r
.5 Mabswid
.60418 .50025 m
.8014 .50154 L
s
0 0 0 r
2.5 Mabswid
.60418 .50025 Mdot
1 0 0 r
.5 Mabswid
.609 .50233 m
.60418 .50025 L
s
0 0 0 r
2.5 Mabswid
.60419 .46774 Mdot
1 .173 0 r
.5 Mabswid
.43304 .56107 m
.39674 .5636 L
s
0 0 0 r
2.5 Mabswid
.39674 .5636 Mdot
.46327 .38814 Mdot
0 .156 1 r
.5 Mabswid
.37681 .48072 m
.201 .46513 L
s
0 0 0 r
2.5 Mabswid
.37681 .48072 Mdot
.58738 .55944 Mdot
.42023 .58832 Mdot
.40828 .57788 Mdot
0 1 .522 r
.5 Mabswid
.55094 .40598 m
.40828 .57788 L
s
0 0 0 r
2.5 Mabswid
.38218 .529 Mdot
.38745 .54025 Mdot
1 .245 0 r
.5 Mabswid
.30793 .46818 m
.37638 .51375 L
s
0 0 0 r
2.5 Mabswid
.37638 .51375 Mdot
.48004 .61085 Mdot
.40433 .42484 Mdot
.55922 .58641 Mdot
0 .989 1 r
.5 Mabswid
.41802 .5601 m
.55922 .58641 L
s
.834 1 0 r
.37803 .50018 m
.20834 .50141 L
s
0 0 0 r
2.5 Mabswid
.37803 .50018 Mdot
1 0 0 r
.5 Mabswid
.38222 .50224 m
.37803 .50018 L
s
0 0 0 r
2.5 Mabswid
.38741 .53698 Mdot
.56844 .42044 Mdot
0 .56 1 r
.5 Mabswid
.79196 .32023 m
.57113 .42394 L
s
0 0 0 r
2.5 Mabswid
.57113 .42394 Mdot
.47842 .38648 Mdot
0 1 .381 r
.5 Mabswid
.39792 .43893 m
.40671 .49681 L
s
0 0 0 r
2.5 Mabswid
.39792 .43893 Mdot
.59304 .54677 Mdot
.38027 .49808 Mdot
.50198 .60607 Mdot
1 .242 0 r
.5 Mabswid
.68874 .47811 m
.59035 .44989 L
s
0 0 0 r
2.5 Mabswid
.59035 .44989 Mdot
.261 1 0 r
.5 Mabswid
.5209 .33846 m
.59783 .49464 L
s
0 0 0 r
2.5 Mabswid
.59783 .49464 Mdot
0 .989 1 r
.5 Mabswid
.51481 .60382 m
.56868 .56794 L
s
0 0 0 r
2.5 Mabswid
.51481 .60382 Mdot
.57832 .56073 Mdot
.819 1 0 r
.5 Mabswid
.59738 .50027 m
.80358 .50163 L
s
0 0 0 r
2.5 Mabswid
.59738 .50027 Mdot
1 0 0 r
.5 Mabswid
.60213 .50232 m
.59738 .50027 L
s
0 0 0 r
2.5 Mabswid
.50853 .60386 Mdot
.55094 .40598 Mdot
0 g
.5 Mabswid
.59554 .53997 m
.53945 .59619 L
s
.5956 .46056 m
.59554 .53997 L
s
.5955 .53993 m
.53941 .59616 L
s
.59554 .46056 m
.59548 .53997 L
s
0 0 0 r
2.5 Mabswid
.58998 .52424 Mdot
.55463 .58376 Mdot
1 .173 0 r
.5 Mabswid
.43836 .55493 m
.40113 .55883 L
s
0 0 0 r
2.5 Mabswid
.40113 .55883 Mdot
.58096 .44301 Mdot
.56868 .56794 Mdot
.38426 .48457 Mdot
.932 1 0 r
.5 Mabswid
.63035 .50234 m
.59055 .50027 L
s
0 0 0 r
2.5 Mabswid
.59055 .50027 Mdot
1 0 0 r
.5 Mabswid
.59526 .50232 m
.59055 .50027 L
s
1 .397 0 r
.71348 .32881 m
.59118 .49013 L
s
0 0 0 r
2.5 Mabswid
.59118 .49013 Mdot
.836 1 0 r
.5 Mabswid
.38496 .50021 m
.20702 .5015 L
s
0 0 0 r
2.5 Mabswid
.38496 .50021 Mdot
1 0 0 r
.5 Mabswid
.38912 .50224 m
.38496 .50021 L
s
0 g
.53954 .40427 m
.5956 .46056 L
s
.5395 .40431 m
.59556 .4606 L
s
0 0 0 r
2.5 Mabswid
.57955 .53347 Mdot
.43322 .58694 Mdot
0 .502 1 r
.5 Mabswid
.68918 .20576 m
.50711 .3953 L
s
0 0 0 r
2.5 Mabswid
.50711 .3953 Mdot
.932 1 0 r
.5 Mabswid
.62158 .50233 m
.58371 .50027 L
s
0 0 0 r
2.5 Mabswid
.58371 .50027 Mdot
1 0 0 r
.5 Mabswid
.5884 .50232 m
.58371 .50027 L
s
0 0 0 r
2.5 Mabswid
.5713 .54981 Mdot
1 .403 0 r
.5 Mabswid
.70463 .32357 m
.58434 .48582 L
s
0 0 0 r
2.5 Mabswid
.58434 .48582 Mdot
.4017 .55823 Mdot
.741 1 0 r
.5 Mabswid
.39963 .53146 m
.4017 .55823 L
s
.932 1 0 r
.61283 .50233 m
.57686 .50027 L
s
0 0 0 r
2.5 Mabswid
.57686 .50027 Mdot
1 0 0 r
.5 Mabswid
.58153 .50232 m
.57686 .50027 L
s
1 .168 0 r
.58529 .4551 m
.81338 .36611 L
s
0 0 0 r
2.5 Mabswid
.58529 .4551 Mdot
.57948 .48171 Mdot
1 .401 0 r
.5 Mabswid
.6958 .31834 m
.57751 .48152 L
s
0 0 0 r
2.5 Mabswid
.57751 .48152 Mdot
.57985 .46986 Mdot
.568 .52496 Mdot
.52701 .39822 Mdot
.3991 .55159 Mdot
.56729 .52365 Mdot
1 .168 0 r
.5 Mabswid
.57966 .46053 m
.81511 .36955 L
s
0 0 0 r
2.5 Mabswid
.57966 .46053 Mdot
.56363 .53217 Mdot
.55881 .5555 Mdot
.932 1 0 r
.5 Mabswid
.60408 .50233 m
.57002 .50027 L
s
0 0 0 r
2.5 Mabswid
.57002 .50027 Mdot
1 0 0 r
.5 Mabswid
.57467 .50231 m
.57002 .50027 L
s
0 1 .643 r
.38947 .46865 m
.42823 .46302 L
s
0 0 0 r
2.5 Mabswid
.38947 .46865 Mdot
1 .169 0 r
.5 Mabswid
.57403 .46595 m
.81688 .37306 L
s
0 0 0 r
2.5 Mabswid
.57403 .46595 Mdot
1 .398 0 r
.5 Mabswid
.68698 .31312 m
.5707 .47723 L
s
0 0 0 r
2.5 Mabswid
.5707 .47723 Mdot
.54811 .58149 Mdot
.42234 .42121 Mdot
.54856 .57249 Mdot
.932 1 0 r
.5 Mabswid
.59534 .50232 m
.56318 .50027 L
s
0 0 0 r
2.5 Mabswid
.56318 .50027 Mdot
1 0 0 r
.5 Mabswid
.5678 .50231 m
.56318 .50027 L
s
1 .17 0 r
.5684 .47137 m
.81869 .37662 L
s
0 0 0 r
2.5 Mabswid
.5684 .47137 Mdot
.57081 .4464 Mdot
0 .414 1 r
.5 Mabswid
.38106 .56469 m
.54697 .56202 L
s
0 0 0 r
2.5 Mabswid
.54697 .56202 Mdot
0 g
.5 Mabswid
.53945 .59619 m
.45997 .59634 L
s
.53945 .59614 m
.45997 .59629 L
s
1 .396 0 r
.67819 .30791 m
.5639 .47295 L
s
0 0 0 r
2.5 Mabswid
.5639 .47295 Mdot
.933 1 0 r
.5 Mabswid
.5866 .50232 m
.55634 .50027 L
s
0 0 0 r
2.5 Mabswid
.55634 .50027 Mdot
1 0 0 r
.5 Mabswid
.56094 .50231 m
.55634 .50027 L
s
0 0 0 r
2.5 Mabswid
.39278 .5348 Mdot
.933 1 0 r
.5 Mabswid
.57787 .50231 m
.5495 .50027 L
s
0 0 0 r
2.5 Mabswid
.5495 .50027 Mdot
1 0 0 r
.5 Mabswid
.55408 .50231 m
.5495 .50027 L
s
0 1 .635 r
.2509 .32002 m
.4311 .41554 L
s
0 0 0 r
2.5 Mabswid
.4311 .41554 Mdot
.5284 .58442 Mdot
.54742 .4898 Mdot
0 .668 1 r
.5 Mabswid
.68862 .39781 m
.55973 .42987 L
s
0 0 0 r
2.5 Mabswid
.55973 .42987 Mdot
.44725 .59374 Mdot
.933 1 0 r
.5 Mabswid
.56915 .50231 m
.54266 .50027 L
s
0 0 0 r
2.5 Mabswid
.54266 .50027 Mdot
1 0 0 r
.5 Mabswid
.54722 .5023 m
.54266 .50027 L
s
0 0 0 r
2.5 Mabswid
.40731 .43751 Mdot
.52153 .4008 Mdot
0 .538 1 r
.5 Mabswid
.52765 .40707 m
.52153 .4008 L
s
0 0 0 r
2.5 Mabswid
.52716 .54934 Mdot
.49928 .59782 Mdot
.933 1 0 r
.5 Mabswid
.56043 .50231 m
.53582 .50027 L
s
0 0 0 r
2.5 Mabswid
.53582 .50027 Mdot
1 0 0 r
.5 Mabswid
.54036 .5023 m
.53582 .50027 L
s
0 0 0 r
2.5 Mabswid
.54748 .43701 Mdot
.51448 .58663 Mdot
.51269 .58957 Mdot
.933 1 0 r
.5 Mabswid
.55172 .5023 m
.52899 .50027 L
s
0 0 0 r
2.5 Mabswid
.52899 .50027 Mdot
1 0 0 r
.5 Mabswid
.5335 .5023 m
.52899 .50027 L
s
1 .392 0 r
.47172 .36041 m
.39118 .50281 L
s
0 0 0 r
2.5 Mabswid
.39118 .50281 Mdot
0 1 .067 r
.5 Mabswid
.66339 .40733 m
.53818 .43813 L
s
0 0 0 r
2.5 Mabswid
.53818 .43813 Mdot
0 1 .516 r
.5 Mabswid
.29532 .21858 m
.5201 .51538 L
s
0 0 0 r
2.5 Mabswid
.5201 .51538 Mdot
.933 1 0 r
.5 Mabswid
.54301 .5023 m
.52215 .50027 L
s
0 0 0 r
2.5 Mabswid
.52215 .50027 Mdot
1 0 0 r
.5 Mabswid
.52663 .50229 m
.52215 .50027 L
s
0 0 0 r
2.5 Mabswid
.51668 .5183 Mdot
0 g
.5 Mabswid
.46001 .40412 m
.53954 .40427 L
s
.46 .40418 m
.53954 .40433 L
s
.838 1 0 r
.39188 .50023 m
.20568 .5016 L
s
0 0 0 r
2.5 Mabswid
.39188 .50023 Mdot
1 0 0 r
.5 Mabswid
.39602 .50224 m
.39188 .50023 L
s
0 0 0 r
2.5 Mabswid
.50488 .56688 Mdot
.51144 .52885 Mdot
.50898 .53769 Mdot
.699 1 0 r
.5 Mabswid
.4222 .42779 m
.48576 .44218 L
s
0 0 0 r
2.5 Mabswid
.4222 .42779 Mdot
.52969 .43135 Mdot
.933 1 0 r
.5 Mabswid
.53431 .5023 m
.51531 .50027 L
s
0 0 0 r
2.5 Mabswid
.51531 .50027 Mdot
1 0 0 r
.5 Mabswid
.51977 .50229 m
.51531 .50027 L
s
0 0 0 r
2.5 Mabswid
.22518 .52346 Mdot
.50173 .55347 Mdot
.52765 .40707 Mdot
.934 1 0 r
.5 Mabswid
.52561 .50229 m
.50847 .50027 L
s
0 0 0 r
2.5 Mabswid
.50847 .50027 Mdot
1 0 0 r
.5 Mabswid
.51291 .50229 m
.50847 .50027 L
s
0 0 0 r
2.5 Mabswid
.52686 .41031 Mdot
1 .243 0 r
.5 Mabswid
.32306 .53909 m
.40579 .55391 L
s
0 0 0 r
2.5 Mabswid
.40579 .55391 Mdot
.761 1 0 r
.5 Mabswid
.53727 .24394 m
.51661 .4455 L
s
0 0 0 r
2.5 Mabswid
.51661 .4455 Mdot
.934 1 0 r
.5 Mabswid
.51692 .50229 m
.50163 .50027 L
s
0 0 0 r
2.5 Mabswid
.50163 .50027 Mdot
1 0 0 r
.5 Mabswid
.50605 .50229 m
.50163 .50027 L
s
0 0 0 r
2.5 Mabswid
.50739 .47084 Mdot
.49561 .52731 Mdot
.49644 .52228 Mdot
.50473 .47964 Mdot
.50291 .48199 Mdot
.49365 .52122 Mdot
.934 1 0 r
.5 Mabswid
.50823 .50229 m
.49479 .50027 L
s
0 0 0 r
2.5 Mabswid
.49479 .50027 Mdot
1 0 0 r
.5 Mabswid
.49918 .50228 m
.49479 .50027 L
s
0 0 0 r
2.5 Mabswid
.48553 .5425 Mdot
.49843 .46988 Mdot
.49757 .47301 Mdot
.47835 .56271 Mdot
.48312 .53361 Mdot
.934 1 0 r
.5 Mabswid
.49955 .50228 m
.48794 .50027 L
s
0 0 0 r
2.5 Mabswid
.48794 .50027 Mdot
1 0 0 r
.5 Mabswid
.49232 .50228 m
.48794 .50027 L
s
0 0 0 r
2.5 Mabswid
.4807 .52472 Mdot
0 .565 1 r
.5 Mabswid
.5112 .53324 m
.49932 .42595 L
s
0 0 0 r
2.5 Mabswid
.49932 .42595 Mdot
.934 1 0 r
.5 Mabswid
.49087 .50228 m
.4811 .50027 L
s
0 0 0 r
2.5 Mabswid
.4811 .50027 Mdot
1 0 0 r
.5 Mabswid
.48545 .50228 m
.4811 .50027 L
s
0 0 0 r
2.5 Mabswid
.48477 .47971 Mdot
0 g
.5 Mabswid
.45997 .59634 m
.45997 .59634 L
s
.45997 .59634 m
.40362 .54011 L
s
.46001 .5963 m
.40366 .54007 L
s
.774 1 0 r
.34631 .37109 m
.39601 .50352 L
s
0 0 0 r
2.5 Mabswid
.39601 .50352 Mdot
.49236 .4304 Mdot
.4822 .47089 Mdot
.41802 .5601 Mdot
.934 1 0 r
.5 Mabswid
.48219 .50228 m
.47426 .50027 L
s
0 0 0 r
2.5 Mabswid
.47426 .50027 Mdot
1 0 0 r
.5 Mabswid
.47859 .50228 m
.47426 .50027 L
s
0 0 0 r
2.5 Mabswid
.48576 .44218 Mdot
.49045 .41591 Mdot
.47964 .46206 Mdot
.456 .57522 Mdot
.43733 .42047 Mdot
.2 0 1 r
.5 Mabswid
.44558 .42743 m
.43733 .42047 L
s
.934 1 0 r
.47352 .50227 m
.46741 .50027 L
s
0 0 0 r
2.5 Mabswid
.46741 .50027 Mdot
1 0 0 r
.5 Mabswid
.47172 .50227 m
.46741 .50027 L
s
0 0 0 r
2.5 Mabswid
.46229 .50967 Mdot
0 .402 1 r
.5 Mabswid
.37941 .40649 m
.4761 .4363 L
s
0 0 0 r
2.5 Mabswid
.4761 .4363 Mdot
.39742 .48207 Mdot
1 .388 0 r
.5 Mabswid
.47971 .35544 m
.3978 .49793 L
s
0 0 0 r
2.5 Mabswid
.3978 .49793 Mdot
.934 1 0 r
.5 Mabswid
.46485 .50227 m
.46056 .50027 L
s
0 0 0 r
2.5 Mabswid
.46056 .50027 Mdot
.39757 .48195 Mdot
.46082 .48098 Mdot
.934 1 0 r
.5 Mabswid
.45618 .50227 m
.45371 .50027 L
s
0 0 0 r
2.5 Mabswid
.45371 .50027 Mdot
1 0 0 r
.5 Mabswid
.45798 .50227 m
.45371 .50027 L
s
.84 1 0 r
.3988 .50025 m
.2043 .5017 L
s
0 0 0 r
2.5 Mabswid
.3988 .50025 Mdot
1 0 0 r
.5 Mabswid
.40292 .50225 m
.3988 .50025 L
s
0 0 0 r
2.5 Mabswid
.39963 .53146 Mdot
0 .375 1 r
.5 Mabswid
.26447 .32788 m
.44012 .42098 L
s
0 0 0 r
2.5 Mabswid
.44012 .42098 Mdot
.934 1 0 r
.5 Mabswid
.44752 .50226 m
.44686 .50027 L
s
0 0 0 r
2.5 Mabswid
.44686 .50027 Mdot
1 0 0 r
.5 Mabswid
.4511 .50227 m
.44686 .50027 L
s
0 0 0 r
2.5 Mabswid
.43988 .52632 Mdot
.43611 .53932 Mdot
0 .43 1 r
.5 Mabswid
.35818 .39766 m
.45723 .4284 L
s
0 0 0 r
2.5 Mabswid
.45723 .4284 Mdot
.43759 .42408 Mdot
0 g
.5 Mabswid
.40362 .4604 m
.46001 .40412 L
s
.40366 .46045 m
.46004 .40416 L
s
.934 1 0 r
.43886 .50226 m
.44001 .50027 L
s
0 0 0 r
2.5 Mabswid
.44001 .50027 Mdot
1 0 0 r
.5 Mabswid
.44423 .50226 m
.44001 .50027 L
s
.493 1 0 r
.59279 .28844 m
.43014 .5468 L
s
0 0 0 r
2.5 Mabswid
.43014 .5468 Mdot
.43254 .53078 Mdot
.57 1 0 r
.5 Mabswid
.58737 .30238 m
.42662 .55654 L
s
0 0 0 r
2.5 Mabswid
.42662 .55654 Mdot
.42797 .54633 Mdot
.4478 .4428 Mdot
1 .26 0 r
.5 Mabswid
.33017 .53291 m
.41062 .54889 L
s
0 0 0 r
2.5 Mabswid
.41062 .54889 Mdot
1 .163 0 r
.5 Mabswid
.42753 .53256 m
.19966 .63503 L
s
0 0 0 r
2.5 Mabswid
.42753 .53256 Mdot
.42899 .52225 Mdot
.934 1 0 r
.5 Mabswid
.4302 .50226 m
.43315 .50027 L
s
0 0 0 r
2.5 Mabswid
.43315 .50027 Mdot
1 0 0 r
.5 Mabswid
.43735 .50226 m
.43315 .50027 L
s
0 0 0 r
2.5 Mabswid
.44558 .42743 Mdot
1 .162 0 r
.5 Mabswid
.42185 .53802 m
.20065 .63826 L
s
0 0 0 r
2.5 Mabswid
.42185 .53802 Mdot
.42544 .51374 Mdot
1 .421 0 r
.5 Mabswid
.33563 .32939 m
.43238 .47573 L
s
0 0 0 r
2.5 Mabswid
.43238 .47573 Mdot
.934 1 0 r
.5 Mabswid
.42155 .50225 m
.42629 .50027 L
s
0 0 0 r
2.5 Mabswid
.42629 .50027 Mdot
1 0 0 r
.5 Mabswid
.43047 .50226 m
.42629 .50027 L
s
1 .161 0 r
.41616 .5435 m
.20162 .64144 L
s
0 0 0 r
2.5 Mabswid
.41616 .5435 Mdot
.43309 .45248 Mdot
1 .422 0 r
.5 Mabswid
.32707 .33502 m
.42543 .48005 L
s
0 0 0 r
2.5 Mabswid
.42543 .48005 Mdot
.42823 .46302 Mdot
.934 1 0 r
.5 Mabswid
.41289 .50225 m
.41943 .50027 L
s
0 0 0 r
2.5 Mabswid
.41943 .50027 Mdot
1 0 0 r
.5 Mabswid
.42359 .50225 m
.41943 .50027 L
s
1 .424 0 r
.31849 .34066 m
.41846 .48439 L
s
0 0 0 r
2.5 Mabswid
.41846 .48439 Mdot
.934 1 0 r
.5 Mabswid
.40424 .50225 m
.41257 .50027 L
s
0 0 0 r
2.5 Mabswid
.41257 .50027 Mdot
1 0 0 r
.5 Mabswid
.4167 .50225 m
.41257 .50027 L
s
0 g
.40362 .54011 m
.40362 .4604 L
s
.40368 .54011 m
.40367 .46041 L
s
0 0 0 r
2.5 Mabswid
.40341 .52518 Mdot
.4117 .49472 Mdot
1 .427 0 r
.5 Mabswid
.30989 .3463 m
.41147 .48874 L
s
0 0 0 r
2.5 Mabswid
.41147 .48874 Mdot
.41125 .48477 Mdot
.40671 .49681 Mdot
.933 1 0 r
.5 Mabswid
.39559 .50224 m
.4057 .50027 L
s
0 0 0 r
2.5 Mabswid
.4057 .50027 Mdot
1 0 0 r
.5 Mabswid
.40981 .50225 m
.4057 .50027 L
s
1 .429 0 r
.30127 .35196 m
.40446 .4931 L
s
0 0 0 r
2.5 Mabswid
.40446 .4931 Mdot
.40622 .47219 Mdot
.22441 .52507 Mdot
.50537 .22449 Mdot
.48937 .77622 Mdot
.47054 .779 Mdot
.22164 .34819 Mdot
.54394 .22092 Mdot
.78295 .26079 Mdot
.64475 .21773 Mdot
.78527 .36705 Mdot
.60027 .21635 Mdot
.78787 .6665 Mdot
.21686 .35654 Mdot
.79107 .50109 Mdot
.79168 .35862 Mdot
.611 .78981 Mdot
.62084 .79031 Mdot
.79306 .50118 Mdot
.79509 .50126 Mdot
.79716 .50135 Mdot
.21092 .50122 Mdot
.79926 .50145 Mdot
.79994 .34306 Mdot
.66556 .20639 Mdot
.20964 .50131 Mdot
.8014 .50154 Mdot
.65532 .20487 Mdot
.20834 .50141 Mdot
.80358 .50163 Mdot
.64681 .20359 Mdot
.20702 .5015 Mdot
.20568 .5016 Mdot
.2043 .5017 Mdot
.81338 .36611 Mdot
.20162 .64144 Mdot
.81511 .36955 Mdot
.201 .46513 Mdot
.20072 .53468 Mdot
.20065 .63826 Mdot
.81688 .37306 Mdot
.19966 .63503 Mdot
.36095 .81172 Mdot
.81869 .37662 Mdot
.82127 .30421 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{808, 461.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<X0001cB000`400?l00000o`00003ooooooooo
oooooooooooo:oooool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00
oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[
ooooo`00oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo003ooooooooooooo
ooooool[ooooo`00oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo003ooooo
ooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo
003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?oooooooooooooooooo
ob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?oooooooooo
ooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?oo
ooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:ooo
ool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooo
oooo:oooool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooo
oooooooooooo:oooool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00
oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[
ooooo`00oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo003ooooooooooooo
ooooool[ooooo`00oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo003ooooo
ooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo
003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?oooooooooooooooooo
ob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?oooooooooo
ooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?oo
ooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:ooo
ool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooo
oooo:oooool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooo
oooooooooooo:oooool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00
oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[
ooooo`00oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo003ooooooooooooo
ooooool[ooooo`00oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo003ooooo
ooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo
003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?oooooooooooooooooo
ob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?oooooooooo
ooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?oo
ooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:ooo
ool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooo
oooo:oooool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooo
oooooooooooo:oooool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00
oooooooooooooooooooo:oooool00?ooooooL_ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo0?oooooo3oooool2o`0006;ooooo001Pooooo`;o00007oooool00ol0ohCoooooooooo`3]
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0ooooool>ooooo`03o`000?oooooo
oooo06;ooooo001Rooooo`03o`000?oooooooooo01cooooo00?o0?n4ooooooooool0k?ooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo0?oooooo3?ooool00ol0003oooooooooo`1Soooo
o`00Hoooool2o`0001gooooo00?o0?n4ooooooooool0j_ooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo0?oooooo2Oooool2o`0006Kooooo001Uooooo`03o`000?oooooooooo01_ooooo
00?o0?n4ooooooooool0jOooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0?oooooo
1oooool00ol0003oooooooooo`1Vooooo`00I_ooool00ol0003oooooooooo`0Kooooo`03o`3oQ?oo
oooooooo0:3ooooo00?oHol0o`000?l00000A?ooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo0?oooooo1_ooool00ol0003oooooooooo`1Wooooo`00Ioooool2o`0001cooooo00?o0?n4
ooooooooool0W_ooool01?mSo`3oooooo`000?l00002ooooo`;o00000oooool2o`0003_ooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`2mooooo`;o00000_ooool2o`0003oooooo0_l0
001Zooooo`00JOooool00ol0003oooooooooo`0Jooooo`03o`3oQ?oooooooooo09cooooo00?oHol0
ooooooooool00oooool00omCo`3o0000o`000003ooooo`;o0000>_ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo0;_ooooo00?oHol0o`000?l000000_ooool2o`0000;ooooo0_l0000:
ooooo`03o`20oooooooooooo02gooooo00?o0000ooooooooool0J_ooool006[ooooo0_l0000Joooo
o`03o`3oQ?oooooooooo09_ooooo00?oHol0ooooooooool00oooool00omCo`3oooooooooo`03oooo
o`03o`3oG_oooooooooo03Wooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2ioooo
o`03of?o0?oooooooooo00;ooooo00GoDol0ooooooooooooooooo`3oGP02o`0000[ooooo00?o083o
ooooooooool0;?ooool00ol0003oooooooooo`1[ooooo`00K?ooool00ol0003oooooooooo`0Hoooo
o`03o`3oQ?oooooooooo09Wooooo00?oHol0ooooooooool00oooool00omCo`3oooooooooo`03oooo
o`03o`3oG_oooooooooo03[ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2hoooo
o`03of?o0?oooooooooo00;ooooo00GoDol0ooooooooooooooooo`3oGP0<ooooo`03o`20oooooooo
oooo02_ooooo0_l0001^ooooo`00KOooool00ol0003oooooooooo`0Hooooo`03o`3oQ?oooooooooo
01Sooooo00?ob?l0ooooooooool0O?ooool00omSo`3oooooooooo`03ooooo`03oe?o0?oooooooooo
00?ooooo00?o0?mNooooooooool0>_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
0;Kooooo00?oHol0ooooooooool00_ooool01OmCo`3ooooooooooooooooo0?mN00cooooo00?o083o
ooooooooool0:oooool00ol0003oooooooooo`1^ooooo`00K_ooool2o`0001Wooooo00?o0?n4oooo
ooooool05oooool00oo8o`3oooooooooo`1aooooo`;o00002?ooool00omSo`3oooooooooo`03oooo
o`04oe?o0?ooooooooooooooo`;o000000?o0?mNooooooooool01?ooool00ol0P?ooooooooooo`0c
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0YOooool2o`0000cooooo0_mSo`03
ooooo`;oDol00_ooool2o`3oGPcooooo00?o083oooooooooool0:_ooool2o`00077ooooo001`oooo
o`03o`000?oooooooooo01Oooooo00?o0?n4ooooooooool05_ooool00oo8o`3oooooooooo`1aoooo
o`;o00001oooool00omSo`3oooooooooo`02ooooo`;oDol01?ooool2o`0000Oooooo00?o083ooooo
ooooool0<oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo0:Gooooo0_l0000;oooo
o`03of?o0?oooooooooo00;ooooo00GoDol0o`000?l0003oooooo`3oGP0=ooooo`03o`20oooooooo
oooo02[ooooo00?o0000ooooooooool0LOooool0077ooooo0_l0000Hooooo`03o`3oQ?oooooooooo
01Kooooo00?ob?l0ooooooooool0F?ooool2o`0001Kooooo00?o0?o7ooooooooool01?ooool2of?o
00Cooooo00?oDol0ooooooooool00oooool00ol0o`Coooooooooo`06ooooo`03o`20oooooooooooo
03?ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Oooooo`03o`3oQ?oooooooooo
01Kooooo00?ob?l0ooooooooool0D?ooool2o`0001Oooooo00?o0?o7ooooooooool02Oooool00omS
o`3oooooooooo`02ooooo`05oe?o0?l0o`Co0000o`000?l0oeh03Oooool00ol0P?ooooooooooo`0Z
ooooo`03o`000?oooooooooo07;ooooo001cooooo`03o`000?oooooooooo01Gooooo00?o0?n4oooo
ooooool05_ooool00oo8o`3oooooooooo`1Hooooo`;o00005_ooool00ol0olOoooooooooo`03oooo
o`03of?o0?oooooooooo00?ooooo00?oDol0ooooooooool00oooool00ol0o`Coooooooooo`06oooo
o`03o`20oooooooooooo03?ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Noooo
o`03o`3oQ?oooooooooo01Kooooo00?ob?l0ooooooooool0D?ooool2o`0001Kooooo00?o0?o7oooo
ooooool02Oooool00omSo`3oooooooooo`02ooooo`03oe?o0?l0o`Cooooo00;o0?mN3Oooool00ol0
P?ooooooooooo`0Yooooo`;o0000MOooool007Cooooo00?o0000ooooooooool05Oooool00ol0ohCo
ooooooooo`0Eooooo`03olSo0?oooooooooo04Wooooo0_l0000>ooooo`03og[o0?oooooooooo01?o
oooo00?o0?o7ooooooooool00oooool00omSo`3oooooooooo`03ooooo`03oe?o0?oooooooooo00?o
oooo00?o0?l4ooooooooool01_ooool00ol0P?ooooooooooo`0dooooo`03o`000?oooooooooo05?o
oooo00?o0000ooooooooool07_ooool00ol0ohCoooooooooo`0Eooooo`03olSo0?oooooooooo03oo
oooo0_l0000@ooooo`03og[o0?oooooooooo01Cooooo00?o0?o7ooooooooool01oooool2of?o00?o
oooo0_mCo`000ol0o`Coooooo`3oGP0>ooooo`03o`20oooooooooooo02Wooooo00?o0000oooooooo
ool0MOooool007Gooooo0_l0000Fooooo`03o`3oQ?oooooooooo01Cooooo00?ob?l0ooooooooool0
BOooool2o`0000oooooo00?oN_l0ooooooooool04_ooool00ol0olOoooooooooo`02ooooo`03of?o
0?oooooooooo00?ooooo00?oDol0ooooooooool00_ooool00ol0oeko0?l4ooooo`07ooooo`03o`20
oooooooooooo03Cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Oooooo`03o`3o
Q?oooooooooo01Cooooo00?ob?l0ooooooooool0?oooool2o`00017ooooo00?oN_l0ooooooooool0
4_ooool00ol0olOoooooooooo`07ooooo`03of?o0?oooooooooo00;ooooo00GoDol0ooooool0o`Co
ooooo`3oGP0>ooooo`03o`20oooooooooooo02Wooooo00?o0000ooooooooool0M_ooool007Oooooo
00?o0000ooooooooool05?ooool00ol0ohCoooooooooo`0Dooooo`03olSo0?oooooooooo04Oooooo
00?o01;oooooooooool04?ooool00omjo`3oooooooooo`0@ooooo`03o`3oaooooooooooo00;ooooo
00?oHol0ooooooooool00_ooool2oe?o00Cooooo00?o0?mNo`3o1?ooool01oooool00ol0P?oooooo
ooooo`0eooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool07oooool00ol0ohCooooo
ooooo`0Cooooo`03olSo0?oooooooooo03oooooo00?o01;oooooooooool04Oooool00omjo`3ooooo
ooooo`0@ooooo`03o`3oaooooooooooo00Oooooo00?oHol0ooooooooool00_ooool01OmCo`3o0?l4
o`3o1?oooooo0?mN00kooooo00?o083oooooooooool0:?ooool2o`0007Wooooo001hooooo`;o0000
5Oooool00ol0ohCoooooooooo`0Cooooo`03olSo0?oooooooooo01;ooooo00?o0?lcooooooooool0
<_ooool00ol04_ooooooooooo`0@ooooo`03og[o0?oooooooooo013ooooo00Go0?o7oooooooooooo
ooooof?o0004ooooo`03oe?o0?oooooooooo00?ooooo0_l0o`@9ooooo`03o`20oooooooooooo03Co
oooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Nooooo`03o`3oQ?oooooooooo01?o
oooo00?ob?l0ooooooooool0?oooool00ol04_ooooooooooo`0Aooooo`03og[o0?oooooooooo013o
oooo00?o0?o7ooooooooool01_ooool00omSo`3oooooooooo`02ooooo`03oe?o0?l0o`Cooooo00;o
0?mN3_ooool00ol0P?ooooooooooo`0Xooooo`03o`000?oooooooooo07Wooooo001jooooo`03o`00
0?oooooooooo01?ooooo00?o0?n4ooooooooool04_ooool00oo8o`3oooooooooo`0Booooo`03o`3o
<ooooooooooo037ooooo00?o01;oooooooooool04_ooool00omjo`3oooooooooo`0>ooooo`05o`3o
aooooooooooooooooomSo`001?ooool00omCo`3oooooooooo`03ooooo`03o`3o1?oooooooooo00Go
oooo0ol000000ol0P?oo0000o`00000eo`0005_ooooo7?l000000oo5o`3o0000o`000002o`000003
o`3oQ?l0003o000001;o000000?ob?l0o`000?l00000?Ol000000ooooooo01;oooooo`0Dooooo`03
og[o0?oooooooooo00kooooo00?o0?o7ooooooooool01_ooool01?mSo`3oooooooooooooool2oe?o
0003o`3o1?oooooo0?mN00oooooo00?o083oooooooooool03_ooool2o`1DoaSooooo00?o0000oooo
ooooool0N_ooool007_ooooo00?o0000ooooooooool04_ooool00ol0ohCoooooooooo`04ooooo`03
o`000?o5o`3ooooo00_ooooo00?ob?l0ooooooooool03_ooool4o`000003o`3o<ol0003o0000037o
000000?o01;oo`000?l000004ol000000omjo`3o0000o`00000=o`000004o`3oaol0003o0000of?o
00Co000000?oDol0o`000?l000000_l000000ol0oeko0?l4o`000007o`0000;ooooo00?o083ooooo
ooooool0=Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01Wooooo00?oaOl0o`00
0?ooool00oooool01?l0ohCoooooooooooooool2o`0000kooooo00?ob?l0ooooooooool0?Oooool0
0ol0003o01;oo`00000Do`000003og[o0?l0003o000000ko000000?o0?o7o`000?l000001?l00002
of?o00?o000000GoDol0o`000?l0o`Co0000o`3oGP0?o`000003o`20ool0003o000000go00000_l0
E?lJo`0007gooooo001loooooaGo000000?o0?n4o`000?l000001?l000000oo5o`3o0000o`00000;
o`000003olSo0?l0003o000000go00001?ooool00ol0oc?oooooooooo`0`ooooo`03o`0Boooooooo
oooo01Cooooo00?oN_l0ooooooooool03?ooool01?l0olOoooooof?o0?mSo`04ooooo`03oe?o0?oo
oooooooo00;ooooo00?o0?mNo`3o1?ooool02Oooool00ol0P?ooooooooooo`0eooooo`;o0000Fooo
ool2o`0001[ooooo00?oaOl0ooooooooool01?ooool01?l0ohCoooooooooool0ol`?ooooo`03olSo
0?oooooooooo01?ooooo00?o0?lcooooooooool09oooool00ol04_ooooooooooo`0Eooooo`03og[o
0?oooooooooo00cooooo00?o0?o7ooooooooool01?ooool00omSo`3oooooooooo`02ooooo`03oe?o
0?oooooo0?l400;o0?mN3oooool00ol0P?ooooooooooo`0<ooooo`;o05Co6Oooool00ol0003ooooo
o`00001mooooo`00O?ooool00ol0003oooooo`00000Cooooo`03o`3oQ?oooooooooo00?ooooo00?o
aOl0ooooooooool01_ooool2o`0000?ooooo00?ob?l0ooooooooool04_ooool00ol0oc?ooooooooo
o`0_ooooo`03o`0Boooooooooooo01Gooooo00?oN_l0ooooooooool02oooool00ol0olOoHol0oooo
o`04ooooo`03oe?o0?oooooooooo00;ooooo00?o0?mNo`3o1?ooool02Oooool00ol0P?oooooooooo
o`09ooooo`;o05Co:_ooool00ol0003oooooo`00001Kooooo`03o`000?oooooo000001[ooooo00?o
aOl0ooooooooool00oooool01?l0ohCoooooooooool0ol`?ooooo`03olSo0?oooooooooo01?ooooo
00?o0?lcooooooooool03oooool2o`0001Gooooo00?o01;oooooooooool05oooool00omjo`3ooooo
ooooo`0;ooooo`03o`3oaooooooooooo00?ooooo00CoHol0oooooooooooooooo0_mCo`02o`3o1003
o`3oG_oooooooooo00kooooo00?o083oooooooooool02oooool2o`1DoaWooooo0_l00002ooooo`03
o`000?oooooooooo07_ooooo001looooo`03o`000?oooooooooo00;o00004_ooool00ol0ohCooooo
ooooo`03ooooo`03olGo0?oooooooooo00Kooooo00Go0?o<ooooooooooooooooolSo000Dooooo`03
o`3o<ooooooooooo01cooooo0_l0000@ooooo`03o`0Boooooooooooo01Oooooo00?oN_l0oooooooo
ool02Oooool00ol0olOoHol0ooooo`03ooooo`;oDol01?ooool00ol0oeko0?l4ooooo`09ooooo`03
o`20oooooooooooo00Sooooo0_l0E?l/ooooo`03o`000?oooooo000005_ooooo00Co0000oooooooo
oooo00006Oooool00oo5o`3oooooooooo`04ooooo`03o`3oQ?oooooo0?o<013ooooo00?ob?l0oooo
ooooool04_ooool00ol0oc?oooooooooo`0?ooooo`;o00005Oooool00ol04_ooooooooooo`0Goooo
o`03og[o0?oooooooooo00[ooooo00?o0?o7ooooooooool00oooool02OmSo`3ooooooooooooooooo
Dol0ooooool0o`Coooooo`3oGP0@ooooo`03o`20oooooooooooo00[ooooo0_l0E?lJooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0Noooool007cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0@ooooo`03o`3oQ?oooooooooo00;ooooo00?oaOl0ooooooooool01_oo
ool01Ol0olcooooooooooooooooob?l001Cooooo00?o0?lcooooooooool07?ooool2o`00013ooooo
00?o01;oooooooooool01_ooool01?o2o`3oooooo`000?l0C_l=ooooo`03og[o0?oooooooooo00Wo
oooo00?o0?o7ooooooooool00_ooool00omCo`3oooooooooo`03ooooo`03o`3oG_l0o`Cooooo00[o
oooo00?o083oooooooooool01oooool00ol0E?ooooooooooo`0[ooooo`04o`000?ooooooooooo`00
05_ooooo00Go0000ooooooooooooooooo`00000Hooooo`03olGo0?oooooooooo00Gooooo00?o0?n4
o`3oc?ooool03oooool00oo8o`3oooooooooo`0Booooo`03o`3o<ooooooooooo00oooooo00?oood0
ooooooooool04oooool00ol04_ooooooooooo`03ooooo`03o`1>ool0003ooooo00[ooooo00?o`_l0
ooooooooool01_ooool00omjo`3oooooooooo`08ooooo`03o`3oaooooooooooo00;ooooo0_mSo`03
ooooo`05oe?o0?oooooo0?l4ooooool0oeh04?ooool00ol0P?ooooooooooo`09ooooo`;o05Co6ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07_ooooo001looooo`03o`000?oooooo
oooo00?ooooo0_l0000Aooooo`05o`3oQ?ooooooooooooooooo5o`002?ooool00ol0olcooooooooo
o`02ooooo`03olSo0?oooooooooo017ooooo00?o0?lcooooooooool07Oooool00oooo@3ooooooooo
o`0=ooooo`03o`0Boooooooooooo00Oooooo00Co`_l0ooooool0003o04ko3_ooool00omjo`3ooooo
ooooo`07ooooo`03o`3oaooooooooooo00;ooooo00?oDol0ooooooooool00_ooool00ol0oeko0?l4
o`3o100;ooooo`03o`20oooooooooooo00Kooooo0_l0E?l]ooooo`05o`000?ooooooooooooooool0
0000Foooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00?oaOl0oooooooo
ool01_ooool00ol0ohCoooooooooo`0>ooooo`03olSo0?oooooooooo01;ooooo00?o0?lcoooooooo
ool03oooool00oooo@3oooooooooo`0Cooooo`03o`0Boooooooooooo00?ooooo00?o04koo`000?oo
ool02_ooool00oo2o`3oooooooooo`06ooooo`03og[o0?oooooooooo00Sooooo00Go0?o7oooooooo
ooooooooof?o0004ooooo`03oe?o0?oooooo0?l400;o0?mN4?ooool00ol0P?ooooooooooo`08oooo
o`;o05Co6oooool2o`0000Kooooo00?o0000ooooooooool0Noooool007cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0>ooooo`05o`3oQ?ooooooooooooooooo5o`002?ooool00ol0
olcoooooooooo`02ooooo`03olSo0?oooooooooo017ooooo00?o0?lcooooooooool07Oooool00ooo
o@3oooooooooo`0=ooooo`03o`0Boooooooooooo00Oooooo00Go`_l0ooooooooooooooooo`1>o`0>
ooooo`03og[o0?oooooooooo00Gooooo00?oHol0o`3oaoooool00_ooool00omCo`3oooooooooo`02
ooooo`03o`3oG_l0o`Cooooo00_ooooo00?o083oooooooooool01Oooool2o`1Dobkooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool05Oooool00oo5o`3oooooooooo`05ooooo`03o`3oQ?oooooooooo00kooooo00?ob?l0
ooooooooool04_ooool00ol0oc?oooooooooo`0?ooooo`03ooom0?oooooooooo01;ooooo00?o01;o
ooooooooool01Oooool00ol0C_ooooooooooo`09ooooo`03ol;o0?oooooooooo00Oooooo00?oN_l0
ooooooooool01_ooool01Ol0olOoooooooooooooooooHol000?ooooo0_mCo`000ooooooo0?l4o`3o
GP0Aooooo`03o`20oooooooooooo00Oooooo0_l0E?lLooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0Noooool007cooooo00?o0000ooooooooool01_ooool2o`0000oooooo00Co0?n4
ooooooooooooaOl02?ooool00ol0olcoooooooooo`02ooooo`03olSo0?oooooooooo017ooooo00?o
0?lcooooooooool07Oooool00oooo@3oooooooooo`0<ooooo`03o`0Boooooooooooo00Sooooo00?o
`_l0ooooooooool00_ooool00ol0C_ooooooooooo`0;ooooo`03og[o0?oooooooooo00Cooooo00?o
Hol0o`3oaoooool00_ooool00omCo`3oooooooooo`02ooooo`03o`3oG_l0o`Cooooo00_ooooo00?o
083oooooooooool01?ooool2o`1Doc3ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00oo5o`3ooooooooo
o`05ooooo`03o`3oc?l0ohCooooo00kooooo00?ob?l0ooooooooool04_ooool00ol0oc?ooooooooo
o`0?ooooo`03ooom0?oooooooooo01;ooooo00?o01;oooooooooool01_ooool00ol0C_oooooooooo
o`08ooooo`03ol;o0?oooooooooo00Sooooo00?oN_l0ooooooooool01Oooool01?l0olOooooooooo
oomSo`03ooooo`05oe?o0?oooooo0?l4o`3o1?l0oeh04Oooool00ol0P?ooooooooooo`06ooooo`;o
05Co7?ooool2o`0000Wooooo00?o0000ooooooooool0Noooool007cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0=ooooo`04o`3oQ?ooooooooooolGo00Oooooo00?o0?o<oooooooo
ool00_ooool00oo8o`3oooooooooo`0Booooo`03o`3o<ooooooooooo01cooooo00?oood0oooooooo
ool03?ooool00ol04_ooooooooooo`08ooooo`03ol;o0?oooooooooo00?ooooo00?o04kooooooooo
ool02oooool00omjo`3oooooooooo`02ooooo`03of?o0?oooooo0?o700;ooooo00?oDol0oooooooo
ool00_ooool00ol0oeko0?l4ooooo`0;ooooo`03o`20oooooooooooo00Cooooo00?o05Cooooooooo
ool0;oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Cooooo`03olGo0?oooooooooo00Gooooo00?o0?o<ooooool0
oh@03_ooool00oo8o`3oooooooooo`0Booooo`03o`3o<ooooooooooo00oooooo00?oood0oooooooo
ool04Oooool00ol04_ooooooooooo`08ooooo`03o`1>oooooooooooo00Oooooo00?o`_l0oooooooo
ool02?ooool00omjo`3oooooooooo`04ooooo`04o`3oaoooooooooooof?o00?ooooo00?oDol0oooo
ool0o`@00_l0oehAooooo`03o`20oooooooooooo00Gooooo0_l0E?lMooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0Noooool007cooooo00?o0000ooooooooool02Oooool2o`0000ko
oooo00?o0?n4ooooooo5o`001oooool00ol0olcoooooooooo`03ooooo`03olSo0?oooooooooo017o
oooo00?o0?lcooooooooool07?ooool00oooo@3oooooooooo`0<ooooo`03o`0Boooooooooooo00So
oooo00?o`_l0ooooooooool01?ooool00ol0C_ooooooooooo`0;ooooo`07og[o0?ooooooHol0of?o
0?oooooo0?o7ooooo`02oe?o00?ooooo0_l0oeh00ol0o`Coooooooooo`0:ooooo`04o`20oooooooo
ooooooooo`;o00000_l0E?l00ooJo`3o0000o`00000_o`0000Kooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooooooo`06oooooaGo000000?oaOl0o`000?l000001Ol000001?l0olco0000o`00
0?l0oh@=o`000003olSo0?l0003o000001;o000000?o0?lco`000?l000003ol000000oooo@3o0000
o`00000Ao`000003o`0Boooooooooooo00Wooooo00?o04koooooooooool01_ooool00oo2o`3ooooo
ooooo`09ooooo`03og[o0?oooooooooo00?ooooo00?o0?o7of?o0?mSo`000oooool01?mCo`3ooooo
o`3o1?l0oeh8ooooo`03o`000?oJo`3ooooo00Oooooo00?o083oooooooooool01?ooool2o`1Doako
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1kooooo`00O?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0?n4olGo0?ooool01_ooool00ol0olcooooo
ooooo`03ooooo`03olSo0?oooooooooo017ooooo00Co0?lcoooooooooooooooo3ol000000ol07ooo
0000o`000009o`000003ooom0?l0003o000000_o000000?o01;oo`000?l000002Ol000000oo2o`3o
0000o`000005o`000003o`1>ool0003o000000[o000000?oN_l0of?o0?l000000_l000000ol0olOo
Dol0o`000003o`000003o`3oG_l0003o0?l400go000000Co083oo`000?l0003o00000_l0E?l00ooo
oooo0000om[o000`ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo0_l0001F
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool01Ol0003oa?l0oooooooo
ooooaOl000Kooooo00Co0?o<oooooooooooo0?n43Oooool00oo8o`3oooooooooo`0Booooo`03o`3o
<ol0003o01oo00oooooo00?oood0ooooooooool04?ooool00ol04_ooooooo`00000;o`000003o`1>
ool0003o000000Co000000?o`_l0o`000?l000002_l000000omjo`3o0000o`000002o`000003o`3o
aomSo`3o000000;o00000_mCo`000ol0003o0?l4o`3oGP0:o`000003om[o0?l0003o000000Go0000
00?o083oo`000?l000001?l000000ol0E?oo0000o`00000No`0000gooooo00?o0000ooooooooool0
Noooool007cooooo00?o0000ooooooooool03?ooool?o`000003o`3oQ?l0003o000000Go000000?o
0?o<o`000?l000000ol000000oo8o`3o0000o`00000Ao`000004o`3o<ol0003o0000o`0000kooooo
00?o0000o`0Oooooool02_ooool00oooo@3oooooooooo`0;ooooo`03o`0Boooooooooooo00Wooooo
00?o`_l0ooooooooool01_ooool00ol0C_ooooooooooo`09ooooo`06of?o0?mjo`3oooooooooool0
olOoDol01?ooool00ol0oeko0?l4o`3o100=ooooo`03o`20oooooooooooo00;o05Co0oooool00ooJ
o`3oooooooooo`0Jooooo`03olSo0?l0003ooooo01;ooooo00?o0000ooooooooool01?ooool01?l0
003o09Goo`2Eool0UOl2o`0005Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?
ooooo`05o`000?o4o`3oooooooooooo5o`001_ooool01Ol0olcooooooooooooooooo0?n400cooooo
00?ob?l0ooooooooool04_ooool00ol0oc?oooooo`0Oo`0?ooooo`03ooom0?oooooooooo00oooooo
00?o01;oooooooooool03Oooool00ol0C_ooooooooooo`03ooooo`03ol;o0?oooooooooo00_ooooo
00GoN_l0oooooooooooo0?o7of?o0003ooooo`05oe?o0?ooooooooooo`3o1?l0oeh02_ooool00ooJ
o`3oooooooooo`05ooooo`03o`20oooooooooooo00?ooooo0_l0E?lPooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01_ooool2o`0007?ooooo001looooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02Oooool01?o4o`3o0000ooooool0oh@7ooooo`03o`3oc?oooooooooo
00?ooooo00?ob?l0ooooooooool04Oooool00ol0oc?oooooooooo`0@ooooo`03o`0Ooooooooooooo
00Wooooo00?oood0ooooooooool02_ooool00ol04_ooooooooooo`0:ooooo`03ol;o0?oooooooooo
00Oooooo00?o04koooooooooool01oooool01_mSo`3ooooooooooomjo`3oooooo`3oa`Cooooo00?o
0?mNo`3o1?ooool03Oooool01?l0P?ooooooo`1Dool0E?l5ooooo`03om[o0?oooooooooo01[ooooo
00?ob?l0o`000?ooool04_ooool00ol0003oooooooooo`03ooooo`;o09GoFoooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo013ooooo00Coa?l0ooooooooooooaOl01_ooool00ol0olco
ooooooooo`02ooooo`03o`3oQ?oooooooooo00Wooooo00?ob?l0ooooooooool04_ooool00ol0oc?o
ooooo`0Oo`0?ooooo`03ooom0?oooooooooo00oooooo00?o01;oooooooooool03_ooool00ol0C_oo
ooooooooo`02ooooo`03ol;o0?oooooooooo00cooooo00?oN_l0oooooomSo`000oooool01OmCo`3o
ooooo`3o1?l0o`Co0?mN00_ooooo00?of_l0ooooooooool01?ooool00ol0P?ooooooooooo`02oooo
o`;o05Co5Oooool00oo8o`3o0000ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool00oooool3o`2Eo`;o0000Loooool007cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`09ooooo`05olCo0?ooooooooooooooool0oh@01_ooool00ol0olcoooooooooo`04oooo
o`03olSo0?oooooooooo013ooooo00?o0?lcooooooooool04?ooool00ol07oooooooooooo`09oooo
o`03ooom0?oooooooooo00[ooooo00?o01;oooooooooool02_ooool00oo2o`3oooooooooo`08oooo
o`03o`1>oooooooooooo00Gooooo00KoHol0ooooooooooooooooog[o0?l0olL3ooooo`;o0?mN00?o
0?l4ooooooooool03?ooool00ol0P?ooooooo`1Do`06ooooo`03om[o0?oooooooooo01_ooooo00?o
b?l0ooooooooool04_ooool00ol0003oooooooooo`03o`2Eo`03ooooool0003ooooo05[ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03olCo0?ooooooaOl000Kooooo00?o
0?o<ooooooooool00oooool00ol0ohCoooooooooo`08ooooo`03olSo0?oooooooooo01;ooooo00Co
0?lcoooooooooooo01oo3_ooool00oooo@3oooooooooo`0>ooooo`03o`0Boooooooooooo013ooooo
00Go04kooooooooooooooooool;o000>ooooo`03og[o0?mSo`3ooooo00;ooooo00CoDol0ooooool0
o`Co0?mN3Oooool00ooJo`3oooooooooo`03ooooo`04o`20ooooooooooooooooo`;o05Co5oooool0
0oo8o`3o0000ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00ol0UOmh
ooooo`00O?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Koa?l0oooo
ooooooooooooolGo0?l0oh@5ooooo`03o`3oc?oooooooooo00Cooooo00?ob?l0ooooooooool04Ooo
ool00ol0oc?oooooooooo`0@ooooo`03o`0Ooooooooooooo00Sooooo00?oood0ooooooooool02Ooo
ool00ol04_ooooooooooo`0;ooooo`03ol;o0?oooooooooo00Wooooo00?o04koooooooooool00ooo
ool00omSo`3oooooooooo`02ooooo`07oe?o0?l0olOoooooooooool0oekoooooo`3o100>ooooo`03
o`20ool0E?oo05Co00Oooooo00?of_l0ooooooooool06_ooool00oo8o`3oooooooooo`0Cooooo`03
o`000?l0UOoo09Go00Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo017ooooo00?oa?l0ooooooo5o`001_ooool00ol0olcoooooooooo`03ooooo`03
o`3oQ?oooooooooo00Sooooo00?ob?l0ooooooooool04_ooool01?l0oc?oooooooooool07ol>oooo
o`03ooom0?oooooooooo00kooooo00?o01;oooooooooool04Oooool01?l0C_ooooooooooooo2o`0=
ooooo`;oHol000Oo0?o7oooooomCo`3oDol0ooooool0o`Co0?mN00gooooo00?of_l0ooooooooool0
0oooool00ol0P?ooooooooooo`02o`1DoaWooooo00?ob?l0ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?l0UOoo09Go07_ooooo001looooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02_ooool01_o4o`3oooooooooooo5o`3oooooo`3oQ0Cooooo00?o0?o<oooooooo
ool01?ooool00oo8o`3oooooooooo`0Aooooo`03o`3o<ooooooooooo013ooooo00?o01oooooooooo
ool02?ooool00oooo@3oooooooooo`09ooooo`03o`0Boooooooooooo00_ooooo00?o`_l0oooooooo
ool02_ooool01Ol0C_ooooooooooooooooooHol000?ooooo0_mCo`001_l0olOoooooog[o0?l0oeko
ooooo`3o10kooooo00?o083oo`1Dooooool01oooool00ooJo`3oooooooooo`0Kooooo`03olSo0?oo
oooooooo017ooooo0ol0UOl6ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Aooooo`04olCo0?ooooooooooolGo00Kooooo00?o0?o<ooooooooool0
0oooool00ol0ohCoooooooooo`07ooooo`03olSo0?oooooooooo01;ooooo00Co0?lcoooooooooooo
01oo3oooool00oooo@3oooooooooo`0<ooooo`03o`0Boooooooooooo01?ooooo00?o04koooooooo2
o`003?ooool01OmSo`3oooooo`3oaomjo`3oDol000;ooooo00?o0?l4o`3oG_ooool03Oooool00ooJ
o`3oooooooooo`02ooooo`04o`20oooooooo05Coo`1Doa[ooooo00?ob?l0ooooooooool02oooool0
0ol0003oooooooooo`09ooooo`?o09GoOOooool007cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0:ooooo`04olCo0?ooooooooooolGo00;ooooo00?o0?n4ooooooooool00_ooool0
0ol0olcoooooooooo`03ooooo`03olSo0?oooooooooo017ooooo00?o0?lcooooooooool04?ooool0
0ol07oooooooooooo`08ooooo`03ooom0?oooooooooo00Sooooo00?o01;oooooooooool03?ooool0
0oo2o`3oooooooooo`0;ooooo`03o`1>ooooooooHol000?ooooo00SoDol0oooooooooooo0?o7oooo
ool0oekoooooo`3o10gooooo0_l0E?l00ol0P?ooooooooooo`07ooooo`03om[o0?oooooooooo01_o
oooo00?ob?l0ooooooooool03oooool2o`2Eo`;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool01?o4o`3o
ooooooooooo5o`06ooooo`03o`3oc?oooooooooo00Cooooo00?o0?n4ooooooooool01_ooool00oo8
o`3oooooooooo`0Booooo`04o`3o<oooooooooooo`0Oo`oooooo00?oood0ooooooooool03?ooool0
0ol04_ooooooooooo`0Dooooo`03o`1>ooo2o`3ooooo00[ooooo00SoHol0oooooooooooo0?o7oe?o
0?mjo`3oooooo`3o113ooooo00?of_l0ooooooooool00_ooool00ol0P?oo05Coooooo`0Kooooo`03
olSo0?oooooooooo00_ooooo00?o0000ooooooooool01oooool2o`2Eo`;ooooo00?o0000oooooooo
ool0Noooool007cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`05olCo
0?ooooooooooooooooo5o`000_ooool01Ol0ohCooooooooooooooooo0?o<00Kooooo00?ob?l0oooo
ooooool04?ooool00ol0oc?oooooooooo`0@ooooo`03o`0Ooooooooooooo00Sooooo00?oood0oooo
ooooool02?ooool00ol04_ooooooooooo`0<ooooo`03ol;o0?oooooooooo00_ooooo0_mSo`03oooo
o`08oe?o0?ooooooooooo`3oaooooooo0?mNooooool0o`@=ooooo`03o`1Doooooooo083o00Wooooo
00?of_l0ooooooooool07?ooool00oo8o`3oooooooooo`0<ooooo`?o09Go1?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Booooo`03olCo0?ooooooaOl000Kooooo00?o0?o<ooooooooool01Oooool00ol0ohCooooo
ooooo`05ooooo`03olSo0?oooooooooo01;ooooo00Co0?lcoooooooooooo01oo3oooool00oooo@3o
ooooooooo`0;ooooo`03o`0Boooooooooooo01Kooooo00?o`_l0ooooooooool02?ooool01_mSo`3o
ooooooooool0olOoDol0ooooo`;o0?l44?ooool01_oJo`3ooooooooooooooooo05Coo`20oakooooo
00?ob?l0ooooooooool02oooool00ol0003oooooooooo`04ooooo`?o09Go1?ooool00ol0003ooooo
ooooo`1kooooo`00O?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00Go
a?l0ooooooooooooooooolGo0002ooooo`05o`3oQ?ooooooooooooooool0ol`01_ooool00oo8o`3o
ooooooooo`0@ooooo`03o`3o<ooooooooooo013ooooo00?o01ooooooooooool02?ooool00oooo@3o
ooooooooo`07ooooo`03o`0Boooooooooooo00gooooo00?o`_l0ooooooooool02_ooool01_mSo`3o
ooooooooool0C_oooooooe?o00?ooooo0_l0oeh2o`3o1003oooooomjo`3ooooo00Wooooo0_l0E?l0
0ooooooo083oooooo`09ooooo`03om[o0?oooooooooo01_ooooo00?ob?l0ooooooooool02_ooool3
o`2Eo`Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool04_ooool00oo4o`3oooooolGo0006ooooo`03o`3oc?oooooo
oooo00Gooooo00?o0?n4ooooooooool01Oooool00oo8o`3oooooooooo`0Booooo`05o`3o<ooooooo
ooooooooool07ol03_ooool00oooo@3oooooooooo`0;ooooo`03o`0Boooooooooooo01Kooooo00?o
`_l0o`1>ooooool01_ooool2of?o00;ooooo0_mCo`001?oooooo0?l4o`3oG_mjo`0@ooooo`05om[o
0?oooooo05Coo`1Dool0P?l07oooool00oo8o`3oooooooooo`0;ooooo`04o`000?oooooooooooooo
o`?o09Go1oooool00ol0003oooooooooo`1kooooo`00O?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00[ooooo00Goa?l0ooooooooooooooooolGo0003ooooo`04o`3oQ?oooooooooo
o`3oc0Kooooo00?ob?l0ooooooooool04?ooool00ol0oc?oooooooooo`0@ooooo`03o`0Ooooooooo
oooo00Sooooo00?oood0ooooooooool01oooool00ol04_ooooooooooo`0=ooooo`03ol;o0?oooooo
oooo00Wooooo00KoHol0ooooooooooooooooo`1>oomCo`03ooooo`03o`3oG_oooooo0?l400?ooooo
00?oN_l0ooooooooool01_ooool2o`1Do`;ooooo00?o083oooooooooool02?ooool00ooJo`3ooooo
ooooo`0Looooo`03olSo0?oooooooooo00Sooooo0_l0UOl:ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo
00Coa?l0ooooooooooooaOl01Oooool00ol0olcoooooooooo`06ooooo`03o`3oQ?oooooooooo00Co
oooo00?ob?l0ooooooooool04_ooool01Ol0oc?ooooooooooooooooo01oo00kooooo00?oood0oooo
ooooool02_ooool00ol04_ooooooooooo`0Gooooo`03ol;o0?oooooo04ko00Gooooo00WoHol0oooo
oooooooooooooe?o0?l0olOoooooo`3o1?l0oeh00_ooool00omjo`3oooooooooo`0=ooooo`;o05Co
00?oooooo`20ooooool07_ooool00oo8o`3oooooooooo`0<ooooo`04o`000?oooooo09Goo`2Eo`[o
oooo00?o0000ooooooooool0Noooool007cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0;ooooo`04olCo0?ooooooooooolGo00Cooooo00?o0?n4ooooool0ol`01_ooool00oo8o`3o
ooooooooo`0@ooooo`03o`3o<ooooooooooo013ooooo00?o01ooooooooooool02Oooool00oooo@3o
ooooooooo`05ooooo`03o`0Boooooooooooo00kooooo00?o`_l0ooooooooool02?ooool01?mSo`3o
ooooooooooooool2oe?o0006o`1>ooooooooooooo`3oG_l0olOo0?l41Oooool00omjo`3ooooooooo
o`03ooooo`;o05Co0oooool00ol0P?ooooooooooo`09ooooo`03om[o0?oooooooooo01cooooo00?o
b?l0ooooooooool01Oooool3o`2Eo`cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool01?o4o`3ooooooooo
ooo5o`05ooooo`03o`3oc?oooooooooo00Oooooo00?o0?n4ooooooooool01?ooool00oo8o`3ooooo
ooooo`0Aooooo`05o`3o<oooooooooooooooool07ol03_ooool00oooo@3oooooooooo`09ooooo`03
o`0Boooooooooooo01Oooooo00Go`_l0ooooooooooooooooo`1>o`03ooooo`08of?o0?oooooooooo
oooooomCo`3o0?o7ooooool0o`@4ooooo`03og[o0?oooooooooo00_ooooo0_l0E?l2ooooo`03o`20
oooooooooooo01kooooo00?ob?l0ooooooooool02oooool3o`2Eo`cooooo00?o0000ooooooooool0
Noooool007cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`04olCo0?oo
ooooooooolGo00Gooooo00?o0?n4o`3oc?ooool01_ooool00oo8o`3oooooooooo`0@ooooo`03o`3o
<ooooooooooo013ooooo00?o01ooooooooooool02?ooool00oooo@3oooooooooo`05ooooo`03o`0B
oooooooooooo00kooooo00?o`_l0o`000?ooool01oooool01OmSo`3oooooooooooooooooDol000?o
oooo00Co04koo`3oG_l0olOo0?l41oooool01Omjo`3ooooooooooooooooo05Co00Cooooo00?o083o
ooooooooool02_ooool00ooJo`3oooooooooo`0Looooo`03olSo0?oooooooooo00?ooooo0_l0UOl?
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01;ooooo00Coa?l0ooooooooooooaOl01Oooool00ol0olcooooooooo
o`08ooooo`03o`3oQ?oooooooooo00?ooooo00?ob?l0ooooooooool04_ooool01?l0oc?ooooooooo
ool07ol>ooooo`03ooom0?oooooooooo00Wooooo00?o01;oooooooooool01_ooool00ol0003o0?m1
ooooo`0>ooooo`03ol;o0?oooooooooo00;ooooo00?o04kooooooomSo`000oooool01?mCo`3ooooo
o`3oaol0o`@6ooooo`03og[o0?oooooooooo00Sooooo0_l0E?l01?oooooof_l0ooooool0P?lQoooo
o`03olSo0?oooooooooo00Sooooo0ol0UOl00ooooooo0000ooooo`0<ooooo`03o`000?oooooooooo
07_ooooo001looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool01Oo4o`3o
ooooooooooooooooaOl000Gooooo00?o0?n4ooooooooool01Oooool00oo8o`3oooooooooo`0@oooo
o`03o`3o<ooooooooooo013ooooo00?o01ooooooooooool02?ooool00oooo@3oooooooooo`04oooo
o`03o`0Boooooooooooo00oooooo00?o`_l0o`3o@Oooool01_ooool01OmSo`3ooooooooooooooooo
Dol000?ooooo0_l0oeh00ol0C_oo0?l4ooooo`07ooooo`04og[o0?oooooo05Coo`1Do`Gooooo00?o
083oooooooooool02Oooool00ooJo`3oooooooooo`0Looooo`04olSo0?ooooooooooooooo`?o09Go
4Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Cooooo`03olCo0?ooooooaOl000Gooooo00?o0?o<ooooooooool0
2?ooool00ol0ohCoooooooooo`03ooooo`03olSo0?oooooooooo01;ooooo00Co0?lcoooooooooooo
01oo3_ooool00oooo@3oooooooooo`08ooooo`03o`0Boooooooooooo00Oooooo00?o0000o`3o@Ooo
ool03_ooool00oo2o`3oooooooooo`03ooooo`03of?o0?oooooooooo00;oDol000?oooooo`3o1?l0
o`@02?ooool00omjo`3oooooooooo`05ooooo`;o05Co0oooool00ooJo`3o083oooooo`0Qooooo`03
olSo0?oooooooooo00Kooooo0_l0UOl4ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0Noooool007cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`05olCo
0?ooooooooooooooooo5o`001Oooool00ol0ohCoooooooooo`05ooooo`03olSo0?oooooooooo013o
oooo00?o0?lcooooooooool04?ooool00ol07oooooooooooo`08ooooo`03ooom0?oooooooooo00Co
oooo00?o01;oooooooooool03oooool00oo2o`3o0?m1ooooo`05ooooo`05of?o0?oooooooooooooo
oomCo`000oooool01Ol0oekoooooooooool0o`Co04ko00Sooooo0_l0E?l6ooooo`03o`20oooooooo
oooo00[ooooo00?of_l0ooooooooool04?ooool00ol0003o0?mLooooo`09ooooo`04olSo0?oooooo
09Goo`2EoaCooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool04oooool01?o4o`3oooooooooooo5o`04ooooo`03o`3o
c?oooooooooo00Wooooo00?o0?n4ooooooooool00_ooool00oo8o`3oooooooooo`0Booooo`05o`3o
<oooooooooooooooool07ol03Oooool00oooo@3oooooooooo`08ooooo`03o`0Boooooooooooo00Oo
oooo00?o0?m1ooooooooool03_ooool01?o2o`3oooooooooooooool2of?o0003ooooool0C_ooDol0
00;ooooo00?o0?l4o`3oaoooool02?ooool01_mjo`3oooooooooooooooooO_l0ooooo`;o05Co1?oo
ool00ooJo`3o083oooooo`0Rooooo`03olSo0?oooooooooo00?ooooo0ol0UOl6ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0Noooool007cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`04olCo0?ooooooooooolGo00Gooooo00?o0?o<o`3oQ?ooool01Ooo
ool00oo8o`3oooooooooo`0@ooooo`03o`3o<ooooooooooo013ooooo00?o01ooooooooooool02?oo
ool00oooo@3oooooooooo`03ooooo`03o`0Boooooooooooo013ooooo00?o`_l0ooooooooool01?oo
ool01OmSo`3oooooooooooooooooDol000?ooooo00Oo0?mNooooool0o`Co0?l4o`3oaooooooo04ko
00Gooooo0_l0E?l2ooooo`03og[o0?oooooooooo00;ooooo00?o083oooooooooool02_ooool00ooJ
o`3oooooooooo`0Aooooo`03o`000?l0oecooooo00Sooooo0ol0UOlFooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01?ooooo00Coa?l0ooooooooooooaOl01?ooool00ol0olcoooooooooo`0:ooooo`05o`3oQ?oooooo
ooooooooooo8o`005?ooool01Ol0oc?ooooooooooooooooo01oo00gooooo00?oood0ooooooooool0
1oooool00ol04_ooooooooooo`08ooooo`03o`3o@Ooooooooooo00kooooo00Co`_l0oooooooooooo
Hol00oooool01OmCo`3o04koooooool0o`Co0?o700_ooooo00GoN_l0ooooooooooooO_l0o`1Do`06
ooooo`03o`20oooooooooooo00oooooo00?o0000o`3oG?ooool03oooool00oo8o`3oooooooooo`02
ooooo`;o09Go2Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07_ooooo001loooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool01?o4o`3oooooooooooo5o`05
ooooo`03o`3oc?oooooo0?n400Kooooo00?ob?l0ooooooooool03oooool00ol0oc?oooooooooo`0@
ooooo`03o`0Ooooooooooooo00Sooooo00?oood0ooooooooool00oooool00ol04_ooooooooooo`0?
ooooo`03o`3o@Oo2o`3ooooo00?ooooo0_mSo`03ooooo`09oe?o0?ooooooooooooooool0oekooooo
o`3o1?oooooo0?o700?ooooo00Go04koooooooooooooooooo`1Do`04ooooo`05og[o0?oooooooooo
ooooool0P?l03Oooool00ooJo`3oooooooooo`0Aooooo`03o`3oG?oooooooooo00Kooooo0_l0UOl0
0ooooooob?l0ooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00Coa?l0ooooooooooooaOl01?oo
ool00ol0olcoooooooooo`0;ooooo`04o`3oQ?ooooooooooolSo01Cooooo00Go0?lcoooooooooooo
ooooo`0Oo`0=ooooo`03ooom0?oooooooooo00Oooooo00?o01;oooooooooool01oooool00ol0od7o
ooooooooo`0?ooooo`03ol;o0?ooooooHol000?ooooo00KoDol0oooooooooooo0?l4ooooool0olL;
ooooo`03og[o0?l0E?ooO_l000Oooooo00?o083oom[o0?ooool04?ooool00ol0003o0?mLooooo`0?
ooooo`03olSo0?oooooo09Go00;o09Go2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo07_ooooo001looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool01?o4
o`3oooooooooooo5o`05ooooo`04o`3oc?ooooooooooo`3oQ0Gooooo00?ob?l0ooooooooool03ooo
ool00ol0oc?oooooooooo`0@ooooo`03o`0Ooooooooooooo00Sooooo00?oood0ooooooooool00_oo
ool00ol04_ooooooooooo`0?ooooo`03o`3o@Ooooooo`_l000?ooooo00CoHol0oooooooooooooooo
0_mCo`03ooooo`03o`3oG_oooooo0?l400;ooooo00?o0?o7ooooooooool00_ooool00omno`3o05Co
o`1Do`06ooooo`03og[o0?oooooo083o00gooooo00?of_l0ooooooooool04Oooool00ol0oecooooo
ooooo`04ooooo`?o09Go0_ooool00oo8o`3oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo
00Oo0000olCo0?ooooooooooolCo0?ooooooaOl000Cooooo00?o0?o<ooooooooool03?ooool00ol0
ohCoooooolSo000Dooooo`05o`3o<oooooooooooooooool07ol03Oooool00oooo@3oooooooooo`06
ooooo`03o`0Boooooooooooo00Oooooo00?o0?m1ooooooooool04?ooool01?o2o`3oHol0oooooooo
ool2oe?o0007ooooool0oeko0?l4ooooool0olOoooooooln0009ooooo`;o05Co00?oO_l0oooooooo
ool01Oooool00ol0P?oof_l0ooooo`0Aooooo`03o`3oG?oooooooooo00kooooo0ol0UOl>ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0Noooool007cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`09ooooo`04o`000?o4o`3oooooolCo00?ooooo00?oaOl0oooooooo
ool00_ooool01Ol0olcooooooooooooooooo0?n400Cooooo00?ob?l0ooooooooool04?ooool00ol0
oc?oooooooooo`0?ooooo`03o`0Ooooooooooooo00Sooooo00?oood0ooooooooool00_ooool00ol0
4_ooooooooooo`0?ooooo`03o`3o@Ooooooo`_l000;ooooo00GoHol0oooooooooooooooooe?o0002
ooooo`05ooln0?l0oeko0?mNooooool0o`@00_ooool00ol0olOoooooooooo`02ooooo`03o`1Doomn
o`3o04ko00Sooooo00?o083oooooooooool03?ooool00ooJo`3oooooooooo`0Aooooo`05o`3oG?oo
oooo0000o`3oG_ooool00_l0UOl5ooooo`05olSo0?ooooooooooo`000?o1o`005?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0@ooooo`05o`000?o4o`3oooooooooooo4o`000_ooool01Oo5o`3o0?naoooooooooooo
0?o<00kooooo00?o0?n4ooooooo8o`005?ooool01Ol0oc?ooooooooooooooooo01oo00gooooo00?o
ood0ooooooooool01_ooool00ol04_ooooooooooo`07ooooo`03o`3o@Ooooooooooo013ooooo00Co
`_l0ooooooooooooDol00_ooool2o`3o1005ooooool0olOoooooo`1>oooo?P001oooool2o`1Do`;o
oooo00?oO_l0og[o0?ooool01?ooool00ol0P?ooooooom[o000Booooo`03o`3oG?oooooooooo00co
oooo0_l0UOl00ooooooob?l0ooooo`02o`0000cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`1kooooo`00O?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo
00Co0000olCo0?ooooooa?l00oooool00oo5o`3oooooooooo`02ooooo`06o`3oc?oooooo0000o`3o
/Ooooooo0?n40oooool00oo8o`3oooooooooo`0@ooooo`03o`3o<ooooooooooo013ooooo00?o01oo
ooooooooool01oooool01Oooo@3ooooooooooooooooo01;o017ooooo00Ko0?m1oooooooooooo`_l0
oooooomSo`03ooooo`05oe?o0?oooooooooooooooooo?P000_ooool01Ol0o`Cooooooooooooooooo
0?o700;ooooo0_l0E?l01?mno`3oooooooooool0C_l7ooooo`03o`20oooooooooooo00_ooooo00?o
f_l0ooooooooool04Oooool00ol0oecoooooooooo`03o`2Eo`Oooooo00Gob?l0oooooooooooo0000
ol7o000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo017ooooo00Coa?l0ooooooooooooa?l00_ooool01Oo5o`3o
0?naoooooooooooo0?o<00oooooo00?o0?n4olSo0?ooool04oooool00ol0oc?oooooooooo`02oooo
o`03o`0Ooooooooooooo00[ooooo00?oood0ooooooooool01Oooool00ol04_ooooooooooo`07oooo
o`03o`3o@Ooooooooooo00oooooo0_mSo`000oo2o`3ooooooe?o0002ooooo`05o`3o1?oooooooooo
ooooool0olL00_ooool01?oo?P3ooooooooooooo?P02ooooo`;o05Co0oooool00omno`3oooooog[o
0004ooooo`04o`20ooooooooooooom[o017ooooo00Co0?mLooooool0003o0?mN2Oooool3o`2Eo`;o
oooo00Gob?l0oooooooooooo0000ol7o000<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0Noooool007cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`04
olCo0?ooooooooooolCo00;ooooo00?oaOl0ooooooooool00_ooool01_l0olcoooooo`000?l0ok7o
ooooo`3oQ0?ooooo00?ob?l0ooooooooool04?ooool00ol0oc?oooooooooo`0@ooooo`03o`0Ooooo
oooooooo00Oooooo00Goood0ooooooooooooooooo`0Bo`0@ooooo`06o`3o@Oooooooooooooooooo2
o`3oHol00oooool02OmCo`3ooooooooooooooooo0?mNoooooooo?P3o0?l4ooln0002ooooo`04o`3o
aooooooo05Coo`1Do`;ooooo00GoO_l0ooooooooooooooooo`1>o`05ooooo`03o`20ooooooooN_l0
00cooooo00?of_l0ooooooooool04?ooool01Ol0oecoooooo`2Eool0UOoo0?mN00Wooooo00Gob?l0
oooooooooooooooool7o000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?oa?l0ooooooo4o`000_oo
ool01Oo5o`3oooooo`3o/Ooooooo0?o<013ooooo00?o0?n4ooooooooool04_ooool00ol0oc?ooooo
ooooo`02ooooo`03o`0Ooooooooooooo00[ooooo00?oood0ooooooooool01Oooool00ol04_oooooo
ooooo`07ooooo`03o`3o@Ooooooooooo00kooooo00?oHol0ooooooo2o`000_mCo`000ooooooo0?mN
o`3o1003ooooo`03o`3oaooooooooooo00;ooooo00?ooch0oooooooo?P000_l0E?l00ooo?@3ooooo
ooooo`02ooooo`04ogko0?nAo`3oooooog[o00;ooooo00Co083ooooooooooooof_l04Oooool01Ol0
oecoooooooooool0003o0?mN00Kooooo0ol0UOl5ooooo`05olSo0?ooooooooooooooooo1o`003?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07_ooooo001looooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00oo4o`3oooooolCo0002ooooo`03olGo0?oooooo
oooo00;ooooo00Oo0?o<ooooooooooooooooo`3o/Ooooooo0?n400?ooooo00?ob?l0ooooooooool0
3oooool00ol0oc?oooooooooo`0@ooooo`03o`0Ooooooooooooo00Oooooo00Coood0oooooooooooo
01;o4Oooool01Ol0od7ooooooooooooooooo`_l000?ooooo00GoDol0ooooooooooooooooo`3oGP02
ooooo`03ooln0?oooooooch000;ooooo00?o0?o7o`1Dooooool00_ooool00omno`3oooooooooo`03
ooooo`05o`1>ooooooooooooooooool0P?l00oooool00omjo`3oooooooooo`08ooooo`03om[o0?oo
oooooooo013ooooo0ol0UOl00ooooooo0?mNooooo`08ooooo`05olSo0?ooooooooooooooooo1o`00
5Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Booooo`06olCo0?ooooooooooolCo0?ooooooaOl00_ooool00ol0
ok7o0?o<ooooo`0?ooooo`03olSo0?l0ohCooooo01;ooooo00?o0?lcooooooooool00_ooool00ol0
7oooooooooooo`0:ooooo`03ooom0?oooooooooo00Cooooo00?o01;oooooooooool01oooool00ol0
od7oooooooooo`0>ooooo`04of?o0?oooooooooool;o00;ooooo00?o0?mNo`3o1?ooool00oooool0
0ol0olOoooooooooo`02ooooo`03ooln0?l0E?oooch000;ooooo00_oocd0ooooooooooooooooogko
0?ooooooTOl0oooooomjo`3oooooo`20o`03ooooo`03om[o0?oooooooooo00oooooo00Co0?mLoooo
oooooooo0?mN1Oooool2o`2Eo`Sooooo00Gob?l0oooooooooooooooool7o000<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool05_ooool00ol0VOoo0000o`00001Rooooo`00O?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?oa?l0ooooooo4o`000oooool0
1Oo5o`3ooooooooooooooooo0?o<00Cooooo00?o0?naooooool0oh@00_ooool00oo8o`3ooooooooo
o`0?ooooo`03o`3o<ooooooooooo013ooooo00?o01ooooooooooool01oooool01?ooo@3ooooooooo
ool04_l@ooooo`06o`3o@OoooooooooooooooomSo`3o`_l00_ooool00omCo`3oooooooooo`02o`3o
GP04ooooool0o`Co0?l4ooln00;ooooo00?ooch0o`1Doooo?@001?ooool00omno`3oooooooooo`04
ooooo`03o`1>oooooooo083o00Cooooo00?oN_l0ooooooooool02?ooool00ooJo`3oooooooooo`0>
ooooo`;o09Go00Go0?mLooooooooooooooooo`3oGP02ooooo`;o00001Oooool01Oo8o`3ooooooooo
oooooooo`Ol001Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04_ooool02_o4o`3oooooooooooo4o`3o0000o`3o
L?o5o`3oooooo`3o/Ol0ol`@ooooo`03olSo0?l0ohCooooo01;ooooo00?o0?lcooooooooool00_oo
ool00ol07oooooooooooo`0:ooooo`03ooom0?oooooooooo00?ooooo00?o01;oooooooooool02?oo
ool00ol0od7oooooooooo`0=ooooo`08of?o0?oooooooooooe?o0?o2o`3oooooo`3oG_l0o`@4oooo
o`03o`3oaooooooooooo00;ooooo00Oo05Coooln0?oooooo04koooln0?ooooooocd000;ooooo00?o
O_l0oooooonAo`000oooool00ol0P?ooooooooooo`02ooooo`03om[o0?oooooooooo00kooooo00Go
0?mLooooooooooooooooo`3oGP02ooooo`?o09Go2_ooool01?o8o`3oooooooooooo1o`0=ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool2o`2Io`03ooooool0003o000006;o
oooo001looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00oo4o`3ooooo
olCo0003ooooo`07olGo0?ooooooooooooooool0olco0000o`3oL002ooooo`06o`3o/Ooooooooooo
o`3oQ?oooooob?l04Oooool00ol0oc?oooooooooo`0@ooooo`03o`0Ooooooooooooo00Oooooo00?o
ood0ooooool04_l04?ooool01ol0od7oooooooooooooooooHol0ooooooo2o`000_mCo`02ooooo`04
o`3oG_ooooooooooo`3o10?ooooo00Gooch0o`1Doooo?P3o0?o7oolm0003ooooo`03ogko0?oooooo
oooo00Gooooo00?o04koo`20ooooool01Oooool00omjo`3oooooooooo`06ooooo`03om[o0?oooooo
oooo00cooooo0ol0UOl2ooooo`04o`3oG?ooooooooooo`3oGP?ooooo00?o0>7oo`000?ooool01?oo
ool01Oo8o`3ooooooooooooooooo`Ol001Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool01oo4o`3ooooo
ooooooo4o`3o0000o`3oL?o5o`000_ooool00ol0olcoooooooooo`0>ooooo`03olSo0?oooooo0?n4
01;ooooo00?o0?lcooooooooool00_ooool00ol07oooooooooooo`0:ooooo`03ooom0?oooooooooo
00?ooooo00?o01;oooooooooool01oooool00ol0od7oooooooooo`0<ooooo`;oHol00_ooool00omC
o`3ooooool;o0002o`3o10Gooooo00?o0?o7ooooooooool00_l0E?l2ooooo`03ooln0?oooooooch0
00;ooooo00Coocd0oooooomno`3oTOl00oooool00ol0P?ooooooog[o0002ooooo`03om[o0?oooooo
oooo00oooooo00Go0?mLoooooooooooo0?mNooooo`02o`2Eo`Sooooo00GoofD0oooooooooooooooo
olSo0003ooooo`03ol7o0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Booooo`;o09WoIoooool007cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`04olCo0?ooooooooooolCo00;ooooo00OoaOl0ooooooooooooooooo`3oc?l0003o0?m`
00?ooooo00Go0?naoooooooooooo0?n4olSo000Booooo`03o`3o<ooooooooooo00oooooo00?o01oo
ooooooooool01oooool00oooo@3oooooo`0Bo`0>ooooo`Co00000_mSo`000ol0003ooooool;o0003
ooooo`04o`3oG_ooooooooooo`3o10?ooooo00Co05Coooln0?oooooooch00_ooool01?oo?@3ooooo
ogko0?nAo`07ooooo`03o`20ool0C_oooooo00Kooooo00?oN_l0ooooooooool01Oooool00ooJo`3o
ooooooooo`0:ooooo`;o09Go1?ooool01Ol0oecooooooooooooooooo0?mN00?ooooo00?o0>7ooooo
ooooool01?ooool01Oo8o`3ooooooooooooooooo`Ol001Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04oooool0
0oo4o`3oooooolCo0002ooooo`05olGo0?ooooooooooo`3oc?l0ok403oooool01?o8o`3ooooooooo
ool0oh@Aooooo`03o`3o<ooooooooooo00?ooooo00?o01ooooooooooool02Oooool00oooo@3ooooo
ooooo`02ooooo`03o`0Boooooooooooo00Sooooo00?o0?m1ooooooooool01ol00004ooooo`03of?o
0?oooooooooo00;oDol000?oooooo`3oG_o2o`001_ooool01?l0olOoooooooooool0E?l4ooooo`0<
ooln0?oooooooch0o`1>ooooooooocd0ogko0?oo?@3oTOl0ooooooooF`3o083o0_ooool01?mjo`3o
oooooooooooJo`0@ooooo`03o`3oG?oooooooooo00?o09Go00?o0000o`3Qooooool01oooool01Ooo
I@3ooooooooooooooooob?l000?ooooo00?o`Ol0ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo013ooooo0_l0VOmYooooo`00Koooool2o`3oXP_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`04olCo0?ooooooooooolCo00;ooooo00GoaOl0
ooooooooooooooooo`3oc002ooooo`04o`3oL?ooooooooooo`3o/@?ooooo00?o0?n4olSo0?ooool0
4?ooool00ol0oc?oooooooooo`0?ooooo`03o`0Ooooooooooooo00Oooooo00?oood0ooooool04_l0
2Oooool6o`000003o`3o@OooooooHol000?ooooo00GoDol0ol;o0?l0003o0000o`3oGP02ooooo`05
o`3o1?ooooooooooooooool0E?l00_ooool02?oo?P3o0?o7ooln0?ooooooocd0oooooomno`3oocd0
0_ooool01OooF`3ooooooooooooooooo083o00;ooooo00?o04koooooooooool01?ooool00omjo`3o
ooooooooo`04ooooo`03om[o0?oooooooooo00Sooooo0ol0UOl5ooooo`05o`3oG?oooooooooooooo
ool0oeh00oooool00ol0hOooooooooooo`04ooooo`05olSo0?ooooooooooooooooo1o`005_ooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooooooo`;o09WoE_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01?ooooo00_oa?l0ooooooooooooa?l0ooooooo5o`3o0?m`oooo
ool0olcoooooo`3o/@0>ooooo`05olSo0?ooooooooooooooool0oh@04?ooool00ol0oc?ooooooooo
o`03ooooo`03o`0Ooooooooooooo00Wooooo00?oood0ooooooooool00_ooool00ol04_oooooooooo
o`06ooooo`Go00000oooool01?l0003oooooooooooooool3o`000004of?o0?l0003ooooooe?o00;o
oooo00?o0?mNo`3o1?o2o`001Oooool01?l0olOoooooo`1Dool0E?l5ooooo`0;ooln0?oooooooooo
ooln0?l0C_ooO_l0oooooonAo`3oocd0ooooool0P?l01?ooool00omjo`3oooooom[o000?ooooo`05
o`3oG?l0UOoo09Goo`2Eool0oeh00_ooool00ol0hOooooooooooo`06ooooo`03oomU0?oooooooooo
00;ooooo00GoofD0oooooooooooooooool7o000=ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03_ooool2o`2Io`;o09CoJOooool0077ooooo0_l0oj89ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00oo4o`3oooooolCo0002ooooo`05olGo0?oooooooooo
ooooool0ol`00oooool01?l0og3oooooooooool0ok42ooooo`03o`3oQ?o8o`3ooooo013ooooo00?o
0?lcooooooooool04?ooool00ol07oooooooooooo`06ooooo`03ooom0?l04_oooooo00Cooooo1_l0
0003ooooo`05o`000?l0og?oooooof?o0?l000000_ooool02?mCo`3ooooool;o0?oooooo0?mNoooo
ool0003o0?l40_l00002o`1Do`?ooooo00_ooch0oooooooo?P3ooooooolm0?mno`3oTOl0oooooooo
?@3ooooooomK0003ooooo`05o`20ooooooooooooooooool0C_l01_ooool00omjo`3oooooooooo`03
ooooo`03om[o0?oooooooooo00Gooooo0ol0UOl4ooooo`05oomU0?ooooooooooooooool0oe`00_oo
ool01Ol0oekooooooooooooooooo0>7o00Oooooo00Gob?l0oooooooooooooooool7o000Fooooo`03
o`000?oooooooooo00Cooooo00Co0000ooooool0VOoo09WoF?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01?ooooo00_oa?l0ooooooooooooa?l0ooooooo5o`3o0?m`ooooool0olco
ooooo`3o/@0>ooooo`05olSo0?l0?_ooooooooooool0oh@04?ooool00ol0oc?oooooooooo`03oooo
o`03o`0Ooooooooooooo00Wooooo00Goood0ooooooooooooooooo`0Bo`04ooooo`Go000000Go0?m1
ooooooooooooooooo`000002o`3oL`03ooooool0003ooooo00Cooooo00CoHol0ooooooooooooDol0
0_l000001?l0oeko0?l4ooooooo2o`05ooooo`;o05Co1oooool02ooo?P3ooooooooooooo?P3ooooo
ogko0?ooooooTOl0oolm0?l0P?oooe/000Cooooo00?oN_l0om[o0?ooool03_ooool2o`2Eo`;ooooo
00Go0?mNooooooooooooooooo`3Qo`07ooooo`03oomU0?oooooooooo00?ooooo00CoofD0oooooooo
oooo`Ol03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0ol0VOl2o`2D
of_ooooo001cooooo`;o0?nR1oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?oa?l0ooooooo4o`000oooool01?o5o`3oooooooooool0ol`3ooooo`05o`3oL?oooooooooo
ooooool0ok400_ooool00ol0ohCoooooooooo`09ooooo`03o`000?l0?_oooooo00?ooooo00?o0?lc
ooooooooool04?ooool00ol07oooooooooooo`06ooooo`03ooom0?l04_oo000000Ko00001oooool2
o`000005of?o0?oooooo0000oooooomCo`000_ooool01_o2o`3o0?mNoooooooooooo0?l4ooooo`;o
05Co00?oooooo`000?l000000_l000001_oo?P3o0000oooooooo?P3oooooogko00;ooooo00Koocd0
oooooooooooooe/0ooooool0P?l5ooooo`03o`1>oooooooooooo00?ooooo00?oN_l0ooooooooool0
0_ooool00ooJo`3oooooooooo`04ooooo`;o09Go1oooool01?ooI@3oooooooooool0oe`3ooooo`05
o`3oG_ooooooooooooooool0hOl01oooool01Oo8o`3ooooooooooooooooo`Ol001Kooooo00?o0000
ooooooooool01?ooool2o`2Ioe[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0C
ooooo`04olCo0?ooooooooooolCo00;ooooo00?oaOl0o`3oL?l0ol`00_ooool00ol0ok7ooooooooo
o`0;ooooo`03olSo0?l0?_oooooo00;ooooo00?o0?n4ooooooooool03Oooool00ol0oc?ooooooooo
o`03ooooo`03o`0Ooooooooooooo00Wooooo00Goood0ooooooooooooooooo`0Bo`04o`0000Gooooo
00Co0?m1oooooooooooooooo0ol000000ol0og?o0000ooooo`03ooooo`05of?o0?oooooooooooe?o
0?ooool00_l0oeh01?l0o`Coooooo`000?o2o`03o`0000;o05Co2_ooool02?oo?P3oooooooln0?mn
o`3ooooooi7o0?oooooo083o0_ooool00oooF`3oooooooooo`02ooooo`03og[o0?oooooooooo00[o
oooo0ol0UOl01Ol0oecooooooooooooooooo0?mN00;ooooo00?o0>7oooooooooool01_ooool00ooo
I@3oooooooooo`02ooooo`05oomU0?o8o`3oooooooooooooIP003_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Wooooo0_l0VOl00ooooooo09Coo`2Do`1]ooooo`00MOooool2o`1O
o`03o`3oX_oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`04oom[0?o4o`3oooooolCo00?ooooo00CoaOl0oooooooooooo0?o<1?ooool01?l0og3ooooooooo
ool0ok42ooooo`03olSo0?l0ohCooooo00Wooooo00?o0000o`0nooooool00oooool00ol0oc?ooooo
ooooo`03ooooo`03oolk0?oooooooooo00[ooooo00?o01ooooooooooool00_ooool4o`000004o`0B
ool0003o0000o`0000cooooo00Ko0?m1of?o0?l0og?oooooo`000?mCo`02ooooo`03o`3oG_o2o`3o
oooo00;o0?l40_l0E?l3ooooo`?o000000[o0?o7oooooooo?P3o0000ooln0?mno`3oTOl0o`000?oo
ooooocd00_ooool00oooF`3o083oooooo`06ooooo`03o`1>oooooooooooo00?ooooo00GoN_l0oooo
ooooooooooooom[o0003ooooo`?o09Go2?ooool01?ooI@3oooooooooool0oe`3ooooo`05o`3oG_oo
ooooooooooooool0hOl02?ooool01Oo8o`3ooooooooooooooooo`Ol001Kooooo00?o0000oooooooo
ool00_ooool2o`2Do`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01_ooool2o`3oXQCo
oooo00Coa?l0ooooooooooooa?l00_ooool00oo5o`3oooooo`3oc003ooooo`03o`3o/Ooooooooooo
00[ooooo00?ob?l0ooooool0?_l00oooool00ol0ohCoooooooooo`0<ooooo`03o`3o<ooooooooooo
00?ooooo00?o01ooooooooooool02?ooool4o`000003o`0Boooooooooooo00Oooooo00?o0?m1oooo
ooooool00oooool01?l0og?o0000o`3oLol00002ooooo`;oHol000Gooooooe?o0?mCo`3oooooo`3o
GP02o`3o10?ooooo00Ko`_l0o`000?l0E?oo05Coooooool0olL4o`0000Kooooo00Sooch0oooooooo
?P3oO_l0oi7o0?oo?@3o083ooolm00;ooooo00?ooe/0ooooooooool00_ooool00ooJo`3oN_l0oooo
o`07ooooo`?o09Go0oooool01?l0oecoooooooooool0oeh2ooooo`03o`3Qoooooooooooo00Kooooo
00?oofD0ooooooooool00_ooool00oooI@3ob?l0ooooo`02ooooo`03oomV0?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`;o09Wo00?o09Coo`2?ool0Sol0
Koooool007Oooooo0_l0Gol01?l0oj;oooooooooool0000>ooooo`03o`000?oooooooooo00_ooooo
00Goof/0olCo0?ooooooooooolCo0002ooooo`04olGo0?ooooooooooo`3oc0Gooooo00Co0?m`oooo
oooooooo0?na0_ooool00oo8o`3o0?n4ooooo`0:ooooo`05o`0nooooooooooooooooool0oc<00_oo
ool01?oo>`3ooooooooooooo>`0<ooooo`So000000?oooooo`0Booooool03Oooool01?l0od7oHol0
o`3oLoooool2oe?o00;ooooo00Ko0?mNooooooo2o`3o0?l4o`3mool0E?l4o`3mo`0Ao`_o0?l0003o
0000o`000?l0olOoooooooln0?oooooooch0ogko0?ooooooocd0o`000?l0oOooocd0o`000?l0P?l0
2Oooool00ol0C_ooooooooooo`03ooooo`03og[o0?oooooof_l000;ooooo0_l0UOl;ooooo`07oomU
0?ooooooooooo`3oG?ooooooofD0o`3oGP03ooooo`03o`3Qoooooooooooo00Kooooo00Gob?l0oooo
oooooooooooool7o000Gooooo`03o`000?oooooooooo00;o09Co0_ooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo00Kooooo00Co0000ooooool0oj;o0?nR4oooool00oo4o`3oooooolCo
0002ooooo`04olGo0?oooooo0?o<o`3oL0;ooooo00?o0?naooooooooool02oooool00oo8o`3ooooo
o`0no`03ooooo`03o`3oQ?oooooooooo00_ooooo00?o0?lcooooooooool01?ooool00ol07ooooooo
ooooo`02ooooo`Go00000_ooool00oooo@3oooooo`0Bo`09ooooo`03o`3o@Ooooooooooo00?ooooo
00Ko0?mcoooooooooooo0?mcoooooomSo`02ooooo`05oe?o0?ooooooooooo`3oG_l0o`@01?l0oOl0
1_l;o`3o`_l0o`1Doonmo`3o2ol0o`3oa`Gooooo1Ol000003?oooooooch0oooooomno`3ooch0oi7o
0?l0P?ooooooo`1>oooo?@3ooooooomK00?ooooo00?of_l0oooooomjo`001_ooool2o`2Eo`Gooooo
00Go0?mLooooooooooooooooo`3oGP02ooooo`03o`3Qoooooooooooo00Gooooo00?oofD0oooooooo
ool00oooool01_ooI@3ob?l0ooooooooooooofH0ol7o00kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`05ooooo`;o09Wo00?o09Coo`2?ool0Sol0LOooool007Wooooo0_l0Gol00ol0
oj;o0000ooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?oof`0ooooooooool00_ooool01?oo
J`3oooooooooooo4o`02ooooo`04olGo0?ooooooooooo`3oc0Gooooo00Wo0?m`oooooooooooooooo
o`3o/Ooooooob?l0ooooool0oh@02oooool01ol0?_oooooooooooooooooo0?lcoooooooo>`000_oo
ool00ooo>`3oooooooooo`06ooooo`So00001?ooool00ol04_ooood0ooooo`0<ooooo`09o`3o@OmS
o`3oooooo`3oLomCo`3o0?mco`000?l0oOoo0?mN00;o0?go00?o`_l0o`1Dool0E?l01?ooool01_l;
o`3ooooooooooonmo`3o0?o7okgo00;ooooo00_ooch0ogko0?oo?P3ooooooolm0?l0003o0?gooolm
0?l0P?oooooooomK0003o`0000Kooooo00?o04koooooooooool00_ooool00omjo`3oooooo`2Eo`02
o`2Eo`cooooo00CoofD0oooooooooooo0?mL0_ooool00oooI@3o0?mNooooo`02ooooo`03o`3Qoooo
oooooooo00Kooooo00Gob?l0oooooooooooooooool7o000Gooooo`03o`000?l0U?oo09Co00Cooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`;o
0?nR4Oooool02Oo4o`3oooooooooooo4o`3oooooolGo0?oooooo0?o<o`3oL003ooooo`03o`3o/Ooo
oooooooo00[ooooo00Cob?l0oooooooooooo03ko0_ooool00ol0ohCoooooooooo`0;ooooo`03o`3o
<ooooooooooo00Cooooo0ol000000ooo>`3o0000o`000002o`3mo`Cooooo00?oood0o`0Booooool0
2?ooool00ol0od7oooooooooo`04ooooo`05o`3oLol0003o0?goo`3oLomSo`000_l0oOl01OmCo`3o
0?goo`3mool0oeko0?l400Cooooo00?o05Cool;o0?nmo`000_l000000onmo`3o0?o7ooooo`04oooo
o`03o`3mool0003o0?go00;ooooo0_l000002_mno`3o0000oi7o0?l0P?oooooooolm0?ooooooocd0
ooooooooF`03ooooo`04om[o0?ooooooooooog[o00;ooooo0ol0UOl7ooooo`04o`3oG?oooooooooo
o`3oGP;ooooo00?o0>7oooooooooool01Oooool00oooI@3oooooooooo`03ooooo`06oomU0?oooooo
b?l0ooooooooIP3o`Ol01?ooool00oooI`3oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00oooool2o`2Io`03o`2Dool0Sooo08oo07?ooooo001kooooo`;o05oo00?o
0?nRooooooooool02oooool00ol0003oooooooooo`07ooooo`03oom/0?oooooooooo00?ooooo00?o
of/0ooooooo4o`000oooool00oo5o`3oooooo`3oc006ooooo`06o`3oL?ooooooooooo`3o/Ooooooo
b?l00_ooool00ol0ohCoooooooooo`09ooooo`06o`0noooooooooc/0o`3o<ooooooooc/00_ooool0
0ooo>`3oooooooooo`05ooooo`Oo00000_l0oOl2o`0000;ooooo00?o01;oooom0?ooool02oooool0
1ol0od7oHol0ooooooooooooDol0o`000?l0og<00_l0oeh2ooooo`03o`3o1?o2o`3ooooo00Cooooo
00ko2ol0oooooooooooo_Ol0ooooool0olOooooookgo0?oooooooch0ogko0?oo?P3o0?gooolm00;o
oooo00So083oooooool0003ooe/0ooooool0003oooooo`0000Kooooo00Co04kooooooooooooooooo
0_l0UOl?ooooo`03oomU0?oooooo0?mL00;ooooo00?oofD0o`3oG_ooool00_ooool00oooIP3ooooo
ooooo`07ooooo`05olSo0?ooooooooooooooooo1o`005_ooool2o`2Do`Kooooo00?o0000oooooooo
ool0FOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0_l0oj8?ooooo`04
olCo0?ooooooooooolCo00;ooooo00CoaOl0o`3oc?oooooo0?m`0oooool00ol0ok7oooooooooo`09
ooooo`05olSo0?ooooooooooooooool0?_l00_ooool00ol0ohCoooooooooo`0:ooooo`03o`3o<ooo
oooooooo00Cooooo0ol000001Ooo>`3o0000o`000?l0003o0?nQ00;o0?go00?o0?nQooooool04_l0
2_ooool00ol0od7oooooooooo`04ooooo`04o`3oLol0003o0000of?o00;ooooo00GoDol0ooooool0
oeko0?mNo`3o1003ooooo`;o05Co00?ooooool;o0?ooool00_ooool00ol0olOo_Ol0ooooo`03oooo
o`05o`3mooooooooooooooooool0oOl00_l000001?ooooooO_l0oi7o0?l0P?l2ooooo`06oolm0?oo
ooooocd0o`1>oooooooooe/00_ooool01?oJo`3ooooooooooomjo`02o`2Eo`Wooooo00Co0?mLoooo
oooooooo0?mN0oooool00ol0hOooooooooooo`05ooooo`03oomU0?oooooooooo00;ooooo00OoofD0
oooooooooooob?l0ooooooooIP3o`Ol000Cooooo00?oofL0ooooooooool02?ooool00ol0003ooooo
ooooo`0;ooooo`04o`000?ooooooooooooooo`;o09Wo00?o09Coo`2?ool0Sol0MOooool007cooooo
00Co0000o`1Oool0Gooo05oo2oooool00ol0003oooooooooo`08ooooo`03oom/0?oooooooooo00;o
oooo00?oa?l0oom[0?o4o`000oooool00oo5o`3oooooo`3oc006ooooo`06o`3oL?oooooooooooooo
ool0ok7ob?l00_ooool00ol0ohCoooooooooo`08ooooo`09oolk0?oooooo03kooolk0?l0oc?ooooo
oolk0?oooooooc/000Kooooo1_l000001Ol0ROoo0?goo`000?l0003o0?nQ00;o0?go00Coooooo`0B
ooooooooood02oooool2of?o00;ooooo00[oDol0o`3oLooooooo0?mNo`3oLooooooo05Coo`3o1?oo
oooo`_l01?ooool01_l;o`3ooooooooooonmo`3oooooo`3oa`;ooooo00go2ol0okgo0?mno`3ooooo
o`000?oo?P3ooooooolm0?oooooo083ooolm0?oooooooe/000;o00000_ooool2o`0000Gooooo0ol0
UOl00ooooooof_l0og[o000=ooooo`04oomU0?ooooooooooo`3oG0;ooooo00KoofD0oooooooooooo
ooooo`3QooooIP09ooooo`05olSo0?ooooooooooooooooo1o`005?ooool01?l0U?oo08ooo`2?ool0
0006ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`03ooooo`;o05oo00?o0?nRooooooooool03?ooool01?o4o`3oooooooooooo4o`02ooooo`05olGo
0?l0olcoooooooooool0og000_ooool00ol0ok7oof/0ooooo`09ooooo`03olSo0?oooooooooo00;o
oooo00Co03kooooooooooooo0?n42oooool00ol0oc?oooooooooo`02ooooo`;o000000Kooc/0oooo
ool0003ooc/0o`3mooooool4o`000003o`3mool0003o01;o00Wooooo00?o0?m1ooooooooool01?oo
ool01Ol0oOoo0?mcof?o0?mSo`3o000000;oDol000Coooooo`3oG_oooooo0?l40_ooool2o`1Do`04
o`_o0?oooooo_Ol0ol;o00;ooooo00Go0?o7ooooool;o`3o_Ol0ooooo`03o`0000;ooooo0_l00002
ooooo`04ogko0?oo?P3oTOl0ooln00;o000000Woocd0oooooooo?@3oooooo`1>ooooF`3oooooom[o
0?ooool00ol0UOl00omjo`3oooooooooo`07ooooo`05o`3oG?ooooooooooooooool0oeh00_ooool0
0ol0hOooooooooooo`05ooooo`03oomU0?oooooooooo00;ooooo00SoofD0oooooooooooob?l0oooo
ooooIP3ooooool7o00?ooooo00?oofL0ooooooooool00_ooool00oooI@3oooooooooo`04ooooo`03
o`000?oooooooooo00_ooooo00Go0000ooooool0VOoo09Woo`2Do`02o`2?ogOooooo001looooo`04
o`000?ooooooooooooooo`;o05oo00?o0?nRooooooooool01_ooool00ol0003oooooooooo`03oooo
o`03oom/0?oooooooooo00?ooooo00Soof`0ooooooooooooooooolCo0?ooooooof/0olCo00;ooooo
00?oaOl0ooooool0ol`01oooool01_l0og3oooooooooool0ok7oooooolSo00;ooooo00?o0?n4oooo
ooooool01?ooool01?oo>`3ooooooooooooo>`02ooooo`03oolk0?l0oc?ooc/000;ooooo00?ooc/0
ooooooooool00oooool3o`000008ooooool0003o0000o`000?l0oOooooooo`29ooooool2o`000005
ooooool0003o01;oo`3oXOooo@002_ooool02OmSo`3o0?m1ooooooooooooDol0ooooool0og?o0?mN
ooooo`02o`1Do`04o`3o1?oooooooooool;o00?ooooo00Co2ol0oooooonmo`3o_Ol00_ooool03_l0
olOoooooooooool;o`3oooooogko0?oo?P3o0000ooln0?ooooooocd0o`20ooooooooocd00_ooool0
1?ooF`3oooooo`000?ooool3o`0000;ooooo0_l0UOl01_oooooo04kooooooooooooof_l0og[o00co
oooo00CoofD0oooooooooooo0?mL0_ooool00oooI@3o0?mNooooo`02ooooo`03oomV0?oooooooooo
00Oooooo00Kob?l0oooooooooooooooool7o0?ooool2o`00017ooooo0_l0Sol2ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo0_l0Gol00ol0oj;oooooooooo`07ooooo`07olCo0?l0003oooooooooooo4o`3o
ooooolCo0002ooooo`05olGo0?l0olcoooooooooool0og000oooool00oooJ`3oooooooooo`08oooo
o`03olSo0?oooooooooo00?ooooo00Co03kooooooooooooo0?n42_ooool01Ol0oc?ooooooooooooo
oooo000000;ooooo00Kooc/0o`000?oo>`3o0?goooooool0ROl2ooooo`;o000000Goooooo`0Bool0
003o0?goo`3oX@07ooooo`03o`3o@Ooooooooooo00?ooooo00?o0?gooooooomSo`000_ooool01?mC
o`3o0?mcooooool0oeh2o`3o1009ooooool0E?oo05Coooooool;o`3ooooookgo0?oooooo`_l000;o
oooo00Go0?o7ooooool;o`3ooooookgo0005o`0000;ooooo00Wo0?googko0?l0003oTOl0o`000?oo
oooooch0o`000?oo?@000_ooool00ooo?@3ooooooomK0003o`2Eo`Cooooo00?oN_l0ooooooooool0
1_ooool01?l0oecoooooooooool0oeh2ooooo`03o`3Qoooooooooooo00Gooooo00?oofD0oooooooo
ool00oooool01OooI@3oooooooooooo8o`3oofH000;ooooo00Co`Ol0ooooooooooooofL01Oooool0
0oooI@3oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo0_l0VOl3o`2?ogWooooo001loooo
o`03o`000?oooooooooo00?ooooo0_l0Gol00ol0oj;oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?oof`0ooooooooool01?ooool01oooK03oa?l0ooooooo4o`3ooooooom[0?o4o`000_oo
ool00oo5o`3oooooo`3oc008ooooo`05o`3oL?ooooooooooo`3o/Oo8o`000oooool00ol0ohCooooo
ooooo`03ooooo`04oolk0?oooooooooooolk00;ooooo00?ooc/0o`3o<ooo>`000_ooool01?oo>`3o
ooooooooooooool3o`0000?ooooo00Oo0000ooooool0oOoo0000ooooool07ooo08Wo00;ooooo00?o
0000o`0Bool000000_l0oOl00ol0oj7oooooooooo`06ooooo`03of?o0?l0od7ooooo00;oDol00_l0
e?l01Ol0oeko0000o`1Dool0og?o0?l400?ooooo00Ko`_l0oooooooooooo2ol0oooooonmo`02oooo
o`;o00001?ooool01omno`3o0?goooln0?o<o`3ooch0o`000?l0P?l00_ooool01ooo?@3o0?goo`00
0?ooF`3oooooo`000?l02Ol00_l00003o`2Eo`Cooooo00Go04koom[o0?ooooooooooog[o000;oooo
o`07oomU0?ooooooooooo`3oG?ooooooofD0o`3oGP03ooooo`03o`3QooooIP3ooooo00?ooooo00?o
ofL0ooooooooool00_ooool02?o8o`3ooooooooooooooooo`Ol0ooooool0003o`Ol03oooool2o`2?
o`Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool2o`1Oo`03o`3oX_oooooooooo00Gooooo00Goa?l0o`00
0?ooooooooooolCo0002ooooo`04olCo0?ooooooaOl0o`3oc0?ooooo00Go0?m`oooooooooooooooo
oom[0009ooooo`03olSo0?oooooooooo00Cooooo00?o03koooooool0oh@02_ooool01Ol0oc?ooooo
o`000?l0003ooc/000;ooooo00?ooc/0o`000?oo>`000_l000002Ooooooo08Woo`29oooooooo08[o
o`000?l04_ooood0ooooo`02o`3mo`;o0?nQ0oooool00ol0od7oooooooooo`02ooooo`;o0?go00[o
0=Coof?o0?l0og?ooooooe?o0?l0003o0?mco`3oG_l0o`Cooooo0_l0E?l2ooooo`03o`_o0?oooooo
_Ol000;ooooo00?o`_l0o`000?l000000oooool00ol;o`3o0?gookgo0002o`0000Gooooo00KoO_l0
oi7o0?l0P?oooch0o`09oooo?P02o`000003oolm0?l0003oocd000;o09Go00?o04koom[o0?ooool0
1?ooool00omjo`3oooooooooo`05ooooo`05o`3oG?ooooooooooooooool0oeh00_ooool00ol0hOoo
ooooooooo`05ooooo`03oomU0?oooooooooo00;ooooo00GoofD0oooooooooooooooooomV0003oooo
o`03ol7o0?l0003oofL000Gooooo00?oofD0ooooooooool01Oooool00ol0003oooooooooo`09oooo
o`;o09Wo0_l0Somlooooo`00O?ooool00ol0003oooooooooo`05ooooo`;o05oo00?o0?nRoooooooo
ool00_ooool00ol0003ooooooom]0004ooooo`03oom/0?oooooooooo00?ooooo00Oo0000oom/0?oo
ooooooooolCo0?ooooooof/000;ooooo00?oaOl0ooooool0ol`02?ooool01Ol0og3ooooooooooooo
oooob?l000Cooooo00?o0?n4ooooooooool00_ooool02Ooo>`3ooooooooooooo>`3ooooooolk0?oo
oooo0?lcoolk0002ooooo`03oolk0?oooooooooo00?o00000oooool00ol0003o0?nQo`3mo`02o`00
0004ooooool07oooooooo`29o`;o000000?o01;oo`000?l000000_l0R_l00ol0oOoo0?nQooooo`04
ooooo`04of?o0?l0e?oo0=Cooe?o00;o0=Co0_l0oeh2o`1Do`;o0?l400Wo0?mcoooooooooooooooo
ol;o0?oooooo2ol0oooooonmo`000oooool2o`0000Cooooo00SoO_l0ooooool0003ooch0o`3mool0
P?oooooooolm00;ooooo00Koocd0ooooooooF`3o00Woo`000?ooool2o`2Eo`?ooooo00?o0000oooo
ooooool00_ooool01Ol0C_ooooooooooooooooooN_l000Wooooo00CoofD0oooooooooooo0?mL0_oo
ool01_ooI@3o0?mNoooooooooooo0>7ooomV00Gooooo00?oofL0ooooooooool00_ooool01Oo8o`3o
oooooooooooooooo`Ol000;ooooo00?o`Ol0ooooooooool02oooool2o`2?o`Kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02Oooool2o`1Oo`03o`3oX_oooooooooo00?ooooo00Goa?l0ooooooooooooooooolCo0002
ooooo`05olCo0?ooooooooooolGo0?l0ol`00_ooool00oooK03o0?m`ooooo`02ooooo`03oom[0?oo
oooooooo00Kooooo00?ob?l0ooooooooool01Oooool00ol0?_ooooooo`3oQ009ooooo`0@o`3o<ooo
>`3ooooooooooooo>`3ooooooolk0?oooooo0000oolk0?l0003oooooo`000?oooooo08[oo`29o`;o
000000Go08[oo`000?l0003o0000o`2:o`02o`3mo`;o0?nQ00Ko0?m1ooooooooooooooooo`3Dool0
oOl2o`3Do`05of?o0?l0003o0?mcoe?o0?ooool00_l0oeh00ol0o`Co05Coo`1Do`03ooooo`03o`_o
0?nmo`3o_Ol000?ooooo00?o`_l0o`000?l000000_ooool01_l0oOoo2ol0o`000?l0003o_Ol0o`00
00Cooooo00WoO_l0o`3moonAo`3o00Woooln0?l0003ooch0ooooool02Ol00ol0UOl2ooooo`03oomK
0?l0C_oooooo00Gooooo00?oN_l0ooooooooool01?ooool01?l0oecoooooooooool0oeh2ooooo`03
o`3Qoooooooooooo00Gooooo00?oofD0ooooooooool00_ooool00oooI@3oooooooooo`02ooooo`07
oomV0?oooooooooool7o0?oooooo0000oomW0004ooooo`03oomU0?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool2o`2Io`04o`2Dool0Sooo08ooo`0007gooooo001looooo`03o`000?oooooo
oooo00Oooooo0_l0Gol01_l0oj;oooooooooool0003ooooooom]00Gooooo00?oof`0ooooooooool0
0oooool01oo4o`3oof`0ooooooo4o`3oooooolCo0?ooJ`000_ooool00oo5o`3oooooo`3oc008oooo
o`04o`3oL?ooooooooooolSo00Gooooo00Go0?n4oooooooooooooooooolk0002ooooo`03oolk0?oo
oooooc/000;ooooo00Co0?lco`0noooooooooc/00ol00005ooooo`04o`000?l0oOoo08Woo`0000Go
08[o0_l00002ooooo`?o000000?o08[oo`3mool0oOl00_l0oj42o`000003o`3Dool0od7oDol000;o
oooo00Go0?mNo`1Dool0E?oo@_l0o`3o1002o`000008o`3oLoooooooooooooooooo2o`3o2ol0oooo
oonmo`05ooooo`05o`15oooooooooooooooooomno`000ol000001Ooo?P3o083oooln0?l0oOooocd0
00;ooooo00?oocd0o`3mool000000ol0UOl00ooooooo00Woooooo`03ooooo`;o000000Coooooom[o
0?oooooo04ko0_ooool00omjo`3oooooooooo`07ooooo`03oomU0?oooooo0?mL00;ooooo00?oofD0
o`3oG_ooool00_ooool00oooIP3oooooooooo`03ooooo`07oomW0?ooooooooooooooooooI@3ooooo
olSo0002ooooo`05ol7o0?ooooooooooooooooo1o`002oooool00ol0U?oo08ooooooo`07ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo00?o05ooo`3oX_l0oj801?ooool01?o4o`3oooooooooooo4o`02oooo
o`05olCo0?ooooooooooolGo0?l0ol`00_ooool00oooK03o0?m`ooooo`02ooooo`03oom[0?oooooo
oooo00Kooooo00?ob?l0ooooooooool01_ooool00ol0?_ooooooo`3oQ007ooooo`03o`000?l0oc?o
oc/000;ooooo00Gooc/0oooooooo>`3o0000oolk0005o`2:o`;ooooo0_l000000oooooooood0o`00
0002o`0000;o08[o0_l0oOl01Ol0oj7o0000o`000?l0e?oo0?go00;ooooo00WoHol0oooooomCo`3o
Dol0o`3Dool0oeko0000o`3o1?l0E?l01?ooool01Ol;o`3o_Ol0oooooooooooo@_l000;ooooo00Go
`_l0o`3oZol0AOooooooo`3mo`02o`000005ooooooo<o`3o_Ol0o`000?l0oOl00oooool01_mno`3o
TOl0o`3moooooooooch0o`0000?o09Go00?oocd0oooooooo?@000_l000000oooF`3oooooo`1>o`05
ooooo`03og[o0?oooooooooo00?ooooo00Co0?mLoooooooooooo0?mN0oooool00ol0hOoooooooooo
o`04ooooo`03oomU0?oooooooooo00?ooooo00GoofD0oooooooooooooooooomV0003ooooo`04ol7o
0?ooooooofL0ol7o00?ooooo00?oofD0ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o
09Wo00?o09Coo`2?ool0Sol00_ooool00ol0003oooooooooo`1kooooo`00O?ooool00ol0003ooooo
ooooo`09ooooo`;o05oo00Goofd0o`000?oooooooooooom]0005ooooo`03oom/0?oooooooooo00?o
oooo00_oof`0ooooooo4o`3oooooolCo0?ooooooof/0ooooooo5o`3oooooo`3oc009ooooo`04o`3o
L?ooooooooooolSo00Gooooo00Ko0?n4oooooooooooooc/0oooooooo>`02ooooo`07oolk0?oooooo
ooooo`3o<ooooooo03kooolk0002o`0000?o0?mQ0_ooool2o`000006o`29ool0R_oo08[oo`000?oo
oooo08[o0oooool01ol0_Ooo08Woooooooooooooood0ooooool000000_l0R_l2o`3mo`;o000000Co
0?gooe?o0?oooooooooo0_l0E?l01?oooooo__l0od;o0?nno`02o`000005o`3oLol09_ooooooo`_o
0?o2o`000_nmo`05ooooo`0?o`3oZol0AOoooooooooooomno`3oTOl0ooooool;o`3oc?l0o`20ooo<
o`3oooooooln0?l0oOooocd000;o00Wo0_l0UOl01OooF`3oooooo`000?oooooo00Wo00Kooooo00Co
0000om[o0?oooooo04ko0oooool00omjo`3oooooooooo`05ooooo`04oomU0?ooooooooooo`3oG0;o
oooo00KoofD0ooooooooooooooooo`3QooooIP04ooooo`03oomW0?oooooooooo00;ooooo00?oofD0
olSo0?ooool00_ooool01?o1o`3oooooooooooo1o`0:ooooo`03o`2Dool0Sooo08oo00Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`;o0000D_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00cooooo0_l0Gol2o`3oXP;ooooo00Ooa?l0oooooooooooooooo
olCo0?ooooooa?l000;ooooo00?oof`0o`3oc?ooool00_ooool00oooK03o0?m`ooooo`02ooooo`03
oom[0?oooooooooo00Gooooo00?ob?l0ooooooooool01oooool00ol0?_ooooooo`3oQ004ooooo`07
o`000?oo>`3o0000o`3o<ooo>`3o0?mQoolk0002ooooo`05oolk0?l0003ooc/0ooooool000000_l0
R_l01Ol0003ooooooooooooooooo0;go00;o08Wo0oooool01Ol0003o08[oo`2:ool0od7o0?go00;o
000000_o0?gooooooomSo`3oHol0oooooomCo`3o__l0o`3oLol0oeko05Coo`3o1002o`000005o`3o
Loo7o`3o0?goo`_o0?nmo`000oooool01_m2o`3oooooooooooo2o`3o0?n[o`15o`;o00000_ooool0
1Ol;o`3oc?l0okgo0?o<o`3ooooo00;o0?go00?oO_l0o`20oonAo`000_l00002o`2Eo`04oooooooo
?P3o00Wooolm00;ooooo00?oocd0ooooooooF`000_ooool00ol0C_ooooooooooo`03ooooo`05og[o
0?ooooooooooooooool0oe`00oooool01?l0oekoooooooooool0hOl7ooooo`03oomU0?oooooooooo
00;ooooo00KoofD0oooooooooooooooooomV0?o8o`03ooooo`03ol7o0?ooI`3o`Ol000Cooooo00?o
ofD0ooooooooool01oooool00ol0003oooooooooo`02ooooo`;o09Wo00?o09Coo`2?ool0Sol01?oo
ool00ol0003oooooooooo`1kooooo`00O?ooool00ol0003oooooooooo`0;ooooo`;o05oo00Co0?nR
ooooooooooooofd01Oooool00oooK03oooooooooo`02ooooo`03olCo0?ooK03oa?l000;ooooo00Ko
a?l0ooooooooJ`3oaOl0ooooool0ol`9ooooo`05o`3oL?ooooooooooolSo0?l0ok401?ooool00ol0
ohCooooooolk0002ooooo`04oolk0?oooooooooooolk00;ooooo00Go0?lco`000?oo>`3o0000oooo
o`02o`0000;ooooo0_l0of42o`000003o`3oHOoooooooooo00;o08[o00Ko0000oooooooooooooooo
o`2mooooool2o`29o`0>ooom0?ooooooooooooooool0003o08[oof?o0?l0e?oo0?gooe?o0?l0oj7o
ooooo`1Dooooool2okko000;o`3o1?l0og?o@_l0o`000?l0e?oo0000o`3oLol;o`3oaol0ol;o0?l0
oOl01?o7o`02ooooo`05o`3oZol0003o0000o`000?mno`000_ooool01oo<o`3o2ol0o`20oooo?P3o
ooooooln0?l02Ol00ol0UOl01ooo?@3o0?gooomK0?oooooo0000ooooool02Ol01_ooool01OoJo`3o
0000o`000?oooooo04ko00?ooooo00?oN_l0ooooooooool01?ooool00oooI@3oooooo`3oG002oooo
o`06oomU0?l0oekoooooooooool0hOooofH01Oooool01oooI`3oooooooooooooooooofD0ooooooo8
o`000oooool01?o1o`3oooooooooooo1o`08ooooo`03o`2Dool0Sooo08oo00_ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`?o0?3o0_l0001Booooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03_ooool2o`1Oo`;o0?nR00Goa?l0ooooooooooooooooolCo0002
ooooo`04olCo0?ooooooof`0o`3oc0Cooooo00?oof`0o`3oL?ooool00_ooool00oooJ`3ooooooooo
o`04ooooo`03olSo0?oooooooooo00Sooooo00?o03koo`3oQ?ooool00_ooool01Ol0003ooooooolk
0?oooooo0?lc00;ooooo00?ooc/0o`3oHOoo>`000_l000001Ooo>`3o0000o`2:ool0003ooooo00;o
00000_ooool00ol0_Oooooooooom0002o`29o`?ooooo00go0000o`2:oooooooo0?goo`3Doooooooo
Hol0o`3oXOooooooDol0okko0?l0oeko05Co00;o0?l400Co0=Coo`000?l0003o0?mc0_l;o`000onm
o`3oaol0olOo0003olOo0006od;o0?o7o`3o`_l0olOo0?l0003oaol00oooool01?o<o`3oooooolco
0?nmo`02ooooo`03ogko0?l0P?ooTOl000?o09Go00_oooooooln0?l0003ooch0o`09ooooooooocd0
oooooooo?@3of_l0oomK0002o`000003ooooool0C_oooooo00Cooooo00CoN_l0oooooooooooo0?mL
0_ooool01?l0oekoooooooooool0hOl7ooooo`03oomU0?oooooooooo00;ooooo00?oofD0oooooooo
ool00_ooool00oooIP3ob?l0ooooo`02ooooo`03ol7o0?ooI`3o`Ol000?ooooo00?oofD0oooooooo
ool02?ooool00ol0003oooooooooo`02o`2Io`03o`2Dool0Sooo08oo00Kooooo00?o0000oooooooo
ool03?ooool00ol0l?oo0000o`00001/ooooo`00O?ooool00ol0003oooooooooo`0<ooooo`03oom]
0?l0Gooo05oo00;o0?nR00?oofd0ooooooooool00oooool01oooK03oooooooooooooooooa?l0oooo
ooooK0000_ooool01_o4o`3oooooooooooooJ`3oooooo`3oc0[ooooo00Co0?m`ooooooo8o`3o0?na
1Oooool01Ol0ohCooc/0oooooooooooooc/000;ooooo00Wooc/0oooooooo>`3o0?lco`000?oo>`3o
ooooo`0nool0of401Oooool00ol0oOoo08Woo`2:o`04o`3oH@;o00000_ooool01Ol0_Ooooooooooo
oooooooo08Wo00Cooooo00GoHol0o`2:ool0R_ooDol0o`3mo`02o`1Do`0@o`3oXOnno`3oooooo`3o
1?nmo`3o0?mco`0Voom2o`3o0=Coof[o0?l0og?oJ_l0okgo0?o2o`3oooooo`3mo`?ooooo00?oaol0
o`000?l000000_o7o`005Omno`3oTOl0olOo0?o7o`3o0000o`20ooo<o`3ooch0o`09oooo?P3o09Go
oolm0?l0oOoooooooolm0?oooooo0?gooomK0?oooooo0000o`09o`06ooooo`06om[o0?oooooooooo
o`000?oooooo04ko0_ooool00omjo`3oooooooooo`03ooooo`03oomU0?oooooo0?mL00?ooooo00Ko
ofD0ooooooooooooooooo`3QooooIP04ooooo`03oomW0?oooooooooo00;ooooo00?oofD0ooooooo8
o`000oooool01?o1o`3oooooooooooo1o`06ooooo`03o`2Dool0Sooo08oo00gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooo`3`o`02o`3`oeOooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0@ooooo`;o05oo0_l0oj82ooooo`04olCo0?ooooooooooolCo00;ooooo00?oof`0
ooooooooool00_ooool00oooK03o0?m`ooooo`02ooooo`03oom[0?oooooooooo00Cooooo00?ob?l0
ooooooooool02Oooool01?l0?_oo0?n4o`000?l00002ooooo`03oolk0?oooooo0?lc00;ooooo00Go
oc/0oooooooo>`3o0000oolk0005o`3oH@;o000000Go05goooooool0_Oooooooooom0002ooooo`05
o`29ooooooooooooo`3o@Oooool00_l0R_l01_ooooooHol0o`3mooooooooDol0okko00;o05Co00Co
0?l4o`3oLoo7o`3o__l00_l000001?l0og?o0?gookgo0?l0oOl5ooooo`04od;o0?oooooo`_l0o`00
00;ooooo0oo7o`02o`00000Jolco0?nmo`3o00Woo`09oomno`3oTOl0o`2Eool0003oooooo`3moooo
oooooch0o`000?oo?P3o00Wooooooooo?@3ooooooolm0?oJo`3ooooooomK0?oooooo0000ooooool0
C_l4ooooo`03og[o0?oooooo0?mL00?ooooo00Co0?mNoooooooooooo0>7o1_ooool00oooI@3ooooo
ooooo`02ooooo`03oomU0?oooooooooo00;ooooo00?oofH0ooooooo8o`000_ooool01?o1o`3oofL0
ooooooo1o`02ooooo`03oomU0?oooooooooo00Wooooo00Co0000o`2Iool0VOoo09Co0_l0Sol8oooo
o`03o`000?oooooooooo00Wooooo0ol0l?l00ooooooo0000o`00001/ooooo`00O?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?ooK@3ooooo00;o05oo00?o0?nRoom]0?ooool01?ooool01?ooK03o
ooooooooooo4o`02ooooo`03oom/0?ooooooa?l000;ooooo00?oof/0ooooool0ol`02oooool01?l0
og3ob?l0ooooool0ok45ooooo`04o`3oQ?oooooooooooolk00;ooooo00Kooc/0o`000?oo>`3o0?lc
oooooooo>`02ooooo`03o`3oHOoooooooooo00?ooooo00?o0?goo`2:ooooool00_l000000ooooooo
_Ol0o`000002o`3oH@03ooooool0_Ooooooo00;ooooo00?oood0o`29ooooool00_mSo`000ooooooo
Dol0oe?o0002o`1Do`05o`3oG_l0oOoo__l0ooooool0o`@00_l09_l01ol0og?ooooood;o0?l0003o
2ol0o`0Vool0og<00_l0oOl01?o2o`3o0?goof[o0?ooool2o`000005o`3oZol0oOoo04Gooooooomn
o`000oooool02Ol0P?oo0000o`2Eool0UOoooch0oooooooo?P3o0000oolm0002o`3mo`05oolm0?l0
oOoooe/0ooooool000001_ooool00ooJo`3oooooooooo`02ooooo`;o000000Co04kooooooooooooo
N_l01?ooool00oooI@3oooooo`3oG002ooooo`06oomU0?ooooooooooooooool0hOooofH01Oooool0
1OooI`3oooooooooooooooooofD000;ooooo00Cob?l0oooooooooooo`Ol00oooool00oo1o`3ooooo
ooooo`02ooooo`03o`2Dool0Sooo08oo00oooooo00?o0000ooooooooool00oooool3o`3`oeKooooo
0_l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool2o`1Oo`;o0?nR
00Coa?l0oom]0?ooooooa?l00_ooool00oo5o`3oof`0ooooo`03ooooo`03oom/0?l0og3ooooo00;o
oooo00?oof/0ooooooooool00oooool00oo8o`3oooooooooo`0:ooooo`05o`000?l0ohCooooooooo
oooo>`000_ooool03_l0oc?ooooooooooooo>`3ooooooolk0?l0003ooc/0o`000?nmo`3oooooo`00
0?nmo`3o00000_l0of401?l0GOoo0;goooooooooo@03ooooo`;o08Wo00Ko0?m1o`3moooooooo0=Co
of?o0?l00002oe?o00;o05Co00Ko_Ol0o`3o1?l0003o0?mcolOo0?nno`02o`000005okgo0?l0og?o
0?goof[o0?l0oOl01?ooool01?l0003o`_l0o`3oZol0AOl5ooooo`;o000000Soc?l0okgo0?l0UOoo
O_l0o`2EoonAo`3o0000o`3mo`;ooooo00Oo0?goooln0?l0003o00Woooln0?ooooooocd000;ooooo
00?oocd0ooooooooF`000_ooool2o`000003o`1>oooooooooooo00;ooooo00GoN_l0o`3oG?oooooo
ooooo`3oGP02ooooo`03o`3Qoooooooooooo00Gooooo00?oofD0ooooooooool00_ooool01OooI@3o
ooooooooooooooooofH000;ooooo00Cob?l0ooooooooooooofL00_ooool00oo1o`3ooooooomU000;
ooooo`;o09Wo00?o09Coo`2?ool0Sol02_ooool00ol0003oooooooooo`06ooooo`?o0?3oL_ooool0
07Cooooo0_l00006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooK@000_ooool3o`1O
o`05o`3oX_ooooooooooooooooooK0000_ooool01_o4o`3oooooooooooo4o`3oof`0olCo00?ooooo
00?oof/0o`3oc?ooool02_ooool01?l0og3oooooolSo0?l0ok45ooooo`04oolk0?l0ohCooooooolk
00;ooooo00Kooc/0o`000?oo>`3o0?lcoooooooo>`02ooooo`03o`3oHOoooooooooo00;ooooo00So
0?goo`000?l0R_oooooookgo0?l0003oooooo`1Mo`;o000000?o_Ol0o`3oHOl0of400oooool01_oo
o@3oooooof?o0?l0ROoo0?gooe?o00;o05Co00Co0?mNo`2:ool0R_oo__l00_l0o`@01ol09_oooooo
o`000?l0og?oaol0o`000?m2o`000_nmo`001Ol0og?o0?goooooooo2o`3o0?go00;o00000ol0oOl0
1?mZo`3o04Googko0?nAo`02o`3oH@0Ao`20ool0UOoo09Goolco0?nmo`3ooch0oooooooo?P3ooooo
oolm0?oooooo0000oolm0?l0oOoooe/0ooooool000001_ooool00ooJo`3oooooooooo`04ooooo`05
o`000?l0C_oooooooooooomjo`000_ooool00oooI@3oooooo`3oG002ooooo`03oomU0?l0oekooooo
00;ooooo00?oofH0ooooooooool00oooool01OooI`3oooooooooooooooooofD000;ooooo00Gob?l0
oooooooooooooooool7o0002ooooo`05ol7o0?ooooooooooooooool0U?l00_l0SolAooooo`03o`00
0?oooooooooo00?o0?3o00?oooooo`000?ooool0E_ooool2o`0000;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Cooooo`07olCo0?l0Gooo05ooo`3oX_ooK@3oooooolCo0002oooo
o`03olGo0?ooK03ooooo00Cooooo00?oof`0o`3oL?ooool00_ooool00oooJ`3oooooooooo`02oooo
o`03olSo0?oooooooooo00Sooooo0_l000005?oooooo03koo`3oQ?oooooooc/0ooooool0of7o0?lc
oooooooo>`3o0000o`3moooo>`3o0000oolk0?nmo`3o01ooooooool0003o05go0_l000001Onmo`3o
0?mQo`3oHOl0003oood000Cooooo00Oo0?m1o`29ool0ROooooooof?o0?ooooooDol000;o05Co00So
0?mNo`3mool0o`Co_Ol0ooooool0og?o0?nQoeGo00;o000000?o0?goo`3oLoooool01?l0oOl2o`00
0005o`3mooo2o`3oooooo`15ool000000_l0of400oooooooc?l0o`09o`03o`2Eo`06ogko0?oooooo
TOl0ooooool0003ooooo0ol0oOl02ooooooooch0o`000?oo?P3ooooooolm0?oooooof_l0oolm0?oo
oooooe/000Cooooo00?o0000o`1>ooooool00_ooool01Omjo`3ooooooooooooooooo0?mN00;ooooo
00?o0>7oooooooooool01?ooool00oooI@3oooooooooo`02ooooo`05oomU0?oooooooooooooooooo
IP000_ooool01oo8o`3oooooooooooooI`3o`Ol0ooooooo1o`000_ooool00oooI@3oooooooooo`07
ooooo`03o`2Iool0U?oo09Co00;o08oo3?ooool00ol0003oooooooooo`03ooooo`?o0?3oMOooool0
07Cooooo0_l000000ol0om?oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00Co0000oooo
ooooooooofd01?ooool2o`1Oo`04o`3oX_oooooooooooom/00;ooooo00Koa?l0ooooooo4o`3ooooo
oom/0?o4o`02ooooo`03olGo0?ooJ`3ooooo00_ooooo00Co0?m`olSo0?oooooo0?na1?ooool04?oo
>`3oooooo`3oQ?oo>`3o0000oolk0?l0003ooooooolk0?oooooo0?lcoolk0?oooooo0?mQooooool0
?_l3ooooo`07o`3mool0003o0000o`000?nmo`3oooooo`1Mo`03o`0000?o00Wo0_l0of403onmo`3o
ood0of?o0?oooooo0?gooe?o0?l0E?oo0=Coo`3oG_oooooo__l0ooooool0o`Co0000ooooo`02o`3m
o`;o0?mc00Koaol0o`000?nmo`3o@_l0o`0Vool0og<2ooooo`05ol;o0?l0003oooooo`3mooooool0
1?l0oOl04Omno`3o0?goo`2Eool0P?oo09Goo`3oHOo7o`3oc?l0o`_o0?oo?P3o0000oooooooo?P3o
oooooolm0?l0003oocd000;o0?go00?ooe/0o`000?ooool00oooool3o`0000Cooooo0_l000002Ooo
oooo0000o`000?ooooooN_l0ooooooooI@3oooooo`3oG003ooooo`06oomU0?ooooooooooooooool0
hOooofH01?ooool00oooI`3oooooooooo`02ooooo`04oomU0?ooooooooooolSo00?ooooo00Ko`Ol0
oooooooooooo`Ol0ooooool0U?l2o`2?oa?ooooo00?o0000o`3`ool0l?l01?ooool00ol0003ooooo
ooooo`1Gooooo`;o0?oC00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`03oom]
0?oooooooooo00;o05oo00Ooofd0ooooooo4o`3oooooolGo0?ooooooof`000Cooooo00?oof`0oooo
ool0og000_ooool00oooJ`3oooooooooo`02ooooo`03olSo0?oooooooooo00Oooooo00?o0000oooo
ooooool00_ooool04_l0ohCooooooolk0?oooooooc/0o`3o<ooooooooc/0o`000?oo>`3o0000o`2:
oooo>`3o0000o`0Ooooooooo05goooooo`;o00000_l02Ol01?l0003o0?mQo`3oHOnmo`02ooooo`;o
0?go00Coooooof?o0?mSo`3o0=Co0_l0E?l2o`3oGP03o`000?l0o`Co0?mc00;o0?go00Oo0?mcoooo
ool;o`3o0000okko0?l0e?oo0?mc00?ooooo0_l000001_oooooo0?goo`3mooo2o`3o@_l0o`3oH@;o
000000Wo0?mQo`000?l0UOoo09Goooooooo<o`3o083oogko0?nAo`000_ooool01?l0003ooooooooo
ooooool2o`3mo`03ooln0?l0003ooch000;ooooo00Goocd0olco0?oo?@3ooooooomK0005ooooo`;o
00000_ooool01?l0oecoN_l0ooooool0oeh2ooooo`03o`3Qoooooooooooo00Cooooo00?oofD0oooo
ooooool00_ooool00oooI@3oooooooooo`02ooooo`04oomV0?ooooooooooolSo00;ooooo00KoofL0
ol7o0?oooooo`Ol0ooooooooI@08ooooo`03o`2Iool0U?oo08oo00;o08oo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`03o`3`ogSooooo001gooooo`;o0?oC0oooool00ol0003ooooooooo
o`0<ooooo`05o`000?ooooooooooooooooooK@001?ooool03OooK@3o05ooo`1Oool0oj;ooooooom/
0?ooooooa?l0ooooooo4o`3ooooooom/0?o4o`000_ooool00oo5o`3o0?o<oom[000;ooooo`05o`3o
L?o8o`3oooooooooool0ok400oooool01_oo>`3oooooooooool0ohCo0000oolk00;ooooo00?ooc/0
ooooool0oc<00_ooool02?l0of7oooooooooool0?_ooooooo`3mool0003ooooo0_l000001?l0R_oo
ooooo`1Mooooool2o`000009ooooool0oOoo0?goooooool0oOoo0?mQoomS0?nmo`3o0?go00;o05Co
1Ol000004Ol0o`Coooooo`2:ool0R_oo0000o`3oLol0oOoo0?mco`_o0?l0003o0?good;o0?l0oOoo
0?n8o`3oLol0003o`_l000;ooooo0_l0oOl01?oooooo0?n[oooooomno`02o`2Eo`03o`20ool0003o
000000;o0?mQ00ooc?l0o`_o0?nmo`3ooch0o`_o0?oo?P3ooooooolm0?l0R_oooooooolm0?l0oOoo
oe/0o`09ool000000oooool3o`0000Cooooo0_l00003ooooo`06o`000?ooooooN_l0oomU0?oooooo
0?mL0_ooool01_ooI@3ooooooooooooooooo0>7ooomV00Gooooo00GoofL0oooooooooooooooooomU
0003ooooo`05olSo0?ooooooooooooooooo1o`000_ooool00ol0U?oo08ooo`2?o`0Cooooo`?o0?3o
1_ooool00ol0003oooooooooo`1Iooooo`;o0?oC1oooool00ol0003oooooooooo`0Cooooo`0=oom]
0?ooooooooooooooooo4o`3o05oooom]0?l0oj;oooooo`3oc?o5o`3ooooooom/0004ooooo`03oom/
0?l0og3ooooo00;ooooo00Goof/0ooooooooooooooooolSo0007ooooo`;o00001_ooool02ol0ohCo
oc/0oooooooo>`3o0?lcoooooooo>`3o0000oolk0?l0003ooc/000;o000000?o01ooo`1Mooooool0
0ol000001Ooooooo0?goo`2mool0oOoo00Wo00;o0?mQ00Go0?gookgo0?l02OooHol0o`09o`02o`1D
o`?o00000_l0o`@03?l0R_oo0000o`000?o7o`3o0?goo`_o0?nmo`3o0000okko0?l0oj7o0=Coo`3o
L`;o00000_ooool01ol0oOooooooooooooo2o`3o@_l0o`15ool0of400ol0UOl2o`000006o`3oHOl0
P?ooO_l0okgo0?nAo`3ooooo0_l0R_l04Ol0003ooooooooooooooooo0?goooln0?l0003oooooooln
0?ooooooocd0olco0?oo?@3o0000ooooooooF`3ooooo00;o00000oooool01Ol0003o0?mLoooooooo
ooooN_l000?ooooo00?o0>7oooooooooool00oooool00oooI@3oooooooooo`03ooooo`05oomU0?oo
ooooooooooooooooIP000oooool01?o8o`3ooooooomW0?o1o`02ooooo`03ol7o0?ooI@3ooooo00Ko
oooo00Co09Woo`2Dool0Sooo08oo0oooool00ol0003oooooooooo`0;ooooo`?o0?3oNoooool007Wo
oooo0ol0om<00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00Goofd0oooooooo
oooooooooom]0002ooooo`;o05oo00Go0?nRoom/0?o4o`3oooooolCo0002ooooo`07oom/0?oooooo
ooooolGo0?l0olcooooooom[000;ooooo`04olSo0?ooooooooooo`3o/@?ooooo00Kooc/0o`000?oo
>`3o0?n4oooooooo>`02ooooo`03oolk0?oooooo0?lc00;ooooo00?o0?mQooooooooool00_l00000
1ol0oOoo0?nQooooool0R_oo_Ol0ooooool0GOl00_ooool01Ol0oj7o0000o`000?oooooo0;go00;o
oooo00SoHol0oomS0?l0E?oo05Cookgo0?l0oeko0000o`29o`;o000000Co0?l4o`000?l02Ooo00Wo
0_l0R_l2o`00000:o`_o0?nmo`3o0000ooooool0003o@_l0o`000?l0og?o0?nQol;o00;ooooo0_l0
oOl01?l0oj_o09Goo`2Eoomno`02o`09o`03o`20ool0003o000000;o2ol000Soc?l0o`3oHOnmo`3o
och0o`3moooo?P3o0?gooolm00;o0?go00Goocd0o`3mool0003ooe/0o`000002o`3mo`05ooooooo<
o`3o_Ol0oooooonmo`000oooool2okko0008o`000?ooooooooooooooool0003oofD0og[o0?l0oe`3
ooooo`06oomU0?ooooooooooooooool0hOooofH01?ooool00oooI`3oooooooooo`02ooooo`05oomU
0?ooooooooooooooooo8o`000_ooool00oo1o`3oooooooooo`02o`2?oa;ooooo0ol0l?l2ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool2o`0004kooooo0_l00004ooooo`03
o`000?oooooo0?oC00;o0?oC1?ooool00ol0003oooooooooo`0Dooooo`04oom]0?ooooooooooolCo
00;ooooo00Coofd0o`3oX_l0oj;oaOl00_ooool00oooK03oooooooooo`02ooooo`03oom/0?l0og3o
oooo00;ooooo00Coof/0oooooooooooob?l01Oooool2o`0000Sooooo00Kooc/0o`3oQ?oooooooc/0
o`3o<ooo>`02o`00000:oolk0?l0003ooc/0okgo0?oooooo05goo`0Ooooooooo0000ooooo`;o0000
00Ko0?nQo`000?oooooo0?goooooool0oOl2o`3oH@03of?o0?l0E?oo05Co00;o000000So0?mNo`29
ool0o`Co0000oomS0?l0og?o08[oolOo00;o000000Wo_Ol0o`3mool0003o02Kookko0?l0003o0?mc
o`3oXOooool00ol0oOl01_oooooo0?mQol;o0?l0UOoo@_l0o`2Eo`;ooooo00co2ol0o`000?l0003o
083oolco0?mno`3oTOl0o`_o0?l0R_oo0000o`2:ool00004ooooo`0<o`000?oo?P3o0000ooln0?oo
ooooocd0okgo0?l0003oocd0ooooooooF`3o__l00_l000001?nno`3oooooooooool0oe`2o`000005
oooooomjo`3oooooooooool0hOl01_ooool00oooI@3oooooooooo`02ooooo`05oomU0?oooooooooo
ooooooooIP001?ooool01?o8o`3oofL0ooooooo1o`02ooooo`03oomU0?oooooooooo00Cooooo00Co
09Woo`2Dool0Sooo08oo1Oooool00ol0003oooooooooo`08ooooo`?o0?3o00?o0000ooooooooool0
Noooool0077ooooo0_l000000ol0oncoooooooooo`06ooooo`;o0?oC3Oooool00ol0003ooooooooo
o`03ooooo`05oom]0?ooooooooooooooooooK@000oooool2o`1Oo`07oom/0?l0oj;oooooolCo0?oo
ooooa?l0oom/0002ooooo`03olGo0?ooooooof/000cooooo00Cob?l0oooooooooooo0?na0_ooool0
1_oo>`3o0000oolk0?oooooo0?n4oolk00;ooooo00Gooc/0ooooool0oc?oooooo`3oH@03ooooo`?o
000000Goooooo`2:oonmo`3o08[oo`1Mo`02ooooo`04o`3oXOl0oOoo0000o`0000;o0?nQ00Woof@0
of?o0?ooH`3o05Cooe?o0?oooooo0?mNo`3oHOl0e?l00_nmo`000ol0o`Coooooo`0Vo`02o`000004
ooooool0og?o08[oo`2:o`Go000000Go@_l0o`3mool0og?o0?gool;o0002o`3mo`?o09Go00Oo0?go
ogko0?l0oOoo0?goo`20ool0oOooc?l000Go0?go00Wo_Ol0ooln0?oooooo08[oooln0?l0003oocd0
o`2:oooo?@000_l000000oooF`3o0000o`000005o`3mo`07o`000?nmo`3ooooookko0?oooooo__l0
o`000004ooooo`03oomU0?mjo`3ooooo00;ooooo00KoofD0ooooooooooooooooo`3QooooIP05oooo
o`05oomW0?ooooooooooooooooooI@000oooool02?o8o`3ooooooooooooooooo`Ol0o`2Dool0Sooo
`Ol04?ooool3o`3`o`Gooooo00?o0000o`04ool01?l00ol0oc<2o`0000;ooooo0ol0okP2o`0004ko
oooo0_l00003o`3ok003ooooool0003ooooo00?ooooo0_l0om<2ooooo`03o`000?oooooooooo01Co
oooo00Coa?l0oom]0?ooooooa?l00_ooool00oooK@3o05ooo`1Oo`02o`3oXP03ooooooooK03ooooo
00?ooooo00?oof`0ooooool0og000_ooool01?ooJ`3o0?naooooooo8o`04ooooo`03o`000?oooooo
oooo00Sooooo013ooc/0ooooool0ohCooc/0o`3o<ooo>`3ooooooolk0?l0003ooooooolk0?nmo`3o
05gooooooon3o`3ooooo0_l0oOl2o`000007o`2mool0oj7o0?nQo`3oXOl0oOooooooo`1Mo`02o`1D
o`0;oe?o0?oooooo0?mNo`3oG_nmo`3o0?l4o`29ool09_ooof<0o`3oLoo7o`000_l0R_l00ol0og?o
0000o`000005o`000003ooooool0oj7o0?nQ00;ooooo00Go0?goo`2Eooo2o`3o0?good;o0003o`3m
o`07olco0?l0oOoo083oo`3moomno`3oTOl0okgo0008o`3mo`;o000000[ooch0o`000?oo?P3o0?n5
olco0?oo?@3o0?gooolm0?nmo`3ooe/00_ooool02ol0003o__l0oooooooooooo0?mLooooool0C_oo
0000oooooomjo`3o0>7o00Kooooo00?oofD0ooooooooool00_ooool00oooI@3oooooooooo`02oooo
o`06oomV0?ooooooooooooooooo8o`3oofL00_ooool01?o1o`3oooooooooooooI@03ooooo`;o09Wo
00?o09Coo`2?ool0Sol01oooool01_l0003ooooooooooooooooo0000o`04o`;ooooo0ol0l?l2o`3o
<`;o00002oooool00ol0okSo0000o`00001_ooooo`00LOooool2o`000004ooooool0onco0?o/o`3o
k0Gooooo00Co0000ooooool0om?o0?oC2oooool00ol0003oooooooooo`03ooooo`03oom]0?oooooo
oooo00;ooooo00?oofd0ooooooooool00_ooool2o`1Oo`;o0?nR00KoooooolCo0?ooooooof`0oooo
ooo5o`02ooooo`03oom[0?oooooooooo00Wooooo00Wob?l0ooooooooooooooooo`000?oo>`3o0000
oooooooo>`000_ooool00ol0ohCooooooolk0002ooooo`03o`3o<ooooooo0?mQ00Cooooo00So08Wo
o`000?l0?_oo08[ookgo0?l0R_oo05gooh?o00;o0?go00_o00Woo`0Oooooooooooooo`2mooooI03o
05CooomS0?mCo`3o0?goo`3oGP02o`3mo`;o0?mQ00?o0?l4o`3mool0ROl01?l0oOl01ol;o`3o_Ol0
o`3mool0R_oo0?goo`000?l0oOl00_l000001?m2o`3o__l0o`3oLoo2o`02o`2Eo`07o`3oXOl0of7o
0?goo`_o0?mno`3o2ol0o`20o`02ooooo`0Golco0?oooooo0?goooooooo<o`3oaol0o`3oHOnmo`3o
och0oooooooo?P3o2ol0oolm0?l0oOoooooooolm0?l0003ooe/0olco0?l0003o0?n5olco0?l0oOl0
0_mZo`04o`3mo`03okko0?oooooooooo00?ooooo00OoofD0ooooool0C_ooN_l0o`000?ooooooofD0
00;ooooo00?o0>7ooomV0?ooool01?ooool01OooI`3oooooooooooooooooofD000Cooooo00Cob?l0
oooooooooooo09Co0_l0Sol00ooooooo`Ol0ooooo`0<ooooo`?o0?3o0_ooool9o`3o<`?ooooo00Co
0000o`3o^?l0okSo0?nhF?ooool3o`3ok0Gooooo0_l0om<00ol0003oooooooooo`0Dooooo`09olCo
0?ooooooofd0ooooooo4o`3oooooolCo0?ooK@3o0?o<00;o05oo0_l0oj800oooK03oooooooooo`02
ooooo`03oom/0?l0og3ooooo00;ooooo00Goof/0oooooooooooob?l0ooooo`02o`0000_ooooo00co
oc/0ooooool0ohCo0?mQo`3o<ooo>`3o0?gooolk0?l0003ooc/0okgo0?l0R_l=o`3mo`09of?o0?l0
E?oo0?gooe?o0?l0oOoo0?mNo`3oHOl0oOooof@000;o_Ol000Ooof<0o`3mool0oOoo0?goo`_o0?nm
o`3o08[o00;o0?go00?o0000o`3mool0oOl00_l000000ol0og?o0?goo`3mo`03o`2Eo`05o`3mooo2
o`3o2ol0o`15oom2o`000_ooool03?o<o`3o083oo`3moomno`3oc?l0oi7o0?l0R_oo_Ol0o`3oHOl0
003o2ol0ooooo`;o0?go00goooooo`000?l0003ooch0o`000?oo?P3oc?l0oooooooo?@3ooooooolm
0?l0oOoooe/000;o0?go00Co__l0oooooooooooo0?mL0oooool01?l0C_oo0000og[o0?l0hOl5oooo
o`03oomU0?oooooooooo00;ooooo00?oofD0ooooooooool00_ooool00oooIP3oooooooooo`02oooo
o`07olSo0?ooI`3oooooooooooo1o`3ooooooomU0002ooooo`;o09Wo00?o09Coo`2?ool0Sol02Ooo
ool00ol0003o0?lco`3o<`02o`3o<`?o0?3o0_l0oc<3ooooo`;o00002?ooool3o`3o^003ooooool0
003o000006oooooo001gooooo`?o0?o/0_ooool01?l0003oooooooooooooool2o`3od`Wooooo00?o
0000ooooooooool01?ooool00oooK@3oooooooooo`02ooooo`03oom]0?oooooooooo00;ooooo00?o
a?l0o`1Oool0Gol00_l0oj801?o4o`3ooooooom/0?o5o`03ooooo`03oom[0?oooooooooo00Sooooo
00?ob?l0o`3oL?ooool00_l000001?oo>`3ooooooooooooo>`02ooooo`08oolk0?l0ohCooc/0oooo
ool0oOoo0?lco`3mool0of43o`3mo`05o`29ool0oOoo0?goo`3mool0R_l02_l0oOl02?ooI03o05Co
oe?o0?ooH`3o0?nQo`3oG_l0oj7o05go0_l000001Ol0o`Co0?mQokko0?l0003o08Wo00;o_Ol000oo
2ol0okgo0?oo^P3oaol0o`3oLol0R_oo0000o`3moonmo`3o0?goo`0Voom2o`3o09Gool;o0?l0e?l0
0_l0of42o`_o0003ogko0?o<o`3o083o00;ooooo01Goc?l0oooooooooooo0?goooooooo<o`3oaol0
oooooonmo`3ooch0o`3oHOoo?P3o0?gooolm0?l;o`3o08[ooolm0?o<o`3o0?gooomK0?l000000_o<
o`001?oooooo0?goo`3moonmo`03o`3oX@03okko0?l0003o0?go00;o0?nQ00Oo0000oomU0?l0oeco
ooooo`1>oomjo`3oofD000?ooooo00?o0>7ooomV0?ooool00oooool00oooI`3oooooooooo`02oooo
o`03oomU0?oooooooooo00;ooooo00Gob?l0o`2Dool0Sooo08oool7o0002ooooo`03ol7o0?oooooo
oooo00Oooooo0_l0oc<2o`3`o`Go0?lc1Oooool00ol01?oo0000ooooo`02ooooo`?o0?nh00?o0000
ooooooooool02?ooool2o`0004gooooo0ol0om`01?oooooo0?o/o`3ok?l0on`4ooooo`;o0?oC5Ooo
ool01Oo4o`3ooooooom]0?ooooooa?l000;ooooo00Coa?l0oom]0?ooooooaOl00_l0Gol00ol0oj;o
of`0ooooo`03ooooo`03oom/0?l0og3ooooo00;ooooo00?oof/0ooooooo8o`000_l000000olc0?oo
0?goo`3mo`09o`3mo`0=oolk0?l0oOoooc/0o`3oQ?l0oc?ooc/0o`29oooo>`3o0000oolk0?nmo`3o
08[oooooo`02o`3mo`03oh?o0?l0003o000000;ooooo00Co0;goo`3mool0003oood00_l0E?l2oe?o
000?o`3oXOl0oeko0000o`000?l0o`Coof@0okko0?ooooooof<0o`29oonmo`3o2ol0olOo0?oo^P3o
0?mc00;o08[o00Ko0000o`0Voooooooo0?gookko0?l0og<2o`2Eo`05o`3oHOl;o`3o00Woo`000?o2
o`000_o<o`003Om2o`3oooooooooool0P?ooooooo`3moomno`3oTOl0o`2:ooo7o`3o_Ol0o`000?l0
of400_l0oOl03Ol;o`3o08[oooooooooooooc?l0o`3moooo?P3o0000ooln0?l0oOooocd0of[o0?oo
?@000_l0oj400oooF`3o0?nQokko0006o`3oX@04ooooool0C_oo0>7oog[o00Gooooo00?oofD0oooo
ooooool00_ooool01OooI@3oooooooooooooooooofH000Gooooo00OoofL0oooooooooooo`Ol0oooo
ooooI@3o`Ol000;o09Wo00?o09Coo`2?ool0Sol00oooool9o`3o<`04ooooool0l?oo0?3oo`3`o`Wo
oooo00?o0000ooooooooool00oooool3o`3o^7Gooooo001hooooo`05o`000?l0omco0?oLo`3og?l0
on`01Oooool3o`3od`Kooooo00?o0000ooooooooool01Oooool00oooK@3oooooooooo`02ooooo`07
oom]0?ooooooooooooooooo4o`3ooooooom/0002o`1Oo`;o0?nR00?ooooooom/0?ooool00oooool0
0oooJ`3oooooooooo`07ooooo`06olSo0?oooooo0000o`000?lc0?oooc/00_l0oOl02_oo>`3o0?go
o`3moooo>`3o0?goo`3oQ?l0oOoooooooolk0?l0oc<4ooooo`0=o`29ool0003o0?nQokgo0?l0R_oo
0000o`2:ool0oOoooooooh?o0?oooooo00Woo`3oH@02o`1Do`08oomT0?mCo`3oof<0o`000?l0oeko
0?lUo`3mool0oj42o`000007o`09oooooooo0?mQo`3oHOl09_oo08Woo`_o0004okgo0005o`3oLol0
003o0?goo`000?nmo`000_l0UOl01?m2o`3o0?mcol;o0?l0e?l2o`09o`04o`3oZoooooooO_l0o`20
o`;o000000Ooooooolco0?ooooooooooo`3mool0oj7oc?l000;o0?nQ00Oo_Ol0o`3moooo?P3o0?nQ
ooln0?l0oj7oocd000;o0?nQ00Coocd0o`3mooooF`3o00000_l0oj401?o<o`3o0000oooooonmo`03
ooooo`03okko0?l0003o0?go00;oJ_l000?oofD0o`000?l0oj400_l0oj401_ooI@3o0000o`000?oo
oooo0>7ooomV00Gooooo00GoofL0oooooooooooooooooomU0004ooooo`05o`2Dool0Sooo08oooooo
ooo1o`000oooool00oo1o`3o0?lco`3o<`06o`3o<`?o0?3o2oooool00ol01?ooooooo`000003o`3o
^0?ooooo00Co0000oooooooooooooooo0_l00005ooooo`;o0000COooool3o`0000Co0?oL0ol0on`0
0ooooooo0000ooooo`02o`3odaCooooo00Coa?l0ooooooooK@3oa?l00_ooool01?o4o`3oofd0oooo
ooo5o`02ooooo`04o`1OooooK03o0?nRo`3oXP?ooooo00Ooof`0o`3oL?oooooooooooom[0?l0ok7o
b?l000;o000000?ooooooc<0ooooool02?ooool04_oo>`3oooooo`000?oo>`3oooooo`3oQ?l0oOoo
08Wooolk0?l0003ooc/0oh?o0?l0R_oo0?goo`3oXOl07oooPol0o`0000;o0?mQ00?oooooo`3moooo
ool00_l0E?l01_l0obGoDol0o`3moooooooo0?mNo`3oX@;o000000Soof@0oonj0?l0of7oof<0o`3o
Looooooo08Woo`3mo`;o_Ol000Ko0?mco`3mool0003o08[oo`000?oo^P03o`2Eo`0<o`3oLol0e?oo
00Woooooooo<o`3ooooool;o0?l0oOooooooo`000?m2o`3o083o0_ooool00omno`3o0?nQoi7o0002
o`3oX@03okgo0?l0oOoo0?go00Oo0?nQ013o0?goooln0?l0003ooch0o`3oXOoo?@3o0?nQokgo0?oo
?@3oJ_l0oomK0?mZo`3o__l0o`3mool0oecooooo0_l000001_l0oeko0?nQo`3oXOl0oj7o0000og[o
00?ooooo00?oofD0ooooooooool00_ooool01OooI@3oooooooooooooooooofH000Gooooo00OoofL0
olSo0?oooooooooool7o0?ooI@3o09Wo00;o09Co0_l0Sol5o`3o<`Oooooo0ol0l?l00ooooooo00Co
ooooo`09ooooo`03o`000?oooooooooo00?o0?nh4?ooool2o`0006Kooooo001hooooo`;o00000_oo
ool4o`3og0Gooooo0_l0om<01Ol0003ooooooooooooooooo000000Sooooo00Koofd0oooooooooooo
ooooo`000?ooK@02ooooo`05olCo0?ooooooof`0olCo0?ooool00_l0Gol2o`3oXP03oom/0?oooooo
oooo00;ooooo00?oof/0ooooooooool01oooool01Oo8o`3o0000o`000?l0003ooc/000;o0?n800?o
oc/0oooooooo>`000_ooool01_oo>`3o0?n4oolk0?oooooo0?lco`0000?ooooo00Co08Woooooool0
oj7o_Ol00_l000001Ol0R_ooPol0ooooooooooooPol000;o05Co00[o0?goo`3oHOooI03ooooooomS
0?l0oeko0000o`3o9Ooooooo0?go0_l00002o`3oX@05okko0?oo^P3o0?mQo`3oHOl0ROl00_o7o`00
1?oooooo00Woo`000?nmo`03o`2Eo`07o`2:ool0003o0000od;o0?o2o`3o0?nQo`3Do`02o`3oX@03
ogko0?l0P?oo000000;o000000?o0?nQolco0?l0oj400_l0oj402oo<o`3o08[oooooool0oOoo_Ol0
o`_o0?oo?P3o0?mQooln0?ooooooocd000;o000000Coocd0o`09ooooF`3o00000_ooool01?o<o`3o
0000okko0?nmo`02o`3mo`04okko0?ooooooooooo`3mo`;ooooo00?oofD0o`3oG?mZo`000_mZo`00
1_ooI@3oN_l0o`000?l0hOoooooooomV00Cooooo00?oofL0ooooooooool00_ooool01?ooI@3ooooo
ooooool0U?l2o`2?o`?o0?lc00So`Ol0o`3o<ol0oc?o`Ol0o`3o<ooooooo`Ol0o`0000;ooooo0ol0
l?l=ooooo`04o`04ool0okSo0?nho`3o^0Kooooo00Co0000o`2Uool0YOoo0:Go0_l00002ooooo`?o
ob/00_l0001?ooooo`03o`000?oooooooooo00;ooooo1?l0om`2o`3ok0;ooooo0ol0om<=ooooo`05
o`000?o3o`3oooooooooooo4o`000_ooool01oooK@3oooooooooooo4o`3o0?o<oom]0?o5o`001?oo
ool00oooK03o05ooo`3oXP02ooooo`03oom/0?l0og3ooooo00;ooooo00Coof/0olSo0?l0003o0000
0_l0ohP00olc0?ooooooooooo`06ooooo`0<oolk0?oooooo0000oolk0?oooooo0?lco`3oQ?oo>`3o
0000oooooooo>`3o08[o0_l00002ooooo`05o`0Ooon3o`3o0?mQooooool0oOl00_l0E?l01?mSo`3o
0000oe?o0?ooool2o`3oGP;ooooo0_l000001?ooI03ookX0oomS0?ooool2o`3oH@07o`3mool0ROoo
ooooooooool0og?o0000okgo0003o`2Eo`04o`3oXOl0003o0000o`3oL`Go0?nQ00Ko`_l0o`000?l0
003o0000o`20ooo<o`02o`3oX@04ogko0?nAo`3oooooooooo`;o0?go00?o_Ol0o`3oHOl0of400_oo
ool2o`3oH@;o000000ko00Woooln0?o<o`3ooch0olco0?l0oOooocd0okgo0?oo?@3ooooooomK0?nn
o`3oooooo`3mo`CoJ_l00_ooool01?l0hOoo0000o`3oR?mjo`02ooooo`03oomU0?oooooooooo00;o
oooo00?oofD0ooooooooool00_ooool01oooIP3ooooooooooooooooo0?lcoomW0?o8o`000ol0oc<0
0ol0VOooofD0o`2Do`02o`2?o`_ooooo0ol0l?l01?oooooo0000ooooool01?l;ooooo`?o0?nh1_oo
ool00ol0YOoo0000o`000007ooooo`?oob/00_l0001Vooooo`00O?ooool01?l0003ooooooooooooo
ool3o`3og0?ooooo00?o0000o`3odol0om<00_ooool00ol0003oooooooooo`07ooooo`08oom]0?oo
ooooooooo`000?o3o`3oofd0ooooooo4o`02ooooo`04oom/0?ooooooa_l0ooooo`?o05oo0_l0oj82
ooooo`03oom[0?oooooooooo00Oooooo00[ob?l0o`3mool0003o<`3ooolk0?lc0?oooooooolk0?l0
ohSooc/00_l000001_oo>`3o0?n4oolk0?oooooo0?lco`0000;ooooo00Go0?goo`29oooooooo_Ol0
o`2:o`02o`000003oooooon3o`3ooooo00;o05Co00OoHol0o`3mool0003oof@0o`2mooooH`3o0?mQ
00Go0?nQ00?o0=Coo`3oXOl0oj400ol0oj401?l;o`3o0?nQo`3oHOl0ROl2o`3oX@?o000000Co0?nQ
okgo0?nmo`3o00000_l0R_l02_l0oOoo@_l0okko0?oooooo0=Coogko0?nAo`3o083oo`000?o<o`02
ooooo`05olco0?l0oj7o0?nQo`3mooo<o`000_l0oOl04oooooooaol0okgo0?oo?P3o0000oooooooo
?P3oc?l0oolm0?l0003oocd0o`09ool0oOoooe/0o`000?ooooooc?l0okko0?nmo`000oooool01onn
o`3oooooooooool0oOoooooooomU0?l0oe`00_ooool01ol0e?ooofD0ooooool0003oN_l0o`000?oo
IP000omZo`02ooooo`07oomW0?oooooo0?lco`3o<oooI@3o0?lco`2Do`02o`2?o`03o`3o<oo8o`3o
oooo00;ooooo00Co`Ol0oooooooooooo`Ol00_ooool01?o1o`3o0?3oo`3`ool0l?l>ooooo`?o0?nh
0_ooool00ol0003oooooooooo`02ooooo`?o0:Go1Oooool5ool[00;o0000Coooool00ol0003ooooo
ooooo`02ooooo`;o000000?oooooo`38ool0om`00ol0om`00ol0oncoooooooooo`02o`3od`_ooooo
00Go0000ol?o0?ooooooooooolCo0003ooooo`06oom]0?ooooooa?l0o`3oc?ooooooofd01Oooool0
1oooK03o05ooo`1Oool0oj;ooooooom/0?l0og000_ooool01Ol0003oof/0o`3oR?oooooo000000;o
oooo00Co<`3oo`3oR?oooooooooo0_l00002okgo000:oolk0?nmo`3ooc/0o`3oHOnmo`3o0?lco`3o
Q?oo>`3o0000oolk00;o08[o0_l00002ooooo`03o`0Oool02Ooo0?go00;o05Co00Ko0;goof?o0?l0
of7oDol0o`3oXOl0oeh3o`3oX@03o`3Dool0oj7oof@000;o0?nQ00Coof<0o`_o0?l;o`3o0?nQ0_l0
of401?l0ROoo0?nQo`000?l0oj42o`0000;o_Ol000[o0000o`3oHOl0oOoo0?mcooooool0e?ooc?l0
ooooooo2o`3ooooo0_l000001ol0P?oo@_l0olco0?l0oj7oO_l0oi7o0?o<o`000_l0oOl00ooooooo
aol0okgo0002ooooo`04o`3oHOooooooc?l0ooooo`;o000000ko00Woooln0?oooooooch0olco0?oo
ooooocd0o`3moooo?@3o0?gooomK0?nno`3oooooo`3mo`;ooooo00?o0?mNoooooomZo`000_l0e?l4
o`000003ooooooooI@3ooooo00?ooooo00GoofD0o`3o<ol0oc?o0?lcoomV0004o`3o<`07oooooooo
I`3ob?l0ooooool0VOoo09CooomU0002o`2?o`;ooooo00?o`Ol0o`000?ooool01Oooool3o`3`o`Co
oooo00?o0000o`04ooooool02?ooool3o`3o^003o`000?oooooooooo00?ooooo0ol0YOl00ooooooo
0000o`000005ooooo`;oob/01?ooool2o`0006Gooooo001looooo`03o`000?oooooooooo00Cooooo
1?l0om`2ooooo`;o0?oC00?o0000ooooooooool02?ooool04?ooK@3oooooooooooo3o`3ooooooom]
0?ooooooa?l0ooooooo4o`3oof`0ooooooo6o`3oooooo`3oc?o5o`02o`1Oo`;o0?nR00?ooooooom[
0?ooool01_ooool02ol0003ob?l0o`3mool0oj7o0000oolk0?oooooo<`3ooolk0?oooooooc/000;o
000000Kooc/0okgo0?l0ohCo_Ol0o`3o<onmo`02o`3oX@07o`29ool0003o0?nQokgo0?l0R_oo0?nQ
o`2:o`02o`3oX@0Ao`1Dool0oj7oHol0o`3mool0oj7oDol0oomT0?l0oekoof<0o`3oXOl0of7ooooo
o`3o9Ol0]_oo0=Cookgo0?l?o`000_ooool02Onno`3o2ol0o`3oXOl0oj7oaol0o`_o0?l0ROoo0000
o`_o0002o`0000;o0?mQ013o0?goo`3oR?l0003o_Ol0o`3moom2o`3o__l0ooooool0oj_oO_l0o`20
oooooooo0?goo`15ooooooooc?l00oooool2o`3mo`?ooooo01;oaol0okgo0?l;o`3ooch0oooooooo
?P3o0?mQoolm0?l0R_oo00Wooolm0?l0oOoooe/0o`000?o<o`3o__l0oooooonmo`02o`3mo`03okko
0?oooooo0?go00;ooooo00?o0?gooomU0?l0oe`00_l0e?l01ol0003oofD0o`000?l0003oN_l0o`3o
<oooIP001?l0oc<01_ooI`3o0?lco`3o<oooooooofD0o`2Do`;o08oo0oooool01Oo8o`3ooooooooo
oooooooo`Ol000;ooooo00Co`Ol0o`3`ool0l?oo0?3o3_ooool3o`3o^007o`04oooooooo@ol0od?o
0?oooooo0000ooooo`03o`2Uo`;ooooo00Co0000oooooooooooooooo1?oo:`03ooooo`;oob/0Cooo
ool00ol0003oooooooooo`06ooooo`04o`000?oooooo0<Soo`38o`?o0?oL00Co0?o/ooooool0om?o
0?oC2_ooool01?o3o`3oooooooooooo4o`03ooooo`07oom]0?ooooooooooolCo0?ooooooaOl0oom]
0004ooooo`03oom/0?oooooooooo00;o05oo00Oo0?nRoom/0?l0og3o0000o`3mooooJ`3o0?n800;o
0?nQ00?o0000ooooooooool00_lc0?l00ol0ohSo0000o`000002ooooo`0;oolk0?oooooooc/0o`3o
HOl0oj7ooc/0o`3o<ol0ohCo0?nQoolk0?l0R_l01_l0oj42o`1Do`03o`3oXOmSo`3oHol000;oDol0
00?o0?nQo`3oG_l0]_l00oooool02?l0e?ooof@0oooooooo^P3oof<0o`_o0?nmo`3oaol00_l;o`00
1Oo7o`3o0?mQo`000?l0og?o0?n800;o000001Go0?mco`0Vool0of7o0000o`2:ool0oOoo0?mcoooo
ool0e?oooooool;o0?oooooo04Goo`20ooooooooc?l0od;o0?mno`3o0?gooi7o0?l0oOl00oooool0
0ol0003o_Ol0ooooo`02ooooo`0Fo`3oHOooooooooooo`2:ool0ohGo00Woo`_o0?oo?P3o0000ooln
0?ooooooocd0oooooooo?@3ooooookko0?ooF`3o0?mLooooool0oOooooooo`3oGP;o0=Co00Co0000
ooooool0003o0?n80_l000000oooI@3o0?lco`3o<`02o`3o<`05oomU0?l0oc?oooooooooooooIP00
1Oooool02OooI`3oooooo`2Iool0U?oo08oooomU0?l0Sooooooool7o0002ooooo`03ol7o0?l0003o
oooo00;ooooo0ol0l?l7ooooo`03o`04oooooooooooo00Gooooo0ol0okP3ooooo`03o`000?oooooo
oooo00?o0:Go2?ooool3ool[00?ooooo0ooo:`03o`0006Cooooo001looooo`03o`000?oooooooooo
00Oooooo00?o0?o/o`3og?l0om`00_l0om`2o`3od`03o`38oooooooooooo00Oooooo00?oofd0oooo
ooo3o`000_ooool03?ooK@3oa?l0ooooooo4o`3ooooooom/0?o6o`3oooooo`3oc?o5o`3ooooooom/
00;o05oo0_l0oj800oooJ`3oooooooooo`04ooooo`0=o`000?o8o`3o0000o`000?l0R_oooc/0o`00
0?oo>`3o<`3oo`3oXOoo>`3o0?nQoolk0002o`3oR008oolk0?l0ohCo0?lco`3oXOoooooo0?goo`29
ooo<o`02okgo0003o`2:oonmo`3o08[o00;o05Co00?oPol0of?o0?l0oOl00_mCo`000oooI03o0?mN
oomS0003okgo00;o0?mQ00Go0;Koo`3Doonmo`3o0?gookgo0002o`000007oonj0?l;o`3o2ol0o`_o
0?o7o`3o0000o`29o`03o`3oH@0<o`09ool0oOoo00Woo`3oHOl09_oo0000okgo0?o2o`3o@_l0okko
0?mno`3o083o0_ooool01Ol0oOoo04Goooooooo<o`3ooooo00;o0?go00?o0000olco0?l0oj400_l0
oj404Ooooooo_Ol0o`_o0?oo?P3oc?l0ooln0?ooooooocd0o`3oQOl02Oooocd0o`3oHOooF`3o0000
olco0?oooooo_Ol000?ooooo00?o__l0ooooooooool00_l0oOl01_ooI@3o0=Coo`3Dool0oc?o0000
oomU00;o0?lc00Co0?n8o`3oXOooIP3o00000oooool01oooI`3o0000o`000?oooooo09CooomU0?l0
Sol01Oooool01?o8o`3oooooooooooo1o`02ooooo`;o0?3o00?ooooool7o0?ooool02oooool3o`3o
^0;ooooo00?o00Cooooooom3o`000_l00003o`2Uo`Gooooo00?o0000ool[0?oo:`000ooo:`02oooo
o`?oob/0DOooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`?o0<So1?l0om`2
o`3od`Wooooo00Co`ol0ooooooooooooa?l00_ooool01?o4o`3oofd0ooooooo4o`02ooooo`03oom]
0?oooooooooo00?ooooo00_oof`0ooooooo6o`3oooooo`1OooooK03o0?nRo`000?l0oOoob?l0oom[
0004o`0000?o0?nQ00Go<`3oo`3oXOl0ohSo0?n8oolk0002o`3oX@08oolk0?l0of7ooc/0olco0?l0
oc?o0000o`3oQ?oo>`02o`2:o`03o`3moon3o`3ooooo00;o05Co00Ko0?mQoooooomSo`3ooooooe?o
0?ooool2o`3oGP03o`3o9Ol0of7o0?mQ00;o_Ol001So0=CooomT0?nmo`3ookX0oomS0?l0003oaol0
o`_o0?nmo`3oaol0o`3oXOl0003o0?mQo`29ool0of7o0000o`3oR?l0of7o02Koooooool0R_oo0000
o`2:ool0oOl2okgo000=o`3Dooo2o`3oooooo`20ool0oOooooooolco0?m2o`3oO_l0oi7o0?oooooo
c?l0o`3oX@02ooooo`0Ao`000?nmo`3oooooooooooo<o`3oooooo`3oHOnmo`3o0?n5o`09ooo<o`3o
0?mQooln0?o<o`3ooch0okgo0?oo?@000_ooool00ooo?@3o__l0oomK0003o`3mo`;o0=Co0ol0oc<0
1_l0003o0?lco`3oR?ooooooofD0og[o00?ooooo00?oofD0ooooooooool00_ooool00oooIP3ooooo
ooooo`02ooooo`03oomW0?l0VOoo09Co00;o08oo00GoofD0ol7o0?oooooooooool7o0002ooooo`03
ol7o0?oooooo0?3o00;o0?3o2?ooool00om3o`3o00Coo`000004ooooo`?o0?nh1_ooool3o`2Uo`So
oooo0ooo:`03ooooo`?oob/000Coooooool[0?oo:`3oob/00_l0001Tooooo`00O?ooool00ol0003o
ooooooooo`0:ooooo`;o0?o/1?l0om`00ol0om?oooooooooo`06ooooo`08oom]0?oooooo`ol0oooo
ooooK@3oa?l0ooooooo4o`02ooooo`04oom/0?o6o`3o0?o<olGo00;ooooo00Ooof`0ooooool0Gooo
05ooo`3oX_ooJ`3ooooo00?o0?oe00?o0000o`3oHOl0oOl00_l000002Ooooooooc/0o`000?oo>`3o
0000oc<0oooo>`3ooooooolk0002ooooo`03oolk0?l0ohSo0?n400;oc?l000Ko0?goo`29ool0003o
_Ol0olco0?l0R_l2o`1Do`;ooooo00SoHol0o`0noomCo`3o0?mQo`3oG_ooI03o0000oomS00?ooooo
00Oo0?lUooom0?l0of7o0=Cookgo0?oooooo_Ol000;o000000Go2ol0o`3mooo7o`3oaol0o`000002
okgo0003o`29ool0og?o0?mQ00?o0?mQ01Co_Ol0o`0Voonmo`3o0000ol;o0?l0oOoo@_l0o`20oonm
o`3o0=Coooooool0oOoo04Goo`3mooo<o`3o0?goo`2:ool0003oooooolco00?ooooo0_l0oj402Onm
o`3oooooooln0?oooooooch0o`3oQOoo?@3o00Wooolm0002o`000004oomK0?l0003o2ol0okgo00;o
0?lc00?o__l0o`3o<ol0oOl00_l000003_ooI@3o0=Cooooooooooooo0000o`3oG_ooI@3oooooo`3o
R?l0hOooofH0oooooomjo`3o00000_ooool01OooI`3oooooo`2Dool0U?ooofD000Kooooo00Cob?l0
oooooooooooooooo0ol0l?l01?o1o`3oooooooooooo1o`0:ooooo`;o0?nh1?ooool00ol01?oo@ol0
od?o0003o`2Uo`04o`3[ool0003o06_oo`1[o`?ooooo1Ooo:`02ooooo`;oob/0E?ooool00ol0003o
ooooooooo`03ooooo`;o07Wo00?oooooo`000?ooool01Oooool2o`38o`03ooooool0onco0?oL00?o
0?oL1oooool01?o3o`3oooooooooooo4o`02ooooo`04olCo0?ooooooofd0olCo00;ooooo00?oaOl0
oom]0?ooool01?ooool00oooK03o0?oeolKo0002o`3om@06oom/0?l0oj;o0?nRolSo0?l0003oof/0
0_l000001_l0oj7o0000o`000?nmo`3ooooooc<0o`;o000000kooc/0o`3oR?l0ohSooc/0o`3oHOoo
>`3o0000o`3o<ol0003ooc/0o`3oQ?l0GOoo08[oo`3mo`;o05Co00So0?goo`0Oool0of7oHol0oh?o
0?mCo`3o0;goo`3oGP;ooooo00?o0?lUooooool0]_l00_l0of401?ooI03o_Ol0o`_o0?ooH`02o`00
0008ooooool09_oo05goolOo0?l0003o0?mQo`3oXOl0og<2o`29o`03o`3oHOnmo`3o02Ko00?o_Ol0
00?o0000o`3oLol0oOl00_nmo`000oo2o`3o083oo`15o`03o`3mo`06ogko0?nAo`3oooooooooooo<
o`3ooooo0_l0oj401?l0003o2ol0okgo0?o<o`02ooooo`0Aokgo0?l0R_oo0?n5o`09oooooooo__l0
ooln0?l0003ooch0okgo0?l0oc?oocd0o`3o<ooo?@3o__l0oomK0?l09_l00_l000001Ol0oekooooo
o`000?l0hOoo000000;ooooo00Go0?n8ooooooooI@3oooooog[o0002ooooo`05oomU0?oooooooooo
ooooooooIP001?ooool02?l0VOooofL0o`2?ool0Sooob?l0ooooooooI@3o`Ol00_ooool00oo1o`3o
ooooo`3`o`02o`3`o`[ooooo00Go@ol0o`04ool0003o0000ooooo`03o`3o^0Kooooo0ol0YOl00ol0
003oooooooooo`06ooooo`;oob/01?ooool2ool[0004oooooooo:`3oob/0ool[00?ooooo00?oob/0
o`000?l00000Hoooool007cooooo00?o0000ooooooooool01oooool00ol0003o07Woo`1io`02oooo
o`04o`000?oooooo0?o/o`3ok0?o0?oL1oooool01OooK@3o`ol0ooooooooooooofd000;ooooo00Ko
a?l0ooooooo4o`3oof`0o`3oc?o5o`03ooooo`03oom/0?l0ooGo0?oe00;o05oo00?oof/0o`3oX_oo
ool00_l000001Ol0oOoo0000o`000?l0of7ooc/000;o0?nQ017ooc/0o`2:ool0R_oooc/0oc<0oooo
>`3o0000olco0?oo>`3oooooo`3o<ol0ohCo0?goo`3oXOl0ROoo_Ol0o`3oX@02o`1Do`09ooooool0
R_oo0?nQof?o0?l0oj7oDol0o`3oHOl0oekoof@000;o0?nQ00Soof<0ooooooooooooooooo`3o9Ooo
o@3o2ol0o`3Do`;o_Ol000Oo2ol0o`3oLonno`3o0?goolOo0?oooooo000000;o0?mQ00Co0?goo`3R
ool0ROoo08Wo0ol0of401ooooooo02Koo`3oLonmo`3o`_l0o`3moom2o`000_l0R_l2okgo00;o0?go
00?oc?l0o`2:ool0R_l00onmo`001?o<o`3o_Ol0okgo0?nmo`02ooooo`0?okgo0?l0oj7ooch0oooo
oooo?P3o08[ooolm0?l02Ooo0?mQoolm0?l0003ooe/0o`000?nmo`3o2ol000;ooooo00?o__l0o`0V
ool0e?l00_l000001_ooI@3o0?goo`0Vool0003o02KooomU00;ooooo00So0?n8ooooooooIP3ooooo
og[o0?oooooo0000oomW00;o09Co0_l0Sol00oooI@3oooooooooo`04ooooo`05olSo0?l0l?oo0?3o
o`3`ooo1o`000_ooool01?o1o`3oooooooooooo1o`07ooooo`?o0?nh1Oooool01_l01?oo@ol0o`2U
ool0YOoo0>_oooooo`?o06_o0_l00005ool[00?ooooo0_oo:`000oooooooob/0ool[001Cooooo`03
o`000?oooooooooo00?ooooo0_l00003o`1io`Oooooo0ol0b?l00ooooooo0?o/o`3ok004o`3og0?o
oooo00Co`ol0ooooooooooooa?l00oooool00oo4o`3ooooooom]0002ooooo`03olGo0?l0ooGoofd0
00Go0?oe00Ooof`0olKo0?oooooo0000o`2cooooK03o05oo00;o0?nR00Woof/0o`3oXOl0oj7o08[o
ooooool0003o_Ol0o`2:ooooool00_l000003?oo>`3ooooooolk0?l0ohSo0?mQoolk0?l0oj7o0?lc
o`3oXOoo>`3o0?n4o`1Mo`;o05Co0_l0oOl01ol0oj7o0?mQof?o0?l0oj7oDol0o`3oXOl0oeh00ooo
ool03ol0obGoooooo`_o0?l;o`3o0=CooomT0?nmo`3oof<0oonj0?l0oOoo0?mcooooool09_ooaol0
o`000002o`3mo`05o`09ool0og?o0?n8o`3oHOl0ROl00_l0of402_l0og?o_Ol0oonj0?l0R_oo0000
o`3mool0R_oooooool;o0?ooool2o`3mo`0:olco0?mno`3o_Ol0oi7o0?nmo`3o0000olco0?nmo`3o
ooooo`0000;o0?nQ01Go_Ol0oooooooooooo_Ol0o`3o<ol0ohGo0?lco`09oonno`3o0?lco`000?oo
?P3o0000ooln0?l;o`3oocd0oooooooo?@3o02KooomK0?l0e?l00_l00002o`3mo`03o`0Vool0003o
oooo00;ooooo00Oo0?n8oomU0?l0oj7oooooog[o0?l0003oofD000?ooooo00ooofH0oooooooooooo
ooooo`2Iool0U?ooofL0o`2?oooooooob?l0ooooooooI@3ooooool7o0?ooool00ol0l?l00oo1o`3o
ooooooooo`08ooooo`;o@ol000?o00Coooooool0okP00_l0okP00ooooooo06_oo`1[o`03ooooo`?o
0:Go0oooool00ol0003oooooooooo`03ooooo`?oob/00oooool3ool[0003oooooooo:`3oob/000?o
oooo0ooo:`000ooooooo0000o`00001Sooooo`00O?ooool00ol0003oooooooooo`07ooooo`;o0000
00Coooooo`1iool0NOoo07Wo1?ooool2o`3ok0Co0?oL0oooool03_ooK@3o`ol0ooooooooooooa?l0
oom]0?ooooooa?l0ooooooo4o`3o0?oeoom/0?l0ooGoaOl00_l0ooD00oooooooof`0ooooo`02oooo
o`06o`1OooooJ`3o0?nRo`3oX_oooooo0?go0_l000003?l0oj7ooc/0o`3oHOl0of7ooc/0o`000?nm
o`3ooc/0o`2:oooo>`3o0000oolk00;ooooo01Ko0?mQo`3o<ol0ohCo08Woo`3oR?nmo`3o05Coo`2:
oooooooo08[oo`3moomSo`3ooooooe?o0?n3o`3o0?mNo`0nooooI03oPol0oomS0?l0_Ooo0?nQ0_l;
o`02o`3mo`03o`3Dool0oOoo0?go00?o0?go00Oo__l0olOo0?l09_oo0000o`3oHOoooooo0?go00;o
00Wo00Go0?mco`3oHOl0ROooooooo`3oX@02o`3oH@08o`0Vool0og?o`_l0o`20oomno`3o@_l0okko
0?l0R_l2o`3mo`05okgo0?o<o`3o_Ol0ooooool000000_ooool05oo<o`3o0?goo`000?l0003o_Ol0
oooooonmo`3oEOl0ooln0?l0oj7o0?n5ooln0?o<o`3oocd0oooooooo?@3o0?mQoomK0?l0003o_Ol0
ooooool;o`3ooooo00;o0=Co0_ooool00oooI@3o02Koo`3mo`02o`000007oomU0?l09_oo02Koo`3Q
ool0ohSoofH0o`3oX@02ooooo`03og[o0?ooI`3o09Co00;o08oo00?ooooooomU0?ooool01?ooool3
o`3`o`?ooooo00Co`Ol0oooooooooooo`Ol00_ooool00oo1o`3oooooooooo`02ooooo`?o0?nh1ooo
ool3o`2Uo`04o`3[oooooooo06_oo`1[o`;ooooo00Co0000ool[0?oo:`3ooooo0_oo:`000ooooooo
0000ool[0005ool[05Gooooo00?o0000ooooooooool01_ooool00ol0003oooooo`1io`02o`1io`Oo
oooo0_l0b?l2ooooo`?o0?o/1?l0om`2ooooo`0:olCo0?oooooo0?oeo`3omOo4o`3o0?oeoom]0?o4
o`3o0?oeolGo00;ooooo00?oofd0ooooooooool00_ooool01oooK03oa_l0ooooool0003ooooooom/
0?ooool00_l0Gol02?l0oj;oof/0o`3oHOoooooo08[ookgo0?l0003ooooo0_l0R_l01_lc0?oooc/0
oooooooo>`3ooooooolk00;o0?n800_o0?lcoooooooo>`3o05Coo`3oQ?l0GOoo0?goo`0noon3o`3o
ooooof?o0002oe?o0003o`000?l0oeko0;go00;o0?nQ0ol;o`001_l0oj7o0?gooomT0?l0003o0?go
oomS00?o0?go00Co0?mQo`0Vool0003o0?go0ol02Ol01_l0og?o0?mQo`3oR?l02Ooo08Woo`0Vo`;o
0?mQ02SookX0ooooooo<o`3o0000o`3mool0P?oo`_l0o`3mool0R_oo0?goolco0?mno`3oTOl0okgo
0?m2o`3o0000olco0?oooooo_Ol0o`000?ooooooEOl0okgo0?l0oj7o_Ol0o`3o<ol0ohGo08[oolco
0?l02Ooo0?mQooooooo<o`3ooch0o`3moooo?P3ooooooolm0?ooooooocd00_l0e?l00oooF`3o0?go
o`3mo`03o`000007o`3mool09_ooooooooooooooI@3oooooo`3oX@02ooooo`03oomU0?oooooooooo
00;ooooo00KoofH0o`2Iool0U?oo09Coo`2?ooooI`03ooooo`03olSo0?ooI@3ooooo00?o0?3o00Co
`Ol0oooooooooooo`Ol02Oooool00om3o`3oooooo`3o^002o`3o^004o`3[ool0003o06_oo`1[o`;o
00000ol0YOl6ooooo`04o`000?ooooooooooooooo`;oob/01?ooool2ool[0004oooooooo:`3oob/0
ool[00?ooooo0_oo:`1Yooooo`00O?ooool00ol0003oooooooooo`0<ooooo`03o`000?l0NOoo07Wo
00Gooooo0ol0on`4o`3og007oom]0?ooooooooooo`3omOo4o`3oofd0olCo0002o`3om@04olCo0?oo
K03oa_l0olGo00?ooooo00?oof`0ooooooooool00_ooool00oooJ`3o05ooo`1Oo`03o`3oXP03o`3o
XOnmo`3ooc/000;o_Ol000?ooc/0o`3oHOoo>`000_nmo`000ooo>`3o<`3ooolk0002okgo0004o`3o
HOl0oc?o0?n4o`0000;o05Co00?o0?n8okgo0?nmo`000_mSo`001?nmo`3oDol0okgo0?l0oeh2okgo
0003oomT0?nmo`3oof<000Ko_Ol000?o0=Coo`000?l000000_nmo`000ol0og?o0?goo`3mo`05o`3m
o`;o0?nQ00Oo0?mco`09oooooooo08Woo`3oR?oooooo0?nQ00;o0?mQ00_o`_l0o`20ool0003o@_l0
o`3moooooooo08[oo`3mool0e?ooc?l0ooooo`03okgo0003ooooooo<o`3o0?go00?ooooo0_nmo`02
o`00000<ooln0?oooooooch0o`3oXOoo?@3o__l0oolm0?oooooo0?gooomK0?l0003ooooo0_l0e?l0
4?l;o`3oooooooooooooooooofD0o`0Vool0003oooooo`000?ooI@3o0?goooooool09_oo0?n8oomV
0?l0oj42ooooo`03o`2DooooI`3o08oo00;ooooo00CoofD0oooooooooooooooo0ol0l?l2ooooo`04
olSo0?oooooooooool7o00?ooooo00?o`Ol0ooooooo1o`000_ooool3o`3o^0Oooooo0ol0YOl00ol0
joooooooo`1[o`02o`1[o`?ooooo1Ooo:`02ooooo`;oob/000?oooooool[0?oo:`00F?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo0ol0NOl6ooooo`?o0<So0_ooool3o`3o
k003o`3omOl0omco0?oL00;o0?oL0_ooool01?o4o`3oooooo`3oc?ooK@02ooooo`03olGo0?oooooo
ofd000Gooooo00Soof`0olKo0?oooooo0?gookgo0?ooK03o_Ol0o`3oX@;o05oo00Koof/0o`3oX_l0
of7o0?mQokgo0?l00002okgo000;oolk0?nmo`3o<`3ooolk0?nmo`3ooc/0okgo0?oo>`3o0?lcoolk
0?l0E?l00_nmo`000ol0ohCo_Ol0okgo0002of?o0004oe?o0?nmo`3o0?mNo`3oGPWo_Ol000?oof@0
o`000?ooH`000onmo`000ol0og?o0?goo`3mo`05o`3mo`08o`3oLol0003o0?n8ooooool02Ooo08Wo
o`3oXOl0og<2o`3oH@0:olco0?mEo`3o083oo`3mooo2o`3o08[oo`3Dool0oOooO_l0oi7o00;ooooo
00So@_l0okgo0?nmo`3o0?gooooooonmo`3oEOl0o`0000;o_Ol000koooooo`3oQOl0oj7o08[oolco
0?l02Oooooooo`3oHOo<o`3ooch0o`3moooo?P3ooooooolm00;o0=Co00Coocd0ooooooooF`3o02Ko
0_l0oOl02?l0003oooooooooool0oOoo02KooomU0?l0ohSo00000_ooool00oooI@3oN_l0o`000002
ooooo`03oomV0?l0U?oo09Co00;o08oo00?oofL0ooooooooool00_ooool01?ooI@3o0?3oo`3`ooo1
o`02ooooo`04ol7o0?oooooooooool7o00Sooooo0ol0okP00ol0joooooooo`1[o`02o`1[o`04oooo
ool0YOoo0:Goo`2Uo`Wooooo00Co0000ool[0?oo:`3oob/00oooool3ool[0003oooooooo:`3oob/0
00?ooooo0ooo:`1[ooooo`00O?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?o
07Wo1Oooool3o`3ok003o`3omOl0omcoofd000;o0?oL00?oa?l0ooooooooK@000_ooool01?o4o`3o
0?o<oom/0?o5o`04ooooo`07oom/0?ooooooooooooooool0003oof/0ooooo`02o`1Oo`0Jo`000?l0
oj;o0?nRoolk0?oMo`3o<`3ooolk0?nmo`3ooc/0o`000?l0of7ooc/0olco0?oo>`3o08[oo`3oXOl0
of7o0?lco`000?l0ohCo0000ooooool0oj7o0?n8of?o0?l0R_l2oe?o00;o0?mN0_l0oOl01OooI03o
0?gooomS0?l07oooPol000?ooooo00So0?lUo`000?l0003ooooookgo0?l0003o0?goo`3oL`;o0000
1Onmo`07o`3mo`Co_Ol000Go`_l0ogko0?l0003o0?mcod;o0002okgo0003o`3mool0R_oo_Ol000Co
_Ol00_l00007okgo000:o`3oQOoo?P3o_Ol0ooln0?nmo`3oocd0okgo0?l0003oocd0o`3oH@;o0000
00co0=Cooooooonno`3oooooo`_o0?l0003oofD0o`3oG?l0003o0?goo`0VooooI@02ooooo`;o0000
00coofH0o`000?l0oj7o09Coo`2?ooooI`3oN_l0ooooool0003ooooooomU0?ooool2o`3`o`Gooooo
00Cob?l0oooooooooooo`Ol00_ooool00oo1o`3oooooooooo`03o`3o^0Oooooo0ol0YOl00ol0jooo
00Coooooo`02o`1[o`?ooooo1Ooo:`02ooooo`?oob/000?oooooool[0?oo:`00F_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l0NOl3ooooo`Oo0?oe0_ooool3o`3ok003
ooooooo4o`3o0?oL00?o0?oL00Go0?o<olCo0?ooK@3oooooolGo0002ooooo`03oom]0?oooooooooo
00;ooooo00ko0000oom/0?oooooo0?goo`000?l0oj7oof`0o`3oR?l0oj7ooooooom[0?l0Gooo0?nR
o`3oI0;o0?mQ00go0000oooooooo>`3o0000oolk0?lc0?oo0?gooolk0?oooooooc/0o`3o<ooo>`3o
oooo00?o0?n800Ko0?n4of?o0?ooooooDol0o`_o0?l0oeh4o`3mo`04oh?o0?ooooooooooo`3o9@;o
oooo00Soof@0o`000?l?o`3oof<0oonj0?o7o`3oooooo`3oL`;o00001Onmo`07o`3mo`?o_Ol000[o
0?mQo`20ool0og?o0000ol;o0?nmo`3o08[oo`3moomno`3oTOl00onmo`000om2o`3o0000o`00000>
okgo000?o`000?oo?P3o0?mQooln0?l0003o0=Cooolm0?l0oecoocd0o`0VooooF`3o0000ooooool0
003o02Ko00?ooooo00Co0000oomU0?l0003o00000_ooool01_ooI@3oooooog[o0?l0VOooofH0o`2D
o`;o08oo0_ooool00oooI`3oooooo`3`o`02o`3`o`04oomU0?oooooooooool7o00;ooooo00Co`Ol0
oooooooooooo`Ol01Oooool3o`3o^0;o0>_o00?o00Coo`1[ool0Jol01?l0YOl;ooooo`;oob/00ooo
ool3ool[0004oooooooo:`3oob/0ool[00;ooooo0ooo:`1^ooooo`00O?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00?ooooo1_l0ooD2ooooo`?o0?o/00?oofd0ooooool0om`00_l0
om`01_ooK@3oooooolCo0?l0olcooooooom/00Gooooo00Soof`0oooooooooooo0000ooooooooJ`3o
_Ol0ooooo`;o05oo00co0?nQo`3oX_l0oj;ogOl0oolk0?l0og3ooc/0o`2:oooo>`3o0?mTo`3oHOoo
>`02o`00000<o`3mool0oc?o0000o`000?l0ohCo0?nQoooooomSo`3o0?gooe?o0?l0ohSo0?mN0_l0
oOl01ol;o`3o00WooomT0?ooooooof<0o`0Ooon3o`000oooool02?l0obGo0000o`000?l0003o_Ol0
o`3mool;o`3o0?mc0_l000002?l0oOoo00Woo`3mool0oOoo0?mQooooool0ohSo0?mc0_l0GOl00ol0
2Ooo0?n8o`3mo`02o`3mo`0:o`20ooo2o`3o0?goo`3mool0003o0?good;o0?l0R_oo0?goolco00;o
08[o0_l0oj400ol0oOoo0000o`000002o`3mo`03oeGo0?l0oOoo0?go00;o_Ol000Oo2ol0o`3moooo
?P3o08[oooln0?l02Oooocd000;o000000Go0?mQo`000?l0003ooooookko0003ooooo`0=o`000?oo
I@3o0000ooooool0003o0?gooomU0?l0003o0>7oo`000?ooIP3o0000o`2Do`02o`2?o`06oooooooo
I`3oooooog[o0?l0003oofD00_l0l?l6ooooo`05olSo0?ooooooooooooooooo1o`000_ooool3o`3o
^003ol7o0?oooooooooo00Cooooo0ol0YOl3o`3[o`03o`04ool0Jooo06_o00?ooooo0_oo:`001Ooo
ooooob/0ool[0?oooooo000000;oob/000Goooooool[0?oo:`3oob/0o`00001Kooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool8o`3om@Kooooo0_l0b?l2ooooo`03ol?o0?l0
om?o0?o/00;o0?o/00?oooooolCo0?ooool00ol0om`00oooK@3oaOl0ooooo`02ooooo`08oom]0?oo
ooooooooooooool0003oof`0o`3moonmo`02ooooo`06oom/0?l0ohSo0?nQomgo0?ooooooof/00_l0
Gol03ol0oj;o08[oo`3oI?l0003ooc/0o`3oHOoo>`3o0000o`3moooo>`3ooooooolk0?l0oc?ooc/0
o`3mo`02o`2:o`06o`3mool0ohCo0?n8oe?o0?l0oOoo0?mN0_o7o`001?oooooo0000o`2moon3o`02
ooooo`0;o`3o9OoooooooooooomT0?l0003oof<0o`000?o7o`3o2ol0ooooool0og<00_l00003o`3o
H@;ooooo00Oo0?mco`1Mool0ohSo00Woooooool02Ooo02Ko00?o0?go00Wo083oo`3mool0oOoo0?go
ol;o0?o<o`3o0?nQogko0?nAo`000_l0oj42o`3mo`03od;o0?l0003o000000?o0?go00_o_Ol0o`_o
0?nmo`3o0?n5o`3moonno`3oc?l0o`3mool02Ooo0?nQolco0002o`000009ooln0?l0003ooch0okko
0?oo?@3ooooooolm0?oooooooe/000;o000000?o0?goo`0Vooooool00_ooool02_ooI@3o0000o`00
0?l0oj7ooooooomU0?oooooo09Woo`2DooooIP02o`2?o`?ooooo00?oofL0o`3`ool0l?l00_ooool0
1OooI@3ooooooooooooooooo`Ol000;ooooo00?o`Ol0ooooooo1o`000oooool3o`3o^005od?o0?l0
jooo0>_oooooool01?l00ol0YOl2ooooo`03o`000?oooooooooo00Oooooo0ooo:`000ooooooo0000
ooooo`02ool[0004oooooooo:`3oob/0ool[00?ooooo0_oo:`1aooooo`00O?ooool00ol0003ooooo
ooooo`0<ooooo`Ko0?oe0_ooool3o`1io`Gooooo00Co0?oCo`3ok?ooK@3o0?o/0_ooool01oo4o`3o
ofd0o`3og?l0omcoooooolKo0?ooK0001Oooool01_ooK03o0000o`000?l0oj7o0?gooom[00?ooooo
0ol0Gol2o`3oXP07oooooooo>`3ooooooolk0?l0003oc?l0oolk0002o`00000<o`3mool0oc?o0000
o`000?nmo`3o0?n4of?o0?l0oOooDol0o`2:ool0oeko05go0_l0ohP01Oo<o`3oof@0oh?o0?o7o`3o
of<000Co0?go00?o0?lUo`_o0?nmo`000_l000001onmo`3o0;Koo`3mool0003o__l0olOo0?l09_l0
0_l0oOl2o`3oH@03o`3mool0ohSo0?mc00;o0?go00Wo0?n8o`3mool0oOoo08Woo`20ool02Ooo`_l0
o`3oLonmo`000_l0oOl00om2o`3o0?goo`3mo`02o`3mo`06o`3Dool0003o0000o`3oXOo<o`3o_Ol0
0_mEo`03o`3oX@09o`3oQOnmo`3o0000olco0?oo?P3o__l0ooln0?l02Oooocd000;o000000Koocd0
o`3mooooF`3o_Ol0okko0?ooool2o`0Vo`0;oomU0?l0003o2ol0o`000?l0oekoofD0o`3mool09_oo
0>7oo`3mooooIP000_l0Sol01?l0oj7ooooooomW0?ooool3o`3`o`03oomU0?oooooooooo00Kooooo
00Cob?l0oooooooooooooooo0ol0okP01?o1o`3oooooooooooo1o`03ooooo`?o0:Go00Koooooo`3[
ool0joooooooo`1[ool01?l4ooooo`Goob/00_ooool2ool[0003oooooooo:`3oob/000?ooooo00?o
0000ooooooooool0FOooool00ol0003oooooooooo`04ooooo`Oo0?oe2?ooool3o`1io`Gooooo0_l0
b?l00oo3o`3oooooooooo`02o`3od`?o0?o/00Co0?o<ooooooo4o`3oofd00ol0om`01?ooooooofd0
ooooooooool2o`000003o`3oXOooK03o_Ol000?ooooo00Ooof`0o`2cool0oj7o_Ol0oc<0ooooJ`3o
oooo00;o05oo00co0?nRoolk0?l0003o0?nQoolk0?l0003ooc/0o`3oHOlc0?oooc/0o`3o<ooo>`03
o`3mo`03of?o0?mCo`3o0?n400;o0?mN00?o0?n8o`3mool0oOl01Oo7o`002Ol0oOoo0?lUo`3moooo
I03o_Ol0o`3mooooH`3o0000olOo0002o`09o`05o`000?l0oOooaol0o`3oHOl0oOl00_l0of401?l0
ohSo0?mco`3mool0ohP5o`3mo`0;o`29ool0P?oo_Ol0ooooool0R_oo0?mcol;o0?l0oOooO_l0o`3m
oonAo`000_l0oOl02?l0oj7o0000o`000?m2o`3o0?nQokgo0?l0oj7o_Ol00_l0oj402Onmo`3oaol0
okko0?o<o`3o0000ooooool02Oooooooolco0002o`00000;ooln0?l0oOoooch0okko0?oo?@3o02Ko
oolm0?oo^P3o0000oomK0?l;o`000_l0oOl02Ol09_oooooooomU0?l0oOoo0?n8ooooool0oj7oofD0
o`2Io`02o`2Do`04o`2?ooooIP3o0000ooooo`;o0?3o00?oofL0ooooooooool00_ooool00oooI@3o
b?l0ooooo`02ooooo`03ol7o0?oooooo`Ol000;ooooo00Go`Ol0o`3o^?l0okSo0?nhooooo`03o`3[
o`04ooooool0YOoo0:Goo`2Uo`Gooooo00?o0000ooooooooool01Oooool2ool[00?ooooo0ooo:`00
0oooooooob/0ool[0003ooooo`?oob/0Loooool007cooooo00?o0000ooooooooool00_ooool2o`00
00;ooooo1_l0ooD00ol0003oooooooooo`08ooooo`;o07Wo0oooool01?o3o`3oooooo`3odoooK@04
o`3ok006oom]0?l0olco0?oLo`3og?o6o`3oof`01?ooool00ol0003oof`0o`000002o`000003oooo
ooooJ`3ooooo00;ooooo00Cooc/0o`2cool0Gooo05oo0_l0oj802Ooooooooc/0o`3o/Ol0003ooc/0
o`3mool0of7o0?goo`3o<`02o`00000?okgo0?mSo`3o0?n4oe?o0?l0Dooo0?mNo`1Cool0GOoo05?o
o`3oHOl0ohSoof@0o`3oR?ooH`3o000000Coaol000ko2ol0okgo0?l0e?oo0?mQo`3moonmo`3o0;Ko
o`000?l0og?o__l0olOo0?l09_oo0?goo`3oH@;o2ol000?o0?mQo`3oR?l0og<00_l;o`003_l0ohSo
0?goo`3mool0P?oo08Woogko0?o2o`3o0?mcolco0?l0R_oo0?mco`000?m2o`3o0?go0_l0oj404?l0
oOoo0000o`000?l0oOooc?l0oeGo0?nmo`3o0?gooooooonmo`3o0?n5oooooonmo`3o0000olco0?oo
?P02o`3oX@08ooln0?oo?@3oc?l0oooooooo?@3o0?mQoomK0?l00002okgo0004ooooool0003oofD0
ooooo`?o000000KoofD0ooooool0oOoo09CooomV0?l0Sol2ooooo`04o`3oXOooI`3o0?3oo`3`o`;o
oooo00?oofD0ooooool000001oooool01?o8o`3o0?nho`3o^?l0okP3ooooo`03ol7o0?oooooo`Ol0
00;ooooo0_l0YOl01?oooooo0>_oo`3[ool0jol3o`1[o`03o`04oooooooooooo00Goob/00_ooool3
ool[0003oooooooo:`3oob/000Gooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`04
o`3om@;ooooo00?o0000ooooooooool03Oooool3o`1io`Gooooo00?o`ol0o`38ooo4o`000_ooool2
o`3od`;o0?o/00Goa?l0ooooooooK@3oaOl0ooooo`02o`3og007oom]0?l0omco0000o`000?l0oOoo
a_l0oom/0003ooooo`07o`3oR?ooK03o0?nQokgo0?oMo`3oof/0o`3o/@02ooooo`;o05oo00_o0?nR
o`000?oo>`3o0?gooolk0?l0of7ooc/0oc<0ool0oc?o_Ol0o`2:o`02of?o0004oe?o0?l0Dooo0?mN
o`3oQ0;oc?l00_l0ohP00ooooooo0;goooooo`02ooooo`0>olOo0?l0obGoof@0okgo0?l0e?ooof<0
o`2foonmo`3ookX0o`_o0?l0003o0?mcolOo0?l0oOl4o`_o0005o`3oR?l0og?o0?n8o`_o0?l0GOl0
0_l0oOl04?l09_oo00Woo`20ool0ROooooooo`2:oooooooo`_l0oeGo0?nno`3oO_l0oi7o0?oooooo
0=Coooooool0oOl2o`000004od;o0?o<o`3o0000okgo00?ooooo023o_Ol0okko0?l0oj7oc?l0o`00
0?l0oj7o00Woo`0Vool0e?oo_Ol0o`3oXOoo?P3o0?mQooln0?nno`3oocd0oooooooo^P3oocd0o`00
0?ooF`3o0>7oo`3moooooooo0?goo`0VooooI@3o0?goo`3oR?oooooo09WooomU00?o08oo00KoofH0
o`3`ool0l?oo0?3oooooooooI`04ooooo`03oomU0?oooooob?l000;ooooo00Co`Ol0oooooooooooo
`Ol00ol0okP2ooooo`;o0>_o00Goooooo`2Uool0YOoo0:Goo`04o`07ooooo`03o`000?oooooooooo
00;ooooo0ooo:`03ooooo`;oob/000Coooooool[0?oo:`3oob/00oooool2ool[07Kooooo001loooo
o`03o`000?oooooooooo00;ooooo00Co0000o`3omOl0ooGo0?oe1_ooool00ol0003oooooooooo`0:
ooooo`?o07Wo00Go`ol0oooooooooooooooooom]0002o`3od`08ooooooooK@3o0?o/o`3ok?oooooo
a_l0ooooooooK003o`3og0;o000000Goof`0o`000?l0003ooooooom[0003ooooo`04oolk0?l0oj7o
oc/0ooooo`;o05oo0_l0oj806?l0oOoooc/0o`000?l0oj7o0?mQo`_o0?l0003o0?lco`3moonmo`3o
0?mQoe?o0?l0ohCo0?mNo`3moooooooo05goooooool0of7o05?ooomT0?o<o`3oof<0o`3oR0Co2ol0
00ko0?lUokgo0?l0e?oo0?goolOo0?nmo`3o0000o`2foooo^P3o0?mcolOo0?l0oOoo0>;oo`3mo`;o
oooo00Co0?n8ooooool0og?o0?mQ0_l0oOl2o`00000;o`_o0?mno`3oTOl0ol;o0?l02Ooo08[ookgo
0?l0og?oc?l0o`000?m2o`000_l0of401?l0oj7o0=CooooooomEo`03o`3mo`;o_Ol001_o0?goo`3o
QOl0003o0?goolco0?o7o`3o08[oooln0?l0e?oooch0oooooooo?@3ooooooolm0?l0of7o0?gooomK
0?l0oOoo0?nQokgo0?ooI@3ookX0o`000?oooooo0000oomU0?l0oOl00_l0U?l00ol0SoooofH0oooo
o`03o`3`o`08oomW0?ooooooooooooooooooI@3oooooog[o0?l00005ooooo`?o0?nh0_ooool01?o1
o`3oooooooooooo1o`02ooooo`?o0:Go00Coooooo`3[ool0jooooooo0_l0Jol01?m3o`3o00Coo`04
ooooool2ool[0003oooooooo:`3oob/000;ooooo0_oo:`001_ooooooob/0ool[0?oo:`3o0?oKo`00
00Gooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`02o`0000Cooooo00?o0000oooo
ooooool04?ooool2o`1io`?ooooo00Oo`ol0ooooool0b?ooa?l0o`38ooooooooa?l000;o0?oC0ol0
on`00oooK@3oooooooooo`02ooooo`03oom]0?l0omco0?oL00;o0?oL00_oof`0oooooooooooooooo
o`3oR?ooK03o_Ol0o`3oXOoooooogOl0oom[0003o`3mo`0@oolk0?l0Gooo0?nRo`3oX_l0ofCooc/0
o`3oHOoo>`3o0?goo`3o<onmo`3oHol0o`2:oomCo`3o0?goo`3oGP;ooooo00Co0?n4o`3moon3o`3o
2ol00ol0ohP01ol;o`3o0?mQo`_o0?l;o`3oof@0okgo0?ooH`000_l02Ol02?nmo`3oaol0o`000?oo
oooo0?mcolOo0?oooooo0?go0oooool00ol0ohSoooooo`3oL`02o`3mo`;o2ol00_l000002_o<o`3o
0000o`29oonmo`3ooooool;o0?mEo`3oO_l0oi7o0?l00002o`3oH@06o`3DoomEo`3o08[oo`2:ooo<
o`3o@_l00_l0oOl03Onmo`3o0?goo`3oQOnno`3o_Ol0olco0?l0R_ooooooo`0Vool02Ooo0=Cooooo
oonmo`000_ooool02_oo?P3o0?goooln0?l0oOooocd0okgo0?oo?@3ooooooomK0?ooool2o`000004
o`3mooooI@3o02Koo`3oR0;o09Co00_oofD0o`2?oooooooo0?3ooomV0?l0l?ooooooog[o0?l0003o
oooooomW0004ooooo`03oomU0?oooooob?l000;ooooo00Co`Ol0o`3o^?l0okSo0?nh0_ooool00oo1
o`3o0>_oo`3[o`03o`2Uo`;ooooo00?o00Coooooooooool01_ooool2o`0000?oob/00oooool3ool[
0004oooooooo:`3oob/0o`0000;ooooo0ooo:`1hooooo`00O?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo00So07Wool?o0?ooooooooooolCo0?ooK@3oa?l0o`3od`?o06ko
0_l0on`01Oo6o`3ooooooom/0?oooooo000000;o0?oL00Koof`0o`3og?oooooo_Ol0ooooooooJ`02
ooooo`06oolk0?l0oj7ooc/0o`3moooo>`3ooooo0_l0Gol3o`3oXP0:o`000?l0of7o2ol0o`000?l0
oc?oHol0okgo0?mCo`3o0?mNo`3oQ0;o0?mQ00Wo2ol0o`1Mool;o`3o0?mQoomT0?ooooooof<0oh?o
0?o<o`000_l0ohP06?l;o`3o0?mQokgo0?l0ohSo0=CoobCo0?l02Ooo0000olOo0?l0]_oookX0o`3o
Lol0oOoo02KoolOo0?oooooo0?goooooool0ohSoooooo`3oLol0oOoo0?mQo`3oR0;o000000Oo2ol0
ogko0?l;o`3o`_l0o`2:ool0og?o2ol000;o000000WoEOl0od;o0?nno`3oooooo`3oHOoooooo0=Co
o`3oXOo<o`000_l0R_l3o`3mo`0Cooooool0003o0000olco0?o7o`3o08[oooln0?l02Ooooch0oooo
oooo?@3o_Ol0oooooooo?@3o0?mQoomK0?oooooo0?gooomU0002okgo0003o`000?l0oekoofD000;o
09Co0_l0Sol01_ooIP3o0?3oo`3`oooooooo0?nQoomW00Cooooo00KoofD0ooooooooooooN_l0o`00
0?ooool3o`3o^003ooooooo8o`3ooooo00;ooooo00?o`Ol0ooooooooool00ol0YOl01Oo1o`3o0>_o
o`3[ool0jooooooo00;o06_o0_m3o`000ol01?ooob/0ool[0004ool[00;ooooo0_oo:`001?oooooo
ob/0ool[0?l0om/2ooooo`;o00001Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool04_ooool3o`1io`09ol?o0?ooooooooooolCo0?oooooo0<SoolCo
0?l0olcooooo00;o0?oC00gooooooom]0?l0onco0?o/ooooool0003ooooooom]0?l0oj7o0?gooooo
ooo6o`3oof`000;o06ko00Co0?n8o`3mooooK03o0?nQ0_l0oOl01_l0003oof/0oooooooooooooc/0
o`3oX@;o05oo0_l0oj802Ol0of7ooc/0o`1Mool0oc?o_Ol0o`3oHOmCo`3o0?mQo`3oGP02o`_o0008
o`3oHOl0ohCo0?gooooooon3o`3oooooo`1Cool0of43o`3oR00>oomT0?nmo`3o0=CooomS0?l0ohSo
aol0okgo0?l0003o0?n8o`3oHOnno`3o0?mcolOo0?l0oOl3ooooo`04o`3oR?l0oOoo0?goooooo`;o
0?mQ00?oooooo`000?l000000_l0R_l02_l0og?o08Wookgo0?o2o`3oO_l0o`000?nAo`3o0?goo`00
0?mEo`02o`3oH@06o`3oXOo<o`3o08[ood;o0?l0oOoooooo0ol0oOl01Ol;o`3o_Ol0olco0?l0R_oo
02Ko00;o0=Co00ooc?l0okgo0?oooooo0?mQo`0Voooo?P3o0?mQooln0?l0oj7oocd0o`000?oo?@3o
_Ol0oomK0?ooool00_l000001_ooI@3o0000o`2Dool0U?oo08oooomU00?o0?3o00?ooooooomV0?oo
ool00_ooool00omjo`3oofL0ooooo`03ooooo`04oomU0?oooooob?l0ooooo`?o0?nh0_ooool3o`2[
o`?o0:Go00Go06_oooooooooooooooooo`04o`09ooooo`;oob/000?o0?oKooooooooool00ooo:`00
1?ooooooob/0ool[0?oo:`02ooooo`?oob/0Noooool007cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0>ooooo`0:ol?o0?l0NOoo07WoolCo0?ooK@3oooooolCo0?oooooo0?oCoom]
00Co06ko00?o0?o/oom/0?l000000_ooool00ol0oOooof`0o`3og002o`3og003o`3mooooJ`3ooc/0
00;o2ol000?ooc/0o`_o0?oo>`000_l;o`001?oo>`3o05ooo`1Oool0oj42o`3oXP0:o`3mool0003o
0?lcokgo0?mCo`3o0?mNo`2:ooo<o`3o0?n4o`2:o`?o0?mQ00cooooooomT0?ooooooof<0oooooon3
o`3oc?l0o`_o0?l0ohSo_Ol0o`3oR?l0e?l2o`09o`09o`000?nmo`3o05?oo`2fool0of7o0?mco`3m
ool09_oo0?n800;oaol00ol0oOl01?l0og?o0?n8o`3oR?l0ohP2o`3oH@04ogko0?nAo`3o0?n8ol;o
00;o000000So0?mco`000?l0003oc?l0o`3moom2o`3o__l0oeGo00;o0?mQ00Oo0=Coolco0?l0oj7o
0?nQo`2:ool0ohGo_Ol000;o0?go00koc?l0okgo0?l0e?oo0=Coo`_o0?oo?P3o_Ol0ooln0?o<o`3o
ocd0o`0Voooo?@3o0?mQoomK00;o000000KoofD0o`09ool0003o0000o`2DooooI@02o`2?o`04o`3`
ooooIP3o0?3oo`3oR0;ooooo00?o0?nQoomW0?ooool00_ooool01?ooI@3oooooooooooooool3o`2[
o`Cooooo00Cob?l0o`2<oooooooo`Ol00ol0YOl01Oo1o`3oooooo`3[ooo1o`3ooooo00?o06_o00?o
oooood?o0?ooool00_oo:`000oooooooob/0ool[0002ooooo`?oob/000?o0?oKool[0?oo:`001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Eooooo`04ol?o0?l0NOoo07WoolCo00?ooooo00Coa?l0o`38ool0b?oo
a?l00_l0om<00oooK@3oooooo`3ok002o`3ok008oom]0?l0oOooooooo`3mooo6o`3o0?gooom/0?l0
oOl3o`1^o`0;oom/0?l0oj7o0;?oo`000?ooJ`3o2ol0oolk0?o<o`3o0?nQoolk0?o<o`000_l0Gol2
o`3oXP04oolk0?l0oc?oDol0oe?o00;o0?mN1?l0of405_l02Ooo0?n4oooooon3o`3oc?l0o`3oHOl0
003o2ol0o`000?l0ohSoof@0o`3oR?ooH`3o05?oolOo0?l0oOoo0000o`2fool0of7o0?gookko0?l0
og<2o`3oR006o`3mooo7o`3o0?goo`3mooo7o`3o0?mc0ol0ohP03?l0of7o02Koo`2:ooo<o`3o0?n8
o`09ool0og?o0000ol;o0?mno`3oTOl0o`0000;o0?go00?o0000okgo0?l0e?l00_l0of406_nmo`3o
08[ood;o0?oooooo0?n5okko0?nmo`3o0?goolco0?l0oOoo08[oo`3Dool0oOoo00Woolco0?nmo`3o
ooooo`0Voooooooooch0o`3oHOoo?P3ookX0oolm0?l0oOooocd00_l000001OooF`3oooooo`3moooo
I@3o09Co00;o08oo00?oofD0o`3`ool0oj400_ooool00oooIP3oooooooooo`02ooooo`03oomW0?mj
o`3o000000;ooooo00?oofD0ooooool0okP00_l0okP00ooooooo0:_oo`2[o`02o`2[o`?o0:Go0_l0
Jol4ooooo`03o`04oooooooooooo00Gooooo0ooo:`000ol0003oooooooooo`02ool[0004oooooooo
:`3oob/0ool[00?ooooo0_oo:`000ol0003oooooooooo`1kooooo`00O?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00kooooo00ko`ol0ooooooooooooa?l0o`1iooooK@3oa?l0oooo
ooo4o`3ooooooom]0?l0om?oaOl0olKo00Co06ko00Ko0?o/o`3mool0oOooof`0o`_o0?nmo`02o`3o
g00;oom[0?l0omco08[ooolk0?l;o`3ooc/0o`_o0?l0003ooc/0olco0?oo>`000_l0Gol01?l0of7o
0?nRo`3oX_l0oc<6o`000009o`3oQ?l0003o0000o`000?ooI03o0?mQooooooooH`3o0?mQ00;o2ol0
00ooc?l0o`2moonmo`3o0?goo`3Dool0ohSo0000olOo0?nmo`3oooooo`3oHOl0]_oo0?mco`1Cool0
9_l00_ooool2o`3mo`03o`3oR?l0of7o0?mc00;oaol000Co0?n8olOo0?o7o`3oO_l00_l0R_l02_o2
o`3o0000o`29ool0ROoo00Woo`3oLoo<o`3o0?goo`_o0?m2o`02o`_o0006okgo0?l0of7o0?mQokgo
0?l0ohSo0?n50_l0R_l00onmo`3o__l0olco0004o`000003ooln0?l0003ooch000Oo000000?oofD0
o`000?l0oOl00_l0U?l02?ooI@3o08ooo`3`ool0l?oooooooomV0?l0ohSo0?go0_ooool00oooI`3o
ooooooooo`02ooooo`05oomU0?l0Zooo0:_oo`2[ool0okP00_l000001Ooooooo08coo`2<ool0S?oo
b?l000?o0:Go0_ooool01?l0jooo`Ol0o`3[ooo1o`02o`1[o`;ooooo0_m3o`02ool[0003oooooooo
:`3oob/000;ooooo0_oo:`001?l0om_oob/0ool[0?oo:`05ooooo`?o0?oO1_ooool00ol0003ooooo
ooooo`1Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool01?o3o`3ooooo
olCo0?l0NOl2ooooo`09olCo0?l0olcoooooolCo0?l0b?ooooooo`3odoooK@3o0?oC00;ooooo00?o
0?o/oom]0?l0on`00_l;o`001?o6o`3o2ol0oom/0?l00002o`2:o`03oom/0?l0K_oo06ko00;o0?oL
00Soof/0oolk0?oooooo0?nQoolk0?oooooooc/0o`0000;o05oo0_l0oj8:o`00000Do`3oQ?oooooo
Pol0olco0?l;o`3o0?n8o`09ooooI03o_Ol0oonj0?ooH`3o0?n8olOo0?l0003o_Ol0o`3oHOl0Dooo
0?gookko0?l0og<2ooooo`;o0?go00Co0?n8o`3oHOoooooo0?mc1?o7o`002ol09_oo0?mQo`3oHOl0
GOoo0?goo`09ool0003oO_l0oi7o0?o<o`3oEOl000;o0?go00Go2ol0o`000?l0ohSo0=Coolco0002
o`3oH@08od;o0?l0R_oo0?n5o`3oR?l09_oo_Ol0olco0?ooool9o`000003ooln0?l0003o000000;o
000000Ooocd0o`3mool0003o0000o`2Iool0U?ooofD000;o08oo00Oo0?3oo`3mooooI@3oooooo`3o
XOooooooofH000Cooooo00KoofL0o`2<oomjo`3o0000ooooooooI@02o`3o^0Co0:_o1?l0YOl2o`1[
o`03ol7o0?oooooooooo00?ooooo00?o00Coooooooooool00oooool00ol0om_oob/0ool[0003oooo
o`?oob/000?oooooool[0?oo:`000oooool3ool[00;ooooo00?o0000ooooooooool0Noooool007co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`04o`000?o<o`3ooooool?o
00?ooooo00?oa?l0ooooooooK@000_l0NOl01Oo4o`3ooooooom]0?l0om?oa_l000;o000000?oof`0
o`_o0?l0K_l00ol0K_l01_ooK03o_Ol0o`000?l0003ooc/0oom[00?o0?oL00Sooc/0o`2:oooo>`3o
08[oolco0?oo>`3o0?goo`0000;o05oo00ooDol0o`3oX_l0oj;oaol0o`2:oooooooo<`3oo`2:ool0
oOoo0?n4o`1Mool0of7oof@0o`000?ooH`001Ol000000onmo`3o0000o`00000Jo`000005ol;o0?l0
003o0000o`000?l0ROl01?l000000om2o`3o0000o`00000;o`000005o`_o0?nmo`3o0?n8o`3moooo
?P000_l000002?oo?P3oocd0oooooonno`3oocd0o`3oHOl0003oofD00_l0U?l2o`2?o`0;oomU0?o=
o`3o0000okgo0?ooIP3o02Koo`3oR?l0oOoooooooomW0?l0oj400_ooool01?l0ZoooofD0o`2[ool0
okP3o`2:o`?o000000Coooooo`2Uool0YOoo0:Go0_ooool01?o1o`3o0>_oo`3[ooo1o`02o`1[o`04
ol7o0?ooooooooooooooo`Koob/000Goooooool[0?oo:`3oob/0o`3of`02ool[00Gooooo0ol0oml0
0ooooooo0000o`000006ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Booooo`05o`000?o<o`3oooooooooooo3o`000_ooool03?o4o`3o07Woo`1i
ooo4o`3o0?o<ooooooo4o`3oooooo`38ooo5o`3o0000oom]00;o0?oC00?o0?goo`000?ooK@000_l0
on`01Oo6o`3ooooooom/0?l0003ooooo00;o000000?oof`0o`3oXOl0K_l00_l0K_l02OooJ`3o0?oL
oolk0?l0oOoo0000oolk0?l0of7o0000of?o0002o`1Oo`;o0?nR00Co08[oo`3oI?lc0?oooooo0ol0
of400ol0R_oo0000o`3oQ005o`000003oomT0?l0003oof<001go000000?oO_l0oi7o0?l000002ol0
00001Om2o`3o0000o`000?l0003oc?l000;o000000?o0?n8olOo0?l02Ol00_l0oOl2o`00000:o`3o
HOl0oOoo__l0ooln0?l0of7o0000o`09oooo?@3o0000o`2Io`;o09Co00KoofD0o`2?oonmo`3o0?go
o`3oR?ooI@02ooooo`03o`3oXOooIP3ooooo00;ooooo0_l0R_l01?ooI`3o08[oo`3o^?l0okP4o`2[
o`0;ooooool0YOoo0:Goo`2Uooo1o`3oooooo`1[ooo1o`3o@ol0ooooooo1o`001?ooool01Ol01?oo
oooooooooooooooo0?oK00?oob/00oooool2ool[0004o`3ogooo:`3oob/0ool[00?ooooo0_oo:`05
ooooo`03o`000?oooooooooo07_ooooo001looooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool01Ol0003oc?l0oooooooooooo`ol000;ooooo00_oa?l0ooooooo4o`3oofd0oooo
ooo4o`3o07WoooooooooK@3o0000olKo0002o`3od`?o06Ko0_ooool4o`1^o`08oolk0?ooJ`3ooc/0
ooooool0oj7ooc/0o`3og?oo>`02o`3og005oolk0?l0oOooHol0o`3oHOl000000_l0Gol00onmo`3o
0?nRo`3oXP02ooooo`0:oc<0ool0oOooooooo`3oQ?o<o`3oof@0o`3oHOooH`3o2ol0ooooo`;o0?mQ
00So_Ol0o`3mool0obGoc?l0o`000?ooooooaol0o`3oH@?o0?n800go0?goo`3oLol0oOoo0?goo`3o
HOoooooo05?oo`3oR?oooooo0?goo`3oLooooooo0?n800;o0?go00SoO_l0o`3mool09_oo0?n[ol;o
0?l0of7oooooolOo00;o000000So0?mco`3mooo7o`3oEOl0od;o0?nno`3oc?l0okgo00;o000001Ko
ooooo`3oHOl0of7o02Koo`3Dooo<o`3o_Ol0o`3oXOnmo`3o08WoolOo0?l02Ooooch0o`000?oo?P3o
0?gooolm0?nno`3oocd0o`3oHOooI@3o09Co0_l0Sol00oo=o`3oofD0o`000002o`000007o`0Voooo
IP3o0?n8okgo0?l0oOoo08[ooomW0003o`2[o`05oomU0?l0R_oo08[oo`2:ooooool00ol0S?l01OmS
o`3o0:Goo`2Uoooooooob?l000;ooooo00Go0>_ool7o0?oooooo06_ool7o0002ooooo`05ol7o0?oo
ooooob/0ool[0?ooool00_oo:`001Ooooooo0?oKool[0?oo:`3ooooo00?oob/00oooool4o`3og`Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool04_ooool01Ol0003oc?l0oooooooooooo`ol000;ooooo00Ooa?l0oooo
ooooooooa?l0o`3oc?l0NOooa?l000;ooooo00?oaOl0o`000?ooK@000_l0k_l2o`3od`08oooooooo
K@3oooooooooooo6o`3o0?o/oom/0?ooool2o`000003ooooooooK03o0?m`00;o06Ko00?oof/0o`1^
ool0K_l00ol0om`01OmSo`3o0000oe?o0?oo>`3o0?lc00;o05oo00Oo0?nRooooool0oOoo<`3oo`3o
HOl0oOoooooo00;oc?l000?o0?n4o`_o0?l0of400_l0of402OooI03o0?lUo`_o0?ooH`3oaol0o`00
0?l0of7ookX0okgo0002o`3oR0;o0?go00?o0?mcooooooooool00_ooool01?l0ohSo0?goo`3oR?l0
og<2o`3mo`05o`2:ool0U_oo0?n[o`0Voooo^P000_ooool01?l0of7oO_l0oi7o0?o7o`02o`000008
o`3moooooooo__l0o`3mool0003oooooolco0?l0e?l2o`00000<od;o0?l0of7o0?mQo`2:ooo<o`3o
0?nQokgo0?l0ROooaol0o`09ool09_oo_Ol00_l000002?l0oOoo__l0oooooooo?P3o0?mQo`000?l0
oOoo09Wo0_l0U?l02?l0SoooofD0o`000?l0003ooooookgo0?ooI@3o0?go0_l0R_l00ol0oj7oofH0
o`2:o`02o`2:o`03o`2<ooooI`3o0:_o00?o0:_o00?oofD0o`000?l0YOl00_l0YOl02Oo8o`3o0>_o
ooooooo1o`3o06_oooooooo1o`3ooooool7o0004ooooo`04o`04oooooooo0?oKo`3of`;oob/00ooo
ool3ool[0003oooooooo:`3oob/000?ooooo0ooo:`06ooooo`?o0?ocO?ooool007cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`04olco0?oooooooooool?o00;ooooo00_o
a?l0ooooooo4o`3ooooooom]0?o4o`3oooooo`1iooo5o`3oofd0olKo0002o`000003o`3odoooK03o
000000Co06Ko00?oof`0o`3ok?l0K_l00ol0K_l01_l0003ooc/0o`000?oo>`3ooooooolk00?o0?oL
00CoDol0o`000?l0ROoo08[o0_l0Gol01?l0R_oo0?nRo`3oX_l0oj82oc<0o`06o`1Mool0ohCoc?l0
oomS0?l;o`3ooooo0_l0R_l04Ol02Ooo_Ol0o`3oHOl0of7o0000olco0?oooooo0?mQo`0noonmo`3o
0?mQo`3mool0ohSo0?mco`0VoooRo`3o000000;ooooo00ko0?n8o`3mool0oOoo0?mco`3mool0ohSo
0000ogko0?oooooo0?mQoonj0?l09_oo`_l0ooooo`;o0?mQ0_l000001_l0og?o0?goo`09oomEo`3o
@_l0o`0000;oaol00_l000001ol0e?oo02Koo`3mool0e?ooc?l0o`_o0?ooool00_nmo`02o`3oX@0E
o`09oooo?P3o_Ol0ooln0?l0ROooocd0o`3moooo?@3o09CooomU0?l0Sooo08Woolgo0?ooI@3o08Wo
o`3mooo=o`3o2ol0oomV0?l0003o0?n800;o0:_o00?oofL0o`3o4Ol0oa400_ooool00oooI@3ooooo
ooooo`02o`2<o`08ooooool0YOoo0:Goo`2Uoooooooo0000ooooooo8o`02o`3[o`06ol7o0?l0Jooo
06_oooooooo1o`3ooooo0ooo:`001Om3o`3oob/0ool[0?l01?oo0?oK00;oob/000?oooooool[0?oo
:`000_ooool2o`3og`;o0?oc2Oooool00ol0003o9P3oobH0o`04ooooo`03o`000?oooooooooo05Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`04olco0?oooooooooool?o
00;ooooo00Ooa?l0ooooooooooooooooolCo0?ooooooa?l000;o07Wo00coaOl0o`000?l0003oofd0
o`3mool0[ooo0000o`3o/OooK@3o0?nao`3^ooo6o`02o`3^o`0;oom/0?l0onco0?o/ooooool0003o
of`0o`000?oo>`3ooooooom[0?l0I_l00ol0K_l4o`3og003o`3o<ol0R_oo08[o00;o05oo00Go0?nR
o`1Moolc0?oo0?goo`3oI002ooooo`0:o`_o0?l0ohCoPol0o`2:ooooI03o_Ol0o`3oHOooH`3o0=Co
o`0000;o0?mQ00CookX0okgo0?l0oOoo0?go0_l0ohP00ol0og?o05?oo`3mo`02o`3mo`0;o`3oR?l0
oOoo0?n8o`3oLooooooo08[oo`3oHOl0oj_oooooo`0Voooo^P000_ooool01?mno`3oEOl0oi7o0?l0
of42o`000008o`3moomEo`3oaol0okko0?l0oOoo0000olco0?l0e?l2o`00000?o`3moom2o`3ooooo
olco0?l0of7o2ol0okgo0?l0oj7o02Koo`09oonmo`3o08Wookgo0?l0ohSo0?mQ00;o0?go00?ooch0
o`3oHOl0VOl00_l0U?l2o`2?o`07o`3mooooI@3ooe/0o`0Vool0003o0?n8oomU0002okgo0004o`3o
XOooIP3o08coo`2<o`Co0:_o0_ooool00omSo`3oofD0o`2Uo`03o`3o4@07olSo0?oooooo06_oo`1[
ooo1o`3o@ol0ol7o0002ooooo`06ol7o0?ooooooooooooooool01?oo0?oK0ooo:`02ooooo`?oob/0
00Koooooool[0?oo:`3oob/0ooooool00003ool[0003ooooool0003o000000?ooooo0ol0oo<00ooo
oooo0000ooooo`1looooo`00O?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00go
oooo00?oc?l0ooooooo3o`000_ooool01_o4o`3oooooooooooo4o`3ooooooom]00;ooooo0_l00000
1_ooK@3oa_l0o`2_ool0oOoo0:oooom/00;o0?na0_ooool5o`1Vo`03oom[0?l0K_oo06ko00;o06ko
00Oo0?gooolk0?mSo`3o0?m`oe?o0?l0omco000000;o0?oL0_l00003o`1Oo`07o`2:ool0oj;o0?nR
oc<0ool0ohCo00WooomS0002olco0003o`09ool0ofCo_Ol000;o08[o00Oo0000o`3Dool0of7o0?mQ
oonj0?l0of7o_Ol000;o0?go00Coaol0o`3oLol0ohSo0?n80ol0oOl02?l0ohSo05?oolco0?l0og?o
ooooo`3oR?l0R_ooO_l00_ooool01Ooo^P3o02Kool;o0?oooooo_Ol000;o000000[oc?l0o`29ool0
oOoo_Ol0oooooomEo`3o@_l0o`000?l0ROoo0?n50_o7o`02o`3Do`03olOo0?o<o`3o0?mQ00;o0000
01Ko_Ol0o`2:ool09_oo00Woolco0?oo?P3o3_l0ooln0?nno`3o09Coo`2?ooooI@3o0000oomK0?o=
o`3o08[ooomU0?oooooo0?goo`3oXOl0ZoooofH00_l0Zol01ol0oa7oofL0o`000?nmo`3o0?nQo`29
ooooI@000_l0ROl01_l0S?oo0:Goo`2Uool0YOooooooof?o00;ooooo00?o0>_oo`000?o8o`000_l0
Jol01?o1o`3oooooooooooooool2ool[0005oooooooo:`3oob/0ool[0?l0om/00ooo:`001?oooooo
ob/0ool[0?ooool2o`3og`?o0?oc2Oooool3obH0o`;o00001?ooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00oo<o`3ooooool?o0002oooo
o`05olCo0?ooooooooooooooooo4o`000_ooool01?o4o`3o0000o`000?o5o`02o`2_o`08oom]0?l0
oOoo0000o`000?ooooooofd0o`3o/Oo6o`02o`3o/@03oom/0?l0003o000000;o0?n]00Ooof`0oc<0
oooo>`3o0?gooom[0?oo>`3o0?na00;o06Ko0ol0K_l00ol0Dooo0000o`000003o`2:o`;o05oo00ko
0?nRoc<0oolc0?oo00Woo`_o0?ooooooc?l0o`3oQ?ooooooof@0o`2:ooooH`3oc?l0o`0000;o0?mQ
00Soooooo`3mool0oOoo0000o`3mool0]_oo__l0o`3oL`;o0?n801?oc?l0o`3oR?ooooooooooo`3m
ool0og?o08[oooooool0of7o0?n[olco0?l09_oo0000oonj0?nmo`3oO_l0oi7o0?o2o`3oc?l000;o
0000013o08Woolco0?mEo`3o08Woo`3mooo<o`3o0000o`0Vool0ohGoaol0o`3moom2o`3o0=Coolco
0?oooooo0?mQ0_l000000ol0oj7o00Wookgo0002o`_o0004o`ko0?nno`3o3_l0o`09o`?o09Co0_l0
Sol02Ooo?@3o08WooomU0?l0oOoooe/0o`000?l0oOooofD0o`3mo`02o`0000Co0:_o0_ooool00ooo
I`3oooooo`2Uo`04o`3o4@0:o`3[ool0003o06_oolSo0?l0Jooooooool7o0?m3o`3ooooool7o00;o
oooo00?o`Ol0o`3ofol0om/00ooo:`02ooooo`04o`3ogooo:`3oob/0ooooo`?oob/00oooool2ool[
00?ooooo0_lV0?l4o`3ol`Cooooo00?o0000ooooooooool0Noooool007cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03olco0?oooooo`ol000?ooooo00Koa?l0ooooooo4
o`3oooooolCo0?ooK@02o`000009olGo0?l0003oofd0o`3moooooooo0?goo`3oXOooK03ooooo00?o
0?na00Coof`0oolk0?l0ohSooc/01?l0I_l00ooo>`3o06koo`1^o`03o`1^o`03o`3oHOl0003o00Wo
00?o000000?o9?l0o`2:ool0R_l00_l0Gol01?l0of7o0?nRo`3oX_l0oh@4o`2:o`08okgo0?l0of7o
0?mQo`000?l0R_oo0=Coo`3oHOooool3o`3oH@;o0?go00Coaol0o`3oLol09_oo00001?l0ohP03?oo
oooo05?oo`3oLol0oOoo08[oogko0?oooooo0?3ooooooooo^P3o02Kool;o00;oEOl00_l000003oo<
o`3o0?mco`29oonmo`3o00WooeGo0?l02Ooo@_l0o`000?o<o`3o_Ol0o`3Dool0Dooo0=Coolco0002
olOo00;o000000So0?mQokgo0?l0R_oo00Wookgo0?oo?P3o0?nQo`2Do`;o08oo00Oo0?nSoomU0?l0
003ooe/0o`3mooooI@3o000000?o0:_o00?oofH0o`3o4Ol0oa400_ooool00oooI`3o0?goo`000002
o`000004oomU0?l0YOoo0:Goo`2Uo`?o08Wo0_l00002o`3[o`;o06_o00Gob?l0oooooooooooo`Ol0
ooooo`02ool[0005oooooooo:`3oob/0o`3ofoooool00_oo:`001?ooooooob/0ool[0?oo:`02o`3o
g`?o0?oc2_ooool2obH0o`;ooooo00Co0000obH0oolV0?oo00000oooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool01?o<o`3oooooooooooo3
o`02ooooo`04olCo0?ooooooooooolCo00;ooooo00Soa?l0ooooooooooooaOl0ooooool0oOoooooo
oom]00Cooooo00?oofd0o`000?o6o`000_l000003_ooK03o0000o`000?l0ok7ooooooom/0?oo>`3o
0?n]oolk0?ooJ`3oHol0oolk0?l02Ooooc/00_l0I_l4o`1^o`;o9?l000?o0?goo`1Mool0Gol00_l0
oj803?lc0?oo08[oo`2:ool0R_oo0?n8o`3oQ?o<o`3o2ol0oomS0?l0003o0=Coolco00;o0?go00Oo
0?mQokgo0?l0oOoo0000o`2foonno`3o0?mc00;ooooo0ol0ohP04?oooooo08[oo`3oLol0l?oo09Ko
o`3oHOooooooc?l0o`0Voonmo`3ookX0ogko0?nAo`3o`_l0o`29ooo<o`02o`000009o`3mool0ROoo
EOl0oooooonno`3o0?gookko0?l0003ooooo00;o0=Co00Goaol0od;o0?o7o`3oaol0o`0Vo`02o`00
0003okgo0?l02Ooo3_l000;o3_l000Co00Wookko0?l0U?oo09Co0ol0Sol01?oo?P3o0?gooolm0?oo
I@02o`000003oomK0?o<o`3oofD000Co0:_o00CoofH0o`000?l0003o00001Ol0oa401?mSo`3oofD0
o`000?ooool2o`1[o`05o`000?o8o`3ooooood?o0?o1o`000_ooool01?o1o`3o0?oKo`3ofoo1o`02
ool[0003o`04oooooooo0?oO00?oob/000?oooooool[0?oo:`000oooool3ool[0004ooooool0003o
9P3oobH0o`?o0?oc00?o9P3oooooooooool01Oooool00ol0003oooooooooo`1kooooo`00O?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?oc?l0ooooooo3o`000oooool0
4Oo4o`3oooooolCo0?oooooo0?o<olCo0?ooK@3o0000olGo0?ooooooofd0olKo0?oooooo0?goo`3o
XOooooooof`000;o000000Wooooookgo0?ooK03o0?naoolk0?l0ok7ooc/0oom[0?l0oj401?l0I_l2
o`3o[@Co06ko00Oo0000o`2:ool02Ooo00Woo`2:ool02Ooo0?go00;o05oo00Wo0000oomS0?l0ohCo
0?nIo`3oHOl0oOoo_Ol0o`2:ool000000_l0R_l01_l0e?oo08[oo`3mool0oOooc?l0okgo00?o0?mQ
00Co0?mco`0VoooOo`3ooooo0ol000003_l0ohSoooooo`3oLol0R_oo0?googko0?oooooo0?3ookgo
0?o<o`3o02Kool;o0?oooooodOl00_o<o`004Ol0003odOl0o`3mool0ROoo_Ol0oooooomEo`3o@_l0
o`3mool0003o0=Coooooool0003oc?l0o`3mool0R_oo3_l000;o02Ko00?o08[ookgo0?l<o`000_l0
R_l2o`2Do`0:o`2?ool0003o0000oomU0?l0R_oo0000o`3oXol0ZoooofD0o`2[o`;o0?lA00KoofH0
o`3mooo<o`3o0?n8ooooooooI`02o`3mo`04o`2<ool0YOooofD0o`2Uo`?o00000_l0onl00ol0ooWo
0000o`000002o`3on@04ooooooo8o`3o0000ooooo`?oob/000Co0?oKool[0?oo:`3ooooo0ooo:`00
0ol01?ooob/0ool[0002o`3og`?o0?oc2_ooool3obH0o`;ooooo0olV0?l00ooooooo0000o`000003
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0D
ooooo`04olco0?oooooooooool?o00;ooooo00Coa?l0ooooooooooooa?l00_ooool02?o4o`3ooooo
ooooooo5o`3oooooo`3mooooooooofd00_ooool2o`000009oom]0?ooooooa_l0ooooool;o`3ooooo
oom/0?o<o`3ooooo00;o0?na00Woof`0o`3o/Ooo>`3o0;?ooom[0?l0ojgooc/0o`3o[Ooo>`000_l0
2Ol3o`1Vo`?o06ko00Co05goo`09ool0Gooo05oo0_l000002?l0oOoo0?n8o`2:ool0ohCo08[ooomS
0?l0003o0=Co0_l0oOl2olco0007o`3mool0of7o0?mQo`3oHOo7o`3o__l0o`3oL`02on;o0003oooo
ool0ohSooooo00;o000001Wo0?mco`3mool0U_oo0?n[okgo0?o<o`3o02KooeGo0?mno`3od?l0oi7o
0?o2o`3odOl0olco0?l0og?o00Woo`3mool0of7o08WooeGo0?ooooooc?l0o`3oQOl0R_oo000000;o
0=Co00Oo08[ood;o0?l0R_oo02Koo`2:ool>o`3o_Ol000;o08[o0ol<o`02o`2Do`;o08oo00So08[o
ooln0?l0003ooch0o`3moooo?@3oofD0o`0000Co0:_o0_l0okP00ol0oOooofH0o`3o4@03o`3o4@06
oomW0?l0003o0000o`3okol0ooWoofD00_l000002?l0ooWoooooooooool0003ob?l0od?o0?oooooo
`Ol00_l0om/01oo1o`3oob/0ool[0?oo:`3oooooo`04ool0oml00_oo:`001?ooooooob/0ool[0?oo
:`03ooooo`;oob/00oooool4o`3ol`;o9P3o0_l00007ooooo`03o`000?oooooooooo07_ooooo001l
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool01?o<o`3oooooooooooo3
o`02ooooo`05olCo0?ooooooa?l0ooooool0ol`00_l000001_ooK@3oaOl0ooooool0oOooofd0olKo
00?o0000013oof`0o`000?l0003ooooooolk0?nmo`3oof`0oolk0?l0003ooc/0oom[0?oo>`3oHol0
oe?o0?oo>`3o0?mN1?l0I_l2o`3o[@Co06ko00Go08[oo`18ool0oOooof@0o`_o0002o`1Oo`0:oc<0
ool0ohCo0?nIokgo0?l0oiWo0000o`09ool0of7o0=Coo`3mo`Ko08[o00?oh_l0olOo0?l0og<00_l0
of402_oooooo0000o`000?l0003oh_l0o`3oR?l0og?o0?n8ogko0?l0oOl2okgo0006o`29ooo<o`3o
02Kool;o0?oAo`3o0?n80_o<o`005?l0003oooooo`3mool0og?o08Wookgo0?l0ohGooooood;o0?l0
oOoo0000o`2:ool>o`3oc?l0o`3Dool>o`3o02Koo`co0?l0R_oo3?l00_nmo`02o`0000;o08oo00?o
__l0ooln0?ooI@001?l0Zol00oooI@3o0?lAo`3o^002o`3oX`06oomV0?l0oOoo0?goo`3oR?l0onoo
ofL00ol0YOl01?ooI@3o0?oio`3onOl0ooT6o`000005o`29ool0003o0000ooooooo8o`000_oo:`00
1Oo1o`3oob/0ool[0?oo:`3o`Ol000;oob/000Go`Ol0o`3ogooo:`3oob/0ooooo`03o`3ol`_ooooo
0_lV0?l3ooooo`;o9P3o00?o??l0o`000?l000001_ooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01?ooool2o`0000kooooo00Coc?l0oooooooooooo
`ol00_ooool01oo4o`3oooooooooooo4o`3oooooo`000?o4o`000_ooool07Oo5o`3oooooo`3moooo
oooo0000oom]0?l0003o08[oo`000?ooooooofd0olKo0?nmo`3o0?n8o`000?ooK03oooooo`3moooo
oooooc/0oom/0?mSo`3ooc/0oe?o0?ooJ`3o0?naoolk0?l0of7ooc/000;o0?n]00Co_Ol0o`3o[Ol0
R_oooooo0_l0I_l3o`1^o`09o`09ool0Gooo05oooc<0ool0oiWoof@0o`3oVOl0ohCo000000;o0?go
0ol0R_l01Oo<o`3o08[ookgo0?oOo`3ooooo00;o0?mQ00Ko0?mcobCo0?oOo`3oh_l0o`3oR?l0R_l2
o`00000Go`3oLol0ohSo0?gookgo0?o<o`3o08Woo`0VoooAo`3oO_l0oi7o0?oooooo`_l0olco0?l0
AOooooooo`3oLol0oOoo_Ol0o`0Vool0ROoo__l0o`3oQOl0oOl00_l0e?l03?l0003o0=Coo`ko0?o<
o`3o@_l0o`ko0?l0R_oo3?l0okgo0?l<o`3o00Woo`2:o`;o00000_l0Sol01_oo^P3o0?nQo`3oXOoo
?P3o0000ooln00Co0:_o0_l0okP00oooI@3o0?goo`3o4@03o`3o4@;o0:Go00?o0?oioomW0?l0ooT0
0ol000000oooI@3o0000ooooo`02o`0000;ooooo00Kob?l0o`000?l0om_o0?oKol7o0?ooool2ool[
0003ooooooo1o`3o0?oO00Koob/00oooool3ool[00;ooooo0ol0oo<01?llo`3o9P3oobH0ool0000;
ooooo`03o`000?oooooooooo07_ooooo001looooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01?ooool00ol0003oood0ooom0006ooooo`04olco0?oooooooooool?o00;ooooo01;oa?l0
ooooooo4o`3oooooo`000?o4o`3o/_l0oom]0?o5o`3o/_l0o`3mool0003oofd0o`3mool0oj7ooooo
o`000?ooK002okgo000<oolk0?nmo`3o0?n8oom/0?l0oOoooc/0of?o0?ooJ`3oDol0oolk0?lc0?oo
0?nQ0_l0ok400ol0of7o0000o`1Vo`04o`1Vo`03o`3o[Ol0K_oo06ko00;o06ko00?o0>kooomS0?oo
ool00_l0Gol01?l0ohCo0000o`000?l0of42o`3mo`06o`3Dool0oiWo0?nIo`3mool0ofCo0?go1?l0
R_l00ol0og?o08[oo`2:o`03o`3oH@0Ao`000?l0R_ooh_l0o`3oLol0ohSoO_l0o`3oR?l0ROoo0?3o
oeGo0?o<o`3o02Kool;o0?o@o`3oc?l0o`000?o<o`000_ooool01?l0oOoo0?mco`0Vool0ohD2o`3D
o`05olco0?m2o`3o3_l0o`000?o<o`000_l0R_l01ol09_oo08[oo`000?l0003o08[ookgo0?l0R_l0
0_l0Sol00oo=o`3ooch0o`2[o`02o`2[o`?o0?lA00?o0?n4oomU0?l0oOl00_l0onl01oooIP3o0000
o`000?l0ohSo0?mWoomW0?l0ofL00ol0ooT01?ooI@3oooooooooooooool2o`0000;o_Ol000Go8P3o
o`000?l0003o0000o`3of`02ool[0005o`3ofooo:`3oob/0oooooom3o`000_oo:`001?l0omooob/0
ool[0?oo:`03o`3ol`_ooooo0olV0?l2ooooo`?o9P3o00Goooooooo[0?ooj`3oooooo`000006oooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04oooo
o`03o`000?ooo@3oood000kooooo00?oc?l0ooooooo3o`000_ooool01?o4o`3oooooooooool0ol`2
o`000005ok;o0?o4o`3o/_l0ok;o0?o5o`000_l000001?l0oOoooooooom]0?l00002okgo0004oooo
ooooK@3oa_l0o`3oR0;o000000goof`0oooooooooooooc/0of?o0?ooK03ooc/0o`3oG_oo>`3oof/0
oolk0?l0of7ooc/000;o0?na00?o_Ol0o`18ool0ojd00ol0ojd00ol0003o06Koo`1Vo`03o`1^o`08
o`1Oool0003o0000o`3oHOl0003o0?n4olOo0?l0e?l2o`3oV@04o`09ool0oOooc?l0okgo00;o08[o
00?oaol0okko0?l0og<00ol0of401ol0R_oo08Woo`3oR?l0ROoo0?mcokgo0?l0oOl00_l0ohP04omE
o`3od?l0ogko0?nAo`3oooooom3o0?o2o`3oc?l0o`15oonmo`3o0?mco`3mool02Ooo_Ol0okko0?l0
ohGoc?l0o`3Dool0oOl00_l>o`001_l0003oc?l0o`co0?m2o`3o3?l0o`2:o`;o000000?o_Ol0o`09
ooo=o`000_l0Sol01?nno`3ookX0o`3oYol0ojL4o`2[o`04oomU0?l0okSo0?nho`3o^0Co0?lA00?o
0?mWoomV0?l000000_l0ooT2ooooo`07oomW0?oooooo0000o`000?nmo`3oofD0ooooo`03o`000005
ooooool0om_ob?l0o`3ofol000000ooo:`000oo1o`3o0?oOool[0002ool[0003oooooooo:`3oob/0
00?ooooo0ooo:`02ooooo`?o0?oc00Go??l0obH0oolV0?oo9P3oo`00000=ooooo`03o`000?oooooo
oooo07_ooooo001looooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`000002
oooo00;o000000?oooooooom0?ooool01Oooool00oo<o`3ooooool?o0002ooooo`0;olCo0?oooooo
ooooolCo0?l0003oa?l0ooooool0003oofd0o`3mooooool00_nbo`000oooK@3o/_l0ok;o0002ok;o
0003oom/0?nbo`3ooc/000;o_Ol0013ooc/0oom/0?oo>`3ooooooolk0?ooJ`3ooc/0o`3oXOl02Ooo
aol0ooooool0of7o0000olco0?l0ok7o_Ol00_l0ok44o`1Vo`03oomT0?l0K_oo06ko00;o06ko0_l0
00002?l0ohCo0?goo`3moooooooo0?lUo`3Doooooooo0?go1?l0oiT01ooo^P3o08[oo`2:ool0og?o
02Koo`2foolTo`000_l0R_l2o`3oH@03o`2:ool0og?oO_l000;o00Wo0_l0ohP01Oo<o`3o00Woo`0V
ooo2o`3o000000;oc?l000ko0?moom3o0?l09_oo0?goo`3oLol0R_oo0?n5o`29oomEo`3oc?l0od;o
0?l0oOoo3?l0o`0000;o02Ko00Go2Ol0o`3Dool0003o0000o`_o0002o`2?o`Co0:_o00Co0?lAoomU
0?l0oa7o0?n40_l000001_ooI@3o0?nWoomK0?l0ojOo0?mWoomV00;o000000Co0?mWoomW0?l0003o
00000_l0oOl00oooI@3o0?nSo`3oX`03o`3oX`;ooooo00?o8P3ookgo0?nmo`000ooo:`001?l0003o
ob/0ool[0?ooool3ool[0004o`3ogooo:`3oob/0ol7o00;o0?oc3?ooool2obH0o`?ooooo0_lV0?l0
1?llo`3oooooooo[0?ooj`04o`3oj0Kooooo00?o0000ooooooooool0FOooool00ol0003ooooooooo
o`06ooooo`04o`000?ooooooooooooooo`;oool01?ooool2ooom00cooooo00Coc?l0oooooooooooo
`ol00_ooool00oo4o`3oooooo`3oc002o`000005ooooool0003o0000o`000?o5o`001Onbo`000ooo
K@3o/_l0ok;o0002ok;o000Aoom]0?nmo`3o0?goo`3mooo<o`3oof`0oooooooo>`3oDol0oolk0?oo
K03o0?mQoolk0?ooooooof/0oolk0?l000000_l0B?l00onmo`3o0?nao`3o/@03o`3o/@;o00000_l0
ojd2o`1Vo`?o06ko00So0000o`3o3_n3o`3o0?n4ooooool0h_ooc?l0o`3mo`;o0?nI00Ko_Ol0olco
0?l0R_ooaol0okko0?l0og<2o`2:o`06o`3oR?l0of7o0?mQo`3oHOl02Ooo0?mc0_l02Ol02_l0oOoo
00Woo`3oR?l0ohSoO_l0oi7o0?l0ohSoc?l0ol;o0?o<o`02o`0Vo`03o`2:ool0oOoo0?mc00;o3_l0
00Go0?n5o`3Dool<o`3o3?l0o`3mo`02o`co0005o`000?l9o`3o@_l0o`Wo0?l0R_l00_l000001Onm
o`3o08ooo`2?ool02Ooo_Ol000Co0:_o0_l0oh@00ooo?P3o0?lAo`3o4@03o`3o4@07oomU0?l0003o
0000ooooool0oOooofH0o`000003o`3mo`0;oomW0?ooooooooooooooool0003oofD0o`2eoonmo`3o
08Woo`07ool0om/00ol00002ool[0003ol7o0?l0omoo0?oO00;oob/000Coooooool[0?oo:`3oob/0
0oooool2ool[0003ooooool0oo?o0?oc00;o0?oc00Go9P3oocco0?lV0?oo9P3oooo[0005o`0000_o
oooo00?o0000ooooooooool0Noooool007cooooo00?o0000ooooooooool03?ooool3o`000005o`3T
ool0003o0000o`3Tooooo`000oooool2ooom00Cooooo00?oc?l0ooooooo3o`000oooool00oo4o`3o
ooooo`000003o`0000;ooooo01Ooofd0oooooooooooo0?goolKo0?ooK@3ooooookgo0?oooooo_Ol0
oom/0?oo>`3o/_l0oolk0?nbo`3oof`0oolk0?mCo`3ooc/0o`3mooooJ`3o0?nQolOo0002o`3oH@09
o`29ool0003o0000o`1Coonmo`3o0?nao`09ool0R_oo0?na00;o00001?l0I_l01Ol0003o06koo`1^
ool0ohCo06ko00?o0?l>00Oo0=Coo`3o3_oooooo0?goo`3Rooo<o`3o_Ol000Co0?nI00Go0?mco`2f
oooMo`3o9?l0o`2:o`02okgo0003o`3oHOl0003o000000Go08[o0_l0ohP01?o2o`3o08[oo`2:ooo<
o`03o`2:o`0Ao`3mool02Ooo0?n5o`co0?nmo`3o08Woolco0?l9o`3o@_l0olco0?l09_oo0000o`09
ool0oOoo0=Coo`Oo0?l000000ol0Zol3o`3o4@0=okko0?oo?P3oofD0ooln0?l0R_oo0000oomU0?oo
?@3o0?mWoomK0?l0003oofH0o`0Vo`02o`3oY`03o`3oR?ooI`3o0?go00;o0?go00Coaol0oomU0?l0
003o00000_l0oj401?l0oOoo0?nSo`3oXolR0?l2ool[0005okgo0?oo:`3oob/0ool[0?l0oj400_oo
:`001?l0003oob/0ool[0?oo:`03o`3ol`_ooooo0olV0?l2ooooo`?o9P3o1_l0onP2ooooo`;o0000
1_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooko0?ono`00
1?l0i?l00oooo`3oooooooooo`02ooooo`03ooom0?oooooooooo00Wooooo00Coc?l0oooooooooooo
`ol00_ooool00oo4o`3oooooo`000003o`00000@olCo0?oooooo0?goolGo0?oooooo2ol0o`3moooo
oooo_Ol0oom]0?nmo`3o08[oooooool;o`3oofd0olKo00?o/_l000_oof`0oe?o0?oo>`3o0?mNoolk
0?ooK03ooc/0o`18oooo>`3oof/0oolk0003o`000006okgo0?l0R_oo0?l@ooooool0oOoo0?mQ1?l0
ok400onmo`3o0?n]o`000002o`0000?o06ko00Co0?n4o`3o3_l0o`ko0?go0_oo^P001oo<o`3o_Ol0
o`3oVOo<o`3oaol0okko0?l0og<00_l0R_l01?l0ohSo9?l0okgo0?l0ohP2o`3oH@;o000000Ko08[o
o`3mool02OooO_l0oi7o0?l0ohP2o`09o`03ol;o0?l09_oo3_l000;o3_l000Oo0?goo`3oLol<o`3o
0?n5o`3Dooo<o`3o08Wo00;o2Ol000So0?goolco0?l0oOoo0000o`3Doom2o`3o08[oo`Oo00;o0000
1?l0Zol3o`3oQ0Co0?lA00?oofD0ooln0?l0ofL00_l000001_ooI@3oaol0oomK0?o7o`3oofH0o`3m
o`;o0?nQ00So0?gooomW0?l0003o0?goo`3oXol0003oofD0o`2eo`;o0?nQ0_nmo`001?l0003oob/0
ool[0?oo:`02o`0000?oob/000Co`Ol0ool[0?oo:`3o`Ol00_ooool3ool[00?o0?oc0_lV0?l01?ll
o`3o9P3oobH0oolV0?l2ooo[0003ooooool0onSo0?oX00;o0?oX00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1kooooo`00O?ooool00ol0003oooooooooo`0<ooooo`03o`000?ono`3oo_l0
00;o00000_ooool00ol0i?ooool0oooo0003o`3To`05ooom0?ooooooooooooooooo<o`000_ooool0
1?o3o`3oooooooooooo4o`02o`000007o`3oc?l0003oa?l0ok;o0?l0oOooaOl0oom]0002o`000003
ooooooo6o`3oofd000;ooooo00go_Ol0o`2:ooooK03ooooooolk0?mSo`3oDol0oom/0?l0oekooc/0
okgo0?oo>`3oof/000;o/_l000[o0?mQo`29ool0003o0000ok;o0?nmo`3o/_l0okgo0?l0R_oo_Ol0
0_l000001?nmo`3oof<0o`3o/Ol0ok44o`1Vo`03o`3oQ?l0K_oo06ko00;o06ko00?oPol0o`3o3_l0
o`h00_l0o`h01_nmo`3oc?l0olco0?l0ROoo__l0o`3oL`Co0?nI00?ofol0ooooool0R_l00_l00003
o`3oH@05o`2:ool0oOoo08[oo`2:ooo2o`000_l0R_l01oo<o`3o02Koo`co0?l<o`3o0=Coo`3oQOl0
og<00_l9o`002Onmo`3o08WooeGo0?l09_oo@_l0o`3mool7o`3o0000o`Oo0003o`2[o`?o0?lA00Go
0?nQo`3oZ_nno`3o_Ol0oomU0002o`3oI`07ooln0?l0003oofD0oolm0?l0of7o067ooomV0002o`00
0009o`_o0?l0ohSoofL0o`2eool0oOoo0?nWo`3mooooI@3ooooo00Co000000Go0?goool[0?oo:`3o
ob/0o`29o`02ool[0005o`000?oo:`3oob/0ool[0?l0oj400_oo:`03o`3ol`03ooooool01?oo`Ol0
00Wooooo0_lV0?l3o`3oj0;o9P3o00?o??l0o`3oj?ooool00_ooj`04ooooo`;ojol00_l00006oooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01_ooool3o`0000;oo_l00_ooool7o`3T
o`03ooom0?oooooooooo00Oooooo00Coc?l0oooooooooooo`ol00_ooool01oo4o`3o0000o`000?o4
o`3oooooo`000?o4o`000_l000006oo5o`3oooooo`000?l0003ooooookgo0?ooooooofd0o`2:oooo
oooo2ol0o`3mooooK@3o_Ol0oooooomSo`3oDol0oom/0?l0oeko_Ol0oolk0?nbo`3oof`0ok;o0?oo
>`3o08Wooom[0003o`000006okgo0?nbo`3o_Ol0okgo0?l0oOoo2ol00_l000001?l0R_oo0000o`3o
/Onmo`02o`000004oomS0?nmo`3o0000o`0000?o06ko01;o0?goo`3o3_l0o`ko0?l>okgo0?o<o`3o
aol0olco0?nno`3o0?mco`2:ool0oiWo0?n8o`3oXOlTo`3o0?n8o`2:ool0og<2o`0000;o0?mQ00?o
O_l0oi7o0?l0R_l00ol0R_l00oo2o`3o3_l0o`3oX@02o`co0003o`3mool<o`3o0?n500Co2Ol000Co
08Wookko0?l0oOooc?l00_l7o`000ol0003o@_l0o`2[o`03o`2[o`;o0?n400?o0?nZo`3o4Ol0oa40
0_l0oa42o`3oI`0;o`3oXOooI@3ooch0ooln0?l09_oo0000oomU0?l0oj7oocd0oomK0?ooIP000ol0
oOl02oo7o`3oofL0o`000?l0003oooooo`000?ooI@3o0;Goo`3ofooooooo08Wo00?oob/000?o_Ol0
olSo0?l0oj400_oo:`001oo1o`3oob/0ool[0?oo:`3o00Cool7o0?ooool00_oo:`03o`3ol`?o9P3o
00?o??l0obH0oolV0?l01_l0onP2ooooo`;ojol03?ooool00ol0003oooooooooo`1kooooo`00O?oo
ool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooooko00Kooooo00Coool0oooooooooooo
0>Co0_ooo@001Ol0i?ooc?l0o`3Toooooooo`ol000;ooooo00Koa?l0o`000?o4o`3o0?o<o`000?o4
o`03o`00000Jok_o0?ooK@3o0000o`3oXOo6o`3ooooooom]0?oooooo_Ol0o`3moooo>`3oof`0oolk
0?mCo`3ooc/0ooooooooK03ooc/0o`18oooo>`3o0?nQoom[0?nmo`3o0?mQokgo0?l00002okgo0003
o`2:oonmo`3o/_l000;o/_l00_l00002ok;o00;o0?go0_l00002o`3o/@05o`1Vool0ohCo06Koo`1V
oonmo`000_l00002o`3o4003o`3oXOl0o`ko0?l>00?o0?l>00?o0?mco`2:ool0R_l00_l0R_l2o`00
0006ogko0?nAo`3o093ooooooooAo`3od?l00ol0of401?l09_oo`_l0o`co0?o<o`03o`2:o`05o`3D
ool0ohGo08[ookko0?l0og<00_ooool01Oo<o`3o08Woolco0?m2o`3o0?go00;o000000Ko0:_oo`3o
4Ol0oa7o0?lAo`09oonmo`05o`3oI`0HoomU0?oo?P3o0?nZooln0?ooI@3oocd0o`2:oooo?@3ooooo
oomV0?l09_oo_Ol0o`_o0?l0ohSoofL0o`2eool0oOoo0?nQoomU0?l0oOoo0?nWo`3mool0ojOo0000
0_oo:`001OlR0?oo4@3oool[0?oo:`3o0?oO00;oob/000CoooooolSo0?oo:`3oob/00_l0oo<2o`00
0004ol7o0?l01?oooooool7o00Cooooo0ol0onP2obH0o`;o0?oX0olV0?l3ooooo`;oon/00oooool8
oa[o0003o`000?oooooooooo00;ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`05
ooooo`;o00001?ooool01?ono`3oooooooooooooool2oooo00?ooooo1ol0i?l4ooooo`03olco0?oo
oooo`ol000;ooooo00Ooa?l0o`000?l0olco0000olCo0?l0003o^ol000;o000000GoaOl0ok_o0?l0
003o0000okgo0002ooooo`0Gokgo0?ooK@3o08[oo`3mooooooooa_l0oom]0?mSo`3oDol0olco0?oo
>`3oof`0okgo0?oo>`3o0?nQoolk0?ooK03ooc/0o`29oooo>`3oof/0olco0?nmo`000_l0R_l2ok;o
000<o`_o0?nbo`3o0000o`000?nbo`3o0?goo`3oHOooI03o0000o`_o0?ooH`3o0?na0_l00002o`3o
/@03o`1Vool0003o000000;o0?l@00Wo_Ol0o`3o3_o7o`3o0?l>okko0?l0og?o08[oo`3oR?l0R_l0
0_l0oiT2o`000009o`3oLooOo`3o093oolco0?l>o`3oO_l0oi7o0?l0of7o3_l000;o3?l000?o`_l0
o`co0?l<o`000_l9o`003?l0oOoo0?n5o`3oLooooooo_Ol0olco0?l09_oo1ol0o`29ooo<o`3o0?go
o`Go00;o000000Co0:_ood;o0?l02Ooo00Wo1?l0oa42o`3oI`03okgo0?l0of7o0?nZ00;o08[o00_o
ofD0ooln0?l0of7ooch0oomU0?oo?@3o2ol0oolm0?l0003oofH0o`3mo`02o`3oY`09o`3mooooI`3o
0?goooooooo7o`3o0000oomU0?l0oOoooooo00;oob/00_l0oml00oooooooob/0ool[0004ool[0003
o`000?o1o`3o00Co00?oob/000?o0?ocooooooooool00_lV0?l01ol0onSo9P3oobH0oolV0?oo0?oX
ooooooooj`001?ooool8oa[o00Wooooo00?o0000ooooooooool0Noooool007cooooo00?o0000oooo
ooooool02oooool00ol0003ooOl0oogo0002ooooo`;oo_l01Oooool00oooo`3oooooooooo`02oooo
o`05ooom0?o<o`3oooooo`3Tooo3o`000_l0i?l01oo4o`3o0000o`000?l0olcoooooolCo0?l0oOl0
0_l000006_nko`3o0000oom]0?l0003o^ol0olKo0?ooooooofd0o`3mool;o`3ooc/0of?o0?ooK03o
0?mNoolk0?l0B?oooc/0oom/0?nmo`3ooc/0o`3oXOooJ`3o_Ol0o`3oHOoooooo00000_nmo`002ol0
R_oo_Ol0ooooool0R_oo2ol0oomT0?l0oOooof<0o`3moonbo`3o000000?o/_l000Go2ol0ooooooo7
o`3o0?n4o`3o/@05o`1Vo`Go0?l@00?o__l0o`3oLol0o`h00_l0o`h01_oKo`3o0000o`000?mno`3o
0?mco`2@o`?o0?nI00Woc?l0o`co0?l0oOoo0?mQol;o0?l0of7oc?l0o`Wo0?l0ohP00_l000001?l0
oOoo__l0o`2:ool0og<4o`2:o`03olco0?l5o`3o@_l000;o000000?o0?lAo`000?l0ofL00ol0ofL0
3ol02Ooo_Ol0olco0?nno`3oofD0olOo0?oo?P3o00Woooln0?ooI@3oocd0o`1Qoooo?@3oofH0oomK
0002o`3oZP0:o`3oR?ooI`3o0;Goo`3oXOl0oOoo0000oomU0?l0oOooooooo`3oX@;oob/000Go0000
ool[0?oo:`3oob/0oiSo0002ool[0007o`000?oo:`3oob/0ool[0?l0oo?o_Ol0ol7o0003o`000003
ol7o0?l0onSo`Ol000Go0?oX0olV0?l01?lJo`3o9P3oobH0oolV0?l;oa[o0003on_o0?oooooooooo
00;ooooo0_oYo`02o`0000Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`05oooo
o`;ooOl01Oooool2ooko00?ooooo0_ooo`04ooooo`;oood00_ooool4o`3To`04olco0?l0i?oo0>Co
ol?o00;ooooo0_l000002?ooooooa?l0o`000?nbo`3oa?l0ok_o0?l0003oaOl00_l000002ol0oOoo
oooooooooonmo`3o0?gooom]0?l0003oooooo`18ooooK@3oDol000;o0?mN00_ooc/0o`3oHOooK03o
0?nQoolk0?l0oj7oof`0o`09oooo>`3o0?mQoom[0002okgo00;o08[o00?o0?goo`3o4?l;o`000ol0
oOl03Ol0003o/_l0ok;o0?l0003o/_l0oomS0?l0oOooaol0ooooool0e?oo0?lUoh?o0?l0ok400_l0
0003o`1Vo`?o0?l@00Go__l0o`3oLoo<o`3o0?n8o`3o3P02o`2:o`;o000000Ko0?mco`ko0?l0T?oo
3_l0ogko0?nAo`02o`co00;o0?mQ00Go2Ol0ol;o0?l9o`3o2Ol0o`3oR002o`000003o`2:ool0og?o
1ol000?o1ol00_l5o`000oo<o`3o1Ol0o`3mo`02o`0000Co0?lA00?o0?mWokgo0?o<o`000_o=o`02
o`09o`0>okgo0?o<o`3oc?l0oomU0?l0003ooch0o`0Voooo?P3oofD0oolm0?l;o`3oocd0oomV0?oo
F`02o`3mo`04ooooooooI`3o0?nWo`3mo`;o0?nW00KoofD0ool[0?oo:`3oob/0o`07ool0ROl3ool[
0006oooooooo:`3oob/0okgo0?o1o`3o00000ooo:`000ol0oo?o`Ol0o`3oj003obH0o`03oa[o0?lV
0?oo9P3o00[o6_l00_o[o`001?oooooo0000onWo0?oYo`02o`0000Wooooo00?o0000ooooooooool0
Noooool007cooooo00?o0000ooooooooool02oooool2o`000003ooooooomo`3ooooo00;ooooo00?o
o_l0ooooooooool00oooool2oooo00?ooooo00Coood0olco0?oooooo`ol00oooool2o`00000/olCo
0?l0i?ooa?l0o`3moonbo`3o0000olGo0?nko`3o0000oom]0?l0003oa_l0o`3mooooK@3o_Ol0o`_o
0?oo>`3oDol0oolk0?ooK03ooc/0okgo0?oo>`3oaol0oom/0?l0oj7oooooo`3oXOooJ`3o0?mQo`3o
c?l0003o05?ookgo0?l0R_oo0?m`o`2:ool;o`3o_Ol0oomT0?l0oOooof<0o`3oHOl00002ooooo`;o
08[o1?nbo`001_l0ohCo08[ooc<0ool0C?ooPol0o`3o/@Co06Ko00?o_Ol0o`3o4?l0og<00_l0oa00
1ol0ohSo0?l>o`3o3_mno`3o0?l>o`3oLol0T?l00ol<o`04o`3oV@05ol;o0?o<o`3oc?l0o`3oHOoo
ool00_l000001ol0oOoo0?n8o`Go0?l0og?o02Koo`Go0?o<o`000ol0oa407Om2o`3o0?mWo`3oIol0
ofOo0?mQo`000?oooooo0=Cookgo0?l02Ooo_Ol0okko0?oo^P3oofD0o`3o@?o<o`3ooch0oomU0?oo
?P3oocd0o`3oR?ooooooofH0o`3mooooF`3ooooooomW0?l0oj[o0;Go00;o0?nZ00?oofD0o`09oooo
:`000_oo:`001?l0ojCoob/0ool[0?l0oj@3ool[0005o`3oY?oo:`3oob/0o`3oloo8o`000_l00000
1Ol0onSo`Ol0okgo0?l0003o0?o;00;o6_l000Co`Ol0oa[o0?lJo`3o6_l00_lV0?l2oa[o00;o9P3o
00?o??l0ooooooooool00oooool2ooo[00Cooooo00?ojol0ooooooooool00_ooool2onWo00;o0000
1_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Kooooo00?o0000oogo0?omo`00
1Oooool2ooko00?ooooo00?oool0ooooooooool00oooool00oooo@3oooooooooo`03ooooo`04olco
0?oooooooooool?o00;o0>Co0_l000002?l0i?ooa?l0ooooool0oOooa?l0oooooonko`3oaOl00_l0
00002ol0oOoo^ol0ok_o0?l0oOoooooooom]0?l0R_oo04Sooe?o0?o6o`3oofd000;ooooo00cooc/0
ooooooooK03ooooooolk0?l0oj7ooc/0oom/0?oo>`3o0?mQo`1CooooJ`02okgo0003o`2:oonmo`3o
2ol000;o0?go00Go00Woo`1Mool0of7o_Ol0o`000002o`2:o`03oomS0?nbo`3o/_l000?o/_l000?o
Pol0o`3^ool0oh@00_oo^P02o`3o/@?o06Ko00?o__l0o`3oLol0oa000_l0oa04o`ko0006o`3oLol<
o`3o093oogko0?l<o`3oTOl01?l9o`001Ol0of7o`_l0o`3oHOnno`3o0=Co00;o000000?o1ol0o`Go
0?l0og<00ol5o`000ol0R_ooc?l0o`3o4@04o`3o4@0No`3oIol02Ooo0000olco0?l02Ooo_Ol0olgo
0?l0od3oooooo`_o0?l0R_ooc?l0okgo0?ooI@3o0000oooooooo?P3o08[ooomU0?ooooooocd0o`3o
Z_ooIP3o0?nZoomK0?l0oj[o0?gooomW0?l02Ooo0?go0_l0oj@2ool[00?o0?nT0_oo:`001ol0ojCo
ob/0ool[0?oo:`3ob?l0oa[o0?l0oo<00_oo:`001ol0ol_o`Ol0oa[o0?lJo`3o`Ol0obH0oolJo`00
0olV0?l4ooooo`03ooo[0?oooooooooo00?ooooo0_o[o`03ooooo`03onWo0?l0003o000000_ooooo
00?o0000ooooooooool0Noooool007cooooo00?o0000ooooooooool03?ooool01?l0003ooooooooo
ooomo`03ooooo`;oo_l01Oooool0>?ooo`3oooooooooooooooooc?l0ooom0?oooooo`ol0ooooool0
003oa?l0ooooool0003oooooo`3mooo4o`3ooooook;o0?o5o`3o0000ok_o0?l0oj7oofd0o`3mooo6
o`3ooooooom]0?oo>`3oDol0o`3oG_oo>`3oof`0oolk0?nmo`3ooc/0oooooooo;`3oof`0o`3oc?l0
oj7o00Wooom[0?oooooo0000o`1Coonmo`3oc?l0o`3oL?l0R_oo2ol0oomT0?l0oOooof<0o`3oHOl0
003o_Ol00_l0R_l02?l0ohSo2ol0ooooooo7o`3oooooo`3moonbo`3o0?n40onbo`000ooRo`3ookX0
okgo0002okgo00;o000000?o0?mco`3o4ol0ohP00ol0oa001?mno`3o0?l@o`3oLol0T?l3o`3o3P06
o`Wo0?l09_oo0?3ooonj0?o2o`3oc?l00_l0oiT02?l0of7o0?n5o`3oHOl0oOoo1Ol0o`3oR?l09_oo
0?lA0_l000001oo<o`3o0?mWolgo0?l0ROoo@_l0o`3mool02Ol00_l0R_l01ol0003o_Ol0o`2:ool0
2Ooo_Ol0okko0?ooI@000_o<o`005?l;o`3ooch0oomU0?oo?P3o02Kooolm0?ooIP3oocd0o`3moooo
F`3o2ol0oomW0?oooooo0;Goo`3oY?l0aOooofD0ool[0?l0ojCo00000_oo:`001Ol02Oooob/0ool[
0?lA0?oo0?oc00;oob/000Co0?goo`09ool0ojCob?l00_l0oj@02?o1o`3o02Koo`000?l0003o0?o;
o`000?oooooo`Ol00olV0?l01Ooooooo9P3oobH0oolV0?oo??l000Gooooo0_ooj`04ooooo`;ojol0
0oooool2onWo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo00Cooooo0ol00002ooooo`03oogo0?oooooooooo00Cooooo00Coo_l0oooooooooooo
oooo0_ooo`04ooooo`;oood00oooool04oo<o`3oooooooooooo3o`3oooooo`000?o4o`3o0?o<o`00
0?o4o`3o0>Coo`3mooo4o`3o0000o`3Tooo5o`3oooooo`3oXOooool00_l0oOl06onmo`3o^ol0o`_o
0?ooK@3oDol0o`3oR?o6o`3o_Ol0oom]0?oo>`3o0?o<olco0?oo>`3oof`0oolk0?lc0?oooc/0o`29
ooooK03o0?mQo`1Cool0003oof/0o`2cool0R_oo0?goo`_o0003okgo000<o`1Mool0R_oo0000oomT
0?l0R_ooof<0olOo0?oooooo0>;oo`000?l0e?oo0?go1?nbo`001_oo^P3o_Ol0okgo0?l0R_ooaol0
okgo00;o000000?o0?mco`3o4oo<o`001?l<o`002ol0og?o0?l>o`2@oomno`3oTOl0o`Wo0?oRo`3o
02Koo`3mool0oiWo`_l000;o1ol000So0?mQo`3oQOl0of7o0?goo`Go0?l0ohSo0?mcolco00Co0?lA
00ko0?mWooooool0ROoo0?goo`09ool0R_oo_Ol0od;o0?l0003ocOl0okgo0?nno`3o0?m0ooooo`;o
c?l0013o067ooomU0?nmo`3o0000o`3oR?l09_ooofD0o`2:oooo?P3o0?gooolm0?ooIP3oocd0oomK
0?l0ojCoofL00_l00003ool[0003o`2eool0003oob/000;oob/000Co00Woool[0?oo:`3o0?nT0_l0
oo<3ool[00?o000000Co0?o;obH0ooo1o`3ooooo0_lV0?l5ooooo`;oon/01Oooool01?o[o`3ooooo
ooooooooool2onWo0003o`000?oooooooooo00_ooooo00?o0000ooooooooool0Noooool007cooooo
00?o0000ooooooooool02_ooool00ol0003onol0oo_o0003ooooo`;ooOl00oooool00oono`3ooooo
ooooo`03ooooo`;oool000goooooolco0?ooooooood0ol?o0?oooooo0000olCo0?oooooo0000oooo
ool0oOooa?l000;ooooo01WoaOl0ooooool0003o^ol0oom]0?l0003oa_l0of?o0?mCo`3oofd0o`3o
G_l0<ooooc/0ok_o0?ooK03o0?gooolk0?l0olcoobl0oom/0?l02Oooooooo`29ool0003oof/000?o
000000[o08[oo`3mool;o`3ooooooomT0?l0oOooof<0o`000?nmo`3o0>3o1?nmo`002Oo7o`3ooooo
o`2:ool0e?oo0?goo`3oQ?l0ROoo04cooc<0o`04ok;o0005o`2:ool0003o0000o`3oLonmo`000ol0
oa<01Omno`3o0?lCo`Wo0?l0og?o093o00;o0?l@00?o08[oo`3o3_l0o`h00_l0o`h01Oo2o`3oc?l0
o`Go0?l5o`3o0?n500;o0?nI00Go0?goo`000?l0003o0?lAo`3oL`02o`00000@o`2aooo=o`3oEOl0
okgo0?l0ROoo@_l0o`3mooo=o`3o08[oolco0?l0003o0?mQo`09oonmo`3o08[ooomU00?o08[o00co
ofD0o`1Qool0003ooch0oomV0?l0ojCoocd0o`3oY?ooF`3oofL0o`3oY?l0aOl2ool[0003oomU0?l0
003oob/000Goob/000[o0000ool[0?oo:`3oob/0o`000?m3o`3oooooo`3mool0L?oob?l00_l09_l0
2?o1o`3o00Woo`000?l0003o`Ol0o`3obolV0?oo`Ol00_ooool2obH0o`;o??l01Oooool2ooo[00Co
oooo0_o[o`04ooooo`03onWo0?oooooooooo00?ooooo0_oWo`05ooooo`03o`000?oooooooooo05Wo
oooo00?o0000ooooooooool01?ooool00ol0003onol0oo_o0003ooooo`;ooOl01Oooool2ooko00?o
oooo0_ooo`04ooooo`;oood001Coooooolco0?oooooooooool?o0?oooooo0000olCo0?l0olco0000
ooooooo4o`3o0?goooooooo4o`3o0000olGo0?nko`3o0?nQo`3To`;o00000_l0<ol03_mSo`3oDol0
oom]0?l0oeko0?o<olKo0?nmo`3oofd0o`3oHOl02Ooooc/0ooooooooK03o<`3o0_oo>`007?ooK03o
0000o`1Cool0003oof/0o`000?oo;`3o2ol0o`3oHOl0oOoo0?mQo`3Poonmo`3o0000oomT0?nmo`3o
of<0o`3mooo7o`3o08[oo`0Vool0ROoo0=Coo`3mool?o`3oPol0olco0?oo^P05ok;o0005o`ko0?l0
003o0000o`3oLol<o`000_l0oa<3o`Wo0005o`3oLol9o`3oO_l0oi7o0?l0Dol01Ol7o`001oo2o`3o
0=Coo`3Dool5o`3o0?n5o`3oVOl0oOl00_l0of42o`00000:o`3oR?o=o`3o0000o`000?mEo`3o0000
o`29ool02Ooo0?goo`2:o`;ocOl000Co@_l0o`000?l0R_oo_Ol00_o<o`003ol0R_oo067ooooooooo
I@3o02Koo`000?l0of7oofD0ooln0?l0ojCooch0o`3oY?ooIP3o0?nToolm0002o`35o`06oomW0?oo
:`3oob/0o`3o`Ol0003oofD00_oo:`001?l0003oob/0ool[0?oo:`03o`3ol`;oob/000?o02Koo`00
0?l02Ol00_l000001Oo1o`3o0?o;obH0ooo1o`3o9P3o00Kooooo00?oon/0ooooooooool00oooool2
on_o00?ooooo00GojOl0oooooooooooo0000ooooo`02onOo00[ooooo00?o0000ooooooooool0Nooo
ool007cooooo00?o0000ooooooooool02_ooool3o`000003oo_o0?oooooooooo00;ooooo00CooOl0
oooooooooooooooo0_ono`05ooooo`0=oooo0?o<o`3oooooooooooo3o`3oood0o`000?o4o`3ooooo
olCo0?l0oOooooooolCo0002ooooo`03olGo0?oooooo000000;o000000Ooofd0of?o0?o6o`3o0?mN
oolk0?ooK@3ooc/000;o03?o00Wooc/0oom/0?oo>`3o03?oool_0?l0<oooof`0o`0cool0ROl00_l0
00000oooJ`3o0000o`000002o`3mo`0<o`_o0?ooI03o0?mQo`3mool0003o_Ol0o`09oooooooo05go
o`3oR?l;o`3oaol00onmo`001_l0e?oo0?goo`29ool0ohCo_Ol0o`ko00;o<`3o00?o08[ookgo0?nb
o`001?nbo`001ol0ohSo_Ol0okgo0?mno`3ocol0o`3o4ol0T?l00_l0oa<00ol7o`3o0?l@o`3o4002
o`3o4006o`3Dooo2o`3oc?l0o`3o3_l0ohGo0?l>0_l;o`001ol0oOoo0000o`000?l0of7o0?mco`3o
HOl0oiT00_l0ohP03_nmo`3oEOl0o`09oom2o`3ocOl0o`3mool0R_oo_Ol0olco0?l0003o00Wookko
0?ooI@3o6_l00_l0oj@02oooI@3o0?nToolX0?oo:03o0000oomV0?oo?@3o0?n8oolm0?l0aOooofL0
00;oob/000Go0;GooomU0?oo:`3oob/0o`3oaP02ool[0006o`3oZol0oo?oob/0ool[0?l0003o0?n=
0_l00002o`1`o`;o02Ko00Cob?l0oooooooooooo`Ol00ol000000oo1o`3o0?o;ol7o0003obH0o`03
occo0?oooooooooo00Cooooo0_ooj`04ooooo`;ojol01?ooool2onWo00Cooooo0_oWo`02o`0000Go
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`06ooooo`03o`000?oko`3onol000?o
oooo0_omo`05ooooo`;oo_l00oooool2oooo00Cooooo0_ooo@002_o<o`3oooooooooooo3o`3o0000
ooooooo4o`3oooooo`000?o4o`02ooooo`04olCo0?ooooooooooolGo00Co000001Go_Ol0of?o0?mC
o`3o0?mNo`3oc?ooK@3o03?oolKo0?l0oOooofd0o`0coooo>`3o03?ooolk0?ooK03ooc/0oooooooo
>`3o0000oom/0?l0oOl00_l000003?ooJ`3oobl0o`3mool0of7o0?goo`09oooooooo0000o`3oR?oo
I03o2ol0oomS00?o_Ol000Ko08[oo`3Dool0oOoo0?lUo`1<oon3o`03o`ko0004o`3oQ?nmo`3o3?l0
o`co00Go/_l00_l9o`02olco0006o`3o4ol0og?o1ol0ogko0?nAo`3o1ol01Ol5o`001?o2o`3o0?l>
o`_o0?l0ohD2o`_o0003o`3mool0oiWo0?nI00;o000001;o0?mQo`3oR?o<o`3o_Ol0o`09oomEo`3o
00Woo`29ooo<o`3o0?gookgo0?o<o`3o@_l0o`09ool0003o_Ol0o`000?l0ogh2o`3oY003oomU0?l0
ojCo0?nT00;o000000SoofD0ooln0?oooooooch0oomV0?oo?@3o0<Gooolm00?oob/000?o0?nQo`3o
a_oo:`001Ooo:`03o`3ol`?oob/000Co02KoolSo0?oooooo9P3o0ol000001?o1o`3o0000o`3oboo1
o`05ooooo`;oon/01?ooool2on_o00?ooooo0_oYo`03ooooo`04o`000?oWo`3o0000o`0000[ooooo
00?o0000ooooooooool0Noooool007cooooo00?o0000ooooooooool03?ooool00ol0003ooooooo_o
0004ooooo`;ooOl00oooool00oono`3oooooooooo`03ooooo`0<oooo0?o<o`3ooooool?o0?oooooo
0000olCo0?oooooo0?o<o`3mooooooooa?l00oooool06oo5o`3o0000o`000?ooooooHol0oom]0?o6
o`3o_Ol0oolk0?ooooooofd0o`000?l0R_oooc/0ooooooooK03o^ol0ool_0?nko`3oc?l0oom/0?l0
ROoo0?mQo`0cooooJ`3o03?ookgo0003o`0co`0;oomT0?l0<ooo0000o`0coonmo`3o00Woo`3oXOl0
GOoo0?n8ooooooo7o`000_l0h?l2o`0000?o_Ol000Oo0?n4o`1<oon3o`3o08[ooc<0oonmo`3o02Ko
00;o2Ol000Co0?mco`Wo0?l0003o00000_nbo`02okgo0003o`2@ool5o`3o1Ol000Co0?lC00Oo08[o
o`3o4?o2o`3oc?l0o`3oQOl0oa3o0?mQ00;o02Ko00Ko0?goo`3o3_l0o`ko0;7oolgo0?l0og<3o`3o
H@;o0?n80_o=o`000om2o`3o__l0o`3mo`03o`3oY0?o000000co0?nTo`2aoooo:03oofD0oolX0?oo
?P3o0000oomV0?l0003oocd0o`35oooo?@02ool[0005o`2:oomMo`3oob/0oomU0?l0olH00_oo:`02
o`3ol`;oob/00ol000000om3o`3o073oo`1`o`02o`0Vo`;o000000Coooooo`3moooooooo`Ol00_l0
00001?o1o`3o0=[oo`3oboo1o`02occo00Kooooo0_ooj`04ooooo`;ojol01?ooool2onWo00Cooooo
0_oWo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`03ooooo`;o000000Goooooo`000?oooooooooooo_o0004ooooo`03oogo0?oooooooooo00Co
oooo00?oo_l0ooooooooool00_ooool00oooo`3oooooooooo`03ooooo`0:olco0?oooooooooool?o
0?l0003oooooolCo0?oooooo0000olCo00;ooooo00Coa?l0ok;o0?ooooooaOl00_l000001Onko`3o
0?gooe?o0?mCo`3o0?mN00;ooooo01Coofd0o`2:ool02Oooa_l0oolk0?ooK@3ooc/0o`3oXOoo>`3o
0000oom/0?l0<ooooc/0o`3mool0of7oof`0o`000?nmo`3o03?ooom[00;o03?o00go0?goo`3o?ol0
003o_Ol0oomT0?l;o`3oof<0o`3Pooo7o`3o0>;ooooooonmo`3o0=Co00;o000000?o3_l0olco0?l<
o`000ol<o`000ol0ohCo<`3oo`Wo0003o`Wo0003o`3oLoo>o`3o/_l000;o000000Oo/_l0o`Oo0?l0
og?oO_l0oi7o0?l0T?oo1Ol000?o0?lC0_l;o`001?o2o`3o2ol0o`3oQOl09_l2o`3o3P04o`3mool0
o`kocOl0olgo00;o0?mc0ol0of401ol0oiWo00Woolco0?o=o`3o08Woo`3mooo<o`000_l0oj@00om2
o`3o0?nTo`000002o`000004oooR0?ooI@3o02Koo`3oH@;oobP000OoofD0o`000?l0of7ooch0oomV
0?l0aOooocd000;oob/000?oofL0oomK0?oo:`000_oo:`000oooI@3oob/0ool[0003o`3ol`?oob/0
0_l09_l2o`00000:olSo0?l0oOooooooo`000?l02Ooo_Ol0ol7o0?l0003o0?o;ol7o00?ooooo0_oo
j`05ooooo`04on_o0?ooooooooooooooo`;ojOl01?ooool2onOo00gooooo00?o0000ooooooooool0
Noooool007cooooo00?o0000ooooooooool02Oooool01?l0003oiol0onOo0?l00002ooooo`;onol0
1?ooool01?omo`3oooooooooooooool2ooko00Cooooo00Ooc?l0oooo0?o3o`3oooooo`000?ooo@3o
a?l000?o000001OoooooolCo0?oooooo03?oolGo0?oooooo0?goof?o0?mCo`3o0?mNoom]0?o6o`3o
oc/0oooooooo>`3oofd0oolk0?l0oOoooc/0okgo0?ooK03oobl0o`3oX@02ok_o000>oom/0?l0of7o
0?goo`000?ooJ`3o_Ol0o`_o0?l0oOoo08[ooomT0?l0003oof<0okgo0?l0/ol8o`0co`;o00000_l0
<ol2o`co000:o`3oQ?l0R_oo_Ol0okgo0?lc0?oo2Ol0oeGo0?l09_oo0?mco`Oo00;o000000GoO_l0
o`Go0?nbo`3o/_l0o`2@o`02ok;o0005okgo0?l;o`3o2ol0o`_o0?l0oa<00_l000000ol0ohGo0?lC
o`3mo`03o`3o4003o`3mooo@o`3ocOl000;o0?l>00Co0?mco`3o3_ooooooB?l01Ol0oj@01_m2o`3o
0?nTo`000?l0003oooooo`09o`;o00000_oo:0000oooI@3oCOl0o`0Vo`02o`000003oomV0?oo?P3o
ob/000;oob/000Go0?goool[0?oo:`3oob/0oomU0002ool[0006o`3olooo:`3oob/0ool[0?l0003o
8P3o0ol00003o`0Vo`?ooooo00_ob?l0oooooolV0?oo`Ol0o`000?l02Ooo_Ol0o`000?lV0?oo0000
o`3ob`06ooooo`;oon/01?ooool2on_o00Cooooo0_oYo`05ooooo`03onOo0?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00?ooooo
00Co0000onOo0?oWo`3o00000oooool2oo_o00?ooooo0_omo`05ooooo`;oo_l00oooool2oooo00?o
oooo00Ooc?l0ooom0?ooo@3o`ol0o`000?ooooooa?l000?o00000_ooool01oo4o`3o03?oo`0cooo5
o`3o0?goo`_o0?mSo`000_l000007_l0oeko_Ol0oooooooooooo0000oom]0?l0oOooa_l0okgo0?oo
ooooofd0o`3oXOoo>`3o^ol0oolk0?ooK03ooc/0o`3oXOl0of7oof`0o`000?nmo`3oobl0oom[0?l0
of7o0?goo`0cool0003o_Ol0oomT00;o03?o00?oof<0o`0cool0<ol00_l0<ol01?l>o`3o0=Coo`00
0?l00004okgo00;o2Ol000Oo0?n4o`Wo0?lc0?oodOl0okko0?l7o`3o0?mc00;o1ol00_l000001_l5
o`3o/_l0ogko0?nAo`3o/_l0o`2@o`Co2ol000Go0=Coo`000?l0003o0?n5o`0Vo`03o`3o4009o`3m
ooo=o`3o0?l>o`3o3_o<o`3o0?mcolco0?l0[ooo00Wo00Go0?nT00?o08Woo`3oY?o<o`000_l00000
2_oooooo_Ol0o`000?l0003ooad0oomU0?l09_ooobP0o`000?ooI@02oolo0003o`35oooo?P3oofH0
00;oob/000Goocd0o`3oa_oo:`3oob/0o`3oZ`03ool[0003o`3olol0ohgo4@3o00;oob/000Co073o
o`0Vool09_oooooo0olV0?l02_o8o`3o00Woo`000?o1o`3o0000okgo0?o1o`3o0000ooooool0ol/2
ooooo`03ooo[0?oooooooooo00?ooooo0_o[o`03ooooo`03onWo0?oooooooooo00?ooooo00?oiol0
ooooool000003Oooool00ol0003oooooooooo`1kooooo`00O?ooool00ol0003oooooooooo`09oooo
o`;o000000?oooooonOo0?ooool00oooool00ooko`3oooooooooo`02ooooo`03oogo0?oooooooooo
00;ooooo00Ooo_l0ooooooooooooooooolco0?ooooooool000;o000000?oooooolCo0?l000000_l0
00002?ooooooa?l0o`0cool0003oaOl0o`3moomSo`3oDol00_l000003?nko`3oofd0o`000?l0003o
oc/0ok;o0?ooK@3o08[ooolk0?nbo`3ooc/0oom/00;o/_l001Co08Woo`3mooooK03o0?nQo`000?l0
R_ooof/0o`_o0?l0R_ooof@0o`000?ooH`3o_Ol0o`000?l0oj7o0;?oo`ko0?l0GOoo3_l0olOo00;o
_Ol000Go3?l0o`3Dool<o`3o3?l0o`Wo0003o`0co`05o`3oQ?l0<ooo03?oo`0coolc0?l00_l0<ol0
2Ol0og?o03?oo`Go0?mno`3o1Ol0o`2fool0U_oo2ol0o`2@o`02o`_o00Go/_l00_l000000ol0ohGo
02Koo`3o4`03o`3o4`03o`3mool0ojCo0?nT00Ko0?nT0_l0o`h3o`3oH@0?od;o0?l0ROoo0000o`00
0?oo:03oofD0oolX0?l0003o_Ol0o`1QooooI@3o0?mQo`35ool0003oofH000;oob/00_oo?`000ooo
I`3oob/0o`3oaP02ool[0005oomU0?l0oo?oob/0ool[0?l0ohd00_l0R_l00olR0?oo073oo`1`o`02
o`0Vo`03o`3mooo7o`3ooooo00?ooooo00Sob?l0obH0ool02Ooo0000obH0ool0oOoo_Ol0o`0000;o
oooo00?o0?o;ooooooooool00_ooool2ooo[00Cooooo0_o[o`04ooooo`;ojOl01Oooool2onOo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Ko
oooo0_oWo`04ooooo`;onol00oooool2oogo00Gooooo0_ono`03ooooo`;oool000Soooooolco0?oo
ooooooooo`000?ooo@3oooooolCo00;o000000[oooooo`000?l0003oa?l0o`0coonbo`3oaOl0o`3m
oomSo`3oDol00_l000003?nmo`3o/_l0o`000?l0003o0?n8o`09ooooK@3oa_l0o`3oHOnmo`3ooc/0
oom]00;ooc/001Co0?gooom/0?l0R_oo0?nQo`1Cool0of7oof`0okgo0?oo;`3o0?gooom[0?l0oOoo
0000okgo0?l0VOooof@0o`ko0?ooH`3o3_l0o`3Ro`?o3?l000?o03?oo`3Dool0<ol02?l0<ol01_l0
ohCo1ol0oc<0ool7o`3o0?n8o`3oL`?o1Ol000Oo0;Koo`3oZol;o`3oO_l0oi7o0?l;o`3o093o00Co
/_l000Coc?l0o`000?l0003o0;7o1?l0oa<00ol0oOoo0?nTo`3oY006o`3oY003olgo0?l0o`koEOl0
00?o0?mQ00Wo08Woo`3mool0003o0000od;o0?l0HOoo_Ol0o`000?ooI@000_oo:0001?l0of7o0000
oomU0?l0aOl2ool[0003oomV0?oo?`3oocl000?oob/000Ko0?ocool[0?oo:`3o0?ocoomU0?l0R_l3
ool[00?o02Ko013oaol0obH0oolV0?ooooooobH0ooo8o`3o00Woooooool0003o`Ol0o`000?nmo`3o
0=[oooooool0003o0?o;0_ooj`04ooooo`;ojol00oooool2onWo00Cooooo0_oWo`02ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0Noooool007cooooo00?o0000ooooooooool03?oo
ool00ol0003oiol0ooooo`03ooooo`03oo_o0?oooooooooo00;ooooo0_omo`03ooooo`;oo_l000Co
ooooolco0?oooooooooo0_l000001oooooooa?l0o`3mooo4o`3o0000ooooooo4o`000_l000001?o5
o`3oHol0oe?o0?ooool2o`000003o`3moonko`3oofd000;o000001Ko00Wooolk0?ooK@3ooc/0oooo
oooo>`3oobl0oom/0?l0oOoo08Woolco0?l0oOooof`0o`000?l0R_oo_Ol0oom[0?l0R_oo0000o`3m
ooooH`3o_Ol00ol>o`000ol0/ooo05goolOo0003o`co0009o`3mool0e?oo2Ol0o`Wo0?l09_ooh_l0
o`2:ool7o`3o0?n400;o1ol000So_Ol0o`Go0?lc0?oo1Ol0o`3oLonmo`3o03?oogko00Co03?o00?o
093oo`0cool0<ol00ol0<ol00om_o`3o_Ol0ok;o0003ok;o00Go0?nT1?l0oa<00oo<o`3o0?mco`3o
4002o`3o4006oooooonmo`3o0?l>o`3o3_l0of7o@_l00_oo:0001_l02OooofD0o`3oVOl0oiWo0000
oomU00;o000000Soocd0ool[0?oo:`3o0?mQo`3oa_oo:`3oofL0oolo00;oob/000Go0?ocoomU0?oo
:`3oob/0o`3oRP02o`3mo`;o08[o00Co073oo`0Vool09_oo0?go1_l0R_l03_lV0?oob?l0o`09oolV
0?oo0000occo0?nmo`3ooooool7o0?l0003o`Ol0o`000?l0ol_ooooo0_ooj`05ooooo`03on_o0?oo
oooooooo00;ooooo0_oYo`05ooooo`;oiol01oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool01_ooool00ol0003oooooonOo0005ooooo`03oo_o0?oo
oooooooo00;ooooo0_omo`05ooooo`03ooko0?oooooooooo00;ooooo00_oool0ooooooo<o`3ooooo
o`000?o3o`3oood0o`3oc?o4o`3o0?goooooo`03o`000009olCo0?l0<ooo03?oof?o0?mCo`3o2ol0
ooooool;o`3o0?go00Go000000_o08[ooom]0?o6o`3ooc/0o`3oXOooK@3o0?gooolk0?l0oOoooc/0
oom/0002o`3oX@0<o`3oHOl0003oof`0ool_0?o<o`3o0?mQoom[0?l>o`3o_Ol0oomT0?l0GOooof<0
0ol<o`02okgo0007o`Wo0?l0e?oo2Ol0o`Wo0?oRo`3o08[oo`3Po`05o`Oo0006o`0cool0ohCo03?o
oc<0ool0<ooo0?mc1Ol0<ol02omno`3oTOl0o`3oLoo<o`3o093oo`3`ool0e?oo__l0okgo0?nbo`3o
0?n500;o/_l01?l0oj@00ol0oOoo0?lCo`3o4`02o`3o4`03o`3oLol02OoocOl000;o0?l@00?o_Ol0
o`3o3_o<o`000_o<o`002_l0of7o08Wookko0?l02Ooo@_l0o`3oVOnmo`3oofD0o`000?l0oOl2o`00
0006oomU0?oo:`3oob/0o`3DooooIP3ooch00_oo:`001ooo?`3oob/0ool[0?oo:`3o0?n=oomK0?oo
I@000_oo:`001?l0L?oo02Koo`0Vool01ol5o`2:o`;o00Wo00cob?l0oooooooooooo0000oooooonm
o`3o`Ol0ooooool0f_oo0000ooo[0?l0ol/4ooooo`03on_o0?oooooooooo00;ooooo00?ojOl0oooo
ooooool00oooool00ooWo`3oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0Noooool007cooooo00?o0000ooooooooool03?ooool01?l0003oooooonOo0?oWo`03oooo
o`;onol01?ooool00oomo`3oooooooooo`02ooooo`04ooko0?o<o`3oooooooooo`;o000000Ooool0
olCo0?l0oOooa?l0ooooool0003oa?l000;ooooo027oHol0o`000?l0003o03?oofoo0?l;o`3o0?go
okgo0?o6o`3oofd0o`000?l0oOoooc/0oom]0?oo>`3oKol0oolk0?oo;`3oof`0o`2:ool0ROooc?l0
ofoo0?l0of7oof`0o`2:oonmo`3o3_l0oom[0?nko`3oof<0okgo0?l0oOl00ol<o`02o`0000?o2Ol0
00Go0?goo`2Iool0e?oo0?lUo`Oo0002o`2:o`0=o`Oo0?l5o`3o1Ol0o`3oQ?l5o`3o_Ol0oonj0?o?
o`3o<`3oo`3oLol;o`3oO_l0ooooo`04okgo0003o`2@ool0/ooo0=Co00Go0?nT00Co0?n5o`3oY?l0
<ooo03?o1Onbo`02o`2_o`04olco0?o=o`3o0?lCo`3oL`;o0?lC00?oooooo`3o4?l0oa000ooo:000
1_oo^P3o@_l0o`3oHOooI@3o0?mQo`3o3P;o0<Go00GoofD0ool[0?oo:`3oob/0oomV0003ool[0006
oomW0?oo:`3oob/0oolm0?oo:`3oofD00_oo?`001?oooooo073oo`1`ool0L?l3o`0Vo`0:o`07oooo
ooooon80o`3mool0ROoo0?goolOo0?oooooo00WoolSo00;o08[o00_o0000ol7o0?nmo`3ooooool7o
0?l0003o0?gool7o0?l0003o0?o;ooo[0005ooooo`;ojol00oooool2onWo00Gooooo0_oWo`09oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;oiol01?ooool2oo_o00Cooooo00?ooOl0ooooooooool00oooool2ooko
00?ooooo013oool0olco0?oooooo0000ol?o0?oooooo0?o<olCo0?l0oOooooooolCo0?l0003ooooo
olCo0?ooooooHol00_l000001Ol;o`3oKol0o`_o0?l0oOoo^ol000;oKol00_l000006_m_o`3oofd0
olKo0?oo>`3o0?gooolk0?ooK@3ooc/0o`2:oooo>`3o0?nQoom/0?l0oj7o0?mQo`000?ooK03oobl0
o`ko0?l0003oof/0okgo0?l<o`3oof@0o`co0?ooH`3oaol00_l00002o`Wo0003o`3mool0e?oooooo
00Co1ol000?ookX0o`Go0?l5o`000_l5o`001ooKo`3o08Woo`3oQ?l;o`3o<`3oo`3oLol;o`000_nm
o`000ol09_ooO_l0oi7o0003o`0co`03o`2@ool0ojCo0?nT00?o0?nT00?o0?n5okgo0?nmo`001?nb
o`000ol0oOooh_l0om7o0002olco000=olgo0?l0og?o0?lCo`3o4ol02Ooo0?l@olco0?l0oa3o08[o
olco0?nno`3o0?l>o`29o`02o`3oH@0:od;o0?oo:03oofD0o`3oVOl0003oob/0oomU0?oo:`3o0000
oolm00Koob/000?oocd0o`3oSOoo?`000ooo:`005_l0R_oo02Koo`0VoolA0?ooon80o`07ool0ROoo
9P3oo`3moolV0?oo00Woo`2:ool0003ob?l0ooooool0003o`Ol0okgo0?oooooo`Ol0o`3mooooj`02
o`000003o`3obooooooooooo00;ojol00oooool2onWo00Cooooo0_oWo`05ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0Noooool007cooooo00?o0000ooooooooool03?ooool01Ol0
003oooooooooooooooooiol000Cooooo00?onol0ooooooooool00_ooool2oogo00?ooooo00Coo_l0
olco0?oooooo00000_ooool02Oooo`3oa?l0ooooooo4o`3o0000olCo0?ooooooHol0o`3mo`02o`00
000Lok;o0?l0<ooo03?oo`_o0?oo>`3o_Ol0olKo0?ooK@3o0?gooolk0?l02Oooofd0o`3moooo>`3o
obl0o`2:ooooK03o08Woooooooo<o`3o0?mQoom/0?l;o`3o_Ol0o`000?ooJ`3o3?l0oomS00Co^ol0
00_o2Ol0o`000?l0003oc?l0o`3o?ol0003o0?goo`Oo0?l0e?oo1ol0o`2:o`03o`Go0005oeGo0?oo
^P3o08[oo`3oQ?nmo`000_l;o`001Ol09_oo0?mcogko0?nAo`3o0?go00Co0?nT00Co093oo`3oY?l0
ojCo_Ol00_l0/Ol01Ooooooo0?n5olco0?l09_oooooo00;ocOl000Co0:oookgo0?nmo`3o0?go1Onb
o`03o`0co`?oobP000Oo03?ooeGo0?nmo`3o0?l@od;o0?l0ROooofD000;o0<Go00Go0?mQo`000?l0
003o0000o`3oaP02ool[0005o`3oZooo:`3oob/0oomW0?l000000_oo:`001?oo?@3oofD0o`2eool0
L?l3oolo0004o`0VoolR0?oo0?nQo`3oX@;o08[o00oo9P3oo`3mool0e?ooooooo`3mool02Ooo9P3o
olSo0?oooooo08[oo`000?nmo`3oooooo`3oQOo1o`000_l0ohD01?o1o`3o0000o`000?l0ol/2o`3J
o`03ooooooo[o`3ojol000Cooooo00?ojOl0ooooooooool00oooool2onOo00_ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool2onOo00Cooooo0_oko`03ooooo`;ooOl01Oooool2ooko00;ooooo00ooc?l0oooo
0?l0003o`ol0ooooool0olcoa?l0o`3mooooo@3oa?l0o`000?ooooooa?l0of?o0?l0oOl00_l00002
o`0co`0Aoooooonmo`3o0?gook_o0?oooooo00Woo`3moooo>`3o0?gooom]0?oo>`3o_Ol0oolk0?l0
R_ooofd0oolk0?ooool00_l>o`003?ooK03o0?mQo`000?oo;`3oof`0o`000?l<o`3o_Ol0oom[0?oo
I03o2Ol0oomS00;o2Ol00_l00003o`Oo0003o`3Dool7o`3o08[o00Co1Ol000?odOl0oh?o0?l;o`00
0ol;o`001?l0ohCo__l0o`3oR?l0og<2o`3mo`;o0?nT00?oO_l0oi7o0?l0oj@00_l0oj@01ol0T?oo
__l0olco0?l09_ooc?l0o`3oQOo=o`001_l0<ol5ok;o0004ooooool0og?o0;7oo`3oL`;oc?l000?o
0?lCokgo0?l0R_l00_l0oa02okko0005o`29oooo:03o@_l0oomU0?l0aOl00_l000000oooI@3o02Ko
ool[0002ool[0003oomV0?oo:`3oob/000;oocd000OoofL0ool[0?oo:`3oob/0oomU0?l0]Ooo02Ko
00Coocl000Co00Ooo`3Dool0oOoo0?nQ0_l02Ol2ooooo`05o`000?o8o`3oooooo`000?nmo`000_l0
ohD00oo1o`3o0?n5o`000002o`000003ooooool0ol_ojol000Cooooo00?ojOl0oolj0?oo>P000ooo
ool00ooWo`3oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Nooo
ool007cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`;oiol00oooool0
0ooko`3oooooooooo`03ooooo`08oogo0?ooooooooooooooooo<o`3oo_l0o`000?o3o`02ooooo`04
olCo0?ooo`3oa?l0ooooo`?o000001Ko0?goolGo0?l0oj7o/_l0oeko0?l;o`3o03?ooolk0?nmo`3o
G_l0oom]0?nko`3ooc/0o`3moooo>`3oofd0oolk0?oo;`3o_Ol0o`29ooooK03o3_l00_l0of402?l0
003oof`0o`000?ooI03o08[ooom[0?ooH`3o0?go0_l9o`001?nmo`3o^ol0ok_o0?nko`02o`Oo0007
o`3mool5o`3o0=Coo`Go0?l0R_oo02Koo`2Io`05o`_o0003olOo0?l0ohCo0?nT00?o0?nT00?oO_l0
o`3oY?l0oj@00_l0ROl00ol0ohSo0=Coo`2@o`02olco0008oeko0?nmo`3o_Ol0o`3oQOnmo`3oc?l0
o`0Vooo=o`02o`2_o`04olco0?l0GOoo0?mQo`3mo`?o_Ol000?o08[oolco0?nbo`000onbo`000ol0
2Ooo_Ol0olgo0003o`0co`06o`35oom2o`3o08Woo`3mool0<oooofD00_l00002ool[0005oomV0?oo
:`3oob/0o`3o3_ooI`000_oo:`02oolm0004oomU0?l0003o0;Goo`3oH@;o02Ko00[o0?gooolo0?oo
?`3oocl0o`07ool0oj7oon80o`2:ool0e?oo0?go1?l0ohD01?o8o`3o0?n5o`000?nmo`02o`3oQ@09
olgo0?oo>P3oocX0ooo[0?o1o`3o0000ooooool0ol_ooooo00;ojol01?ooool2onWo00Cooooo0_oW
o`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Cooooo00?oiol0ooooooooool00oooool00ooko`3ooooooooo
o`02ooooo`;ooOl01Oooool02Oono`3oooooolco0?oooooo0000ol?o0?ooo`3o0?o<olCo0002oooo
o`03olCo0?ooo@3o000000;o000000Go0?goolGo0?o>o`3oG_l0o`_o0002o`0co`03o`3moomNo`3o
^ol000;o0?go00Gooc/0o`3oHOl0R_ooofd0o`3oX@02oolk000Aoom]0?oo>`3o3_l0o`3mool<o`3o
of`0o`3oHOl0003oobl0o`000?ooK03o2Ol0okgo0?l9o`3oof/0okgo0?ooH`001?l7o`001?l0ocoo
1Ol0o`Go0?l0e?l2o`Go0003o`2Iool0R_oo2ol000?o2ol000?oPol0okgo0?l0oOl00_l0oj@00ol0
ohCo0?nTo`3oL`02o`3oY008o`3oR?mno`3oTOl0o`2fooo<o`3o0?mcokgo0?l0T?l2okgo0004olco
0?l0ohGocOl0o`0Vo`;o0:oo0_o<o`000ol0GOoo0?goo`3mo`02olgo0003olco0?l0/Ooo/_l000?o
/_l01ol0<ol2okko0005oolX0?l0ROooofD0od;o0?nmo`000_l000000oooI@3oob/0o`3oaP03ool[
0003o`3oVOl0ohSooch000;oob/00ooo?@001oooI@3o02KooomK0?l0oj7o2ol0oa40ool0R_l01?oo
?`04o`3oQ@05olSo0?l0ohGo0000okgo0?o1o`000_o=o`001oo1o`3ooooool7o0?l0003o0=[oon_o
0?l0ol/00oooool2onWo0004oolj0?ooooooooooooooo`;oiol02?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo07_ooooo001looooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01?ooool01?oWo`3oooooooooooooool2oo_o00Cooooo00CooOl0ooooooooooooc?l00_l0
00001oo3o`3oooooo`3mooo4o`3oooooolCo0?ooo`000ol000001Ol0oOooaOl0o`3oXOo>o`3o/_l0
00;o2ol0017ooc/0o`3moooo>`3oa_l0oom]0?oo>`3ooooooolk0?l0R_ooofd0ool_0?nmo`3o08Wo
ooooooooK03o0?goo`3oH@02o`000006oom/0?ooI03o08[ooomS0?ooJ`3o0?go0ol7o`000oo7o`3o
0000o`Go0003o`Go0003o`3o?ol0e?oo2ol000;o2ol01ol0oj@03Onmo`3o0?n4om_o0?ooooooO_l0
oi7o0?l0h?oo<`3oo`2Fool0/Ooo0=Coo`2fool0T?l00_o<o`002?l0/ooo02Koo`3oQOooooooc?l0
olgo0?l09_oo_Ol00_ooool01ol0GOooc?l0olgo0?l0oOoocOl0olco0?l0/Ol00onmo`000ol0og?o
0?lno`3oL`05ok;o0006o`35ool0oOoo@_l0o`09ool0ROoo0?o61?oo:`000oooIP3o0000o`000002
ool[0006oomW0?l0<ooooch0o`0cool0003oofD00_oo?@000ol09_oo0?mQo`3oV@04o`3oQ@?oocl0
00_o0?n5o`2:ool0R_ooooooo`3oXOo7o`3o0?goolSo0?oooooo_Ol0ol7o0002olgo0004oolj0?o1
o`3oon/0ol7o00;ooooo00?o0000on_o0?l0ol/00_ooool01?l0f_ooooooonWo0?oYo`04ooooo`;o
iol03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`;oiol01?ooool2oo_o00Cooooo00?ooOl0oooooooo
ool00oooool2ooko0007o`000?oooooooooool?o0?l0olco0?goolCo0002ooooo`0<olCo0?l0003o
0000o`000?l0oj7oooooolGo0?oooooo2ol0oooooonmo`3o03?o0ol0oOl02_nko`3ooc/0o`ko0?oo
>`3oa_l0oom]0?nmo`3ooc/0o`co0?ooK@02o`co0003oc<0ool0Doooof`000;o000000Wo2Ol0o`3o
HOooK03o0?gooomT0?ooJ`3oof<0o`Oo0?l0GOl01?l5o`000ol0ocoo0=Coo`3mo`04o`_o00Oo0?nT
0_ooool02?nno`3o0?n4o`3oLol0h?oookX0oc<0oomno`3oTOl00_l0e?l01ol0og?o__l0o`2@ool0
9_oocOl0o`3oQOo<o`000_nmo`02odSo0006o`1Mooo<o`3oc?l0olco0?l0oOoo00Wo0_o<o`001Onm
o`3oc?l0olco0?l0og?ooad000Co/_l000?oc?l0o`3DoomEo`000_l0<ol2o`35o`06oomU0?m2o`3o
ob/0ool[0?ooI@3o0?o60_oo:`000oooIP3o0?l>o`3oS@03ool[00Co000000CoofD0oolm0?oo?@3o
ocd01Ol0ohD00ol0R_oo0?n5ooooo`03oolo000Booooooo8o`3ocOl0okgo0?o1o`3ocOl0ooo[0?o1
o`3o0?goooooooo1o`3ojol0o`000?l0f_ooooooo`3obooooooojOl00_oo>P02ooooo`;oiol02_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07_ooooo001looooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01Oooool00ooWo`3oooooooooo`02ooooo`03oo_o0?oooooo
oooo00;ooooo0_omo`003oo<o`3o0000o`000?o3o`3oo_l0o`3mooo4o`3oooooolCo0?ooooooool0
o`000?l0oOooooooolGo0002o`00000Mooooool;o`3o2ol0oolk0?l0oOoooc/0o`0cooo6o`3oofd0
oolk0?l0R_oooc/0o`3oXOooK@3o3?l0o`29ool0of7o0?gooom/0?l0of7o0000okgo0?l0oj7oof`0
okgo0?ooH`3o1ol0oom[0?nmo`001?l5o`000ol0GOoo0?goo`3oY006o`3oY00;oooooooAo`3ogol0
oonj0?l0VOoo02KoolOo0?nmo`3oPol0o`3oQ?ooool00_l00002o`2ao`0?oc<0ool0e?oo0?n8o`2@
ool0og?oc?l0oonj0?l09_oo__l0o`3oQOo=o`3oc?l0o`29oooo^P3o02Ko00;o_Ol00_o=o`001On3
o`3o0?goolco0?o=o`3od?l000;oc?l000Co0?lnokgo0?l0og?o_Ol00ol0aOl01onmo`3oc?l0ok;o
0?ooI@3o/_l0od;o0?nbo`000_l00002ool[0003o`3oSOooIP3oob/000;o000000WoofL0ooln0?l0
ohGo0?n8o`000?ooI@3o0000o`2eoonmo`000_oo?@08o`0co`?oocl001?o08[oooooool0003ob?l0
o`3moonmo`3ooooool7o0?ooooooocX0ol7o0?l0oOoooooool7o0?oooooojol0o`000?oooooo0?o;
00;ooooo0_oYo`05ooooo`03onOo0?oooooooooo00oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool2onOo
00Cooooo0_oko`03ooooo`;ooOl01Oooool01ol0003oo_l0ooooooo3o`3o0?o<o`3mooo4o`000_oo
ool01?o4o`3oooooo`000?o4o`02o`000005olGo0?l;o`3o2ol0oooooonmo`000ol0oOl02?l0<ooo
3_l0oolk0?l0of7ooc/0o`2:ooooK@3o3?l00_oo>`003ol0ROooofd0o`Wo0?l9o`3o2ol0o`3oHOl0
003oobl0o`Oo0?nmo`3oof`0oomT0?nmo`3o1Ol0oom[0002o`Go0004o`3mool0/ooo2ol0o`_o00Oo
0?nT00_ookX0o`0Vool09_oo09WoolOo0?nmo`3ookX0o`000?l0oo7o__l0o`2Fo`02o`00000;okgo
0?mno`3oTOl0o`3Dool0/ooo0;Koo`3oLol09_oo0?n8o`2@ool0ohD01?o<o`04okgo00;ocOl00_l0
oOl3olco0008o`2:oonmo`3o0?mcokgo0?l0e?oo0?mcokgo0?l0R_l5ok;o0003okko0?ooI@3o0?go
00;o000000KoofD0ool[0?oo:`3o0?n[o`0cooooIP02ool[0003o`3oHOooI`3o03?o00;o000000Ko
och0oomU0?l0]Oooocd0ob80ooooF`03oolm0003o`09ool0oj7o08Wo00;o08[o00?o0000olOo0?l0
oj401?oo?`003_o1o`3oooooooooooo1o`3oooooon_o0?o1o`3oooooo`000?oooooo0=[oo`3obooY
o`3oocX00oooool00ooWo`3oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0Noooool007cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`;o
iol00oooool2oo_o00Cooooo00Woc?l0o`000?l0003o`ol0ooooool0oOooa?l0ooooooo4o`000_oo
ool01?l0003o0?goolgo0?o5o`03o`0000;o0?go01Kooc/0okgo0?oo>`3oooooolKo0?l0<oooofd0
ok_o0?oo>`3o3?l0ool_0?ooK@3o08Woo`3mool9o`3o0000oom/0?l0003o_Ol0oomT0?l0R_ooof`0
0ol5o`001?ooJ`3o0?nTo`000?l00003o`3oY005o`3oDol0R_oo08[oo`3DoomEo`000onko`02okko
0008oonj0?l09_ooaol0o`2Ioonmo`3oPol0o`3oQ?mno`02o`000007ooooool0e?oo0=Cooc<0ool0
ohSo093oo`3oL`02o`0Vo`08olgo0?l0ohGookX0o`3oR?o<o`3oPol0oonj0?l09_l2olgo00;o0;7o
00?o00Woo`3mooo<o`000oo<o`000ol0ocko0=Coo`35o`02o`35o`?o_Ol000Oo08[oo`3oa_ooI@3o
0?o6o`3mool0oj_o@_l000;o000000co/_l0ool[0?ooIP3oob/0o`3oQOl0003oofL0o`000?l0ohGo
och0o`0VooooI@03o`000003o`2:ooooF`3o0?l>00?oocd000Co00Oooa40ool02Ooo00Wo0_l0oiT2
o`0co`?oocl000?o03?ookgo0?l0<ol00_l0<ol00ooo>P3o03?oolco0004olco00;o000000Cooooo
o`3obooYo`3ojOl00_ooool00ol0f_ooooooooooo`02onOo01;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Ooo
ool00ooWo`3oooooooooo`03ooooo`;onol00oooool2oogo00?ooooo00Oo0000ooooooono`3o`ol0
o`3oc?l0oOooa?l000;oool000Coa?l0ooooool0003oa?l00_l000000oo5o`3o2ol0o`ko0002o`3m
o`;o3_l001_o0?goo`co0?oo>`3o03?ook_o0?oo>`3o0?nQolKo0?ooK@3o_Ol0oolk0?l9o`3o0?nQ
oom]0?l;o`3o0000o`2:ool0003oobl0o`Go0?nmo`3o1Ol0oom/0?l5o`3oof<0o`3oY?ooJ`000_l0
0003o`3oY003olco0?l0e?oo^ol000;o^ol000go__l0o`0Vool09_ooon80omgo0?l0C?ooaol0okgo
0?oo^P3o0000o`3olOnno`3o09Ko00;o000000OoO_l0oi7o0?l0e?oo<`3ookko0?l09_oo0?mc00;o
cOl000Ko093oolco0?o<o`3oB?l0oonj0?l09_l2olco00;ocOl000Co_Ol0o`09ool0oOoo_Ol00_o<
o`001Ol0e?oo00Wool_o0?l0og?o08[o00?o_Ol000So08[oo`35ool0aOoo0<GooeGo0?l02OooofD0
ok;o00?oob/000?oofD0o`3oZol0ohD00ooo:`001Ol0ohGo0000o`3oR?ooI`3o02Ko00;o000000Ko
ofD0o`000?oo?@3o03?ooolm0?ooF`03o`0co`Coocd000So0?goo`2:ool0003oooooo`3oXOnmo`3o
0000ooo[00Coocl00oo<o`02o`000004oooooooYo`3o0=[ooolj00;ooooo0_oWo`0=ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0Noooool006Cooooo0_l00006o`0Woa3ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`02ooln00Kooooo00?oiol0ooooooooool00_oo
ool00ooko`3oooooooooo`02ooooo`09o`000?oooooo`ol0ooooool0oOoo0?o<olCo0?ooooooa?l0
00;ooooo00Co0000olgo0?ooooooaOl00_l0oOl06Ol>o`3o2ol0oolk0?nmo`3ooc/0o`co0?oo>`3o
a_l0oolk0?ooK@3ooc/0o`Wo0?oo;`3o08[ooom]0?nmo`3o0000o`_o0?l7o`3oof`0okgo0?ooI03o
0?nToomS0?ooK0000_l0oj@01?l;o`3oof/0o`000?l00003o`3mo`08o`2:ool0oOoo0=Coo`2cool0
h_oo0?loom3o0?o?o`03ok_o000Eokko0?o7o`3o__l0okgo0?l0/OooPol0o`3oQ?nno`3o0?mco`3D
ool0U_oo_Ol0o`3olOlc0?oo093oo`3oLol0h?oocOl0o`3oQOl0/oooPol000;oc?l000?o9?l0olco
0?o=o`000_l0/Ol02?o<o`3o00Woo`3Dool0oOooc?l0o`1Coonmo`3oc?l00_l0aOl01?l02Ooo0?mc
oloo0?l0od03o`3oaP03o`3oQOooI@3o0?n[00;o000000Go@_l0o`3oSOoo:`3oob/0oomV0003ok;o
0008o`000?ooI`3o0?goo`000?oo?P3o0?lCoomU0?l0oOl2o`000006oolm0?l0oa3ooe/0ob80ool0
oOoo00000_oo?@02o`3o3P;o000000?o08Woo`3oVOl0oOl00_o<o`03oolo0004olco0?oo>P3o0000
olco00Co03?o0ol00002onWo0003o`3obooooooooooo00;ooooo0_oWo`0Dooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0C?ooool2o`0000Go02Oo1_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00[ooooo0_oWo`05ooooo`03oo_o0?oooooooooo00;ooooo0_omo`00
2?oooooo0000oooooooooooo`ol0o`3oc?l0oOooa?l00_ooool01oo4o`3oooooo`3mool0003o0?nQ
o`000?o5o`000_l0oOl00ol;o`3o_Ol0o`co0002o`3mo`04o`000?oo>`3o2Ol0o`0co`;ooc/000Co
a_l0oolk0?ooK@3ooc/00_l7o`001_ooK@3o0000o`3oY?l0ojCo0000oom/00;o0?nT00?oof@0o`3o
Y?ooK0000_l;o`002_ooJ`3o0000o`000?l0oOoo08[oo`2cool09_oo0=Coolco0?l0ocl2o`0Vo`;o
^ol001Ko__l0oonj0?oQo`3oaol0okgo0?n3o`3o09Woo`3oR?nno`3o0;7oo`3oLol0ohCoO_l0oi7o
0?l0k_ooc?l0oc<0ooo=o`3o0?mco`3Pool0ohSo093o0_o<o`000ol0ofCoc?l0o`0Vo`02olgo0006
o`3Dool02Ooo00Woo`3Dool0oOooc?l01?nmo`001Oo?o`3o05?oo`3oLol0R_oo0?n500;o0<Go0ol0
ohD01?l0olKoofD0o`000?l00002o`3oZ`0:oomU0?oo:`3oob/0ool[0?ooIP3o073oo`000?o7o`3o
02KooomW00;o0?lC00So08[ooom90?ooI@3o0000oolm0?lR0?ooocd0o`3oH@;o000000?o0?l>olgo
0?l0ROl00_l00003oolm0003o`2:oonmo`3o03?o00;o03?o0_l000000ol0<ooo`Ol0oolo0003oolo
0007o`000?oYo`3oocX0oolj0?l0ol_oooooonOo000?ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0Noooool006Cooooo0_l00006ooooo`co02Oo1?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00;ooooo0_oo?P05ooooo`03onOo0?oooooooooo00;ooooo00Gonol0
ooooooooooooooooo`000002oogo000=ol?o0?l0oOoo0?o<olCo0?ono`3oa?l0ooooool0oOoo0000
ooooool0oOooaOl0ooooo`03o`co000;oolk0?l0oOoooc/0o`3moooo>`3oa_l0oolk0?l0of7oofd0
ok_o0?oo;`000_l000003_ooK@3o1Ol0o`3oY?l0ojCo0000oom/0?l0ojCo0?nQoomS0?ooK03o2ol0
o`3mool0ohSoof/00_nlo`000ol0oOooooooo`2:o`02oeGo0004o`3Dool0oOoo0?goo`3mo`;o02Ko
00?o0?gooonj0?l0oOl00onko`002?nmo`3o0?googko0?l0ohSo0?n4o`3oLooMo`3o_Ol00_l0[ol0
1Ol0ohSo093ooc<0ooo=o`3o0?n500;o0>3o00?o0;?oolco0?o<o`000_o=o`002?l09_oo0=Coo`3D
ool02Ooo9?l0olco0?l0oOoo0?n50ol0aOl4o`3oQ@;o0?o600Ko_Ol0o`3oZol0oj_oofD0okko0?l0
ohd2o`000006oomU0?m2o`3o__l0o`1`ooooIP3o_Ol00_o7o`002Ol0003o02Kook;o0?nbo`3o0000
oomU0?nbo`3ooch0oolm0003o`000003oomK0?nmo`3o00Wo00;o000000Goc?l0oolm0?oo?@3oocd0
o`000003olco0003o`_o0?nmo`3ob?l000;o08[o0ooo?`001Ol0oOoo`Ol0on_o0?o1o`3ooooo00?o
00000_ooool00ol0ol_oooooooooo`02onOo0003ooooool0f_oooooo01?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1<ooooo`;o00001Oooool;o`0Wo`Cooooo00?o0000oooooooo
ool03?ooool2onOo00Cooooo0_oko`02ooooo`;ooch000?ooOl0o`000?o<o`000_ooool00oo3o`3o
0?goolCo0003ooooo`04olCo0?l0oOoo0000olCo00;o0?go013oaOl0o`co0?l<o`3o_Ol0ooooool0
oOoo2Ol0o`3moooo>`3o0?mQoolk0?l7o`3ooc/0o`0cooo6o`3oofd00_l00002o`3oY00;oom]0?o<
o`3o08[oo`000?nmo`3oof`0o`_o0?ooI03o0?gooom/0?o7o`000_ooool00oooJ`3o08[oo`3mo`02
o`3mo`04o`3Dool0oOoo02Koo`0Vo`?o0?go00oookX0ok_o0?nko`3o^ol0olOo0?nmo`3oPol0o`3m
ool0ohSo__l0okgo0?l0og?oO_l0oi7o0?o<o`000_l09_l01_o=o`3o<`3oo`3oLol0ohSo0?n5o`2@
o`?oc?l00_o=o`001?l0e?oooad0o`09ooo;o`02olco0003o`3mool0ohGo0?n500Go0?n500Ko0?mc
o`35ool0aOoo0?mco`2:ool0ol42o`3oaP05okgo0?ooI@3o0000o`000?nno`000_oo:`002?m2o`3o
08Woo`1`ooooIP3o/_l0o`000?nbo`3oofL00_l000000ol0ohSo0?lCoomU0003o`000003okgo0?oo
?@3oc?l000;o00000oo<o`02o`0000;oc?l000Ko_Ol0oolm0?oo?@3oocd0o`2:ooo1o`02o`000003
ol7o0?l0<ooo03?o00;o03?o00Oo0000oolo0?oo?`3oocl0oooooooWo`3o0?o;013ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1kooooo`00N?ooool<o`0Wo`04ooooool0003o:03o
obP0o`?ooooo00?o0000ooooooooool01?ooool2ooln00Cooooo0_oWo`03ooooo`;onol000gooooo
o`000?oooooooooool?o0?l0oOooooooolCo0?ooooooa?l0ooko0?l0oOooa?l000;o000000?oaOl0
o`co0?oof@000_l9o`002ooo>`3o0?gooolk0?l0oOoooc/0o`Oo0?o6o`3o0?mQoolk0?ooK@3oobl0
00;o000000oo0?nToom]0?l;o`3o08[oo`000?ooK03o_Ol0oomS0?l0oj7o^ol0oom/0?l0oOooaol0
okko0?ooJ`000_l0oOl03?l0R_oo05gookco0?l0of7o0=Coo`3oDooRo`3o02Koolko0?l0ocoo_Ol0
oonj00;o0;7o00Goaol0oooooonmo`3o^ol0ogko0002o`3Do`04o`3oQ?l0003o0?goo`3mo`;o02Ko
00?o093oo`000?l000000_l0oOl2o`0000Wo0?n50ol0aOl01?l0ocko027oolco0?l02Ol3o`3oaP06
o`3oLol0oj_o0?n[okgo0?l0R_ooofD00_l000000ooo:`3oofD0okgo0002o`000003oomV0?l0oOoo
08Wo00;o02Ko00Oo0000o`1bool0L_oo0?n8o`000?ooI@3oodT000;o/_l00ol000001oooF`3o_Ol0
olco0?l0oa?o0?goo`3oHOl08Ol00_l0oa03oolm0007oooooonmo`3ob?l0o`000?l0o`koocX0o`2:
o`02o`3mo`04oolo0?oooooooooool7o00;o03?o0_l00003ooooo`03o`3obooWo`3ooooo00?ooooo
00?o0=[oooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool00_ooool;o`0Wo`[ooooo00?oiol0ooooooooool00oooool2oo_o00;ooooo
00?ooch0o`000?o<o`000_ooool01?o3o`3o0?goooooooo4o`02ooooo`03olCo0?l0oOoo0?go00;o
000000GoomT0olGo0?l9o`3o2Ol0okgo0002o`3mo`0;o`Oo0?l0oOoooc/0o`Oo0?oo>`3ooooooolk
0?nko`3oa_l0oolk0?ooK@000_l00002o`_o000:oom]0?l;o`3o0000okgo0?ooK03oof@0o`_o0?oo
H`3oaol0oom/00;o_?l000?o05gooom[0?l0oa000_mEo`000ol0e?oo02Koon;o0002okgo0004o`3o
?ooo^P3oc?l0omgo00;o0;7o00coaol0okgo0?n3o`3ookX0o`3oR?nno`3o0?googko0?nAo`3o0000
o`3oQ?o=o`03o`3mo`;o000000Go0?goo`2@ool0003o0000olgo0005o`3oQ@08olco0?l0ohGo0?n5
o`3mool0ocko00Woolco0?l0oOl2o`3ok@;o0<Go00?o0?mcokgo0?l0R_l00_l0olH01?nno`3o0?n:
oomU0?l00003ool[00;o000000?o_Ol0od;o0?ooIP000_l09_l00ol0003oofL0o`3oR002o`000003
ok;o0?ooI@3o000000?o00000_oo?@001?l0oa?ooe/0ol_o0?l0of43o`3o4007o`3oXOoooooo0?l>
okgo0?l0o`ko0000o`2:o`03oolm0006o`3mooo1o`3oooooooooooo1o`3ooooo0_oo>P02ooooo`Co
ocl03oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07_ooooo001looooo`03o`00
0?oooooooooo00Gooooo3?l09ol4ooooo`;ooch01?ooool00ooWo`3oooooooooo`02ooooo`0:o`00
0?o<o`3oooooooooooo3o`3o0?gooogo0?o4o`3oooooolCo00;o0?go00Coa?l0o`000?l9o`3oaOl0
0_l9o`003_oooooooc/0o`3mool7o`3ooc/0o`Oo0?oo>`3o1Ol0olKo0?l5o`3ooc/0o`3oY?ooK@3o
00000_l;o`000oooK@3o_Ol0o`2:o`02o`00000@oom/0?ooH`3o0?nQoooooonko`3oof`0olco0?l0
GOoooooooom[0?l0R_ooEOl0o`1Moooooooo_?l0o`3Do`;o02Ko00So0?lUo`2coooOo`3o0;7ooonj
0?oMo`3o_Ol0olOo00;o_Ol000OoO_l0o`3Doonko`3o__l0o`000?l0ohCo08[o00?o0?n500Go093o
o`000?l0003o<`3oo`3oQ@02o`000005olco0?l0h?oo0>3ooonj0?l09_l00_o<o`02o`35o`04olco
0?l0oOooc?l0o`3mo`?o0?o600Go0?o]o`3oZol0oj_o0?n[olco0002o`3oS@Co000000?oofD0o`2:
ool07?l00_l000001_ooIP3o02Koo`0Vool0ROooofL0o`0000;oc?l000?o0?n8oomU0?ooB@000ol0
00002ooo?@3o00Wooolm0?l0ohSooe/0okgo0?lA0?oo0?goo`3o4ol0of7o0?lC00;o000000Wo0?nQ
o`3o4?oo?@3oocd0olSo0?l0003oocX0ol7o0?l000000_l0R_l01Oo1o`3oooooo`0cooo1o`3ojOl0
00?ooooo00Co0000onOo0?oWo`3o0?o;1_ooool00ol0f_ooooooooooo`0@ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`02ooooo`;o00000_ooool3
obP0o`Cooooo2ol09ol2onOo00Gooooo00?onol0ooooool000000_oo?P02oogo000:ol?o0?l0oOoo
ooooolCo0?ono`3o0?goolCo0?oooooo2Ol0o`0000;o2Ol000coaOl0ooooool7o`3o1ol0o`3mool7
o`3ooooooolk0?l0oOoo1Ol0oolk0?l5o`02oolk0005o`_o0?o6o`3o08Wooom]0?l;o`000_nmo`00
0ol0oOooofd0o`000002o`00000Coom/0?l0GOooof<0olOo0?nno`3oof`0o`2:ool0GOooof/0oeGo
0?nlo`3o02Koo`3Dool0oe?o0;?oo`29oooOo`3oon80oonj0002o`2ao`07okgo0?o7o`3ooooookgo
0?l0odSoPol0o`3oR002o`3Do`04ogko0?nAo`3o0000o`3oQ0Co0?n50_l000001Olc0?oo093oo`00
0?l0003obol000;o0?go00?o00Woolco0?o<o`000_l0oOl01_o<o`3o0?goo`3mool0oOooc?l0o`3m
o`;o0<Go00?o0?gooonj0?l0olH00_l0olH00ol0og?o__l0o`000003o`0000;o0?n=00KoofD0o`00
0?l0003o02KooomV0?l0ROl2olco0007o`000?ooI`3o0?n8olco0?ooooooofD0oom90002ok;o0009
ooln0?l0ohSoocd0o`3oHOoo?@3ooe/0o`3mool0oa?o0?mQ00;o00000_l0oa002?nmo`3o08[oo`2:
ool0003o0?l>ooob0?l0R_oo0?go1?oo?@001_o1o`3oocX0oooooooooooo0000onOo00?ooooo00?o
0?o;oolo0?oo?`003Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07_ooooo001l
ooooo`03o`000?oooooooooo00cooooo0olX0?l2ooooo`Ko02Oo0_oo?P04o`0Wo`?ooooo0_l00000
1_o<o`3ooooool?o0?l0oOooooooolCo00;o0?go00Ooa?l0o`000?o4o`3o2Ol0o`000?l7o`3oaOl0
00;o1ol00_l000001ooo>`3o1Ol0oolk0?l0oOoooc/0o`3oHOo6o`000_l;o`001ooo;`3oofd0ok_o
0?l;o`3o_Ol0oom]0?l0R_l00ol000002OooK03o<`3oo`3oXOl;o`3o0?gooom/0?nko`3o0?goo`2:
o`02o`00000=o`1MoooAo`3o0=Coo`0Vool0of7o0?mCokco0?l0/Ooo0;?ooooooooo^P3ogOl0oooo
o`03o`3oQ@0;ogko0?l0ohGo0?n5o`3oQOl0og?o0?n5o`3oQ?nko`3o0?n8okko0?l0T?l00_l00000
0oo<o`3o<`3oolgo0002olco0003ol_o0?oo7@3o00Wo00?o0<Go00Co027oolco0?o9o`3o0?go0_l0
olH01Oo<o`3o0?n[o`3oZol0oj_o0?o100?o0?n=00CookX0o`2:ool0003o00000_o<o`007_ooI@3o
c?l0olco0?o<o`3oofH0od;o0?nno`3o0?gooomW0?l0ROoo0000okgo0?l0ohSoofD0o`3DooooB@3o
och0o`000?oo?P3oocd0ob80oooo?@3ooooooomK0?lF0?oo_Ol0o`3moooohP3obol0o`3oH@;o0000
00Co0?lCokgo0?l0oa?o0?lC0ooo?@002?o1o`3o0?l@o`000?l0003o08[oo`0coooYo`3o`Ol01?oo
ool01Ol0003ooooooooooooooooo0?o;00Kooooo0_l0f_l@ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?o:03o
3?ooool;o`0Wo`0Bolco0?oo?P3ooooool?o0?l0olcoooooolCo0?l0oOoo0000olCo0?l9o`3oom/0
olCo0?l0003o1ol0olGo0?l7o`3o0?go0_l00002o`Go0003oolk0?l0oOoo0?mQ00;ooc/000_o2ol0
oolk0?l0oiOoa_l0o`000?l;o`3oofd0o`0cool0Dooo0?gooom]0003o`000009o`3oXOooK03oaol0
olco0?ooooooof`0ooooool0GOooEOl000;o000000Go0=Cookco0?nlo`3o0?mCo`2co`02o`2ao`05
oonj0?l0ocoookX0om_o0?o7o`001?l0ohD01?l0e?oo0?n5ogko0?nAo`02o`3oQ@05okko0?l0ohCo
__l0o`2Iool0ohD00_l000001_o=o`3o093oolco0?oooooo0?3ooonj00;oc?l000Oo0>3oolWo0?o9
o`3obOl0olco0?l0oOoo00Wo00?o0<Go00Oo0?goo`3o`Ol0olKo0?o6o`3oLol0oOoo08[o00;o0?n[
0_l00002o`3oS@03olco0?ooI@3oc?l000;o02Ko00SoofH0od;o0?nmo`3o08Woo`3DooooI`3o0?n8
o`3Do`;o027o00?oofD0oom90?l000000_oo?P002?l0of7oocd0oa40oooo?@3o_Ol0oomK0?o7o`3o
c?l00_l000001_l0oa?o_Ol0o`2:ool0oOoo0000olSo00;o0?l@00Ko`Ol0o`000?l0003o`Ol0oooo
oooo>P03oolm0003onOo0?l0003ooooo00?ooooo00?o0?o;o`3Jooooool03Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo07_ooooo001looooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool00olX0?l7ooooo`;ooch00_ooool<o`0Wo`08o`000?o4o`3o1ol0o`Oo0?o4o`3o
0000oooK0?o5o`02o`Go00;o000001cooc/0o`000?l0003o0000oolk0?l;o`3oa_l0o`3oXOl0003o
obl0oom]0?l;o`3o0?nGok_o0?nmo`3oofd0o`000?nmo`3oof<0olco0?ooK03o0?nQolOo0?l0oOoo
c?l0oom/0?l0R_oooooo0_l000000ol0GOoo02Koo`3Do`0:o`3oQ@;o0:oo00WoO_l0o`3Dool0ohSo
_Ol0okko0?l0og?o_Ol0o`3oQ?l0/Ol00_nko`002?l0T?oo0?mcolgo0?o=o`3obol0oc<0ooo<o`3o
__l00ol0aOl01?l09_oobOl0o`3Pool0h?l3o`3oaP03o`3okOl0oj_o0?n[00;oc?l00_l0ohd8olco
00;o00000_l09_l04OooIP3o02Koo`2:oom2o`3o_Ol0oomW0?l0e?oo0000o`0Qool0ohSoofD0okgo
0?ooB@3ooch0o`2:oooo?P3o000000;oocd000Go/_l0oomK0?lA0?oo0?mQokgo0002o`3oR005olOo
0?l0of7o0?mQokgo0?l0R_l00_ooool01Ooo>P3o0?lCo`3o4ooo?@3o0?go00Co000000Cooooool7o
0?oooooooooo0_oWo`001Ol0003ooooooooooooooooo0?o;00Sooooo00?o0=[oooooooooool03Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`?o:03o3Oooool00ooWo`3oooooooooo`02ooooo`04o`000?ok
o`3o02Ooo`0Wo`;ooch01ol09ol2o`Oo0003o`000?o=o`3oaOl000;o1Ol00_l000000ooooooo2ol0
oolk0002o`000003o`3moooo>`3ooooo00;ooc/000[oa_l0okgo0?l;o`3oofd0o`3oUol0<ooo08[o
ool_0?ooK@3oof@00_l0oiL02?ooH`3oof`0olco0?l0R_oo^ol0oom/0?l0GOoo02Ko0_l000000ol0
e?oo0>;oo`2ao`09o`3oQ@09o`3Doonmo`3o_Ol0o`3Doon3o`3o__l0ogko0?nAo`3o0?mc00?o^ol0
00?o0?n4o`3oQOo<o`000_o=o`001?l0VOoo093ooc<0ooo=o`02olco0007olWo0?l09_oobOl0o`2H
ool0ongoc?l0o`3ok@02o`35o`?oc?l00_l0olH2olco00?o0?n[00Goc?l0o`3oSOl0ohgo02Koo`3m
o`02o`0000;o02Ko023o07;ookgo0?ooIP3o_Ol0od;o0?l08OooofL0o`000?l0ohSo0?goo`09oooo
I@3o1`3ooom90?l0oOoooch0o`3moooo?P3oocd0oa40oooo?@3o0?n8oomK0?l0oOoo0?nQooooool0
of7o08[ookgo0?l0oj7o0?lCo`0000?o0?lC00Oo`Ol0o`000?l0003o0000oolj0?o1o`3ooooo00;o
iol00ooo?@04ooooo`03o`3obol0f_oooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`1kooooo`00O?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo
0olX0?l6ooooo`;ooch00_ooool02_oWo`3o0000ooooooo<o`3oooooo`3mooo3o`3oooooo`3oc?o4
o`0<o`0Wo`0Goolk0?l;o`3o0000o`000?oo>`3o0?gooolk0?o6o`3oooooool_0?nmo`3oofd0o`1[
ool0R_oo_Ol0oomT0?ooK@3o0?mQoomS0?o<o`3o0?nGoom/0?l0oj400_l0ohD2o`0000Ko0?n501;o
0?nGok_o0?nko`3o0?mQo`3oDooohP3ookX0o`2cool0e?ooaol0o`3Doomno`3oTOl0okco0?l0ohSo
cOl0o`0Vool0og<2o`000005o`3oQ?l0ohSo0?n5o`2@ooo=o`000_nko`02o`0000;o0<Go00Coc?l0
olWo0?o9o`3oc?l00ol0olH01Oo<o`3o0?n[o`3oZol0oj_oc?l000?o0?n=00[o0?nWo`3mool0oh[o
_Ol0o`3oLol0GOoo08[ookko0?l0og?o01co0_l000007?o;o`3oEOl0oomV0?l09_oo027ood;o0?oo
I`3o_Ol0o`3mool0003o08WooomU0?nmo`3oodT0o`09oooo?P3o_Ol0o`3moooo?P3o0000olWo0?oo
?@3o5P3ooomK0?l0oj7o0?gookgo0?o7o`02o`3oR005okgo0?l0of7o0?goo`3oXOoo>P000_l0oOl0
1Oo1o`3o0?goo`0cool0<ooo`Ol000;o000000Co`Ol0oooooooWo`3oiol00_ooool00ol0003ooooo
ooooo`02ooooo`03o`3obooooooooooo00Kooooo00?o0=[oooooooooool03?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`?o:03o2oooool2onOo00;ooooo00Co0000ooooooooooooc?l00_l0oOl01ooo?P3o
oooooooN0?o4o`3o0?gooooM0?o4o`002ol09ol01?oo>`3o0000o`000?nno`03o`000006oolk0?l0
ROooa_l0o`2:oonmo`3oofd00_nmo`002?oo;`3o0000oom]0?l0ohSoof<0o`3oXOooK03o08[o0_l0
ohD2o`0000?o0?n500?o0=Coo`3oQOl0ohD00ol0oiL00ol0/ooookX0o`3Do`02o`3Do`0:olOo0?n3
o`3o0=Coo`3Dool0ohSo02Koogko0?nAo`3o_Ol0o`3oL`;o00000_o<o`002ol0ohCocOl0o`3oLol0
GOoo0;Koo`2@ool0003o<`3ookko0?oo^P3o000000Coc?l00_l0aOl00ol0oOooc?l0olco0002o`3o
aP06o`3oR_oo^P3o0?n[o`3oZol07?oo0?mc0_l0ohd01?l0Oooo0?mcolco0?o;o`02o`00000Eo`0V
oomEo`3o08[ooomV0?nno`3o_Ol0od;o0?l0oOooofL0o`000?l0ohSo00WooomU0?l0e?oo08[ooom9
0?l0oOoooch0o`000?oo?P3o0?go00;oocd000Coaol0oomK0?nmo`3o0?n80_l0R_l01Onmo`3o0?go
o`3oXOl0003ob?l000;o0?go00?o`Ol0o`3mool0<ol00_oo>P000ol0003o`Ol0onOo0003ooooo`04
o`000?ooooooocd0oolm00;ooooo00?o0?o;ooooool0f_l03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo07_ooooo001looooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01_ooool3obP0o`Gooooo0_oo?P001ooooooo0000onOo0?o<o`3o0?goooooooo3o`000_l00000
3Oo4o`3o1Ol0olCo0?l5o`3oomd0olCo0?l;o`3o0000olGo0?l;o`3o0?gooolk0?ooool01?l09ol2
o`000007oolk0?o6o`3o_Ol0ool_0?l;o`3o__l0oom]0002o`000003oomT0?l0003oofd000Co0?n5
00?oof`0o`2:ool0oOl00_l00002o`0Vo`05o`2aool0GOoo0;7oo`3DoooRo`001Ol0oiL02?oo^P3o
0?nGo`000?l0003o0?loogko0?nmo`3ocOl00_l09_l02_nno`3o0?mco`000?l0003oc?l0o`3oQ?l0
T?oo0000o`3oLoo<o`03o`000004olco0?lc0?oo<`3oolco00;o0?o60_l0ond2o`3oZ`0?o`3o`Ol0
oOoo0?n=o`3oSOl0ojOoc?l0o`3oYoo<o`3o0?n:o`3moonmo`3obol0o`3oLonno`3obol000;o02Ko
00?obol0o`09ooo<o`000ol000005ol0e?oocOl0oomW0?nmo`3o08[oo`000?l0ohSoofD0o`09oooo
B@3o08[ookgo0?oo?P3o0?goooln0?oo?@3o0000oolm0?lA0?oooe/0ok;o0?oohP3o0?go00;o0000
017o08[ookgo0?l0ohSo0?mQoolj0?l0003o0?goooooool0003o0?goooob0?l0oOoo`Ol0oood0?oo
oooo`Ol0ooof0004ooooo`03o`000?oooooooooo00;ooooo00?o0?o;ooooooooool01oooool00ol0
f_ooooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo1?lX0?l9ooooo`;oiol000Oo0000oooo
ool0oOooc?l0oo_o0?l0oOoo`ol000;ooch000coa?l0o`Go0?l5o`3oa?l0ooooool;o`3oa?l0o`00
0?l;o`3oaOl0o`3moonmo`02o`3oY003oolk0?l09ooo02Oo00;o02Oo0_l000003Onno`3ooc/0o`29
ooo6o`3o__l0o`2:oonmo`3oofd0o`000?oo;`3o0000oom]0?ooH`000_l0ohD01?l0oj7oof`0olco
0?l0oOl2o`0000;o0;7o00Coon80o`3Doonko`3o0?mQ0ol0e?l00ooo^P3o0?nGo`3oU`02o`3oU`;o
000000Go_Ol0olgo0?l09_ooO_l0oi7o0002o`2ao`07o`3oLol0003o0000okgo0?l0ohGo0?n4okgo
0002olco00;o000000?o093oolco0?lc0?l00_o<o`001_l09_oo0?o1o`35ool0aOoo00Woo`3o`@?o
0?o600Ko0?n:olco0?l0oj_o0?n[okgo0?l0oOl2o`3oS@04o`2:oonno`3obol0o`1oo`;o02Ko00?o
00Woo`0Qool09_l00ol000003_l0R_oo__l0okgo0?ooI`3o00Woo`000?l0ROooofD0okgo0?l0R_oo
_Ol0oom90?l0oOooc?l00_oo?P001_l0003oocd0ok;o0?oo?@3ooe/0ooooo`;o000000Oo_Ol0oooo
ool0of7oooooo`000?o8o`3o000000;o0?go00Ko0000oolj0?o1o`3oooooo`2:ooo1o`04ooooo`03
o`000?oooooooooo00Cooooo00?o0?o;o`3Jooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo07_ooooo001looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2Oooool3obP0o`Cooooo0_oo?P002_l0oOooc?l0ooooool0oOoo`ol0oooP0?l0003oa?l0o`3mooo4
o`02o`_o0005olCo0?oooooo0000olGo0?l0oj400_l000001Ol0ojCooc/0o`_o0?oo>`3o0?mQ00;o
000000Cooc/0o`3oQOo6o`3o00000ol0ohD01_ooK@3o0000oomT0?l0003oof<0oom]00;o000000[o
03?oo`000?l0003o0?goolco0?l09_oo0;7oo`1Moooo603o05go1_l0e?l01?l0[ooo0?mQoonj0?nk
o`02o`000005ogko0?nAo`3o_Ol0o`0Vool0ohP00_o<o`001_l0og?oc?l0olco0?l0ohGoc?l0o`3o
Q0?o0<Go0_l000000oo<o`3o00Woo`3oaP02o`3oaP05ok_o0?l0oj_o0?n[o`3oZol0ol400ol0ohd2
o`3oY`09o`0Gooo<o`3obol0ol_o0?o<o`3ookX0okgo0?l07?oo0?mc00;o02Ko00Go027oo`3oLol0
8Ooo00Woo`3Do`03o`00000;olWo0?ooI`3o@_l0okko0?nmo`3o0000oomU0?l02Ooo08Wooom90?l0
R_l00_l000001_l0oOoooch0okgo0?oo?@3o0000oolm00;o000000[o/_l0o`3mool0003o0000okgo
0?l0oj7ooooooolj0?l0003ob?l00_l0<ol02Ol0003o0?goooooool0oj7o`Ol0oooooonmo`3o`Ol0
ooof0005ooooo`03o`000?oooooooooo00;ooooo00?o0?o;ooooooooool01oooool00ol0f_oooooo
ooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00gooooo0olX0?l7ooooo`0;o`000?l0oOoo0?goooooooo<
o`3oooooo`3mooo3o`3o1Ol0oooooooo?P000_l;o`002?o4o`3o2ol0o`3mooo4o`3o08[oo`000?o5
o`3o0?go0_l000002Oo>o`3ooc/0o`3moooo>`3ocol0oolk0?l0003ooc/0o`3oQ@02o`00000:olKo
0?l0ohGo0?n5okgo0?l0003oofd0o`2:ool0003o0?mQoom]00;o000000Ko0?nQo`000?l0003o05go
o`2aool0GOl5o`3Do`05o`3Rool0of7o0:ooo`2_oooo^P000_nko`002Oo;o`3oaol0o`000?l0003o
_Ol0o`0Vool0C?ooO_l0oi7o0002olco0004o`3oLoo<o`3oc?l0o`3oQ@;oc?l000?o0?n4o`3oLoo<
o`000_l000001Ol0T?oo^ol0o`3okOlc0?oo0?o100;o0<Go00Oo0?o1olco0?l0olKo0?o6o`3mooo;
o`3oc?l000;o0?n[00Ooc?l0ol_o0?l0ohgo0?n=o`3mool0R_oo0?mc00?o02Ko00Go0?mco`3Dool0
2Ooo02Koolco0003o`0000;obOl000WoofL0od;o0?l0oOoo0000ooooooooI@3o1`3oo`2:ool0e?l0
0_l000001?l0oOoooch0ooln0?l0of43o`000005o`3mooooF`3o0000o`000?ooool00_l0ohP03?l0
of7o0000olSo0?l0oOoo03?oo`3moooo>P3ooo@0ol7o0?nmo`3o08[ool7o00Gooooo00?o0000oooo
ooooool00oooool00ol0ol_oooooo`3Jo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0Noooool007cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`?o
:03o00?oooooo`000?l000000_oo?P001?o<o`3o0?goooooooo3o`02o`_o0009olCo0?ooooooa?l0
oooM0?ooooooa?l0o`2:ool0003o0?go00;o000000Oo2ol0oolk0?nno`3ooc/0o`3oHOl0003ooc/0
00;o0?go00_oa_l0o`000?l0oj7oooooo`15oonmo`3oofd0o`2:ool0003o0?mQooooo`02o`000005
o`2:ool0003o0000o`0cooo<o`000onno`001Ol0e?oo05goo`3DoooRo`3o08[o00;o0:oo00?oPol0
o`3o9Ol0of401?o<o`000omno`3oc?l0olco0003olco0009okko0?o<o`3o0?mco`3oQOl0ohSo0<Go
o`2@ool0ohCo0?mc00;oc?l00ol0olH01Ol0ongo0?n[o`3oZol0oj_o^ol000?o0?n=00?obol0o`09
ool0oOl00oo;o`001Oo<o`3ookX0o`1Qoooo^P3o_Ol000?o02Ko00[o0?mco`1booo9o`3obOl0o`3D
ool02OoobOl0o`0Vooo9o`3oEOl00_l000002Ol08Ooo@_l0okgo0?ooI@3o0?goooooool0R_ooodT0
olco0002o`000005ooln0?l0ohSooch0oolm0?lA0?l00ol000000onmo`3o0?gook;o0002okgo0005
o`3oXOoo>P3o0000o`0cooo8o`000_l0ohP2o`3mo`04o`3oXOoooooo`Ol0o`3mo`;o00001_ooool0
0ol0003oooooooooo`02ooooo`03o`3obooooooooooo00Sooooo00?o0=[oooooooooool02Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0@ooooo`?o:03o0oooool2o`000007oooooooWo`3o0000olco0?oooooo0?go
ol?o0002o`_o000:olCo0?oo?P3ooch0olCo0?l0oOoo08[oolCo0?oooooo0?nTo`3mo`Co000000Ko
oc/0o`000?oo>`3o0?n5o`000?l0oOl2oolk00;o000000?oooooolKo0?l0oOl00_nmo`001OooK@3o
of@0o`000?ooH`3oaol000;o000000Co03?oo`000?l0003o__l00_l0e?l01Ol0GOooPol0o`3Dool0
9_ooh_l000;o0:oo00Co0?mQol_o0?oo^P3obol01oo<o`004_mno`3oTOl0okko0?n3o`3oc?l0o`3o
Loo=o`3o0?n5odgo0?l0GOoo08[oolco0?l0ohCooad0olco0?l0ongo093ookgo00?o0<Go00Co<`3o
ol_o0?l0olKo0?o60_o;o`001Ol0oOoo0?n[o`3oZol0HOoookX000;o0?n=00?o_Ol0o`0Qool0oOl0
0_l09_l02ol0L_oobOl0o`3Dool0e?oo0?mco`09ool09_ooon80olco0?nmo`3oEOl000;o000000Wo
_Ol0o`0Voom2o`3o0000oomU0?l70?oo08[oo`_o0?ooB@000_l000001Ol0oOoooch0okgo0?oo?P3o
ocd000;o000000Co/_l0oomK0?nmo`3o_Ol00oooool01?l0003ob?l0o`0cool0<ol2oolj0004o`3o
XOoom03o`Ol0ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`3obooooooo0=[o00[o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1kooooo`00O?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o:03oo`000?l000000_ooool3ooln000Jol?o
0?l0olco0?goolCo0?ooooooa?l0oooM0?l0oOooa?l0oooK0?l0003o0?gooooI0?oo>`3o0?n5oolk
0?l0oOoooc/0o`000?l0of7ooc/0o`3mooo7o`3o08WoolKo0?nmo`02ooooo`06okgo0?ooI03oofd0
o`000?l0of7oEOl00_l000001_o<o`3o0?goo`0Vool0oj7o03?oolco00;oPol02_o<o`004ooo^P3o
cOl0olgo0?mno`3oTOl0o`2coonmo`3o0?n8ok_o0?o<o`3o__l0olgo0?l0aOoo0?n5o`35ooo<o`3o
093oolco0?l0oh@00_l0olH2olco00;o0?n[0_o;o`02o`3oS@03olco0?o;o`3o^ol000;o^ol000Go
0?goo`0Lool07?ooc?l0o`0Qo`02o`0000;o02Ko00CobOl0o`3moonno`3o0?mc0ol0e?l01_l0og?o
00Woo`0Vool;o`3oIol0oeGo00;o00000_l02Ol01_m2o`3oofD0olco0?l0oOooodT0o`29o`;o08[o
00Goaol0ooln0?l0e?oooch0o`2:o`02oolm000=olOo0?l0003o0000o`000?nmo`3o/_l0oooooooo
>P3oooooo`000?o8o`3oood0o`3oH@02o`3mo`;o0?n800?o`Ol0oood0?l0oOl00_l000000ol0R_oo
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0?o;ooooooooool02Oooool00ol0f_oo
ooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01?ooooo0olX0?l2o`0000;ooooo01Go0000oooM0?o<
o`3o0?gooooP0?o3o`3oooooo`3mooo4o`3oooooooln0?o4o`3oooooo`3oY?o4o`3o0?nQo`3mooo5
o`3o_Ol0o`3oQOoo>`000_l0ohD02ooo>`3o0000oolk0?oo>`3oaol0oolk0?l0ROoo0?goo`29ooo6
o`3o0?go00;o_Ol000Goobl0oom]0?l0003oof<0oeGo0002o`000004o`3Dool0oj7o03?oo`0co`;o
__l000?o05goolco0?l0e?l02?o<o`003ol0e?oocOl0o`0Vool09_oo0;7ookgo0?l0ohSoTOl0olco
0?nno`3oPol0olgo0?l0og?o0?n5olco0002okco0008olco0?nlo`3o00Woo`3oQ?o<o`3obol0o`2@
ool0aOl2ol_o00?o0?o600Koc?l0o`3oR_l0oj_o0?n[o`3mool08Ol3o`3oS@0>o`1ooonmo`3o0000
o`000?l09_oo08[ookko0?l0og?o0=Coooom0?mWo`3o00Woo`0Vool;o`02oonj0008o`0Qool02Ooo
0000o`000?nmo`3o__l0od;o0?ooI@02o`2:o`0;ol_o0?l0ROooodT0olOo0?l0e?oo0?goooln0?lA
0?oooch0o`3oHOoo?@000ol000000onmo`3o0?nQokgo0002ooooo`09o`000?o8o`3o0?mQoolj0?o1
o`3oooooo`3oXOo1o`3ooooo00?o00001Oooool00ol0003oooooooooo`04ooooo`04o`3obooooooo
ooooo`3Jo`Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1kooooo`00O?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00Oo0000o`3moolX0?oo:03oolco
0?l0oOoooooo00;ooch000_o0?goolCo0?oogP3oa?l0oooM0?l0R_ooa?l0o`3oY?l0oOoo0000o`3o
Q@02oolk000Cokgo0?oo>`3o0000oolk0?nno`3ooc/0o`3oXOl0oOoo08Woool_0?o6o`3o0?gookgo
0?ooI03o_Ol0oomS0?ooK@3o0?mQo`2:o`02o`0000Soc?l000?o06_oo`1Mool0e?l00oo;o`000ooo
oooo__l0o`3Do`02olgo0006okko0?l09_ooO_l0olWo0?l0/ooo_Ol00_o<o`03o`35o`08o`3oQOn3
o`3o0?n8olOo0?l0T?oo0?o6o`3oQ?l02Ol3o`3oZ`0<ol_o0?l0ohgo0?n=o`3oSOl0ojOookX0oc<0
ool0oh[o00Woo`3oR_l08Ooo0?go0_nko`003Oo<o`3ookX0o`000?l0003o_Ol0o`1Mool0L_ooc?l0
okko0?l0og?o02Kookgo0?mVo`000_l02Ol01?l09_oo2ol0o`3mool08Ol2o`09o`0Colco0?l0003o
0000o`000?o7o`3o08[ooom90?l0of7o08Woo`09ool0R_oooch0o`3oHOl0e?oooch0oolm0?l0of7o
ocd0oomK0002o`0000;ooooo00koocX0o`0coonmo`3o_Ol0olSo0?ooo@3o0?gool7o0?l0oOoooooo
o`000?o1o`3o0?goooooo`;o000000?o08[oo`_o0?l;o`000oooool00ol0003oooooooooo`03oooo
o`03o`3obooooooooooo00Wooooo00?o0=[oooooooooool01oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Foooo
o`03obP0ool0003o0?go00;ooooo00[oomd0olco0?l0oOoo0?o<ol?o0?l0oOooooooolCo0?l0003o
08[o0_oo?P004Ol0ohGoa?l0o`3mool0ohGoaOl0okgo0?l;o`3ooc/0o`000?l0of7o0000oolk0?l0
oj7ooc/0o`3moooo>`3o08Wo00?o_Ol000Soa_l0okgo0?l0e?ooof@0okgo0?ooK@3o0?mQokgo00;o
00000_o<o`000ol0oj7oc?l0olco0002olco0004o`1[ool0e?ooh_l0o`29o`Co__l000GocOl0o`3D
oonmo`3o02KoolOo0002olWo0004okgo0?mno`3oTOl0ok_o00;ocOl000CoPol0o`3oQOo7o`3oaol0
0_o<o`001?o;o`3o00Woo`3oLol0oh@2o`35o`04o`2@ool0ojOo0?o6o`3oaP;o0?n:00?oc?l0o`3o
Zol0oj/00_nko`001ol0oOoo0?n=olco0?oo^P3o07ooo`1bool09_l00_l000002Oo<o`3o__l0o`3m
ool0og?o_Ol0oloo0?l0003o00Woo`0Vo`02o`0Qo`;o00Wo00Co_Ol0oeGo0?o<o`3oaol00ol00000
2Ol0R_oo00Woo`2:ool0R_ooodT0o`3oHOl0e?oo0?goolOo0002ooln0003o`3oHOoo?@3o0?mQ00;o
00001?nmo`002_l0003ooooooolj0?oo>P3o0?mQol7o0?l0ohSooooool7o0?ooool2o`000003o`2:
ool;o`3o2ol000?ooooo00?o0000ooooooooool01Oooool01?l0ol_oooooooooool0f_l8ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0Noooool007cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0@ooooo`09o`000?oooooo0?goooooooo<o`3o0?goobP0ooo3o`3o
on0000;ooch000Woomh0olCo0?l0ojCo0?nTolCo0?oof`3o0?goo`000?oo>`000_l000002onmo`3o
0000o`3oHOoo>`3ocOl0oolk0?l0oj7o0?goo`29oooo;`3oa_l000;oc?l000?oof@0olco0?ooH`00
0_l000000ol0of7oc?l0ok_o0002o`3mo`;o_Ol000?o0?nQolco0?o;o`000_l0<ol04_l0e?oo06_o
o`1[ool0Jooogol0o`000?l0e?oocOl0oonj0?o9o`3o02Koogko0?o9o`3o__l0olco0?nmo`3ocOl0
o`35o`;o__l000?o0?n5o`3oLol0olH00_l0olH01Ol0T?oo0?n[o`3oZol0ohCo0?o100?o0?n=00Oo
08[oo`3oYol0ojOo_?l0olco0?l09_oo<`3o00;o027o00GobOl0o`3mooo9o`3o067oolco0002ok_o
000:olgo0?nmo`3o0=Coo`3Doonno`3o08[oo`3mool0og?o_Ol0o`3Po`;o00Wo00Oo027oo`_o0?l0
2Ooo00WoolOo0?mEo`3oaol000?o000001[o08[oooooooooB@3o0?goo`0Vool0ROoo00Woo`3moooo
?P3o08[oooln0?oo?@3oaol0oolm0?oooooooe/0o`000?ooooooocX0o`0coooooooo0000okgo0?o8
o`3o0?gookgo00;o000000?o0?nQo`000?o1o`000_ooool00oo1o`3oooooo`2:o`02ooooo`04o`_o
0?ooooooooooo`0000Gooooo00?o0?o;ooooooooool02Oooool00ol0003o0=[oooooo`07ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooool0oOl00_lX0?l01?o<o`3oooooo`3oc?o3o`02o`3m
o`0;olCo0?l0ojCo0?nTolCo0?l0ohGooch0olCo0?l0oOoo00WoolGo0?nmo`000_l000001Onmo`3o
0000o`3oHOoo>`3o0?nQ00;ooc/000?o2ol0o`29ool0e?l00_o<o`001Oo6o`3oc?l0ool_0?ooI03o
of<000;o000000Co0?mQolco0?l0oOoo0?go0_o;o`001Ol0oj7o0:oool_o0?l0<ooo0=Co00Co06_o
00cogOl0o`3Rool0e?oo0=Cookgo0?l09_oo__l0olOo0?nno`3oc?l0ogko0?nAo`02olgo0004okko
0?o;o`3o0?n5o`3oL`;oc?l000[obol0o`3okOl02Ooo0?o1o`3oLol0aOoo0?n4o`3oYol0T?oo0?o6
0ol08Ol2o`3oZ`08olWo0?lc0?oo0?n=o`3oSOl0oOoo^ol0olco0?oo^P02o`0Vo`04olgo0?l0e?oo
0=Coolco00;o__l000Ko0?mcokgo0?nno`3ocol0o`09ool08Ol2o`09o`06olco0?o7o`3ooooooeGo
0?oohP3oc?l00ol000004Ol0ohSo0?goo`09ool;o`3oodT0o`29ooo9o`3o0?goo`2:oooo?P3oaol0
ooln0?oo?@3o_Ol0oolm0?l0003ooe/000;o03?o0_nmo`000ooo>P3o0?gookgo0002o`00000:o`3o
R?oooooo`Ol0o`3moonmo`3o`Ol0ooooool0R_ooooooo`_o00;ooooo00?o0000ooooooooool01Ooo
ool01Ol0ol_oooooooooool0003o0=[o00Oooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`1kooooo`00O?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00oooooo0_l0
0002ooooo`08o`3mooo<o`3o0?goooooooo3o`3oon00obP0ooo4o`02ooln0007oooM0?ooooooa?l0
o`3mooooooooaOl0oolk0003o`00000?oolk0?o<o`3ooc/0olco0?oo>`3oc?l0o`29ooo<o`3oobl0
okko0?o6o`3oof@0oloo0?mEo`3oof<000;o000000[o0?mQo`000?l0003o^ol0o`3mooo<o`3o_Ol0
o`3oXOnmo`3oc?l00_nmo`001?l0e?oo03?oo`1MoooOo`02o`3Do`06olgo0?o9o`3ookX0o`0Voonm
o`3oO_l00_o<o`02olgo000Ao`3oR?o;o`3obol0o`3oQOo;o`3o0?o6olco0?n3o`3o0?o]o`2@ool0
2Ooo0?o1o`3oLol0ohCo^ol0olco0?o9o`001?l08Ol00oo<o`3o02Koo`09o`02oc<0o`08o`1oool0
oOoo02Koo`0Vooo<o`3ocOl0oonj0?nmo`02ok_o0006okgo0?nno`3o08[oo`3mool0og?oc?l00_o7
o`03o`09o`07o`3moooooooooooooeGo0?nmo`3obol0o`3oR003o`00000:olco0?l0oOoo0?n8o`_o
0?l0ROoo0?goooln0?lA0?oooch0o`2:o`;oocd000Co_Ol0oomK0?l0<oooocX00_ooool01_l0003o
0?nQok;o0?l0oOoooooookgo00?o000000Go0?n8ol7o0?oooooooooool7o0002ooooo`04o`2:oooo
ooooooooo`_o00;ooooo00?o0000ooooooooool00oooool00ol0ol_oooooooooo`08ooooo`;o0000
2?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Fooooo`0@o`000?ooooooooooooooool0oOooooooolco0?lX0?oo
0?o<ol?o0?l0oOoo0?nTolCo0?l0R_ooooooolCo00;ooooo0_oo?P000onmo`3oaOl0o`000003o`00
0004oolk0?o<o`3ooc/0olco00;ooc/000[o08Woolco0?o<o`3ocol0o`3mooo6o`3o02KooomT0?mE
o`3oof<00_l000000ol0of7o0000o`000003okgo0005o`3oXOnmo`3o_Ol0o`1Mool0e?l00_l0<ol0
1Ol?o`3obOl0olgo0?l0e?oookX000;o02Ko00So0?mQolOo0?l0003oc?l0ol_o0?nAo`3ocOl0ol_o
00?o__l000Ko0?n5o`3oLonno`3o__l0o`3o`Ol02Ol2ok_o000@o`3oLoo<o`3o027oo`3oQ?l0T?oo
027oolWo0?l0L?oo0?n[olco0?l09_oo_?l0o`3oSOlc0?oo067oo`3mo`?o02Ko00?o^ol0okgo0?nk
o`000_nmo`001onno`3oaol0olco0?o7o`3o0?mco`0Qool09_l00_l02Ol01?l0og?ooaP0ooooool0
GOl2ooooo`04oeGo0?o;o`3o_Ol0o`2:o`?o0000017o0?goo`09ooooB@3oaol0o`29ool0oOoo0=Co
ooln0?l0ROoooch0oolm0?ooooooocd0o`3mool0003oooooo`3oX@02oolj0003o`3mooo8o`3o_Ol0
00?o000000Oooo@0ol7o0?oooooo_Ol0ol7o0?oooooo08[o00;ooooo00Co2ol0oooooooooooo0000
1oooool01?l0ol_oooooo`000?l00007ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0Noooool007cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00;ooooo00Go0?goolco0?oooooo0000ol?o0002o`3oY006olCo0?l0FOoooch0ooln
0?oooooo0?go0_l000002Ooo>`3oc?l0o`000?o<o`3ooc/0o`3oHOoo>`3o_Ol0oolk0002o`000005
o`3moooo;`3o0000olKo0?ooI0000_l000000ol0R_oo0000o`000003o`00000>ol_o0?nko`3o^ol0
olco0?l0oj7oooooolco0?ooooooon80o`3Dool0GOoo03?oo`3Dooo=o`02okgo00;o02Ko00[obol0
ogko0?o<o`3obol0olgo0?o;o`3o_Ol0o`0Qool0/ooo0?n50_o<o`001Ol0og?o0?n8oh?o0?l0o`3o
093o00;obOl000?o0?mcolco0?l0oh@00_l08Ol01_nno`3o0?n:o`0Looo<o`3ookX0o`0Vo`;o07oo
00Ko02Kooc<0ool0oOoocOl0oonj0?o<o`02o`3Do`08okgo0?o7o`3oaol0okko0?nko`3o08[oo`0Q
ool0og<2olco00;o00Wo00?o0?mco`3Pool0oOl00_nno`001?o;o`3oEOl0ooooool0R_l3o`000003
olWo0?o<o`3o0?go00;o2ol001Co08Woo`09oooo?P3oaol0ooln0?oo?@3o_Ol0oolm0?l0<oooocX0
o`3mool0003oooooo`000?l0oj7o0?gookgo0?l0oOoo`Ol0o`3mo`;o000000Go`Ol0o`3oHOoooooo
`Ol0ooof0002ooooo`07o`2:ooooooooooooooooool;o`3oooooo`000005ooooo`03o`3obooooooo
oooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`;o0?go01Goc?l0
o`000?l0oOoo`ol0o`000?l0FOooa?l0o`2:ooooooooa?l0ooooool0oOooa?l0ooln0?l0003oaOl0
oolk0?l0003oc?l0oolk0?ooool00_oo>`002Ol;o`3o0000o`000?l0/Ooo_?l0o`3mool09_oo_Ol0
olKo0002o`000003okgo0?l0003o000000?o000000Sooooookgo0?oo5`3oon80o`3oXOl0003o05go
o`3Do`;o_Ol00_l0<ol00ol0e?oo_Ol0o`0Vo`03ol_o0006olOo0?o<o`3ocOl0ogko0?nAo`3o027o
0_o=o`001?o<o`3o0?n5o`3oR?l0og<2olWo000Mo`09oonno`3o__l0okko0?l0og?oc?l0okko0?nk
o`3o093oo`2fool07?oo00Woolco0?l0Oooo02Koo`1oooo=o`3o07;ooc<0ool0oOoookX0olco0?l0
e?ooaol0okgo0?o7o`3o^ol0olco0?nno`000_l08Ol00oo<o`3o0?mco`09o`02o`09o`03o`_o0?l0
oOoo0?mc00;o__l00_o;o`001?mEo`3oooooo`2:ool0ohP3o`0000;o0?go00KoodT0o`2:ooo7o`3o
08Woo`2:ool0e?l2ooln000=o`3oHOoo?@3o03?ooolm0?ooF`3o0000oolj0?l0003o0?goolSo0?nm
o`3o0?gool7o0002o`000004ol7o0?oooooooooool7o00;ooooo00Oo08[oooooooooooooooooo`_o
0?oooooo000000Oooooo00?o0?o;ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo07_ooooo001[ooooo`?o00003_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00?ooooo00Coe?l0omGo0?oEo`3oe_l0:OoGo`03onko00?okol000Coo`00onoo0?o_o`3o
o`000_o_o`02ool00004onoo0?oo003oo`00onoo00;oo`0000?okol0ool00?oo00001?oo0003onoo
00ooo`0000?o093oool00?oo00000ooo00000ol0ohCoo`00ool0000Sool000Cok_l0:ooAo`03om3o
00?ocol000?oc_l0ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo0ol0001:ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00kooooo00?oe?l0omGo0?oEo`000ooFo`0YomOo0004o`000?oo003ok_l0o`0000;oo`0000Co0000
ool00?oo003o00000_oo00001?l0003oo`00ool00?l00002ool00004o`000?oo003oo`00o`0000;o
o`0000Oo0000ool00?oo003o0000ogko0?nAo`3o000000;oo`0000Cokol0ool00?oo003okol00_oo
00000oo_o`3oo`00ool00002onoo0005ool00?o_o`3okol0ool00?l0T?l01Oo_o`0Yonko02WodOl0
0_o@o`02oloo0003olko0?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`09ooooo`Co0000K_ooool006Oooooo1ol0000WomOo00Cooooo5_oo0002ooln00Goo`001?o^
o`0Bonoo0003ool00?o_o`3okol000;oo`0000Cokol0ool00?oo003oo`000oo_o`0Cool00003o`2@
oooo003oo`0002Coo`000_l000001ooo003o0000o`000?o^o`3o0000onko0?l000000oo^o`001?oo
003o0000o`000?oo0002o`000004ool00?l0003o0000oolj00Go000000?oo`00o`000?l000000_oo
00000ol0003oP_l0oh;o0003oh;o00?oOol01?mno`03ogco00;o000000?oooooom7o0?oAo`009?oA
o`05o`0004Gooooo1Ol0000WomOo0004oooooon;o`3oRol0oh_o00?oS?l00on=o`03ohoo00?oT?l0
1OnAo`001Ol0003o0?nQo`000?l0003ooch000Go000000Cooc/0o`000?l0003o08Wo0_l000001?mE
o`3o0000o`000?l00002onko000Sokgo0?l0003o0000o`3oHOoo003o0000onoo0?oo003o0000onoo
0?oo003o0000o`3Doooo003o0000o`3Doooo003o0000okgo0?oo003o0000o`0coooo003o0000onoo
0?oo003oO_l0oi7o0?o_o`3o0000olco0?oo003okol0o`0Qoooo00000_o_o`001Ooo003okol0onoo
0?oo003o000000;okol000Go0000onoo0?l0T?ookol0o`09o`07onoo02kok_l000Wo0000ool00?l0
003o0?goool00?l0003oooooool00?l000001On2o`04ogoo00;oO_l00omlo`000ol0003ooooooooo
o`05ooooobGodOl02?l0001Zooooo`00Ioooool5o`00017ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`08ooooo`;oRol01?n<o`03ohgo0003ohoo0?n@o`3oT?l000;oT?l01OnAo`04
ooooo`;o0?go0_l0FOl2ooln0006oolk0?l0003o0000oolk0?l=0?oooc/00_o2o`000ol0ROooEOl0
ool_0004o`000009olOo0?l0Dooo0000o`2:ool0of7o_Ol0o`2:ooo;o`3o0?go00?obol000Wo^ol0
o`3oXOo=o`3o0=CoolOo0?l0GOooaol0o`0Voonlo`000_o<o`001?oo^P3ocOl0ogko0?o7o`02olWo
0004o`3okOo<o`3o_Ol0o`3oQ@;o027o00Ko__l0o`2cool0og?o0?n8o`3oYol0T?l3okgo0007olco
0?nmo`3oc?l0olOo0?l0ohCoaol0o`0Vo`02o`0Io`0<oonj0?l09_oo0=Coo`3Dooo<o`3o00_oo`3m
oonko`3o<`3oolco0?l08Ooo_Ol01?nno`002?l0R_oo00Woo`09ool0Dooo0?mco`3mool02Ooo2ol0
1?nko`005_oo5`3o1`3oo`2:ool0ohSo_Ol0o`000?ooB@3o007oo`2:oonno`3o0?mQok?o0?l0oOoo
4@3oo`3mool0<ooooch0olOo0?oo?P3oocX0o`3oHOoo?@02o`00000=o`2:ool0oOoo0000ooooool0
oj7oooooo`3oXOl0oOoo_Ol0ok;o0?nmo`3o0?goooooo`06oh;o00;oOol01?mno`04ogco00?ooooo
00?o0?o;ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
1?l00015ooooo`Co00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo
0_n;o`04ohco00?oSOl00_n?o`04oi3o00GoTOl00_ooool02?l0R_oo0?goo`1Iool0003oc?l0o`3o
XOl0003ooc/00_oo?P000ol0003ooc/0oolk0004ol;o0003olgo0?l0oOoo_Ol000Co0000013o08[o
okgo0?l0003o08[oo`3oHOl0oOoo_Ol0ol_o0?o<o`3o0;7ook_o0?nmo`3o0?nQo`3Dooo7o`3o0=Co
0_l09_l01?nmo`3oc?l0olco0?oo^P02olgo0004o`0cooo7o`3oO_l0oi7o00;oc?l000So027oo`3o
QOl09_oo__l0o`3oR?l02Ooo0?mcoh?o00Go_Ol000Ooc?l0okgo0?l0Oooo07ooolgo0?l0T?oo0?n4
00;o02Ko00Co0=Coo`0Vool0e?oo^ol00_oo^P000ol0oOooc?l0okko0002o`0Io`;o__l00_l06ol2
o`09o`06okco0?oAo`3o02Koo`3oLoo;o`3o00Wo0_nko`02oolG000Go`3oLonmo`3o1`3oo`2:ool0
ohSoEOl0okgo0?l0003o08[ookko0?o7o`3oodT0o`3moonco`3o4@3oo`3moonmo`3o08Woooln0?l0
e?oooch0oolm0?oo>P000ol000000ol0oOoo0000o`3oX@02ooooo`05o`3oXOnmo`3o0?n8okgo0?l0
oOl00_nmo`06oh;o00?oOol00_mno`04ogco00Cooooo00?o0?o;ooooooooool01_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo1Ol0001Zooooo`00OOooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00?ooooo0_n;o`03ohco00CoSOl000?oSol0oi3o0?n@o`00
0_n@o`05oi7o0005ooooool0oOoo0?goooooool0og<00oooool2o`3mo`05ooooool0R_ooc?l0oolk
0?l0FOl00_oo?P001_l0003ooc/0ol_o0?oo>`3o0?nQooooo`;o`_l000?oobl0ol;o0?l=0?l00_nm
o`002Oo7o`3obol0o`000?l0oOoobol0o`3oHOnmo`3o08[oo`3mo`02o`d0o`;ocOl000Co0?nQo`3D
ool0e?oobOl00_l09_l2olco0005olWo0?o=o`3ocOl0ogko0?l08Ol00_l0<ol03_l08Oooc?l0o`3o
R?l0ohGo0?o1okco0?l09_oo__l0o`09ool0og?o0?n8olOo0?l0T?ooPol00_o7o`02olco00;o_Ol0
00Co01Woo`3oQ?l06Ooo00Wo0_l0e?l01?l09_oo01_oo`0Kool0l?l2o`02o`04oonj0?l08Ooo<`3o
okgo00;o^ol000Gooad0okko0?l02Ooo00WooolM0002okko000Eo`0Vool0og?o00Woo`_o0?nno`3o
09Woolco0?l0og?o^ol0o`2:ool0ohSo007ooeGo0?l0003oodT0o`2:ool0of7o__l0olOo0?nco`3o
gOl000;o0?go01?o_Ol0ooln0?l0ROooocX0o`3moooo?@3o0000o`3mooooF`3o0?goooooool0003o
08[oo`3oXOoooooo0?nQo`3mool0oj7o_Ol000;o/_l000Oooooookgo0?nmo`3oooooo`3oHOl0R_oo
oooo00KoP_l000?oOol0ogko0?mno`000omno`04ogco00oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool0
0on;o`3oS?l0ohco0002ohco00CoSOl00_n?o`04oi3o00GoTOl000Co0?gooooooooooooo0?mc0ooo
ool00ol0oOoo08[oo`09o`02o`1Io`0<o`3oXOoo>`3o_Ol0o`3oXOoo>`3ooch0o`000?oo>`3o02Ko
oolk0?oooooo08Wo1?o2o`005ol=0?ooobl0o`2:ool=0?oo_Ol0o`000?l0oOoo08[oo`3oHOl=0?oo
_Ol0o`d0ooo<o`3o3@3ook_o0?l=0?oo0?nQo`3Dool09_oo3@3ookgo0?o<o`3ooad000;ocOl00_l0
8Ol03oo7o`3o03?ooi7o0?o<o`3o0?n8okgo0?l0ohGo0?o1o`0Voonno`3o00Woo`1[ool0og?o06_o
oh?o0002o`0Lo`04olgo0?o<o`3oc?l0o`1oo`;o_Ol000_o00Woo`2@ool09_oo0?n4o`3Dool0HOoo
02Koolco0?oo^P3oc?l0oonj0003o`0Io`07okgo0?l06ooo01_oo`0Koonno`3o00Woo`2:o`03o`02
o`06o`0Voonno`3o0?mco`09ooo<o`3o007o0_nko`000ol0og?obOl0o`2:o`02o`3oR00?oeGo0?nm
o`3o0000o`3oHOo7o`3o__l0oom90?oohP3o/ol0oa40ool0oOoo_Ol0o`3mool0ROoooch000;oocX0
00_o0000o`3moooo?@3ooe/0ooooool0003o0?nQooooool0oOoo0?nQo`3oR002okgo0006o`3moonm
o`3o_Ol0ooooool0of7o08[o0_l000000oooooooP_l0oh;o0003oh;o00CoOol00_mno`03ogco00So
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1kooooo`00OOooool00ol0003ooooo
ooooo`0:ooooo`;o0?nd00?oRol0ohco0?n<o`000_n<o`04ohgo0004ohoo0?n@o`3oT?l0oi3o00Ko
TOl00oooool01?l0oOooooooooooool0omP2o`3mo`05ooooool0og?oooooooooool0oOl00_ooool0
1_l0R_oo0000oolk0?oo>`3o05Wooolk00;ooch000So2ol0oolk0?l;o`3oEOl0o`29ooo;o`3oobl0
okgo00?o`_l0017o_Ol0o`3oHOl0003o0?goon?o0?l0of7o_Ol0o`2:ool0oOoo_Ol0olgo0?o9o`3o
c?l0o`3Dool0oj7o0=Coo`0Vo`02olco0008o`d0ooo=o`3ocOl0o`0Qoomno`3oTOl0o`d0ooo7o`02
o`00000Ao`0cool0ohGo_Ol0o`3oYoo7o`3o02Kookko0?o7o`3o0?mco`3oR?l0Jooo093ooh?o0?l0
7?ooc?l0o`3oLoo<o`000_l06Ol01?l0od3o0=Coo`3oQ?l0e?l3o`0Ko`?o00;o00Go_Ol0o`3moooo
^P3o3@3oolco0002oc<0o`0<oolM0?l02Ooo00Wook_o0?l0R_oooaL0ol_o0?l09_oo007oo`3oLol0
2Ooo0?go0_l00Ol01Onno`3o0?mco`2:oonno`3o0?n800;o^ol001go0000oooooonmo`3oc?l0olOo
0?nno`3o/ol0o`0coooKo`3o0?goo`3oXOooooooocX0o`29oooo?P3o0000o`3oHOoo?@3ooe/0oooo
ool0of7oooooo`000?l0R_oo0?nQooooool0oOoo0?nQo`3oR002okgo0003ok;o0?nmo`3o_Ol000;o
08[o00?o0?mQooooooooool00_ooool00ol;o`3o0000ooooo`05oh;o0003ogoo0?mno`3oO_l000?o
O_l01?mlo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F_ooool00ol0003o
ooooooooo`03ooooo`04o`000?l0okCo0?ndo`3o]0Kooooo0_n;o`04ohco00CoSOl000?oSol0oi3o
0?n@o`000_n@o`06oi7o0003o`3moooooooo0?go00;ooooo0_l0oOl2ooooo`0:o`3oLooooooo0?go
o`3moooooooo08[ool_o0?o<o`3o0000oolk00;o_Ol00_oo>`02ooln000:oolk0?o;o`3oEOl0o`29
ool0R_ooaol0o`3mool0Dooo`_l0ool_00;o`_l000Wo_Ol0o`000?l0oOoo08[oo`3oHOl02Ooo_Ol0
olgo0?o<o`000_o9o`001Onko`3o0?nQo`0VoooOo`3oc?l000;o3@3o00?ocOl0o`d0ool=0?l00_l=
0?l00oo7o`3oO_l0oi7o0002o`00000:okgo0?l0ohGo_?l0okko0?l02Ooo0?n8okco0?l0og?ocOl0
oh?o00?o06_o00?oc?l0o`3oLol0L_l00ol09_l01?l0T?ooc?l0o`3oQ?l0HOl2okgo0005o`0Vool0
6Ooo01Woo`0Iool0oOl00ol06ol00ol09_oo<`3oo`09o`03o`02o`03om3o0?o;o`3o02Ko00;o007o
00?o0?mco`09ool0oOl00_o<o`02okko0003o`2:oonko`3o0?n800;o08[o00_oEOl0o`000?o7o`3o
_Ol0o`_o0?ooB@3o08Woo`0coonco`3o0?goo`09o`02olco0007oolj0?oo?P3o0000oolm0?l0oOoo
ocd0oomK0002o`2:o`05o`000?oooooo0?nQo`3oXOl0ohP00_nmo`000ooooooo0?gookgo0002o`2:
o`03o`3oHOoooooooooo00;ooooo00Co2ol0o`000?oooooooooo1_n2o`04ogoo0003ogko0?mlo`3o
O?l000;oO?l00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07_ooooo001moooo
o`03o`000?oooooooooo00Oooooo00?oRol0ohco0?n<o`000_n<o`04ohgo00CoT?l01OnAo`05oooo
o`03o`000?oooooooooo00;o0?go00Coooooo`3of?oooooooooo0_l0oOl00ooooooo0000o`000002
ol_o0009o`09ooo;o`3ooc/0olco0?oo>`3ooooooolk0?l0of7ooc/000;ooch000WoEOl0ol_o0?l0
ROoo08[oool_0?nmo`3o0?goolOo0?l;o`000_o2o`002Ol0003o`_l0olWo0?l0of7obOl0okgo0?l0
oOoocOl0okko0002o`3Do`05olco0?l0e?oo02Koolco0?l0GOl00_o=o`001Ol08Ooooooooonj0?mn
o`3ocOl000;oc?l00_l000001?l0ohGo03?ookgo0?o7o`02o`09o`08okko0?l0oh[o0?mcolgo0?l0
/ooo093ookco0?n3o`03o`0Io`03okco0?l0e?oo0=Co00;o01_o01?o0?n4o`02ool00_oo00;oolco
0?oo^P3o027oo`2:ool0oOoo_Ol0olco0?l0GOoo_Ol0o`09oolc0?oo__l0olco0?l00Ooo08[o00;o
007o00co02Koo`d0ool=0?oo0?mco`_o0?l0oOoobOl0o`d0ool0R_oo0?mco`3oR?l=0?l2o`2:o`04
o`000?nko`3o_Ol0olOo00;o03?o00Co__l0ok?o0?nmo`3o0?go0_l000005?oo?P3oaol0ooln0?oo
?@3o0?mQoolm0?nno`3ooe/0o`3oHOoooooo0000ooooool0oj7o0?goo`2:oooooooo0?n8oooooonm
o`3o0?go0_l0R_l3ooooo`06o`3oHOooooooooooo`_o0?oooooo00001_ooool6oh;o0003ogoo0?mn
o`3oO_l000;oO_l01Omlo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`03ooooo`?o000000?oooooo`3o]?n;o`001On<o`03ohgo00;oSol01?n@
o`05oi7o00?ooooo00Go0000ooooool0oOooooooo`3mo`04ooooo`;o0?go0_ooool2o`00000Kol_o
0?l02Ooobol0o`2:oooooooo0000oolk0?nmo`3ooc/0o`3oHOoo>`3o2ol0oolk0?oo?P3oEOl0o`2:
ool0ROoo0?gookgo0?l0oOoo05?oolOo0?oo;`3o08[oolWo0?o2o`3o000000;o`_l000Ko0?mQolgo
0?o=o`3o_Ol0o`000?o<o`02o`3Do`04ok_o0?l0oj7oc?l0o`0Qo`;ocOl000So05gooonj0?o<o`3o
0?o1olco0?mno`3oTOl0olOo00;o000000So0?n5o`0cool02Ooo00Woo`0Lool0ohSocOl0o`3oL`;o
_?l000CoPol0o`1bool0L_ooc?l00_l09_l2o`3Do`05o`3o@?l0T?ooc?l0o`1Qool0oh@00ol06Ol0
1ooo5`3o01_oo`0Kool06oooc?l0okgo0?l02Ol00ol00_l00oo<o`3o08[oo`01o`02o`01o`06o`0V
ool=0?oo3@3oo`3oLol02OoobOl00_l0oOl01Oo<o`3o08[oo`3oLonno`3o0?n800;o^ol000_oEOl0
o`000?l0of7o0>3oo`_o0?ooB@3o03?ooa40oonco`3o0?goo`2:o`02o`00000;ooln0?l0003ooch0
oolm0?l0oOooocd0o`3oHOooF`3oooooo`000?l0R_l00_l0oj401_l0ohSo_Ol0oooooonmo`3o0?go
o`2:o`?ooooo00Ko0?mQoooooooooooo2ol0ooooool00008ooooo`GoP_l01?moo`000omno`3oO?l0
ogco0002ogco00_ooooo00?o0000ooooooooool0Noooool007gooooo00?o0000ooooooooool00_oo
ool4ohco00GoSOl01?n@o`05oi7o00[ooooo00Oo0000ooooool0oOooooooo`3moooooooo0?oH00?o
oooo00Co0?gool_o0?l0003o00000_ooool02?l02Ooo0000oolk0?l0R_oooc/0ol_o0?oo>`3o0?mQ
0_oo>`02o`000007o`2:ool0ROoo0?goool_0?oooooobOl0o`3mo`02olWo0003o`2:ool0003o0;7o
00?o`_l000Co_Ol0o`3mool0R_oo0=Co0_l000001_l09_oo0=Coo`3oXOnko`3ocOl0okgo00?o0?o]
00?oO_l0oi7o0?o<o`000_o7o`02o`3oY`09o`3oQOl0ohSo_Ol0o`0cool0oh[o02Kookko0?o<o`3o
0?mc00;o07oo00Go093oo`0Iool06Oooc?l0o`3oL`02o`3Do`;o01_o00goc?l0o`02ool00_oo0?n4
okco0?oo^P3o02Kooonj0?l0l?oookX0o`3mool0/oooc?l000;o00Wo0_l00Ol01_lc0?oo007ookgo
0?l0R_oo_Ol0o`0Vo`;o_Ol000[obOl0o`3oLoo9o`3o0?goofoo0?l70?oo08[oo`3oLol0ohSo08[o
0_l0VOl01?l0003oEOl0okgo0?l0<ol2ok_o0004oa40oonco`3o__l0o`3mo`;o000000Cooch0o`00
0?l0oOoooch00_oo?@003Oo<o`3ooe/0ooooool0of7o__l0o`000?l0oj7o0?goo`3oXOl0ohSo08[o
oooooonmo`000_l000000onbo`3oooooooooo`02ooooo`05o`3oHOl0003o2ol0ooooool000002Ooo
ool00ol0ol_oooooooooo`05oh;o0003ogoo0?mno`3oO_l000?oO_l01Omlo`06ooooo`03o`000?oo
oooooooo05[ooooo00?o0000ooooooooool00oooool5ohco00CoSOl000?oSol0oi3o0?n@o`000on@
o`05oi7o00Sooooo00Go0000o`3mooooooooooooo`3mo`05ooooo`03o`3mooo;o`3o0?go00;o0000
00[oooooo`09ooo;o`3o08[oo`000?o;o`3ooc/0okgo0?oo>`3o05Wo0_oo>`004OmEo`3ooc/0o`00
0?l0003o08WoolWo0?nmo`3oaol0o`3moooo;`3obOl0o`2:ooo=o`3o_Ol0o`000?l0R_oo_Ol000Co
`_l000Ko027oo`3Dool0003o0000olco0?l0oj42olgo00;o0?o]00Ko__l0oonj0?o<o`3oc?l0o`3o
`OnAo`02o`3oY`04o`3oR?l0ohGo_Ol0o`09o`;o03?o00goc?l0o`3oR?l0Oooo0?mco`3oDol0L_oo
Pol0o`3oR?l09_ooc?l0o`3oLol0e?oo00Wo00;o06_o00Go093oo`0Iool06Ooo01Woo`3oQ003o`0K
o`03o`2coon3o`3o0?go00?o00;o0_l00Ol00onno`3o<`3oo`2:o`02okgo0003o`0Voonmo`3o_Ol0
00;o_Ol000Go0?mco`000?oohP3o0?goo`L0o`03o`2:o`0>o`3oR?l0of7o_?l0olOo0?l0003o_Ol0
ok_o0?l0<oooodT0okko0?nmo`3o__l0ok?o0?l0R_l4o`000006ooln0?l0oOooocd0oolm0?l0of7o
oe/00_nno`001ol0003o08[oo`2:oooooooo_Ol0o`3o]_l0R_l00_l00004ooooo`05o`3oHOl0003o
2ol0ooooool000003?ooool00ol0ol_oP_l0oh;o0004oh;o00CoOol000?oO_l0ogco0?mlo`000_ml
o`05ooooo`03o`000?oooooooooo07_ooooo001jooooo`;o000000?oooooohco0?n<o`000_n<o`04
ohgo00CoT?l01_nAo`04ooooo`?o0?nd2?ooool2o`000005o`3moooooooo0?goo`3of?ooool00_l0
0002ol_o0004o`3mooo;o`3o0?goo`3oL`;obol000Oo0000oolk0?l0R_oooc/0olWo0?oo>`3o2ol0
00;ooc/00_l000003ol;o`3o08WoolWo0?oo;`3obOl0olOo0?l0oOoo0?n8o`1Cool0oOoo0000oooo
ool0R_oo0?mQokgo0003ol;o000Go`0Qool0003o0000oloo0?l0e?oo0?nQolgo0?nko`3o0?o]olOo
0?nmo`3o0?o1ogko0?l0ol7oc?l0o`3oYoo7o`3o0?nWo`3oQOl0oh[o0?n8okgo0?o=o`000_l0<ol0
0onno`3oc?l0o`3oL`02o`0Io`04o`2@ool0/ooo0=Coolco00?o01_o0ol00_l02_l0Jooo067oo`00
0?l0003ookX0o`0Voonlo`3o007ooonj0?l0oOl2o`09o`0:okgo0?oo603o02Kookko0?o<o`3o<`3o
o`2:ool0of7o02KooolH00;obOl000Wo_Ol0o`3oLonmo`3oaol0o`L0ool0R_oo_Ol0o`2:ool0ohP0
0_o<o`001?l0of7o0000o`0coonmo`02okco0004o`_o0?nmo`3o/ol0ok_o00?o0?go0ol000002ooo
?P3oocd0o`3oHOoo?@3ooe/0olco0?l0of7oooooo`000?l0oj7o0?go00?o0?nf0_l0R_l3o`0000Co
oooo00Go2ol0o`3oHOl0003oooooo`00000:ooooo`03o`3obooooooooooo00Cooooo1_n2o`05ogko
00GoO?l000?oooooo`000?ooool0FOooool3o`0000GoS?l01?n=o`000on?o`3oT?l0oi3o0002oi3o
00KoTOl03Oooool2o`000003ooooool0omSo0?go00?ooooo0_l000003Oo;o`3o0?gool_o0?o;o`3o
0?goo`3oLol02Oooooooolco0?l0003ooc/0o`3oXOnmo`000_oo>`001?l;o`3ooc/0oolk0?l;o`02
o`00000Ao`29ool0ohSo_Ol0olOo0?l0oOooobl0oolM0?l0R_oooooookgo0?l0003o08[oolgo0?l0
of7o08[oo`000?l0e?l00_o2o`02o`0000;ocOl000Co0?nQok_o0?oooooo__l00_o<o`001?l0ol7o
0?nWogko0?nAo`02o`3oRP03o`3oQOo=o`3o00Wo00;o01co00?o__l0o`0cool0<ol00_l0L_l01?l0
og?o02Koo`0Vool09_l2olco0003o`3oLol02Ooo0?m000;o01Wo00?o093oo`1[ool06ol00_l06ol2
o`000007okco0?l00_oo00;oo`02oonmo`3o007oolco0002ol_o0006okko0?l0of7o<`3ooc<0ool0
9_ood?l00_o9o`000ooAo`3o00Woo`3oL`03okgo00;o08[o00Ooc?l0o`3oR?nmo`3o0?mQolOo0?nl
o`3o000000;o03?o00So^ol0oom90?nmo`3o__l0o`3moonco`3o0?gookko00?o000000Kooch0o`29
oooo?@3ooooooolm0?ooF`02ooooo`03o`000?l0okKo0?nf00;o0?nf00Co08[oo`000?l0003o0000
1?ooool01Ol;o`3o0?mQo`000?oooooo000000cooooo00?o0?o;ooooooooool01?ooool5oh;o00Go
Ool01?mlo`000ol0003oooooooooo`1kooooo`00NOooool2o`000003ohco0?n=o`3oSOl000;oSOl0
1?n@o`05oi7o00;ooooo00?o0000ooooooooool02?ooool3o`3o]0Gooooo0_l000001Ooooooo0?go
o`3mool0omSooooo00;o000000goooooo`3moooooooo0?goo`000?l0oOoo0?mco`000?o9o`3ooc/0
olco0?oo>`3obOl000;ooc/00_l000004_l0R_oo_Ol0o`000?l0ROooaol0ool_0?o7o`3o0?n8olOo
0?l0oOoo05?ookgo0?l0003ocOl0o`2:ool0of7o027oo`3Do`;o_Ol01?o2o`001?l0e?oo0?o]o`3o
XOl0GOl2ok_o0003olco0?mno`3ookX000;o0?nW00_oaol0o`3oR_l0ohGo0?n:o`3oR?l02Ooo_Ol0
o`3o_ol0Oooo02Kookko0002o`0Io`03o`3oLol0e?oo093o00?o01_o0ol00_l01?oo7@3oc?l0o`0Q
ool0HOl3o`00000Ho`1[ool09_oo007ooonj0?l02Ooo0?goo`1Moonmo`3o08[oo`0Voonlo`3o__l0
olco0?nlo`3o<`3ookco0?l09_oobOl0o`1CoooAo`3ooaP0o`09ool0og?o1`3o0ol0R_l04_l0ohSo
0?mcokgo0?l0of7oodT0o`000?nmo`3oEOl0okgo0?l0VOoo4@3ookgo0?l0oOoo/ol0o`3moonko`3o
0000ok_o00Co00000_oo?@000ol0e?oooe/0olco0002o`3o]P07o`000?l0okKo0?n8ooooool0R_oo
__l0o`000003okgo00?ooooo00Ko2ol0ooooool0003o0?mQooooool0000:ooooo`03o`3obooooooo
oooo00[ooooo1_n2o`04ogko0003ogco0?l0003o000005Sooooo0ol000000on<o`3oSOl0ohgo0002
ohgo00GoT?l01OnAo`05ooooo`?o0?nd2oooool2o`0000?o0?go0oooool2o`000008o`3moooooooo
0?goo`000?oooooo0?goo`3oLoo<o`02o`000003oolk0?l0oj7o_Ol000;ooc/000?obOl0o`000?l0
00000_l0FOl01?l;o`3o0000okgo0?l0e?l2olOo000@ool_0?l08Ooo08[ookgo0?o=o`3o0000olOo
0?l0R_oo0?mQolOo0?l0e?oo02Koolco0?nmo`3oc?l0o`3Do`Co`_l000Oo^ol0olco0?o<o`3ookX0
o`1Moomno`3oTOl000;ocOl000Co0?n5o`3oR?l02Ooo_Ol00_l0Ool00onno`3oc?l0o`3oR002o`0c
o`06o`3oLol0e?oo0=Cooh?o0?o<o`3ooad00ol06Ol01Ol08Ooo01_oo`2@ool06oooood000Co0000
00Go00;oo`09ool02Ooo0?gookgo0003okco000>okko0?o<o`3o0?nHo`2:ool0Dooo<`3oolWo0?mN
o`3o00WooolH0?l02Ooo0?mcooooooo<o`02o`2:o`08o`3moonko`3o0?n8olco0?o7o`3o_Ol0o`0c
ool00002okgo0004oom90?nmo`3o4@3ookko00;o^ol000Go/ol0o`000?ooooooon80o`09o`02o`00
0004oolm0?l0e?ooocd0oomK00;o0?nf00?o0?nQo`000?l0ohP00ol0R_l01?nmo`3o__l0o`3moonm
o`02ooooo`06o`_o0?oooooo0000o`3oHOoooooo00003Oooool00ol0ol_oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo1_n2o`04ogoo0003ogco0?l0003o000007[ooooo001hooooo`;o0000
00?oSOl0oi3o0?n@o`000_n@o`05oi7o00Oooooo00?o0000ooooooooool02oooool3o`3o]0?ooooo
00Co0000ooooool0003o00000_l0oOl2ooooo`;o000000_oooooo`3mool0oOoo0?goolWo0?l0003o
bOl0oolk0?o<o`3ooc/0oeGo0002oolk00;o000000Oo0?nQolgo0?nmo`3o0000okgo0?oo;`3oaol0
00;o027o0_l0oOl03Onmo`3o0000olOo0?o7o`3o08[oo`3oHOl0oOooc?l0okgo0?l0R_oo_Ol0olgo
0?l0e?l00oo2o`001_l0GOooc?l0olco0?nko`3oO_l0oonj00;o0?n:00Soaol0o`3oQOo=o`3o01co
o`09ool07?oo_Ol0o`1oo`?o01Wo00Go02Koo`0cool0og?o01_oo`2@o`02o`000008o`02ool0og?o
0?loo`09ooo<o`3o007oo`1Qool00Ol2o`000003oolM0?oo^P3o02Ko00;o00Wo00So0?3oo`3mool0
GOoo_Ol0ol_o0?l09_oo__l0olco00;ooaP000?o08[ooc<0oonlo`000_nlo`001?o7o`3o2ol0o`09
ool0og<2o`2:o`04olco0?l0oOoo0?n8o`3mo`;o03?o00CoodT0o`000?nko`3oEOl00onmo`000ol0
of7o_Ol0ok?o0002o`000004okco0?l0oOoo0?gook_o00;o00000_oo?@001ol0okKooe/0o`3o]_l0
of7o0?nQo`3mool000000_l0R_l2okgo0003o`000?nmo`3o_Ol000;o000000Goooooo`_o0?oooooo
ooooo`3oH@02o`0000cooooo00?o0?o;ooooooooool03?ooool00ol0003oooooogoo0005oh;o00?o
0000Eoooool2o`000003ohgo0?n@o`3oT?l000?oT?l01OnAo`0=ooooo`?o0?nd2Oooool00ol0003o
0?oHo`000003o`3mo`;ooooo00So0?goo`000?l0003oooooo`3mooo9o`3o0?goolWo00;o000000Go
c?l0oolk0?l0R_oooc/0o`_o0002oolk00;o000000Ko_Ol0o`_o0?l0FOoo08Woo`000?l08Ol2olOo
000?ool_0?l0R_oo0?gookgo0?o7o`3o0000oolG0?l0R_oo0?mQokgo0?l09_oo08[ookgo0?o=o`3o
0=Co00;oc?l000?o05gookko0?l0oj401?o2o`002Oo=o`3oTOl0olOo0?l07?oo0?n5o`0Lool02Ooo
07oookgo0002o`1bo`09okko0?l0ohSo02Koo`0Vool0e?oo0?mco`0cool0ohSo01Wo00;o000000So
0?mco`0Kool06ooo01_oo`01ool0T?oo007oo`02o`;o000000?ookX0o`09ool02Ol00_l0Jol00ol0
oOooc?l0oolH0002oolH0008okko0?oo603o_?l0o`2:ool09_oo_?l0oc<0oonlo`02olOo0005o`09
oonmo`3o0?mco`2:ool0Dol00ol0oOl02_l0ohSoaol0o`0cool0<ooo^ol0o`000?nmo`3o0?mQoom9
0?lA0?l2okgo0007okko0?nmo`3o/ol0o`3moonko`3ooad0o`3mo`02o`00000=oolm0?l0ROooocd0
o`3oHOooF`3o0?nQo`3mool0003o08[ookgo0?l0003o08[ookgo0002okko00?o00000_ooool00ol0
003o0?mQo`00000>ooooo`03o`3obooooooooooo00?ooooo00?o0000ooooooooool02?ooool5oh;o
0003ogoo0?l0003o000007Wooooo001gooooo`?o00001OnAo`0<ooooo`03o`000?oooooooooo00ko
oooo0ol0ok@01_l0003oooooooooool0omSo0?goooooo`;o0?go0_l00002olWo00;o0?go00Gooooo
o`000?l0og?ooc/0o`000002oolk00;o000000?o08[oo`3oXOo<o`000_o<o`001?l08Ooo0000ool_
0?l0FOl2olco0008olgo0?l0oOoo_Ol0o`000?l08Ooo0?nQo`3Dool0of42o`0Vo`04okgo0?o=o`3o
cOl0okgo00;o00000_o<o`03ol;o0003ogko0?nko`3o0?go00;o0?n:00Ko0?n5o`0Lool0GOoo00Wo
o`3oR?l0Ool2o`0Io`03o`0Vool0e?oo__l000?o01_o00?o00;oo`2@ool000000_l000001Ol0og?o
00Woo`3o?oo<o`3o067o00;oood00_nno`02oonj000;o`09oooo^P3ooad0o`1[ool0oOoo06_ookgo
0?l09_oooad0okko0?o<o`000_o9o`001Ol0R_oo02Kooc<0oolc0?ooaol000;o000000ko00Woo`2:
ool0R_oo_?l0o`3oR?nlo`3o0?n8o`0cool0og?oaol0oom90?l0003oc?l0ok_o00;o_Ol000Oo4@3o
o`3oHOl0ROoo0000ok?o0?nmo`3oaol000;o0?go0_l0okH02_l0oOoo0000o`000?oo?@3ooe/0o`0V
ool0oj7o_Ol0o`2:ool00002okgo00?o00000_nmo`03o`0000;ooooo00Co0?mQoooooooooooo0000
3?ooool00ol0ol_oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00CoOol0o`000?l0003o
0000E_ooool3o`000003oi3o0?nAo`3oTOl000?oTOl00oooool00ol0003oooooooooo`0?ooooo`?o
0?nd1_ooool01_l0003ooooooooooooooooo0?goooooo`;o0?go00?oooooo`000?l000000_o9o`02
o`3mo`;o000000Ko0?mcolOo0?oo>`3oEOl0oolk0?l;o`02o`0000?oc?l000So2ol0olco0?l0ROoo
05Woo`000?o<o`3oobl0olco00;o0?go00Co_Ol0oolM0?l0003o027o0_l0e?l01ol0of7o0?o]olgo
0?o=o`3o_Ol0o`3Dooo<o`000_l000002?o<o`3o0?nQolco0?o=o`3o^ol0okgo0?mno`3oTOl00_o2
o`001_l0ohGo00Woo`1bool0L_oo_Ol0o`1bo`?o02Ko00?o0=CooolM0?l0of400ol06Ol02_o<o`3o
0000o`000?l0003o0?mco`1Qooo<o`3o00;oo`2@ool00_l2oonj00;o00Wo00Go02KooolM0?o;o`3o
bol0o`3mo`02o`1[o`0<oolM0?nno`3oc?l0olWo0?l0R_oooaP0o`0Vooo<o`3oaol0oc<0ool02Ooo
c?l00_l000000ol0R_oo_?l0okco0002okco0007o`3oR?l0<ooo03?oo`3oLoo<o`3oooooo`000002
okgo0003oom90?lA0?oooooo00;ooad000?o0000o`3moonco`000_l0oOl2o`3o]P0:o`3mool0003o
0000oolm0?oooooooe/0o`3oXOl0R_oo0000okgo00;o00000_nmo`000oooooooVOl0o`000002o`00
00;ooooo00?o0?mQooooool000003oooool00ol0ol_oooooooooo`02ooooo`03o`000?oooooooooo
00_ooooo00?o0000oooooon2o`000_l0001iooooo`00Moooool2o`000005oi7o0?oooooooooooooo
ool000003Oooool00ol0003oooooooooo`0Aooooo`06o`000?l0okCo0?ndooooool0oOoooooo0ol0
oOl2ooooo`;o000000Co0?goo`000?o7o`3oaol00_oo>`001?l0003ooc/0o`000?l00005o`0Qo`04
olOo0?l0ROooobl0oolM00;ocOl00_l0oOl01onmo`3o0000o`000?l0e?ooc?l0o`3oHOl0oOl00_o=
o`000onmo`3oc?l0o`2:o`02o`0000;oc?l00_l000000onno`3oO_l0ol;o0002ol;o0004o`3oQOo7
o`3o00Woo`09o`?o01Wo00Co_Ol0o`3Dool0e?oo01_o0_l00002o`02o`03o`2@ool0C?ooc?l000;o
000000Wo0?mcoh?o0?o<o`3o067oooom0?l0oj_o__l0oooooooo^P000_l02Ol01ol09_oobol0ol_o
0?o;o`3o0?gookgo0?o<o`000_l0Jol01Onno`3oc?l0oolM0?oo7@3o08[o00;oaol000?od?l0oc<0
ool000000_l000001Onmo`3o0?mco`3oR?l0<ooo0?n800;o0?go0_l000003_nlo`3o0000okco0?o<
o`3o_Ol0oeGo0?nmo`3o0?mQo`000?l0oj7o/ol0o`3o]_l0oOoo0?nf0_l0oOl03?oo7@3o0?goo`00
0?l0003oocd0o`29ooooF`3o0?nQo`2:ool0of7o0?n8o`0000;ooooo00Go_Ol0o`000?l0003ooooo
o`_o0002o`000003ooooool0of7ooooo00;ooooo00?o0000ooooooooool02oooool00ol0ol_ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Gooooo0ol0001Fooooo`?o000000?oTOl0o`000?ooool0
1_ooool00ol0003oooooooooo`0Booooo`Co0?nd00?oooooo`3of?l000000oooool01?l0oOoooooo
o`3mooooool2o`3mo`;ooooo0_l000001ol0oOoo0000olOo0?o7o`3ooc/0oeGo0?l09_l00_oo>`02
o`0000;o027o00coaol0o`3mool;o`3o08WoolOo0?l0FOoo0000ool_0?o7o`3o0?goolco0?nmo`02
o`00000:o`3Dool0R_oo0?goo`3oHOnmo`3oc?l0o`2:oooRo`3o0=Coolco00;o000000[ocOl0olco
0?l0003o0000oonj0?nko`3oTOl0o`1oooo7o`3o0?n51?o2o`02o`0Vo`04o`3Doonno`3o0?n8o`0I
o`;o000000Go0?mco`0Kool06ooo01_oo`0co`02o`0000?o00;o00?oooooo`3o?ol0T?l00_l02Ol0
3ooo^P3obol0ol_o0?l09_ooPol0o`0Vool0oOoooad0o`2:ool0Jooo__l0olco0?oo7@3o08[oo`0V
o`02olOo00;oc?l000?o<`3oo`2:ool000000_l000001om_o`3o0?goo`3mooo7o`3o0?n8o`3moonl
o`000_l000001_o<o`3o0000okgo0?mEo`3oodT0okgo00;o^ol000Co0000okko0?l0oOoo/ol00_l0
oOl2oolM000:o`3mool0003o0000okgo0?oo?@3ooe/0o`2:oonmo`3o0?n8o`0000?o_Ol00_l00000
1_l;o`3ooooooooooonmo`3oooooo`3oH@;ooooo00?o0000ooooooooool03Oooool00ol0ol_ooooo
ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_l0001iooooo`00Mooo
ool2o`0000Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Aooooo`;o000000Ko
0?oHo`3o]?l0oOoo0?goo`3o]?ooool2o`000007o`3mool0003o0000olOo0?l0003o0?gooeGo0002
oolk00Co00000_l0oj403?oooooo0?gooooooonmo`3o08Woool_0?l0003o0?n8o`3mool0FOoo08[o
okgo00;o000000go0?o]o`0Vool0of7ocOl0o`09ool0ol7o_Ol0on;o0?l0R_oo0=Coolco0?l02Ooo
c?l000;o000000KoO_l0olco0?oo^P3oc?l0ok_o0?l0ohD3ol;o00;o02Ko00Go0=Coo`0Kool06ooo
01_oo`02o`02o`000005oolM0?l0og?o093oo`0Qooo<o`000_l000001ol0<oooPol0olco0?ooo@3o
0?lookko0?l0oj/00_l02Ol03?oooooookX0o`0VoolTo`3oooooo`1Mool0oOoo_Ol0olco0?o9o`3o
__l0olco00?o06_o00?o08[ooolM0?oo7@000_o<o`002_lc0?oo0000o`000?nmo`3o0?mco`0cool0
003o0?n8ofoo0?o7o`02o`000008o`3mool0003ooad0okgo0?l0ROoo_Ol0o`3o]_l00002o`3o]P08
ok?o0?l0oOoo_?l0o`2:ool09_oo0?gookgo0?l0oOl2okgo00?o000000?o08[oo`3mool0of400_l0
0002okgo00?o000000?o2ol0ooooool0of400_l0of401Ol0003ooooooooooooooooo000000gooooo
00?o0?o;ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Kooooo
0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool2o`3o]004o`00
0?ooooooooooooooo`;o0?go0oooool2o`00000:o`3mool0003o0000o`3mool0003oaol0oeGo0?oo
>`3o0?mco`0Qo`Co000000Oooad0o`2Doooooooo0?goo`_o0?l0ROooaol000;ocOl000Goobl0o`1I
ool0oOoo0?gookgo0002o`000004o`0Vooo=o`3ocOl0o`3oH@;o_Ol000?o08[oo`3Dooo<o`000_o<
o`000ol0GOooc?l0olco0002o`000008olco0?mno`3oTOl0olOo0?l0ohGo07;oo`01ool0ohP2o`0V
o`Co`_l000Oo01Woo`3o?_l0003o0000o`0Kool0of7o04co00;o00;o0_l000003ol0<oooc?l0oooo
oooooooo00Woo`2@oolTo`3ookX0ol_o0?l0]_oo0?3oo`0Vool0oaoo_Ol0o`3mo`02olWo0007o`2:
oonno`3oc?l0o`1[ool0R_oo02Koo`1[o`03olco0003o`2:oolc0?oo00Wo00;o000000Oo0?mco`00
0?l0<ooo03?oo`3oR?oo7@3o0?go00;o000000Go08Woo`000?o<o`3o_Ol0oom90002o`3o]P03o`00
0?nlo`3o^ol000;o0?go00Oo/ol0okgo0?l0oOoo_Ol0o`3mool09_oo0?mQ00?o000000Co0?goo`00
0?l0003o00000_ooool3o`000003oiWo0?oooooooooo00;o0?mQ0oooool00ol0003oooooooooo`0>
ooooo`05o`3oboooooooooooooooool000003Oooool00ol0003oooooooooo`1kooooo`00OOooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo0_l00002ooooo`;o0?go00Gooooo
o`3o]?l0003o0000ooooo`03o`000003o`3moomEo`3ooc/000Co000000Oo0?mQokgo0?l0oj7o0?nQ
oolM0?l0oOoooad000;o000000Soobl0okgo0?l0003o0?goo`3oR?l0R_oo_Ol0o`0000;o02Ko00?o
cOl0o`3oHOl0oOl00_l0ol401?nmo`3oc?l0o`3Dool0R_l2o`000008o`3oR_o<o`3o0?nQogko0?nm
o`3ookX0o`01ool0ohD2o`0Io`;o02Ko0oo2o`03o`02o`08o`0Voonno`3o0?n8olco0?l0og?o093o
ooooooo<o`02o`000004o`3oLol0<ooo03?ookko00?o000001;ookX0ol_o0?o;o`3ookX0o`0Vool0
]_ooooooo`1Mool0oOoobOl0olco0?oSo`3o__l0olco0?o7o`3oPol0o`2:ooooool2o`1[o`;o08[o
00oo2ol0o`2:ool0<ooo03?oo`3oLol0oOoo0?mQo`3oR?o7o`3o02Koo`3mooooB@3o0?mco`000?nm
o`000_l0okH01?nmo`3o0000okgo0?l09_l2o`3mo`03ok?o0?l0003o_Ol000;o_Ol00_l0oOl2okco
00?o000000?oooooo`3mool0ohP00ol000000onmo`3o0000o`000003o`3oH@04oooooonIo`3o0000
o`0000?ooooo00?o0000ooooooooool02oooool00ol0ol_oooooooooo`0;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01Kooooo00?o0?oHooooool000000ol0ok@2o`3mo`?ooooo0_l000001?l0mooo0000o`000?l0
0002oeGo0004oooooooo>`3o08oooolk00;o000000Oo08[oo`3oXOl0U?oooad0o`3moooo7@3o_Ol0
00;o000001Cooad0o`1Coooo;`3o0000o`2:ool0oOoo_Ol0o`3Dool0003ocOl0o`3o`Ol0oOoo0?mQ
okgo0?o=o`3oc?l0o`3Dool0okoogol0okgo00;o000000So01cookgo0?l0oj7oO_l0oi7o0?l00Ooo
0?n5ok_o00?o02Ko00Koc?l0o`0Iool06Ooo01Woolco0?l06ol4ol;o00?o00;o00Koc?l0o`1Qool0
003o0000olco0?l0<ol2o`09o`07oonj0?l0T?oo0000o`3o?ooSo`3o0;Koo`1Mo`02o`0Vo`0<okgo
0?l0oOoo0000oooooonno`3oc?l0olOo0?l0ofCo08[oolco0?l0Dooo06_o0_l0R_l02Ooo7@3o0?n8
o`2:oooAo`3o0?goo`3oLol0<ooo0?goo`3oR002o`0Vo`0:o`3mool09_oo02Koo`3oLol0003o0?nf
okgo0?ooB@3o02Koo`0000;o_Ol00_l0oOl00ol0003o/ol0okco0002o`3mo`03oolM0?l02Ooo0?mQ
00?o000000Cooe/0ok_o0?l0003o00000_nmo`02o`000004o`2:ool0of7o0?mQo`3oH@;o00000ooo
ool00ol0003oooooooooo`0>ooooo`05o`3oboooooooooooooooool000003Oooool00ol0003ooooo
ooooo`1kooooo`00OOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo1?oo
@P05ooooo`05o`000?oooooo0?goooooool0oOl00oooool4o`0Qo`?o0?go00Cooc/0o`000?l0003o
0?mc0_l0of401_nmo`3o08[oo`3oXOl0oOooooooo`2Do`;o000000Goobl0o`_o0?l0oOoo0000olco
0003o`0000;ocOl000?o0?o1o`3oHOl0oOl00_l0okl00oo<o`3o_Ol0o`000003o`000007o`09ooo<
o`3oO_l0o`3oXOl0Oooo01Woo`3oQ@02o`0Vo`04ok_o0?l06ooo01_oo`3oR0;o00;o1?o2o`001Onn
o`3o0?n8ooooool0og?o093o00;oc?l000Go00Woolco0?o<o`3o0?mcoh?o0002o`09o`;o000000ko
0?loon?o0?oo^P3ookX0o`0Vool0]_oo05goolWo0?l0oOoo0?lOolco0?nno`3oaol0olco00;o02Ko
00Go08[oo`0Vool0R_oo08[oo`0Vo`02o`000007o`0coolc0?oo02Koo`0Vool0og?o0?n8olOo0002
o`3o]P0Aoom90?l0okKo0?mco`000?oo7@3o08Wooa40ool0003oEOl0okgo0?l0oOoo_Ol0o`000?nc
o`3o0000oolM0?l0oOl00_oo7@001Ol0oOoo^ol0o`2:ool0of7o00Wo00;o00000onmo`001Onko`3o
0000o`000?l0003o0?mQ00;o00000_ooool00onIo`3o_Ol0ooooo`02ooooo`03o`000?oooooooooo
00gooooo00?o0?o;ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
05[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`09o`3of?oooooooooo
ooooool0003oooooo`3mool0okCo0?go00;o0?nd1Ol08Ol01_l0oj7o0?goo`3mool02Ooo0?gooolk
00;o000000Co_Ol0o`3oLol0R_oo0?nQ0_ooool00ol0oOoo<ol0okgo0002o`000006okgo0?l0Dooo
obl0o`3oHOl0003o0=Co0ol00002olgo0007o`3mool0of7oc?l0okgo0?l0okoo0=Coo`2:o`04o`00
00;o007o00Co0?nQoi7o0?nmo`3o0?n50_l09_l01Onko`3o01Woo`0Iool06Ooo0?nb00?o01_o00?o
__l0o`3oR?l00_l00_l00_l4ol;o00?oc?l000?o0?mco`09ooo<o`000_l0<ol03_l0T?oo0000oonj
0?l0ocoo0?l@o`1Mool09_oo_Ol0o`3o7ol0oOoohOl0olOo0?nno`3oc?l00_l09_l01?l0R_oo02Ko
o`2:ool0R_l3o`0Vo`;o00000_lc0?l01Oo7o`3o0?mco`0Vool0ohSo0?go00;o0?nf00So0?gookgo
0?l0og?o0000oooooonmo`3oodT0o`0000;o_Ol000?o0?goo`000?l000000_l000001?nco`3ooooo
o`3moonlo`02o`2:o`04o`3oHOl0oj7o0000o`0000;o_Ol000Go08[oo`000?l0003o0000o`3oH@02
o`000004oiWo0?oooooooooookgo00;ooooo00?o0000ooooooooool04?ooool01?l0ol_ooooooooo
ool0000=ooooo`03o`000?oooooooooo07_ooooo001Tooooo`;o000000?o<ol0ooooooooool05?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo1_oo@P001?l0003oooooo`0Q
ool0oOl3o`0Qo`?ooooo00?o0000o`3o]?l0ok@00_l000001_l02Ooo2ol0ooooool0og?o0?mQokgo
00;o000000Oo0?gooolM0?nmo`3ooad0o`29oooo;`3ooad000Ko000000Ko0?o1o`1Iool0FOoo08[o
o`3oHOo<o`03oolY00;o000000Go08[ookgo0?l0Oooo00Woogko0002o`0Io`03o`3oQOl09_oo01_o
00;o01_o0ol00_l01onmo`3o0?gookgo0?nno`3oc?l0o`0Vooo2o`000_l000001ol0og?o093oolco
0?l02Ooo0?mno`1Qooo<o`000_l02Ol2o`0Vo`;o03?o0_l09_l00ooo^P3o02Koo`0Vo`02o`0Vo`09
okgo0?l0oOoo02Koolco0?nno`3oc?l0o`0Vooo<o`3o02Ko00;o08[o00?oooooo`2:ool0of@00_l0
00001Ol02OoodOl0oc<0ool0Jooo0?mc00;o000000WoHol0o`1MooooB@3o0?gookgo0?l0003o_Ol0
oa40ool000000_nmo`001Ol0oOoo_Ol0olco0?oo7@3o/ol000;o08[o00Go0?goo`2:ool0oOoo08[o
o`3mo`02o`2:o`05o`3oHOl0003o0000o`000?l0ohP00ol0of42o`000003ooooool0003o000000?o
oooo00Go_Ol0ooooooooooooooooo`00000?ooooo`03o`3obooooooooooo00[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1;ooooo`;o000000?o<ol0ooooooooool02_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00Co0?oHoooooooooooooooo0_l00003
o`0Qo`03o`3mool08Ooood8000?ood8000?o0?nQo`000?ooool00_l0oOl4o`000004okgo0?l0oj7o
0?mco`2:o`;o000000Co0?gooolM0?nmo`3o08Wo0_l;o`000ooo;`3o0?goo`000005o`000007o`1I
ool0oOooc?l0o`3oHOl00Ooo_Ol0o`01o`02oolY00;o000000So05goolco0?l0L_ooc?l0ogko0?nA
o`3o0?n5o`0Vo`?o01Wo00Ko^ol0o`0Kool06ooo01_ookgo0?o<o`03o`02o`;ohol00_l000000ol0
ohSoc?l0o`3oH@04ol;o00;o02Ko00CookX0olco0?l0T?oo03?o1?o<o`002_l09_oo_Ol0olco0?l0
oOooc?l0okko0?l09_ooc?l0oooR0?l09_l2o`2:o`05o`1Coooooooo0?mQo`3oR?l0R_l00_l00000
1Ol0Joooaol0oc<0ool0og?o0?go00;o00000_oo7@003Onmo`3o0?gookgo0?l0003o_Ol0oom90?l0
003oEOl0oolM0?l0oOoo_Ol0o`2:ool0oOl00_l0R_l01?nco`3o08[oo`3mool0oOl2o`2:o`;o_Ol0
0ol000000onko`3o0?mQo`3oH@02o`000004ooooool0003o0000oiWo00;ooooo00Co_Ol0oooooooo
oooo00004_ooool01?l0ol_oooooooooool0000=ooooo`03o`000?oooooooooo07_ooooo001Toooo
o`;o000000Cooooooc?o0?lco`3o<ol04oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo017ooooo0_l00006oom200;ooooo0_mEo`000ol0003oooooooooo`04o`000004o`3mool0of7o
0?mcokgo00Co000000?o_Ol0oc?o0?l0ROl01?l000001Ol09_oo0000okgo0?l0003o0?go00;o007o
00coc?l0oolY0?oo:@3o0?n:on;o0?l07?oo_Ol0o`1ooonno`3o08[oo`0Ioomno`02o`0Vo`03o`3o
QOl06ooo01_o00?o00;o00?o_Ol0ok_o0?l0ohP00_l08Ol01Onmo`3o02Koo`0Vool09_oo__l000;o
00000oo2o`02o`0Vo`;o00Wo00?o0?mco`0Voon3o`000_l000003?oooooo03?oo`0cool0ocoookX0
o`0Vool0GOoo0;Kookgo0?l0oOooc?l0okko00?oc?l000?o02Koo`2:ool0R_l00_o<o`001ol0<ooo
08[oolco0?o@o`3o00Woo`3moooAo`000_lc0?l2o`0000;o06_o01GoodT0okgo0?nmo`3o0000o`2:
ool0003o08[oo`_o0?l0oOooEOl0o`3oHOnmo`3oc?l0o`3moonco`3ooad0o`3moooo7@3o08[ooooo
ool0oOl00_nmo`000ol0of7oc?l0o`000004o`000004o`_o0?l0003o0000o`0000Gooooo00Go_Ol0
ooooooooooooooooo`00000@ooooo`03o`3obooooooooooo00Wooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1;ooooo`;o000000?ooooooc?o0?lco`002_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Cooooo00Co0?oHoooooooooooooooo0ol00003ooooo`03o`3m
ool0mooo0?Oo00;o097o00?oEOl0oom20?oo@P000ooo@P04o`000004okgo0?l0oj7o0?nQo`3oL`Go
000000Go0?n8o`29ool0003o0000o`3Do`02o`000008o`01oonmo`3o0?goo`000?l00Oooc?l0o`1I
ool0of43oolY000=o`1ooooOo`3o08[oo`1boonmo`3o05goolco0?mno`3oTOl0o`0Iool0ohGo01Wo
olOo0003o`0Ko`03ok_o0?l0GOoo00;o00;o00;o00Go02Kookko0?l09_oo02Koo`3o@002o`000003
o`0Vooo<o`3o02Ko00;o00Wo00?o02Koo`3oLoo2o`000_o2o`02o`00000;olWo0?l0<ooo03?oo`1M
ool0ocoo02Kookgo0?o7o`3o0?goolco0?nno`000_o<o`000ol09_oo08[oo`2:o`04olco0009o`2:
ool0<ooo03?oo`09ooo7o`3odOl0okgo0?lc0?oo0?n800;o00001?nmo`002_l0oOoo0000oa40oooo
B@3o_Ol0o`2:ool0oOooc?l0o`2:oonmo`02o`3mo`03o`2:ool0QOoo/ol000;o0?go0_nmo`000ol0
of7o0?n8o`3mo`04o`000003o`3mool0003o000000?ooooo00CoVOl0oooooooooooo_Ol00_ooool0
0ol0003oooooooooo`0Aooooo`03o`3obooooooo000000gooooo00?o0000ooooooooool0Noooool0
06[ooooo0_lco`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool5ooln
00Gooooo00Go0?oHo`000?l0003o0000o`3mo`02ooooo`03o`3moooooooood8000Good8000?o097o
o`3mooooool00_l000001?l0oOoo0?mQo`3o]?l0og<2o`3oX@;o000000?o_Ol0o`3o_ol0ROl00_l0
0002o`0Vo`06olgo0?l0R_oo_Ol0o`000?l0oOooc?l00_oo:@000ol0of7o05WooolY0002o`000004
okgo0?l06Ooo01Woo`0Io`;o000000?o01_oo`3oQOl0oj400_l00_l01_l09_ooaol0o`0Vool09_oo
0?n8ok_o00;o02Ko00[o_Ol0o`1Mooo<o`3o02Kookko0?l0od3o3ol0o`3oLoo<o`3o0?mn1?o2o`00
0ol0og?o0?mQoh?o0002o`000003o`2coooo^P3obOl000;o03?o00go05goo`0Vooo7o`3o_Ol0o`3m
ooo<o`3o__l0ooooooo<o`3oon80o`0Vool0okKo08[o00;o03?o0_l0R_l02?l;o`3od?l0o`09ooo<
o`3oaol0olco0?l0ohSo<`3o0onmo`000oooB@3o06_oo`1[o`02o`00000;o`3o8?oooooo0?gookgo
0?o7o`3oEOl0okgo0?nno`3o0?gook?o0?ooool00_l0R_l01?l0oOoo_Ol0okgo0?l0oOl3o`3oH@09
o`3mool0ROoo0000o`000?l;o`3o0?goooooool0003o_Ol000Gooooo00GoVOl0o`000?l0003ooooo
o`00000@ooooo`03o`3obooooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1@ooooo`?o<ol01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo
00?o0?oHooooooooool00_ooool2o`000003ooooool0oOoooooo00Cooch000GooooooeGo0?oooooo
0000ooooo`02o`3o]003o`3moooo@P3ood8000?ood8000Gooad0o`3oXOl09_oo0?mco`2:o`02o`00
00;o0?no00So08Woo`000?l0003ocOl0o`2:ool0e?ooaol0okgo00;o000000Koc?l0o`3moooo:@3o
obT0o`3oHOoRo`02o`000009omoo0?l09_oo08[oomgo0?l09_oo0000oi7o0?l06Ooo0?n500?o01_o
0_l09_l3o`02o`04o`0Voonmo`3oc?l0o`3mo`;o__l000Go0?m0okko0?l02Ooo0?mcolco0002o`09
o`07ol_o0?o<o`3o0;goo`3oLooo^P3o0;?oo`3o4002o`0000?o`_l00_l0<ol01onmo`3o0?3oolco
0?l0oOooon80okko0?o<o`000ol0R_l00ol0okKo08[oo`2:o`02o`2:o`04o`0cool0R_oo08[oo`09
o`Coc?l000Go<`3oolco0?o<o`3oc?l0okgo0002olco000<olko0?l0003o0000oom90?nmo`3o0?go
oeGo0?ooooooc?l0okgo0?l0oOoooooo0_l0R_l01?nco`3o_Ol0okgo0?l0oOl4o`3oH@04ooooool0
ROoo0000o`0000;o_Ol000?o0000ooooooooool00_ooool01_nIo`3o_Ol0okgo0?l0003oooooo`00
01?ooooo00?o0?o;ooooool000003Oooool00ol0003oooooooooo`1kooooo`00K?ooool3oc?o00ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`Oooch00_l000001Ol0oOoo
0000oooooooooooo0?go00;o000000Co0?nQo`000?oooooo097o1_oo@P03o`3mo`07o`3oLol0okCo
0?nQokgo0?l0okoo007oo`29o`02o`000005olgo0?l09_oo08[oo`0Voonmo`000ooo:@001Ol09_oo
obT0oolY0?oo:@3o02Ko00;o000000Co01Wookgo0?l09_oo01_o0_l000002ol00_oo0?n5o`02ool0
oj7oI_l0o`0Qooo7o`3o027ooolM0?l0ohSooooo00;o^ol000So_Ol0olco0?l0GOoo02Kookko0?oo
oooo__l0o`3oL`;o00Wo00Co0?n8olco0?o<o`3ooooo0oo2o`001on3o`3obOl0o`3oDooo^P3o0;go
o`3oVOoo^P000_l0<ol02Onmo`3o08[oo`3mooo<o`3o__l0o`2:ooo<o`3o02Koo`2:o`02o`0co`;o
08[o00Goooooo`000?l;o`3od?l0o`09o`03okgo000Eo`3oR?l0og?o<`3oo`1CooooB@3oooooo`3m
ool0ROoo0000oa40ool0og?o0?goolco0?nmo`3oc?l0o`3oHOmEo`3o_Ol0o`3moonco`3o08[o00;o
_Ol000Go0?goo`3oHOl0of7o0?mQo`3mo`02o`3oH@04o`3oXOl0QOoo08Woo`_o00;o000000?o_Ol0
o`000?ooool01Oooool2okgo0003o`000?oooooo0000017ooooo00?o0?o;ooooooooool02?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo05?ooooo0_lco`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04_ooool00ol0omSoooooooooo`04ooooo`;o00000_l0oOl0
1?l0moooooooo`3mool00005ooln0006ooooool0olGo0?goo`_o0?l0ROoo<ol00_l0oOl5oom20005
okgo0?ooooooaol0oolM0?l0ROl00_l000001ol0of7o08[ookgo0?o7o`3o_Ol0olco0?l000000_oo
:@001?l09_oo08[ooolY0?oo:@02o`000003o`0Vool0L_oo01Wo00;o01Wo00KoO_l0oi7o0?l0ohGo
01_oo`3oXOo7o`03o`02o`05o`000?o?o`3ocol0ok_o0?nmo`000_ooool04?nno`3o0?m0okko0?l0
2Ooo067oo`3oLoo<o`3obol0ooooooo<o`3o04coo`3oHOl0og?oPol0olWo0?oo^P02o`2mo`03o`3o
Dol0R_oo08[o00Co`_l000?o08[oo`3moonno`000_l0R_l02?l09_oo08[oo`2:ool0R_oo0?mTo`0c
ool0R_oooooo0_l0oOl00oo7o`3o00Wookgo0003okgo0004o`3oLolc0?ooKol0okgo00;oc?l000Ko
06_oolco0?l0003o0?mcoom90?l0oOl2olco0004oeGo0?o<o`3oc?l0o`3mo`?o_Ol000?o0?gook?o
0?l0of400_l000000oo<o`3o0?mQooooo`02o`_o0005o`3mool0003o0000ooooool000000oooool2
okgo0005ooooool0003o0000ooooool000005?ooool00ol0ol_o0000ooooo`0<ooooo`03o`000?oo
oooooooo07_ooooo001_ooooo`;o<ol03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00oooooo00?o0?oHooooooooool01ooo?P001Ol0moooooooo`000?l0oj7o097o00;ooooo00Go
2ol0o`3mool0olGo08Woo`3oH@06oom20009okgo0?l09_oo0=Coo`29oooo;`3o02Koo`3oYol0oh[o
08[o00;oobT000Go0000o`3oR_oo:@3oobT0odSo0002o`0000;o01Wo00So0=Coo`0Kool06ooo01_o
ogko0?nAo`3o00;oo`3oQ@;oc?l0013o0?nQo`0Qool0003oaol0olgo0?lc0?oo0?n8olko0?l0ocko
oooookgo0?o<o`3o_Ol0o`0Voonno`3o0?go0_l000001?o<o`3o__l0ol_o0?o<o`02o`2:o`03o`3o
Lol0R_oookX000Co`_l00ol0R_l02Ooo^P3o02Koo`0cool0<ooo0?gookko0?l0R_ooc?l0o`0Vo`02
o`0co`04o`2:oon3o`3oooooo`2:o`Co_Ol000_o00Woo`_o0?l;o`3o0?n8o`_o0?mSo`3o0?mcoc<0
ooooB@3oooooo`3mo`02o`0000;o0?go00Oo08Woo`1[oonmo`3o06_oo`3oHOmEo`3ooooo00;o0000
00Ko/ol0o`3oHOl0of7o0?mQolco0?l0of42o`000006o`09ool0of7oooooo`_o0?l0ROoooooo0_l0
0002ooooo`04o`000?ooooooooooooooo`;o_Ol000GooooooiWo0?ooooooooooo`00000Aooooo`03
o`3obooooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Eooooo`;o
<ol00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0?oHoooooooo
ool01?ooool3o`000004o`3gool0oOoo0?gooeGo00;o000000Coooooo`000?l0Sooo0?o51Ooo?P00
1Ol0ooOo0?mQo`3mool0J?oo0?nQ00;o000000?o0?gooom20?oo@P000ooo@P02o`000005o`3oHOl0
R_ooc?l0olco0?nmo`000_oo:@001?m8o`3oobT0oolY0?oo:@02o`000005o`3Dool06Ooo01Woo`0I
oooMo`000_l06ol00onAo`3o0?n5oonj0003o`02o`03olco0?l0003o0?n800;ooooo00Oo0?lnoloo
0?nko`3o^ol0okgo0?nno`3oood000?o00Wo0_l00002o`2:o`07olco0?l0R_oo08[oo`3oLon3o`3o
08[ooonj0003o`2:o`06o`3oDol09_ooc?l0okgo0?l0okKo02Ko1?o2o`002?n3o`3o02Koooooool0
R_oo0;?oo`0cool0ohSo08[o0onmo`002Ol02Oood?l0oooooooooooodOl0o`3oR?l0og?o05gooc<0
o`02ooooo`08olgo0?o<o`3o0000o`000?l0oOooodT0o`3oHOnmo`02ooooo`;o_Ol00_l000001Ol0
R_oo0?mQo`3oHOnco`3oc?l000;o000000Ko0?goo`3oHOl;o`3oooooo`29oonmo`02o`0000;ooooo
00Go0000oooooonmo`3ooooooiWo0004ooooo`03o`000?oooooooooo01;ooooo00?o0?o;o`000?oo
ool03?ooool00ol0003oooooooooo`1kooooo`00LOooool3oc?o00Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0>ooooo`03o`3of?oooooooooo00;ooooo00Ko0000oooooooooooo
EOl0ooooool0oOl7ooln0004o`_o0?l0oOoo08Wooc?o00;o0?mQ00Go0?goo`000?l0003o00Wookgo
0006oom20005o`3oR_oo:@3oobT0olco0?nmo`001Ooo:@02o`000003o`0Vool06ooo01_o00?o0000
00koO_l0o`09ool0ohGo05gooonj0?o<o`3o00Woo`3oXOo7o`3o0?lUoonj0?o=o`3o0?n8o`3o?P;o
08[o00Ko_Ol0ok_o0?l0od3o02Kookko0?l02Ol2o`00000;o`3mool0R_ooc?l0olco0?nno`3ooooo
o`3oLooo^P3oooooobCo0?n3o`000_o7o`03ol;o000@oonj0?nmo`3o0?loo`3o?ol0oOoo__l0o`0c
ooo<o`3o03?oo`3oe?nmo`3o08[ookgo0?l0R_oo_Ol0o`3oR0;o2ol001?oaol0o`09ool0R_oo08[o
o`3oR?nmo`3o0000okgo0?l0DoooodT0oeko0?l0003ocOl0o`3moooooooo0?goo`3oLol;o`3o0?nQ
00;o_Ol000Oo08[oo`3oHOl0003o0000ok?o0?o<o`3o0?go00;o0?mQ00Koooooo`000?l0003o0?go
o`3oHOl;o`02ooooo`03o`29oonmo`3o0=Co00;ooooo00Co0000oooooonmo`3o_Ol00oooool00onI
o`3oooooo`00000Cooooo`03o`3obooooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Gooooo`;o<ol000?oooooo`000?ooool01_ooool00ol0003oooooooooo`0Aoooo
o`03o`3of?oooooooooo00Kooooo00?o0000o`3gool0TOl00_mEo`001Ooooooo0?goo`3mool0Sooo
000000;o0?nQ0_lco`000ol;o`3o0?ogo`3om`05ooln00;o000000Co0?ndo`3mool0oOoo0?go0_l0
0005oom200;oobT000CoB?l0oolY0?oo:@3o0?go0_oo:@02o`000003o`0Iool09_oo01_o00?o0000
00coTOl0o`3oQOl00_oo00;oo`09oolc0?oo0?nQolgo0?l0R_oo0?n8o`2:ool0och2o`2:o`04okgo
0?l0R_oo^ol0okko00;o00Wo00Ko08[oo`3oO_l0003o0000oonj0?o<o`02olWo0004oonj0?l0og?o
0?mQoh?o00;oaol00_l0okH02?oo^P3o0?mCoooooonmo`3oon80o`0Vooo<o`3o0?go0_l0<ol4ol;o
0009o`0coonmo`3o08[oo`1Cool0oOooaol0o`_o0?l02Oood?l000;o000000GodOl0o`3oR?mNo`3o
0?mco`3mo`02oc<0o`07olgo0?l0003o0000o`000?l;o`3oodT0o`3oH@03okgo0004o`2:oooooooo
0000o`0000;o0?mQ00Oo0?goo`000?nco`3o00Woo`3oXOl0oOoo0?mQ00;ooooo00?o_Ol0o`29ool0
e?l00oooool01Ol0003o_Ol0ooooooooooooVOl000?ooooo00?o0000ooooooooool05?ooool00ol0
ol_oooooooooo`0;ooooo`03o`000?oooooooooo07_ooooo001dooooo`;o<ol01oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0?oHooooooooool00_ooool02?l0003o
oooooeGo0?oooooo0?Ooooooool0oOoo00000_l0oOl2ooooo`03o`_o0?oo?P3ooch000Gooch000Ko
_Ol0o`3mool0003o_Ol0olgo0?l09_l2o`0000?oobT000?ood80oolY0?oo:@000ooo:@001_l06Ooo
0000o`000?l06ooo0?mQo`0Ko`;o00;o0ol000001Ol02Ooo0?n5o`2:ool0R_oookX000;oc?l000Oo
0?nQolOo0?l0R_oo08[oo`3oR?l0ockocOl000;ooooo00?o_Ol0o`3o@?nko`000ol02Ol03_l0ogko
0?mcolko0?l0oOooc?l0ooooooo9o`3o__l0o`3oLooo^P3o0?nfolOo0?n3o`3o0?mQ0_o<o`002?l0
oe?o0;?ool;o0?o2o`3o9?l0o`2:ool0oOooc?l00ol0<ol04_nmo`3o2ol0o`2:ool0R_oo0?goo`3o
R?l0_Ooo2ol0olOo0?l0Dooo00Woo`3oHOl0odSo0?n8om7o0?nmo`3o0?mcoom900;o000000Ko0?go
o`000?l0003oooooo`29ool0og<2okgo00?o0?mQ00OoEOl0o`3mool0Jooo06_ook?o0?l0oOooc?l0
00;ooooo00[o0?nQooooool0oOoo0?goo`3oHOoooooo0?goo`29ool0QOoo0=Co0_ooool00onmo`3o
0000ooooo`05ooooo`03oiWo0?l0003ooooo01;ooooo00?o0?o;ooooooooool01oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo05Wooooo0olco`06ooooo`03o`000?oooooooooo013o
oooo00?o0?oHooooooooool01oooool00ol0003o097ooeGo0003ooooo`04o`3mool0Sooo0000o`3m
o`;o<ol000Go0?nQo`_o0?l0ROoo0?goo`1Xo`02o`3oH@03okgo0?l0oj7o0?go00Gooch000?o0?mc
o`000?l000000_l00003oolY0004oom20?oo:@3oobT0oom200;oobT00_l000001Ol0of7o01_oo`0K
ool06ooo_Ol000?o000000CoTOl0o`2:oonmo`3oc?l00_l0R_l08oo7o`3o0?nQolgo0?l0ohSo0?ln
ooooooo>o`3o__l0okgo0?l0od3o0?n8ok_o0?l0HOoo_Ol0o`3oO_oooooo0?mco`3mooo9o`3oc?l0
okko0?l0okKookX0o`3oLooo^P3oPol0o`3oVOoooooo0;?oo`0Voooo^P3o0?n[o`3oDonmo`3ooooo
00;o08[o00?o0?goo`3o?oo<o`000ol0<ol05Ol0R_oo`_l0ol;o0?oQo`3o05?oolOo0?oooooo0?mQ
o`09ool0odSod?l0ooooool0003o0?n8okgo0?l0og?o0?gooooooom_o`3o0000o`29o`02o`000005
o`3oR?ooB@3o0?mcokgo0?l0R_l00ol0of401ol0oOoo0?mQo`2:ooo<o`3o0?gooooooonco`000_l0
oj402?l;o`3o0?goo`3oHOnmo`3oooooo`29ool0e?oooooo0_nmo`000ooooooo0000ooooo`02oooo
o`04oiWo0?ooooooooooo`0001Kooooo00?o0?o;ooooooooool02oooool00ol0003oooooooooo`1k
ooooo`00M_ooool3oc?o00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=oooo
o`03o`3of?oooooooooo00?ooooo0_l000001_mEo`3o0?Oooooooooooooo0?goo`0000;ooooo0_l0
oOl00ol;o`3o08Woo`3oX@02o`0000;o0?mQ00?o0000ooln0?oo?P001?oo?P02oolY0005olOo0?o<
o`3oobT0oolY0?l0oOl00_oo:@000onmo`3ood80oom20003o`000003o`3oHOl00_oo0=Co00;o08[o
013o00Wooi7o0?l0ohGofol0o`1Iool0R_oookX0olco0?l0of7oc?l0o`3oXOl0obGookX0o`3oR?oo
oooo<`3o0_o=o`003onmo`3o00Woo`09oonko`3o__l0o`3oO_nmo`3oc?l0o`3oLonmo`3oc?l0o`3m
ool0okKo04coo`3oL`02okko0006oonj0?n3o`3oc?l0o`3oHOoooooo05go0_l0oe<2o`000006okgo
0?l0oOoo03?oolco0?l09_oooooo0_l0<ol02Ol0R_oo0?goo`3oR?n3o`3o0000olOo0?l0_Ooo00Wo
o`2mo`02o`000008of?o0?nmo`3oooooo`1CooooB@3o0000ooooool0oOl2o`0000;o_Ol000So0?mQ
o`000?l0003o_Ol0o`3oHOoooooo_Ol0o`3mo`;o0?mQ01?o/ol0o`3mool0Joooc?l0o`3oXOoooooo
2ol0o`3mool0003o0?gooooooonmo`3o08Woo`3Dool0QOoooooookgo0?oooooo000000Kooooo00?o
VOl0o`000?ooool04oooool00ol0ol_oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0F_ooool01?l0003ooooooc?o0?lco`04ooooo`03o`000?oooooooooo013ooooo
00?o0?oHooooooooool01_ooool01?l0mooo0000oeGo0?mEo`03ooooo`04o`2?ool0oOoo0000o`3o
m`?o0?go00?o2ol0o`1Xool0oOl00_l000002Ol0of7o_Ol0o`3oXOl0E_oo0?goolgo0?nmo`3o0=Co
o`000003ooln00;oobT000?o0?goo`_o0?oo:@001?oo:@000ol06Ooood80o`000002o`00000Fo`3D
ool00_oo00;oo`02oonmo`3o00Wooi7o0?l0GOoo08[oolco0?nmo`3oc?l0olOo0?oooooo0?nQo`3o
R?l0ockocOl0oooooonno`3oc?l0okgo00;o00Wo01Ko__l0ok_o0?l0ogko3ol0okgo0?l0og?obOl0
olco0?l0oOoo0?nfoonj0?o7o`3o0?mcoonj0?ooooooPol0olco0?oooooo02Kooonj0?oohP3o_Ol0
0_l0R_l2o`00000Ao`3moonmo`3o03?oo`0cool0oOoo08[oo`0cool0R_oo0?nHo`3mooo7o`3o0;go
o`3oHOl;o`3o00Woooooooo@o`000_l00002okgo000:oeko0?l0og?o0000o`000?l0ohSo0?gookgo
0?l0003oodT0ooooo`;o000000Wo0?mQoloo0?l0of7oEOl0o`3moooooooo06_oo`3mooo<o`000_oo
ool01?nco`3o2ol0o`3mooooool2o`3mo`;ooooo00?o08Wookgo0?ooool00_ooool01Ol0003ooooo
ooooooooooooVOl000;ooooo00?o0000ooooooooool05?ooool00ol0003o0?o;ooooo`0;ooooo`03
o`000?oooooooooo07_ooooo001iooooo`;o<ol00_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00gooooo00?o0?oHooooooooool00oooool3o`000005oeGo0?ooooooooooo`000?oo
ool00olco`001?l;o`3o0?goo`3mool0oOl2o`000006ooooool0of7ooooookgo0?o=o`3o02Ko0ooo
:@000ol0og?oobT0oolY0004oolY0003ooln0?l0003o_Ol000;o00000ol00_l02?l0003o0=Coo`3D
ool08Ooo00Wooi7o0?l;o`3o0?n50_ooool03?l0GOoo08[oolco0?l0FOooc?l0o`3oXOl02Ooo0?ln
o`3oR?oooooo__l0ooom00;o00Wo00Sobol0ooooool09_oo^ol0o`3o]_l0GOooc?l0o`3oL`;oc?l0
00Ko_Ol0o`3mool0003o0000oooooooo^P02okko0003oh?o0?l;o`3o_Ol000?o_Ol00_l000001?l0
<ooo0?goolco0?l09_l2o`3mo`0;ooooool0R_oo03?oo`0cooooooooPol0olOo0?l;o`3o0?goo`09
oooQo`000_l000002_l0_Ooo_Ol0o`2:ool0Dooo0000o`29ool0oOoo0?n8okgo0?l00002o`3oH@05
o`_o0?l0003o0000okgo0?l0of400_l000001Ol0oOoo0?nQoooooonco`3o0?go00;ooooo00Oo0?nQ
o`_o0?l0Jooo0?goo`1Xool0oOoo_Ol000;ooooo00Co08Wookgo0?nmo`3o08Go0_ooool00ol0003o
ooooooooo`03ooooo`03oiWo0?l0003ooooo01?ooooo00?o0?o;ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo05[ooooo00Co0000oooooooooooooooo0_lco`02oooo
o`03o`000?oooooooooo00oooooo00?o0?oHooooooooool01_ooool01ol0mooo097oo`000?l0003o
oooooeGo0?l0ooL00_lco`000ol0003oooooooooo`02o`1Xo`04o`_o0?l0oOoo0?goo`3mo`;o0000
00?ooooookgo0?l0oj400_o=o`000ol0e?oo_Ol0o`2:o`02o`0000;oobT000?o08[oo`3oHOoo:@00
0ooo:@000ooo?P3o_Ol0o`000002o`0Ko`0Go`3Dool00_oo0?mQo`000?nbo`3o00Woo`_o0?nmo`3o
bol0oi7o0?l0GOoo08[oolco0?l0FOooc?l0olOo0?l02Ooo0?lno`3oXOl0003o__l0olgo0?o;o`00
0_l02Ol01Ol0okKo0?n8okko0?l0ogko^ol000;obOl000So0?mcokgo0?o<o`3ooooooonj0?o7o`3o
ooooo`3oL`;o000000OoPol0o`3oHOl09_ooon80oonj0?nmo`3o08[o00;o_Ol00_l000001Ol0oOoo
03?oo`3mool0ocoo0?go00;o08[o0_l0<ol02?o7o`3o05?oo`3oHOmSo`3o2ol0o`09ool0R_ood?l0
0_l000003?oAo`3o_Ol0ooooool0og?o0000okgo0?l0oOoo_Ol0oc<0ool0003oodT0o`3oH@;o0000
00Go_Ol0o`3oHOl0003o0000o`3mo`02ooooo`09o`3mooooooooc?l0o`_o0?nco`3o00Woo`3moonm
o`3o0?go00;ooooo0_nmo`05ooooo`04o`000?oooooooooooiWo00;ooooo00?o0000ooooooooool0
5?ooool00ol0003o0?o;ooooo`0;ooooo`03o`000?oooooooooo07_ooooo001kooooo`?o<ol03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`3of?oooooooooo00Cooooo0_l000000ooooooo0000oeGo
0003oeGo0007o`3omol0Soooooooo`_o0?l0ROoo06Soo`2Do`02o`3mo`04o`3oHOoooooocOl0o`0V
o`;oobT000Go0?n8o`3moooo:@3oobT0o`29o`02oolY0004o`0Iool0R_oo01_oo`0Ko`;ooch00_l0
0002o`3mo`;oob`000So0000o`3Dool0e?oo0=Cooi7o0?l0ohGo0=Cookgo00Oo0=Co00Co0?nQo`3D
ool0ohSo__l00_l02Ol02oo<o`3o_Ol0olgo0?l02Ooo02Kookko0?nko`3oc?l0olWo0?l0og?oc?l0
00;oaol000Go_Ol0o`000?l0003o0?gooonj0004okgo000@o`1Mool0R_oo08[oo`0cool09_oo0?mC
okko0?l0oOooc?l0o`0Vool0ocoo0?n[o`2:oon3o`3o08[oo`3oV0;o03?o0ol000001?l02OooHol0
o`3oR?o@o`02okgo0004om7o0?l0003o0?goo`3mo`?o0?mQ00So0000oc<0ool0R_oo08[oo`_o0?l0
og?o0?mQokgo00;o000000Go0?gooeGo0?oooooo0?gook?o0002ooooo`08o`3oXOl0003o0000o`3o
XOoooooo_Ol0o`3mool0J?l2okgo00;o06So00Coooooo`25oooooooo00001_ooool00ol0003ooooo
ooooo`0Booooo`03o`3obooooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Jooooo`03o`000?oooooooooo00?ooooo0olco`0@ooooo`03o`3of?oooooooooo00Kooooo
00Oo0?Ooo`2Aoooooooo0000o`3omolco`3o000000CoEOl00_l0J?l01Ooooooo2ol0o`29oooooooo
000000;o0?go00Wo0?mQo`1Fooo=o`3ocOl0o`0Vool0e?oo_Ol0o`3mooooool00_oo:@000ol0003o
obT0oolY0003oolY0004o`_o0?l0003o0000ooln00;o00000_l00_l01?mVo`3o0=Coo`3oHOl00003
o`3Do`03oi7o0?oo;03oob`000;oob`00_l0e?l01_o7o`3o0=Coo`3Dool0oj7o0?nfol_o00;o00Wo
00Goc?l0okgo0?l02Ooo0?n8okko0002olWo0004ok_o0?o<o`3o0?mcolco00;oaol000CookX0o`3m
oooo^P3o0?mc0_l000001?nno`3oPol0okgo0?nmo`02o`2:o`;ooooo00Go0>koo`0Voonno`3o0?go
olco0002o`3mo`05o`3o?ol0R_ooPol0o`3mooo7o`000_l0<ol02?oooooo0000o`000?l02Ooo0?mQ
o`2:ool0ohSo08Wo0ol0ohP00ol0003o0?goo`3mo`03o`3oH@07o`000?ooB@3o0000o`3mool0og?o
_Ol0o`3oX@02o`000006oeGo0?l0oOooooooo`3moooooooo2ol00_l0oj402?nco`3o0000o`3mool0
J?oo0?gookgo0?l0e?oo08Wo1Oooool01?l0003ooooooooooonIo`02ooooo`03o`000?oooooooooo
01Cooooo00?o0000o`3oboooool02oooool00ol0003oooooooooo`1kooooo`00OOooool00ol0003o
<ol0oc?o000;ooooo`03o`000?oooooooooo00cooooo00?o0?oHooooooooool00oooool01?l0mooo
ooooo`000?ooool2o`000003oc?o0?l0003o0?go00GoEOl000?o09Coo`000?l000000ol0oOl2oolY
0005oooooonmo`3oobT0oolY0?l0oOl00_oo:@002Ol06Ooo0000o`000?l06ooo02Koo`02ool0003o
_Ol0o`3oR003ool/0005o`3mool0of7o0=Coo`000?l0ok@00_l000002ooooooofol0okgo0?l;o`3o
okX0o`1Mool0R_ooc?l0o`000?o7o`3o0?nQ00?o00Wo2Ol0e?l01_o<o`3o0=Coo`3oLol0e?oookX0
olco00Go_Ol000Go0?goo`000?ooooooPol0o`2:o`02o`0co`09oonj0?l09_oooooookko0?l0oOoo
02Koo`2fool0oOoo0?lo00;o08[o00Coooooo`3oV?o7o`3o0?oD0_l000002OmSo`3o00Woooooool0
ohSo_Ol0o`3oB?l0ohSo0000oom90002o`3oH@0EoooooolF0?oo0?goo`2:ool0003o<`3oo`3mool0
of7o0?mcoloo0?nmo`3o0?mQooooool0oOooEOl0o`000?l0oOoo/ol0ooooool0oj7ooooo00?o0000
00So_Ol0o`3mool0of7o0?goo`1iool0e?oo08Woooooo`Co06So00?o0000o`1Xooooool00_ooool0
0ol0003oVOl0ooooo`0Dooooo`03o`3obooooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Gooooo00?o0000oc?o0?lco`003_ooool0
0ol0omSoooooooooo`04ooooo`;o0?Oo0_l000001?l0ooOo<ol0o`000?l0Sol2o`000003ooooool0
003o06So00GoEOl000Co0000o`1Fool0oOoooooo0ol0oOl2o`3Do`05oooooooo:@3oobT0oolY0?l0
7?l00_oo:@000ol06OooobT0oolY0003o`0Ko`03o`_o0?l00_oo_Ol000;o000000?o0?goool/0?oo
;0000ooo;0002ol0003oob`0o`000?l0003o2ol0o`1Moooooooo08[oolco0?l0okKoaol000;o05Wo
00?o0?n8o`3oXOl02Ol00ol0e?l01?nmo`3o0=Coo`3Doonno`03o`3Do`;o^ol000Oo0?mcoooooooo
^P3oc?l0okgo0?oo^P3o0?mc00?o_Ol001KoPol0okko0?l0R_oookX0okgo0?l0/oooooooo`0cool0
9_ooc?l0o`3mooo<o`3o0000o`3oR?oooooo08[oo`3mooo7o`3oHol0o`3oHOl0Dooo03?o0_l00000
0ol02Ooo0?mQokgo0002o`3oR0;o_Ol000Wo0000o`3mool0og?o0?mQoooooolF0?oo08[oo`000?oo
B@000ol0of401?l0og?o_Ol0o`000?l00002o`3mo`03ooooool0oOoo2ol000;o0?nQ00[o0?gook?o
0?l0003o0?gookgo0?l0of7o0?goo`3Doooooooo08Wo1?l0J?l01_l0003oooooooooooooooooVOl0
o`0001Oooooo00?o0000ooooool0ol/02oooool00ol0003oooooooooo`1kooooo`00OOooool00ol0
003oooooooooo`03oc?o00Sooooo00?o0000ooooooooool02oooool00ol0omSoooooooooo`03oooo
o`03o`3goooooooooooo00;o000000[o<ol0ooooool0003o06Soo`3mool0J?oo2ol0ooooool0ROoo
00000omEo`03oolY0003o`3moooo:@3oobT000CoobT000?o0?goo`000?l000000_l0og<2o`02o`06
ooooool0003o_Ol0ool/0?nno`3oaol00_l0oOl2o`00000>o`3mool0003o0000o`000?l0okCofol0
okgo0?oooooookX0o`1Mool0okKo08[oolOo0?l0okH3o`09o`0=o`3o@?l0of7o0?mQolco0?nmo`3o
00WoolWo0?l09_oo__l0olgo0?o<o`3o^ol0o`3oL`03okgo00Wo0=Co00?o03?oo`3Doonmo`000_l0
e?l06Ol09_ooooooo`3mooo<o`3o0?goo`2fool0R_oo0?loo`2:ool0oiSoaol0o`3oHOl0oOoo2ol0
of?o0?l0<ooo00Woo`2:ool0ohSod?l0o`3oHOl0003o0?gooom90?l0GOl00_l000003Ooooooo08[o
olOo0?l0003o0?mQoc<0ool;o`3o__l0o`3oLonmo`3o0?mQo`2mool0oOl00_l000001ol0oOoo/ol0
o`_o0?l0oj7o0?goooooool02Ol00onmo`001_l0of7o0?goooooool0e?oo08Woo`0000?ooooo00?o
08Goooooool000000ol0J?l00ol0003o06Soo`1Xo`0Dooooo`03o`3obooooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_lco`0;ooooo`03o`3of?oooooooooo00Cooooo00?o0?Ooooooooooool00olc
o`000ooooooo0000ooooo`02o`1Xo`06o`000?l0U?ooooooo`3moooooooo2ol00_l00006oeGo0006
o`3Dool0oOooobT0oolY0?o<o`3o01co0_oo:@000ol06OooobT0oolY0002o`0000;o0?mc0_l00_l0
0ol0003o_Ol0o`000002ool/00?o0?go0_l000003?oMo`3o0000o`000?l0003o0?nfo`1Moooo^P3o
0?nfo`2:ool0ockoaol0olco00;o00Wo00[o0?nQo`3o@?lc0?ooc?l0o`09oonmo`3o0?mno`3oR?nn
o`3oc_l00_o7o`02olco0003o`3oLol0e?oo0=Co00?o0=Co00Co0?mco`3Dool0e?oo0=Co0_l0R_l2
o`3Do`0:okgo0?l0<ooo03?oooooool09_ooc?l0o`3moooooooo0?n8o`0000;o08[o00Woaol0of?o
0?l0003o0?mQo`1Cool0/ooo2ol0o`0cool02Ol00_nmo`001ol0ohSo_Ol0o`3oHOl0003o0?gooooo
ool0og<00_l000002Ol0R_oo2ol0o`000?ooB@3o<`3oo`3oXOl0of7o0?mcokgo0002o`2mo`04o`3m
ool0003o0000o`_o00;o0?nQ00_o0?gookgo0?l02Ooo/ol0okgo0?oooooo0?mQo`3Dool0oOoo0000
o`29o`04ooooo`03o`1Xool0003o06So00;o06So00?o0000ooooooooool05Oooool00ol0003ooooo
o`3ob`0;ooooo`03o`000?oooooooooo07_ooooo001mooooo`03o`000?oooooooooo00?ooooo0_lc
o`06ooooo`03o`000?oooooooooo00_ooooo00?o0?oHooooooooool00_ooool01?l0mooooooooc?o
0?lco`02o`00000;ooooool0J?oo0000o`2?ool0003o0?goo`_o0?l0ROoo0000o`1Fooo=o`000_oo
:@02o`0Vo`;oobT000Co0000oolY0?oo:@3o01Wo0ol06ol2o`000003o`02oonmo`3o0?mc00;o0?mc
0_l00004ool/0006o`09ool0003o0000o`2:ool0ohGo00001Ol0oOl01?oo^P3o05goo`000?l0R_lZ
o`1Yo`;o00001ol0e?l01?l02Ooo0?n8o`3oHOl0of43o`00000=om7o0?l0GOoo0000o`000?l0R_oo
aol0o`3oHOl0003o0?goo`_o0?lc0?oo0?nQo`3oL`02o`00000:ooooool0oOoo0000o`000?l0oOoo
2ol0ok?o0?l0oOooooooo`0000;o_Ol000So0?goolco0?oooooo0?mQo`3mool0e?oo07Woo`29o`;o
00000_ooool00ol0QOoo0000ooooo`02ooooo`03o`000?ooooooVOl000Ko06So3oooool00ol0ol_o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_lco`08ooooo`03o`3of?oooooooooo00Co
oooo00Co0?Oooooooolco`3o<ol00_ooool01?l0003o08ooo`000?l0J?l2ooooo`06o`000?oooooo
ooooo`1Fool0oOoo2ol00_ooool3olgo0003o`3mool0of7o0=Co00;oobT000?oEOl0o`0Ioooo:@00
1?oo:@000ol06ooo0000o`000002o`000003o`0Qool0og?o0?mc00?o000000Goooooo`3mool02Ooo
0?goool/0002o`0000;o0?go00So0000ool/0?oo;03oob`0oonj0?oooooo0?lno`2:o`;o00Wo00co
0?n8o`3o@?l02Ooo0?nQolWo0?o<o`3o0000okgo0?l0ohSo02Kookko0?o7o`02o`000004okgo0?o<
o`3o0?mcok_o00;ookX000Go0000ooooool0og?o02Koo`2:o`0Ao`1Yo`;o00001?l0e?l01Ol;o`3o
_Ol0okgo0?nmo`3o0?n800;o0?mQ0ol000001?l0ROoo0?mco`000?l00002o`3oH@03o`000?ooB@3o
0?nQ00;o<`3o00Go_Ol0o`000?l0003o0?goo`2mo`02o`000003o`3oXOo<o`3o0?go00?o_Ol000Wo
/ol0olco0?ooooooooooo`3oHOl0oOooooooo`29ool000001?ooool01Ol0003ooooooooooonIo`3o
000000Ko06So4Oooool01?l0003oooooooooool0ol/:ooooo`03o`000?oooooooooo07_ooooo001m
ooooo`03o`000?oooooooooo00Gooooo0olco`03ooooo`03o`000?oooooooooo00[ooooo00?o0?oH
ooooooooool00_ooool00ol0mooo<ol0oc?o0002ooooo`;o000000?o06Soo`000?ooool00_l00000
0ol;o`3o08Woo`00000/o`1Yo`08o`3mool;o`3o2ol0o`3oR?l0oj7oooooo`09ooo<o`04okgo00;o
00000oo<o`002Ol0og?o^ol0ok_o0?o>o`3o_Ol0oonj0?l0og?ocol0o`2:o`02o`0co`07o`1Mool0
003oPol0okgo0?oooooookX0okko0002o`0Vo`05o`3moonno`3o08[oo`3oDoooool00_l000001Ol0
of7o0?loo`3oR?l;o`3o0?n800?o0?mQ00Co0?n8o`3Dool0003o0?go0_l00002o`3Do`03o`2:ool0
og?o0=Co00;o0=Co00Co0000o`3oXOl;o`3o__l00_lc0?l2o`0000;ooooo00Ko0?goo`3oCOl0oOoo
0?nQok?o0?ooool2okgo0007o`09oooooooo0?goo`000?o<o`3o0?mQo`3Do`02o`000004o`29ool0
003o0000o`0000;ooooo00Oo08Goo`000?ooooooooooo`000?ooooooVOl000Kooooo1_l0J?l9oooo
o`03o`3obooooooooooo00Cooooo00?o0000ooooooooool00ol0D?l2ooooo`03o`000?oooooooooo
05[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`?o<ol01Oooool00ol0
omSoooooooooo`03ooooo`03o`3goolco`3o<ol000?ooooo0ol0J?l01?l0003oooooo`2Dool00003
o`1Fo`03o`000?l;o`3ooooo00?ocOl000?oooooo`000?l0e?l00_oo:@000oo<o`3o_Ol0oolY0003
oolY0006o`000?mEo`3o0000o`000?l00_oo0?mQ0_l0R_l00onno`3o0000o`000007ool/0003oooo
ool0of7o0?n500?o06Wo00?o0000o`1Yool0JOl04_l0JOl2o`0000_o06Wo00Oo05goobCo0?n3o`3o
03?ookgo0?oooooo0?mQ00;o__l000So0;?oo`0Vool0oOoo0;Koo`2:oomSo`3o08[oooooo`;o0000
00?o0?n8o`3oe?l0Dol00_nmo`03o`3oH@04o`3oR?l0<ooo0000o`3mo`;o000000?o0=Coo`2:ool0
og<00_l0e?l01ooooooo0000oom90?ooooooc_l0o`3oHOlc0?l00_l000001_oooooo2ol0o`3mool0
odgo08[oo`3mo`;o_Ol000Soc?l0o`3mool0003o/ol0olco0?oooooo0?mQo`29o`;o000000?o08Wo
o`000?l000000oooool01?l0003ooooooiWo0?l00006ooooo`Go06So3?ooool01?l0003ooooooooo
ool0ol/3ooooo`?o053o1?ooool00ol0003oooooooooo`1kooooo`00OOooool00ol0003ooooooooo
o`08ooooo`;o<ol000?oooooo`000?ooool02oooool01_l0omSooooooooooolco`3o0?Oooc?o00;o
oooo0_l0J?l2o`000004ooooool0003oooooo`1Fo`;o00000ooo:@001?ooooooobT0oolY0?l00002
oolY0004olco0?l0e?oo_Ol0o`3oR0;o000000Goooooo`3oXOl0003o0000o`3mo`03oeGo00;o0000
00Go__l0okgo0?l0og?o0?mco`09o`02o`3mo`07o`3Dool0of7o0?n5omgo0?l09_oo2ol0o`000002
o`_o0006oonj0?l02Ooo00Wool_o0?nbo`3oaol01Ol0oOl2okgo0006oooooonmo`3oaol0o`3oR?l0
9_oo__l00_o<o`002?l0ohSo0?mcoonj0?oo^P3o^ol0oonj0?nmo`3o0?mc0_l000001Oo?o`3o05go
o`3mool0oOoo9?l000?o_Ol000_o__l0o`0Vool09_oo0?goo`2:ool0ohSo__l0o`3oDoo7o`3o08[o
o`3oR004o`3oH@09o`3oI?nmo`3o00Woo`3oR?l0003o0?goo`29ool0<oooodT000;o08[o00Ko0?mQ
o`3oLoo7o`3o0000o`3mool00005o`3Do`0>oc<0ool0og?o0=Coo`3Dool0oOoo0?m=o`3moomEo`3o
0?nQok?o0?l0e?ooooooo`09ool0oOl3ooooo`04o`3oHOl0e?oo0000o`0000;o08Wo00?o0000oooo
ool000000ol00002ooooo`03o`000?ooooooVOl000cooooo1_l0J?l4ooooo`03o`3obooooooooooo
00;ooooo1?l0D?l00ooooooo0000o`000002ooooo`03o`000?oooooooooo05[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`07ooooo`;o<ol00_ooool00ol0omSoooooooooo`02oooo
o`03oc?o0?l0mooo<ol000?ooooo0_l0J?l3ooooo`05o`000?l0U?oo05Koo`000?ooool00ol00000
0ol0oOoocOl0olgo0003o`0000;oobT000?oc?l0oolY0?oo:@000ooo:@001Ol0oOoo0000o`000?l0
of7o000001;o06Wo00SobOl0o`0VoooKo`3o2ol0o`000?nmo`3o05goo`09o`Ko0?go00?oooooo`1Q
ool0oj401?nmo`000ol09_oo__l0olco0003olco0006oonj0?l0og?oc_l0oonj0?nko`3o3ol00_l0
R_l3o`0000;o03?o0onmo`000ol0k_oo0?mQokko0002o`0Vo`08o`3mool0R_ooHol0olOo0?l0R_oo
0?n8o`3oHOooool2okgo00?o0?mQ00Ko_Ol0o`09ool0ohSo08Woo`000?l0oOl2o`0co`;o08[o00Ko
0?mQo`3oLol0oj7o2ol0o`3DooooB@05o`3Do`04o`3oLol0e?oo2ol0o`3Do`;o0?go00Go0?m=okgo
0?ooooooooooo`3mo`02o`29o`04ok?o0?l0ROoo08Woo`3oH@Co00000_ooool2o`000005ooooool0
003oooooooooool000002oooool6o`1Xo`Kooooo00Go0000oooooooooooo053oo`3ob`02o`1@o`03
ooooool0003o000000Cooooo00?o0000ooooooooool0Noooool007gooooo00?o0000ooooooooool0
2_ooool3oc?o00[ooooo00Go0?oHoooooolco`3o<ol0o`3go`02ooooo`;o06So0oooool2o`0000;o
05Ko00Go0000oolY0?oo:@3o0?goo`29o`02oolY0004oooooooo:@3oobT0olco00;o0=Co00?o0?nQ
okgo0?l0oOl01?oEo`000ol0oj7o08Woo`000002o`3mo`;o08[o00?o__l0oeGo0?nmo`000_mEo`03
o`3oL`0=o`3Dool0ohGo08[ookgo0?l0Doooooooom_o0?l0003obol0o`09oonmo`3o05goooooo`05
okgo0003olco0?l0oj7o0?go00Co0?go00_o0?n8o`0Vooo<o`3o05Woolco0?l0ohSo0?mcoooooooo
^P3o05gook_o0002o`0co`;o000000co04coo`3mooo?o`3o3ol0okgo0?n3o`3ooooooonj0?nno`3o
02Koo`29ool0R_l3o`3oR00;olOo0?l0of7o0?mQo`3oHOnmo`3o08Woo`_o0?l0ROoo_Ol0o`29ool0
ohP00_l000001?oooooo_Ol0o`2:ooooB@02o`0co`04ooooooo7o`3o0?mcooooo`;o00000_l;o`00
1ooooooo_Ol0olgo0?oooooo0?mco`3mool;o`000_l0oOl01_l0odgo_Ol0okgo0?nco`3oooooo`3D
o`Ko08Wo00Co0?mQolco0?l0oOoooooo1?l000000ooooooo0000o`000002o`0000;ooooo00?oVOl0
ooooooooool04?ooool4o`1Xo`03o`3obol0D?oo053o00;o053o00?oooooo`000?ooool01_ooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool2
oc?o00?ooooo0_lco`000ol0moooooooooooo`03o`1Xo`Cooooo0_l0E_l4o`000006ooooool0003o
0000olgo0?l0oOoo08Wo0ooo:@001?l0003oobT0oolY0?ooool2oolY000>okgo0?l0oOooooooo`3o
XOl0003o_Ol0o`3oHOoohP3o08Woo`3mool0R_ooeOl0olOo0?l0R_l2oeGo0004okgo0?l0003oEOl0
oeGo00?o0?mc00Co0?n5o`2:oonmo`3ofol00_o;o`000onno`3o0000o`09o`02ooooo`03olOo0?l0
od3o08[o00;oc?l01Ol0oOl01Onmo`3o0?n8o`0Voonno`3o05Wo00;oc?l000[ookX0olgo0?l0og?o
okX0oooR0?l0R_oo^ol0ooooool0og?o0?go0_l00002ooooo`0=okgo0?oo^P3o0?gookgo0?nno`3o
02Koolco0?l09_oo08[oo`3oR?o7o`3o08Woo`2:o`02okgo00?o0?mQ00Ko0?loo`_o0?nmo`3o09Ko
o`09ool0ohP2o`000003om3o0?o?o`3o08[o00;o03?o01;oooooo`3oLol0003o0?nQo`3mooooB@3o
Kol0oooooonmo`3o0?mQo`3moonmo`3o0?mco`3oXOoooooo0?gookgo0?l0odd4o`29o`?o0=Co00Ko
/ol0o`3Doooooooo0?mQo`000?l0oOl3o`0000;ooooo00Go0000ooooool0003o0000oiWo000Aoooo
o`Co06So1Ol0D?l00ooooooo0?o;ooooo`08ooooo`03o`000?oooooooooo07_ooooo001mooooo`03
o`000?oooooooooo00_ooooo00Co0000oooooolco`3o<ol01oooool01Ol0omSo<ol0oc?o0?oooooo
0?Oo00?o06So0oooool2o`1Fo`;o00000ooo:@000ol0003oobT0oolY0004oolY0004olco0?l0e?oo
0?mQo`0Vo`;o000000?o_Ol0o`3mooooool00oooool01Ol0oj7o0000o`29oooooooo08[o00;o0?go
00Koaol0o`_o0?l0003o_Ol0o`09ool;o`02oeGo0009o`3oQOl0og?o0?gooeGo0?nmo`3ofol0o`1C
ool02Ooo000000Co_Ol000OoooooolOo0?o<o`3o08[oooooooo<o`3o0?nQ00;oc?l000?o00Wookgo
0?ooool01Ol0oOl01?l0FOoo0?mco`29ool0ROl2o`0co`05ok_o0?l0ROoo0?mco`0Vool0C?l00ol0
ROl01?nmo`3oPol0o`3moonno`02o`0Vo`03o`3oR?l0R_oo0?n800?o0?mQ0_nmo`001onno`3ooooo
oh?o0?l;o`3o_Ol0o`3oI?ooool00ol000001_nmo`3o08[ooom90?l0of7oooooom7o00;o03?o00Co
0?mcolko0?l0oOoo00000_l;o`003Onmo`3oooooo`000?l0003o_Ol0o`3oLol0oj7o0?gookgo0?l0
odgo08WooeGo0?nco`000_l0ROl02Ol0oOooooooooooooooooooc?l0o`000?l0of7oooooo`3mo`03
ooooo`03o`1ioooooooo000000Co00000oooool00onIo`3oooooooooo`0?ooooo`Co053o00?ooooo
o`3obol0J?l01Ol0J?l6ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`09ooooo`03o`3of?oooooo<ol000;o<ol000?oooooo`3gooooool00_l0J?l4
ooooo`?o05Ko00?o09Coo`000?l000001?l000000ol;o`3ocOl0ooooo`02oolY0005o`3Dooo<o`3o
obT0oolY0?l0of400_oo:@02o`0Vo`09okgo0?l0oOooeOl0ooooool0oj7o0000oooR0?l0of7o08Wo
00Co0?go00Oo08[oo`000?l02Oooc?l0okgo0?l0oOooaol000;oEOl000Ko0?n5o`3oLol0og?o05?o
okgo0?nno`02o`09o`07oonj0?l0003obOl0olWo0?o7o`3o_Ol0o`2:o`02okgo00;oc?l000?ooooo
o`3oXOo<o`001_l0oOl02Oo<o`3ookX0ooooool0og?ookX0o`2:oooo^P3o0?gook_o0002o`0co`;o
08Wo00co04coo`29oonmo`3oPol0o`3mool0ROoo__l0o`0Vooo<o`3o02Koo`2:ooo7o`02okgo00?o
0?mQ00SoPol0o`3oV?oooooo2ol0okgo0?l0omCo08Woo`09o`?o00000_l0R_l00ol0GOoodOl0olOo
0002o`0co`08o`3oLol;o`3o2ol0oom90?oooooo_Ol0ooooool0of42o`00000;o`3oLolc0?oo0?go
o`3mool0ROoo0?nQo`3oCOoooooo0?goooooool02Ol00_ooool01_nco`3o0000o`1iool0of7oc?l0
o`3mo`?ooooo1_l000000onIo`3oooooooooo`0?ooooo`Co053o0_ooool5o`1Xo`03o`3obol0003o
000000Kooooo00?o0000ooooooooool0Noooool007gooooo00?o0000ooooooooool02oooool01?l0
003oooooooooooooool3oc?o00;ooooo0olco`000oooooooeOl0omGo0009omGo00;oobT00_l00002
oolY0006o`000?oo:@3oobT0o`3Dooo<o`3o0=Co0ol09_l01?l0ROoo0000o`000?l0oOl6ooooo`06
o`3oXOl0ROoo0?goo`2:ool0oOoo00000_l0oOl02?l0003o_Ol0oooooooRo`3o0?goo`3oQOl0e?oo
0?mQ0_l0og<00omEo`3o00Woo`09o`02oeGo000<o`000?l0ROoo_Ol0olWo0?o7o`3o08Woolco0?l0
R_oo067oo`3oO_l02Ooo0?nQ0_l0ROl01?nmo`3o08Woo`3oR?l09_l2olco0003o`3oR?l0oOoo0?go
00Go0?go00_o^ol0o`3oLol0GOoo_Ol0o`1<oolTo`3o_Ol0oloo0?l0oOooPol0okko0002o`0Vo`03
o`2:ool0oOoo0?mQ00;o_Ol000co0?3oo`2:ool0003o0000o`3oDol;o`3o_Ol0ooooool0oOoo0000
o`09ool0Dol2o`2:o`0?o`3oHOooB@3od?l0o`1Mooo7o`3odOl0olko0?l0og?o03?oo`3mool0003o
__l0o`_o0?nmo`3o08Wo00;o000000?o08Woo`3oLolc0?l00_l0oOl01ol0odgo0?nQoeGo0?oooooo
/ol0o`3mool02Ol01Oooool01?l0of7oooooooooool0oOl3ooooo`04o`1iooooooooooooooooo`;o
00000oooool00onIo`3oooooooooo`0;ooooo`Co053o1Oooool00ol0ol_oooooooooo`02ooooo`03
o`000?oooooo06So00;o06So0oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02Oooool3oc?o0005oooooolco`3o<ol0oc?o0?l0J?l01?ooool2o`1F
o`;ooooo0ooEo`02o`000004omGo0?l0003o0000o`_o00;oobT000?oeOl0o`3moooo:@001?oo:@02
o`0Vo`03ooooool0003o000000?ooooo00Wo0?nQoooooonmo`3o0000o`29ool0003o0?goo`_o0?oo
ool00_l0oOl02_oooooo0000okgo0?l0oOooaol0o`3Dool0ohGobOl0o`3mool0of42o`3oL`?oEOl0
0_nmo`001ol0003oaol0ok;o0?o<o`3o0?n8o`2:ool0ogh00_o<o`002Ol0ROoo0?nQo`09oonmo`3o
0?n8o`0Voonno`3o08Woolco0006o`3mo`03oonj0?l0<ooo03?o00;o^ol00_l0oOl02ol0C?oo_Ol0
o`3moon3o`3o0?n8okko0?l09_oo0?n8olco0?l0R_oo0?go00?o0?mQ00?o08[ookko0?l0oe<00_l0
00003Ooooooo_Ol0o`1Cool0ocoo0?goo`000?l02Ooo0?mQo`2:ool0of7od?l0olko0?oAo`000_l0
oj401_l0oOoo0?mco`0cool;o`3oodT0o`0000;o08Wo00_o2ol0o`000?l0003o_Ol0o`3oLolc0?oo
0?goo`3oXOoooooo0?m=o`3mo`02ooooo`09o`09oooooooooooooooooonco`3oc?l0o`3oHOl0003o
0?go00Oooooo0_l000000oooooooVOl0ooooo`0;ooooo`Co053o1_ooool00ol0003oooooooooo`02
ooooo`03o`3obol0J?oo06So00Kooooo00?o0000ooooooooool0Noooool007gooooo00?o0000oooo
ooooool02oooool00ol0003oeOl0omGo0004omGo00?o<ol00ooEo`001?l0J?ooooooooooooooool3
o`1Fo`;ooooo0_oo:@000ol0003oobT0oolY0004oolY00;o000000_oc?l0ooooool0003o02Kooooo
ool0of7oooooo`3moonmo`3o0?goo`3oR005o`_o0006o`3oXOl0ROoo0?goo`2:ool0ROoo0?go0_l0
2Ol02_l0003o_Ol0o`3moooRo`3o0?n5o`3Doonmo`3o0?mQokgo0?l0oOl3o`3oL`09o`3o?_l0Dooo
EOl0o`000?mEo`3o_Ol0oeGo0?oo^P3oaol000;o000000?o00Woolco0?l0oj400_ooool00onmo`3o
00Woo`3oR002olco0007olko0?oo^P3oc?l0o`3oLooohP3ookX0o`1Io`06o`3mo`03o`1<ooo>o`3o
_Ol000;o0?n800So__l0o`3oHOl0of7o08[oo`0Vool0oOooaol0o`3oH@;o_Ol001So08[oo`000?l0
003ooooookgo0?nno`3o0?goo`000?l0ohSo0?loo`2:ool0of7oooooo`3oe?ooB@3od?l0o`1Mooo7
o`3odOl0o`3oXOl0ROoo0?mco`0cool00003o`29o`03o`000?l;o`3o0?nQ00;o_Ol000[o0?mco`3m
ool0oOoo0?nQo`3oCOooooooEOl0ok?o0?l0oOoo00Wo1_ooool01?l0of7oc?l0o`3mooo<o`03oooo
o`?o000000?oooooo`000?ooool00_ooool00onIo`3oooooooooo`06ooooo`Go053o2Oooool00ol0
ol_oooooooooo`02ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`1Joooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool2oc?o00?ooooo00Co06SoomGo
0?oEo`3oeOl00_lco`07omGo00?ooooo00Co0000ooooool0003o00000_oo:@02ooooo`CoobT00_l0
9_l01?l0ROoo0?goo`3oXOooool2o`0000?o2ol001Oo0?nQo`_o0?l0003o_Ol0o`29ool0of7o08[o
o`3mool0oj7o00WoolOo0?l0oOoo0000okgo0?l0oOoogol0o`3oQOo<o`3obOl0omgo0?l0of7o00Wo
okgo0003o`3oL`?oEOl000Ko0000oeGo0?mEo`3o0?n8o`2:ool0ROl2o`00000?ooooool02Ooo0?nQ
okgo0?l0ohSo02Kookko0?o<o`3ookX0oooR0?oooooo08[oo`3oLol0FOoo03?o00Go0?go00go^ol0
o`3oR?l0ohSo_Ol0o`3oR?oo^P3oPol0okko0?l09_oo_Ol0o`2:ool09_oo0?go00;o_Ol000Co08[o
oh?o0?l0003ooooo0_l000001_nmo`3o2ol0o`1Cool0oOoo0000o`3oR0;o08[o0_o>o`000oo@o`3o
aol0o`3oX@04o`29o`0Ao`3oLol0<oooodT0o`000?oooooo2ol0ooooool0of7o0?gookgo0?l0og?o
ooooo`3moolc0?ooooooo`3oCOmEo`000_ooool02_l02Ooooooooooooooooooo/ol0ooooool0003o
0?mQo`3mooo<o`03ooooo`?o000000Coooooo`000?ooooooVOl02?ooool4o`1@o`[ooooo00?o0000
ooooooooool00oooool00ol0ol_oooooooooo`05ooooo`03o`000?oooooooooo07_ooooo001moooo
o`03o`000?oooooooooo00Kooooo1_oEo`04ooooo`;o<ol00_ooool01Ol0J?oo<ol0oc?o0?l0mooo
oooo00?o05Ko0_ooool3oolY0004oooooooo:@3oobT0o`0000;oobT000?oooooo`000?l000000_l0
0002ooooo`?o00000_l0of401Ol0oj7o0?gookgo0?l0ROoo0?n800Co08Wo01Go0?nQo`29oonmo`3o
08[oo`3oHOl02Ooo0?goo`2:ool0003o_Ol0o`000?l0ohGo0?goo`3Dooo7o`3o00Woo`3oHOl0oOoo
fol0o`3oXOl0och00_l0og<01Ol0oj7o05?oo`000?nmo`3oaol000;oEOl00_l000000omEo`3oc?l0
o`3oX@02ok;o0003okgo0?oooooo0?n800;oc?l000Ooc_l0o`0cool0<ooo0?mcoonj0?l0oOoookX0
00?o05Wo00?o0?mcok_o0?l0ohP01Ol0oOl01ol0of7o_Ol0o`2:oomSo`3o02Koo`3mool0of400_oo
ool01Ol0oOoo08[ookgo0?l0oiSo_Ol000;o0?go00So0000okko0?l0ohSo08[oo`3o?oooooooc_l0
oom900Ko08Wo00Co0?nQo`3oLoo=o`3o00000_l0<ol02?l0003o2ol0okgo0?nmo`3oKol0okgo0?l0
og?o0?go0_lc0?l01?l0odgo08[ooooooonco`02o`0000Kooooo00Co0?mQooooool0oOooc?l01Ol0
00000ooooooo0000ooooo`04ooooo`04oiWo0?ooooooooooooooo`Co053o3oooool01Ol0ol_ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00goeOl00_ooool3o`1Fo`;o<ol02Oooool3oolY0003o`000?oo:@3oobT000?o
obT000_o0000o`0Voooooooo0?mQo`000?l0oOoo08Wookgo0?l0oOooooooo`3oR002ooooo`03o`3o
XOoooooooooo00;o08Wo00go08[oo`29ool02Ooo0?goo`29ooo7o`3o08Woo`000?nmo`3o0?goo`3o
QOl0003o_Ol000;o00Wo00Ko0?mQo`2:ooo9o`3obOl0oooooonmo`02o`3oL`04okgo0?o7o`3o0000
o`3oR0?oEOl00_l000001ooooooo0000o`3oXOnmo`3o00Woo`0Voonno`000_o<o`02o`2:o`03oonj
0?l0og?o03?o00?o05Wo00?ocOl0o`3oLol0ohP01_l0oOl01_nmo`3o0?mQo`3oHOl0R_ooc?l0o`0V
o`;o0?go00?o0?mQo`2:oonmo`000oo?o`002Onmo`3o2ol0o`3mool0oOoo0000o`3oR?l0R_ooc_l0
o`09o`05o`29o`0Fom7o0?oQo`3ocOl0o`3mool0og?o2ol0oom90?l0003o2ol0ofoo0?nmo`3o0?go
oooooonmo`3o/_l0o`3oLol0oOoo0?nQoc<0ool0oOoo0?m=o`09o`;o00001?ooool01Onco`3ooooo
o`3oHOl0003o0?go00?o00000oooool01?l0003ooooooooooonIo`04ooooo`Co053o3_ooool00ol0
003oooooooooo`03ooooo`03o`3obooooooooooo00Gooooo00?o0000ooooooooool0Noooool007go
oooo00?o0000ooooooooool01_ooool2o`0000?ooooo00?o0000oooooolco`000_lco`02ooooo`;o
06So00?o0?oHo`3gool0mol00olco`02ooooo`;oobT00_ooool2oolY0003oooooooo:@3oobT000?o
00000_ooool5o`00000<o`_o0?l0003o0000ooooool0oOoo0?mQokgo0?l0003oooooo`3oR?oooooo
on800_ooool01?l0ROoo08[oooooool0oOl3okgo0005o`000?nmo`3o0000o`000?l0oOl00_l02Ol0
2?oMo`3o0?mQolco0?l0oOoo0?lnolWo0?oooooookX00_l0og<02?l0GOoo0000okgo0?l0HOoo0?n8
o`09ool0oj7o_Ol01_mEo`004?l02Oooc?l0o`0cool0<oooon80olco0?l0oOoo0?mco`000?oo^P3o
ooooo`3oHOl0ohSo0?mco`3oR?nko`03o`3oH@;o_Ol01_l0oOl03Ooooooo3ol0o`oo0?l0of7o08[o
o`3moonmo`3o0?goo`_o0?l0003o08[oo`3oR?l02Ol01?l0ROl00oooB@3o0000olOo0002o`000008
olgo0?oAo`3o0?goo`3oLooQo`3o0000okgo0?l;o`02okgo0005o`3mooooooooKol0o`3oHOnmo`00
0_l0oOl01ol02Ooo0?m=o`2:ool02OooEOl0ok?o0?l000001_ooool00ol0of7o0000o`000002o`00
00Cooooo00?o0000ooooooooool01?ooool4o`1@oa?ooooo00Go0?o;ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo05[ooooo00Go0000ooooooooooooooooo`000006omGo00;ooooo0_lc
o`03ooooo`?o06So00?o0?Ooooooool0E_l00_l0E_l5ooooo`;o<ol01Oooool2oolY0005ooooool0
003oobT0oolY0?ooool00_oo:@03o`0000;o2ol00_l00002o`3oH@05o`3moonmo`3o08Woo`29ool0
ohP00_l0ROl02?l0oj7o08Woo`2:ool0ROoo08[oo`09oooooooo0?mQ0_l0oOl01?o7o`3o0000okgo
0?l0oOl2o`000007o`3moooMo`3obOl0o`3oHOl0oOoo02Koo`3mo`02o`3oX@07okgo0?l0GOoo0?mc
o`3oLol0HOoo0000olco0002ooooo`03o`2:ooooooooEOl000GoEOl00_o<o`001ol0R_oo0?goo`0c
ool0<ooo0?mcooooool09_l00ol0ohP01_l0og?ocOl0o`3mool0oOoo^ol0okgo00;o0?mQ1Ol0oOl0
1_l09_oo0?goo`3oHOl0of7o08[oo`3mo`?o_Ol000Ko0?nHo`3mool0of7o0000o`2:ool0ohP3o`29
o`05o`1Cool0oj7od?l0o`3oXOo=o`000_l000005?l0oOoo0000o`3oLol;o`3oodT0o`000?oooooo
_Ol0o`3mool0of7o_Ol0oooooonmo`3o0?mco`3mool02Ooo0?gooc<0ool0odgoEOl00_l00005oooo
o`03ok?o0?l0of7o000000?o00000oooool01?l0003oooooooooooooool5o`1@oa;ooooo00?o0000
ooooooooool01?ooool00ol0ol_oooooooooo`04ooooo`03o`000?oooooooooo07_ooooo001moooo
o`03o`000?oooooooooo00_ooooo0_lco`02ooooo`?o06So0_ooool00ol0mooo05Koo`1Fo`02oooo
o`?oobT000?ooooooolY0?oo:@001?oo:@02ooooo`?o00000_l;o`02ooooo`;o000000Soooooo`00
0?l0003o0000ooooool0oOoo0000okgo00?o0?mQ00Go0?n8oooR0?oooooo0000o`29o`02o`000007
okgo0?l0oOooooooo`3oHOl0003o_Ol0o`3oQ@02o`09o`04o`3Dool;o`3o0?goo`3oH@;o0?go00Ko
c?l0o`_o0?oooooookX0okgo0?o<o`02o`3oL`07o`000?l0ogko0?n8olco0?ooooooc?l0okgo0003
o`3oX@04okgo0?l0ohSo03?oo`0co`?oEOl000Coc?l0oonj0?l0og?o0>;o0ol0ohP01?l0GOoo0?mQ
o`3oHOl0of44okgo0006okko0?l0R_ooc_l0olOo0?o<o`3o02Ko1Ol0oOl04?l0R_oo0000o`000?l0
ROoo0000o`2:oonmo`3o0?n8o`09ool0003o05?ookko0?l0ocooodT0o`000?o7o`02o`000008o`3o
XOoAo`3o0?goooooool0og?o0000o`_o0?nmo`02o`3mo`?o03?o0_nmo`002?l0oOoo0?nQooooool0
odgo<`3oo`3moooooooo/ol01Oooool3o`000004o`3oHOl0oOoo0000o`0000Cooooo00?o0000oooo
ool0D?l01?l0D?l00onIo`3oooooooooo`0Eooooo`04o`3oboooooooooooo`0000Oooooo00?o0000
ooooooooool0F_ooool01?l0003oooooooooooooool2o`0000;ooooo00?o0000ooooooooool00_lc
o`03ooooo`;o06So0_ooool00ol0mooo05Koo`1Fo`0:ooooo`?o<ol00_oo:@02ooooo`;oobT000Co
0000oolY0?oo:@3o2ol00_ooool5o`000005ooooool0003o0?goo`3moonmo`000_l0of402?oooooo
0?n8ooooool0oj7o0000o`3oHOl0ROoo08[o0_l000002_oooooo_Ol0o`3moonmo`3o0000okgo0?l0
ohGo0=Coo`09ooo9o`02o`3mo`04o`3oHOl0oOooc?l0olco00;o0?m000CookX0o`1Mool0Dooo_Ol0
0_l0og<02?l0003o0?nQo`3oXOl0R_oo0?nQolco0?nmo`3o2ol00_l0oj400ol09_ooEOl0oeGo0002
o`0co`03oeGo0?oooooo0?mc00;o0?n800Cooooooonj0?l0GOoo0?mc0_l0FOl3o`3oH@07o`1<ool0
ohSo__l0o`2:ooo7o`3oooooolco0006o`3mo`0@o`29oonmo`3o0000o`000?l0ROoo0000o`2:ool0
oj_o0?n8okko0?l0003o0?loo`3oXOo7o`3o0?nQom3o00?o00000_l0oOl01ol0003oodT0o`3mool0
003o_Ol0o`3mooooool00_l0<ol02Ooooooo_Ol0o`3mool0oOooooooo`3moooooooo<`3oo`3oC@06
ooooo`05o`000?nco`3oooooo`3oHOl0oOl00_l00003ooooo`06o`000?l0D?oo053oo`1@oooooooo
VOl05Oooool00ol0003oooooooooo`04ooooo`03o`3obooooooooooo00Cooooo00?o0000oooooooo
ool0Noooool007gooooo00?o0000ooooooooool02Oooool01?l0003o<ol0o`000?ooool2o`1Xo`;o
oooo0_l0E_l01?l0moooooooooooooooool2oolY00;ooooo0_oo:@000olco`3oobT0oolY0006oooo
o`;o00001Oooool00ol0oOooooooooooo`02ooooo`?o000000Co_Ol0oooooooooooooooo0ol0of40
1?l0003o08Woo`000?l00002o`3oH@04o`3mool0003o0000okgo00;o000000Ko0?goo`3Dool;o`3o
gOl0o`3oHOl0och2o`3mo`;oaol000WookX0olco0?nmo`3o0?goolOo0?l0ogko0000o`3oLoooool0
0_o<o`001?nmo`3o9?l0olco0?l0oj42o`0co`05olco0?l09_oo__l0o`3oXOo<o`000_mEo`000ol0
og?oEOl0o`3oH@03o`3oH@0:o`3oLonmo`3o_Ol0okgo0?nko`3o04coo`29ool0R_oo08WoolOo00;o
000000Oo02Koo`3mooo?o`3o0000ooooool0R_oo0?go00Go000000Oo_Ol0o`3oR?l02Ooo0000o`1C
ooooooooodT000;o000000[o__l0o`1Mool0ofCoooooom7o0?l0003oooooo`3oLol0003o_Ol00_l0
oOl03_ooooooG_l0o`09oonmo`3o03?ookgo0?l0oOoo0?mcok;o0?oooooo0?m=oc<0oooooooo/ol0
0_ooool3o`0000?ooooo00?o0?mQooooool0oOl00oooool01?l0D?oo0000o`1@ool0D?l6ooooo`03
oiWo0?oooooooooo01Cooooo00Co0?o;oooooooooooo00001oooool00ol0003oooooooooo`1Joooo
o`03o`000?oooooooooo00Gooooo0olco`02ooooo`?o06So00Go0?oHooooool0E_oo0?Ooo`1Fo`0=
ooooo`;oobT00_lco`02oolY0004oooooooo:@3oobT0o`0000Kooooo00?o0?goooooooooool00ol0
00001?oooooo_Ol0o`3mool0oOl3o`3oH@05o`3oXOl0003o0?mQo`29ool0R_l00_l000003Onmo`3o
ooooo`3oHOl0oOoo0000okgo0?l02Ooo0=Coo`_o0?oMo`3o0?lnooooool0of400_l0oOl05?l0od3o
c?l0oonj0?oooooo05goolOo0?l0ogko_Ol0o`3oR?o<o`3o0000o`3oLoo<o`3o08[ooooR0?nmo`3o
oooookgo0?l0oj7o08[o0_l0<ol3o`3oR003oeGo0?l0og?oEOl000?oEOl000Go05goo`3oHOl0of7o
0?mQokgo0002o`29o`06ok_o0?nno`3o08[oolOo0?n3o`3oc?l00_l000001Ol0oOooooooo`3`ool0
R_oo0?mQ00;o0?go1Ol000000ol0ohSo00Woo`3o3002okko000Do`3o?oo7o`3o0000o`000?l0of7o
0000o`3oI?oooooo0?nQo`_o0?ooB@3o_Ol0o`000?l0oOoooooookgo0?l0of7o0000o`0coonmo`03
o`3mo`;ooooo00?o08[oo`3oCOmEo`000_ooool3o`0000;ooooo00Co/ol0o`3oHOl0oOoooooo0ol0
D?l00ol0003oooooooooo`03ooooo`03oiWo0?oooooooooo01?ooooo00?o0000ooooooooool01Ooo
ool00ol0ol_oooooooooo`03ooooo`03o`000?oooooooooo07_ooooo001mooooo`03o`000?oooooo
oooo00Wooooo0_l00002o`1Xo`;ooooo0_l0E_l01?oooooo0?Ooo`000?ooool2oolY0005oooooooo
:@3oobT0oolY0?ooool00_oo:@000ooooooo<ol0oc?o0006ooooo`;o00001Oooool01Ol0oOoooooo
oooooooooooo0?go00;ooooo0ol000001ooohP3oooooooooool0oOoo00Woo`29ool0R_l00oooool0
0ol0of7o0000o`000003o`000003o`3Dool0003obOl000;o000000Cofol0olOo0?l0oOoo0?go0ol0
00001_oooooo067oolOo0?l0oOoo_Ol0o`0000;o0?mc00?oc?l0obCo0?nmo`000_l0<ol03?nmo`3o
0?n8olco0?l09_oo0?n8okko0?l0ohSookX0o`3oHOl0og?o0?mQo`29o`GoEOl000So0?nQokgo0?l0
003o0000ok_o0?l0R_ooaol0okgo00;o000000Co02Koo`3mool0003o00000_l0oOl2o`2:o`03o`00
0?l;o`3o000000?o000000Go00Woo`3mool0oOoo0?gooom90002o`0000;o0?go00So0?mTo`3mool0
oOoo0?gookgo0?l0og?o0?goo`0000Oo0?go00_o_Ol0o`3mool0og?o0?goo`000?l0odgo0?gooc<0
ool0003o/ol0o`000006o`3mo`04o`3oHOl0oOoo0?goo`0000;o053o00?o0000ooooooooool01ooo
ool00onIo`3oooooooooo`0Eooooo`03o`3obooooooo000000Oooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`03ooooo`03o`000?lco`3o000000;ooooo0_l0J?l2ooooo`?o05Ko00?o
0?Ooooooooooool02oooool2oolY00;ooooo1Ooo:@02ooooo`03o`000?oooooooooo00Gooooo00Go
0?gooooooooooooo0?gookgo0003o`000004ooooool0oOoo0?goo`3mo`;o0?mQ00Co00Woo`29ool0
R_oooooo1?l0of45o`000006o`2:ool;o`3oooooolOo0?oKo`3o0?mQ0ol0oOl2o`000005o`1Mooo7
o`3o_Ol0okgo0?l000000_o<o`001Ol0003o0?mco`3oLol0R_ooc?l000;o_Ol00_l0<ol00oo<o`3o
0?n8oonj0003o`29o`03o`3oLol0ROoo08Wo00;o0?mQ1OmEo`002?oooooo05Woo`000?l0003o^ol0
olko0?n3o`3o0?mQ0_l000001?l0oOooooooolko0?l0R_l2o`3mo`;o08[o00Ko0000o`3mool0003o
0000o`3mool00005o`3mo`;o00000_l0oOl01ol0ofCo0?goo`_o0?nmo`3oodT0o`3mool000001ol0
oOl01?nmo`3o0?goo`3oLol0oOl2o`000004o`3mool0odgo0000o`0000Go0?go00Co/ol0o`3oHOl0
oOoo00000_ooool00ol0003oooooooooo`04ooooo`03oiWo0?oooooooooo01?ooooo00?o0000oooo
ooooool01Oooool00ol0ol_oooooooooo`03ooooo`03o`000?oooooooooo07_ooooo001mooooo`03
o`000?oooooooooo00Sooooo0ol0J?l01?l0003o05Koo`1Fool0E_l2ooooo`05o`3goooo:@3oobT0
oolY0?ooool00_oo:@001?ooooooobT0oolY0?oo:@05ooooo`?o<ol00oooool00ol0003oooooo`00
0005ooooo`04o`3moooooooo0?gookgo00;ooooo00?o_Ol0ooooooooool00ol000001?l02Ooo0?n8
o`29ool0R_l2o`3oH@;o00Wo00?oooooo`000?l000000_l0oOl00ol0e?oo08[oo`2:o`02o`000004
om_o0?l0oj7o08[oo`3mo`;o00000_l0oOl01ol0ogkoaol0o`09oonmo`3o08Woo`000?o<o`000ol0
og<00onmo`3o08[oo`3oX@02olco0003o`0Vool0ohSo0?mQ00;o0?mQ00?o00Woo`3oLonmo`000_nm
o`001Ol0GOooooooo`3oLol0003oEOl000?o000000OoEOl0ok_o0?l0FOoo05Woolco0?n3o`3o02Ko
00;o08[o00Wo0?goo`2:oonmo`3o08Woo`000?l0oiSo2ol0okgo0?l?o`000_l000001ol02OoocOl0
o`000?l0oe?o_Ol0o`2cool0oj/00_l0ocl01Ol0ofCo0?gookgo0?nmo`3o2ol000?o000000gooooo
on7o0?nmo`3o_Ol0oeko0?oooooo0?mQofoo0?l0oOooooooo`3oLol0003o0?m=00;o000000?o<`3o
ok?o0?ooool01?ooool3o`1@o`03o`3oHOl0003o000000;ooooo00?o0000ooooooooool01oooool0
0onIo`3oooooooooo`0Eooooo`03o`3obooooooo000000Oooooo00?o0000ooooooooool0F_ooool0
0ol0003oooooooooo`03ooooo`?o00000_l0J?l2ooooo`;o05Ko0_ooool00ol0moooooooooooo`09
ooooo`?oobT000?ooooooolY0?oo:@000ooo:@02ooooo`;o<ol000?oooooo`000?l000001oooool0
1ol0oOooooooo`3moonmo`3ooooookgo0?ooool00ol000001_oooooo00Woo`09ool0of7o08Woo`2:
o`?ooooo0_l02Ol5o`000004o`3oHOl;o`3o08[oo`2:o`;o000000?o08[oo`3mool02Ol00_l00000
1?l0ogko05goo`29oonmo`02o`29o`;oc?l000?o0000o`29ool0og<00_l0og<00ol0<oooc?l0o`3o
X@02olco0005oonj0?l02Ooo/_l0o`0Vool0og<00_l0of402?l0GOoo0?gooonj0?l0og?ooooookgo
0?ooooooEOl00ol000001omEo`3o^ol0o`3oHOo<o`3oooooolko0?l0oOl00_l0R_l02Ol0oOoo08[o
o`2fool0of7o0000o`_o0?o=o`3o0?goo`3oR002o`00000>o`3oDonmo`3oaol0o`3oXOoooooo0?lo
om3o0?l0oOoo0?nQo`3oI?l;o`3o_Ol0o`_o0?ooB@02o`00000;okgo0?ooooooooooo`3oHOm_o`3o
ooooo`3oXOnmo`3o0?goo`3oLol0<ol00ol000001?l0odgo0000o`000?ooool4o`1@o`04oooooonc
o`3o0?mQo`0000;ooooo00?o0000ooooooooool01?ooool00onIo`3oooooooooo`0Cooooo`03o`00
0?oooooooooo00Kooooo00?o0?o;ooooooooool00_ooool00ol0003oooooooooo`1kooooo`00OOoo
ool00ol0003oooooooooo`06ooooo`03o`000?l0J?oooooo00?o05Ko1?ooool2oolY00;ooooo0_oo
:@000oooooooobT0oolY000;ooooo`;o<ol00_ooool2o`0000Kooooo0_l0oOl01_nmo`3ooooooooo
oonmo`3ooooooooR00;ooooo00Oo00Woo`000?l0003o08Woo`2:ool0oj7o00Wo00;o0?mQ00Co0?n5
o`000?oRo`3o_Ol00_l0oOl01?oooooogOl0o`2:ool0R_l2o`3oH@06o`2:ool0oOoookX0o`3oHOl0
HOoo0?mn0_l0oOl02?nmo`3o0?n8okgo0?oooooo0000o`0coooooooo08[o0_l0og<00ol0oj7oc?l0
o`3oH@02o`3oH@08okko0?l02Ooo_Ol0okgo0?l0og?o02Koo`3mool0GOl2o`000003o`3oLomSo`3o
_Ol000;o000000Co08[oolOo0?l0C?oo^ol01?mEo`02o`3mo`0<o`3oXOnmo`3o08[oo`000?l0oj7o
2ol0o`3oXOl0]_oo0?n8olgo0?l?o`3o00Wo0_l0oOl00ol0003o0?mCokgo0002okgo0006o`1Mool0
ofCo_Ol0o`_o0?nno`3odOl00ol000002Ooooooo_Ol0on7o0?ooooooG_l0ooooool0of7o0?nQo`3m
o`02o`000003o`3oLol0<ooo0?m=00;ooooo00?o0000ok?o0?l0D?l00ol0D?l3ooooo`05o`3oHOoo
ooooooooooooool000002oooool00onIo`3oooooooooo`0Eooooo`03o`3obol0003ooooo00Kooooo
00?o0000ooooooooool0F_ooool01?l0003oooooooooooooool2o`0000?o06So00Coooooo`1Fool0
E_oo05Ko0oooool00ol0moooooooooooo`08ooooo`;oobT00_ooool2oolY0003oooooooo:@3oobT0
00Kooooo0olco`08ooooo`07o`3moonmo`3ooooooooooonmo`3ooooooooR0002ooooo`?o000000Co
0?goo`29ool0oOoo0?mQ0_l02Ol01_ooooooh_l0o`3oQOl0003o0?gookgo00;o0?go00?o08Woo`_o
0?oKo`000_l000001Ol0R_oo0?goo`3oHOl0of7o0?mn00?o0?go00?o0?n8okgo0?o<o`000_o<o`00
1Ol0oOoo0000o`0cool0<oooc?l000;o0?mc00Co0?nQokko0?oo^P3o00Wo0ol0of402ol0og?o/_l0
o`3mool0GOoo0000oonj0?l0og?o05gookgo0?l0ohSooooo00;o000000Go04cooonj0?l0of7o^ol0
oeGo0003o`2:o`;o0?go0_l0oj402?l0]_oo0000o`_o0?o=o`3o0;?oo`oo0?l0ohSo0?go0_l02Ol0
3?l0oe?o_Ol0okgo0?oooooo0?goo`3o?ol0oj7o2ol0o`3oI?oAo`3o2ol0o`3mo`?o000000_oG_l0
oooooooooooo0?mQofoo0?oooooo0?gookgo0?l0003o0?goo`3oL`02o`0co`;o053o00?o0?m=o`00
0?l0D?l01Oooool01Onco`3o0?mQoooooooooooo000000Sooooo00?oVOl0ooooooooool04_ooool0
0ol0003oooooooooo`06ooooo`03o`3obooooooooooo00;ooooo00?o0000ooooooooool0Noooool0
07gooooo00?o0000ooooooooool01_ooool2o`000004o`1Fool0003oooooo`0000;ooooo0_oo:@00
0oooooooobT0oolY0004oolY00oooooo0olco`02o`0000Gooooo0_l0oOl01Ol0oj7ooooooooooonm
o`3o000000;ooooo00Go00Woooooool0R_ooooooo`29o`02o`09o`09o`000?oooooo0?n5o`3mool0
003o0?mQokgo0?l0oOoo0=Co00;o0?go00?oooooo`_o0?l0of400_l0R_l01ol09_oo0?goo`1Qool0
ogko0?mQo`09ooo7o`000_l00002o`0co`06olco0?l0003o08[oo`3oR?oooooo0?mQ0_l0og<00ooo
oooo02Koo`3oR002okgo000?o`09oooooooo0?mco`3moooooooo05gooonj0?mSo`3o0?mcok;o0?nm
o`3o0?n8o`2:oonno`3o0>ko00;o08[o00?o^ol0olco0?l0of400_l0oOl3oeGo0007o`000?mEo`3o
EOl0o`_o0?o=o`3o0;Koo`3oR002o`3oX@03o`09ool0/ooo3ol000;o0?go00Oo0?mCo`09oonmo`3o
_Ol0o`3oI?l;o`3o000000;o0?go00Co2ol0o`3oLol0003o_Ol00_ooool00ooQo`3oG_l0ooooo`02
o`000006okgo0?l0oOoo0?goo`3oLonbo`3o0?m=0_l0<ol00ol0003o/ol0oeGo0006ooooo`04o`3o
HOooooooooooo`0000cooooo00?oVOl0ooooooooool05Oooool00ol0ol_o0000ooooo`06ooooo`03
o`000?oooooooooo05[ooooo00Oo0000ooooooooooooooooo`000?l0J?oooooo00?o05Ko1?ooool2
o`3go`Wooooo0_oo:@02ooooo`;oobT000?ooooooolY0?oo:@002oooool2oc?o00Gooooo00?o0?go
ooooool0oOl00_ooool01_nmo`3o0000oooooooooooo00Woo`2:o`;ooooo00Co0000o`29ool0003o
00Wo0_l0oOl03Ol0of7o0?n5o`3oHOl0003o0?gookgo0?l0ROoogOl0o`3mool;o`3o0?m0ooooool0
of400_l0R_l02?l0oOoookX0o`3oHOl0of7o05goo`3oHOl0oOoo_Ol00_l000001_nmo`3o03?oo`0c
ool0003o08[ooonj00;o_Ol00_l0og<2o`3oH@06okgo0?l09_ooHol0o`3oLol0oOoo05go0_nbo`00
2Ooo^P3o0?mcoooooonmo`3oooooolOo0?l0R_oo__l0ooooo`03o`2:o`05ok_o0?l0FOoo0?mQo`3m
ooooool00omEo`006ol0003oEOl0oeGo0?l0of7o0000o`2cool0ohSo3ol0o`09ool0oOooaol0o`3o
Dol02Ooo_Ol0o`3oXOnmo`3o2ol0o`3oHOoooooo0?mTo`3mool;o`3oooooo`3oLol0003ohOl0oeko
0002ooooo`;o0?go00Go0000okgo0?l0003o0?goo`3oL`02o`1@o`;o03?o00?o0?m=oc<0ooooool0
1_ooool00onco`3oooooo`000009ooooo`03oiWo0?oooooooooo01;ooooo00?o0000ooooooooool0
1oooool01Ol0ol_ooooooooooooooooo000007gooooo001mooooo`03o`000?oooooooooo00Sooooo
0_l000001OooooooobT0oolY0?oo:@3o0?Oo00;oobT000?ooooooolY0?oo:@005Oooool2oc?o0003
o`000?oooooooooo00;ooooo00?o0?gookgo0?l0oOl00_ooool01onmo`3o0000ooooool02Ooooooo
o`2:ooooool00_l02Ol2ooooo`03o`3oR?l0003o000000?o000000Go_Ol0o`3Dool0of7o0?goo`3o
H@02o`3mo`04o`3oHOoooooo0?nQo`2:ocOo00000omEo`001?l0003oaol0o`09ool02Ol2okgo00;o
0?nQ00Oo0?mTokgo0?l0oOoo0?goom7o0?l;o`3o0?mc00;o00000_ooool3o`000004o`2:ool0oOoo
_Ol0o`3mo`;o053o00Oo0?mco`3oCOooooooooooo`0coonco`3o<`3o00Oooooo00?o0?mQooooool0
00003?ooool00onIo`3oooooooooo`0Eooooo`03o`3obol0003ooooo00Kooooo00?o0000oooooooo
ool0F_ooool00ol0003oooooooooo`02ooooo`04o`000?l0E_ooooooo`0000Cooooo00?o0?Oooooo
ooooool01oooool2oolY00;ooooo0_oo:@000oooooooobT0oolY000=ooooo`;o00000_lco`03oooo
o`0:o`3moonmo`3o0?nQo`3moooooooo_Ol0o`000?oooooo00Woo`2:o`Cooooo00?o08Woo`3oR?l0
00000_l000002Ol0ohGo0?goo`29ool0003o0?gookgo0?l0003o0?mQooooo`02o`3mo`05ooooool0
of7o0?n8o`2:ool0oOl00_l0R_l00oo7o`3o05goo`3oR002o`3oR3Oo000000oo0?nQokgo0?l;o`3o
d?l0o`3o?ol0oOoo0?mTo`000?l;o`3o_Ol0o`3oLol0003ooooooeko0?l0oOl00ol000001_l0oOoo
053ookgo0?l0oOoo/_l0o`3oL`?ooooo00?o0?m=o`0coolc0?l01_ooool00onco`3o0000o`000009
ooooo`03oiWo0?oooooooooo01;ooooo00?o0000ooooooooool01oooool01Ol0ol_ooooooooooooo
oooo000007gooooo001mooooo`03o`000?oooooooooo00Wooooo0_oo:@001Ol0003ooooooolY0?oo
:@3ooooo00;oobT06?ooool03?l0003o<ol0oc?o0?lco`3oooooo`3moooooooo_Ol0ooooool0oOoo
oooookgo00;o00000_ooool2o`09o`06o`3mool0ROoo0?goo`3moooooooo0?n50_ooool=o`000003
oonj0?l0oOoo08[o00;o08[o0_l0<ol00ol0ohSo08[oo`3oH@02o`3oH@09o`000?oooooo_Ol0okgo
0?o<o`3o_Ol0o`3oXOoo^P3oHol000;o0?mc0_l0oOl00ol0og?o05goooooo`02o`000007oonj0?l0
R_oo08[oo`2:ooo7o`3o__l0o`1Mo`03o`3oH@06o`3moooo^P3o^ol0olco0?l0oOoo_Ol00_l00002
o`1Io`05o`3`ool;o`3o<`3oo`3oR?l0]_l02ol000001ol0ofCo0000om3o0?l0ocoo0000om7o0?l0
og<01?l000001ooooooo053oo`3mool0oj7o0?goofoo0?l0oOl00_ooool00ol0og?o/_l0o`3oC@02
ooooo`04oeGo0?nco`3o03?oo`0000Cooooo00?o0?mQo`000?l000003_ooool00onIo`3ooooooooo
o`0Eooooo`03o`3obooooooooooo00Gooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`02ooooo`;o000000?oooooo`000?ooool00_ooool00ol0moooooooooooo`05ooooo`?oobT00_oo
ool5oolY013ooooo00?o0000ooooooooool00olco`002_oooooo_Ol0oooooooooooo0?gookgo0?oo
oooo00Woooooool0R_l2o`3mo`;o00Wo00Go08Woooooool0ohSoooooo`3oQ@04o`000008o`3Dool0
003o0000o`3oHOl0od3ofol0o`000?l0oOl;o`000003o`0cooo<o`3o0?go00;o0?go00[o0?mQo`00
0?l0of7o_Ol0olco0?nmo`3o__l0o`3oXOl09_oo0?nI0_l0og<01?l0h_oo0?mco`09ool02Ol3o`00
00Co08[o013o__l0o`3oHOoooooookX0o`1<ooo<o`3o0?gooh?o0?nko`3o0?goo`1Iool0R_oo05Wo
o`000?lc0?oo2ol00_l000000ol02Ooo0?n8o`00000<o`000003o`3oI?l0003o000000Ko000000[o
053oo`3oHOl0oj7o0?gooooooonmo`3o0?gook;o0?l0og?o00000_ooool01?mEo`3o0?m=o`0cool0
0005ooooo`03o`000?nco`3ooooo00Wooooo00?oVOl0ooooooooool04_ooool00ol0003ooooooooo
o`08ooooo`04o`3oboooooooooooo`0007gooooo001mooooo`03o`000?oooooooooo00Kooooo0ooo
:@000oooooooobT0oolY0004oolY01_ooooo0_l000001Ooooooo<ol0oc?o0?nmo`3o0?nQ00;ooooo
00Co0?gooooR0?l02Ooo00000_l02Ol3ooooo`09o`29ooooooooooooo`3oQOoooooo0?n8ooooool0
003o0?go00;o000000Coooooomgo0?l0oOoo0?go0_l000000ol0of7o0?goo`3mo`02o`3mo`04o`09
ool0<ooo03?oo`2:o`?o0?mQ00Koc?l0okgo0?oooooo_Ol0o`000?nmo`02olco0006okgo0?l0oj7o
_Ol0okgo0?nno`3o0?mQ0ol0og<02_l02Ooo08[oo`000?l0003o08[oo`3oLonmo`3o08[oo`0Voonn
o`02o`3oH@;o0?go00?oc?l0oonj0?ooool00_nko`003_oooooo0000o`2:oonmo`3oooooo`_o0?l0
oiSo00Woo`3oR?l02Ooo0;Koo`09ool0of7o04Co0_l00002o`3oX@05o`_o0?mEo`3oEOl0o`3oI?mE
o`001ol00002o`1@o`;o0?go00GoG_l0o`3oXOl0oOooKol0o`3mo`02ooooo`03o`000?l0og?o0?m=
00;oEOl000Co0?mQok?o0?l0003o03?o0_l0of42o`000003ooooool0003o000000kooooo00?oVOl0
ooooooooool05Oooool00ol0ol_oooooooooo`05ooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooool0mol6ooooo`;oobT00_ooool5oolY01Cooooo00Go
0000ooooooooooooooooo`3mo`02oc?o00?ooooo00?o0?goo`09ool0oOl00_l0oOl2o`09o`;ooooo
00Ko08Wooooooooooooo0?n8o`3oQOooool5o`000006okgo0?l0003o0000o`000?l0of7o2ol00_l0
00001ol0R_oo0?n8o`3mooooooooaol0o`1Mool0ohP00_l0<ol00oo<o`3o_Ol0o`3oH@02o`3oH@;o
_Ol000?o0000o`2:ooo<o`000_nmo`000ol0oj7o_Ol0o`3oH@02o`3oH@;o0?mc00?o9?l0ooooool0
R_l00_l000001_o7o`3o08Woo`2:ool09_oo__l0ok;o00;o0?mQ0_l0oOl00oo<o`3o_Ol0okgo0002
ok_o0005o`2:ool0003o05Woo`09ool;o`000_l02Ol01_l0ohSoooooo`3oHOl02Oooaol0ooooo`;o
00000_l;o`000ol0oe?oEOl0oeGo0002oeGo0003o`3oI?l0003o000000?o000000go053ooooooomN
o`3o08[oo`3oXOl0oOooKol0oooooonmo`3o0?gooeGo0?l0003o0?mc00;oEOl000Co0?mQo`3oCOl0
003o00000_l0of42o`000003o`3oHOl0003o/ol000_ooooo00?oVOl0ooooooooool04Oooool00ol0
003oooooooooo`08ooooo`04o`3oboooooooooooo`0007gooooo001mooooo`03o`000?oooooooooo
00Cooooo0_oo:@02ooooo`;oobT000?ooooooolY0?oo:@007_ooool3o`000003o`3moooooooo<ol0
00;o<ol00ol0oOl2o`000003o`2:oooooooooooo00;ooooo00Co08Wooooooooooooo0?n50_ooool0
3?l0003o08Woo`000?l0003o0=Coomko0?oMo`3o0?m0om_o0?l0oOoo0?mQo`3mo`;o0?mQ00Co08[o
o`3mool0oOoo0?go0_l0of401?l0ohSo08[oo`2:ool0R_l2okgo0009olco0?mSo`3o0000o`3mooo<
o`3o0?gookgo0?l0oj7oc?l000?o_Ol000Co08[oo`3oLol0og?o0?mc0ol0of400onmo`3o08[oo`00
0003o`00000;o`3mool0GOooc?l0o`0Vool0C?oo_Ol0olco0?l0oOoo^ol0o`000?l0R_l00_l02Ol0
1Ol;o`3o0?nHo`1Iool0ohSo05Wo00?o04Co00?o_Ol0o`000?l000000ol;o`001_l0oOoo0?mTo`3m
ool0oe?o3ol0om3o00KoEOl000So0?goo`2:ool0of7o0?nQo`000?l0oOooEOl0o`3mo`;oEOl00_l0
00001Ol0odgo0?mQoooooooooooo/ol000Cooooo0_l000000ooooooo0000ooooo`0>ooooo`03oiWo
0?oooooooooo01Gooooo00?o0000o`3oboooool01Oooool00ol0003oooooooooo`1Jooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool0mol01Oooool2oolY00;ooooo0_oo:@000oooooooobT0
oolY000Fooooo`;o000000Goooooo`3moooooooo_Ol0o`3oX@02oc?o0003o`3mool0003o0?go00;o
000000?o00Woooooooooool00_ooool01_l0ROooooooooooool0ohGo0?n8o`29o`?o000000Co0=Co
omgo0?nmo`3ooooo0_l0oOl01?l0ohSo0?mQo`3oHOl0of44o`3mo`04olOo0?l0<ooo03?oo`0000?o
0?mQ0_nmo`001OmSo`3ookX0olco0?l0oOoo000000;oc?l000?o_Ol0o`0Vool0oj400onmo`02o`2:
o`?o0?mc00Oo0?mQokgo0?l0of7o08[oo`0Voonno`3o0?mQ00;o000000Wo0?goolco0?ooooooc?l0
okgo0?n3o`3o0?goo`2:oonko`000_l02Ol01Ooooooo2ol0o`1Ioolc0?oo0?n800;ooooo0ol0A?l2
o`_o00;o00000_l0oOl01Oooooood?l0okgo0?l0ofCodOl000KoEOl000Co08[oo`000?l0oj7o0?go
0_mEo`001_nmo`3o0?goo`3oHOnbo`3o0?mco`3oH@?ooooo00Co0?m=oooooooooooooooo0_l00000
1?oooooo0000oooooonco`0:ooooo`03oiWo0?oooooooooo017ooooo00?o0000ooooooooool02Ooo
ool00ol0ol_oooooo`00001mooooo`00OOooool00ol0003oooooooooo`02ooooo`;oobT000Gooooo
oolY0?oo:@3oobT0ooooo`02oolY0003o`000?oooooooooo01kooooo00Oo0000o`3mool0oOoo0?go
okgo0?l0oj7ooooo00;o<ol000Coooooo`000?l0003o08[o0oooool01?l0R_oo08Woooooool0ohD2
ooooo`09o`000?l0oj7o0?n8o`000?l0e?oo_Ol0omgo0?l0od3ooooo00;o0?n800Co0?goo`3oHOl0
oOoo03?o0_l000000ol0of7o08[oo`3mo`02o`3mo`?o_Ol000?o08[ookgo0?l;o`000_o<o`001Ol0
003ooooookgo0?l0oOoo0?nQ00Co08[o00Coooooo`3oLonmo`3o_Ol00_l0og<2o`000003o`3oHOl0
003o000000;o00000_ooool03Oo<o`3o02Kookgo0?ooooooc?l0o`000?n3o`3o^ol0o`2:oooooooo
0?mQo`_o0?l0oiP00ol0A?l00onmo`3o00Woo`_o0002o`3oX@;o2ol000oo0?mQo`3mool0of7o0?mT
o`3mool0of7o0?mCokgo0?l0of7o0000o`3mool0003oooooo`2:oomEo`000_l000001OmEo`3o0?go
o`000?oooooo0?go00Cooooo00?o0?m=ooooooooool00_ooool00onco`3oooooooooo`03ooooo`03
o`000?oooooooooo00oooooo00?oVOl0ooooooooool05?ooool00ol0003o0?o;ooooo`05ooooo`03
o`000?oooooooooo05[ooooo00?o0000ooooooooool01Oooool00ol0003o0?Ooooooo`03ooooo`;o
obT00_ooool2oolY0003oooooooo:@3oobT001Wooooo00Ko0000o`3mool0oOoo0?gookgo0?l0oj42
ooooo`;o<ol000?oooooo`000?l000001?ooool03_l0R_oo08Woooooool0ohGoooooo`3oXOl0003o
0?goolCo0?oooooo0=Coomgo0?oooooo_Ol00_l0ohP3o`3mo`?o0?mQ0_l00002o`3mo`;o0?mQ0_nm
o`002Ol02Ooo_Ol0o`2:ool0R_ooc?l0o`3oR?oooooo_Ol0o`000002o`3mo`03okgo0?l0oj7o08[o
00;o08[o00Go_Ol0o`3oLonmo`3o_Ol0o`3oR002o`3oL`Co000000Ooooooo`000?l0003ookX0olco
0?l0C?oo_Ol000;o00Wo00Oo0?goo`000?oooooo^ol0o`3oHOl;o`3o0?nH00;o2ol00ol0A?l01?l0
2Ooo_Ol0o`3oHOl;o`02o`3oH@08o`3mool0of7o0?mQo`3oDonmo`3o0?mQo`3oI?l0oOl2o`3oH@05
o`000?oooooo08[oo`000?mEo`000_l000001Ol0oOooooooofoo0?oooooo0?go00;ooooo00?o0?mc
ooooooooool00_ooool00ol0odgoooooooooo`03ooooo`04o`000?oooooooooook?o00[ooooo00?o
VOl0ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`3obooooooo000007gooooo001m
ooooo`03o`000?ooooooobT000;oobT000CooooooolY0?oo:@3ooooo0ooo:@000ol0moooooooo`00
000Qooooo`;o00000_nmo`001?l0oj7ooooooooooooohP03oc?o00Cooooo00?o08[oo`29ool0ohD0
0_ooool02?l0003oooooo`29ool0oj7o0000o`3Dool0oOoo_Ol00_l0ohP01_oKo`3o067oo`3oO_l0
of7o03?oo`09o`;o000000?o08[oo`3moonmo`000_nmo`03o`3mo`07olco0?nmo`3o08[oolco0?l0
R_ooc?l0o`000003o`2:o`08o`3oXOl0oOooooooooooool0GOoo0?mcoooooolTo`02okgo00;o0000
00?o0?mco`3mool0oOl02?nmo`001_l0003o0?goo`0Voonmo`3o^ol0okgo00?o04Co00Oo0?n8okgo
0?l0003o0000o`09ool0oj7o05Wo00;o2ol000Go053oo`3mool0D?oo053oo`3oI002ooooo`07okgo
0?o@o`3o0?goo`3mool0003o0?mco`2:o`02ooooo`;o000000Co0?nQo`3mool0of7ohOl00_l00003
ooooo`03o`3oLol0odgooooo00;ooooo00?o/ol0ooooooooool00_ooool00ol0003oooooooooo`0@
ooooo`03oiWo0?oooooooooo01Cooooo00?o0000ooooool0ol/01Oooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00Gooooo00Co0?Oooooooooooooooooo0_oo:@02ooooo`;oobT000?o
oooooolY0?oo:@006oooool4o`000006okgo0?l0oj7ooooooooooooohP3o_Ol00olco`04ooooo`04
o`2:oooooooo08Woooooo`;o000000Go0?nQo`3oR?o4o`3o0=Coo`000002o`3oR009okgo0?oooooo
0?mnobCo0?l0oOooooooo`3oHOl0oOoo03?o00;o000000?o0?gookgo0?l0oOl00_l0oOl01_o<o`3o
oooookgo0?o<o`3o02Koolco00;o08[o0_o<o`002ol0003o08[oo`2:ool0R_oo0?nQooooool0GOoo
ooooo`3oLol02Ooo0?n800;o_Ol000?o08[oo`000?l000000_l000001Ol0oOoo05goo`0Vooo<o`3o
00Wo00Co_Ol000Ko0000okgo0?nmo`3o_Ol0ok_o0?nmo`03o`14o`04okgo0?l0003o0000o`09o`;o
2ol00_l0D?l2o`3mo`03o`1Mool0o`co_Ol000;o0?go00So0?mTo`3oHOl?o`3o3ol0o`000?l0R_oo
ooooo`3oe0?o000000?o0?goon7o0?m_o`000ol000000ooooooo/_l0o`3oL`04ooooo`05o`3oCOoo
ooooooooooooool000001?ooool00onco`3oooooooooo`07ooooo`03oiWo0?oooooooooo017ooooo
00?o0000ooooooooool02_ooool00ol0ol_o0000ooooo`1looooo`00OOooool2oolY00;ooooo0_oo
:@001_ooooooobT0oolY0?oooooo0000o`3go`;ooooo00?o0000ooooooooool07oooool3o`000004
o`3oXOnmo`3ooooooooR00;ooooo00Co_Ol0o`2:oolco`3o<ol00_ooool02Ol0R_oo08Woo`3oQOoo
oooo0000ooooool0ROooooooo`3mo`02o`0000Go_Ol000?o03?oo`000?l0of401Onmo`000ol0oOoo
_Ol0okgo0004okgo00;o0?go00?o_Ol0o`2:ool0R_l00_l0R_l00ol0003o_Ol0okgo0002o`0000?o
_Ol000Ko0?mcokgo0?nmo`3o_Ol0o`2:oonmo`02o`3mo`Go0?mc00Soc?l0okgo0?l0of7o0?mQo`00
0?oooooo0?goo`0Vo`?o04Co00Go2ol0o`3oV?l0ohSo05?oo`3oH@02o`000006o`09ool0oj7o2ol0
o`1Iool0003o0?go0_lc0?l01?l0oOoo0?mToooooonmo`02o`3mo`05om3o0?l0003o0000o`3oLol?
o`000oooool2o`000003o`3mool0of7ooooo00;o00000oooool00ol0og?o0?m=ooooo`03ooooo`05
ok?o0?ooooooooooooooool000004_ooool00onIo`3oooooooooo`0Dooooo`03o`000?oooooo0?o;
00Gooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`04ooooo`03o`3gool0003oobT0
00;oobT00_ooool2oolY0003oooooooo:@3oobT001kooooo0_l00002okgo00;ooooo00Koon80oooo
oooooooo_Ol0ooooool0oOl2oc?o00;ooooo00?o08[oo`3oQOl0ROl00_l000001_l0ROoo0?nQo`00
0?l0ohSo0=Coo`0000;oHol000Wo_Ol0o`3oO_mSo`3oHol0olOo0?l0oOoo0?mQo`000?l0R_l00_nm
o`001Ol0oOoo05goo`000?ooooooc?l000?o0?go00Co_Ol0olco0?nmo`3o_Ol00ol0R_l00onmo`3o
0000okgo0005okgo0005o`3oLonmo`3o_Ol0okgo0?l0R_l00_nmo`02o`3mo`Go0?mc0_nmo`001oo<
o`3oooooo`000?l0oOoo08[oo`_o0?nbo`000_l0A?l01?oooooo0?mQo`3oR?l0oj42o`00000?o`09
ool0D?ooooooo`3oHOl0oOooooooo`3mool0GOoo_Ol0o`3mool0003od?l0o`3oI?l0of7o0?n[00;o
00000_l?o`001?oooooo0?oDo`000?l0oOl2ooooo`07on7o0?l0003o0000o`000?oooooo/_l0o`3o
L`04ooooo`05o`3oCOooooooooooooooool000001?ooool00onco`3oooooooooo`08ooooo`03oiWo
0?oooooooooo013ooooo00?o0000ooooooooool02_ooool00ol0ol_o0000ooooo`1looooo`00Nooo
ool2oolY0003o`000?oo:@3oobT000CoobT00oooool2o`0000;ooooo00?o0000ooooooooool08?oo
ool2o`000003o`3oXOl0003o000000Oo_Ol00olco`0:okgo0003o`3moomSo`3o_Ol000;o03?o00Co
ooooo`000?l0003o08[o0onmo`02olOo0004o`3mool0ohSo05goo`3mo`;ooooo0ol0R_l2o`3mo`05
oonj0?l0of7o_Ol0o`000?l0R_l00_l000001ol0oj7o0?mQo`3oHOl0oOoo0?mcolOo0?l0R_l00_l0
oOl00ol09_oo0?mcokko0002o`09o`;o_Ol00ol0og<00ol0003o0?mco`14o`02o`14o`09oh?o0?l0
R_oooooook_o0?l0oiSo0?n8o`3`ool0oOoo0?nQ00;o000000Ko2ol0ooooool0oOoo0?goooooool0
of42o`000005o`3oI?nmo`3o0?goooooool0o``00ol000003?l0og?o0?n[o`oo0?l?o`3oooooo`3o
XOl0003o0?goo`3oHOl0oOoohOl0okgo00?ooooo00?o/_l0o`3oCOooool00oooool01?nco`3ooooo
ooooool0000Dooooo`03oiWo0?oooooooooo01?ooooo00Co0000oooooooooooo0?o;1?ooool00ol0
003oooooooooo`1Jooooo`03o`000?oooooooooo00;ooooo00Co0000o`3goooo:@3oobT00_ooool6
oolY027ooooo0_l000001?l0oj7o_Ol0o`000?l00002ooooo`05okgo0?ooooooooooo`3mooooool0
0_lco`001Ol0R_oo0?n5o`29ool0003oHol000co_Ol00_l0<ol2o`0000Co_Ol000?o0?gookgo0?nm
o`001?nmo`04o`2:o`07o`3oHOo<o`3oc?l0o`0Vool0R_oo0000o`3oH@02o`0000;o0?go00Go0?mc
olOo0?l02Ooo08[oooooo`02o`3mo`03o`09oonno`3ookX000Co_Ol00ol0og<00ol0003o0?mco`3m
o`03o`14o`07ok;o0?l;o`3o^ol0o`3oR?l0oj7o0?goolOo0002o`000003ooooool0oOoo0?go00;o
000000Co0?gookgo0?oooooo0?l<0_l000001Ol0ofCoooooo`2:ool0003o0?mc00;ooooo00Co3ol0
o`3oXOl0omCo00000oooool00ol0oOooooooooooo`02ooooo`03o`3oLooooooooooo00;ooooo00Co
0?m=oooooooooooo00001_ooool00onco`3oooooooooo`07ooooo`03oiWo0?oooooooooo013ooooo
00?o0000ooooooooool02oooool00ol0ol_oooooooooo`1kooooo`00N?ooool3oolY0004oooooooo
:@3oobT0ooooo`;oobT02_ooool00ol0003oooooooooo`0Qooooo`05o`000?l0oj7o0000o`000?oo
hP000_ooool01?nmo`3oHol0of?o0?l0oOl2of?o0004o`3oQOlco`3o<ol0of?o00;ooooo00Ko08Wo
ooooool0oOoo0=Coo`000?l0oOl2o`0co`03om_o0?oooooog_l000?o_Ol000So0?goo`_o0?l0R_oo
0000olOo0?l0oOoo0?n8o`1Mo`?o08[o00Go0?gooonj0?o<o`3o_Ol0olco0003o`3mo`0>o`0Vool0
003o08[ookko0?nmo`3o0?nQoooooolTo`3o0?mco`3mool0R_oo_Ol0o`0Vool02Ol2o`0000;ooooo
00Co2ol0okgo0?o<o`3o_Ol00ol0A?l5o`3oL`;o000000Go^ol0o`3oR?l0oj7o0?nQo`09o`02o`00
0003ok;o0?l0oOoo/_l000;ooooo00Go0?goo`000?nmo`3o0?mTooooo`03oc<0o`08o`2:ool0003o
0?mQo`3oLooooooo0?n[ooooool0oj42o`oo0005o`000?l0of7o0?gookgo0?oQo`001?ooool00ol0
og?o0?m=ooooo`02ooooo`03ok?o0?oooooo000001Gooooo00?oVOl0ooooooooool04oooool01?l0
003oooooooooool0ol/4ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool00_ooool2
oolY0005ooooool0003oobT0oolY0?ooool00_oo:@0Uooooo`03o`000?l0oj7o0?nQ00;o00002Onm
o`02oc?o00?o_Ol00_ooool02?l0oOoo0?nQo`3Dool0oOoo0000om_o0?oNo`3o_Ol00_l0<ol2okgo
0004o`3mool0of7o0000o`2:o`;oaol000Co0?goolOo0?l0oOoo0?go0ol0R_l00oo<o`3o_Ol0oooo
o`03o`3mo`05olco0?l09_oo__l0o`000?o<o`000_l000000ol0oj7o0?n8o`3oL`02o`3mo`05o`2:
ool0oOoo0?mcoooooonno`000_l00002o`_o00Co_Ol000Co0000o`14ool0A?oo04Co0ol0og<00ol;
o`3o0?nHo`000002ok_o0005ok;o0?l;o`3o0000o`000?l0oOl00_ooool2o`3mo`03okgo0?l0GOoo
<`3o00;o<`3o00Ko]_l0o`3oI?l0R_oo0?mQo`000?l0og<3ooooo`08o`3oXOl?o`3o0?goo`000?oo
oooo_Ol0o`3moooQo`03ooooo`03ok;o0?l0og?ooooo00?ooooo00?o0?m=o`000?ooool01_ooool0
0onco`3oooooooooo`07ooooo`03oiWo0?oooooooooo013ooooo00?o0000ooooooooool02oooool0
0ol0ol_oooooooooo`1kooooo`00M_ooool2oolY0005oooooooo:@3oobT0oolY0?ooool00_oo:@0<
ooooo`03o`000?oooooooooo027ooooo1?l00004o`3oX@?ooooo00Go0?goooooool0ohGo08Wooooo
o`03oc?o0008oooooolTo`3o0?goo`3Doooooooo03?oo`1Qooo2o`03okgo0007o`09oooooooookX0
o`3oHOl0oOoo08[oo`000004o`2:o`08o`3oR?ooooooaol0oonj0?o<o`3o0?gookgo0?o<o`02o`00
000?okgo0?l0oOoo0?goo`000?nno`3o_Ol0o`2:ool0oj7o0?goo`3oLol0R_oo00Wookgo0?l0oOoo
00Wo00;o00000_l;o`003Onmo`3o04Coo`14ool0A?oookX0o`0Vooo<o`3o_Ol0o`3mool09_oo_Ol0
oh?o0?l0og<00_l00002o`3oL`08ok_o0?l;o`3o2ol0oh?o0?l0oOoo083oo`3oHOnbo`02o`3mo`03
okgo0?nbo`3o0?mT00?o/_l000Go08[ooc<0ool0003o<`3oo`3oL`02ooooo`05o`3oZol0oj7ooooo
o`3mool?o`000_l000000onmo`3oKol0on7o0003ooooo`03o`3oLol0odgooooo00?ooooo00?o/ol0
o`000?ooool05?ooool00onIo`3oooooooooo`0Cooooo`04o`000?ooooooooooo`3ob`Cooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`02oolY00;ooooo0_oo:@000oooooooobT0oolY
000Wooooo`Co00001Ol0oj43ooooo`04o`3mool0ohGo0000o`0000?o<ol00_ooool01?l0oOoo0=Co
o`3oXOl0oOl2o`0000;o03?o00?o_Ol0o`2:ooooool00_ooool01Ol0of7o2ol0o`2:ooo7o`3o0?n8
00Co08[o0ol0oOl01Oo<o`3o_Ol0oonj0?l0ohSoc?l000;o00000_l0oOl02Ooooooo0000o`1Moonm
o`3o08[oo`3oXOl0og?o0?goo`2:o`02o`3mo`03o`3oLooooooo__l000;o000000Cooooookgo0?o<
o`3ookX00ol0A?l2okgo0004o`3mool09_ooPol0o`1Co`;o0?mc0_l000001_l0og?o2ol0ok_o0?oo
oooo0?gook;o00;o0?go00?o/_l0okgo0?l0of400onbo`001?l0o`co<`3oo`3oI?lc0?l2o`000004
o`3oLol0oj_oooooo`3oX@;ooooo00Oo0?goo`3oHOl0003o0?gooooooom_o`3ohOl000?ooooo00?o
0?mcooooooooool00_ooool00ol0odgo0000ooooo`07ooooo`03ok?o0?oooooooooo00Kooooo00?o
VOl0ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`000?l0ol_ooooo07_ooooo001c
ooooo`?oobT000CooooooolY0?oo:@3ooooo0ooo:@000ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo02;ooooo0ol000001?oooooo08[ooooooonmo`04o`3oX@04o`3mool0003oooooo`29o`;o
oooo00Co08Woo`000?l0003o0?go0_l0<ol02_l0003o_Ol0okgo0?nmo`3o08[oo`09oooooooog_l0
oonj0?l0of43o`2:o`07olOo0?oooooo0?goo`1Moooooooo0?n8oonj0002olco0003o`3moonmo`3o
0?go00;o000000Go_Ol0o`0Vooo<o`3oaol0o`000003o`3mo`06o`3oXOl0R_oo08[ookgo0?l09_oo
oooo0ol00003o`14o`0:olco0?l0003o00Wooooooooo^P3oc?l0o`1Mool0oOoo02Koo`2:o`?o_Ol0
00?o0?n8o`09ool02Ol01?l0og<00on3o`3o0000o`20o`02o`3mo`04okgo0?oooooo05goo`3oI0;o
oooo00Oo08[ook;o0?nbo`3o0000ok;o0?lc0?oo0?mc00;o<`3o00[o0?nQooooool0oOooooooo`3m
oonmo`3o0000oooooom_o`3ohOl00_ooool00onbo`3o0?m=ooooo`03ooooo`03ok?o0?oooooooooo
01Gooooo00?oVOl0ooooooooool04_ooool01Ol0003ooooooooooooooooo0?o;00?ooooo00?o0000
ooooooooool0F_ooool3oolY00;ooooo0_oo:@000oooooooobT0oolY000Zooooo`?o000000Gooooo
o`2:oooooooo_Ol0ooooo`04o`3oX@;o000000Goooooo`29oooooooo08Wooc?o0002o`000003o`3D
ool0oj7o0?go00;o03?o00?o_Ol0o`2:ool0R_l01?ooool00ooo^P3o0?mQo`2:o`02o`2:o`0<o`00
0?l0oOooc?l0olco0?oo^P3oooooolco0?l0oOoo_Ol0o`3mooo7o`3oc?l00_l000001ol09_oo__l0
o`3mool0oOoo0000o`09oonmo`000_l0oOl01?l0R_oo_Ol0o`000?l09_l2o`3mo`Co000000[ooooo
o`14ool0A?oo0000olco0?oooooo04coooooool0oOoo02Ko0onmo`001?l0oiSo0?n8o`_o0?o7o`05
o`3oL`03o`3mool0of7o_Ol000;ooooo00?o0?mQooooooooool00_l0R_l00onbo`3o0?mTo`000002
oc<0o`03o`3oLolc0?oo0?nQ00;ooooo00So0?goo`3oHOnmo`3o0000o`oo0?m_o`3oooooon7o00;o
oooo00?o0?mcooooooooool00_ooool00ol0003o0?m=ooooo`07ooooo`03ok?o0?oooooooooo00Oo
oooo00?oVOl0ooooooooool03oooool00ol0003oooooooooo`0;ooooo`03o`000?l0ol_ooooo07_o
oooo001aooooo`;oobT00_ooool2oolY0003oooooooo:@3oobT000?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Sooooo`;o000000Cooo/0o`2:oooooooo_Ol00oooool02?l0ohGo
0000o`3mool0oj7o08Woo`3oXOl0ROoo08[o0_l000001?l0<ooo0=Cookgo0?l00007o`2:o`;o0000
00Oo0?mQooooool0oOooaol0o`3oR?oooooo0?go00;ooooo00?ookX0olco0?ooool00_l000001_nm
o`3oc?l0onko0?nmo`3o02Koolco00;o0?go00Wo0000olOo0?l0oOoo08[oo`3oLol0of7o_Ol0o`0V
ool0R_l00ol0A?l04Ol0003o0?goo`3Rooo<o`3o0000ooooool02Ooo0000olco0?oooooo0?goo`0V
ool0R_oo0?goo`_o0?l0003o0?n800?o_Ol00_l0oOl00onko`3o0?mco`3oL`03o`3oL`;o0?mQ00go
05goo`3oI?l0of7o08[oooooool;o`3o0000ojWo0?l0o`co0?mQo`3oLooooooo0?nQ00;o<`3o00So
0?gook;o0?l0oOoo0000ok;o0?l0003oKol0on7o00?ooooo00Ko0?m=ooooooooooooooooo`000?nc
o`0Gooooo`03oiWo0?oooooooooo01;ooooo00Go0000ooooooooooooooooo`3ob`03ooooo`03o`00
0?oooooooooo05Sooooo0_oo:@000ol0003oooooooooo`02oolY0004oooooooo:@3oobT0o`0002co
oooo00Ko0000oooooooon`3o08[ooooooonmo`04ooooo`04o`000?l0oj7o0?goo`3oX@;o08Wo00Go
ooooo`2:ool0003o0000o`3Do`02o`0co`03o`2:ool0003o08[o00Go08[o0_l000002?l0R_oo0?go
oonj0?l0ohSo0000o`1Mool0oOoookX00_ooool01?o<o`3o0?gooonj0?nmo`02o`000008okgo0?o^
o`3o00Wookko0?l;o`3oaol0o`2:ool00002o`3mo`07o`2:ool0of7o_Ol0o`0Voooooooo00Wookko
0004o`00000?o`14ooo<o`3ookX0o`000?o<o`3o05goooooool0C?oo0?goo`0Vool0oj7oPol0o`3m
oonmo`3o0?n800;o_Ol000?oooooo`3mool0oOl00_nko`04o`3oL`0Jo`3oHOl0GOoo0?mQo`2:oonf
o`3o2ol0ojWo0?l0ofCo0000ooooool0of7o0?mcooooool0oj7o<`3oo`3moonbo`3o0?mQokgo0?l0
oOoo0000ok;o0?m_o`3o3ol0on7o0?ooool2o`0000;ooooo00?o0000ooooool0odd02Oooool00onc
o`3oooooooooo`06ooooo`03oiWo0?oooooooooo00oooooo00?o0000ooooooooool02oooool00ol0
003oooooo`3ob`1kooooo`00Koooool2oolY0003oooooooo:@3oobT000CoobT01Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02?ooooo0ol000000ooon`3o08[oo`2:o`03o`2:o`;o
000000Go08[oo`3mool0ROoo08[oo`3oX@02o`0co`09okgo0?l0e?oo067oo`3mool0R_oo0000o`3o
XOl02Ooo_Ol000;ooooo00oookX0o`000?l0003oooooo`3oHOl0R_oo0?goo`3oR?o<o`3o0?gooooo
oooo^P3o0?goolco0?l0ROl00_l000001?nmo`3oc?l0onko0?nmo`03o`3mo`07okko0?o7o`3o0000
o`2:oooooooo0?mco`3mo`03o`14o`07o`3on?nmo`3o08[oo`09oooooooo0?goo`000003ooooo`0=
o`000?o<o`3oooooo`3mool0C?oo02Koo`3oXOl;o`3o0?n8o`3oV?l;o`3o0?nQo`3mo`04okgo00;o
^ol000?o_Ol0ooooool0og<00_l0og<03?l0ofCo0?mco`3oHOoooooo2ol0o`000?nYo`3o0?l<o`3o
HOl0og?oooooo`3oX@;ooooo00Wo0?gooc<0ool0oOoo0?mQooooool0omCo0000o`oo0?oQo`000ol0
00001_l0odgoooooooooool0003ooooook?o01Kooooo00?oVOl0ooooooooool04_ooool00ol0003o
ooooooooo`02ooooo`04o`3oboooooooooooo`0005Sooooo0_oo:@02ooooo`KoobT00_ooool00ol0
003oooooooooo`0Zooooo`?o000000?ooo/0o`2:ool0R_l00ol0R_l3o`000003o`2:ool0oOoo08Wo
00Co0?nQ0_l0<ol01Ol0oOoo`_l0o`2:ool0003o00Wo00;ooooo00?o_Ol0ooooooooool00_l00000
3_oooooo0?mQo`3mool0ohSo0000o`1Mool0oOooc?l0o`3oR?o<o`3o0?gooonj0?l0003o_Ol00_l0
00001?nmo`3ok_l0o`3moonno`03o`3mo`07olco0?l0003o08[oo`3oLol0oOoo0?nQo`0Vo`02o`2:
o`04o`3on?l0A?oo04Coo`3Ro`;o0?go00ooooooo`000?l0003oc?l0o`000?l0GOoo04coo`3mool0
9_oo0?gooh?o0?l02Ooo0?n8olOo0?l02Ol00_l0oOl2okgo0004o`3moooooooo^ol0ok_o00;ooooo
1Ol0og<02?l;o`3o0?l<o`3oI?l0003oooooo`3oHOl0og?o0?nQ0_ooool02Ol0oOoo<`3ookgo0?l0
oOoo<`3oooooool0003oKol0ok;o0004o`0000;ooooo00Co0000oooooooooooo0?m=2?ooool00onc
o`3oooooooooo`06ooooo`03oiWo0?oooooooooo00oooooo00?o0000ooooooooool02oooool00ol0
003oooooo`3ob`1kooooo`00K?ooool3oolY0004oooooooo:@3oobT0ooooo`;oobT02?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo0ol000001?oon`3o_Ol0ooooooooool3
o`000003ooooool0R_oo08Wo00;o000000Co_Ol0oooooooooooo0=Co0ol0oj401_l0003o0?nQo`09
ooo[o`3o_Ol0ooooo`;o000000Soooooomko0?l0of7o08[oo`_o0?l0oOooc?l0o`1Mo`;o0?go013o
c?l0oooooooo^P3oooooo`000?l0ohSo_Ol0onko0?l0oOoo02Koooooool0GOooaol0o`3mool0R_oo
00000ol0A?l01_l09_oo0?goo`3on?l0oOoo0?mcooooo`;o08[o00?o0000olOo0?l0oOl00_l0oOl0
2oooooooc?l0o`09ool0oOoo0?nQo`0Vool02Ooo2ol0o`3oR?l;o`3o0?nQ00?o0?go00?oPol0oooo
ool0oOl00_nmo`02ok_o0005ooooool0GOoo08[oo`3oI?l0of401Ol0og<01Ooooooo0?l<o`3oLooo
oooo0?nQ00;ooooo0_l0oOl00ooooooo0?mco`3oL`02o`3oL`03o`000?l0og?o000000;o000000?o
0?m=ooooool000000_ooool00onco`3oooooooooo`0Dooooo`03oiWo0?oooooooooo01;ooooo00?o
0000ooooooooool00_ooool01?l0ol_oooooooooool0001Fooooo`;oobT00_ooool2oolY0003o`00
0?oo:@3oobT000Gooooo00?o0000ooooooooool0:oooool2o`000003oooooooon`3o_Ol000;ooooo
1?l000000ooooooo08[oo`29o`02okgo00;o03?o00?o0=Coo`3oXOl0oj400ol0oj401Ol0003ooooo
oooooonmo`3og_l000;o000000SookX0ooooooo7o`3o0?mQo`3mool0003o05goo`29o`;o0?go00[o
c?l0oonj0?l0003oooooo`3oR?nmo`3oc?l0okgo0?l09_ook_l00ol0oOl01ol;o`3o08[oo`2:ool0
003o0?mcokgo0?l0oOl00_l0A?l01?l0ooSo0?mco`2:ool0R_l2olOo0005olco0?l0003o0?goo`3m
ooo<o`000_l000001?l0oj7o0?goo`0Vool02Ol2o`_o0004o`3oR?l0oOoo0?gooh?o00;ooooo00?o
Pol0okgo0?nmo`000_nmo`001Onko`3oooooo`2:ool0R_oooooo00;o00000_l0og<00ol0ofCo0?mc
o`3oL`02o`000007o`3oXOooooooooooo`3moonmo`3oooooo`3mo`03o`3oL`Go000000?o0?mcoooo
ool000000oooool00ol0odgoooooooooo`07ooooo`03ok?o0?oooooooooo00Gooooo00?oVOl0oooo
ooooool03oooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`3obg[ooooo001Zoooo
o`;oobT000GooooooolY0?oo:@3oobT0ooooo`02oolY00[ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Uooooo`;o000000Cooooooook0?l0003o00001?l0<ol01?nmo`3o08Woo`00
0?l00002o`2:o`06o`1Qool0e?ooooooo`3moooooooo00001?l0oj400ooooooo0000o`000003oonj
000<o`3oHOl0R_oo0?n8o`3mool0GOoo0?goooooooo<o`3ooooooonj0?l0003ooooo0_l0oOl01_o^
o`3o_Ol0o`0Vool0GOooaol0okko00?o04Co00Oo0000o`3oLonmo`3o_Ol0o`3on?nno`3o05?o00?o
0?go00Ko0000olco0?l0R_oo08[oo`3Rooo7o`02o`3mo`08o`3oXOl0oOoo08[oo`0Vool;o`3o0?n8
olOo0?n3o`02o`3mo`;o05go00OoPol0o`3moon3o`3o_Ol0ooooool0P?oo_Ol000;o^ol000Co_Ol0
o`3oI?oooooooooo0ol000001?l0of7o0?mco`000?l00007o`3oL`04oeko0?ooooooooooooooo`;o
000000Go<Ol0ooooool0003o0?m=o`000003ooooo`03ok?o0?oooooooooo01Gooooo00?oVOl0oooo
ooooool04Oooool00ol0003oooooooooo`03ooooo`03o`3obooooooo000005Cooooo0_oo:@02oooo
o`;oobT000?ooooooolY0?oo:@001oooool00ol0003oooooooooo`0/ooooo`;o000000?ooooooook
0?ooool00_l00002ooooo`04o`0coonmo`3o_Ol0o`29o`;o000000Woooooo`1Qool0e?oo08[oo`3m
ooo2o`3oooooo`3oXOl000000ol0oj405?nmo`3o0000o`000?oooooookX0olOo0?l0of7o2ol0o`3m
ool0GOooooooo`3mooo<o`3ooooooonj0?l0003oooooo`3oR?nmo`3oc?l00_l0oOl01Oo^o`3o__l0
olOo0?lTo`3o0?go00;o08[o00Ko0000o`3oLol0A?oo04Cookgo0?l0ooP3o`3mo`04o`09ool0R_oo
08[oo`0000;ooooo00coaol0o`3mool0oOoo0?nQolOo0?l0oOoo02Koo`_o0?l0oj7oPol0o`3oR?l0
oOl3o`1Mo`03oooooonmo`3o_Ol000?ooooo00Co_Ol0ok_o0?nko`3o05go0_ooool2o`000004o`3o
HOl0ofCo0?mQooooo`;o00001ol0og<3ooooo`?o000000Co<Ol0o`000?l0003o00001Oooool00ol0
odgoooooooooo`06ooooo`03ok?o0?oooooooooo00Kooooo00?oVOl0ooooooooool03_ooool00ol0
003oooooooooo`0;ooooo`04o`000?ooooooooooo`3obg[ooooo001Xooooo`;oobT000CooooooolY
0?oo:@3ooooo0ooo:@0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09Oooool0
1ol0003oooooo`000?oon`3o0000o`0cooooool00onmo`004?oooooo08Woo`29ool0oOooooooo`00
0?l0R_oo0=Coooooool0oOooooooo`09ool0003o`_l0o`3oXOooool4o`3oX@05oooooooNo`3o0?mQ
o`2:ooo<o`000_l0oOl01Ooooooo0?goolco0?oo^P3ooooo00;o0?go00Go0?n8olco0?o^o`3o_Ol0
o`0Vo`03o`14o`0=o`2:oooooooo0?mQokgo0?l0003o_Ol0o`3on?nno`3oooooo`3oXOl0og?ooooo
o`000003o`3mo`05ooooool0R_oo08[oo`3mooo<o`000_l0oOl01?l0R_oo02Koo`000?l00002o`3m
o`0?ooooool0003o0?3oooooool0GOoo0?gookgo0?l0GOoo0000ooooool0P?oo08[oo`1Moonko`3o
0?mT00?o_Ol000Co0000o`3oHOl0of7ooooo0_l000002Ol0oj7oooooooooool0oOoo_Ol0o`3moooo
oooo0?n[oeko0002ooooo`;o000000Go<Ol0ooooooooooooooooo`3oC@04ooooo`03ok?o0?oooooo
oooo01Cooooo00?oVOl0ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`3obooooooo
0000057ooooo0ooo:@02ooooo`;oobT000GooooooolY0?oo:@3oooooo`000007ooooo`03o`000?oo
oooooooo02cooooo0_l000000ooooooo0000oook0002o`0co`?o_Ol00_ooool03?l0ROoo0000o`00
0?l0003o08[oo`3Doooooooo0?gool;o0?l02Ooojol0o`0000?ooooo1?l0oj401Oo7o`3o08Woo`2:
ool0of7ookX000;o0?go00Coc?l0o`3moooo^P3o0?n80_ooool02?l0ohSo0?goo`3moonmo`3o02Ko
onko0?nno`3o9?l00_ooool01Ol0R_oo04Coo`14ool0A?oo_Ol000;ooooo00Co0?oho`3oXOl0og?o
oooo0_l0oOl01ol0003oooooo`2:ool0R_ooooooolco0?l0oj400ol0oOl02_l09_oo2ol0o`000?l0
003o0?goo`09ool0l?oooooooh?o0?nmo`03o`1Mo`03ooooool0R_oo08[o00;ooooo0_nko`02okgo
0004ojWo0?l0003o0?mTo`3o30;o0?mQ00So0?mcoooooooooooo0?gookgo0?l0of7o0?gooeko00;o
000000Goooooo`000?l0003o0000oc7o0002ooooo`03o`000?oooooooooo00?ooooo00?o0?m=oooo
ooooool01oooool00onco`3oooooooooo`05ooooo`03oiWo0?oooooooooo00kooooo00?o0000oooo
ooooool02oooool01Ol0003ooooooooooooooooo0?o;07Wooooo001Sooooo`;o00000ooo:@001?oo
ooooobT0oolY0?ooool2oolY00oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0V
ooooo`?o000000?ooo/0okgo0?nmo`001?ooool04?l0ROooooooo`000?l0oOoo0000o`3Dool0oOoo
ooooo`3mool02Oooa?l0o`000?o2o`3o0?nQoooooonmo`03ooooo`Go0?nQ00GookX0o`1Mool0oOoo
0?goolco0002o`3mo`04ooooool0ohSoooooo`3oR0?o04Co0_ooool04Ol0R_oooooookgo0?nmo`3o
08[oo`3oLol0ooSo0?gookko0?l0oOooooooo`3oLol0003oooooolco0?oooooo00Wo00?o0?go00Ko
c?l0o`2:ool0R_oo0?goo`2:ool09_l2o`00000:ooooool0oiSoPol0o`000?l0ofCo0?3oo`3moonm
o`3ooooooh?o00;o05go00Wo08[oooooool0GOooooooo`3oI?nko`3oooooo`_o0?l000000_nmo`00
1?l0of7oooooo`000?l00002ooooo`;o0?go0_ooool2o`0000;ooooo00OoO?l0oooooolao`3o0000
ooooool0003o0?m=00Cooooo00?o/ol0ooooooooool05?ooool00onIo`3oooooooooo`0Aooooo`03
o`000?oooooooooo00Cooooo00?o0?o;o`000?ooool0C_ooool2oolY00?ooooo0_oo:@000ooooooo
obT0oolY0003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Oooool3o`000003
oook0?nmo`3o_Ol000Cooooo0_l0ROl03?oooooo0?goo`2:ool0e?oo0?goooooool0oOoo00Wooooo
ooo[o`3oooooo`0000;ooooo00Co_Ol0oooooooooooo08Wo1Ol0oj401ol0GOoo0?goolco0?l0oOoo
ooooo`000?l0ohP00_l0oOl01oo<o`3o_Ol0okgo0?l09_ook_l0okko0?lTo`000ol0A?l02Onmo`3o
08[oo`3oLol0003o_Ol0o`3on?nno`3oooooo`3oL`02o`1Co`03o`000?o<o`3o0?go00;o0?go00So
08[oolco0?l0R_oo00Woo`2:ool0oOoo02Koo`3mo`;o000000GoPol0ooooool0l?oooooookgo0002
ooooo`03oh?o0?oooooo08[o00?o05go0_l000002Ooooooo^ol0o`_o0?nmo`3o0000o`3oI?nmo`3o
0?mQo`3oX@02o`000004ooooool0oOoo_Ol0o`3mo`;ooooo0_l00002ooooo`05ogco0?oooooo<Ol0
ooooool000001_ooool00ol0odgoooooooooo`07ooooo`03ok?o0?oooooooooo00Gooooo00?oVOl0
ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool0ol/0NOoo
ool006?ooooo0_l000001OooooooobT0oolY0?oo:@3ooooo00;oobT04Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo02Oooooo0_l000000ol0ok[ooo/0ooooo`04ooooo`08o`29oooo
oooo0000o`000?l0oOoo0=Coo`3mool00002o`3mo`07ooooool0003o`_l0on_o0?l0oj7ooooookgo
0002o`29o`05oooooooo^P3oaol0o`2:ool0of400ol0oj42o`3mo`03o`000?oooooooooo00?o04Co
00Gok_l0okgo0?l09_ooooooo`2:o`02okgo00;ooooo00_o_Ol0o`3on?oooooo0000okko0?l;o`3o
0?goo`000?l0oj7o05?oolco0002ooooo`03o`09ool0oj7ooooo00;o0?go00Go05?oo`3mool0R_oo
02Koo`3oR002o`3mo`06o`3oV?n3o`3oooooo`3oI?l0oOoo_Ol00_ooool01?n3o`3o08[oo`2:oooo
ool2o`000003ooooool0ofCooooo00;o^ol000?o0000oooooonYo`000_nmo`02o`0000;ooooo0_l0
oOl2ooooo`;o00000_ooool00omlo`3ooooooc7o0002o`000003ooooool0odgooooo00Cooooo00?o
/ol0ooooooooool05?ooool00onIo`3oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o
0?o;o`000?ooool0C?ooool2o`0000;ooooo1_oo:@05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0;_ooool2o`000003o`3o^_oon`3ooooo00Cooooo0_l0ROl2o`00000Eo`3mool0
e?oo0?goo`000?l0oOoooooool;o0?o[o`3oooooo`000?l0oj7oooooo`29oonmo`3o08Woomko0?o7
o`3o0?n8o`000?l0R_oo0?mQ00Co0?nQ0ol0oOl01ol0ohSoooooolco0?o<o`3o_Ol0o`0Vooo^o`00
0_l0A?l02Ol0R_oo_Ol0oooooooooooo_Ol0o`3oLooooooo0?ohokko0002o`3mo`05o`3oLol0oj7o
0000o`1Cooo<o`000_ooool04?l0oj7o0?goo`3mool0oOoo08[oo`_o0?l0oOoo02Koo`3mool0ohSo
0?goo`09oon3o`3o0?mTokgo0?n3o`02ooooo`03oh?o0?l0R_oooooo00?ooooo0_l000001ooooooo
2ol0ok_o0?nko`3o0000o`3oI?ooool00_nmo`02o`000004ooooool0oOoo0?mQo`3mo`;ooooo00So
?ol0ooooooooooooooooogco0?oooooo0000oc7o00Sooooo00?o0?m=ooooooooool01oooool00onc
o`3oooooooooo`04ooooo`03oiWo0?oooooooooo00kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`02ooooo`03o`3obooooooooooo07Kooooo001Tooooo`;o000000CooooooolY0?oo
:@3oobT04oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Sooooo00Ko0?njo`00
0?oooooooo/0o`000?ooool2o`000003o`29oooooooo02co00;ooooo0_l0oOl2o`000008ooooool0
oOooa?l0o`000?o[o`3o08Woo`3oXOnmo`03ooooo`05o`3mooo7o`3o0?n8o`3oHOl;o`000_l0oOl0
0ooo^P3o0?goo`14o`02o`14o`09o`3oR?oooooo0?n8olOo0?o^o`3o02Koo`2:oonmo`3o0?mQ00?o
oooo00co_Ol0o`3on?oooooo__l0o`000?oooooo0000o`3oLol0oOoo0?nQolco0?l0Dol2o`3oX@;o
000000?oc?l0o`1Cool0oOl00_l0oOl01?l09_oo0000o`000?ooool2o`3mo`04oooooonmo`3o_Ol0
oh?o00;ooooo00Co08[oo`000?oooooooooo0_l000001Ooooooo0?mTo`_o0?oooooo000000;o^ol0
00GoZOl0oooooooooooo0?nQo`3oL`02okgo00;o0?go0oooool01_loo`3ooooooooooomlo`3ooooo
oc7o00?ooooo00?o0?m=ooooooooool00oooool00onco`3oooooooooo`0Dooooo`03oiWo0?oooooo
oooo013ooooo00?o0000ooooooooool01Oooool00ol0ol_oooooooooo`1;ooooo`;o00000_oo:@00
0oooooooobT0oolY0008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool3
o`000003oooooooon`3ooooo00?ooooo0_l0ROl2o`000004ooooool0e?oo0?goo`0000;o0?go00So
`_l0on_o0?oooooo0000o`3oXOl0ROoooooookgo00;ooooo00Soaol0o`3oR?l0oOoo08[oo`3oHOl0
GOooc?l0o`0000;o0?go0ol0oj400ol0ohSo0000olco0002o`14o`03ooooooo^o`3o08[o00Cooooo
01;o_Ol0o`2:ool0ooSoooooo`000?l;o`3oooooo`3mool0003o0?goooooooo<o`3o00Woo`3oXOl0
2Oooc?l0o`3mool;o`03o`3mo`04o`0Vool0R_oo0000o`0000;o0?go00Co_Ol0o`3`oon3o`3ooooo
0_l0R_l00ol0P?ooooooooooo`05ooooo`09o`_o0?nYo`3o0000ok_o0?l0ofCoooooo`3o3?l0oj7o
0?mc00;o_Ol00_l0oOl3ooooo`08ocoo0?oooooooooooooooomlo`3o0000oooooolao`08ooooo`03
o`3oCOoooooooooo00Oooooo00?o/ol0ooooooooool01Oooool00onIo`3oooooooooo`09ooooo`co
GOl01_ooool00ol0003oooooooooo`02ooooo`03o`3obooooooooooo07Kooooo001Tooooo`?o0000
5_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Sooooo00Go0?njooooool0003o
oo/0ooooo`03o`000003o`29ool0;?oooooo00;ooooo00?o0=Coo`3mool02Ol00oooool01ol0oOoo
0000o`29ooo[o`3o0?nQoooooonmo`000_l0oOl00oo7o`3oooooo`3oR002o`000005olco0?l0A?oo
04Coo`14ool0oOl00_ooool4o`3oX@05onko0?l0R_oo9?l0o`3oHOnno`000_ooool01Ol09_oo0?oh
o`3oLol0R_oo__l000?o000000Co0?mco`_o0?o<o`3o0?nQ0_l000001ooooooo0000o`09ooo<o`3o
2ol0ooooool0oOl01?l00003o`2:o`08okgo0?l0oOoo0?gooooooon3o`3o08[ooh?o0?l00003oooo
o`08o`20oooooooo0?mTo`_o0?oooooo0000okKo0?ooool2ok_o0003o`3oXOoooooo0?mc00;o0000
00?o0?goooooooooool00_ooool00oloo`3oooooogco0002o`000003oc7o0?oooooooooo00;ooooo
00?o0?m=ooooooooool00_ooool00onco`3oooooooooo`0Dooooo`03oiWo0?oooooooooo00?ooooo
4_mMo`03ooooo`03o`3obooooooooooo04_ooooo0_l000000oooooooobT0oolY000:ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0;oooool01_l0ok[oooooo`000?l0003ooo/0oooo
o`;o000000?oooooo`29ooooool00_ooool01ol0e?oo0?goo`09ooo4o`3oooooo`3mooo[o`000_l0
ROl02_l0003o0?nQoooooooooooo_Ol0ooooooo7o`3o0?n8ooooool0R_l2o`0000?o0?go00Cooooo
o`3moooooooo0?n80ol0A?l2o`3oX@03okgo0?o^o`3ooooo00?ooooo00Wo_Ol0o`0Voooooooo0?oh
oooooonno`3o0000o`_o0?l000000_ooool2o`3mo`;o000000Oo0?goolco0?l;o`3o0?nQo`000?l0
R_oo0?go00Co000000?ooooookgo0?l0oOl00_l0oOl01Ol0R_oooooooh?o0?oooooo083o00Gooooo
00_o2ol0okKo0?nYo`3o0000ooooool0ofCo^ol0o`3oXOl0o`co0?mcooooo`02o`000005o`3moooo
ooooooooooooooloo`000_ooool01Ol0003oO?l0oooooooooooo<Ol000Wooooo00?o0?m=oooooooo
ool01?ooool3oego0003ok?o0?mMo`3oGOl0013oGOl01?ooool00ol0003oooooooooo`03ooooo`;o
00001_ooool00ol0003oooooooooo`03ooooo`03o`3obooooooooooo07Gooooo001Uooooo`;o0000
5_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Sooooo00Ko0?njoooooooooooo
oooooook0?ooool2o`000009o`29ooooooooooooooooool0e?oo0?goo`09ool0oOoooooo00?o08Wo
00Koooooo`000?o[o`3oooooo`3oXOnmo`02ooooo`;o0?go1?l0A?l01?l0GOoo0000olco0?l0oOl2
ooooo`06o`3oR?o7o`3o_Ol0o`000?o^o`3o_Ol00ol0oj400ooooooo02Koo`3on002ooooo`05o`3o
Lol0003oooooo`000?ooool00_l000001Oo<o`3o0?nQo`000?l0003o05?o00;o0?go00Co2ol0oooo
ool0oOoo0?go0_l000000ol09_ooooooo`3mo`02o`3mo`?o08[o0_l0oOl01?ooooooPol0ooooool0
0002ooooo`03o`20oooooooo0?mT00;ooooo00Go0000o`3oXOl0oj7o0?nQo`000002ok_o0004o`3o
Lol0003o0000o`3mo`Cooooo00?o?ol0oooooomlo`000_ooool01_lao`3oooooooooooooooooGOl0
o`3oC@GoGOl000?o/ol0oego0?mMo`006OmMo`0=ooooo`03o`000?oooooooooo00;o00000oooool0
0ol0ol_oooooooooo`1;ooooo`?o00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo02oooooo00Ko0?njooooooooooooooooo`000?oon`03o`000008o`29ooooooooooooo`3Doooo
oooo00Woo`3mooo4o`02o`29o`;o0?go00_oooooo`000?oooooo0?nQoooooonmo`3oaol0oonj0?l0
ohSo0000o`3mo`02o`000004o`1Mooooooooc?l0o`3mo`?o04Co00CoooooolOo0?nmo`3o_Ol00_l0
00000oo^o`3o0?nQo`3oX@02ooooo`06okgo0?oooooo0?oho`3oLonno`3ooooo0ol000001?oooooo
0?nQolco0?l0oj42o`000004o`1Cool;o`3o0?nQooooo`?o0?go0_l000001ol0oiSo0?goo`3mool0
oOooPol0o`3`ool0R_l00_l0oOl00oooooooPol0o`20o`05ooooo`07o`_o0?oooooo0000o`000?l0
oj7o0?mTo`000002ok_o0005o`3oLooooooo0000o`000?l0oOl00oooool01Oloo`3oooooo`000?mM
o`3oO?l000;oGOl000?o<Ol0oego0?mMo`001omMo`000ol0odgoGOl0oego0004oego00?ooooo00?o
/ol0ooooooooool01?ooool00onIo`3oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00oooool00ol0ol_oooooooooo`1eooooo`00OOooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo02Sooooo00?o0?njooooooooool00_ooool01?oon`3o0000o`000?l0
0003ooooo`05o`3Dool02Oooooooo`29ool0oOl00_ooool01Oo4o`3oooooo`000?l0oOoooooo00?o
0?go0ol0A?l05_o7o`3o08[oolco0?l0of7o05goo`3oXOooooooc?l0o`3mooooooooaol0okgo0?l0
R_oo0000onko0?l0of7o_Ol0olco0?nno`3o0?nQo`3on?nmo`02o`000007o`3oLol0R_ooooooo`00
0?nmo`3o0?mco`3oX@02o`0000;o0?go00ko0?nQo`000?l0003oc?l0o`3moooooooo0?goooooool0
ohSo02Koooooool0003o_Ol0ooooo`?o0?go00Ko0000oh?o0?l0oOoo0?goooooool00003ooooo`08
o`20ool0ofCo0?nQo`000?l0oj7o]_l0oooooonYo`02ooooo`03o`000?l0oOoo0?go00;o0?go0omM
o`001?loo`3o0000o`000?mlo`02oego0006oc7o0?mMo`3oGOl0oego0?oooooo0?m=1Oooool00onc
o`3oooooooooo`0Dooooo`03oiWo0?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0
003o0?o;ooooo`1<ooooo`;o00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02kooooo00?o0?njooooooooool00oooool00ol0003ooo/0o`27o`02o`0000;ooooo00_o0=Coo`09
ool0oOoo08Woo`3moooooooo`_l0ooooooo[o`3o0?goo`000002ooooo`03o`3oXOnmo`3oaol000?o
0?go00Gog_l0olco0?oo^P3o0?mQo`_o0002o`14o`;o0?go00Go0?n8okgo0?nmo`3o08[ookgo0002
o`000003onko0?o<o`3oc?l000?o0?nQ00?o0?oho`3oXOl0og<01?l000002?l0og?o0000o`000?o<
o`3oooooo`3oXOoooooo2ol00_l000002_l0oOoo08[oooooool0oOoo0>;oo`0Vool0oiSo_Ol0o`3m
ooooool3o`3mo`;o00000_l0oOl00ol0P?ooooooooooo`02ooooo`04o`_o0?l0oj7o0?nQo`0000?o
oooo00?o0?mTooooool000001?l0oOl4oego0005ocoo0?l0003oGOl0oooooomlo`000_ooool00ola
o`3oooooooooo`08ooooo`03o`3oCOoooooooooo00Oooooo00?o/ol0ooooooooool00oooool00onI
o`3oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0
ol_oooooooooo`1dooooo`00OOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02So
oooo00?o0?njooooooooool00oooool01?oon`3o0000ooooool0ROl2ooooo`05o`3Dool0oOoo08Wo
ooooool0oOl00_ooool00oo4o`3oooooo`000002o`0000?o04Co1?l000001Oo7o`3oc?l0olOo0?l0
of7o0?nQ00;o000000co0?goolOo0?l0R_oo0?n8o`1Mooooooook_l0o`0Voonmo`3o02Koo`000?l0
ooP2o`000003olco0?l0oj7o0?mc00;o0?nQ00?o0000okgo0?l0og<00_l000001?l0oOoo0000o`00
0?l;o`02o`00000>o`3mooooooooooooo`3mool0ohSoooooo`0Vool0h_oo_Ol0o`000?oooooo0?mT
oh?o0?l00009o`3mo`06o`3oI?l0oOoo0?goo`000?oooooo]_l01Ol0oOl2o`000003o`3mool0o`co
oooo00;ooooo00Co?ol0ooooooooooooO?l00_ooool00olao`3oooooooooo`03ooooo`03o`3oCOoo
oooooooo00;ooooo00?o/ol0ooooooooool05?ooool00onIo`3oooooooooo`0?ooooo`03o`000?oo
oooooooo00Gooooo00?o0000o`3oboooool0F_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02kooooo00?o0?njooooooooool01?ooool01?l0;?oooo/0o`000?l0ROl2ooooo`09o`3D
ool0ROoo0?goooooooo4o`3o0?gool;o0?oooooojol000;ooooo0ol00002o`3mo`;o00000_o7o`00
1Oo<o`3o04Coo`14ool0A?ooc?l000;ooooo00_o0?gookgo0?l0R_oo08[oo`000?nmo`3o02Kookgo
0?nno`3ok_l0o`0Vo`02o`000004o`3on?l0003o0000o`3oL`?o0?nQ00?o0000o`3oLol0oOl00ol0
0002o`_o000;o`3oXOl0003o0000ooooool0R_oo02Koo`3mool0ohSo02Kookgo0?l000000_ooool0
1Ol0ofCoPol0o`000?l0oOoo000000[o0?go00Go0000oooooooooooo0?goo`3oI002o`3mo`?o0000
00Ko0?goooooooooooooooooo`000?loo`03ooooo`04ogco0?oooooooooooc7o00[ooooo00?o0?m=
ooooooooool01oooool00onco`3oooooooooo`04ooooo`03oiWo0?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`3obooooooooooo07Cooooo001moooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09oooool00ol0ok[oooooooooo`04oooo
o`03o`0/oooon`3o000000?o000000?o0=Coo`3mooooool00_ooool01?l0oOooooooooooool0oOl3
o`14o`;ooooo00[o0?nQokgo0?ooooooc?l0ooooooo<o`3o08[oo`000?o7o`3o0?mQ0_nmo`003Oo7
o`3o0?goo`3mool0ohSo05goo`3oHOo^o`3o02Kookgo0?oooooo0?oho`000?nmo`000_ooool01Onn
o`3o0?mcooooool0R_oo000000;o0?nQ0_l00002ooooo`05o`_o0?l0003o0000o`3mooo<o`000_oo
ool01_l0oOoo2ol0ooooool09_oo_Ol0o`3Ro`;ooooo00Go0?mToooooon3o`3o0?3oo`000002oooo
o`09oh?o0?l0oj7o0?nQo`3oXOl0oOoo0?mTo`20ool0oOoo000000[o0?go00Go0?l<ooooool0003o
0000ocoo0002ooooo`04ogco0?oooooooooooc7o00Gooooo00?o0?m=ooooooooool00oooool00onc
o`3oooooooooo`0Dooooo`03oiWo0?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0
003oooooo`3ob`1Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool00ol0
ok[oooooooooo`03ooooo`05o`0/oooooooooo/0ooooool000000_l0ROl02ol0e?ooooooo`3moooo
ooooa?l0ooooool0oOooooooon_o0?oooooo0?go00?o000000Co0?nQokgo0?oo^P3ooooo0ol0A?l0
0ooooooo05goo`3oH@03okgo000;o`2:ool0oOooooooo`3oR?l0of7o_Ol0o`0Voonmo`3o__l0onko
0?ooool00_l000001ol0ooSo0000ooooool0og?oooooo`2:ool0oOl00ol0oj42o`000005o`_o0?l0
003o0000o`3oXOl0oOl00_ooool01ol0R_oo2ol0o`3moooooooo02Koo`3mool0h_l00_ooool01?l0
ofCooooooh?o0?n3o`02ooooo`04oh?o0?l0003o0?nQo`3oX@;o0?go00CooooookKo0?l0003o0000
0ol0oOl00ol0ofCo0?goo`3mo`03o`3mo`06o`000?oooooo0000o`000?oooooo?ol00oooool01?ml
o`3ooooooooooolao`0;ooooo`03o`3oCOoooooooooo00Oooooo00?o/ol0ooooooooool00oooool0
0onIo`3oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool0
0ol0ol_oooooooooo`1cooooo`00OOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02Oooooo00?o0?njooooooooool00oooool01?l0;?oo08Oooook0?ooool2o`000003o`3Dool0003o
0?go00?ooooo00Ko0?goo`14ool0A?oo04Cool;o0?l00004ooooo`07okgo0?o<o`3o0000oonj0?o<
o`3o08[oo`3oR002okgo00;o000000Ooooooo`3mool0ohSo0?goo`3oHOlTo`3ok_l000;o000000?o
0?ohokko0?nmo`000oooool02Onno`3o0?mcooooool0oj7o0000o`3mool0003o_Ol0ooooo`04o`3o
X@0Booooool0003o0000o`_o0?oooooo0?goo`_o0?oooooo02Koooooool0ojko0>;oooooool0ofCo
oooooh?o0?l0l?ooPol00ol0oj401ooooooo0000ooooool0003o0?mTo`3mool000000_ooool00onf
o`3oZOl0ooooo`04ooooo`;o000000Goooooo`000?ooooooooooocoo0002ooooo`04ogco0?oooooo
oooooc7o00Gooooo00?o0?m=ooooooooool06_ooool00onIo`3oooooooooo`0>ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooool0ol/0F_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02kooooo00?o0?njooooooooool00_ooool01Ol0;?ooooooo`27oooooooooo/000;o0000
00So0=Coo`000?oooooo0?goooooooo4o`3ooooool;o00?o0?go00?oooooo`000?ooool00_ooool3
o`14o`04o`000?o<o`3o08[oo`3oR0;o_Ol000Co0?mQo`2:ool0003o00000_l0oOl01ol0of7ooooo
okgo0?l0003o0?n8okgo0?o^o`000_l000003Ol0ooSooooooooooooooooo0?mco`3mooo<o`3o08[o
o`000?l0og?o_Ol0ooooool;o`001?l0oj402?l0003oooooooooool0R_oo2ol0o`3moonmo`3o02Ko
0_ooool01ol0h_ooooooo`3oI?ooooooPol0o`000?n3o`000ol0oj400ooooooo083oooooo`02o`00
0003o`3mool0003ooooo00?ooooo00?o0?mTooooooooool00_ooool3o`0000?ooooo00Go?ol0oooo
ooooooooooooogco0002ooooo`03oc7o0?oooooooooo00Wooooo00?o0?m=ooooooooool01oooool0
0onco`3oooooooooo`03ooooo`03oiWo0?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`05ooooo`03o`3obooooooooooo07?ooooo001mooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool09oooool00ol0ok[oooooooooo`02ooooo`05o`0/oooooooo08Oo
oooooooon`000_l000001?l0e?oo0000o`000?l0oOl3o`14o`06ooooool0oOooa?l0ol;o0?l0003o
jol00oooool2o`000003oonj0?o<o`3o000000;o_Ol01?l000003?o<o`3o0?n8o`3mool0of7o0?go
obCo0?o^o`3o0000ooooool0ooSo__l0okgo00;ooooo00?o__l0ooooool0og<00_l0oOl02Ol0003o
08[oo`000?l0og?o_Ol0o`_o0?l0oj7o0?goooooo`03o`3oX@;o000000Go0?goo`_o0?nmo`3o02Ko
o`3o[P02ooooo`03o`3Rool0ofCooooo00?o0?nQ00ko0000oooooon3o`3oooooo`000?oooooo0000
o`3oI?oooooo0000oooooonfo`3oooooojWo00Kooooo0_l000001?oooooo0?l<ooooooloo`02oooo
o`04ogco0?oooooooooooc7o00Kooooo00?o0?m=ooooooooool06Oooool00onIo`3oooooooooo`0>
ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0?o;FOooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02gooooo00?o0?njooooooooool00oooool00ol0;?ooooooo`27
o`02ooooo`07oook0?l0003o0=Coo`000?oooooo0?goooooo`03o`3mo`03ooooool0oOoooooo00;o
oooo00Co0000o`14ool0A?oooooo0_l000001?o<o`3o0000okgo0?nmo`02o`2:o`05o`3oHOl;o`3o
0000o`000?ooool00_l0oOl02?lTo`3o_Ol0oooooooooooo0000onko0?oooooo0?oh0oooool03?nn
o`3o0?mcoooooooooooo08[oo`000?l0og?o_Ol0o`_o0?l0oj7oooooo`3mo`;ooooo1?l0oj401?l0
ohSo0?goo`3mool09_l3ooooo`03o`3Rool0ofCooooo00?o0?nQ0_ooool01?n3o`3oooooo`20ool;
o`02o`000003okKo0?l0003ooooo00?ooooo00?o0?mTooooooooool00_ooool2o`0000Cooooo00Go
?ol0ooooooooooooooooogco0003ooooo`03oc7o0?oooooooooo00Sooooo00?o0?m=ooooooooool0
2?ooool00onco`3oooooooooo`02ooooo`03oiWo0?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`06ooooo`03o`3obooooooooooo07;ooooo001mooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool09oooool00ol0ok[oooooooooo`02ooooo`03o`0/oooo
oooo08Oo00;ooooo00?ooo/0ooooool0m?l00ol0A?l00ol0003oooooooooo`02ooooo`04o`3moooo
oooo`_l0o`0000;ooooo00CookX0o`000?l0003o00000_nmo`002_l0003o08[oo`000?l0003o0?mQ
o`_o0?l0oj7o0?n8o`3mooooool2o`000004onko0?oooooo0?ohooooo`;o_Ol00_ooool03?nno`3o
0000o`000?l0og?oooooo`000?l0R_oo0000o`_o0?nmo`3o0?nQo`3mo`Cooooo00?oc?l0ooooool0
ohP00_l00002o`3oX@03o`0Voooooooooooo00;o000001;o0?nQoooooon3o`3o0?3ooh?o0?l0003o
Pol0ooooool0003o2ol0ooooool0ofCoooooo`000?oooooo]_l0oooooonYo`05ooooo`07o`000?oo
ooooooooooooool0o`coooooocoo0002ooooo`04ogco0?oooooooooooc7o00Kooooo00?o0?m=oooo
ooooool06_ooool00onIo`3oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo0?o;FOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02gooooo00?o0?nj
ooooooooool00_ooool01?l0;?ooooooooooool0Qol3ooooo`03oook0?l0003o000000;o000000Oo
0?goolCo0?oooooo`_l0ooooool0oOoooooo00?o04Co0_ooool00ooo^P3o0000o`000002okgo0004
o`000?l0R_oo0000o`1Mo`;o000000Oo0?nQo`3oR?l0of7o0?goooooool0oOoo_Ol000;o000000Go
__l0okgo0?o^o`3o0?ohooooo`02o`3mo`06okko0?l0003o0000ooooooo<o`3o00000_l;o`000onm
o`3oooooo`3mo`03ooooo`03olco0?oooooo08[o00?o000000?o0?nQo`0Vool0oj400_ooool2o`00
0004o`3oXOooooooPol0o`0000;ooooo00SoPol0ooooool0P?oo2ol0oooooonfo`3o0000ojWo00Co
oooo00Oo0?mTooooooooooooooooo`000?oooooo0?l<00Cooooo00Go?ol0ooooooooooooooooogco
0003ooooo`03oc7o0?oooooooooo00Wooooo00?o0?m=ooooooooool01oooool00onco`3ooooooooo
o`03ooooo`03oiWo0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`06ooooo`03o`3obooooooooooo07;ooooo001mooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool09_ooool00ol0ok[oooooooooo`02ooooo`04o`0/ooooooooooooo`27o`;ooooo0ol0
A?l00ol0m?oo0000o`000003o`0000;ooooo00Goa?l0o`3mooo2o`3o0000ooooo`02o`000005oooo
ool0003o_Ol0ooooool000001?ooool02_l0GOoo0?mQolco0?l0of7o0?n8o`3moolTo`3oooooonko
0?l0ooP2ooooo`05okgo0?l0ohSooooookko0?l0oOl00_l000002?oooooo0?mco`000?o<o`3o2ol0
o`3oLol0oOoo_Ol01?ooool01?o<o`3oooooo`3oR?l0R_l4o`000003o`0Vool0003o000000;o0000
0_ooool01on3o`3o0?3ooh?o0?l0003oPol0ooooool;o`000_ooool01ol0ofCoooooo`000?oooooo
]_l0oooooonYo`000oooool2o`0000Gooooo00Go0?l<ocoo0?ooooooooooogco0002ooooo`03oc7o
0?oooooooooo00Cooooo00?o0?m=ooooooooool06_ooool00onIo`3oooooooooo`0=ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`3ob`1Hooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0;Oooool01Ol0ok[ooooooooooooooooo02co00?ooooo00?o08Oooooo
ooooool00_ooool00ooon`3o0?Coo`000002o`000003olCo0?oooooo`_l000?o04Co0_ooool00ol0
003oooooo`000002o`000003okgo0?oooooooooo00;o00000_ooool2o`000005o`_o0?l0of7ooooo
o`1Mool0oOl00_l00002ooooo`03okko0?nmo`3o0?oh00;o0?go00?o0?nQokko0?ooool00_l00000
1?oooooo0000o`000?l0R_l2ooooo`05o`3mooooooooooooooooooo<o`000_ooool00ol0ohSo2ol0
o`000002o`000003o`0Vool;o`3o000000?o00000_ooool2oh?o0009o`000?ooooooPol0o`000?l;
o`3o083ooooooonfo`3o000000Gooooo00Co0?mTooooool0003o00000oooool01Ol0o`cooooooooo
oooooooo?ol000?ooooo00GoO?l0oooooooooooooooooc7o000;ooooo`03o`3oCOoooooooooo00So
oooo00?o/ol0ooooooooool00_ooool00onIo`3oooooooooo`0;ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01oooool00ol0ol_oooooooooo`1aooooo`00OOooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02Kooooo00Go0?njooooooooooooooooo`0/o`03ooooo`?o
04Co0_ooool00ooon`3o0?Coooooo`02ooooo`03o`000?oooooo000000;ooooo00Coa?l0o`3mool0
003ooooo0_l000001?oooooo0000o`000?l00006ooooo`05o`1Mool0of7o0000o`000?l0oOl00_oo
ool01?l0ooSo0?goooooooooool2okgo0003o`3moonno`3ooooo00Cooooo00Co0000o`_o0?l0R_oo
0?go0_ooool03Onmo`3oooooooooooooooooc?l0o`3oR?l0oeSo0?goo`000?oooooo02Koo`3o[_l0
9_l00_l000000ol0oiko2ol0ooooo`02ooooo`;oPol000Cooooooh?o0?oooooo2ol00_ooool01ol0
ofCo0000ooooool0P?oo]_l0oooooonYo`000_ooool00ol0003oooooooooo`05ooooo`04o`3o3?lo
o`3oooooogco00?ooooo00?o<Ol0ooooooooool01?ooool00ol0odgoooooooooo`0Jooooo`03oiWo
0?oooooooooo00gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0?o;05So
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0]ooooo`04o`3o^_ooooooooooo`0/
o`Cooooo00?o08Ooooooooooool00oooool01?oon`3oooooooooooooool3o`14o`04ooooooo[o`3o
ooooo`3mo`;ooooo1Ol000000ol0oj7o0000ooooo`03ooooo`04omko0?l0003o0?mQolco00;o0000
00co0?gooooooonmo`3o0?gooooooonno`3o0?ohonko0?oooooo0?nQoooooonno`03ooooo`04o`3o
Lol;o`3o0000o`2:o`;o0?go00go_Ol0ooooooooooooooooolco0?oooooo_Ol0o`3oR?l0003o0?go
o`0Voooooooo02Ko00?o000000oo0?nNo`_o0?ooooooooooo`3`oon3o`3o0000oooooon3o`3o0000
o`_o0?l0P?oooooookKo0?l000001Oooool00ol0ofCo0000ooooo`04ooooo`05o`3o3?oooooooooo
ooooooloo`000oooool01Omlo`3ooooooooooooooooo<Ol000cooooo00?o0?m=ooooooooool03?oo
ool00onIo`3oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool00ol0ol_oooooooooo`1aooooo`00OOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo02Kooooo00Go0?njoooooooooooo02coooooo`03o`14o`03o`27oooooooooooo00;ooooo00?o
oo/0o`000?l0m?l00oooool4o`000004olCo0?o2o`3o0?goo`0000?ooooo00?o0000ooooool0oj40
1_ooool3o`00000<o`3oXOoooooo0?goo`3on?o^o`3o0000o`3moonmo`3o0?gookgo0?l0ohSo__l0
1Oooool01?l0003o0?mco`3mool0og<2ooooo`08okgo0?ooooooooooooooooo<o`3o0?n8okgo0?l0
oOl2ooooo`05o`0Voooooooo02Koooooool0oih00_l00003o`_o00;oPol000gooooooh?o0?l;o`3o
ooooo`000?oooooo0?mTo`000?oooooo083ookKo0?ooooooZOl000;o00002?ooool01?loo`3o0?l<
oooooomlo`03ooooo`03oc7o0?oooooooooo00Gooooo00?o0?m=ooooooooool06_ooool00onIo`3o
ooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`3ob`1Hoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;?ooool01?l0ok[oooooooooool0;?l5
ooooo`03o`27oooooooooooo00?ooooo00Wooo/0ooooool0A?oo04CoolCo0?oooooo0000ooooooo[
o`000_ooool00ol0oOooooooo`000002ooooo`04o`000?oooooo0?nQo`0000Gooooo1?l000002_lT
o`3oooooo`3moonmo`3o0000o`3mool0ooSo_Ol0onko0?nno`02ooooo`09okko0?oooooooooooooo
ool;o`3o0?mco`000?l0oOoo08[o00;ooooo00Oo_Ol0ooooooooooooc?l0okgo0?l0ohSo08[o00;o
0?go00?oooooo`0Vool09_l00_ooool00ol0oiko0000ooooo`03o`_o00;oPol000?o0000oh?o0?l;
o`000_ooool00ol0P?oo0000ojWo0004ooooo`03o`000?l0ofCooooo00Kooooo00Co0?l<oooooooo
oooo?ol00oooool01Omlo`3ooooooooooooooooo<Ol000cooooo00?o0?m=ooooooooool03?ooool0
0onIo`3oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool0
0ol0ol_oooooooooo`1`ooooo`00OOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02Kooooo00?o0?njooooool0A?l00_l0A?l3ooooo`03o`27oooooooooooo00?ooooo00?ooo/0o`00
0?ooool01?ooool01_l0003oooooo`000?o2o`3ojol0o`3mo`;ooooo00Go0000ooooool0003ooooo
o`3oX@03ooooo`Go000000Go9?l0o`3oXOl0ooSoooooonko0002o`000003okgo0?l0003o0?go00;o
000000?o0?goooooooooool00_l;o`001Ol0003o0?goo`3oLol0og?o08[o00;ooooo00Go_Ol0oooo
oooooooo0?n8ooooo`02o`3mo`;ooooo00Go02Koooooool09_ooooooo`3oWP02ooooo`;o000000_o
ooooo`_o0?n3o`3oPol0ooooool;o`3oooooo`000?oooooo0?mTo`000002ooooo`03o`20oooooooo
000000[ooooo00Co?ol0o`3o3?ooooooO?l00oooool00olao`3oooooooooo`05ooooo`03o`3oCOoo
oooooooo01[ooooo00?oVOl0ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0?o;ooooooooool0EOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02cooooo00?o0?njooooool0;?l01_ooool00ol0Qoooooooooooo`02ooooo`?o04Co0_oo
ool00oo4o`3ooooool;o0002o`0000?ooooo00So0?goo`000?ooooooooooo`000?oooooo0000o`3o
X@Cooooo1?l000001Ol;o`3o0?nQooooool0oOoo_Ol000;o000000Co0?ohokgo0?o^o`3o_Ol00_l0
0002ooooo`;o2ol000Koooooo`000?l0003o0?mcolco0?l0R_l2ooooo`07okgo0?ooooooc?l0o`3o
R?oooooo08[oo`3mo`02ooooo`06o`0Voooooooo02Koooooool0oikooooo0_l00002ooooo`05o`00
0?n3o`3oPol0o`000?l;o`000_ooool00ol0P?oo0000ojWo0003ooooo`03o`000?oooooo0?mT00Oo
oooo00Co0?l<oooooooooooo?ol00oooool01Omlo`3ooooooooooooooooo<Ol000gooooo00?o0?m=
ooooooooool03?ooool00onIo`3oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02?ooool00ol0ol_oooooooooo`1`ooooo`00OOooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo02Gooooo0ol0A?l00ol0;?ooooooooooo`03ooooo`03o`27oooooooooooo
00Cooooo00?ooo/0ooooooooool01?ooool3o`000004on_o0?l0003o0?goooooo`;o00000_ooool0
1?l0oj7oooooo`000?l00003ooooo`;o000000GoD_l0o`3on?mBo`3oD_l0onko0005oe;o00;o0000
00?oD_l0o`3mool;o`000ol0oOl2o`000003o`3oLol0R_oooooo00;ooooo0_nmo`001ol0ohSo0?go
o`3mool0R_ooooooo`3o[_ooool00_l09_l00ol0oikoooooooooo`03ooooo`;o000000?o0?3oo`00
0?l000000ol000000ooooooo0?mTooooo`02ooooo`;o000000?oZOl0ooooooooool02?ooool01?lo
o`3oooooo`3o3?mlo`03ooooo`03oc7o0?oooooooooo00Gooooo00?o0?m=ooooooooool06_ooool0
0onIo`3oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0ol_oooooooooo`1Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;?ooool0
0ol0ok[o02coooooo`06ooooo`03o`27oooooooo04Co00;o04Co00[oooooo`000?l0003ooo/0oooo
ooo4o`3ooooool;o0?oooooojol00_l00002ooooo`03o`3mool0003ooooo00;o00000_ooool00ol0
oj7oooooo`000002o`000004ooooool0ohSo0000o`0000GoD_l000Go0?ohoe;o0?mBo`3oD_l0onko
0002o`0000?oD_l000Oo0?goooooool0003o0000o`3oLoo<o`3o08[o00;ooooo00Co_Ol0olco0?o<
o`3o0?n80_l0oOl3ooooo`04o`0Voooooooo02Koo`3oWPCooooo0_l000000ol0l?oo0000ooooo`03
o`000005ooooool0P?oo0000ojWo0?ooool00_l00002ooooo`03o`3oI?oooooooooo00Kooooo00?o
0?l<ooooooloo`000oooool01Omlo`3ooooooooooooooooo<Ol000gooooo00?o0?m=ooooooooool0
3?ooool00onIo`3oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2?ooool2o`00077ooooo001mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08_oo
ool3o`14o`03o`3o^_oooooo02co00Kooooo00?o08Ooooooooooool01Oooool00ooon`3ooooooooo
o`04ooooo`03olCo0?l0003o000000;o000000?o0?goo`000?l000000_ooool2o`0000Gooooo0_l0
00001Ol0oOoo0?ohooooool0oOook_l000;o00001?ooool00onmo`3ooooooe;o000Eoe;o0003o`3o
W_mBo`3oD_l000Gooooo1ol000002?oooooo0?mToooooooooooo0000okKo0?l0P?ooZOl02_ooool0
1?loo`3oooooo`3o3?mlo`03ooooo`03oc7o0?oooooooooo00Kooooo00?o0?m=ooooooooool06_oo
ool00onIo`3oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool2o`0005Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0[ooooo`03o`3o^_l0
;?oooooo00Kooooo0ol0A?l7ooooo`06oook0?o4o`3ooooool;o0?oooooojol00_ooool01Ol0003o
ooooooooool0003ooooo00;o000000Coooooo`000?l0003o00001?ooool02?l0ohSo0000o`000?l;
o`3oooooo`000?l0oOoo0?oh0_l00002ooooo`04onko0?nmo`3o0?n8o`_o00;ooooo5OmBo`000ol0
oikoD_l0oe;o0006oe;o0009ooooool0003o0000o`000?oooooo0000o`20oonYo`3o000000Gooooo
00?o0?mTooooooooool01_ooool00ol0o`co?ol0ooooo`02ooooo`05ogco0?oooooooooooooooola
o`003Oooool00ol0odgoooooooooo`0<ooooo`03oiWo0?oooooooooo00[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`08ooooo`;o0000LOooool007gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Oooooo`?o04Co0oooool00ol0ok[o02coooooo`05ooooo`03o`27
oooooooooooo00Kooooo00?ooo/0ooooooooool01?ooool00oo4o`3oooooo`000003o`000004o`3m
oooooooo0000o`0000;ooooo00Co0?nQoooooooooooooooo0_l000001_l0oOoo0?ohooooool0oj7o
0000onko00;o00001?ooool01?nmo`3o2ol0o`3oR?l0oOl3ooooo`03o`000?oooooo0?go00;o0000
00Woc?l0okgo0?l0ohSo_Ol0ooooool0003o0?goooooool0ojh00_ooool01?l09_oo0?nNo`0Voooo
ool=oe;o0003o`3oI?mBo`3oD_l000[oD_l01?ooool01?loo`3ooooooooooomlo`02ooooo`03oc7o
0?oooooooooo00Oooooo00?o0?m=ooooooooool06_ooool00onIo`3oooooooooo`0;ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2o`0005Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0[ooooo`03o`3o^_l0;?oooooo00Cooooo0_l0A?l00ol0Qooooooo
ooooo`08ooooo`05oook0?oooooo`_l0ooooooo[o`000oooool3o`000003o`3mool0003o000000;o
000000?oooooo`3oXOooool00oooool2o`000006omko0?l;o`3oooooo`3oXOl0ooSo0?go0_l00002
ooooo`06onko0?nmo`3o2ol0o`3oR?oooooo0?go0_ooool01?l0003oooooooooool0oOl2o`000006
olco0?oooooo0?n8o`3mool0003o0?go1Oooool00ol09_oo0?nNooooo`07ooooo`03o`3`oomBo`3o
D_l000coD_l000?o0?mToe;o0?mBo`003_mBo`02ooooo`03oc7o0?oooooooooo00_ooooo00?o0?m=
ooooooooool03?ooool00onIo`3oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0Noooool007gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Loooo
o`?o04Co1_ooool00ol0ok[oooooooooo`05ooooo`03o`27oooooooooooo00Oooooo00?ooo/0oooo
ooooool01?ooool00oo4o`3o`_l0on_o0003o`000003o`3moooooooooooo00;ooooo00Co0?nQoooo
oooooooo0?go0_l000000ol0ooSoooooo`000002o`000003onko0?l;o`3o2ol000Co0?go00Co2ol0
okgo0?l0oOoo0?n80oooool00ol0003oooooooooo`02o`000008okgo0?l0003o0000oooooonmo`3o
0000o`2:ool0ojh3ooooo`03o`3oW_oooooo02Ko00Oooooo0_l00002ooooo`?o000000Oo0?mToooo
oooooooooooookKo0?nYo`3o083o00Kooooo1?mBo`001?loo`3oD_l0oe;o0?mlo`02oe;o0003oc7o
0?mBo`3oD_l000OoD_l000?o0?m=oe;o0?mBo`000_mBo`0Hooooo`03oiWo0?oooooooooo00_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0:oooool01?l0ok[oooooooooooooool3o`14o`;ooooo00?o08Oooooooooo
ool02?ooool01Oo4o`3ooo/0ol;o0?oooooojol000Gooooo1?l00004ooooo`04o`3oXOoooooo0?go
o`3mo`;o000000Ooooooomko0?l0003o0000o`3on?l0003o2ol000?o0?go00Gok_l0o`000?nmo`3o
ooooo`3mo`03ooooo`04o`000?ooooooooooooooo`;o000000?o08[oo`3mool000000_l000000ol0
oOooooooooooo`03ooooo`03o`3oW_l09_oooooo00Oooooo0_l000000ooooooo0000o`000002o`00
0003ojWo0?l0P?oooooo00Gooooo00?o0?mTooooooooool01_ooool00oloo`3o0?l<ooooo`02oooo
o`03ogco0?oooooooooo013oD_l000?o0?m=oe;o0?mBo`002omBo`000oooooooVOl0ooooo`0:oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Noooool007gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Iooooo`?o04Co2?ooool00ol0;?oo0?njooooo`06ooooo`03
o`27oooooooooooo00Sooooo00?ooo/0ooooooooool00oooool01?o4o`3o`_l0on_o0?ooool3o`00
0003o`3mool0003o000000;o00000_l0oOl2ooooo`03o`3on?l0003o000000;o00000_ooool02oo^
o`3og_l0oooooooooooo0?nQo`000?l0oOoo_Ol0o`000?oooooo0?n800;ooooo00Go0000oooooooo
oooooooookgo0003o`000005o`2:ool0003o_Ol0oi_o0?l0ojh00_ooool01?l0oikoooooo`000?l0
0007ooooo`;o000000?oooooo`000?l000000_l000001ol0ofCooooooooooooooooo]_l0ojWo0?l0
P?l02_ooool01oloo`3ooooooooooomlo`3o0?l<oooooolao`002Oooool00ol0odgoooooooooo`02
ooooo`goD_l02oooool00onIo`3oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0F_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02[ooooo00?o02co
o`3o^_l0A?l00_l0A?l5ooooo`03o`27oooooooooooo00Sooooo00Goa?l0oook0?o2o`3oooooon_o
0005ooooo`?o000000Co0?goo`000?oooooooooo0ol0oOl3ooooo`;o000000Go0?nQo`000?l0ooSo
ooooo`3oX@03ooooo`07o`3oXOl0oOook_l0okgo0?l0003oooooo`3oR002ooooo`06o`000?oooooo
oooooooooonmo`3ooooo1?l000000onmo`3oVol0ooooo`04ooooo`03o`3oW_l0003o000000Oooooo
1_l000000onfo`3oZOl0o`20o`06ooooo`03o`3oI?oooooooooo00Kooooo00?o?ol0o`3o3?ooool0
0_ooool00omlo`3oooooooooo`02ooooo`03oc7o0?oooooooooo00cooooo00?o0?m=ooooooooool0
2_ooool?oe;o00cooooo00?o0000ooooooooool0Noooool007gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Fooooo`?o04Co2oooool00ol0ok[oooooooooo`06ooooo`03o`27oooo
oooooooo00Wooooo00?ooo/0ooooooooool00_ooool00oo4o`3o`_l0on_o0004ooooo`So000000Co
0?ohooooool0003o00001?ooool01?o^o`3o0?nQomko0?l0oj43ooooo`07okgo0?l0003ooooooooo
ool0ohSoooooo`000002ooooo`04okgo0?oooooo0000o`0000Cooooo00Co0?n^oi_o0?oooooo0?nN
0_ooool2o`0000Gooooo0ol000000on:o`3o0000ooooo`03ooooo`08o`3oI?oooooooooooooooonf
o`3oZOl0ooooool0P?l8ooooo`08ocoo0?oooooooooooooooomlo`3oooooo`3o3?lao`0:ooooo`03
o`3oCOoooooooooo01[ooooo00?oVOl0ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo05[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`?o
04Co2?ooool00ol0Qoooooooooooo`08ooooo`05olCo0?oooooooo/0ooooooo[o`002?ooool00ol0
003o0?goo`000005o`0000;o0?nQ0_l000000ooooooo0?ohomko0002ooooo`03o`3oXOoooooo0?nQ
00;ooooo00?ok_l0okgo0?l000000_ooool01_l0ohSoooooo`000?oooooo0?mHokgo00;ooooo0_l0
00001Ooooooo0?n^ooooooooooooVol000?ooooo00Co0?nNo`000?l0003o00001?ooool5o`0000?o
oooo00Go]_l0oooooonYo`3oooooo`20o`05ooooo`03o`3oI?oooooooooo00Kooooo00?o?ol0oooo
ool0o``00_ooool00omlo`3oooooooooo`02ooooo`03oc7o0?oooooooooo00cooooo00?o0?m=oooo
ooooool02oooool00onIo`3oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0Noooool007gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Cooooo`?o
04Co3Oooool00ol0;?oo0?njooooo`07ooooo`03o`27oooooooooooo00[ooooo00Oooo/0oooooooo
ooooooooolCo0?o2o`3ojol000Wooooo0_l000000ol0ooSo0000o`000004o`0000;ooooo00?ok_l0
o`000?l000001Oooool00onmo`3oooooooooo`03o`000005oooooonmo`3oooooooooool0ohP01Ooo
ool01?l0ojkooooooi_o0?l0oih2ooooo`Oo00000oooool00on:o`3oooooooooo`03ooooo`08o`3o
I?oooooooooookKo0?ooooooZOl0ooooool0P?l8ooooo`04ocoo0?ooooooooooogco00;ooooo00?o
0?l<oc7o0?ooool02Oooool00ol0odgoooooooooo`0Jooooo`03oiWo0?oooooooooo00[ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0:?ooool00ol0A?ooooooo`3o^P09ooooo`03o`27oooooooooooo00Wooooo00Co
a?l0ol;o0?oon`3ojol03_ooool6o`000004o`3on?ooooooooooomko00;ooooo0_l00002ooooo`03
onko0?oooooo_Ol000;ooooo0ol000001Ol0oeSo_Ol0oooooooooooo0?n800;ooooo00?o0?n^oooo
ooooool00_ooool2oi_o0003ooooool0oiko000000Ko00001?ooool02On:o`3ooooooooooooooooo
]_l0oooooonYo`3oooooo`20o`05ooooo`03o`3oI?oooooooooo00Kooooo00Ko?ol0oooooooooooo
0?l<oooooomlo`04ooooo`03oc7o0?oooooooooo00gooooo00?o0?m=ooooooooool02oooool00onI
o`3oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Noooool007go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`?o04Co3oooool00ol0;?oo
ooooo`3o^P08ooooo`03o`27oooooooooooo00[ooooo00Oooo/0ooooooooooooooooolCo0?oooooo
jol000[ooooo00?o0?ohooooooooool00_ooool5o`000004onko0?l0003o0000omko00Cooooo00?o
_Ol0ooooooooool00ol000001?l0ohSoooooooooool0ohP5ooooo`04o`3o[_ooooooooooo`3oWPGo
00002?ooool00on:o`3oooooooooo`03ooooo`06o`3oI?oooooooooookKo0?ooooooZOl00_ooool0
0ol0P?ooooooooooo`05ooooo`04ocoo0?ooooooooooogco00?ooooo00?o<Ol0ooooooooool02?oo
ool00ol0odgoooooooooo`0Jooooo`03oiWo0?oooooooooo00[ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09ooo
ool01?l0;?ooooooooooool0okX9ooooo`03o`27oooooooooooo00Wooooo00Coa?l0ol;o0?oooooo
oo/04oooool00ol0003o0?oho`000003o`000003ooooool0003o000000;ooooo00?ok_l0oooooonm
o`000_ooool3o`000007o`3oR?ooooooooooooooool0ohSoooooo`3o[P05ooooo`;o000000?o0?nN
o`000?l000000_l00008ooooo`06oh[o0?oooooooooooooooonfo`3oZOl00_ooool00ol0P?oooooo
ooooo`03ooooo`03o`3oI?oooooooooo00Kooooo00Ko?ol0oooooooooooo0?l<oooooomlo`04oooo
o`03oc7o0?oooooooooo00gooooo00?o0?m=ooooooooool02oooool00onIo`3oooooooooo`08oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Noooool007gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0>ooooo`;o04Co4Oooool01?l0;?ooooooooooool0okX8oooo
o`03o`27oooooooooooo00_ooooo00Oooo/0ooooooooooooa?l0ooooooo2o`3ojol000Wooooo00?o
0?ohooooooooool01oooool00oo^o`3o0000o`000004o`0000;ooooo00Wo_Ol0oooooooooooo0?mH
o`000?oooooo0?n8ooooool0ohP00oooool4o`000003o`3oW_oooooooooo00;ooooo00?oVol0oooo
ooooool01oooool00on:o`3oooooooooo`03ooooo`06o`3oI?oooooooooookKo0?ooooooZOl00_oo
ool00ol0P?ooooooooooo`05ooooo`04ocoo0?ooooooooooogco00?ooooo00?o<Ol0ooooooooool0
2Oooool00ol0odgoooooooooo`0Jooooo`03oiWo0?oooooooooo00Wooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
9_ooool01Ol0;?oooooooooooooooooo0?nj00Wooooo00?o08Ooooooooooool02Oooool01Oo4o`3o
`_l0ooooooo[o`3ooo/001;ooooo00?o0?ohooooooooool00_ooool00ooNo`3o0000o`000003o`00
0004onko0?oooooooooookgo00;ooooo00Ko0?mHo`000?oooooo0?n8ooooool0ohP2ooooo`03o`3o
[_l0003o000000?o000000Goooooo`3oW_oooooooooooi_o000:ooooo`06oh[o0?oooooooooooooo
oonfo`3oZOl00oooool00ol0P?ooooooooooo`02ooooo`03o`3oI?oooooooooo00Kooooo00Ko?ol0
ooooooooooooooooo`3o3?mlo`04ooooo`03oc7o0?oooooooooo00kooooo00?o0?m=ooooooooool0
2_ooool00onIo`3oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
Noooool007gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Qooooo`04o`0/oooo
ooooooooo`3o^PSooooo00?o08Ooooooooooool03?ooool01_oon`3oooooooooooo4o`3o`_l0on_o
00Sooooo00?o0?ohooooooooool02?ooool00oo^o`3oooooooooo`02ooooo`06omko0?l0003o0000
o`000?nmo`3o00000_nmo`000ol0003oooooo`000005o`000005ooooool0ojkoooooooooool0oih0
1Oooool2oi_o00Sooooo00GoR_l0ooooooooooooooooo`3oI003ooooo`03okKo0?ooooooZOl000?o
oooo00?o083oooooooooool01?ooool01?loo`3ooooooooooomlo`03ooooo`03oc7o0?l0o`cooooo
00Wooooo00?o0?m=ooooooooool06_ooool00onIo`3oooooooooo`09ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02Kooooo00Co02cooooooooooooo0?nj2_ooool00ol0Qoooooooooooo`09ooooo`06olCo0?oooooo
`_l0on_o0?oooooooo/04?ooool00ol0ooSoooooooooo`04ooooo`03omko0?oooooooooo00;ooooo
00Co0000onko0?l0003o_Ol00_l000001?nmo`3o0000ooooooooool5o`0000Kooooo00Co0?nNoooo
oooooooooooo0_nKo`08ooooo`06oh[o0?oooooooooooooooonfo`3oZOl00oooool00ol0P?oooooo
ooooo`02ooooo`03o`3oI?oooooooooo00Kooooo00Ko?ol0ooooooooooooooooo`3o3?mlo`04oooo
o`03oc7o0?oooooooooo00kooooo00?o0?m=ooooooooool02_ooool00onIo`3oooooooooo`08oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Noooool007gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Pooooo`04o`0/ooooooooooooo`3o^PWooooo00?o08Oooooo
ooooool03Oooool01Ooon`3oooooolCo0?o2o`3ojol000Oooooo00?o0?ohooooooooool02Oooool0
0oo^o`3oooooooooo`03ooooo`05omko0?ooooooooooo`000?nmo`001_l00005ooooo`03o`3o[_oo
oooo0?nN00Sooooo00?oVol0ooooooooool01Oooool01On:o`3ooooooooooooooooo0?mT00?ooooo
00?o]_l0oooooonYo`000oooool00ol0P?ooooooooooo`04ooooo`04ocoo0?ooooooooooogco00?o
oooo00?o<Ol0ooooool0o``02Oooool00ol0odgoooooooooo`0Jooooo`03oiWo0?oooooooooo00Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool09Oooool01Ol0;?oooooooooooooooooo0?nj00[ooooo00?o08Oooooo
ooooool02Oooool01?o4o`3ooooool;o0?o[o`02ooooo`03oook0?oooooooooo00cooooo00?o0?oh
ooooooooool01_ooool00ooNo`3oooooooooo`02ooooo`04onko0?oooooooooookgo00Oo000000?o
0?n^ooooooooool01Oooool00ol0oikoooooooooo`04ooooo`03oi_o0?oooooooooo00Kooooo00Go
R_l0oooooooooooo]_l0ojWo0004ooooo`05o`20ooooooooooooooooool0of@02?ooool00oloo`3o
ooooooooo`02ooooo`03ogco0?oooooooooo00?ooooo00?o<Ol0ooooooooool03Oooool00ol0odgo
ooooooooo`0;ooooo`03oiWo0?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`1kooooo`00OOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo
00Go02coooooooooooooooooo`3o^P08ooooo`03o`27oooooooooooo00oooooo00Cooo/0olCo0?o2
o`3ojol01_ooool00ol0ooSoooooooooo`0:ooooo`03onko0?oooooooooo00Cooooo00?og_l0oooo
ool0oeP02oooool00ol0ojkoooooo`3oWP0:ooooo`;oVol01Oooool01On:o`3ooooooooooooooooo
0?mT00?ooooo00?o]_l0oooooonYo`000oooool00ol0P?ooooooooooo`04ooooo`04ocoo0?oooooo
ooooogco00?ooooo00?o<Ol0ooooool0o``02Oooool00ol0odgoooooooooo`0Kooooo`03oiWo0?oo
oooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Jooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool09?ooool00ol0;?ooooooooooo`02ooooo`03o`3o^_oo
oooooooo00Oooooo00?o08Ooooooooooool02_ooool01?o4o`3ooooool;o0?o[o`02ooooo`03oook
0?oooooooooo00cooooo00?o0?ohooooooooool01oooool01ooNo`3oooooooooooooooook_l0oooo
ool0oeP02?ooool00ol0ojkoooooooooo`05ooooo`03o`3oW_oooooooooo00Gooooo0_nKo`06oooo
o`05oh[o0?oooooo]_l0oooooonYo`001?ooool01Ol0P?oooooooooooooooooo0?mT00Sooooo00?o
?ol0ooooooooool00_ooool00omlo`3oooooooooo`03ooooo`03oc7o0?oooooooooo00kooooo00?o
0?m=ooooooooool02_ooool00onIo`3oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0Noooool007gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0N
ooooo`03o`0/oooooooooooo00;ooooo00?o0?njooooooooool01_ooool00ol0Qoooooooooooo`0?
ooooo`04oook0?o4o`3oooooon_o00Gooooo00?o0?ohooooooooool02oooool00oo^o`3ooooooooo
o`05ooooo`03o`3oF?oooooooooo00[ooooo00?o0?n^ooooool0oih03?ooool2oi_o00?ooooo00Go
R_l0ooooooooooooooooo`3oI003ooooo`03okKo0?ooooooZOl000Cooooo00?o083oooooooooool0
0oooool01?loo`3ooooooooooomlo`03ooooo`04oc7o0?ooooooooooo`3o30Wooooo00?o0?m=oooo
ooooool06_ooool00onIo`3oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02?ooooo00?o02cooooo
ooooool00_ooool00ol0ok[oooooooooo`08ooooo`03o`27oooooooooooo00[ooooo00Coa?l0oooo
ooo2o`3ojol00oooool00ooon`3oooooooooo`0:ooooo`03o`3on?oooooooooo00Wooooo00Gog_l0
ooooooooooook_l0o`3oF008ooooo`03o`3o[_oooooooooo00Gooooo00?o0?nNooooooooool02?oo
ool2oi_o00Cooooo00CoR_l0oooooonfo`3oZOl01Oooool00ol0P?ooooooooooo`02ooooo`03o`3o
I?oooooooooo00Gooooo00?o?ol0ooooooooool00_ooool00omlo`3o0?l<ooooo`03ooooo`03oc7o
0?oooooooooo00kooooo00?o0?m=ooooooooool02_ooool00onIo`3oooooooooo`07ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0Noooool007gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Mooooo`03o`0/oooooooooooo00?ooooo00?o0?njooooooooool01_oo
ool00ol0Qoooooooooooo`0@ooooo`03oook0?oooooojol000Cooooo00?o0?ohooooooooool03?oo
ool00oo^o`3oooooooooo`04ooooo`03o`3oF?oNo`3ooooo00[ooooo00?o0?n^ooooool0oih03ooo
ool01?nKo`3ooooooooooon:o`03ooooo`07o`3oI?oooooooooooooooonfo`3oooooojWo0004oooo
o`03o`20oooooooooooo00;ooooo00Go?ol0ooooooooooooooooogco0003ooooo`04oc7o0?oooooo
ooooo`3o30Wooooo00?o0?m=ooooooooool06_ooool00onIo`3oooooooooo`08ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02;ooooo00?o02coooooooooool00oooool00ol0ok[oooooooooo`08ooooo`03o`27oooo
oooooooo00[ooooo00Goa?l0ooooooo2o`3oooooon_o0003ooooo`03oook0?oooooooooo00Sooooo
00?o0?ohooooooooool02_ooool01OoNo`3oooooooooool0oeSok_l000Oooooo00?o0?n^oooooooo
ool01Oooool00ol0oikoooooooooo`0;ooooo`08oi_o0?oooooooooooooooon:o`3ooooookKo0?nY
o`06ooooo`05o`20ooooooooooooooooool0of@01oooool00oloo`3oooooooooo`02ooooo`03ogco
0?oooooo0?l<00?ooooo00?o<Ol0ooooooooool03oooool00ol0odgoooooooooo`09ooooo`03oiWo
0?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1kooooo`00OOoo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o02coooooooooool00_oo
ool00ol0ok[oooooooooo`06ooooo`03o`000?l0Qooooooo01;ooooo00?ooo/0ol;o0?o[o`000_oo
ool00ol0ooSoooooooooo`0=ooooo`03onko0?oooooooooo00?ooooo00Co0?mHoooooooooooog_l0
2_ooool00ol0ojko0?nNooooo`0@ooooo`;oVol000GoR_l0ooooooooooooooooo`3oI003ooooo`03
okKo0?nYo`3ooooo00Gooooo00Go083oooooooooooooooooocoo0003ooooo`05ogco0?oooooooooo
oooooolao`000oooool00ol0o`coooooooooo`06ooooo`03o`3oCOoooooooooo01_ooooo00?oVOl0
ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`03o`0/oooooooooooo00Cooooo00?o0?nj
ooooooooool02?ooool00ol0Qoooooooooooo`0:ooooo`05olCo0?oooooo`_l0ooooooo[o`001?oo
ool00ooon`3oooooooooo`06ooooo`03o`3on?oooooooooo00cooooo0_l0oeP00oooooook_l0oooo
o`06ooooo`03o`3o[_oooooooooo00Gooooo00?o0?nNooooooooool03?ooool2oi_o0005oooooon:
o`3ooooookKo0?nYo`001_ooool01Ol0P?oooooooooooooooooo0?mT00Oooooo00?o?ol0oooooooo
ool00_ooool00omlo`3oooooo`3o3003ooooo`03oc7o0?oooooooooo00oooooo00?o0?m=oooooooo
ool02_ooool00onIo`3oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0Noooool007gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Looooo`03o`0/
oooooooooooo00?ooooo00?o0?njooooooooool01_ooool00ol0003o08Ooooooo`0Booooo`03olCo
0?oon`3ojol000;ooooo00?o0?ohooooooooool03Oooool00oo^o`3oooooooooo`02ooooo`03o`3o
F?oooooooooo00;ooooo00?og_l0ooooooooool01_ooool00ol0ojkoooooo`3oWP0Cooooo`05oh[o
0?nKo`3oooooooooool0of@00oooool00onfo`3oZOl0ooooo`05ooooo`05o`20oooooooooooooooo
ooloo`000_ooool00omlo`3oooooooooo`02ooooo`05oc7o0?ooooooooooooooool0o``02Oooool0
0ol0odgoooooooooo`0Jooooo`03oiWo0?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool0
0ol0;?ooooooooooo`05ooooo`03o`3o^_oooooooooo00Oooooo00?o0000o`27ooooool02oooool0
1Oo4o`3ooooool;o0?oooooojol000Gooooo00?ooo/0ooooooooool01Oooool00ol0ooSooooooooo
o`0;ooooo`05o`3oF?oooooog_l0ooooooo^o`001_ooool00ol0ojkoooooooooo`05ooooo`03o`3o
W_oooooooooo00oooooo00GoVol0oh[o0?oooooo]_l0ojWo0007ooooo`04o`20ooooooooooooo`3o
I0Oooooo00?o?ol0ooooooooool00_ooool01?mlo`3oooooooooool0o``2ooooo`03oc7o0?oooooo
oooo013ooooo00?o0?m=ooooooooool02Oooool00onIo`3oooooooooo`06ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0Noooool007gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Kooooo`03o`0/oooooooooooo00Cooooo00?o0?njooooooooool06_ooool01_l0
003oa?l0oook0?o[o`3oooooo`3on13ooooo00Gok_l0ooooooooooooooooo`3oF006ooooo`03omko
0?oooooooooo00Gooooo00?o0?n^o`3oW_ooool04oooool01On:o`3ooooooi_o0?oooooo0?mT00?o
oooo00?o]_l0ojWo0?ooool01_ooool01?l0P?ooooooooooooloo`02ooooo`03ogco0?oooooooooo
00;ooooo00?o<Ol0ooooooooool00_ooool00ol0o`coooooooooo`06ooooo`03o`3oCOoooooooooo
01[ooooo00?oVOl0ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
05[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`0/oooooooooooo
00Cooooo00?o0?njooooooooool02?ooool2o`0000_ooooo00Ko0000olCo0?oooooo`_l0ooooooo[
o`06ooooo`03oook0?oooooooooo00?ooooo00?o0?ohooooooooool02oooool01_l0oeSooooooooo
oooooooog_l0onko00Gooooo00?o0?n^ooooooooool01_ooool00ol0oikoooooooooo`0@ooooo`04
oh[o0?nKo`3oooooojWo00Oooooo00Co083ooooooooooooo0?mT1oooool00oloo`3oooooooooo`02
ooooo`04ogco0?ooooooooooo`3o30;ooooo00?o<Ol0ooooooooool04?ooool00ol0odgooooooooo
o`09ooooo`03oiWo0?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1kooooo`00OOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o02co
ooooooooool01Oooool00ol0ok[oooooooooo`0Jooooo`;o000000?o`_l0oook0?l0ooP04Oooool0
1?o^o`3oooooo`3oF?l0oeP8ooooo`03omko0?oooooooooo00?ooooo00?o0?n^o`3oW_ooool05Ooo
ool01?n:o`3ooooooi_o0?l0of@3ooooo`03okKo0?nYo`3ooooo00Kooooo00Co083ooooooooooooo
?ol00_ooool00omlo`3oooooooooo`02ooooo`03oc7o0?oooooooooo00?ooooo00?o0?l<oooooooo
ool01Oooool00ol0odgoooooooooo`0Kooooo`03oiWo0?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool07oooool00ol0;?ooooooooooo`05ooooo`03o`3o^_oooooooooo01Gooooo0_l000001?oooooo
`_l0ooooooo[o`06ooooo`03oook0?oooooooooo00;ooooo00?o0?ohooooooooool02oooool00ol0
oeSoooooooooo`03ooooo`03omko0?o^o`3ooooo00?ooooo00?o0?n^ooooooooool01Oooool00ol0
oikoooooooooo`0Aooooo`04oh[o0?nfo`3oVol0oi_o00Oooooo00Co083ooooooooooooo0?mT1ooo
ool00oloo`3oooooooooo`02ooooo`07ogco0?ooooooooooooooool0o`cooooooc7o000Cooooo`03
o`3oCOoooooooooo00Sooooo00?oVOl0ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo07_ooooo001mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
6_ooool00ol0;?ooooooooooo`05ooooo`03o`3o^_oooooooooo01gooooo00?o0?ohoook0?ooool0
4?ooool00oo^o`3o0?mHooooo`0:ooooo`03omko0?oooooooooo00;ooooo00?o0?n^o`3oW_ooool0
5Oooool02On:o`3oooooooooool0ofCoVol0oooooonfo`3oooooojWo0008ooooo`03o`20oooooooo
?ol000;ooooo00?oO?l0ooooooooool00_ooool00olao`3oooooooooo`03ooooo`03o`3o3?oooooo
oooo00Kooooo00?o0?m=ooooooooool06_ooool00onIo`3oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01kooooo00?o02coooooooooool01_ooool00ol0ok[oooooooooo`0Hooooo`03ol;o0?oooooo
jol000Oooooo00Cooo/0oooooooooooo0?oh3Oooool00ol0oeSoooooooooo`05ooooo`05onko0?oo
ooooooooooooool0ojh01oooool00ol0oikoooooooooo`0Booooo`05oh[o0?nfo`3oZOl0oooooonK
o`001oooool00ol0P?ooooooo`3oI007ooooo`03ocoo0?oooooooooo00;ooooo00?oO?l0oooooooo
ool00_ooool00ol0o`cooooooc7o000Booooo`03o`3oCOoooooooooo00Wooooo00?oVOl0oooooooo
ool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07_ooooo001mooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0;?ooooooooooo`05ooooo`03o`3o
^_oooooooooo01gooooo00Co0?ohon_o0?oooooooo/04?ooool00oo^o`3oooooooooo`0;ooooo`05
omko0?ooooooooooo`3o[_l0oih05oooool01On:o`3oooooooooool0ofCooooo00;oVol000?o0000
ojWo0?ooool01oooool00ol0P?ooooooocoo0002ooooo`03ogco0?oooooooooo00;ooooo00?o<Ol0
ooooooooool01?ooool00ol0o`coooooooooo`05ooooo`03o`3oCOoooooooooo01[ooooo00?oVOl0
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`0/oooooooooooo00Oooooo00?o0?nj
ooooooooool06?ooool00oo2o`3oooooon_o0008ooooo`03oook0?oooooo0?oh00cooooo00?o0?mH
ooooooooool01_ooool01?o^o`3oooooooooool0ojh8ooooo`03o`3oW_oooooooooo01;ooooo00?o
R_l0okKo0?nYo`000_ooool2oi_o00Gooooo00?o083oooooool0of@01oooool00oloo`3ooooooooo
o`02ooooo`03ogco0?oooooooooo00;ooooo00?o0?l<oooooolao`004_ooool00ol0odgooooooooo
o`09ooooo`03oiWo0?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1kooooo`00OOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo00?o02co
ooooooooool01_ooool00ol0ok[oooooooooo`0Looooo`03o`3on?l0003ojol000;ooooo00?ooo/0
ooooooooool03?ooool00ol0oeSok_l0ooooo`0<ooooo`04omko0?ooooooooooo`3oWQSooooo00Co
R_l0oooooooooooo0?mT0_ooool00onfo`3oVol0oi_o0009ooooo`05o`20ooloo`3oooooooooooml
o`001?ooool00olao`3oooooooooo`04ooooo`03o`3o3?oooooooooo00Gooooo00?o0?m=oooooooo
ool06oooool00onIo`3oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0F_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01cooooo00?o02cooooooooo
ool01oooool00ol0ok[oooooooooo`0Hooooo`04o`000?o2o`3oooooon_o00Wooooo00?o0?ohoooo
ooooool02_ooool00ol0oeSoooooooooo`07ooooo`04onko0?oNo`3oooooo`3o[POooooo00?o0?nN
ooooooooool05?ooool00on:o`3o0000ooooo`03ooooo`;oVol01?ooool00ol0P?oo0?mTooooo`06
ooooo`05ocoo0?oooooooooooooooomlo`001_ooool00ol0o`co<Ol0ooooo`0Booooo`03o`3oCOoo
oooooooo00Sooooo00?oVOl0ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo07_ooooo001mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool0
0ol0;?ooooooooooo`07ooooo`03o`3o^_oooooooooo01_ooooo00Oo0?ohooooooooooooooooon_o
0?oooooooo/000gooooo00Co0?mHooooooooooook_l03Oooool00ooNo`3o0?n^o`3oWP0Hooooo`04
oh[o0?ooooooooooo`3oI0;ooooo00Co]_l0ooooooooooooVol02?ooool01Oloo`3ooooooooooooo
ooooO?l000Cooooo00?o<Ol0ooooooooool01Oooool00ol0o`coooooooooo`04ooooo`03o`3oCOoo
oooooooo01_ooooo00?oVOl0ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo05[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Kooooo`03o`0/oooo
oooooooo00Sooooo00?o0?njooooooooool06?ooool2o`000003ooooooo[o`3ooooo00Oooooo00?o
0?ohoooooooon`002_ooool00ol0oeSoooooooooo`08ooooo`03onko0?oooooog_l000Sooooo00?o
0?nNooooooooool04oooool00onfo`3oR_l0ooooo`06ooooo`06oi_o0?ooooooooooooooool0P?oo
0?mT1oooool01Oloo`3oooooooooooooooooO?l000Kooooo00?o0?l<oc7o0?ooool04_ooool00ol0
odgoooooooooo`08ooooo`03oiWo0?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`1kooooo`00OOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Ko
oooo00?o02coooooooooool02?ooool00ol0ok[oooooooooo`0Kooooo`05o`3on?oooooooooooooo
ooo[o`000_ooool00ooon`3oooooooooo`09ooooo`05o`3oF?ooooooooooooooooo^o`003Oooool0
0ol0ojko0?nNooooo`0Hooooo`04oh[o0?ooooooooooo`3oI0;ooooo00Co]_l0oooooooooooooooo
0_nKo`06ooooo`05ocoo0?l0P?oooooooooooomlo`001?ooool00olao`3oooooooooo`05ooooo`03
o`3o3?oooooooooo00Gooooo00?o0?m=ooooooooool06_ooool00onIo`3oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01[ooooo00?o02coooooooooool02Oooool00ol0ok[oooooooooo`0Kooooo`03
on_o0?oooooooooo00Gooooo00Go0?ohoooooooooooooooooook0007ooooo`;o0?mH3?ooool00oo^
o`3o0?n^omko0006ooooo`03o`3oW_oooooooooo01?ooooo00?o0000okKo0?n:o`002?ooool2oi_o
0003ooooool0P?oo0?mT00Oooooo00Go?ol0ooooooooooooooooogco0007ooooo`03oc7o0?oooooo
oooo01;ooooo00?o0?m=ooooooooool01oooool00ol0003oVOl0ooooo`05ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0Noooool007gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Fooooo`03o`0/oooooooooooo00Oooooo00?o0?njooooooooool06oooool00ol0
ooSoooooooooo`02ooooo`05on_o0?l0003ooooooooooooon`002Oooool00ol0oeSoooooooooo`02
ooooo`03onko0?oooooooooo00_ooooo00?o0?nNoooooooNo`006?ooool01on:o`3oooooooooool0
ofCoooooo`000?nfo`001Oooool00onKo`3oooooooooo`03ooooo`05ocoo0?l0P?ooooooooooooml
o`001?ooool00olao`3oooooooooo`06ooooo`03o`3o3?oooooooooo00Cooooo00?o0?m=oooooooo
ool06_ooool00ol0003oVOl0ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0F_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o02cooooooooo
ool02?ooool00ol0ok[oooooooooo`0Kooooo`03o`000?o[o`3ooooo00Kooooo00?o0?ohoooooooo
ool00_ooool00ooon`3oooooooooo`03ooooo`03o`3oF?oooooooooo00cooooo00Cok_l0oooooooo
oooog_l01?ooool00ol0oikoooooooooo`0Dooooo`03o`000?nfo`3oR_l000[ooooo00CoVol0oooo
ool0P?oo0?mT1_ooool01Oloo`3oooooooooooooooooO?l000Oooooo00?o<Ol0o`3o3?ooool04_oo
ool00ol0odgoooooooooo`07ooooo`03o`000?nIo`3ooooo00Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1kooooo`00OOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01Gooooo00?o02coooooooooool02?ooool00ol0ok[oooooooooo`0Jooooo`03o`3on?oooooo
oooo00?ooooo0_l00003ooooo`03oook0?oooooooooo00Gooooo00?o0?mHooooooooool00oooool0
0oo^o`3oooooooooo`0:ooooo`05o`3oW_oooooooooooooooooNo`006?ooool01?n:o`3oooooo`3o
I?ooool2o`0000Kooooo0_nKo`03ooooo`04ocoo0?oooooo083oogco00Gooooo00?o<Ol0oooooooo
ool01oooool00ol0o`coooooooooo`03ooooo`03o`3oCOoooooooooo01[ooooo00?o0000oiWo0?oo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Iooooo`03o`0/oooooooooooo00Wooooo00?o0?njoooooooo
ool06oooool00ol0003ojol0ooooo`05ooooo`03o`3on?oooooooooo00?ooooo00?ooo/0oooooooo
ool00_ooool00ol0oeSoooooooooo`0<ooooo`05o`3o[_o^o`3ooooooooooooNo`001?ooool00ol0
oikoooooooooo`0Fooooo`03oh[o0?oooooooooo00Wooooo0_nKo`000ol0ofCoooooooooo`04oooo
o`05ocoo0?oooooooooooooooomlo`001oooool00olao`3o0?l<ooooo`0Cooooo`03o`3oCOoooooo
oooo00kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1kooooo`00OOooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo00?o02coooooooooool02Oooool00ol0
ok[oooooooooo`0Iooooo`03o`3on?oooooooooo00[ooooo00?ooo/0ooooooooool00oooool00ol0
oeSoooooooooo`04ooooo`03onko0?oooooooooo00[ooooo00?o0?nNooooooooool00_ooool00ooN
o`3oooooooooo`0Eooooo`03oh[o0?oooooo0?mT00_ooooo0_nKo`001Ooooooo?ol0ooooool0P?oo
O?l000Gooooo00?o<Ol0ooooooooool01oooool00ol0o`coooooooooo`04ooooo`03o`3oCOoooooo
oooo027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool06?ooool00ol0;?ooooooooooo`0:ooooo`03o`3o^_oooooo
oooo02;ooooo00?o0?ohooooooooool01Oooool01?oon`3oooooooooool0oeP?ooooo`03o`3o[_o^
o`3ooooo00;ooooo00Cog_l0oooooooooooo0?nN6Oooool00on:o`3oooooooooo`0;ooooo`03o`3o
I?nKo`3ooooo00Cooooo00Go?ol0ooooooooooooooooogco0008ooooo`03oc7o0?l0o`cooooo01;o
oooo00?o0?m=ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07_o
oooo001mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool00ol0;?oooooo
ooooo`0:ooooo`03o`3o^_oooooooooo01Sooooo00?o0?ohooooooooool02oooool00ooon`3ooooo
ooooo`02ooooo`03o`3oF?oooooooooo00Gooooo00?ok_l0ooooooooool02Oooool00ol0oikooooo
ooooo`04ooooo`03omko0?oooooooooo01Cooooo00?oR_l0ooooool0of@03Oooool01OnKo`3o?ol0
ooooool0P?ooO?l000Gooooo00?o<Ol0ooooooooool02?ooool00ol0o`coooooooooo`03ooooo`03
o`3oCOoooooooooo027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Jooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool05oooool00ol0;?ooooooooooo`0;ooooo`03
o`3o^_oooooooooo02;ooooo00?o0?ohooooooooool01_ooool00ooon`3o0?mHooooo`0>ooooo`04
o`3o[_ooooooooooonko00?ooooo00?og_l0ooooool0oih06Oooool00on:o`3oooooooooo`0;oooo
o`04o`3oI?oooooo0000o`0000?ooooo00Go?ol0ooooooooooooooooogco0008ooooo`03oc7o0?l0
o`cooooo01;ooooo00?o0?m=ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo07_ooooo001mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_ooool0
0ol0;?ooooooooooo`0;ooooo`03o`3o^_oooooooooo01Oooooo00?o0?ohooooooooool03Oooool0
1?oon`3oooooooooool0oeP8ooooo`03onko0?oooooooooo00Sooooo00?o0?nNo`3o[_ooool01_oo
ool00ooNo`3oooooooooo`0Cooooo`03oh[o0?oooooo0?mT00gooooo00Go0000ocoo0?oooooooooo
ogco0005ooooo`03oc7o0?oooooooooo00Sooooo00?o0?l<ooooooooool09oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Fooooo`03o`0/oooooooooooo00_ooooo00?o0?njooooooooool08_ooool00ol0ooSooooo
ooooo`07ooooo`03o`3oF?oon`3ooooo00gooooo00Go0?n^ooooooooooooooooonko0004ooooo`03
o`3oW_oooooooooo01Sooooo00?oR_l0ooooooooool02oooool01?l0ofCoooooo`000?l00003oooo
o`05ocoo0?oooooooooooooooomlo`002?ooool00olao`3oooooo`3o300Cooooo`03o`3oCOoooooo
oooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1kooooo`00OOooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o02coooooooooool02_ooool00ol0
ok[oooooooooo`0Gooooo`03o`3on?oooooooooo00oooooo00?ooo/0o`3oF?ooool02?ooool00oo^
o`3oooooooooo`08ooooo`03o`3oW_oooooooooo00Kooooo00?og_l0ooooooooool04oooool00on:
o`3o0?mTooooo`0=ooooo`05o`000?loo`3ooooooooooomlo`001Oooool00olao`3oooooooooo`09
ooooo`03o`3o3?oooooooooo02Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0;?ooooooooooo`0<
ooooo`03o`3o^_oooooooooo027ooooo00?o0?ohooooooooool01oooool01?l0oeSooooooooooooo
n`0=ooooo`05o`3o[_ooooooooooooooooo^o`000oooool00ol0oikoooooomko000Iooooo`03oh[o
0?oooooooooo00_ooooo00?o0?mTo`20ooooool01?ooool01Oloo`3oooooooooooooooooO?l000So
oooo00?o<Ol0ooooool0o``04oooool00ol0odgoooooooooo`0=ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0Noooool007gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Aooooo`03o`0/oooooooooooo00_ooooo00?o0?njooooooooool05oooool00ol0ooSooooo
ooooo`0>ooooo`03o`3oF?oooooooo/000Wooooo00?ok_l0ooooooooool01oooool00ol0oiko0?n^
ooooo`08ooooo`03omko0?oooooooooo01;ooooo00?oR_l0o`3oI?ooool03Oooool01_loo`3ooooo
ooooooooooooO?l0o`20o`Cooooo00?o<Ol0ooooooooool02Oooool00ol0o`coooooooooo`0Voooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Cooooo00?o02coooooooooool03Oooool00ol0ok[oooooooooo`0Poooo
o`03o`3on?oooooooooo00Oooooo00?o0?mHooooooooool00_ooool00ooon`3oooooooooo`09oooo
o`03o`3o[_oooooooooo00;ooooo00Gok_l0ooooooooooooooooo`3oWP02ooooo`03omko0?oooooo
oooo01Oooooo00?oR_l0ooooooooool02_ooool00ol0ofCo083oooooo`04ooooo`05ocoo0?oooooo
oooooooooomlo`002?ooool01?lao`3oooooooooool0o``Cooooo`03o`3oCOoooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1kooooo`00OOooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo013ooooo00?o02coooooooooool03?ooool00ol0ok[ooooooooo
o`0Fooooo`03o`3on?oooooooooo00kooooo00Co0?mHoooooooooooooo/02Oooool00oo^o`3ooooo
ooooo`06ooooo`03o`3oW_l0ojkooooo00[ooooo00?og_l0ooooooooool04Oooool00on:o`3o0?mT
ooooo`0=ooooo`06ocoo0?oooooooooooooooomlo`3o083o1?ooool00olao`3oooooooooo`0:oooo
o`03o`3o3?oooooooooo02Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Joooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0;?ooooooooooo`0>oooo
o`03o`3o^_oooooooooo023ooooo00?o0?ohooooooooool01_ooool00ol0oeSoooooooooo`03oooo
o`03oook0?oooooooooo00Oooooo00?o0000o`3o[_ooool01?ooool01?o^o`3oooooooooool0oih3
ooooo`03omko0?oooooooooo01Oooooo00?oR_l0ooooooooool02_ooool00ol0ofCoooooo`20o`04
ooooo`05ocoo0?oooooooooooooooomlo`002?ooool01Olao`3ooooooooooooooooo0?l<027ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1kooooo`00OOooool00ol0003ooooooooo
o`0:oooooa?o000000?o02coo`000?l000003Ol000000ol0ok[o0000o`00000Eo`000003o`3on?l0
003o000000ko000000?o0?mHo`000?l000000_l000000ooon`3o0000o`000006o`000003onko0?l0
003o000000Ko000000?o0?nNo`000?l000001Ol00006ooooo`03omko0?oooooooooo013ooooo00?o
R_l0o`3oI?ooool03Oooool01oloo`3oooooooooooooooooO?l0ooooool0P?l00oooool00olao`3o
ooooooooo`0:ooooo`03o`3o3?oooooooooo02Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0;?oo
ooooooooo`0=ooooo`03o`3o^_oooooooooo023ooooo00?o0?ohooooooooool01Oooool2o`3oF0Oo
oooo00?ooo/0ooooooooool01_ooool2o`0000Cooooo0_l000000oo^o`3o0000o`3oWP04o`000003
omko0?l0003o000001Ko000000?oR_l0o`000?l000002_l000000ol0ofCo0000o`20o`04o`000005
ocoo0?l0003o0000o`000?mlo`002?l000001Olao`3o0000o`000?l0003o0?l<02?o00003?ooool0
0ol0003oooooooooo`1kooooo`00OOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
017ooooo00?o02coooooooooool03?ooool00ol0ok[oooooooooo`0Eooooo`03o`3on?oooooooooo
00kooooo00?o0?mHooooooooool01?ooool00ooon`3oooooooooo`05ooooo`03onko0?oooooooooo
00Gooooo00?o0?nNooooooooool01_ooool7o`000003omko0?l0003o0000013o000000?o0?mTo`00
0?l000003?l000001oloo`3o0000o`000?l0003oO?l0o`000?l0P?l00ol000000olao`3o0000o`00
000;o`000003o`3o3?l0003o000002Go00001oooool00ol0003oooooooooo`1Jooooo`03o`000?oo
oooooooo00Gooooo5Ol000000ol0;?oo0000o`00000>o`000003o`3o^_l0003o000001oo000000?o
0?oho`000?l000001Ol000000ol0oeSo0000o`000008o`000003oook0?l0003o000000_o00000_oo
ool00oo^o`3o0?nNooooo`05ooooo`03omko0?oooooooooo01Gooooo00?oR_l0ooooooooool02_oo
ool00ol0ofCoooooo`20o`04ooooo`05ocoo0?oooooooooooooooomlo`002?ooool00olao`3ooooo
ooooo`02ooooo`03o`3o3?oooooooooo023ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1kooooo`00OOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o
02coooooooooool03Oooool00ol0ok[oooooooooo`0Dooooo`03o`3on?oooooooooo00kooooo00?o
0?mHooooooooool01_ooool00ooon`3oooooooooo`04ooooo`03onko0?oooooooooo00Cooooo00?o
0?nNooooooooool03oooool00ooNo`3oooooooooo`0?ooooo`03o`3oI?oooooooooo00cooooo00Co
?ol0ooooooooooooO?l00_ooool01Ol0003o083ooooooooooooo<Ol000kooooo00?o0?l<oooooooo
ool08oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Aooooo`03o`0/oooooooooooo00oooooo00?o0?njoooooooo
ool07_ooool00ol0ooSoooooooooo`05ooooo`03o`3oF?oooooooooo00[ooooo00?ooo/0oooooooo
ool03?ooool00oo^o`3oooooooooo`06ooooo`03omko0?oooooooooo01Cooooo00?oR_l0oooooooo
ool02_ooool01?l0ofCoooooo`000?l0P?l3ooooo`05ocoo0?oooooooooooooooomlo`002Oooool0
1Olao`3ooooooooooooooooo0?l<02?ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`1kooooo`00OOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o02co
ooooooooool03_ooool00ol0ok[oooooooooo`0Cooooo`03o`3on?oooooooooo00kooooo00?o0?mH
ooooooooool02?ooool00ooon`3oooooooooo`03ooooo`03onko0?oooooooooo00Cooooo00?o0?nN
ooooooooool03oooool00ol0003og_l0ooooo`0?ooooo`03o`3oI?oooooooooo00cooooo00Co?ol0
ooooooooooooO?l00_ooool2o`0000;ooooo00?o<Ol0ooooooooool03?ooool00ol0o`cooooooooo
o`0Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo017ooooo00?o02coooooooooool03oooool00ol0ok[ooooooooo
o`0Oooooo`03o`3on?oooooooooo00Cooooo00?o0?mHooooooooool03?ooool00ooon`3ooooooooo
o`0;ooooo`03onko0?oooooooooo00Kooooo00?o0000omko0?ooool05?ooool00on:o`3ooooooooo
o`0;ooooo`03o`3oI?l0003o000000?ooooo00Go?ol0ooooooooooooooooogco0009ooooo`03oc7o
0?oooooooooo00;ooooo00?o0?l<ooooooooool08Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo07_ooooo001mooooo`03o`000?oooooooooo00Gooooo0_l0000Cooooo`03o`0/oooo
oooooooo00oooooo00?o0?njooooooooool04_ooool00ol0ooSoooooooooo`0>ooooo`03o`3oF?oo
oooooooo00Wooooo00?ooo/0ooooooooool00oooool00oo^o`3oooooooooo`03ooooo`03o`3oW_oo
oooooooo013ooooo0_l0000@ooooo`03o`3oI?oooooooooo00cooooo00Co?ol0ooooooooooooO?l0
1_ooool00olao`3oooooooooo`0=ooooo`03o`3o3?oooooooooo02Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
4Oooool00ol0;?ooooooooooo`0@ooooo`03o`3o^_oooooooooo01kooooo00?o0?ohooooooooool0
1?ooool00ol0oeSoooooooooo`0>ooooo`03oook0?oooooooooo00Wooooo00?o0?nNooooooo^o`00
1oooool2o`0001Gooooo00?oR_l0ooooooooool02oooool00ol0ofCoooooooooo`03ooooo`05ocoo
0?oooooooooooooooomlo`002Oooool00olao`3oooooooooo`03ooooo`03o`3o3?oooooooooo027o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1kooooo`00OOooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000o`0/ooooool04Oooool00ol0ok[ooooo
ooooo`0Booooo`03o`3on?oooooooooo00gooooo00?o0?mHooooooooool02oooool00ooon`3ooooo
ooooo`02ooooo`03onko0?oooooooooo00;ooooo00?o0?nNooooooooool08oooool00ol0ofCooooo
ooooo`0<ooooo`04ocoo0?ooooooooooogco00Kooooo00?o<Ol0ooooooooool03Oooool00ol0o`co
ooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0F_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo013ooooo00?o02coooooooooool04Oooool00ol0ok[o
ooooooooo`0Mooooo`03o`3on?oooooooooo00Cooooo00?o0?mHooooooooool03oooool00ooon`3o
ooooooooo`09ooooo`03o`3oW_ooooook_l001kooooo00?oR_l0ooooooooool02oooool00ol0ofCo
ooooooooo`03ooooo`05ocoo0?oooooooooooooooomlo`002Oooool00olao`3oooooooooo`03oooo
o`03o`3o3?oooooooooo02;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1koooo
o`00OOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo0_l0000Aooooo`03
o`3o^_oooooooooo01;ooooo00?o0?ohooooooooool03Oooool00ol0oeSoooooooooo`0=ooooo`05
oook0?ooooooooooooooooo^o`001?ooool00ol0oikoooooooooo`0Sooooo`03oh[o0?oooooooooo
00_ooooo00Go?ol0ooooooooooooooooogco0006ooooo`03oc7o0?oooooooooo00kooooo00?o0?l<
ooooooooool09?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`03o`0/ool0003ooooo01;ooooo00?o0?nj
ooooooooool07?ooool00ol0ooSoooooooooo`04ooooo`03o`3oF?oooooooooo017ooooo00?ooo/0
ooooooooool01oooool01?l0oikoooooooooooo^o`0Nooooo`03oh[o0?oooooooooo00_ooooo00?o
0?mTooooooooool00oooool01Oloo`3oooooooooooooooooO?l000Wooooo00?o<Ol0ooooooooool0
1?ooool00ol0o`coooooooooo`0Rooooo`;o00001Oooool00ol0003oooooooooo`1kooooo`00OOoo
ool01?l0003oooooooooooooool2o`0002Oooooo00?o0000o`3o^_ooool04_ooool00ol0ooSooooo
ooooo`0=ooooo`03o`3oF?oooooooooo00oooooo00Gooo/0ooooooooooooooooonko0002ooooo`03
o`3oW_oooooooooo02Cooooo00?oR_l0ooooooooool02oooool01Oloo`3oooooooooooooooooO?l0
00Kooooo00?o<Ol0ooooooooool03_ooool00ol0o`coooooooooo`0Uooooo`05o`000?oooooooooo
ooooool00000G?ooool01Ol0003ooooooooooooooooo000001?ooooo0_l0000Booooo`03o`3o^_oo
oooooooo01gooooo00?o0?ohooooooooool00oooool00ol0oeSoooooooooo`0Cooooo`03oook0?oo
oooooooo00Gooooo00Go0?nNooooooooooooooooonko000Nooooo`03oh[o0?oooooooooo00_ooooo
00?o0?mTooooooooool00_ooool00oloo`3oooooooooo`02ooooo`03ogco0?oooooooooo00Oooooo
00?o<Ol0ooooooooool01?ooool00ol0o`coooooooooo`0Tooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0Noooool007gooooo00Co0000oooooooooooo0000:Oooool2o`0001;ooooo
00?o0?ohooooooooool03?ooool00ol0003o0?mHooooo`0Booooo`06oook0?ooooooooooonko0?oo
oooo0?nN9oooool00on:o`3oooooooooo`0;ooooo`05ocoo0?oooooooooooooooomlo`001Oooool0
0olao`3oooooooooo`0@ooooo`03o`3o3?oooooooooo02Cooooo00Go0000ooooooooooooooooo`00
001Looooo`05o`000?ooooooooooooooool000009_ooool00ol0003o0?njooooo`0Mooooo`03o`3o
n?oooooooooo00?ooooo00?o0?mHooooooooool05Oooool00ooon`3oooooooooo`04ooooo`03o`3o
W_oooooooooo00;ooooo00?ok_l0ooooooooool07?ooool00on:o`3oooooooooo`0?ooooo`03ocoo
0?oooooooooo00;ooooo00?oO?l0ooooooooool01oooool00olao`3oooooooooo`05ooooo`03o`3o
3?oooooooooo02Cooooo00Go0000ooooooooooooooooo`00001mooooo`00OOooool00ol0003ooooo
o`00000mooooo`03o`3on?oooooooooo00gooooo0_l0000Cooooo`06oook0?ooooooooooonko0?oo
oooo0?nN:?ooool00on:o`3oooooooooo`0:ooooo`05ocoo0?oooooooooooooooomlo`001Oooool0
0olao`3oooooooooo`0Aooooo`03o`3o3?oooooooooo02Cooooo00Co0000oooooooooooo0000G?oo
ool01?l0003oooooooooool0000Wooooo`;o00007Oooool00ol0ooSoooooooooo`02ooooo`03o`00
0?l0oeSooooo01Sooooo00?ooo/0ooooooooool00_ooool00ol0oikoooooooooo`03ooooo`03onko
0?oooooooooo01cooooo00?oR_l0ooooooooool03oooool00oloo`3oooooooooo`02ooooo`03ogco
0?oooooooooo00Oooooo00?o<Ol0ooooooooool01_ooool00ol0o`coooooooooo`0Tooooo`04o`00
0?ooooooooooo`0007gooooo001mooooo`;o0000?Oooool00ol0ooSoooooooooo`0Tooooo`04oook
0?ooooook_l0o`3oWRWooooo00?oR_l0ooooooooool02_ooool01Oloo`3oooooooooooooooooO?l0
00Gooooo00?o<Ol0ooooooooool04Oooool00ol0o`coooooooooo`0Uooooo`03o`000?oooooo0000
05cooooo00?o0000ooooool00000A_ooool00ol0ooSoooooooooo`03ooooo`;o00006_ooool01Ooo
n`3ooooooooooooooooo0?nN00Gooooo00?ok_l0ooooooooool07?ooool00on:o`3oooooooooo`0?
ooooo`03ocoo0?oooooooooo00;ooooo00?oO?l0ooooooooool02?ooool00olao`3oooooooooo`05
ooooo`;o00009_ooool00ol0003oooooo`00001mooooo`00O?oooollo`0000?ooooo00?o0?ohoooo
ooooool09_ooool00ooon`3ok_l0ooooo`0Yooooo`03oh[o0?oooooooooo00[ooooo00Co?ol0oooo
ooooooooO?l01_ooool00olao`3oooooooooo`0Aooooo`;o00009_ooool00ol0003oooooo`00001L
ooooo`03o`000?oooooo000004Kooooo00?o0?ohooooooooool08?ooool00ooon`3oooooo`3oWP06
ooooo`03onko0?oooooooooo01cooooo00?oR_l0ooooooooool03oooool00oloo`3oooooooooo`02
ooooo`03ogco0?oooooooooo00Sooooo00?o<Ol0ooooooooool01Oooool2o`0002Oooooo0_l0001m
ooooo`00Noooool00ol0003oooooooooo`0jooooo`?o000000?o0?oho`000?l000009_l000000ol0
oikok_l0o`00000Yo`000003oh[o0?l0003o000000[o000000Co?ol0o`000?l0003oO?l01_l00000
0olao`3o0000o`000002o`0000oooooo0_l0000Wooooo`;o0000G?ooool2o`0004Kooooo00?o0?oh
ooooooooool08Oooool00ooon`3o0?nNooooo`05ooooo`03o`000?o^o`3o000001go000000?oR_l0
o`000?l000003ol000000oloo`3o0000o`000002o`000003ogco0?l0003o000000So000000?o<Ol0
o`000?l00000<Ol0001looooo`00N_ooool00ol0003oooooooooo`0mooooo`03o`3on?oooooooooo
02Oooooo00?o0?nNonko0?ooool0:?ooool2o`0000_ooooo00Go?ol0ooooooooooooooooogco0006
ooooo`03oc7o0?oooooooooo00;ooooo>_l0001LooooodOo000000?o0?oho`000?l000008ol00000
0ol0oiko0000o`000004o`0000;ooooo00?ok_l0ooooooooool06oooool2o`00013ooooo00?o?ol0
ooooooooool00_ooool00omlo`3oooooooooo`08ooooo`03oc7o0?oooooooooo037ooooo00?o0000
ooooooooool0NOooool007Sooooo0_l0000oooooo`03o`3on?oooooooooo02Oooooo00Co0?nNoooo
ooo^o`3ooo/0=Oooool01Oloo`3oooooooooooooooooO?l000Kooooo00?o<Ol0ooooooooool0>ooo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo04?ooooo00?o0?ohooooooooool08ooo
ool00ol0oikooooooook0007ooooo`03onko0?oooooooooo02gooooo00?o?ol0ooooooooool00_oo
ool00omlo`3oooooooooo`08ooooo`03oc7o0?oooooooooo03;ooooo00?o0000ooooooooool0N?oo
ool007Oooooo00?o0000ooooooooool0?_ooool00ol0ooSoooooooooo`0Wooooo`03o`3oW_oooooo
oooo00;ooooo00?ooo/0ooooooooool0<_ooool01Oloo`3oooooooooooooooooO?l000Kooooo00?o
<Ol0ooooooooool0??ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo04Cooooo00?o
0?ohooooooooool08oooool01?l0oikooooooooooooon`0fooooo`03ocoo0?oooooooooo00;ooooo
00?oO?l0ooooooooool02?ooool00olao`3oooooooooo`0cooooo`03o`000?oooooooooo07Oooooo
001fooooo`03o`000?oooooooooo03kooooo00?o0?ohooooooooool0:?ooool00ol0oikooooooooo
o`03ooooo`03oook0?oooooooooo037ooooo00Go?ol0ooooooooooooooooogco0006ooooo`03oc7o
0?oooooooooo03cooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`14ooooo`03o`3o
n?oooooooooo02?ooooo00?o0?nNooooooooool00_ooool00ooon`3oooooooooo`0cooooo`03ocoo
0?oooooooooo00;ooooo00?oO?l0ooooooooool02?ooool00olao`3oooooooooo`0dooooo`03o`00
0?oooooooooo07Kooooo001dooooo`;o0000@?ooool00ol0ooSoooooooooo`0Xooooo`03o`3oW_oo
oooooooo00Gooooo0_l0000aooooo`05ocoo0?oooooooooooooooomlo`001_ooool00olao`3ooooo
ooooo`0mooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0A?ooool00ol0ooSooooo
ooooo`0Sooooo`03o`3oW_oooooooooo00?ooooo0_l0000dooooo`03ocoo0?oooooooooo00;ooooo
00?oO?l0ooooooooool02?ooool00olao`3oooooooooo`0eooooo`;o0000M_ooool007?ooooo00?o
0000ooooooooool0?oooool00ol0ooSoooooooooo`0Xooooo`;o00001oooool2o`00037ooooo00Go
?ol0ooooooooooooooooogco0006ooooo`03oc7o0?oooooooooo03kooooo00?o0000ooooooooool0
E?ooool00ol0003oooooooooo`13ooooo`03o`3on?oooooooooo02;ooooo0_l000000ol0oikooooo
ooooo`03ooooo`;o0000=?ooool00oloo`3oooooooooo`02ooooo`03ogco0?oooooooooo00Wooooo
00?o<Ol0ooooooooool0=_ooool00ol0003oooooooooo`1cooooo`00L_ooool00ol0003ooooooooo
o`10ooooo`03o`3on?oooooooooo02Sooooo0_l0000jooooo`05ocoo0?oooooooooooooooomlo`00
1_ooool00olao`3oooooooooo`0nooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
A?ooool00ol0ooSoooooooooo`0Rooooo`;o0000??ooool00oloo`3oooooooooo`02ooooo`03ogco
0?oooooooooo00Wooooo00?o<Ol0ooooooooool0=oooool00ol0003oooooooooo`1booooo`00L?oo
ool2o`0004;ooooo00?o0?ohooooooooool0IOooool01?loo`3ooooooooooomlo`07ooooo`03oc7o
0?oooooooooo03oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`14ooooo`03o`3o
n?oooooooooo067ooooo00?o?ol0ooooooooool00_ooool00omlo`3oooooooooo`09ooooo`03oc7o
0?oooooooooo03Sooooo00?o0000ooooooooool0LOooool006oooooo00?o0000ooooooooool0@Ooo
ool00ol0ooSoooooooooo`1Uooooo`05ocoo0?oooooooooooooooomlo`001oooool00olao`3ooooo
ooooo`0oooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0A?ooool00ol0ooSooooo
ooooo`1Rooooo`03ocoo0?oooooooooo00;ooooo00?oO?l0ooooooooool02Oooool00olao`3ooooo
ooooo`0iooooo`03o`000?oooooooooo073ooooo001^ooooo`03o`000?oooooooooo047ooooo00?o
0?ohooooooooool0I_ooool01Oloo`3oooooooooooooooooO?l000Oooooo00?o<Ol0ooooooooool0
@?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo04Cooooo00?o0?ohooooooooool0
H_ooool00oloo`3oooooooooo`02ooooo`03ogco0?oooooooooo00Wooooo00?o<Ol0ooooooooool0
>_ooool00ol0003oooooooooo`1_ooooo`00KOooool00ol0003oooooooooo`11ooooo`03o`3on?oo
oooooooo06Oooooo00Go?ol0ooooooooooooooooogco0007ooooo`03oc7o0?oooooooooo043ooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`14ooooo`03o`3on?oooooooooo06;ooooo
0_l00003ooooo`;o00002oooool00olao`3oooooooooo`0kooooo`;o0000Koooool006_ooooo0_l0
0013ooooo`03o`3on?oooooooooo06Oooooo0_l00003ooooo`;o00001_ooool00olao`3ooooooooo
o`11ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0A?ooool00ol0ooSooooooooo
o`1Sooooo`;o00000oooool2o`0000_ooooo00?o<Ol0ooooooooool0?Oooool00ol0003ooooooooo
o`1/ooooo`00J_ooool00ol0003oooooooooo`12ooooo`03o`3on?oooooooooo06Sooooo0_l00003
ooooo`;o00001_ooool00olao`3oooooooooo`12ooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool0A?ooool00ol0ooSoooooooooo`1fooooo`03oc7o0?oooooooooo03kooooo00?o0000
ooooooooool0Joooool006Wooooo00?o0000ooooooooool0@oooool00ol0ooSoooooooooo`1eoooo
o`03oc7o0?oooooooooo04;ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`14oooo
o`03o`3on?oooooooooo07Oooooo00?o<Ol0ooooooooool0?_ooool00ol0003oooooooooo`1Zoooo
o`00Ioooool2o`0004Gooooo00?o0?ohooooooooool0_?ooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo04Cooooo00?o0?ohooooooooool0N?ooool00olao`3oooooooooo`0oooooo`03
o`000?oooooooooo06Wooooo001Vooooo`03o`000?oooooooooo04Cooooo00?o0?ohooooooooool0
_Oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo04Cooooo00?o0?ohooooooooool0
NOooool00olao`3oooooooooo`10ooooo`;o0000JOooool006Gooooo00?o0000ooooooooool0A?oo
ool00ol0ooSoooooooooo`2oooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0A?oo
ool00ol0ooSoooooooooo`1jooooo`03oc7o0?oooooooooo04;ooooo00?o0000ooooooooool0I_oo
ool006?ooooo0_l00016ooooo`03o`3on?oooooooooo0<3ooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`14ooooo`03o`3on?oooooooooo0<3ooooo00?o0000ooooooooool0IOooool0
06;ooooo00?o0000ooooooooool0AOooool00ol0ooSoooooooooo`32ooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool0A?ooool00ol0ooSoooooooooo`32ooooo`03o`000?oooooooooo
06Cooooo001Qooooo`03o`000?oooooooooo04Cooooo0_l00036ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0A?ooool00ol0ooSoooooooooo`34ooooo`03o`000?oooooooooo06?o
oooo001Pooooo`03o`000?oooooooooo04Gooooo0_l00036ooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool0A?ooool2o`000<Oooooo00?o0000ooooooooool0H_ooool00?ooooooL_oo
ool00ol0003oooooooooo`26ooooo`;o0000b?ooool00ol0003oooooooooo`1Qooooo`00oooooooo
oooooooooooo:oooool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00
oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[
ooooo`00oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo003ooooooooooooo
ooooool[ooooo`00oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo003ooooo
ooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo
003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?oooooooooooooooooo
ob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?oooooooooo
ooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?oo
ooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:ooo
ool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooo
oooo:oooool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooo
oooooooooooo:oooool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00
oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[
ooooo`00oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo003ooooooooooooo
ooooool[ooooo`00oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo003ooooo
ooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo
003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?oooooooooooooooooo
ob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?oooooooooo
ooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?oo
ooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:ooo
ool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooo
oooo:oooool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooo
oooooooooooo:oooool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00
oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[
ooooo`00oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo003ooooooooooooo
ooooool[ooooo`00oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo003ooooo
ooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?ooooooooooooooooooob_ooooo
003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?oooooooooooooooooo
ob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?oooooooooo
ooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:oooool00?oo
ooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooooooo:ooo
ool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooooooooooo
oooo:oooool00?ooooooooooooooooooob_ooooo003oooooooooooooooooool[ooooo`00oooooooo
oooooooooooo:oooool00?ooooooooooooooooooob_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 807}, {460.688, 0}} -> {-0.051051, -0.0285774, \
0.00260484, 0.00260484}, {{19.5625, 458.312}, {449.688, 10.9375}} -> \
{-0.0445923, -0.0250765, 0.00227923, 0.00227923}, {{348.625, 787.375}, \
{449.688, 10.9375}} -> {-0.7946, -0.0250765, 0.00227923, 0.00227923}},
  CellTags->"Solitaire Diamond Example"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Add Surface Roughness", "Section",
  CellTags->"Add Surface Roughness"],

Cell["lensSurface = Move[LensSurface[50],50];", "Input",
  CellTags->"Add Surface Roughness"],

Cell[CellGroupData[{

Cell["?AddSurfaceRoughness", "Input",
  CellTags->"Add Surface Roughness"],

Cell[BoxData[
    \("AddSurfaceRoughness[component, {x1,x2}, {y1,y2}, options] is a genetic \
building block that introduces a random factor to the surface normals of one \
or more optical surfaces in the component. \n\nHere, the parameters {x1,x2}, \
{y1,y2} specify the angular range of the tilt fluctuations along the \
horizontal and vertical directions. When the random behavior is symmetric \
about the surface normal, then the single-valued half-angles x and y can be \
specified in place of {x1,x2} and {y1,y2}. When the surface roughness is \
non-isotropic and only varies in x, then the y parameters can be omitted. \n\n\
AddSurfaceRoughness inserts a Random function within the \
SurfaceNormalFunction."\)], "Print",
  CellTags->{"Info3252053787-3333948", "Add Surface Roughness"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["roughlens = AddSurfaceRoughness[lensSurface,15]", "Input",
  CellTags->"Add Surface Roughness"],

Cell[BoxData[
    TagBox[\(AddSurfaceRoughness[
        Move[LensSurface[50], 50.`], {\(-15\), 15}]\),
      HoldForm]], "Output",
  CellTags->"Add Surface Roughness"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{LineOfRays[20,NumberOfRays->15],roughlens,Boundary[100,\
GraphicDesign->Off]},PlotType->TopView];\
\>", "Input",
  CellTags->"Add Surface Roughness"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.25 0.00952381 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.5 .0119 m
.5 .09127 L
.5 .17063 L
.5 .25 L
.5 .32937 L
.5 .40873 L
.5 .4881 L
.5 .4881 L
.5 .40873 L
.5 .32937 L
.5 .25 L
.5 .17063 L
.5 .09127 L
.5 .0119 L
.5 .0119 L
s
.5 .25 m
.5 .25 L
.5 .25 L
.5 .25 L
.5 .25 L
.5 .25 L
.5 .25 L
.5 .25 L
.5 .25 L
.5 .25 L
.5 .25 L
.5 .25 L
.5 .25 L
.5 .25 L
.5 .25 L
s
.5 .4881 m
.5 .47998 L
.5 .4562 L
.5 .41836 L
.5 .36905 L
.5 .31162 L
.5 .25 L
.5 .18838 L
.5 .13095 L
.5 .08164 L
.5 .0438 L
.5 .02002 L
.5 .0119 L
.5 .02002 L
.5 .0438 L
.5 .08164 L
.5 .13095 L
.5 .18838 L
.5 .25 L
.5 .31162 L
.5 .36905 L
.5 .41836 L
.5 .4562 L
.5 .47998 L
.5 .4881 L
s
.039 .916 .04 r
.02381 .15476 m
.5 .15476 L
s
% Start of user PostScript
0 -10. 50. -10. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5 .15476 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16837 m
.5 .16837 L
s
% Start of user PostScript
0 -8.57143 50. -8.57143 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5 .16837 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18197 m
.5 .18197 L
s
% Start of user PostScript
0 -7.14286 50. -7.14286 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5 .18197 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19558 m
.5 .19558 L
s
% Start of user PostScript
0 -5.71429 50. -5.71429 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5 .19558 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20918 m
.5 .20918 L
s
% Start of user PostScript
0 -4.28571 50. -4.28571 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5 .20918 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22279 m
.5 .22279 L
s
% Start of user PostScript
0 -2.85714 50. -2.85714 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5 .22279 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23639 m
.5 .23639 L
s
% Start of user PostScript
0 -1.42857 50. -1.42857 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5 .23639 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.5 .25 L
s
% Start of user PostScript
0 0 50. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26361 m
.5 .26361 L
s
% Start of user PostScript
0 1.42857 50. 1.42857 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5 .26361 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27721 m
.5 .27721 L
s
% Start of user PostScript
0 2.85714 50. 2.85714 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5 .27721 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .29082 m
.5 .29082 L
s
% Start of user PostScript
0 4.28571 50. 4.28571 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5 .29082 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .30442 m
.5 .30442 L
s
% Start of user PostScript
0 5.71429 50. 5.71429 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5 .30442 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .31803 m
.5 .31803 L
s
% Start of user PostScript
0 7.14286 50. 7.14286 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5 .31803 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .33163 m
.5 .33163 L
s
% Start of user PostScript
0 8.57143 50. 8.57143 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5 .33163 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .34524 m
.5 .34524 L
s
% Start of user PostScript
0 10. 50. 10. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5 .34524 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .15476 m
.97619 .13501 L
s
% Start of user PostScript
50. -10. 100. -12.0744 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .13501 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .16837 m
.97619 .20358 L
s
% Start of user PostScript
50. -8.57143 100. -4.8738 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .20358 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .18197 m
.97619 .20948 L
s
% Start of user PostScript
50. -7.14286 100. -4.25414 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .20948 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .19558 m
.97619 .1597 L
s
% Start of user PostScript
50. -5.71429 100. -9.48193 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .1597 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .20918 m
.97619 .17787 L
s
% Start of user PostScript
50. -4.28571 100. -7.57368 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .17787 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .22279 m
.97619 .22177 L
s
% Start of user PostScript
50. -2.85714 100. -2.96454 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .22177 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .23639 m
.97619 .26735 L
s
% Start of user PostScript
50. -1.42857 100. 1.82134 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .26735 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .25 m
.97619 .2253 L
s
% Start of user PostScript
50. 0 100. -2.59379 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .2253 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .26361 m
.97619 .2905 L
s
% Start of user PostScript
50. 1.42857 100. 4.25204 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .2905 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .27721 m
.97619 .31416 L
s
% Start of user PostScript
50. 2.85714 100. 6.7373 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .31416 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .29082 m
.97619 .29567 L
s
% Start of user PostScript
50. 4.28571 100. 4.795 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .29567 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .30442 m
.97619 .32515 L
s
% Start of user PostScript
50. 5.71429 100. 7.89067 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .32515 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .31803 m
.97619 .35481 L
s
% Start of user PostScript
50. 7.14286 100. 11.0046 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .35481 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .33163 m
.97619 .34978 L
s
% Start of user PostScript
50. 8.57143 100. 10.4765 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .34978 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .34524 m
.97619 .3539 L
s
% Start of user PostScript
50. 10. 100. 10.91 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .3539 Mdot
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{605.312, 302.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009M0001;R000`400?l00000o`00003oo`3ooooo
0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo
003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooobl0
oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo
;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<00000
0?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0
oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0
o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool0
0`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?oo
o`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo
0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_
0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?oo
obd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000
003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o
0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo
0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo
00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3o
ool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?oo
o`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo
;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3o
ool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`00
0000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00
o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?oo
o`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?oo
o`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0
oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003o
ool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?oo
obl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0
oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<0
00000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool0
0?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3o
ool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3o
ool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]
0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000
oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3o
ool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o
0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`03
0000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo
003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0
oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0
oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo
;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<00000
0?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0
oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0
o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool0
0`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?oo
o`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo
0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_
0?ooo`030000003oool0oooo0?l0oooo5@3oool500WZ2Q<0oooo003o0?ooobl0oooo00<000000?oo
o`3oool0o`3ooolA0?ooo`/02NX:0P00000?0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?P0
oooo6009jPX60?ooo`D02NX:0P00000?0?ooo`00o`3oool_0?ooo`030000003oool0oooo0>00oooo
6009jPXM0?ooo`<02NX:503oool00?l0oooo;`3oool00`000000oooo0?ooo`380?oooaP02NX:=03o
ool00`09jPX0oooo0?ooo`0E0?ooo`00o`3oool_0?ooo`030000003oool0oooo0;00oooo6009jPYT
0?ooo`00o`3oool_0?ooo`030000003oool0oooo09P0oooo6009jPYl0?ooo`00o`3oool_0?ooo`03
0000003oool0oooo0840oooo5`09jPZD0?ooo`00o`3oool_0?ooo`030000003oool0oooo06T0oooo
6009jPZ[0?ooo`00o`3oool_0?ooo`030000003oool0oooo0540oooo6009jP[30?ooo`00o`3oool_
0?ooo`030000003oool0oooo03T0oooo6009jP[K0?ooo`00o`3ooolW0?ooo`<02NX:1@3oool00`00
0000oooo0?ooo`0Q0?oooaP02NX:l`3oool00?l0oooo:03oool600WZ2P030?ooo`000000oooo00X0
oooo6009jP[o0?ooo``0oooo000>0?ooool02NX:8009jPX00`0000002NX:00WZ2P0:00WZ2_l0oooo
903oool00?l0oooo:03oool500WZ2P030?ooo`00000000000?l0oooo;`3oool00?l0oooo9`3oool2
00WZ2PH0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`D02NX:4`3oool00?l0oooo;`3oool00`00
0000oooo0?ooo`3o0?oooaH0oooo1P09jPX2000000l0oooo003o0?ooobl0oooo00<000000?ooo`3o
ool0o`3oool90?ooo`d02NX:00<0oooo00WZ2P09jPX00`09jPX2000000l0oooo003o0?ooobl0oooo
00<000000?ooo`3oool0n`3oool=00WZ2Pd0oooo0`09jPXD0?ooo`00o`3ooolW0?ooo`<02NX:1@3o
ool00`000000oooo0?ooo`3^0?ooo`d02NX:6@3oool00`09jPX0oooo0?ooo`0E0?ooo`00o`3ooolX
0?ooo`H02NX:00<0oooo0000003oool0hP3oool=00WZ2Sh0oooo000>0?ooool02NX:8009jPX00`00
00002NX:00WZ2P0600WZ2/l0oooo3@09jPY;0?ooo`00o`3ooolX0?ooo`D02NX:00<0oooo00000000
00001`3oool=00WZ2[D0oooo3@09jPYH0?ooo`00o`3ooolW0?ooo`802NX:1P3oool00`000000oooo
0?ooo`0B0?ooo`d02NX:V`3oool=00WZ2VD0oooo003o0?ooobl0oooo00<000000?ooo`3oool07`3o
ool=00WZ2X40oooo3@09jPYb0?ooo`00o`3oool_0?ooo`030000003oool0oooo02`0oooo3@09jPYW
0?ooo`d02NX:O`3oool00?l0oooo;`3oool00`000000oooo0?ooo`0i0?ooo`d02NX:C@3oool=00WZ
2W@0oooo1@09jPXC0?ooo`00o`3oool_0?ooo`030000003oool0oooo04H0oooo3@09jPXc0?ooo`d0
2NX:P@3oool700WZ2P8000003`3oool00?l0oooo9`3oool300WZ2PD0oooo00<000000?ooo`3oool0
D`3oool=00WZ2QT0oooo3@09jPYo0?ooo`l02NX:0P3oool500WZ2P8000003`3oool00?l0oooo:03o
ool600WZ2P800000HP3ooolI00WZ2Wd0oooo3`09jPX@0?ooo`<02NX:503oool000h0ooooo`09jPXP
00WZ2P0300000009jPX02NX:00P02NX:F03oool=00WZ2P030?ooo`09jPX02NX:00/02NX:K@3oool?
00WZ2Qh0oooo00<02NX:0?ooo`3oool05@3oool00?l0oooo:03oool500WZ2P80oooo00<000000?oo
o`3oool01`3ooolB00WZ2ST0oooo3@09jPXK0?ooo`d02NX:D@3oool?00WZ2TD0oooo003o0?ooobL0
oooo0P09jPX60?ooo`030000003oool0oooo01T0oooo4P09jPXJ0?ooo`d02NX:=@3oool=00WZ2SD0
oooo3`09jPYD0?ooo`00o`3oool_0?ooo`030000003oool0oooo02/0oooo6P09jPY?0?ooo`d02NX:
6@3oool?00WZ2V<0oooo003o0?ooobl0oooo00<000000?ooo`3oool0:`3oool=00WZ2PD0oooo4P09
jPYB0?oooaT02NX:LP3oool00?l0oooo;`3oool00`000000oooo0?ooo`0N0?ooo`d02NX:903ooolB
00WZ2S/0oooo3`09jPX30?ooo`d02NX:L@3oool00?l0oooo9`3oool300WZ2PD0oooo00<000000?oo
o`3oool04@3oool=00WZ2T<0oooo4P09jPXI0?oooa002NX:7`3oool=00WZ2V@0oooo003o0?ooobP0
oooo1P09jPX2000000H0oooo3@09jPYR0?oooaT02NX:?03oool=00WZ2UL0oooo000>0?ooool02NX:
8009jPX00`0000002NX:00WZ2P0500WZ2VX0oooo3`09jPX80?oooa402NX:?`3oool=00WZ2TX0oooo
003o0?ooobP0oooo1@09jPX20?ooo`030000003oool0oooo05l0oooo3`09jPXX0?oooa802NX:>P3o
ool=00WZ2Sd0oooo003o0?ooobL0oooo0P09jPX60?ooo`030000003oool0oooo0500oooo3`09jPY9
0?oooa802NX:=@3oool=00WZ2QP0oooo0P09jPXF0?ooo`00o`3oool_0?ooo`030000003oool0oooo
0440oooo3`09jPYZ0?oooa802NX:<03oool=00WZ2P`0oooo1009jPXC0?ooo`00o`3oool_0?ooo`03
0000003oool0oooo0380oooo3`09jPZ;0?oooa802NX::`3ooolB00WZ2P8000003`3oool00?l0oooo
;`3oool00`000000oooo0?ooo`0S0?ooo`l02NX:[03ooolB00WZ2RD0oooo1P09jPX2000000l0oooo
003o0?ooobL0oooo0`09jPX50?ooo`030000003oool0oooo01@0oooo3`09jP[=0?oooa802NX:4P3o
ool400WZ2Q@0oooo003o0?ooobP0oooo1P09jPX00`3oool000000?ooo`060?ooo`l02NX:kP3ooolB
00WZ2P030?ooo`09jPX02NX:00@02NX:4@3oool000h0ooooo`09jPXP00WZ2P0300000009jPX02NX:
00H02NX:o`3oool@0?ooo`L02NX:0P00000?0?ooo`00o`3ooolX0?ooo`D02NX:00<0oooo00000000
0000o`3ooolH0?ooo`D02NX:00<0oooo0000000000003`3oool00?l0oooo9`3oool200WZ2PH0oooo
00<000000?ooo`3oool0o`3ooolE0?ooo`802NX:5P3oool00?l0oooo;`3oool00`000000oooo0?oo
o`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?oo
o`030000003oool0oooo0?l0oooo;@3oool00?l0oooo9`3oool300WZ2PD0oooo00<000000?ooo`3o
ool0o`3ooolE0?ooo`<02NX:5@3oool00?l0oooo:03oool600WZ2P030?ooo`000000oooo0?l0oooo
5`3oool600WZ2P8000003`3oool000h0ooooo`09jPXP00WZ2P0300000009jPX02NX:0?l02NX:7@09
jPX2000000l0oooo003o0?ooobP0oooo1@09jPX00`3oool000000000003o0?oooaP0oooo1P09jPX2
000000l0oooo003o0?ooobL0oooo0P09jPX60?ooo`030000003oool0oooo0?l0oooo4`3oool900WZ
2P8000003`3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?oooa<02NX:0`3oool500WZ2Q80
oooo003o0?ooobl0oooo00<000000?ooo`3oool0k03ooolC00WZ2QD0oooo0P09jPXF0?ooo`00o`3o
ool_0?ooo`030000003oool0oooo0=T0oooo4`09jPY00?ooo`00o`3ooolW0?ooo`<02NX:1@3oool0
0`000000oooo0?ooo`360?oooa<02NX:D`3oool00?l0oooo:03oool600WZ2P030?ooo`000000oooo
0;@0oooo4`09jPYV0?ooo`003P3ooooo00WZ2R002NX:00<0000000WZ2P09jPX01`09jPZJ0?oooa<0
2NX:N@3oool00?l0oooo:03oool500WZ2P030?ooo`000000000000P0oooo3`09jPYg0?oooa@02NX:
S03oool00?l0oooo9`3oool200WZ2PH0oooo00<000000?ooo`3oool05@3oool?00WZ2UD0oooo4`09
jPZP0?ooo`00o`3oool_0?ooo`030000003oool0oooo02@0oooo3`09jPXc0?oooa<02NX:/`3oool0
0?l0oooo;`3oool00`000000oooo0?ooo`0c0?ooo`l02NX:4@3ooolC00WZ2/H0oooo003o0?ooobl0
oooo00<000000?ooo`3oool0@03ooolC00WZ2]T0oooo003o0?ooobl0oooo00<000000?ooo`3oool0
;@3ooolC00WZ2Q40oooo3`09jP[<0?ooo`00o`3ooolW0?ooo`<02NX:1@3oool00`000000oooo0?oo
o`0J0?oooa<02NX:<`3oool?00WZ2[d0oooo003o0?ooobP0oooo1P09jPX2000000T0oooo4`09jPYE
0?ooo`l02NX:[P3oool000h0ooooo`09jPXP00WZ2P0300000009jPX02NX:00P02NX:M`3oool@00WZ
2Yh0oooo003o0?ooobP0oooo1@09jPX20?ooo`030000003oool0oooo08h0oooo3`09jPZ?0?ooo`00
o`3ooolW0?ooo`802NX:1P3oool00`000000oooo0?ooo`2M0?ooo`l02NX:P03oool00?l0oooo;`3o
ool00`000000oooo0?ooo`2/0?ooo`l02NX:L@3oool00?l0oooo;`3oool00`000000oooo0?ooo`2k
0?ooo`l02NX:HP3oool00?l0oooo;`3oool00`000000oooo0?ooo`3:0?ooo`l02NX:D`3oool00?l0
oooo9`3oool300WZ2PD0oooo00<000000?ooo`3oool0f@3oool?00WZ2T@0oooo003o0?ooobP0oooo
1P09jPX200000>X0oooo3`09jPXe0?ooo`003P3ooooo00WZ2R002NX:00<0000000WZ2P09jPX02009
jP[`0?ooo`l02NX:3P3oool300WZ2QD0oooo003o0?ooobP0oooo1@09jPX20?ooo`030000003oool0
oooo00L0oooo4P09jP[]0?oooaD02NX:4@3oool00?l0oooo9`3oool200WZ2PH0oooo00<000000?oo
o`3oool06@3ooolB00WZ2^X0oooo1P09jPX2000000l0oooo003o0?ooobl0oooo00<000000?ooo`3o
ool0:`3ooolB00WZ2]P0oooo1@09jPX00`3oool000000000000?0?ooo`00o`3oool_0?ooo`030000
003oool0oooo03d0oooo4P09jP[50?ooo`802NX:5P3oool00?l0oooo;`3oool00`000000oooo0?oo
o`1?0?oooa802NX:b`3oool00?l0oooo9`3oool300WZ2PD0oooo00<000000?ooo`3oool0H@3ooolB
00WZ2[T0oooo003o0?ooobP0oooo1P09jPX00`3oool000000?ooo`1d0?oooa802NX:Y`3oool000h0
ooooo`09jPXP00WZ2P0300000009jPX02NX:00H02NX:P03ooolA00WZ2YH0oooo003o0?ooobP0oooo
1@09jPX00`3oool00000000000070?ooo`d02NX:Q03ooolB00WZ2X@0oooo003o0?ooobL0oooo0P09
jPX60?ooo`030000003oool0oooo0180oooo3@09jPZ90?oooa802NX:LP3oool00?l0oooo;`3oool0
0`000000oooo0?ooo`0O0?ooo`d02NX:SP3ooolB00WZ2V00oooo003o0?ooobl0oooo00<000000?oo
o`3oool0;03oool=00WZ2Y<0oooo4P09jPY>0?ooo`00o`3oool_0?ooo`030000003oool0oooo03T0
oooo3@09jPZH0?oooa802NX:?03oool00?l0oooo9`3oool300WZ2PD0oooo00<000000?ooo`3oool0
AP3oool=00WZ2Yd0oooo4P09jPXB0?ooo`<02NX:5@3oool00?l0oooo:03oool600WZ2P030?ooo`00
0000oooo05@0oooo3@09jPZR0?oooa802NX:00<0oooo00WZ2P09jPX01009jPXA0?ooo`003P3ooooo
00WZ2R002NX:00<0000000WZ2P09jPX0;`09jPXb0?ooo`d02NX:Y`3oool700WZ2P8000003`3oool0
0?l0oooo:03oool500WZ2P030?ooo`00000000000300ooooH009jPZ60?ooo`H02NX:00<0oooo0000
000000003`3oool00?l0oooo9`3oool200WZ2PH0oooo00<000000?ooo`3oool0NP3oool=00WZ2PL0
ooooG`09jPXW0?ooo`L02NX:4@3oool00?l0oooo;`3oool00`000000oooo0?ooo`270?ooo`d02NX:
F@3oool^00WZ2P8000003`3oool00?l0oooo;`3oool00`000000oooo0?ooo`2D0?ooo`d02NX:M03o
ool500WZ2P030?ooo`000000000000l0oooo003o0?ooobl0oooo00<000000?ooo`3oool0X@3oool=
00WZ2VH0oooo0P09jPXF0?ooo`00o`3oool_0?ooo`030000003oool0oooo0:h0oooo3@09jPYa0?oo
o`00o`3ooolW0?ooo`<02NX:1@3oool00`000000oooo0?ooo`2k0?ooo`d02NX:I03oool00?l0oooo
:03oool600WZ2P800000bP3oool=00WZ2UL0oooo000>0?ooool02NX:8009jPX00`0000002NX:00WZ
2P0;00WZ2//0oooo3@09jPY:0?ooo`00o`3ooolX0?ooo`D02NX:0P3oool00`000000oooo0?ooo`0:
0?oooaP02NX:`03oool=00WZ2Sd0oooo003o0?ooobL0oooo0P09jPX60?ooo`030000003oool0oooo
0280oooo6009jPZe0?ooo`d02NX:<03oool00?l0oooo;`3oool00`000000oooo0?ooo`0j0?oooaP0
2NX:ZP3oool=00WZ2P/0oooo0`09jPXE0?ooo`00o`3oool_0?ooo`030000003oool0oooo0580oooo
6009jPZO0?oooa802NX:4@3oool00?l0oooo;`3oool00`000000oooo0?ooo`1Z0?oooaP02NX:U03o
ool500WZ2P8000003`3oool00?l0oooo9`3oool300WZ2PD0oooo00<000000?ooo`3oool0PP3ooolG
00WZ2W`0oooo1@09jPX00`3oool000000000000?0?ooo`00o`3ooolX0?ooo`H02NX:0P00002K0?oo
oaP02NX:H`3oool200WZ2QH0oooo000>0?ooool02NX:8009jPX00`0000002NX:00WZ2P0600WZ2Z`0
oooo6009jPYS0?ooo`00o`3ooolX0?ooo`D02NX:0P3oool00`000000oooo0?ooo`050?ooo`d02NX:
]`3ooolH00WZ2T/0oooo003o0?ooobL0oooo0P09jPX60?ooo`030000003oool0oooo0180oooo3@09
jP[20?oooaP02NX:6`3oool300WZ2QD0oooo003o0?ooobl0oooo00<000000?ooo`3oool07`3oool=
00WZ2/d0oooo6009jPX40?ooo`H02NX:4@3oool00?l0oooo;`3oool00`000000oooo0?ooo`0/0?oo
o`d02NX:f03oool:00WZ2P8000003`3oool00?l0oooo;`3oool00`000000oooo0?ooo`0i0?ooo`d0
2NX:c`3oool500WZ2P030?ooo`000000000000l0oooo003o0?ooobL0oooo0`09jPX50?ooo`030000
003oool0oooo04H0oooo3@09jP[10?ooo`802NX:5P3oool00?l0oooo:03oool600WZ2P800000E@3o
ool=00WZ2/`0oooo000>0?ooool02NX:8009jPX00`0000002NX:00WZ2P0<00WZ2UD0oooo3@09jPZo
0?ooo`00o`3ooolX0?ooo`D02NX:0P3oool00`000000oooo0?ooo`0;0?oooaX02NX:B03oool=00WZ
2[80oooo003o0?ooobL0oooo0P09jPX60?ooo`030000003oool0oooo02D0oooo6P09jPXk0?ooo`d0
2NX:Y@3oool00?l0oooo;`3oool00`000000oooo0?ooo`0o0?oooaX02NX:;P3oool=00WZ2YP0oooo
003o0?ooobl0oooo00<000000?ooo`3oool0F@3ooolJ00WZ2R40oooo3@09jPZ;0?ooo`00o`3oool_
0?ooo`030000003oool0oooo07<0oooo6`09jPXC0?ooo`d02NX:OP3oool00?l0oooo9`3oool300WZ
2PD0oooo00<000000?ooo`3oool0SP3ooolJ00WZ2PH0oooo3@09jPYa0?ooo`00o`3ooolX0?ooo`H0
2NX:00<0oooo0000003oool0Z@3ooolP00WZ2V@0oooo000>0?ooool02NX:8009jPX00`0000002NX:
00WZ2P0L00WZ2ZL0oooo6P09jPY@0?ooo`00o`3ooolX0?ooo`D02NX:00<0oooo0000000000007@3o
ooli00WZ2X40oooo8@09jPXN0?ooo`<02NX:5@3oool00?l0oooo9`3oool200WZ2PH0oooo00<00000
0?ooo`3oool0E03ooolj00WZ2U@0oooo3@09jPX70?oooaX02NX:1@3oool600WZ2P8000003`3oool0
0?l0oooo;`3oool00`000000oooo0?ooo`2>0?ooocT02NX::03oool=00WZ2Q@0oooo2`09jPX20000
00l0oooo003o0?ooobl0oooo00<000000?ooo`3oool0a`3ooom200WZ2P`0oooo1P09jPXA0?ooo`00
o`3oool_0?ooo`030000003oool0oooo0?l0oooo0@3ooolK00WZ2P8000003`3oool00?l0oooo;`3o
ool00`000000oooo0?ooo`3o0?oooaH0oooo1P09jPX2000000l0oooo003o0?ooobl0oooo00<00000
0?ooo`3oool0o`3ooolE0?ooo`@02NX:503oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?oo
obd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000
003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o
0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo
0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo
00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3o
ool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?oo
o`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo
;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3o
ool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`00
0000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00
o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?oo
o`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?oo
o`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0
oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003o
ool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?oo
obl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0
oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<0
00000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool0
0?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3o
ool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3o
ool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]
0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000
oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3o
ool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o
0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`03
0000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo
003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0
oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0
oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo
;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<00000
0?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0
oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0
o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool0
0`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?oo
o`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo
0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_
0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?oo
obd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000
003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o
0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo
0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo
00<000000?ooo`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3o
ool00?l0oooo;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?oo
o`3oool0o`3oool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo
;`3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3o
ool]0?ooo`00o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`00
0000oooo0?ooo`3o0?ooobd0oooo003o0?ooobl0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00
o`3oool_0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo;`3oool00`000000oooo0?oo
o`3o0?ooobd0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0
oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?oo
ool0ooooG`3oool00001\
\>"],
  ImageRangeCache->{{{0, 604.312}, {301.625, 0}} -> {-2.59299, -26.2503, \
0.174059, 0.174059}},
  CellTags->"Add Surface Roughness"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{
\tLineOfRays[45,NumberOfRays->7],
\tMove[PlanoConvexLens[100,50,10],50],
\tBoundary[150]}, PlotType->TopView];\
\>", "Input",
  CellTags->"Add Surface Roughness"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00634921 0.5 0.00634921 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.38204 .34127 m
.40476 .34127 L
.40476 .39418 L
.35873 .39418 L
.38204 .34127 L
F
.35873 .39418 m
.40476 .39418 L
.40476 .44709 L
.34555 .44709 L
.35873 .39418 L
F
.34555 .44709 m
.40476 .44709 L
.40476 .5 L
.34127 .5 L
.34555 .44709 L
F
.34127 .5 m
.40476 .5 L
.40476 .55291 L
.34555 .55291 L
.34127 .5 L
F
.34555 .55291 m
.40476 .55291 L
.40476 .60582 L
.35873 .60582 L
.34555 .55291 L
F
.35873 .60582 m
.40476 .60582 L
.40476 .65873 L
.38204 .65873 L
.35873 .60582 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.38204 .34127 m
.35873 .39418 L
.34555 .44709 L
.34127 .5 L
.34555 .55291 L
.35873 .60582 L
.38204 .65873 L
.40476 .65873 L
.40476 .60582 L
.40476 .55291 L
.40476 .5 L
.40476 .44709 L
.40476 .39418 L
.40476 .34127 L
.38204 .34127 L
s
.5 g
.38204 .5 m
.40476 .5 L
.40476 .5 L
.35873 .5 L
.38204 .5 L
F
.35873 .5 m
.40476 .5 L
.40476 .5 L
.34555 .5 L
.35873 .5 L
F
.34555 .5 m
.40476 .5 L
.40476 .5 L
.34127 .5 L
.34555 .5 L
F
.34127 .5 m
.40476 .5 L
.40476 .5 L
.34555 .5 L
.34127 .5 L
F
.34555 .5 m
.40476 .5 L
.40476 .5 L
.35873 .5 L
.34555 .5 L
F
.35873 .5 m
.40476 .5 L
.40476 .5 L
.38204 .5 L
.35873 .5 L
F
0 g
.38204 .5 m
.35873 .5 L
.34555 .5 L
.34127 .5 L
.34555 .5 L
.35873 .5 L
.38204 .5 L
.40476 .5 L
.40476 .5 L
.40476 .5 L
.40476 .5 L
.40476 .5 L
.40476 .5 L
.40476 .5 L
.38204 .5 L
s
.38204 .65873 m
.40476 .65873 L
.40476 .65332 L
.38204 .65332 L
.38204 .65873 L
s
.38204 .65332 m
.40476 .65332 L
.40476 .63746 L
.38204 .63746 L
.38204 .65332 L
s
.38204 .63746 m
.40476 .63746 L
.40476 .61224 L
.38204 .61224 L
.38204 .63746 L
s
.38204 .61224 m
.40476 .61224 L
.40476 .57937 L
.38204 .57937 L
.38204 .61224 L
s
.38204 .57937 m
.40476 .57937 L
.40476 .54108 L
.38204 .54108 L
.38204 .57937 L
s
.38204 .54108 m
.40476 .54108 L
.40476 .5 L
.38204 .5 L
.38204 .54108 L
s
.38204 .5 m
.40476 .5 L
.40476 .45892 L
.38204 .45892 L
.38204 .5 L
s
.38204 .45892 m
.40476 .45892 L
.40476 .42063 L
.38204 .42063 L
.38204 .45892 L
s
.38204 .42063 m
.40476 .42063 L
.40476 .38776 L
.38204 .38776 L
.38204 .42063 L
s
.38204 .38776 m
.40476 .38776 L
.40476 .36254 L
.38204 .36254 L
.38204 .38776 L
s
.38204 .36254 m
.40476 .36254 L
.40476 .34668 L
.38204 .34668 L
.38204 .36254 L
s
.38204 .34668 m
.40476 .34668 L
.40476 .34127 L
.38204 .34127 L
.38204 .34668 L
s
.38204 .34127 m
.40476 .34127 L
.40476 .34668 L
.38204 .34668 L
.38204 .34127 L
s
.38204 .34668 m
.40476 .34668 L
.40476 .36254 L
.38204 .36254 L
.38204 .34668 L
s
.38204 .36254 m
.40476 .36254 L
.40476 .38776 L
.38204 .38776 L
.38204 .36254 L
s
.38204 .38776 m
.40476 .38776 L
.40476 .42063 L
.38204 .42063 L
.38204 .38776 L
s
.38204 .42063 m
.40476 .42063 L
.40476 .45892 L
.38204 .45892 L
.38204 .42063 L
s
.38204 .45892 m
.40476 .45892 L
.40476 .5 L
.38204 .5 L
.38204 .45892 L
s
.38204 .5 m
.40476 .5 L
.40476 .54108 L
.38204 .54108 L
.38204 .5 L
s
.38204 .54108 m
.40476 .54108 L
.40476 .57937 L
.38204 .57937 L
.38204 .54108 L
s
.38204 .57937 m
.40476 .57937 L
.40476 .61224 L
.38204 .61224 L
.38204 .57937 L
s
.38204 .61224 m
.40476 .61224 L
.40476 .63746 L
.38204 .63746 L
.38204 .61224 L
s
.38204 .63746 m
.40476 .63746 L
.40476 .65332 L
.38204 .65332 L
.38204 .63746 L
s
.38204 .65332 m
.40476 .65332 L
.40476 .65873 L
.38204 .65873 L
.38204 .65332 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .35714 m
.37387 .35714 L
s
% Start of user PostScript
0 -22.5 55.1338 -22.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.37387 .35714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .40476 m
.35534 .40476 L
s
% Start of user PostScript
0 -15. 52.2161 -15. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.35534 .40476 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .45238 m
.34473 .45238 L
s
% Start of user PostScript
0 -7.5 50.5451 -7.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34473 .45238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.34127 .5 L
s
% Start of user PostScript
0 0 50. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .54762 m
.34473 .54762 L
s
% Start of user PostScript
0 7.5 50.5451 7.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34473 .54762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .59524 m
.35534 .59524 L
s
% Start of user PostScript
0 15. 52.2161 15. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.35534 .59524 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .64286 m
.37387 .64286 L
s
% Start of user PostScript
0 22.5 55.1338 22.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.37387 .64286 Mdot
.039 .916 .04 r
.5 Mabswid
.37387 .35714 m
.40476 .3621 L
s
0 0 0 r
2 Mabswid
.40476 .3621 Mdot
.039 .916 .04 r
.5 Mabswid
.35534 .40476 m
.40476 .40981 L
s
0 0 0 r
2 Mabswid
.40476 .40981 Mdot
.039 .916 .04 r
.5 Mabswid
.34473 .45238 m
.40476 .45537 L
s
% Start of user PostScript
50.5451 -7.5 60. -7.0288 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .45537 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .5 m
.40476 .5 L
s
% Start of user PostScript
50. 0 60. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.34473 .54762 m
.40476 .54463 L
s
% Start of user PostScript
50.5451 7.5 60. 7.0288 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .54463 Mdot
.039 .916 .04 r
.5 Mabswid
.35534 .59524 m
.40476 .59019 L
s
0 0 0 r
2 Mabswid
.40476 .59019 Mdot
.039 .916 .04 r
.5 Mabswid
.37387 .64286 m
.40476 .6379 L
s
0 0 0 r
2 Mabswid
.40476 .6379 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .3621 m
.97619 .50389 L
s
% Start of user PostScript
60. -21.7189 150. 0.613175 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .50389 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .40981 m
.97619 .4992 L
s
% Start of user PostScript
60. -14.2042 150. -0.126338 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .4992 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .45537 m
.97619 .49871 L
s
% Start of user PostScript
60. -7.0288 150. -0.202445 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .49871 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .5 m
.97619 .5 L
s
% Start of user PostScript
60. 0 150. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .54463 m
.97619 .50129 L
s
% Start of user PostScript
60. 7.0288 150. 0.202445 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .50129 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .59019 m
.97619 .5008 L
s
% Start of user PostScript
60. 14.2042 150. 0.126338 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .5008 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .6379 m
.97619 .49611 L
s
% Start of user PostScript
60. 21.7189 150. -0.613175 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .49611 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-3.75078, -78.7507, 0.548786, \
0.548786}},
  CellTags->"Add Surface Roughness"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{
\tLineOfRays[45,NumberOfRays->7],
\tMove[AddSurfaceRoughness[PlanoConvexLens[100,50,10],2],50],
\tBoundary[150]}, PlotType->TopView];\
\>", "Input",
  CellTags->"Add Surface Roughness"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00634921 0.5 0.00634921 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.38204 .34127 m
.40476 .34127 L
.40476 .39418 L
.35873 .39418 L
.38204 .34127 L
F
.35873 .39418 m
.40476 .39418 L
.40476 .44709 L
.34555 .44709 L
.35873 .39418 L
F
.34555 .44709 m
.40476 .44709 L
.40476 .5 L
.34127 .5 L
.34555 .44709 L
F
.34127 .5 m
.40476 .5 L
.40476 .55291 L
.34555 .55291 L
.34127 .5 L
F
.34555 .55291 m
.40476 .55291 L
.40476 .60582 L
.35873 .60582 L
.34555 .55291 L
F
.35873 .60582 m
.40476 .60582 L
.40476 .65873 L
.38204 .65873 L
.35873 .60582 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.38204 .34127 m
.35873 .39418 L
.34555 .44709 L
.34127 .5 L
.34555 .55291 L
.35873 .60582 L
.38204 .65873 L
.40476 .65873 L
.40476 .60582 L
.40476 .55291 L
.40476 .5 L
.40476 .44709 L
.40476 .39418 L
.40476 .34127 L
.38204 .34127 L
s
.5 g
.38204 .5 m
.40476 .5 L
.40476 .5 L
.35873 .5 L
.38204 .5 L
F
.35873 .5 m
.40476 .5 L
.40476 .5 L
.34555 .5 L
.35873 .5 L
F
.34555 .5 m
.40476 .5 L
.40476 .5 L
.34127 .5 L
.34555 .5 L
F
.34127 .5 m
.40476 .5 L
.40476 .5 L
.34555 .5 L
.34127 .5 L
F
.34555 .5 m
.40476 .5 L
.40476 .5 L
.35873 .5 L
.34555 .5 L
F
.35873 .5 m
.40476 .5 L
.40476 .5 L
.38204 .5 L
.35873 .5 L
F
0 g
.38204 .5 m
.35873 .5 L
.34555 .5 L
.34127 .5 L
.34555 .5 L
.35873 .5 L
.38204 .5 L
.40476 .5 L
.40476 .5 L
.40476 .5 L
.40476 .5 L
.40476 .5 L
.40476 .5 L
.40476 .5 L
.38204 .5 L
s
.38204 .65873 m
.40476 .65873 L
.40476 .65332 L
.38204 .65332 L
.38204 .65873 L
s
.38204 .65332 m
.40476 .65332 L
.40476 .63746 L
.38204 .63746 L
.38204 .65332 L
s
.38204 .63746 m
.40476 .63746 L
.40476 .61224 L
.38204 .61224 L
.38204 .63746 L
s
.38204 .61224 m
.40476 .61224 L
.40476 .57937 L
.38204 .57937 L
.38204 .61224 L
s
.38204 .57937 m
.40476 .57937 L
.40476 .54108 L
.38204 .54108 L
.38204 .57937 L
s
.38204 .54108 m
.40476 .54108 L
.40476 .5 L
.38204 .5 L
.38204 .54108 L
s
.38204 .5 m
.40476 .5 L
.40476 .45892 L
.38204 .45892 L
.38204 .5 L
s
.38204 .45892 m
.40476 .45892 L
.40476 .42063 L
.38204 .42063 L
.38204 .45892 L
s
.38204 .42063 m
.40476 .42063 L
.40476 .38776 L
.38204 .38776 L
.38204 .42063 L
s
.38204 .38776 m
.40476 .38776 L
.40476 .36254 L
.38204 .36254 L
.38204 .38776 L
s
.38204 .36254 m
.40476 .36254 L
.40476 .34668 L
.38204 .34668 L
.38204 .36254 L
s
.38204 .34668 m
.40476 .34668 L
.40476 .34127 L
.38204 .34127 L
.38204 .34668 L
s
.38204 .34127 m
.40476 .34127 L
.40476 .34668 L
.38204 .34668 L
.38204 .34127 L
s
.38204 .34668 m
.40476 .34668 L
.40476 .36254 L
.38204 .36254 L
.38204 .34668 L
s
.38204 .36254 m
.40476 .36254 L
.40476 .38776 L
.38204 .38776 L
.38204 .36254 L
s
.38204 .38776 m
.40476 .38776 L
.40476 .42063 L
.38204 .42063 L
.38204 .38776 L
s
.38204 .42063 m
.40476 .42063 L
.40476 .45892 L
.38204 .45892 L
.38204 .42063 L
s
.38204 .45892 m
.40476 .45892 L
.40476 .5 L
.38204 .5 L
.38204 .45892 L
s
.38204 .5 m
.40476 .5 L
.40476 .54108 L
.38204 .54108 L
.38204 .5 L
s
.38204 .54108 m
.40476 .54108 L
.40476 .57937 L
.38204 .57937 L
.38204 .54108 L
s
.38204 .57937 m
.40476 .57937 L
.40476 .61224 L
.38204 .61224 L
.38204 .57937 L
s
.38204 .61224 m
.40476 .61224 L
.40476 .63746 L
.38204 .63746 L
.38204 .61224 L
s
.38204 .63746 m
.40476 .63746 L
.40476 .65332 L
.38204 .65332 L
.38204 .63746 L
s
.38204 .65332 m
.40476 .65332 L
.40476 .65873 L
.38204 .65873 L
.38204 .65332 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .35714 m
.37387 .35714 L
s
% Start of user PostScript
0 -22.5 55.1338 -22.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.37387 .35714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .40476 m
.35534 .40476 L
s
% Start of user PostScript
0 -15. 52.2161 -15. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.35534 .40476 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .45238 m
.34473 .45238 L
s
% Start of user PostScript
0 -7.5 50.5451 -7.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34473 .45238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.34127 .5 L
s
% Start of user PostScript
0 0 50. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .54762 m
.34473 .54762 L
s
% Start of user PostScript
0 7.5 50.5451 7.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34473 .54762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .59524 m
.35534 .59524 L
s
% Start of user PostScript
0 15. 52.2161 15. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.35534 .59524 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .64286 m
.37387 .64286 L
s
% Start of user PostScript
0 22.5 55.1338 22.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.37387 .64286 Mdot
.039 .916 .04 r
.5 Mabswid
.37387 .35714 m
.40476 .36171 L
s
0 0 0 r
2 Mabswid
.40476 .36171 Mdot
.039 .916 .04 r
.5 Mabswid
.35534 .40476 m
.40476 .40952 L
s
0 0 0 r
2 Mabswid
.40476 .40952 Mdot
.039 .916 .04 r
.5 Mabswid
.34473 .45238 m
.40476 .45466 L
s
% Start of user PostScript
50.5451 -7.5 60. -7.14091 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .45466 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .5 m
.40476 .50016 L
s
% Start of user PostScript
50. 0 60. 0.0244982 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .50016 Mdot
.039 .916 .04 r
.5 Mabswid
.34473 .54762 m
.40476 .54458 L
s
% Start of user PostScript
50.5451 7.5 60. 7.02192 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .54458 Mdot
.039 .916 .04 r
.5 Mabswid
.35534 .59524 m
.40476 .59022 L
s
0 0 0 r
2 Mabswid
.40476 .59022 Mdot
.039 .916 .04 r
.5 Mabswid
.37387 .64286 m
.40476 .63754 L
s
0 0 0 r
2 Mabswid
.40476 .63754 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .36171 m
.97619 .48307 L
s
% Start of user PostScript
60. -21.7811 150. -2.6663 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .48307 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .40952 m
.97619 .48582 L
s
% Start of user PostScript
60. -14.2499 150. -2.23289 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .48582 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .45466 m
.97619 .48297 L
s
% Start of user PostScript
60. -7.14091 150. -2.68188 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .48297 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .50016 m
.97619 .50936 L
s
% Start of user PostScript
60. 0.0244982 150. 1.4735 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .50936 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .54458 m
.97619 .49499 L
s
% Start of user PostScript
60. 7.02192 150. -0.788768 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .49499 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .59022 m
.97619 .50618 L
s
% Start of user PostScript
60. 14.2091 150. 0.973259 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .50618 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .63754 m
.97619 .49478 L
s
% Start of user PostScript
60. 21.6628 150. -0.821515 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .49478 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-3.75078, -78.7507, 0.394741, \
0.394741}},
  CellTags->"Add Surface Roughness"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[{
\tLineOfRays[45,NumberOfRays->101],
\tMove[AddSurfaceRoughness[PlanoConvexLens[100,50,10],2],50],
\tBoundary[150]}, PlotType->TopView];\
\>", "Input",
  CellTags->"Add Surface Roughness"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00634921 0.5 0.00634921 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.38204 .34127 m
.40476 .34127 L
.40476 .39418 L
.35873 .39418 L
.38204 .34127 L
F
.35873 .39418 m
.40476 .39418 L
.40476 .44709 L
.34555 .44709 L
.35873 .39418 L
F
.34555 .44709 m
.40476 .44709 L
.40476 .5 L
.34127 .5 L
.34555 .44709 L
F
.34127 .5 m
.40476 .5 L
.40476 .55291 L
.34555 .55291 L
.34127 .5 L
F
.34555 .55291 m
.40476 .55291 L
.40476 .60582 L
.35873 .60582 L
.34555 .55291 L
F
.35873 .60582 m
.40476 .60582 L
.40476 .65873 L
.38204 .65873 L
.35873 .60582 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.38204 .34127 m
.35873 .39418 L
.34555 .44709 L
.34127 .5 L
.34555 .55291 L
.35873 .60582 L
.38204 .65873 L
.40476 .65873 L
.40476 .60582 L
.40476 .55291 L
.40476 .5 L
.40476 .44709 L
.40476 .39418 L
.40476 .34127 L
.38204 .34127 L
s
.5 g
.38204 .5 m
.40476 .5 L
.40476 .5 L
.35873 .5 L
.38204 .5 L
F
.35873 .5 m
.40476 .5 L
.40476 .5 L
.34555 .5 L
.35873 .5 L
F
.34555 .5 m
.40476 .5 L
.40476 .5 L
.34127 .5 L
.34555 .5 L
F
.34127 .5 m
.40476 .5 L
.40476 .5 L
.34555 .5 L
.34127 .5 L
F
.34555 .5 m
.40476 .5 L
.40476 .5 L
.35873 .5 L
.34555 .5 L
F
.35873 .5 m
.40476 .5 L
.40476 .5 L
.38204 .5 L
.35873 .5 L
F
0 g
.38204 .5 m
.35873 .5 L
.34555 .5 L
.34127 .5 L
.34555 .5 L
.35873 .5 L
.38204 .5 L
.40476 .5 L
.40476 .5 L
.40476 .5 L
.40476 .5 L
.40476 .5 L
.40476 .5 L
.40476 .5 L
.38204 .5 L
s
.38204 .65873 m
.40476 .65873 L
.40476 .65332 L
.38204 .65332 L
.38204 .65873 L
s
.38204 .65332 m
.40476 .65332 L
.40476 .63746 L
.38204 .63746 L
.38204 .65332 L
s
.38204 .63746 m
.40476 .63746 L
.40476 .61224 L
.38204 .61224 L
.38204 .63746 L
s
.38204 .61224 m
.40476 .61224 L
.40476 .57937 L
.38204 .57937 L
.38204 .61224 L
s
.38204 .57937 m
.40476 .57937 L
.40476 .54108 L
.38204 .54108 L
.38204 .57937 L
s
.38204 .54108 m
.40476 .54108 L
.40476 .5 L
.38204 .5 L
.38204 .54108 L
s
.38204 .5 m
.40476 .5 L
.40476 .45892 L
.38204 .45892 L
.38204 .5 L
s
.38204 .45892 m
.40476 .45892 L
.40476 .42063 L
.38204 .42063 L
.38204 .45892 L
s
.38204 .42063 m
.40476 .42063 L
.40476 .38776 L
.38204 .38776 L
.38204 .42063 L
s
.38204 .38776 m
.40476 .38776 L
.40476 .36254 L
.38204 .36254 L
.38204 .38776 L
s
.38204 .36254 m
.40476 .36254 L
.40476 .34668 L
.38204 .34668 L
.38204 .36254 L
s
.38204 .34668 m
.40476 .34668 L
.40476 .34127 L
.38204 .34127 L
.38204 .34668 L
s
.38204 .34127 m
.40476 .34127 L
.40476 .34668 L
.38204 .34668 L
.38204 .34127 L
s
.38204 .34668 m
.40476 .34668 L
.40476 .36254 L
.38204 .36254 L
.38204 .34668 L
s
.38204 .36254 m
.40476 .36254 L
.40476 .38776 L
.38204 .38776 L
.38204 .36254 L
s
.38204 .38776 m
.40476 .38776 L
.40476 .42063 L
.38204 .42063 L
.38204 .38776 L
s
.38204 .42063 m
.40476 .42063 L
.40476 .45892 L
.38204 .45892 L
.38204 .42063 L
s
.38204 .45892 m
.40476 .45892 L
.40476 .5 L
.38204 .5 L
.38204 .45892 L
s
.38204 .5 m
.40476 .5 L
.40476 .54108 L
.38204 .54108 L
.38204 .5 L
s
.38204 .54108 m
.40476 .54108 L
.40476 .57937 L
.38204 .57937 L
.38204 .54108 L
s
.38204 .57937 m
.40476 .57937 L
.40476 .61224 L
.38204 .61224 L
.38204 .57937 L
s
.38204 .61224 m
.40476 .61224 L
.40476 .63746 L
.38204 .63746 L
.38204 .61224 L
s
.38204 .63746 m
.40476 .63746 L
.40476 .65332 L
.38204 .65332 L
.38204 .63746 L
s
.38204 .65332 m
.40476 .65332 L
.40476 .65873 L
.38204 .65873 L
.38204 .65332 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .35714 m
.37387 .35714 L
s
0 0 0 r
2.5 Mabswid
.37387 .35714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .36 m
.37251 .36 L
s
0 0 0 r
2.5 Mabswid
.37251 .36 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .36286 m
.37118 .36286 L
s
0 0 0 r
2.5 Mabswid
.37118 .36286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .36571 m
.36989 .36571 L
s
0 0 0 r
2.5 Mabswid
.36989 .36571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .36857 m
.36863 .36857 L
s
0 0 0 r
2.5 Mabswid
.36863 .36857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .37143 m
.3674 .37143 L
s
0 0 0 r
2.5 Mabswid
.3674 .37143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .37429 m
.36621 .37429 L
s
0 0 0 r
2.5 Mabswid
.36621 .37429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .37714 m
.36504 .37714 L
s
0 0 0 r
2.5 Mabswid
.36504 .37714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .38 m
.36391 .38 L
s
0 0 0 r
2.5 Mabswid
.36391 .38 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .38286 m
.36281 .38286 L
s
0 0 0 r
2.5 Mabswid
.36281 .38286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .38571 m
.36173 .38571 L
s
0 0 0 r
2.5 Mabswid
.36173 .38571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .38857 m
.36069 .38857 L
s
0 0 0 r
2.5 Mabswid
.36069 .38857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .39143 m
.35968 .39143 L
s
0 0 0 r
2.5 Mabswid
.35968 .39143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .39429 m
.3587 .39429 L
s
0 0 0 r
2.5 Mabswid
.3587 .39429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .39714 m
.35774 .39714 L
s
0 0 0 r
2.5 Mabswid
.35774 .39714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .4 m
.35682 .4 L
s
0 0 0 r
2.5 Mabswid
.35682 .4 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .40286 m
.35592 .40286 L
s
0 0 0 r
2.5 Mabswid
.35592 .40286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .40571 m
.35505 .40571 L
s
0 0 0 r
2.5 Mabswid
.35505 .40571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .40857 m
.35421 .40857 L
s
0 0 0 r
2.5 Mabswid
.35421 .40857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .41143 m
.3534 .41143 L
s
0 0 0 r
2.5 Mabswid
.3534 .41143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .41429 m
.35262 .41429 L
s
0 0 0 r
2.5 Mabswid
.35262 .41429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .41714 m
.35186 .41714 L
s
0 0 0 r
2.5 Mabswid
.35186 .41714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .42 m
.35113 .42 L
s
0 0 0 r
2.5 Mabswid
.35113 .42 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .42286 m
.35043 .42286 L
s
0 0 0 r
2.5 Mabswid
.35043 .42286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .42571 m
.34976 .42571 L
s
0 0 0 r
2.5 Mabswid
.34976 .42571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .42857 m
.34911 .42857 L
s
0 0 0 r
2.5 Mabswid
.34911 .42857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .43143 m
.34849 .43143 L
s
0 0 0 r
2.5 Mabswid
.34849 .43143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .43429 m
.34789 .43429 L
s
0 0 0 r
2.5 Mabswid
.34789 .43429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .43714 m
.34732 .43714 L
s
0 0 0 r
2.5 Mabswid
.34732 .43714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .44 m
.34678 .44 L
s
0 0 0 r
2.5 Mabswid
.34678 .44 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .44286 m
.34626 .44286 L
s
0 0 0 r
2.5 Mabswid
.34626 .44286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .44571 m
.34577 .44571 L
s
0 0 0 r
2.5 Mabswid
.34577 .44571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .44857 m
.34531 .44857 L
s
0 0 0 r
2.5 Mabswid
.34531 .44857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .45143 m
.34487 .45143 L
s
0 0 0 r
2.5 Mabswid
.34487 .45143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .45429 m
.34446 .45429 L
s
0 0 0 r
2.5 Mabswid
.34446 .45429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .45714 m
.34407 .45714 L
s
0 0 0 r
2.5 Mabswid
.34407 .45714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .46 m
.34371 .46 L
s
0 0 0 r
2.5 Mabswid
.34371 .46 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .46286 m
.34337 .46286 L
s
0 0 0 r
2.5 Mabswid
.34337 .46286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .46571 m
.34306 .46571 L
s
0 0 0 r
2.5 Mabswid
.34306 .46571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .46857 m
.34277 .46857 L
s
0 0 0 r
2.5 Mabswid
.34277 .46857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .47143 m
.34251 .47143 L
s
0 0 0 r
2.5 Mabswid
.34251 .47143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .47429 m
.34228 .47429 L
s
0 0 0 r
2.5 Mabswid
.34228 .47429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .47714 m
.34206 .47714 L
s
0 0 0 r
2.5 Mabswid
.34206 .47714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .48 m
.34188 .48 L
s
0 0 0 r
2.5 Mabswid
.34188 .48 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .48286 m
.34172 .48286 L
s
0 0 0 r
2.5 Mabswid
.34172 .48286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .48571 m
.34158 .48571 L
s
0 0 0 r
2.5 Mabswid
.34158 .48571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .48857 m
.34147 .48857 L
s
0 0 0 r
2.5 Mabswid
.34147 .48857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .49143 m
.34138 .49143 L
s
0 0 0 r
2.5 Mabswid
.34138 .49143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .49429 m
.34132 .49429 L
s
0 0 0 r
2.5 Mabswid
.34132 .49429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .49714 m
.34128 .49714 L
s
0 0 0 r
2.5 Mabswid
.34128 .49714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.34127 .5 L
s
0 0 0 r
2.5 Mabswid
.34127 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .50286 m
.34128 .50286 L
s
0 0 0 r
2.5 Mabswid
.34128 .50286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .50571 m
.34132 .50571 L
s
0 0 0 r
2.5 Mabswid
.34132 .50571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .50857 m
.34138 .50857 L
s
0 0 0 r
2.5 Mabswid
.34138 .50857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .51143 m
.34147 .51143 L
s
0 0 0 r
2.5 Mabswid
.34147 .51143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .51429 m
.34158 .51429 L
s
0 0 0 r
2.5 Mabswid
.34158 .51429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .51714 m
.34172 .51714 L
s
0 0 0 r
2.5 Mabswid
.34172 .51714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .52 m
.34188 .52 L
s
0 0 0 r
2.5 Mabswid
.34188 .52 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .52286 m
.34206 .52286 L
s
0 0 0 r
2.5 Mabswid
.34206 .52286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .52571 m
.34228 .52571 L
s
0 0 0 r
2.5 Mabswid
.34228 .52571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .52857 m
.34251 .52857 L
s
0 0 0 r
2.5 Mabswid
.34251 .52857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .53143 m
.34277 .53143 L
s
0 0 0 r
2.5 Mabswid
.34277 .53143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .53429 m
.34306 .53429 L
s
0 0 0 r
2.5 Mabswid
.34306 .53429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .53714 m
.34337 .53714 L
s
0 0 0 r
2.5 Mabswid
.34337 .53714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .54 m
.34371 .54 L
s
0 0 0 r
2.5 Mabswid
.34371 .54 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .54286 m
.34407 .54286 L
s
0 0 0 r
2.5 Mabswid
.34407 .54286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .54571 m
.34446 .54571 L
s
0 0 0 r
2.5 Mabswid
.34446 .54571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .54857 m
.34487 .54857 L
s
0 0 0 r
2.5 Mabswid
.34487 .54857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .55143 m
.34531 .55143 L
s
0 0 0 r
2.5 Mabswid
.34531 .55143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .55429 m
.34577 .55429 L
s
0 0 0 r
2.5 Mabswid
.34577 .55429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .55714 m
.34626 .55714 L
s
0 0 0 r
2.5 Mabswid
.34626 .55714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .56 m
.34678 .56 L
s
0 0 0 r
2.5 Mabswid
.34678 .56 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .56286 m
.34732 .56286 L
s
0 0 0 r
2.5 Mabswid
.34732 .56286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .56571 m
.34789 .56571 L
s
0 0 0 r
2.5 Mabswid
.34789 .56571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .56857 m
.34849 .56857 L
s
0 0 0 r
2.5 Mabswid
.34849 .56857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .57143 m
.34911 .57143 L
s
0 0 0 r
2.5 Mabswid
.34911 .57143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .57429 m
.34976 .57429 L
s
0 0 0 r
2.5 Mabswid
.34976 .57429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .57714 m
.35043 .57714 L
s
0 0 0 r
2.5 Mabswid
.35043 .57714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .58 m
.35113 .58 L
s
0 0 0 r
2.5 Mabswid
.35113 .58 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .58286 m
.35186 .58286 L
s
0 0 0 r
2.5 Mabswid
.35186 .58286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .58571 m
.35262 .58571 L
s
0 0 0 r
2.5 Mabswid
.35262 .58571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .58857 m
.3534 .58857 L
s
0 0 0 r
2.5 Mabswid
.3534 .58857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .59143 m
.35421 .59143 L
s
0 0 0 r
2.5 Mabswid
.35421 .59143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .59429 m
.35505 .59429 L
s
0 0 0 r
2.5 Mabswid
.35505 .59429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .59714 m
.35592 .59714 L
s
0 0 0 r
2.5 Mabswid
.35592 .59714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .6 m
.35682 .6 L
s
0 0 0 r
2.5 Mabswid
.35682 .6 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .60286 m
.35774 .60286 L
s
0 0 0 r
2.5 Mabswid
.35774 .60286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .60571 m
.3587 .60571 L
s
0 0 0 r
2.5 Mabswid
.3587 .60571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .60857 m
.35968 .60857 L
s
0 0 0 r
2.5 Mabswid
.35968 .60857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .61143 m
.36069 .61143 L
s
0 0 0 r
2.5 Mabswid
.36069 .61143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .61429 m
.36173 .61429 L
s
0 0 0 r
2.5 Mabswid
.36173 .61429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .61714 m
.36281 .61714 L
s
0 0 0 r
2.5 Mabswid
.36281 .61714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .62 m
.36391 .62 L
s
0 0 0 r
2.5 Mabswid
.36391 .62 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .62286 m
.36504 .62286 L
s
0 0 0 r
2.5 Mabswid
.36504 .62286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .62571 m
.36621 .62571 L
s
0 0 0 r
2.5 Mabswid
.36621 .62571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .62857 m
.3674 .62857 L
s
0 0 0 r
2.5 Mabswid
.3674 .62857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .63143 m
.36863 .63143 L
s
0 0 0 r
2.5 Mabswid
.36863 .63143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .63429 m
.36989 .63429 L
s
0 0 0 r
2.5 Mabswid
.36989 .63429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .63714 m
.37118 .63714 L
s
0 0 0 r
2.5 Mabswid
.37118 .63714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .64 m
.37251 .64 L
s
0 0 0 r
2.5 Mabswid
.37251 .64 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .64286 m
.37387 .64286 L
s
0 0 0 r
2.5 Mabswid
.37387 .64286 Mdot
.039 .916 .04 r
.5 Mabswid
.37387 .35714 m
.40476 .36247 L
s
0 0 0 r
2.5 Mabswid
.40476 .36247 Mdot
.039 .916 .04 r
.5 Mabswid
.37251 .36 m
.40476 .36536 L
s
0 0 0 r
2.5 Mabswid
.40476 .36536 Mdot
.039 .916 .04 r
.5 Mabswid
.37118 .36286 m
.40476 .36806 L
s
0 0 0 r
2.5 Mabswid
.40476 .36806 Mdot
.039 .916 .04 r
.5 Mabswid
.36989 .36571 m
.40476 .37095 L
s
0 0 0 r
2.5 Mabswid
.40476 .37095 Mdot
.039 .916 .04 r
.5 Mabswid
.36863 .36857 m
.40476 .3743 L
s
0 0 0 r
2.5 Mabswid
.40476 .3743 Mdot
.039 .916 .04 r
.5 Mabswid
.3674 .37143 m
.40476 .37706 L
s
0 0 0 r
2.5 Mabswid
.40476 .37706 Mdot
.039 .916 .04 r
.5 Mabswid
.36621 .37429 m
.40476 .37982 L
s
0 0 0 r
2.5 Mabswid
.40476 .37982 Mdot
.039 .916 .04 r
.5 Mabswid
.36504 .37714 m
.40476 .38204 L
s
0 0 0 r
2.5 Mabswid
.40476 .38204 Mdot
.039 .916 .04 r
.5 Mabswid
.36391 .38 m
.40476 .385 L
s
0 0 0 r
2.5 Mabswid
.40476 .385 Mdot
.039 .916 .04 r
.5 Mabswid
.36281 .38286 m
.40476 .388 L
s
0 0 0 r
2.5 Mabswid
.40476 .388 Mdot
.039 .916 .04 r
.5 Mabswid
.36173 .38571 m
.40476 .39125 L
s
0 0 0 r
2.5 Mabswid
.40476 .39125 Mdot
.039 .916 .04 r
.5 Mabswid
.36069 .38857 m
.40476 .39423 L
s
0 0 0 r
2.5 Mabswid
.40476 .39423 Mdot
.039 .916 .04 r
.5 Mabswid
.35968 .39143 m
.40476 .39633 L
s
0 0 0 r
2.5 Mabswid
.40476 .39633 Mdot
.039 .916 .04 r
.5 Mabswid
.3587 .39429 m
.40476 .39978 L
s
0 0 0 r
2.5 Mabswid
.40476 .39978 Mdot
.039 .916 .04 r
.5 Mabswid
.35774 .39714 m
.40476 .40199 L
s
0 0 0 r
2.5 Mabswid
.40476 .40199 Mdot
.039 .916 .04 r
.5 Mabswid
.35682 .4 m
.40476 .40487 L
s
0 0 0 r
2.5 Mabswid
.40476 .40487 Mdot
.039 .916 .04 r
.5 Mabswid
.35592 .40286 m
.40476 .40742 L
s
0 0 0 r
2.5 Mabswid
.40476 .40742 Mdot
.039 .916 .04 r
.5 Mabswid
.35505 .40571 m
.40476 .41111 L
s
0 0 0 r
2.5 Mabswid
.40476 .41111 Mdot
.039 .916 .04 r
.5 Mabswid
.35421 .40857 m
.40476 .41329 L
s
0 0 0 r
2.5 Mabswid
.40476 .41329 Mdot
.039 .916 .04 r
.5 Mabswid
.3534 .41143 m
.40476 .41632 L
s
0 0 0 r
2.5 Mabswid
.40476 .41632 Mdot
.039 .916 .04 r
.5 Mabswid
.35262 .41429 m
.40476 .41958 L
s
0 0 0 r
2.5 Mabswid
.40476 .41958 Mdot
.039 .916 .04 r
.5 Mabswid
.35186 .41714 m
.40476 .42119 L
s
0 0 0 r
2.5 Mabswid
.40476 .42119 Mdot
.039 .916 .04 r
.5 Mabswid
.35113 .42 m
.40476 .42395 L
s
0 0 0 r
2.5 Mabswid
.40476 .42395 Mdot
.039 .916 .04 r
.5 Mabswid
.35043 .42286 m
.40476 .42722 L
s
0 0 0 r
2.5 Mabswid
.40476 .42722 Mdot
.039 .916 .04 r
.5 Mabswid
.34976 .42571 m
.40476 .43068 L
s
0 0 0 r
2.5 Mabswid
.40476 .43068 Mdot
.039 .916 .04 r
.5 Mabswid
.34911 .42857 m
.40476 .43235 L
s
0 0 0 r
2.5 Mabswid
.40476 .43235 Mdot
.039 .916 .04 r
.5 Mabswid
.34849 .43143 m
.40476 .43546 L
s
0 0 0 r
2.5 Mabswid
.40476 .43546 Mdot
.039 .916 .04 r
.5 Mabswid
.34789 .43429 m
.40476 .43881 L
s
0 0 0 r
2.5 Mabswid
.40476 .43881 Mdot
.039 .916 .04 r
.5 Mabswid
.34732 .43714 m
.40476 .44165 L
s
0 0 0 r
2.5 Mabswid
.40476 .44165 Mdot
.039 .916 .04 r
.5 Mabswid
.34678 .44 m
.40476 .44347 L
s
0 0 0 r
2.5 Mabswid
.40476 .44347 Mdot
.039 .916 .04 r
.5 Mabswid
.34626 .44286 m
.40476 .44678 L
s
0 0 0 r
2.5 Mabswid
.40476 .44678 Mdot
.039 .916 .04 r
.5 Mabswid
.34577 .44571 m
.40476 .44961 L
s
0 0 0 r
2.5 Mabswid
.40476 .44961 Mdot
.039 .916 .04 r
.5 Mabswid
.34531 .44857 m
.40476 .45227 L
s
0 0 0 r
2.5 Mabswid
.40476 .45227 Mdot
.039 .916 .04 r
.5 Mabswid
.34487 .45143 m
.40476 .45387 L
s
0 0 0 r
2.5 Mabswid
.40476 .45387 Mdot
.039 .916 .04 r
.5 Mabswid
.34446 .45429 m
.40476 .45663 L
s
0 0 0 r
2.5 Mabswid
.40476 .45663 Mdot
.039 .916 .04 r
.5 Mabswid
.34407 .45714 m
.40476 .45927 L
s
0 0 0 r
2.5 Mabswid
.40476 .45927 Mdot
.039 .916 .04 r
.5 Mabswid
.34371 .46 m
.40476 .46285 L
s
0 0 0 r
2.5 Mabswid
.40476 .46285 Mdot
.039 .916 .04 r
.5 Mabswid
.34337 .46286 m
.40476 .46508 L
s
0 0 0 r
2.5 Mabswid
.40476 .46508 Mdot
.039 .916 .04 r
.5 Mabswid
.34306 .46571 m
.40476 .46858 L
s
0 0 0 r
2.5 Mabswid
.40476 .46858 Mdot
.039 .916 .04 r
.5 Mabswid
.34277 .46857 m
.40476 .47111 L
s
0 0 0 r
2.5 Mabswid
.40476 .47111 Mdot
.039 .916 .04 r
.5 Mabswid
.34251 .47143 m
.40476 .47349 L
s
0 0 0 r
2.5 Mabswid
.40476 .47349 Mdot
.039 .916 .04 r
.5 Mabswid
.34228 .47429 m
.40476 .47611 L
s
0 0 0 r
2.5 Mabswid
.40476 .47611 Mdot
.039 .916 .04 r
.5 Mabswid
.34206 .47714 m
.40476 .47882 L
s
0 0 0 r
2.5 Mabswid
.40476 .47882 Mdot
.039 .916 .04 r
.5 Mabswid
.34188 .48 m
.40476 .48103 L
s
0 0 0 r
2.5 Mabswid
.40476 .48103 Mdot
.039 .916 .04 r
.5 Mabswid
.34172 .48286 m
.40476 .48434 L
s
0 0 0 r
2.5 Mabswid
.40476 .48434 Mdot
.039 .916 .04 r
.5 Mabswid
.34158 .48571 m
.40476 .48676 L
s
0 0 0 r
2.5 Mabswid
.40476 .48676 Mdot
.039 .916 .04 r
.5 Mabswid
.34147 .48857 m
.40476 .48946 L
s
0 0 0 r
2.5 Mabswid
.40476 .48946 Mdot
.039 .916 .04 r
.5 Mabswid
.34138 .49143 m
.40476 .49256 L
s
0 0 0 r
2.5 Mabswid
.40476 .49256 Mdot
.039 .916 .04 r
.5 Mabswid
.34132 .49429 m
.40476 .49506 L
s
0 0 0 r
2.5 Mabswid
.40476 .49506 Mdot
.039 .916 .04 r
.5 Mabswid
.34128 .49714 m
.40476 .49715 L
s
0 0 0 r
2.5 Mabswid
.40476 .49715 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .5 m
.40476 .49942 L
s
0 0 0 r
2.5 Mabswid
.40476 .49942 Mdot
.039 .916 .04 r
.5 Mabswid
.34128 .50286 m
.40476 .50336 L
s
0 0 0 r
2.5 Mabswid
.40476 .50336 Mdot
.039 .916 .04 r
.5 Mabswid
.34132 .50571 m
.40476 .50575 L
s
0 0 0 r
2.5 Mabswid
.40476 .50575 Mdot
.039 .916 .04 r
.5 Mabswid
.34138 .50857 m
.40476 .50727 L
s
0 0 0 r
2.5 Mabswid
.40476 .50727 Mdot
.039 .916 .04 r
.5 Mabswid
.34147 .51143 m
.40476 .51042 L
s
0 0 0 r
2.5 Mabswid
.40476 .51042 Mdot
.039 .916 .04 r
.5 Mabswid
.34158 .51429 m
.40476 .51272 L
s
0 0 0 r
2.5 Mabswid
.40476 .51272 Mdot
.039 .916 .04 r
.5 Mabswid
.34172 .51714 m
.40476 .51666 L
s
0 0 0 r
2.5 Mabswid
.40476 .51666 Mdot
.039 .916 .04 r
.5 Mabswid
.34188 .52 m
.40476 .51934 L
s
0 0 0 r
2.5 Mabswid
.40476 .51934 Mdot
.039 .916 .04 r
.5 Mabswid
.34206 .52286 m
.40476 .52091 L
s
0 0 0 r
2.5 Mabswid
.40476 .52091 Mdot
.039 .916 .04 r
.5 Mabswid
.34228 .52571 m
.40476 .52477 L
s
0 0 0 r
2.5 Mabswid
.40476 .52477 Mdot
.039 .916 .04 r
.5 Mabswid
.34251 .52857 m
.40476 .52631 L
s
0 0 0 r
2.5 Mabswid
.40476 .52631 Mdot
.039 .916 .04 r
.5 Mabswid
.34277 .53143 m
.40476 .52945 L
s
0 0 0 r
2.5 Mabswid
.40476 .52945 Mdot
.039 .916 .04 r
.5 Mabswid
.34306 .53429 m
.40476 .53171 L
s
0 0 0 r
2.5 Mabswid
.40476 .53171 Mdot
.039 .916 .04 r
.5 Mabswid
.34337 .53714 m
.40476 .53424 L
s
0 0 0 r
2.5 Mabswid
.40476 .53424 Mdot
.039 .916 .04 r
.5 Mabswid
.34371 .54 m
.40476 .53758 L
s
0 0 0 r
2.5 Mabswid
.40476 .53758 Mdot
.039 .916 .04 r
.5 Mabswid
.34407 .54286 m
.40476 .54078 L
s
0 0 0 r
2.5 Mabswid
.40476 .54078 Mdot
.039 .916 .04 r
.5 Mabswid
.34446 .54571 m
.40476 .54302 L
s
0 0 0 r
2.5 Mabswid
.40476 .54302 Mdot
.039 .916 .04 r
.5 Mabswid
.34487 .54857 m
.40476 .546 L
s
0 0 0 r
2.5 Mabswid
.40476 .546 Mdot
.039 .916 .04 r
.5 Mabswid
.34531 .55143 m
.40476 .54873 L
s
0 0 0 r
2.5 Mabswid
.40476 .54873 Mdot
.039 .916 .04 r
.5 Mabswid
.34577 .55429 m
.40476 .55073 L
s
0 0 0 r
2.5 Mabswid
.40476 .55073 Mdot
.039 .916 .04 r
.5 Mabswid
.34626 .55714 m
.40476 .55297 L
s
0 0 0 r
2.5 Mabswid
.40476 .55297 Mdot
.039 .916 .04 r
.5 Mabswid
.34678 .56 m
.40476 .55698 L
s
0 0 0 r
2.5 Mabswid
.40476 .55698 Mdot
.039 .916 .04 r
.5 Mabswid
.34732 .56286 m
.40476 .55847 L
s
0 0 0 r
2.5 Mabswid
.40476 .55847 Mdot
.039 .916 .04 r
.5 Mabswid
.34789 .56571 m
.40476 .56244 L
s
0 0 0 r
2.5 Mabswid
.40476 .56244 Mdot
.039 .916 .04 r
.5 Mabswid
.34849 .56857 m
.40476 .56508 L
s
0 0 0 r
2.5 Mabswid
.40476 .56508 Mdot
.039 .916 .04 r
.5 Mabswid
.34911 .57143 m
.40476 .56791 L
s
0 0 0 r
2.5 Mabswid
.40476 .56791 Mdot
.039 .916 .04 r
.5 Mabswid
.34976 .57429 m
.40476 .56971 L
s
0 0 0 r
2.5 Mabswid
.40476 .56971 Mdot
.039 .916 .04 r
.5 Mabswid
.35043 .57714 m
.40476 .57332 L
s
0 0 0 r
2.5 Mabswid
.40476 .57332 Mdot
.039 .916 .04 r
.5 Mabswid
.35113 .58 m
.40476 .57556 L
s
0 0 0 r
2.5 Mabswid
.40476 .57556 Mdot
.039 .916 .04 r
.5 Mabswid
.35186 .58286 m
.40476 .57874 L
s
0 0 0 r
2.5 Mabswid
.40476 .57874 Mdot
.039 .916 .04 r
.5 Mabswid
.35262 .58571 m
.40476 .5808 L
s
0 0 0 r
2.5 Mabswid
.40476 .5808 Mdot
.039 .916 .04 r
.5 Mabswid
.3534 .58857 m
.40476 .58311 L
s
0 0 0 r
2.5 Mabswid
.40476 .58311 Mdot
.039 .916 .04 r
.5 Mabswid
.35421 .59143 m
.40476 .58634 L
s
0 0 0 r
2.5 Mabswid
.40476 .58634 Mdot
.039 .916 .04 r
.5 Mabswid
.35505 .59429 m
.40476 .58979 L
s
0 0 0 r
2.5 Mabswid
.40476 .58979 Mdot
.039 .916 .04 r
.5 Mabswid
.35592 .59714 m
.40476 .59163 L
s
0 0 0 r
2.5 Mabswid
.40476 .59163 Mdot
.039 .916 .04 r
.5 Mabswid
.35682 .6 m
.40476 .59483 L
s
0 0 0 r
2.5 Mabswid
.40476 .59483 Mdot
.039 .916 .04 r
.5 Mabswid
.35774 .60286 m
.40476 .5972 L
s
0 0 0 r
2.5 Mabswid
.40476 .5972 Mdot
.039 .916 .04 r
.5 Mabswid
.3587 .60571 m
.40476 .60078 L
s
0 0 0 r
2.5 Mabswid
.40476 .60078 Mdot
.039 .916 .04 r
.5 Mabswid
.35968 .60857 m
.40476 .60335 L
s
0 0 0 r
2.5 Mabswid
.40476 .60335 Mdot
.039 .916 .04 r
.5 Mabswid
.36069 .61143 m
.40476 .60616 L
s
0 0 0 r
2.5 Mabswid
.40476 .60616 Mdot
.039 .916 .04 r
.5 Mabswid
.36173 .61429 m
.40476 .60894 L
s
0 0 0 r
2.5 Mabswid
.40476 .60894 Mdot
.039 .916 .04 r
.5 Mabswid
.36281 .61714 m
.40476 .61227 L
s
0 0 0 r
2.5 Mabswid
.40476 .61227 Mdot
.039 .916 .04 r
.5 Mabswid
.36391 .62 m
.40476 .61487 L
s
0 0 0 r
2.5 Mabswid
.40476 .61487 Mdot
.039 .916 .04 r
.5 Mabswid
.36504 .62286 m
.40476 .61717 L
s
0 0 0 r
2.5 Mabswid
.40476 .61717 Mdot
.039 .916 .04 r
.5 Mabswid
.36621 .62571 m
.40476 .62034 L
s
0 0 0 r
2.5 Mabswid
.40476 .62034 Mdot
.039 .916 .04 r
.5 Mabswid
.3674 .62857 m
.40476 .62276 L
s
0 0 0 r
2.5 Mabswid
.40476 .62276 Mdot
.039 .916 .04 r
.5 Mabswid
.36863 .63143 m
.40476 .6263 L
s
0 0 0 r
2.5 Mabswid
.40476 .6263 Mdot
.039 .916 .04 r
.5 Mabswid
.36989 .63429 m
.40476 .62881 L
s
0 0 0 r
2.5 Mabswid
.40476 .62881 Mdot
.039 .916 .04 r
.5 Mabswid
.37118 .63714 m
.40476 .63205 L
s
0 0 0 r
2.5 Mabswid
.40476 .63205 Mdot
.039 .916 .04 r
.5 Mabswid
.37251 .64 m
.40476 .6345 L
s
0 0 0 r
2.5 Mabswid
.40476 .6345 Mdot
.039 .916 .04 r
.5 Mabswid
.37387 .64286 m
.40476 .63775 L
s
0 0 0 r
2.5 Mabswid
.40476 .63775 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .36247 m
.97619 .52122 L
s
0 0 0 r
2.5 Mabswid
.97619 .52122 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .36536 m
.97619 .50163 L
s
0 0 0 r
2.5 Mabswid
.97619 .50163 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .36806 m
.97619 .51437 L
s
0 0 0 r
2.5 Mabswid
.97619 .51437 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .37095 m
.97619 .49325 L
s
0 0 0 r
2.5 Mabswid
.97619 .49325 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .3743 m
.97619 .52104 L
s
0 0 0 r
2.5 Mabswid
.97619 .52104 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .37706 m
.97619 .50833 L
s
0 0 0 r
2.5 Mabswid
.97619 .50833 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .37982 m
.97619 .5139 L
s
0 0 0 r
2.5 Mabswid
.97619 .5139 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .38204 m
.97619 .484 L
s
0 0 0 r
2.5 Mabswid
.97619 .484 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .385 m
.97619 .48777 L
s
0 0 0 r
2.5 Mabswid
.97619 .48777 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .388 m
.97619 .49701 L
s
0 0 0 r
2.5 Mabswid
.97619 .49701 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .39125 m
.97619 .50708 L
s
0 0 0 r
2.5 Mabswid
.97619 .50708 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .39423 m
.97619 .51373 L
s
0 0 0 r
2.5 Mabswid
.97619 .51373 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .39633 m
.97619 .4991 L
s
0 0 0 r
2.5 Mabswid
.97619 .4991 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .39978 m
.97619 .49509 L
s
0 0 0 r
2.5 Mabswid
.97619 .49509 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .40199 m
.97619 .49402 L
s
0 0 0 r
2.5 Mabswid
.97619 .49402 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .40487 m
.97619 .49429 L
s
0 0 0 r
2.5 Mabswid
.97619 .49429 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .40742 m
.97619 .47929 L
s
0 0 0 r
2.5 Mabswid
.97619 .47929 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .41111 m
.97619 .50734 L
s
0 0 0 r
2.5 Mabswid
.97619 .50734 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .41329 m
.97619 .49672 L
s
0 0 0 r
2.5 Mabswid
.97619 .49672 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .41632 m
.97619 .4927 L
s
0 0 0 r
2.5 Mabswid
.97619 .4927 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .41958 m
.97619 .50318 L
s
0 0 0 r
2.5 Mabswid
.97619 .50318 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .42119 m
.97619 .47953 L
s
0 0 0 r
2.5 Mabswid
.97619 .47953 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .42395 m
.97619 .49014 L
s
0 0 0 r
2.5 Mabswid
.97619 .49014 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .42722 m
.97619 .49752 L
s
0 0 0 r
2.5 Mabswid
.97619 .49752 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .43068 m
.97619 .50971 L
s
0 0 0 r
2.5 Mabswid
.97619 .50971 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .43235 m
.97619 .48235 L
s
0 0 0 r
2.5 Mabswid
.97619 .48235 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .43546 m
.97619 .50178 L
s
0 0 0 r
2.5 Mabswid
.97619 .50178 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .43881 m
.97619 .50714 L
s
0 0 0 r
2.5 Mabswid
.97619 .50714 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .44165 m
.97619 .5146 L
s
0 0 0 r
2.5 Mabswid
.97619 .5146 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .44347 m
.97619 .49845 L
s
0 0 0 r
2.5 Mabswid
.97619 .49845 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .44678 m
.97619 .51236 L
s
0 0 0 r
2.5 Mabswid
.97619 .51236 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .44961 m
.97619 .50137 L
s
0 0 0 r
2.5 Mabswid
.97619 .50137 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .45227 m
.97619 .50496 L
s
0 0 0 r
2.5 Mabswid
.97619 .50496 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .45387 m
.97619 .48022 L
s
0 0 0 r
2.5 Mabswid
.97619 .48022 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .45663 m
.97619 .48442 L
s
0 0 0 r
2.5 Mabswid
.97619 .48442 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .45927 m
.97619 .48811 L
s
0 0 0 r
2.5 Mabswid
.97619 .48811 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .46285 m
.97619 .50499 L
s
0 0 0 r
2.5 Mabswid
.97619 .50499 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .46508 m
.97619 .50671 L
s
0 0 0 r
2.5 Mabswid
.97619 .50671 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .46858 m
.97619 .51156 L
s
0 0 0 r
2.5 Mabswid
.97619 .51156 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .47111 m
.97619 .5149 L
s
0 0 0 r
2.5 Mabswid
.97619 .5149 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .47349 m
.97619 .50288 L
s
0 0 0 r
2.5 Mabswid
.97619 .50288 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .47611 m
.97619 .5 L
s
0 0 0 r
2.5 Mabswid
.97619 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .47882 m
.97619 .49242 L
s
0 0 0 r
2.5 Mabswid
.97619 .49242 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .48103 m
.97619 .49963 L
s
0 0 0 r
2.5 Mabswid
.97619 .49963 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .48434 m
.97619 .49995 L
s
0 0 0 r
2.5 Mabswid
.97619 .49995 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .48676 m
.97619 .49754 L
s
0 0 0 r
2.5 Mabswid
.97619 .49754 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .48946 m
.97619 .50027 L
s
0 0 0 r
2.5 Mabswid
.97619 .50027 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .49256 m
.97619 .50186 L
s
0 0 0 r
2.5 Mabswid
.97619 .50186 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .49506 m
.97619 .51119 L
s
0 0 0 r
2.5 Mabswid
.97619 .51119 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .49715 m
.97619 .49235 L
s
0 0 0 r
2.5 Mabswid
.97619 .49235 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .49942 m
.97619 .49677 L
s
0 0 0 r
2.5 Mabswid
.97619 .49677 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .50336 m
.97619 .51545 L
s
0 0 0 r
2.5 Mabswid
.97619 .51545 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .50575 m
.97619 .49678 L
s
0 0 0 r
2.5 Mabswid
.97619 .49678 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .50727 m
.97619 .49207 L
s
0 0 0 r
2.5 Mabswid
.97619 .49207 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .51042 m
.97619 .5052 L
s
0 0 0 r
2.5 Mabswid
.97619 .5052 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .51272 m
.97619 .49167 L
s
0 0 0 r
2.5 Mabswid
.97619 .49167 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .51666 m
.97619 .51248 L
s
0 0 0 r
2.5 Mabswid
.97619 .51248 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .51934 m
.97619 .51154 L
s
0 0 0 r
2.5 Mabswid
.97619 .51154 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .52091 m
.97619 .49825 L
s
0 0 0 r
2.5 Mabswid
.97619 .49825 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .52477 m
.97619 .50339 L
s
0 0 0 r
2.5 Mabswid
.97619 .50339 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .52631 m
.97619 .48511 L
s
0 0 0 r
2.5 Mabswid
.97619 .48511 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .52945 m
.97619 .50338 L
s
0 0 0 r
2.5 Mabswid
.97619 .50338 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .53171 m
.97619 .48674 L
s
0 0 0 r
2.5 Mabswid
.97619 .48674 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .53424 m
.97619 .48705 L
s
0 0 0 r
2.5 Mabswid
.97619 .48705 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .53758 m
.97619 .50328 L
s
0 0 0 r
2.5 Mabswid
.97619 .50328 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .54078 m
.97619 .50361 L
s
0 0 0 r
2.5 Mabswid
.97619 .50361 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .54302 m
.97619 .49465 L
s
0 0 0 r
2.5 Mabswid
.97619 .49465 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .546 m
.97619 .50874 L
s
0 0 0 r
2.5 Mabswid
.97619 .50874 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .54873 m
.97619 .50377 L
s
0 0 0 r
2.5 Mabswid
.97619 .50377 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .55073 m
.97619 .505 L
s
0 0 0 r
2.5 Mabswid
.97619 .505 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .55297 m
.97619 .49325 L
s
0 0 0 r
2.5 Mabswid
.97619 .49325 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .55698 m
.97619 .50752 L
s
0 0 0 r
2.5 Mabswid
.97619 .50752 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .55847 m
.97619 .49136 L
s
0 0 0 r
2.5 Mabswid
.97619 .49136 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .56244 m
.97619 .51362 L
s
0 0 0 r
2.5 Mabswid
.97619 .51362 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .56508 m
.97619 .51855 L
s
0 0 0 r
2.5 Mabswid
.97619 .51855 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .56791 m
.97619 .51382 L
s
0 0 0 r
2.5 Mabswid
.97619 .51382 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .56971 m
.97619 .49556 L
s
0 0 0 r
2.5 Mabswid
.97619 .49556 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .57332 m
.97619 .52119 L
s
0 0 0 r
2.5 Mabswid
.97619 .52119 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .57556 m
.97619 .51278 L
s
0 0 0 r
2.5 Mabswid
.97619 .51278 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .57874 m
.97619 .50064 L
s
0 0 0 r
2.5 Mabswid
.97619 .50064 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .5808 m
.97619 .50519 L
s
0 0 0 r
2.5 Mabswid
.97619 .50519 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .58311 m
.97619 .48727 L
s
0 0 0 r
2.5 Mabswid
.97619 .48727 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .58634 m
.97619 .49272 L
s
0 0 0 r
2.5 Mabswid
.97619 .49272 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .58979 m
.97619 .51989 L
s
0 0 0 r
2.5 Mabswid
.97619 .51989 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .59163 m
.97619 .49856 L
s
0 0 0 r
2.5 Mabswid
.97619 .49856 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .59483 m
.97619 .50691 L
s
0 0 0 r
2.5 Mabswid
.97619 .50691 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .5972 m
.97619 .48406 L
s
0 0 0 r
2.5 Mabswid
.97619 .48406 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .60078 m
.97619 .51157 L
s
0 0 0 r
2.5 Mabswid
.97619 .51157 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .60335 m
.97619 .49663 L
s
0 0 0 r
2.5 Mabswid
.97619 .49663 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .60616 m
.97619 .50459 L
s
0 0 0 r
2.5 Mabswid
.97619 .50459 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .60894 m
.97619 .4911 L
s
0 0 0 r
2.5 Mabswid
.97619 .4911 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .61227 m
.97619 .50395 L
s
0 0 0 r
2.5 Mabswid
.97619 .50395 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .61487 m
.97619 .49392 L
s
0 0 0 r
2.5 Mabswid
.97619 .49392 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .61717 m
.97619 .49862 L
s
0 0 0 r
2.5 Mabswid
.97619 .49862 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .62034 m
.97619 .49767 L
s
0 0 0 r
2.5 Mabswid
.97619 .49767 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .62276 m
.97619 .49476 L
s
0 0 0 r
2.5 Mabswid
.97619 .49476 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .6263 m
.97619 .50242 L
s
0 0 0 r
2.5 Mabswid
.97619 .50242 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .62881 m
.97619 .48483 L
s
0 0 0 r
2.5 Mabswid
.97619 .48483 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .63205 m
.97619 .50139 L
s
0 0 0 r
2.5 Mabswid
.97619 .50139 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .6345 m
.97619 .48029 L
s
0 0 0 r
2.5 Mabswid
.97619 .48029 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .63775 m
.97619 .48262 L
s
0 0 0 r
2.5 Mabswid
.97619 .48262 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
I03oool800000:<0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0I03o
ool00`000000Ogmo07moO`0407moO`030000003oool0oooo0:40oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0H`3oool900000:<0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0H`3oool2000000H0Ogmo00<000000?ooo`3oool0X@3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1R0?ooo`030000001oOgl0000000H0
Ogmo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`050?ooo`001P3ooomT00WZ2P040000
0009jPX02NX:00WZ2PH0Ogmo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`050?ooo`00
1P3ooomS00WZ2P0300000009jPX02NX:00L02NX:0P00002S0?ooo`030000003oool0oooo00D0oooo
00060?ooof<02NX:00<0000000WZ2P09jPX01`09jPX0100000002NX:00WZ2P09jPZQ0?ooo`030000
003oool0oooo00D0oooo00060?ooofL02NX:00<0000000WZ2P09jPX00`09jPX00`0000002NX:00WZ
2P0500WZ2Yd0oooo00<000000?ooo`3oool01@3oool000H0ooooHP09jPX00`0000002NX:00WZ2P07
00WZ2P0307moO`0000002NX:00/02NX:V03oool00`000000oooo0?ooo`050?ooo`001P3ooomR00WZ
2P0300000009jPX02NX:00P02NX:00<0000000WZ2P09jPX03P09jPZD0?ooo`030000003oool0oooo
00D0oooo00060?ooof402NX:00<0000000WZ2P09jPX02@09jPX00`0000002NX:00WZ2P0500WZ2P03
0?ooo`09jPX02NX:00X02NX:T03oool00`000000oooo0?ooo`050?ooo`001P3ooomQ00WZ2P030000
0009jPX02NX:00T02NX:00<0000000WZ2P09jPX02@09jPX20?ooo`/02NX:S03oool00`000000oooo
0?ooo`050?ooo`001P3ooomU00WZ2P0307moO`09jPX02NX:00D02NX:00<0000000WZ2P09jPX03@09
jPX20?ooo`/02NX:R03oool00`000000oooo0?ooo`050?ooo`001P3ooomP00WZ2P0300000009jPX0
2NX:00X02NX:00<0000000WZ2P09jPX04@09jPX30?ooo`/02NX:P`3oool00`000000oooo0?ooo`05
0?ooo`001P3ooomP00WZ2P0300000009jPX02NX:00X02NX:00D0000000WZ2P09jPX02NX:0?ooo`0B
00WZ2P@0oooo1P09jPX00`3oool02NX:00WZ2P0200WZ2Wl0oooo00<000000?ooo`3oool01@3oool0
00H0ooooG`09jPX00`0000002NX:00WZ2P0600WZ2P0307moO`09jPX02NX:00802NX:00<0000000WZ
2P09jPX01P09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00T02NX:103oool600WZ
2P030?ooo`09jPX02NX:00802NX:N`3oool00`000000oooo0?ooo`050?ooo`001P3ooomO00WZ2P03
00000009jPX02NX:00/02NX:00<0000000WZ2P09jPX02`09jPX00`3oool02NX:00WZ2P0@00WZ2P80
oooo2`09jPYg0?ooo`030000003oool0oooo00D0oooo00060?oooel02NX:00<0000000WZ2P09jPX0
2`09jPX00`0000002NX:00WZ2P0@00WZ2P80oooo7@09jPYc0?ooo`030000003oool0oooo00D0oooo
00060?ooofd02NX:00<0000000WZ2P09jPX05@09jPX20?oooad02NX:KP3oool00`000000oooo0?oo
o`050?ooo`001P3ooomN00WZ2P0300000009jPX02NX:00`02NX:00<0000000WZ2P09jPX06P09jPX2
0?oooa`02NX:JP3oool00`000000oooo0?ooo`050?ooo`001P3ooomN00WZ2P0300000009jPX02NX:
00`02NX:00<0000000WZ2P09jPX02009jPX00`3oool02NX:00WZ2P0D00WZ2P80oooo6`09jPYV0?oo
o`030000003oool0oooo00D0oooo00060?ooofd02NX:00<0000000WZ2P09jPX03P09jPX00`3oool0
2NX:00WZ2P0C00WZ2P<0oooo6@09jPYR0?ooo`030000003oool0oooo00D0oooo00060?ooofd02NX:
00<0000000WZ2P09jPX05009jPX20?oooa<02NX:0`3ooolH00WZ2Uh0oooo00<000000?ooo`3oool0
1@3oool000H0ooooG@09jPX00`0000002NX:00WZ2P0=00WZ2P0300000009jPX02NX:01T02NX:103o
oolA00WZ2P<0oooo6009jPYI0?ooo`030000003oool0oooo00D0oooo00060?oooed02NX:00<00000
00WZ2P09jPX03@09jPX00`0000002NX:00WZ2P0O00WZ2P@0oooo4009jPX20?oooaP02NX:E@3oool0
0`000000oooo0?ooo`050?ooo`001P3ooomM00WZ2P0300000009jPX02NX:00d02NX:00<0000000WZ
2P09jPX02`09jPX00`3oool02NX:00WZ2P0G00WZ2PD0oooo9`09jPYA0?ooo`030000003oool0oooo
00D0oooo00060?ooofd02NX:00<0000000WZ2P09jPX02P09jPX00`3oool02NX:00WZ2P0700WZ2P03
0?ooo`09jPX02NX:00L02NX:0`3oool:00WZ2PD0oooo9`09jPY;0?ooo`030000003oool0oooo00D0
oooo00060?oooe`02NX:00<0000000WZ2P09jPX03P09jPX00`0000002NX:00WZ2P0A00WZ2P<0oooo
2009jPX00`3oool02NX:00WZ2P0700WZ2P80oooo3009jPX20?oooaT02NX:0P3oool;00WZ2TH0oooo
00<000000?ooo`3oool01@3oool000H0ooooG009jPX00`0000002NX:00WZ2P0>00WZ2P0300000009
jPX02NX:02@02NX:00<0oooo00WZ2P09jPX01`09jPX00`3oool02NX:00WZ2P0R00WZ2P@0oooo2`09
jPY00?ooo`030000003oool0oooo00D0oooo00060?oooe`02NX:00<0000000WZ2P09jPX03P09jPX0
0`0000002NX:00WZ2P1?00WZ2P80oooo2009jPX30?ooo``02NX:>P3oool00`000000oooo0?ooo`05
0?ooo`001P3ooomL00WZ2P0300000009jPX02NX:00h02NX:00<0000000WZ2P09jPX00`09jPX00`3o
ool02NX:00WZ2P0=00WZ2P030?ooo`09jPX02NX:01002NX:0P3oool/00WZ2P030?ooo`09jPX02NX:
00X02NX:00<0oooo00WZ2P09jPX02@09jPXe0?ooo`030000003oool0oooo00D0oooo00060?ooofH0
2NX:00<0Ogmo00WZ2P09jPX01009jPX00`0000002NX:00WZ2P0<00WZ2P80oooo3009jPX20?oooa40
2NX:1`3ooolK00WZ2P80oooo8P09jPX_0?ooo`030000003oool0oooo00D0oooo00060?ooofd02NX:
00<0000000WZ2P09jPX05@09jPX40?ooo`X02NX:00<0oooo00WZ2P09jPX03P09jPX90?oooaP02NX:
00<0oooo00WZ2P09jPX03P09jPX20?oooa402NX::@3oool00`000000oooo0?ooo`050?ooo`001P3o
oomK00WZ2P0300000009jPX02NX:00l02NX:00<0000000WZ2P09jPX02@09jPX20?oooc802NX:203o
ooli00WZ2R@0oooo00<000000?ooo`3oool01@3oool000H0ooooF`09jPX00`0000002NX:00WZ2P0?
00WZ2P0300000009jPX02NX:00H02NX:0P3ooolm00WZ2PP0oooo=`09jPXN0?ooo`030000003oool0
oooo00D0oooo00060?oooe/02NX:00<0000000WZ2P09jPX03`09jPX00`0000002NX:00WZ2P0D00WZ
2PH0oooo=`09jPX30?ooob802NX:00<0oooo00WZ2P09jPX04@09jPXH0?ooo`030000003oool0oooo
00D0oooo00060?oooe/02NX:00<0000000WZ2P09jPX03`09jPX00`0000002NX:00WZ2P0Q00WZ2P`0
ooooDP09jPX00`3oool02NX:00WZ2P0=00WZ2Q<0oooo00<000000?ooo`3oool01@3oool000H0oooo
F`09jPX00`0000002NX:00WZ2P0?00WZ2P0300000009jPX02NX:02l02NX:203ooolV00WZ2PD0oooo
9`09jPX00`3oool02NX:00WZ2P0;00WZ2P/0oooo00<000000?ooo`3oool01@3oool000H0ooooF`09
jPX00`0000002NX:00WZ2P0?00WZ2P0300000009jPX02NX:03d02NX:0`3ooomO00WZ2P<0oooo00<0
00000?ooo`3oool01@3oool000H0ooooF`09jPX00`0000002NX:00WZ2P0?00WZ2P0300000009jPX0
2NX:08d02NX:00<0oooo00WZ2P09jPX04@09jPX2000000L0oooo00060?oooe/02NX:00<0000000WZ
2P09jPX03`09jPX00`0000002NX:00WZ2P0?00WZ2PD0ooooQ@09jPX20?ooo`H02NX:0P0000070?oo
o`001P3ooomK00WZ2P0300000009jPX02NX:00l02NX:00<0000000WZ2P09jPX0X@09jPX2000000L0
oooo00060?oooe/02NX:00<0000000WZ2P09jPX03`09jPX00`0000002NX:00WZ2P2Q00WZ2P800000
1`3oool000H0ooooK@09jPX00`0000002NX:00WZ2P2Q00WZ2P8000001`3oool000H0ooooK@09jPX0
0`0000002NX:00WZ2P2Q00WZ2P8000001`3oool000H0ooooK@09jPX00`0000002NX:00WZ2P2Q00WZ
2P8000001`3oool000H0ooooK@09jPX00`0000002NX:00WZ2P2Q00WZ2P8000001`3oool000H0oooo
K@09jPX00`0000002NX:00WZ2P0I00WZ2P030?ooo`09jPX02NX:08D02NX:0P0000070?ooo`001P3o
oomK00WZ2P0300000009jPX02NX:00l02NX:00<0000000WZ2P09jPX09`09jPXB0?ooofP02NX:0P00
00070?ooo`001P3ooomK00WZ2P0300000009jPX02NX:00l02NX:00<0000000WZ2P09jPX03009jPXE
0?oooh002NX:0P0000070?ooo`001P3ooomK00WZ2P0300000009jPX02NX:00l02NX:00<0000000WZ
2P09jPX0EP09jPX20?ooodT02NX:0P0000070?ooo`001P3ooomK00WZ2P0300000009jPX02NX:00l0
2NX:00<0000000WZ2P09jPX0>@09jPX50?oooeh02NX:00<0oooo00WZ2P09jPX00P09jPX2000000L0
oooo00060?oooe/02NX:00<0000000WZ2P09jPX03`09jPX00`0000002NX:00WZ2P0W00WZ2P`0oooo
G@09jPX20?ooo``02NX:0`3oool2000000L0oooo00060?oooe/02NX:00<0000000WZ2P09jPX03`09
jPX00`0000002NX:00WZ2P0K00WZ2P`0ooooG`09jPX00`3oool02NX:00WZ2P0=00WZ2P`0oooo00<0
00000?ooo`3oool01@3oool000H0ooooF`09jPX00`0000002NX:00WZ2P0?00WZ2P0300000009jPX0
2NX:01002NX:1`3ooolK00WZ2P030?ooo`09jPX02NX:02@02NX:00<0oooo00WZ2P09jPX0<@09jPXE
0?ooo`030000003oool0oooo00D0oooo00060?oooe/02NX:00<0000000WZ2P09jPX03`09jPX00`00
00002NX:00WZ2P0400WZ2P80oooo7@09jPX40?ooob`02NX:0P3ooolW00WZ2P030?ooo`09jPX02NX:
00H02NX:7@3oool00`000000oooo0?ooo`050?ooo`001P3ooomK00WZ2P0300000009jPX02NX:00l0
2NX:00<0000000WZ2P09jPX05009jPX30?ooobL02NX:0P3ooolm00WZ2RD0oooo00<000000?ooo`3o
ool01@3oool000H0ooooK@09jPX00`0000002NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:02/02NX:
1P3oooll00WZ2Rd0oooo00<000000?ooo`3oool01@3oool000H0ooooK@09jPX00`0000002NX:00WZ
2P0W00WZ2PX0oooo?009jPXe0?ooo`030000003oool0oooo00D0oooo00060?ooofD02NX:00<0Ogmo
00WZ2P09jPX01@09jPX00`0000002NX:00WZ2P0L00WZ2P/0oooo@@09jPXj0?ooo`030000003oool0
oooo00D0oooo00060?oooe`02NX:00<0000000WZ2P09jPX03P09jPX00`0000002NX:00WZ2P0D00WZ
2PL0oooo;009jPX20?oooa<02NX:0P3oool500WZ2Sl0oooo00<000000?ooo`3oool01@3oool000H0
ooooG009jPX00`0000002NX:00WZ2P0>00WZ2P0300000009jPX02NX:00/02NX:1@3ooolG00WZ2P<0
oooo5P09jPX30?oooa@02NX:0P3oool600WZ2T<0oooo00<000000?ooo`3oool01@3oool000H0oooo
G009jPX00`0000002NX:00WZ2P0>00WZ2P0300000009jPX02NX:00802NX:0P3ooolG00WZ2PT0oooo
5P09jPX20?oooaP02NX:00<0oooo00WZ2P09jPX01009jPY70?ooo`030000003oool0oooo00D0oooo
00060?oooe`02NX:00<0000000WZ2P09jPX03P09jPX00`0000002NX:00WZ2P0B00WZ2PL0oooo4`09
jPX00`3oool02NX:00WZ2P0500WZ2P80oooo8009jPY<0?ooo`030000003oool0oooo00D0oooo0006
0?ooofd02NX:00<0000000WZ2P09jPX02P09jPX40?oooaL02NX:0P3oool600WZ2P80oooo8`09jPY@
0?ooo`030000003oool0oooo00D0oooo00060?oooed02NX:00<0000000WZ2P09jPX03@09jPX00`00
00002NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:01<02NX:00<0oooo00WZ2P09jPX01009jPX20?oo
o`L02NX:00<0oooo00WZ2P09jPX08`09jPYD0?ooo`030000003oool0oooo00D0oooo00060?oooed0
2NX:00<0000000WZ2P09jPX03@09jPX00`0000002NX:00WZ2P0B00WZ2P030?ooo`09jPX02NX:00@0
2NX:00<0oooo00WZ2P09jPX0;P09jPYH0?ooo`030000003oool0oooo00D0oooo00060?oooed02NX:
00<0000000WZ2P09jPX03@09jPX00`0000002NX:00WZ2P0C00WZ2P030?ooo`09jPX02NX:00d02NX:
0`3oool800WZ2P030?ooo`09jPX02NX:01@02NX:G@3oool00`000000oooo0?ooo`050?ooo`001P3o
oom]00WZ2P0300000009jPX02NX:00d02NX:00<0oooo00WZ2P09jPX03009jPX40?ooo`P02NX:0`3o
ool500WZ2P030?ooo`09jPX02NX:00h02NX:H@3oool00`000000oooo0?ooo`050?ooo`001P3ooom]
00WZ2P0300000009jPX02NX:01D02NX:1@3oool900WZ2P<0oooo1@09jPX00`3oool02NX:00WZ2P0?
00WZ2VD0oooo00<000000?ooo`3oool01@3oool000H0ooooGP09jPX00`0000002NX:00WZ2P0<00WZ
2P0300000009jPX02NX:00l02NX:1@3oool900WZ2P<0oooo1P09jPX00`3oool02NX:00WZ2P0?00WZ
2VX0oooo00<000000?ooo`3oool01@3oool000H0ooooGP09jPX00`0000002NX:00WZ2P0<00WZ2P03
00000009jPX02NX:00X02NX:103oool;00WZ2P80oooo1P09jPX00`3oool02NX:00WZ2P0@00WZ2Vh0
oooo00<000000?ooo`3oool01@3oool000H0ooooK@09jPX00`0000002NX:00WZ2P0500WZ2P80oooo
3@09jPX20?ooo`H02NX:00<0oooo00WZ2P09jPX04@09jPYb0?ooo`030000003oool0oooo00D0oooo
00060?oooel02NX:00<0000000WZ2P09jPX02`09jPX0100000002NX:00WZ2P3oool>00WZ2P80oooo
1`09jPX00`3oool02NX:00WZ2P0A00WZ2WH0oooo00<000000?ooo`3oool01@3oool000H0ooooG`09
jPX00`0000002NX:00WZ2P0;00WZ2P0300000009jPX02NX:00X02NX:00<0oooo00WZ2P09jPX01P09
jPX00`3oool02NX:00WZ2P0B00WZ2WX0oooo00<000000?ooo`3oool01@3oool000H0ooooI`09jPX0
0`0000002NX:00WZ2P0300WZ2P0300000009jPX02NX:00D02NX:00<0oooo00WZ2P09jPX01P09jPX0
0`3oool02NX:00WZ2P0600WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01@09jPYn
0?ooo`030000003oool0oooo00D0oooo00060?ooof002NX:00<0000000WZ2P09jPX02P09jPX01000
00002NX:00WZ2P3ooolA00WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX01P09jPZ1
0?ooo`030000003oool0oooo00D0oooo00060?ooof002NX:00<0000000WZ2P09jPX02P09jPX00`00
00002NX:00WZ2P0D00WZ2P80oooo1`09jPZ50?ooo`030000003oool0oooo00D0oooo00060?ooof@0
2NX:00<0Ogmo00WZ2P09jPX01P09jPX00`0000002NX:00WZ2P0900WZ2P030?ooo`09jPX02NX:00@0
2NX:00<0oooo00WZ2P09jPX01P09jPZ90?ooo`030000003oool0oooo00D0oooo00060?ooof402NX:
00<0000000WZ2P09jPX02@09jPX00`0000002NX:00WZ2P0<00WZ2P030?ooo`09jPX02NX:00L02NX:
S03oool00`000000oooo0?ooo`050?ooo`001P3ooomX00WZ2P0307moO`09jPX02NX:00802NX:00<0
000000WZ2P09jPX02009jPX00`3oool02NX:00WZ2P0700WZ2Y00oooo00<000000?ooo`3oool01@3o
ool000H0ooooHP09jPX00`0000002NX:00WZ2P0800WZ2P0300000009jPX02NX:00h02NX:U03oool0
0`000000oooo0?ooo`050?ooo`001P3ooomR00WZ2P0300000009jPX02NX:00H02NX:00<0Ogmo00WZ
2P0000003@09jPZG0?ooo`030000003oool0oooo00D0oooo00060?ooofH02NX:00<0Ogmo00WZ2P09
jPX01009jPX00`0000002NX:00WZ2P0700WZ2Y/0oooo00<000000?ooo`3oool01@3oool000H0oooo
H`09jPX00`0000002NX:00WZ2P0700WZ2P0300000009jPX02NX:00<02NX:W`3oool00`000000oooo
0?ooo`050?ooo`001P3ooomY00WZ2P0507moO`09jPX02NX:00WZ2P0000000P09jPZR0?ooo`030000
003oool0oooo00D0oooo00060?ooof@02NX:00<0000000WZ2P09jPX00`09jPX407moO`030000003o
ool0oooo0:40oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0H@3oool2
0000000307moO`000000Ogmo00D0Ogmo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`1R0?ooo`030000001oOgl0000000H0Ogmo00<000000?oo
o`3oool0X@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1S0?ooo`T0
0000X`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1S0?ooo`800000
1P1oOgl00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo06@0oooo2000002S0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo0P00
003o0?oooa40oooo00<000000?ooo`3oool01@3oool000H0ooooo`00000D000000L0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-3.75078, -78.7507, 0.548786, \
0.548786}},
  CellTags->"Add Surface Roughness"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Realistic Fresnel Lens Model", "Section",
  CellTags->"Realistic Fresnel Lens Model"],

Cell[CellGroupData[{

Cell["?Fresnel", "Input",
  CellTags->"Realistic Fresnel Lens Model"],

Cell[BoxData[
    \("Fresnel[component, groovespacing, options] is a generic building block \
used for transforming a regular optical element into a flattened Fresnel \
equivalent. \n\nThe groovespacing argument specifies the width of the Fresnel \
grooves and the groove direction is specified by the FresnelSymmetry option. \
If SagFit->True is used then the groovespacing parameter denotes the depth of \
each groove and the groove width is varied to match the specified sag. \
Fresnel uses the AffectedSurfaces option to specify the component surfaces \
affected by Fresnel. If AffectedSurfaces does not specify a number or list of \
numbers, Fresnel will transform all surfaces present. See also: \
SmoothFresnel, SmoothKernelSize, SmoothKernelRange, FresnelSymmetry, and \
SagFit."\)], "Print",
  CellTags->{"Info3252053738-6121344", "Realistic Fresnel Lens Model"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["?SmoothFresnel", "Input",
  CellTags->"Realistic Fresnel Lens Model"],

Cell[BoxData[
    \("SmoothFresnel -> True is an option of Fresnel that specifies that the \
\"rounding\" of sharp groove edges due to the manufacturing process is \
modelled. \n\nThis setting also enables the vertical facets to be modeled. \
For SmoothFresnel -> False, the grooves have perfect sharpness but the \
straight vertical facets are not modeled. This setting enables the fastest \
ray-trace speeds. See also: SmoothKernelSize and SmoothKernelRange."\)], \
"Print",
  CellTags->{"Info3252053750-8945673", "Realistic Fresnel Lens Model"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
flens = Fresnel[PlanoConvexLens[100,{50,50},2],.254, \
SmoothFresnel->True]\
\>", "Input",
  CellTags->"Realistic Fresnel Lens Model"],

Cell[BoxData[
    TagBox[\(Fresnel[PlanoConvexLens[100, {50, 50}, 2], 0.254`, 
        SmoothFresnel \[Rule] True]\),
      HoldForm]], "Output",
  CellTags->"Realistic Fresnel Lens Model"]
}, Open  ]],

Cell[CellGroupData[{

Cell["surfacefunc = SurfaceFunction/.(Surfaces/.flens)[[1]]", "Input",
  CellTags->"Realistic Fresnel Lens Model"],

Cell[BoxData[
    TagBox[\(CompiledFunction[{SCx, 
          SCy}, {If[SCx == 0.` && SCy == 0.`, 4.7488903678051427`*^-7, 
            Block[{TV1, TV2}, TV1 = Re[SCx\/\@\(SCx\^2 + SCy\^2\)]; 
              TV2 = Re[SCy\/\@\(SCx\^2 + SCy\^2\)]; 
              Plus @@ \(\((Re[\((\(\(51.872033213443714`\)\(\[InvisibleSpace]\
\)\) - \@\(\(\(2690.707829696608`\)\(\[InvisibleSpace]\)\) - \((SCx - #1\
\[LeftDoubleBracket]1\[RightDoubleBracket]\ TV1)\)\^2 - \((SCy - #1\
\[LeftDoubleBracket]1\[RightDoubleBracket]\ TV2)\)\^2\) - 
                              If[\@\(\((SCx - #1\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ TV1)\)\^2 + \((SCy - #1\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ TV2)\)\^2\) == 0.`, 
                                0.`, \(\(51.872033213443714`\)\(\
\[InvisibleSpace]\)\) - \[Sqrt]\((\(\(2690.707829696608`\)\(\[InvisibleSpace]\
\)\) - \(0.064516`\ \((SCx - #1\[LeftDoubleBracket]1\[RightDoubleBracket]\ \
TV1)\)\^2\ Floor[3.937007874015748`\ Re[\@\(\((SCx - #1\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ TV1)\)\^2 + \((SCy - #1\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ TV2)\)\^2\)]]\^2\)\/\(\((SCx - #1\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ TV1)\)\^2 + \((SCy - #1\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ TV2)\)\^2\) - \(0.064516`\ \((SCy - #1\
\[LeftDoubleBracket]1\[RightDoubleBracket]\ TV2)\)\^2\ \
Floor[3.937007874015748`\ Re[\@\(\((SCx - #1\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ TV1)\)\^2 + \((SCy - #1\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ TV2)\)\^2\)]]\^2\)\/\(\((SCx - #1\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ TV1)\)\^2 + \((SCy - #1\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ TV2)\)\^2\))\)])\)\ #1\[LeftDoubleBracket]2\
\[RightDoubleBracket]] &)\) /@ {{\(-0.0225`\), 
                      0.00016091256078966553`}, {\(-0.02205`\), 
                      0.0001966324237933318`}, {\(-0.0216`\), 
                      0.0002393103192817306`}, {\(-0.02115`\), 
                      0.0002900740156417159`}, {\(-0.0207`\), 
                      0.00035018483558790087`}, {\(-0.02025`\), 
                      0.00042104348442400293`}, {\(-0.019799999999999998`\), 
                      0.0005041940010705115`}, {\(-0.01935`\), 
                      0.0006013253385468225`}, {\(-0.0189`\), 
                      0.000714270053318571`}, {\(-0.01845`\), 
                      0.0008449995685510406`}, {\(-0.018`\), 
                      0.000995615477989833`}, {\(-0.01755`\), 
                      0.0011683363779742186`}, {\(-0.0171`\), 
                      0.0013654797577770349`}, {\(-0.016649999999999998`\), 
                      0.0015894385454207941`}, {\(-0.0162`\), 
                      0.001842651999074724`}, {\(-0.01575`\), 
                      0.0021275707539952383`}, {\(-0.0153`\), 
                      0.0024466159816195457`}, {\(-0.01485`\), 
                      0.002802132789561053`}, {\(-0.0144`\), 
                      0.0031963381862691485`}, {\(-0.013949999999999999`\), 
                      0.0036312641479815774`}, {\(-0.0135`\), 
                      0.0041086965528571075`}, {\(-0.013049999999999999`\), 
                      0.004630110980977559`}, {\(-0.0126`\), 
                      0.005196606611126546`}, {\(-0.01215`\), 
                      0.00580883966669103`}, {\(-0.0117`\), 
                      0.006466958063710195`}, {\(-0.01125`\), 
                      0.0071705390836143985`}, {\(-0.0108`\), 
                      0.007918532021170438`}, {\(-0.01035`\), 
                      0.008709207834698775`}, {\(-0.009899999999999999`\), 
                      0.009540117841900939`}, {\(-0.00945`\), 
                      0.010408063453337887`}, {\(-0.009`\), 
                      0.011309078811510798`}, {\(-0.00855`\), 
                      0.012238428003926164`}, {\(-0.0081`\), 
                      0.013190618243706832`}, {\(-0.00765`\), 
                      0.01415943006465706`}, {\(-0.0072`\), 
                      0.015137965165949625`}, {\(-0.00675`\), 
                      0.016118712074832595`}, {\(-0.0063`\), 
                      0.01709362928713578`}, {\(-0.00585`\), 
                      0.01805424501084383`}, {\(-0.0054`\), 
                      0.01899177209579319`}, {\(-0.0049499999999999995`\), 
                      0.019897236202415933`}, {\(-0.0045`\), 
                      0.020761614764941587`}, {\(-0.00405`\), 
                      0.02157598386001437`}, {\(-0.0036`\), 
                      0.02233166971967281`}, {\(-0.00315`\), 
                      0.0230204013454742`}, {\(-0.0027`\), 
                      0.023634460502756954`}, {\(-0.00225`\), 
                      0.024166825311491703`}, {\(-0.0018`\), 
                      0.02461130370944832`}, {\(-0.00135`\), 
                      0.024962653246318516`}, {\(-0.0009`\), 
                      0.025216683970807383`}, {\(-0.00045`\), 
                      0.02537034158837449`}, {0.`, 
                      0.025421768582348778`}, {0.00045`, 
                      0.02537034158837449`}, {0.0009`, 
                      0.025216683970807383`}, {0.00135`, 
                      0.024962653246318516`}, {0.0018`, 
                      0.02461130370944832`}, {0.00225`, 
                      0.024166825311491703`}, {0.0027`, 
                      0.023634460502756954`}, {0.00315`, 
                      0.0230204013454742`}, {0.0036`, 
                      0.02233166971967281`}, {0.00405`, 
                      0.02157598386001437`}, {0.0045`, 
                      0.020761614764941587`}, {0.0049499999999999995`, 
                      0.019897236202415933`}, {0.0054`, 
                      0.01899177209579319`}, {0.00585`, 
                      0.01805424501084383`}, {0.0063`, 
                      0.01709362928713578`}, {0.00675`, 
                      0.016118712074832595`}, {0.0072`, 
                      0.015137965165949625`}, {0.00765`, 
                      0.01415943006465706`}, {0.0081`, 
                      0.013190618243706832`}, {0.00855`, 
                      0.012238428003926164`}, {0.009`, 
                      0.011309078811510798`}, {0.00945`, 
                      0.010408063453337887`}, {0.009899999999999999`, 
                      0.009540117841900939`}, {0.01035`, 
                      0.008709207834698775`}, {0.0108`, 
                      0.007918532021170438`}, {0.01125`, 
                      0.0071705390836143985`}, {0.0117`, 
                      0.006466958063710195`}, {0.01215`, 
                      0.00580883966669103`}, {0.0126`, 
                      0.005196606611126546`}, {0.013049999999999999`, 
                      0.004630110980977559`}, {0.0135`, 
                      0.0041086965528571075`}, {0.013949999999999999`, 
                      0.0036312641479815774`}, {0.0144`, 
                      0.0031963381862691485`}, {0.01485`, 
                      0.002802132789561053`}, {0.0153`, 
                      0.0024466159816195457`}, {0.01575`, 
                      0.0021275707539952383`}, {0.0162`, 
                      0.001842651999074724`}, {0.016649999999999998`, 
                      0.0015894385454207941`}, {0.0171`, 
                      0.0013654797577770349`}, {0.01755`, 
                      0.0011683363779742186`}, {0.018`, 
                      0.000995615477989833`}, {0.01845`, 
                      0.0008449995685510406`}, {0.0189`, 
                      0.000714270053318571`}, {0.01935`, 
                      0.0006013253385468225`}, {0.019799999999999998`, 
                      0.0005041940010705115`}, {0.02025`, 
                      0.00042104348442400293`}, {0.0207`, 
                      0.00035018483558790087`}, {0.02115`, 
                      0.0002900740156417159`}, {0.0216`, 
                      0.0002393103192817306`}, {0.02205`, 
                      0.0001966324237933318`}, {0.0225`, 
                      0.00016091256078966553`}}\)]], SCx, SCy}, 
        "-CompiledCode-"]\),
      False,
      Editable->False]], "Output",
  CellTags->"Realistic Fresnel Lens Model"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot[First[surfacefunc[x,0]],{x,19,20},PlotPoints->100];", "Input",
  CellTags->"Realistic Fresnel Lens Model"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-18.0714 0.952381 0.0147151 6.10235 [
[.21429 .00222 -12 -9 ]
[.21429 .00222 12 0 ]
[.40476 .00222 -12 -9 ]
[.40476 .00222 12 0 ]
[.59524 .00222 -12 -9 ]
[.59524 .00222 12 0 ]
[.78571 .00222 -12 -9 ]
[.78571 .00222 12 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13676 -24 -4.5 ]
[.01131 .13676 0 4.5 ]
[.01131 .25881 -24 -4.5 ]
[.01131 .25881 0 4.5 ]
[.01131 .38086 -24 -4.5 ]
[.01131 .38086 0 4.5 ]
[.01131 .5029 -24 -4.5 ]
[.01131 .5029 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(19.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(19.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(19.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(19.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13676 m
.03006 .13676 L
s
[(0.02)] .01131 .13676 1 0 Mshowa
.02381 .25881 m
.03006 .25881 L
s
[(0.04)] .01131 .25881 1 0 Mshowa
.02381 .38086 m
.03006 .38086 L
s
[(0.06)] .01131 .38086 1 0 Mshowa
.02381 .5029 m
.03006 .5029 L
s
[(0.08)] .01131 .5029 1 0 Mshowa
.125 Mabswid
.02381 .04523 m
.02756 .04523 L
s
.02381 .07574 m
.02756 .07574 L
s
.02381 .10625 m
.02756 .10625 L
s
.02381 .16727 m
.02756 .16727 L
s
.02381 .19779 m
.02756 .19779 L
s
.02381 .2283 m
.02756 .2283 L
s
.02381 .28932 m
.02756 .28932 L
s
.02381 .31983 m
.02756 .31983 L
s
.02381 .35034 m
.02756 .35034 L
s
.02381 .41137 m
.02756 .41137 L
s
.02381 .44188 m
.02756 .44188 L
s
.02381 .47239 m
.02756 .47239 L
s
.02381 .53341 m
.02756 .53341 L
s
.02381 .56393 m
.02756 .56393 L
s
.02381 .59444 m
.02756 .59444 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .50172 m
.03318 .52535 L
.04339 .55114 L
.04836 .56369 L
.05078 .56959 L
.05193 .57195 L
.05243 .57297 L
.05272 .57339 L
.05298 .57406 L
.05324 .57435 L
.05352 .57461 L
.05381 .57536 L
.05408 .57553 L
.05527 .5764 L
.05581 .57677 L
.05609 .57636 L
.05639 .57712 L
.05667 .57655 L
.05693 .57573 L
.05719 .57639 L
.05744 .57531 L
.05771 .57599 L
.058 .57479 L
.05828 .57329 L
.05854 .57394 L
.05884 .57219 L
.05915 .57018 L
.05942 .57086 L
.05971 .56845 L
.06003 .56573 L
.0602 .56615 L
.06038 .56267 L
.06054 .56307 L
.06071 .5635 L
.061 .5599 L
.06221 .54705 L
.06344 .52953 L
.06458 .50661 L
.06589 .47879 L
.06646 .4687 L
.06676 .45738 L
.06708 .45819 L
.06735 .44628 L
.06766 .43394 L
.06793 .43464 L
.06819 .42173 L
.06846 .40842 L
.0687 .40903 L
.06898 .39539 L
.06924 .39606 L
Mistroke
.06952 .38208 L
.06982 .36789 L
.0701 .36859 L
.07035 .35407 L
.07065 .33952 L
.07082 .33994 L
.07097 .34033 L
.07125 .32565 L
.07155 .31097 L
.07185 .31172 L
.07202 .29673 L
.07217 .29713 L
.07246 .28253 L
.07276 .26814 L
.07303 .26882 L
.07328 .25451 L
.07356 .25521 L
.07386 .24129 L
.07418 .22776 L
.07449 .21455 L
.0748 .21534 L
.07497 .2022 L
.07515 .20265 L
.07546 .19036 L
.07576 .17851 L
.07603 .17919 L
.07633 .16784 L
.0766 .15701 L
.07686 .15767 L
.07715 .14742 L
.07745 .13781 L
.07777 .13862 L
.07807 .1296 L
.07834 .12109 L
.07864 .12184 L
.0789 .11389 L
.07918 .10659 L
.07947 .10734 L
.07975 .1006 L
.08 .09439 L
.08024 .09498 L
.0805 .08932 L
.08077 .09001 L
.08107 .08497 L
.08123 .08537 L
.08139 .0805 L
.0817 .08127 L
.08198 .07718 L
.08225 .07351 L
.08251 .07415 L
Mistroke
.08278 .07093 L
.08308 .06816 L
.0834 .06896 L
.08358 .06625 L
.08374 .06667 L
.08405 .06463 L
.0842 .06503 L
.08437 .06296 L
.08469 .06377 L
.08499 .06232 L
.08528 .06112 L
.08555 .0618 L
.08581 .06075 L
.08609 .05996 L
.08635 .06063 L
.08658 .05993 L
.08686 .05952 L
.08717 .06029 L
.08745 .06005 L
.08772 .05989 L
.08799 .06058 L
.08824 .06051 L
.08852 .06122 L
.08883 .06138 L
.08913 .06163 L
.08944 .06199 L
.08971 .06267 L
.09 .06305 L
.09032 .06356 L
.09062 .06431 L
.09129 .06553 L
.0925 .06815 L
.09476 .07379 L
.09984 .08667 L
.1094 .1109 L
.11859 .13421 L
.12837 .15904 L
.13779 .18296 L
.1478 .2084 L
.15744 .23293 L
.16672 .25653 L
.17659 .28166 L
.18609 .30588 L
.19619 .33162 L
.20592 .35644 L
.21529 .38034 L
.22524 .40577 L
.23483 .43028 L
.24406 .45386 L
.25387 .47898 L
Mistroke
.26332 .50317 L
.27337 .5289 L
.28305 .55371 L
.28747 .56507 L
.28999 .57153 L
.29236 .57737 L
.29467 .58219 L
.29534 .58309 L
.29597 .5842 L
.29625 .58429 L
.29654 .58505 L
.29671 .58476 L
.29686 .58515 L
.29716 .58508 L
.29748 .58492 L
.29764 .58533 L
.29782 .58578 L
.29813 .58545 L
.29842 .58489 L
.2986 .58534 L
.29877 .58426 L
.29908 .58507 L
.29926 .58379 L
.29942 .58421 L
.2996 .58466 L
.29979 .58318 L
.30008 .58169 L
.30039 .58249 L
.30069 .58072 L
.30096 .57857 L
.30226 .57112 L
.30285 .56822 L
.30314 .56408 L
.30341 .56476 L
.30372 .56018 L
.30405 .55516 L
.30433 .54947 L
.30463 .55024 L
.3049 .54394 L
.30518 .54466 L
.30544 .5378 L
.30569 .53028 L
.30597 .53101 L
.30628 .52308 L
.30657 .51449 L
.30684 .51519 L
.30716 .50606 L
.3075 .49639 L
.30766 .4968 L
.30782 .48609 L
Mistroke
.30812 .48685 L
.3084 .47587 L
.30867 .46428 L
.30896 .46503 L
.30927 .45302 L
.31186 .37374 L
.31667 .21837 L
.31799 .18187 L
.31871 .15974 L
.31906 .14952 L
.31922 .14992 L
.31939 .13981 L
.31967 .14053 L
.31996 .13134 L
.32012 .13174 L
.32028 .12283 L
.32058 .1236 L
.32075 .1153 L
.32094 .11578 L
.32111 .10809 L
.32127 .10851 L
.32158 .10174 L
.32173 .10213 L
.3219 .10257 L
.32221 .09639 L
.32255 .09084 L
.32286 .08577 L
.32316 .08653 L
.32342 .08184 L
.32372 .07771 L
.32402 .07849 L
.32431 .07481 L
.32463 .07163 L
.3248 .07208 L
.32496 .06891 L
.32524 .06964 L
.32555 .06723 L
.32589 .06524 L
.3262 .06351 L
.32638 .06396 L
.32657 .06445 L
.32674 .06265 L
.3269 .06306 L
.32716 .06178 L
.32745 .06252 L
.32773 .06149 L
.32798 .06062 L
.32827 .06137 L
.32859 .06088 L
.32889 .06052 L
Mistroke
.32916 .06123 L
.32948 .06106 L
.32977 .06098 L
.33004 .06166 L
.33033 .06168 L
.33064 .06188 L
.3308 .06228 L
.33097 .06221 L
.33128 .063 L
.33157 .06329 L
.33187 .06371 L
.3322 .06424 L
.33278 .06548 L
.3341 .06833 L
.3365 .07429 L
.341 .08586 L
.35016 .10943 L
.3599 .13454 L
.36928 .15871 L
.37926 .18444 L
.38887 .20923 L
.39811 .23309 L
.40794 .2585 L
.41741 .28297 L
.42747 .309 L
.43717 .33409 L
.44649 .35825 L
.45641 .38396 L
.46597 .40874 L
.47515 .43257 L
.48494 .45797 L
.49435 .48242 L
.50436 .50843 L
.514 .53351 L
.52327 .55764 L
.52845 .57113 L
.53314 .58334 L
.53549 .58891 L
.53673 .59134 L
.53741 .59227 L
.53758 .59271 L
.53774 .5926 L
.53804 .59338 L
.5383 .59345 L
.53859 .59347 L
.5389 .59427 L
.53918 .59416 L
.53947 .59392 L
.53979 .59475 L
.53995 .59401 L
Mistroke
.54012 .59447 L
.54044 .59395 L
.5407 .5931 L
.54099 .59385 L
.54125 .59279 L
.5415 .59344 L
.54179 .59219 L
.5421 .59072 L
.54236 .59139 L
.54264 .58956 L
.54296 .58748 L
.54313 .58794 L
.5433 .58511 L
.54362 .58595 L
.54391 .58307 L
.54509 .57265 L
.54637 .55803 L
.54669 .55178 L
.54686 .55225 L
.54703 .55268 L
.54721 .54549 L
.54741 .546 L
.54757 .53818 L
.54776 .53866 L
.54807 .53059 L
.54824 .53103 L
.54839 .52197 L
.5487 .52277 L
.54899 .51341 L
.55029 .48291 L
.55263 .42164 L
.55706 .26191 L
.55828 .22073 L
.55959 .18364 L
.56195 .13335 L
.56324 .11011 L
.56446 .09204 L
.56474 .08678 L
.565 .08745 L
.56529 .08278 L
.56556 .07852 L
.56586 .0793 L
.56603 .07525 L
.56618 .07566 L
.56647 .07234 L
.56676 .07311 L
.56708 .07031 L
.56737 .06781 L
.56753 .06823 L
.5677 .06578 L
Mistroke
.56802 .06661 L
.56832 .06481 L
.56863 .06335 L
.5689 .06405 L
.56919 .06282 L
.56936 .06326 L
.56954 .06197 L
.56986 .06127 L
.57003 .06173 L
.5702 .06216 L
.57038 .06129 L
.57057 .0618 L
.57074 .06108 L
.57092 .06155 L
.57109 .062 L
.57125 .06141 L
.57155 .06134 L
.57186 .06216 L
.58105 .08211 L
.59084 .10768 L
.60026 .13231 L
.61027 .15851 L
.61992 .18377 L
.62919 .20807 L
.63907 .23395 L
.64857 .25888 L
.65867 .28539 L
.66841 .31095 L
.67777 .33556 L
.68773 .36174 L
.69732 .38698 L
.70655 .41126 L
.71637 .43713 L
.72582 .46204 L
.73586 .48853 L
.74554 .51407 L
.75485 .53865 L
.76476 .56482 L
.76968 .57784 L
.7743 .59004 L
.77656 .5958 L
.77872 .59997 L
.77929 .60103 L
.77961 .60133 L
.7799 .60211 L
.78007 .60193 L
.78025 .60241 L
.78057 .60251 L
.78073 .60293 L
.7809 .60251 L
Mistroke
.7812 .6033 L
.78147 .603 L
.78176 .6026 L
.78203 .60332 L
.78228 .60263 L
.78257 .60184 L
.78289 .60268 L
.78319 .6017 L
.78347 .6004 L
.78373 .6011 L
.78402 .59955 L
.78429 .59764 L
.78453 .59829 L
.7848 .59607 L
.78506 .59675 L
.78534 .59419 L
.78565 .5913 L
.78687 .58083 L
.7874 .57671 L
.78769 .57746 L
.78799 .5722 L
.78833 .56648 L
.78864 .56012 L
.78883 .56061 L
.789 .55329 L
.78916 .55371 L
.78933 .55416 L
.78964 .5466 L
.78997 .53847 L
.79029 .52967 L
.79057 .53042 L
.79088 .521 L
.79117 .51089 L
.79148 .51172 L
.79164 .50066 L
.79181 .50112 L
.79211 .48983 L
.79242 .49066 L
.79272 .47879 L
.79299 .4663 L
.79762 .30966 L
.80002 .23807 L
.80266 .16458 L
.80385 .13515 L
.80514 .11154 L
.80541 .1045 L
.80567 .10519 L
.80597 .09879 L
.80625 .0929 L
.80655 .0937 L
Mistroke
.80672 .08808 L
.80688 .0885 L
.80716 .08371 L
.80746 .07948 L
.80778 .08032 L
.80808 .07655 L
.80841 .07331 L
.80859 .07379 L
.80876 .07055 L
.80893 .07101 L
.80912 .07152 L
.80929 .06866 L
.80947 .06913 L
.80978 .06701 L
.81012 .0653 L
.81044 .06383 L
.81072 .06459 L
.81104 .0634 L
.8112 .06383 L
.81138 .06251 L
.81167 .06328 L
.81194 .06244 L
.81211 .06288 L
.81226 .06195 L
.81256 .06273 L
.82187 .08025 L
.83178 .10654 L
.84133 .13188 L
.8505 .15625 L
.86027 .18221 L
.86968 .20722 L
.87967 .23382 L
.8893 .25946 L
.89857 .28413 L
.90842 .31041 L
.91791 .33572 L
.928 .36263 L
.93771 .38858 L
.94706 .41356 L
.95701 .44014 L
.96658 .46576 L
.97579 .49041 L
.97619 .49148 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{597.812, 369.5},
  ImageMargins->{{42, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009E0001LB000`400?l00000o`00003oo`3ooooo
0?oooeL0oooo003o0?ooool0ooooE`3oool00880oooo0`0000030?ooo`8000001@3oool010000000
oooo0?ooo`3oool5000005P0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`030?oo
o`<00000F@3oool3000000<0oooo0P0000050?ooo`030000003oool0oooo0080oooo0`00001I0?oo
o`<000000`3oool2000000D0oooo00<000000?ooo`3oool00P3oool3000005l0oooo1@0000030?oo
o`8000002P3oool008<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`04
0000003oool0oooo000005T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`050000003oool0oooo0?ooo`000000F@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00H0oooo00D000000?ooo`3oool0oooo0000001O0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000002@3oool008<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`D00000FP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00D000000?ooo`3oool0oooo0000001I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool01@000000oooo0?ooo`3oool000000600oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000090?ooo`00P`3oool00`000000oooo0?ooo`020?ooo`@000002P3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo0080oooo100000070?ooo`040000003oool0oooo
000005/0oooo00<000000?ooo`3oool00P3oool4000000L0oooo1000001J0?ooo`030000003oool0
oooo0080oooo100000080?ooo`<00000HP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool01`3oool008<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo00D0oooo00D000000?ooo`3oool0oooo0000001I0?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0000005/0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0F`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3o
ool0000005h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000T0
oooo00220?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000L0oooo00D000000?ooo`3o
ool0oooo0000001H0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000T0oooo0P00001J
0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0F@3o
ool2000000<0oooo00D000000?ooo`3oool0oooo000000070?ooo`050000003oool0oooo0?ooo`00
0000GP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000002@3oool0
08<0oooo00<000000?ooo`3oool00P3oool3000000T0oooo0`00001J0?ooo`030000003oool0oooo
0080oooo0`00000;0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool00P3oool30000
00X0oooo0P00001J0?ooo`030000003oool0oooo0080oooo0`0000090?ooo`<00000H03oool30000
00@0oooo0P00000:0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooool0oooo=@3oool001l0oooo
00<000000?ooo`3oool0o`3ooooo0?ooocD0oooo000O0?ooo`030000003oool0oooo0?l0ooooo`3o
oole0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooool0oooo=@3oool001l0oooo00<000000?oo
o`3oool0o`3ooooo0?ooocD0oooo000O0?ooo`030000003oool0oooo0?l0ooooo`3ooole0?ooo`00
7`3oool00`000000oooo0?ooo`3o0?ooool0oooo=@3oool001l0oooo00<000000?ooo`3oool0o`3o
oooo0?ooocD0oooo000O0?ooo`030000003oool0oooo0?l0ooooo`3ooole0?ooo`004@3ooooo0000
0?l00000AP00000001l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00/0oooo000O0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0;0?ooo`007`3oool00`000000oooo0?ooo`1[0?ooo`030000003o
ool0oooo06/0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1[0?ooo`030000003o
ool0oooo06`0oooo00<000000?ooo`3oool02`3oool001l0oooo00<000000?ooo`3oool0o`3ooooo
0?ooocD0oooo000O0?ooo`030000003oool0oooo0?l0ooooo`3ooole0?ooo`007`3oool00`000000
oooo0?ooo`3o0?ooool0oooo=@3oool001l0oooo00<000000?ooo`3oool0o`3ooooo0?ooocD0oooo
000O0?ooo`030000003oool0oooo0?l0ooooo`3ooole0?ooo`007`3oool00`000000oooo0?ooo`3o
0?ooool0oooo=@3oool001l0oooo00<000000?ooo`3oool0o`3ooooo0?ooocD0oooo000O0?ooo`03
0000003oool0oooo0?l0ooooo`3ooole0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooool0oooo
=@3oool001l0oooo00<000000?ooo`3oool0o`3ooooo0?ooocD0oooo000O0?ooo`030000003oool0
oooo0?l0ooooo`3ooole0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooool0oooo=@3oool001l0
oooo00<000000?ooo`3oool0o`3ooooo0?ooocD0oooo000O0?ooo`<00000o`3ooooo0?ooocD0oooo
000O0?ooo`030000003oool0oooo0?l0ooooo`3ooole0?ooo`007`3oool00`000000oooo0?ooo`3o
0?ooool0oooo=@3oool001l0oooo00<000000?ooo`3oool0o`3ooooo0?ooocD0oooo000O0?ooo`03
0000003oool0oooo0?l0ooooo`3ooole0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooool0oooo
=@3oool001l0oooo00<000000?ooo`3oool0o`3ooooo0?ooocD0oooo000O0?ooo`030000003oool0
oooo0?l0ooooo`3ooole0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooool0oooo=@3oool001l0
oooo00<000000?ooo`3oool0803oool3000008X0oooo0P00002;0?ooo`030000003oool0oooo0?H0
oooo000O0?ooo`030000003oool0oooo0200oooo100000280?ooo`@00000R@3oool2000008X0oooo
0P00001/0?ooo`007`3oool00`000000oooo0?ooo`0P0?ooo`040000003oool0oooo000008P0oooo
00@000000?ooo`3oool00000R03oool3000008T0oooo0`00001/0?ooo`007`3oool00`000000oooo
0?ooo`0O0?ooo`8000000`3oool00`000000oooo0?ooo`250?ooo`050000003oool0oooo0?ooo`00
0000Q`3oool010000000oooo0?ooo`0000280?ooo`040000003oool0oooo000006/0oooo000O0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`250?oo
o`050000003oool0oooo0?ooo`000000Q`3oool010000000oooo0?ooo`0000280?ooo`040000003o
ool0oooo000006/0oooo000O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`230?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0Q03o
ool01@000000oooo0?ooo`3oool0000008L0oooo00D000000?ooo`3oool0oooo0000001Z0?ooo`00
7`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
P`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`250?ooo`050000003oool0oooo0?ooo`000000JP3oool001l0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0880oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06L0oooo
000O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`220?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1W0?ooo`007`3oool3000001l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`22
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1W
0?ooo`007`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0P@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0840oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0IP3oool001l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0840oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`210?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo06H0oooo000O0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
P03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1U0?ooo`007`3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo07l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`200?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0I@3oool001l0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0P03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo06@0oooo000O0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
07l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1T0?ooo`007`3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0OP3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`1n0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0I03oool001l0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo07d0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06<0oooo
000O0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`1m0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`1S0?ooo`007`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0O@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo07d0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0HP3oool001l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo07`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1l0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0680oooo000O0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`1R0?ooo`007`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1l0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0H@3oool001l0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0O03o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0640oooo000O0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1j0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo07/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1P0?ooo`007`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0NP3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`1k0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0H03oool001l0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0600
oooo000O0?ooo`<000007@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05l0oooo
000O0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`1O0?ooo`007`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0GP3oool001l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo07P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo05h0oooo000O0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`1N0?ooo`007`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1g0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0G@3oool001l0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05d0oooo000O0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo07H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1M0?ooo`007`3oool00`00
0000oooo0?ooo`0L0?ooo`8000004P3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1L0?ooo`007`3oool00`000000
oooo0?ooo`0L0?ooo`8000004`3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1L0?ooo`007`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0M@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`1e0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0G03oool001l0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0M@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05/0oooo000O
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1K
0?ooo`007`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0LP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo07@0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0F`3oool001l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo0780oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo05X0oooo00020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`800000
0P3oool5000000P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo0780oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo05X0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`1I0?ooo`0000D0oooo0000003oool0oooo000000080?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0203oool4000001/0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0L`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0780oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`1I0?ooo`0000D0oooo0000003oool0oooo00000008
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`1b0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0F@3oool000050?ooo`000000
oooo0?ooo`000000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0L03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0F03oool000050?ooo`000000oooo0?ooo`000000203oool01P000000oooo0?ooo`000000oooo
000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo0740oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0F03oool00080oooo0P00000:0?ooo`8000000`3oool30000
00T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
06l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
05L0oooo000O0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`1_0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0L@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`1G0?ooo`007`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo06l0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0E`3oool001l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`1_0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo05H0oooo000O0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0KP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo06h0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`1F0?ooo`007`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo06h0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1^0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0E@3oool001l0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0K@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05D0oooo000O0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1]0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo06d0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1E0?ooo`007`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0K@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0E03o
ool001l0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo06`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo05@0oooo000O0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`1/0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0K03oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`1C0?ooo`007`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0D`3oool001l0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`1[0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo05<0oooo000O0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0J`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06/0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`1B0?ooo`007`3oool3000001/0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0JP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo06X0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`1B0?ooo`007`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo06X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1Z0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0DP3oool001l0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0JP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0540oooo000O0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1X0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo06T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1A0?ooo`007`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0D@3o
ool001l0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo0500oooo000O0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`1V0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`1@0?ooo`007`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06H0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0D03oool001l0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`1V0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo04l0oooo000O0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0IP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1?0?ooo`007`3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0C`3oool001l0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0IP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo04h0oooo000O0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo06D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1>0?ooo`00
7`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
I03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
C@3oool001l0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo06<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo04d0oooo000O0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`1S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`1=0?ooo`007`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
06<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool0C03oool001l0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0I03oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo04`0oooo000O0?ooo`<000006P3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`1R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0H`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo04/0oooo000O0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0HP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`1;0?ooo`007`3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0BP3oool001l0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo05l0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0HP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04X0oooo000O0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1O0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo0680oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1:0?ooo`00
7`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
G`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
B@3oool001l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo05h0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1O0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo04T0oooo000O0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`1N0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0G`3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`180?ooo`007`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0B03oool001l0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`1N0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo04P0oooo000O0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0600oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`170?ooo`007`3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`1O0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0A`3oool001l0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo05`0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo04L0oooo000O0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1L0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`160?oo
o`007`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0AP3oool001l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo05/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1K0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo04D0oooo000O0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`150?ooo`007`3oool3000001X0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`1J0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`150?ooo`007`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0A03oool001l0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`1J0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo04@0oooo000O0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`140?ooo`007`3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0@`3oool001l0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo04<0oooo000O0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`120?oo
o`007`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0@P3oool001l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo0480oooo000O0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`110?ooo`007`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0@@3oool001l0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo0440oooo000O0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`100?ooo`007`3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0@03oool001l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0400oooo000O
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0o
0?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0`0000080?oo
o`030000003oool0oooo01T0oooo0P00000d0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo03l0oooo00001@3oool0
00000?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0o
0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`050000003oool0oooo0000003oool01@00
00080?ooo`@00000603oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo03h0oooo0000
1@3oool000000?ooo`3oool0000000P0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo03h0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo000000090?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0m0?ooo`0000D0oooo0000003oool0oooo000000080?oo
o`040000003oool0oooo000000<0oooo0P0000090?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo05<0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0m0?ooo`000P3oool2000000X0oooo0P0000050?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo0500oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo03d0oooo000O0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0l0?ooo`007`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool0?03oool001l0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0D@3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03/0oooo000O0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0k0?ooo`007`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1@0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0>`3oool001l0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03X0
oooo000O0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0j0?ooo`007`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0CP3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0>@3oool001l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo03T0oooo000O0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0>@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0i0?ooo`007`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo04h0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool0>03oool001l0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03P0oooo000O0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0g0?ooo`007`3oool3
000001T0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0g0?ooo`007`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`1<0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0=`3oool001l0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo04X0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03H0
oooo000O0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`0f0?ooo`007`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0=P3oool001l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo03D0oooo000O0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`0e0?ooo`007`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0=@3oool001l0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03@0oooo000O0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0d0?ooo`007`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=03oool0
01l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
03<0oooo000O0?ooo`030000003oool0oooo01P0oooo0P0000120?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03<0
oooo000O0?ooo`030000003oool0oooo01P0oooo0P0000120?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03<0oooo
000O0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0b0?ooo`007`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool0<P3oool001l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo0380oooo000O0?ooo`<00000603oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo0340oooo000O0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0a0?ooo`007`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0<03oool001l0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo0300oooo000O0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`007`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0;`3oool001l0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo04<0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo02l0oooo
000O0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`007`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool0;P3oool001l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`170?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo02h0oooo000O0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`0]0?ooo`007`3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0;@3oool001l0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo02`0oooo000O0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0/0?ooo`007`3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`170?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0;03oool001l0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo02/0
oooo000O0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0[0?ooo`007`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo04L0oooo00<0
00000?ooo`3oool0:P3oool001l0oooo0`00000H0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool0:P3oool001l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`170?oo
o`030000003oool0oooo02X0oooo000O0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`0Y0?ooo`007`3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo03`0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool0:@3oool001l0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0BP3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02P0oooo000O0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0X0?ooo`007`3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0:03oool001l0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo04X0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02L0
oooo000O0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0C@3oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`0W0?ooo`007`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool09P3oool001l0oooo00<000000?ooo`3oool05`3oool200000500oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool09P3oool001l0oooo00<000000?ooo`3oool05`3oool200000500oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool09P3oool001l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`1<0?ooo`03
0000003oool0oooo02D0oooo000O0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
D03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`0U0?ooo`007`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo0500oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool09@3oool00080oooo0P0000040?ooo`030000003oool0
oooo00<0oooo0P0000030?ooo`<000002@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0903oool000050?ooo`000000oooo0?ooo`000000203oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0903oool000050?ooo`00
0000oooo0?ooo`000000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0903oool000050?ooo`000000oooo0?ooo`000000203oool01@000000oooo0?ooo`000000
oooo00@000002@3oool4000001H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0S
0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`060000003oool0oooo0000003oool00000
303oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
8`3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo02<0oooo00020?ooo`8000002P3oool2000000@0oooo0P0000090?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1@0?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0R0?ooo`007`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool08P3o
ool001l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo0280oooo000O0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`0Q0?ooo`007`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool08@3oool001l0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo0240oooo000O0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool0DP3oool00`000000oooo0?ooo`0P0?ooo`007`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0803oool001l0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01l0oooo000O0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0O0?ooo`00
7`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
7`3oool001l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1D0?ooo`030000003o
ool0oooo01h0oooo000O0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`0N0?ooo`007`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool07@3oool001l0oooo0`00000G0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool07@3oool001l0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`1I0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo01d0oooo000O0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0F@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0L0?ooo`007`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0703oool001l0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01/0oooo000O0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo05T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0K0?ooo`00
7`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
6`3oool001l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1L0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo05T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01X0oooo000O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0J0?ooo`007`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
05d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool06P3oool001l0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`1M0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo01T0oooo000O0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0I0?ooo`007`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`1K0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool06@3oool001l0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0G03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01P0oooo000O0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0H0?oo
o`007`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0G03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool0603oool001l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1P0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo05`0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1K0?ooo`030000
003oool0oooo01L0oooo000O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`0G0?ooo`007`3oool3000001H0oooo00<000000?ooo`3oool0H03oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`1M0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`0G0?ooo`007`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
05d0oooo00<000000?ooo`3oool05P3oool001l0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`1Q0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`1M0?ooo`030000003oool0oooo01H0oooo000O0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0600oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0F0?ooo`007`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`1Q0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool05@3oool001l0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0H@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo05l0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo01D0oooo000O0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo0680oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1O0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0D0?oo
o`007`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0H03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3o
ool0503oool001l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1S0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo0640oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1O0?ooo`030000
003oool0oooo01@0oooo000O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0I03o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`0C0?ooo`007`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo0600oooo00<000000?ooo`3oool04`3oool001l0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`1T0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0I03oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`1Q0?ooo`030000003oool0oooo0180oooo000O0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06@0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0B0?ooo`007`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool04P3oool001l0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0140oooo000O
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0A
0?ooo`007`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0H`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06<0oooo00<000000?oo
o`3oool0403oool001l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1X0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo06@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo0100oooo000O0?ooo`<000005@3oool00`000000oooo0?ooo`1X0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1S0?ooo`030000
003oool0oooo0100oooo000O0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0I03o
ool00`000000oooo0?ooo`0?0?ooo`007`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo06T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool03`3oool001l0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`1Y0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`1T0?ooo`030000003oool0oooo00l0oooo000O0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06L0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`1X0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool03P3oool001l0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0J@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00h0oooo000O
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1W
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo06`0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06H0oooo00<000000?oo
o`3oool03@3oool001l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo06P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1V0?ooo`03
0000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
K03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
I`3oool00`000000oooo0?ooo`0<0?ooo`007`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1[0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo06P0oooo00<000000?ooo`3oool02`3oool001l0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`1^0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0J`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1f0?ooo`007`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
06l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
07H0oooo000O0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0K`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`1Z0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0MP3oool00080oooo
0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<000002@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`1/0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0JP3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo07H0oooo00001@3oool000000?ooo`3oool0000000P0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0K@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo06`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`1f0?ooo`0000D0oooo0000003oool0oooo000000080?oo
o`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`060?ooo`@000004`3o
ool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0K@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`1f0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003o
ool0oooo00000080oooo0`0000090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
MP3oool000050?ooo`000000oooo0?ooo`000000203oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool01P3oool2000001D0oooo00<000000?ooo`3oool0L@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`1]0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0MP3oool00005
0?ooo`000000oooo0?ooo`000000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<0
00000?ooo`3oool01P3oool2000001D0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`1]0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0MP3oool00080oooo0P00000:
0?ooo`8000000`3oool3000000T0oooo0P00000E0?ooo`030000003oool0oooo0780oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0KP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo07H0oooo000O0?oo
o`030000003oool0000001@0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo06l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1^0?oo
o`030000003oool0oooo01P0oooo0P00001h0?ooo`007`3oool00`000000oooo0000000D0?ooo`03
0000003oool0oooo07<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1`0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0H0?ooo`80
0000N03oool001l0oooo00@000000?ooo`3oool000004`3oool00`000000oooo0?ooo`1c0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo06l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1g0?ooo`00
7`3oool010000000oooo0?ooo`00000C0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0K`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo07L0oooo000O0?ooo`040000
003oool0oooo000001<0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0740oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1`0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0M`3oool001l0oooo00D000000?ooo`3oool0
oooo0000000B0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`1b0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo07L0oooo000O0?ooo`050000003oool0oooo0?ooo`00
00004P3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`1g0?ooo`007`3oool01@000000oooo0?ooo`3oool000000180
oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo07<0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0M`3oool001l0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0L@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo07L0oooo000O0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`1g0?ooo`007`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1b
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0M`3oool001l0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07H0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0140oooo0P00001d0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0M`3oool001l0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0140oooo0P00001d0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0M`3oool001l0oooo0`0000040?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo07H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0M`3oool001l0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo07L0oooo000O0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo07@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1g0?ooo`007`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`1e0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0M`3oool001l0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07X0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo07L0
oooo000O0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1j0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0N03oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`1g0?ooo`007`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0NP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0N03oool001l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo07P0oooo000O0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`1h0?ooo`007`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1g0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0N03oool001l0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07P0oooo000O0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1l0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1h0?ooo`007`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0OP3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0N03oool0
01l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
07h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
07P0oooo000O0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`1o0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0O03oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`1h0?ooo`007`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo07`0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0N03oool001l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`1m0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo07P0oooo000O0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0O@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo07/0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`1h0?ooo`007`3oool3000000/0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0O@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo07`0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`007`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0N03oool001l0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo07P0oooo000O0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool00P3oool2000008@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0O@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo07P0oooo000O0?ooo`030000003oool0
oooo00d0oooo00D000000?ooo`3oool0oooo000000250?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0P03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07d0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`1i0?ooo`007`3oool00`000000oooo0?ooo`0=
0?ooo`050000003oool0oooo0?ooo`000000Q@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0800oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0N@3oool001l0oooo00<000000?ooo`3oool03P3oool0
10000000oooo0000000000250?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`1i0?ooo`007`3oool00`000000oooo0?ooo`0>0?ooo`<00000Q`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0N@3oool0
01l0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0N@3oool001l0oooo00<000000?ooo`3oool0V@3oool01@000000
oooo0?ooo`3oool0000008D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`200?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0N@3oool001l0oooo00<000000?ooo`3o
ool0VP3oool010000000oooo0?ooo`0000250?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0P@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo07T0oooo000O0?ooo`03
0000003oool0oooo09X0oooo00@000000?ooo`0000000000QP3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0840oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1i0?oo
o`007`3oool00`000000oooo0?ooo`2J0?ooo`@00000QP3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0880oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1i0?ooo`00
7`3oool00`000000oooo0?ooo`3o0?ooobH0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`220?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0N@3oool001l0oooo00<0
00000?ooo`3oool0o`3ooolV0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0PP3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07X0oooo000O0?ooo`030000003oool0
oooo0?l0oooo9P3oool01@000000oooo0?ooo`3oool0000008H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1j0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooobL0oooo00@00000
0?ooo`3oool00000QP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07X0oooo000O
0?ooo`<00000o`3ooolX0?ooo`<00000Q`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo07X0oooo000O0?ooo`030000003oool0oooo0?l0oooo:@3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0NP3oool001l0oooo00<000000?ooo`3o
ool0o`3ooonb0?ooo`040000003oool0oooo0?ooo`800000O03oool001l0oooo00<000000?ooo`3o
ool0o`3ooonc0?ooo`040000003oool0oooo000007d0oooo000O0?ooo`030000003oool0oooo0?l0
oooo/`3oool2000000030?ooo`000000oooo07`0oooo000O0?ooo`030000003oool0oooo0?l0oooo
]03oool3000007d0oooo000O0?ooo`030000003oool0oooo0?l0oooo]@3oool00`000000oooo0?oo
o`1l0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooool0oooo=@3oool001l0oooo00<000000?oo
o`3oool0o`3ooooo0?ooocD0oooo000O0?ooo`030000003oool0oooo0?l0ooooo`3ooole0?ooo`00
7`3oool00`000000oooo0?ooo`3o0?ooool0oooo=@3oool001l0oooo00<000000?ooo`3oool0o`3o
oooo0?ooocD0oooo000O0?ooo`030000003oool0oooo0?l0ooooo`3ooole0?ooo`007`3oool00`00
0000oooo0?ooo`3o0?ooool0oooo=@3oool001l0oooo00<000000?ooo`3oool0o`3ooooo0?ooocD0
oooo003o0?ooool0ooooE`3oool00001\
\>"],
  ImageRangeCache->{{{0, 596.812}, {368.5, 0}} -> {18.9433, -0.00497857, \
0.00181235, 0.000282849}},
  CellTags->"Realistic Fresnel Lens Model"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot[10*First[surfacefunc[x,0]],{x,19.2,19.4},PlotPoints->200];\
\>\
", "Input",
  CellTags->"Realistic Fresnel Lens Model"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-149.102 7.74964 0.0147151 0.628764 [
[.00132 .00222 -15 -9 ]
[.00132 .00222 15 0 ]
[.15631 .00222 -15 -9 ]
[.15631 .00222 15 0 ]
[.31131 .00222 -15 -9 ]
[.31131 .00222 15 0 ]
[.62129 .00222 -15 -9 ]
[.62129 .00222 15 0 ]
[.77628 .00222 -15 -9 ]
[.77628 .00222 15 0 ]
[.93128 .00222 -15 -9 ]
[.93128 .00222 15 0 ]
[.4538 .14047 -18 -4.5 ]
[.4538 .14047 0 4.5 ]
[.4538 .26622 -18 -4.5 ]
[.4538 .26622 0 4.5 ]
[.4538 .39197 -18 -4.5 ]
[.4538 .39197 0 4.5 ]
[.4538 .51773 -18 -4.5 ]
[.4538 .51773 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00132 .01472 m
.00132 .02097 L
s
[(19.24)] .00132 .00222 0 1 Mshowa
.15631 .01472 m
.15631 .02097 L
s
[(19.26)] .15631 .00222 0 1 Mshowa
.31131 .01472 m
.31131 .02097 L
s
[(19.28)] .31131 .00222 0 1 Mshowa
.62129 .01472 m
.62129 .02097 L
s
[(19.32)] .62129 .00222 0 1 Mshowa
.77628 .01472 m
.77628 .02097 L
s
[(19.34)] .77628 .00222 0 1 Mshowa
.93128 .01472 m
.93128 .02097 L
s
[(19.36)] .93128 .00222 0 1 Mshowa
.125 Mabswid
.04007 .01472 m
.04007 .01847 L
s
.07882 .01472 m
.07882 .01847 L
s
.11757 .01472 m
.11757 .01847 L
s
.19506 .01472 m
.19506 .01847 L
s
.23381 .01472 m
.23381 .01847 L
s
.27256 .01472 m
.27256 .01847 L
s
.35005 .01472 m
.35005 .01847 L
s
.3888 .01472 m
.3888 .01847 L
s
.42755 .01472 m
.42755 .01847 L
s
.50505 .01472 m
.50505 .01847 L
s
.5438 .01472 m
.5438 .01847 L
s
.58254 .01472 m
.58254 .01847 L
s
.66004 .01472 m
.66004 .01847 L
s
.69879 .01472 m
.69879 .01847 L
s
.73754 .01472 m
.73754 .01847 L
s
.81503 .01472 m
.81503 .01847 L
s
.85378 .01472 m
.85378 .01847 L
s
.89253 .01472 m
.89253 .01847 L
s
.97003 .01472 m
.97003 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.4663 .14047 m
.47255 .14047 L
s
[(0.2)] .4538 .14047 1 0 Mshowa
.4663 .26622 m
.47255 .26622 L
s
[(0.4)] .4538 .26622 1 0 Mshowa
.4663 .39197 m
.47255 .39197 L
s
[(0.6)] .4538 .39197 1 0 Mshowa
.4663 .51773 m
.47255 .51773 L
s
[(0.8)] .4538 .51773 1 0 Mshowa
.125 Mabswid
.4663 .04615 m
.47005 .04615 L
s
.4663 .07759 m
.47005 .07759 L
s
.4663 .10903 m
.47005 .10903 L
s
.4663 .17191 m
.47005 .17191 L
s
.4663 .20334 m
.47005 .20334 L
s
.4663 .23478 m
.47005 .23478 L
s
.4663 .29766 m
.47005 .29766 L
s
.4663 .3291 m
.47005 .3291 L
s
.4663 .36054 m
.47005 .36054 L
s
.4663 .42341 m
.47005 .42341 L
s
.4663 .45485 m
.47005 .45485 L
s
.4663 .48629 m
.47005 .48629 L
s
.4663 .54916 m
.47005 .54916 L
s
.4663 .5806 m
.47005 .5806 L
s
.4663 .61204 m
.47005 .61204 L
s
.25 Mabswid
.4663 0 m
.4663 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .48871 m
.0027 .48959 L
.01085 .49223 L
.01869 .49477 L
.02624 .49722 L
.03428 .49982 L
.04201 .50233 L
.04945 .50474 L
.05736 .5073 L
.06498 .50977 L
.07308 .5124 L
.08089 .51493 L
.08839 .51737 L
.09638 .51996 L
.10407 .52245 L
.11224 .5251 L
.12012 .52765 L
.1277 .53011 L
.13575 .53273 L
.14351 .53524 L
.15098 .53766 L
.15892 .54024 L
.16657 .54272 L
.1747 .54536 L
.18253 .5479 L
.19006 .55035 L
.19808 .55295 L
.20579 .55545 L
.21321 .55786 L
.22111 .56042 L
.22872 .56289 L
.2368 .56552 L
.24459 .56805 L
.25208 .57048 L
.26005 .57307 L
.26772 .57556 L
.27588 .57821 L
.28374 .58076 L
.2913 .58321 L
.29934 .58582 L
.30708 .58834 L
.31453 .59076 L
.32246 .59333 L
.33009 .59543 L
.3382 .59766 L
.34601 .59961 L
.35353 .60122 L
.354 .60137 L
.35423 .60145 L
.35449 .601 L
Mistroke
.35463 .60104 L
.35477 .60109 L
.35503 .60117 L
.35553 .60133 L
.35649 .60165 L
.35697 .6018 L
.35741 .60194 L
.35764 .60202 L
.3579 .60147 L
.35815 .60155 L
.35843 .60164 L
.35936 .60195 L
.3599 .60212 L
.36048 .60231 L
.36076 .6024 L
.36103 .60249 L
.36127 .60256 L
.3614 .60187 L
.36153 .60191 L
.36252 .60223 L
.3636 .60258 L
.3641 .60274 L
.36437 .60283 L
.36462 .60291 L
.36484 .60211 L
.36507 .60219 L
.36556 .60235 L
.36654 .60267 L
.36702 .60283 L
.36747 .60297 L
.36787 .6031 L
.36808 .60317 L
.3683 .60223 L
.36853 .6023 L
.36877 .60238 L
.36921 .60253 L
.37012 .60282 L
.37109 .60314 L
.37138 .60323 L
.37152 .60328 L
.37165 .60332 L
.37189 .60223 L
.37202 .60227 L
.37216 .60231 L
.37315 .60263 L
.3741 .60294 L
.37462 .60311 L
.37488 .6032 L
.37512 .60328 L
.37526 .60197 L
Mistroke
.3754 .60202 L
.37571 .60211 L
.37624 .60229 L
.37729 .60263 L
.3778 .6028 L
.37808 .60289 L
.37835 .60297 L
.37857 .60304 L
.37881 .60157 L
.37894 .60161 L
.37907 .60165 L
.37932 .60173 L
.38045 .6021 L
.38095 .60226 L
.3815 .60244 L
.38173 .60252 L
.38198 .6026 L
.38221 .60267 L
.38242 .60096 L
.38266 .60104 L
.38293 .60113 L
.3834 .60128 L
.38446 .60163 L
.38499 .60179 L
.38521 .60187 L
.38547 .60195 L
.38571 .6 L
.38594 .60007 L
.38644 .60024 L
.38749 .60058 L
.38837 .60087 L
.38863 .60095 L
.38887 .60103 L
.38909 .6011 L
.38932 .59887 L
.38958 .59895 L
.38982 .59903 L
.39036 .5992 L
.39146 .59956 L
.39193 .59971 L
.39241 .59987 L
.39267 .59995 L
.39281 .59739 L
.39295 .59743 L
.39344 .59759 L
.39443 .59792 L
.39495 .59808 L
.3955 .59826 L
.39574 .59834 L
.39599 .59842 L
Mistroke
.39613 .59847 L
.39626 .59557 L
.39652 .59565 L
.39745 .59596 L
.39835 .59625 L
.39882 .5964 L
.39908 .59648 L
.39932 .59656 L
.39956 .59664 L
.39981 .59342 L
.40004 .59349 L
.40025 .59356 L
.4011 .59384 L
.40203 .59414 L
.40253 .59431 L
.40278 .59439 L
.40302 .59446 L
.40323 .59084 L
.40346 .59092 L
.40395 .59107 L
.4048 .59135 L
.40528 .59151 L
.4058 .59167 L
.40604 .59175 L
.40628 .59183 L
.4065 .5919 L
.40673 .58787 L
.40688 .58792 L
.40701 .58796 L
.40726 .58804 L
.40783 .58823 L
.40886 .58856 L
.4093 .5887 L
.40977 .58886 L
.40991 .5889 L
.41004 .58894 L
.41029 .58447 L
.41052 .58454 L
.41077 .58463 L
.41175 .58494 L
.41229 .58512 L
.41279 .58528 L
.41322 .58542 L
.41347 .5855 L
.41369 .58054 L
.41392 .58062 L
.41417 .5807 L
.41467 .58086 L
.41551 .58113 L
.41642 .58143 L
Mistroke
.41668 .58151 L
.41682 .58156 L
.41696 .5816 L
.41719 .57615 L
.41732 .57619 L
.41745 .57623 L
.41843 .57655 L
.4193 .57683 L
.41977 .57698 L
.42026 .57714 L
.42041 .57719 L
.42056 .57724 L
.42069 .57122 L
.42083 .57127 L
.42136 .57144 L
.42241 .57178 L
.4229 .57194 L
.42343 .57211 L
.42365 .57218 L
.42388 .57226 L
.42413 .56573 L
.42437 .5658 L
.42637 .56645 L
.42691 .56663 L
.42721 .56673 L
.42736 .56678 L
.4275 .56682 L
.42773 .55971 L
.42799 .5598 L
.42854 .55997 L
.42954 .5603 L
.43046 .5606 L
.4307 .56068 L
.43093 .56075 L
.43106 .55301 L
.43119 .55306 L
.43143 .55314 L
.43249 .55348 L
.43338 .55377 L
.43388 .55393 L
.43412 .55401 L
.43435 .55408 L
.43448 .55413 L
.43461 .54579 L
.43476 .54584 L
.4349 .54588 L
.4354 .54605 L
.43639 .54637 L
.43741 .5467 L
.43769 .54679 L
Mistroke
.43785 .54684 L
.43799 .54689 L
.43824 .53797 L
.43838 .53802 L
.43852 .53806 L
.43949 .53838 L
.44052 .53871 L
.44102 .53887 L
.44115 .53892 L
.4413 .53897 L
.44144 .53901 L
.44156 .52943 L
.4418 .52951 L
.44206 .52959 L
.44252 .52974 L
.44358 .53009 L
.44415 .53027 L
.44444 .53037 L
.4447 .53045 L
.44495 .53053 L
.44508 .52033 L
.44522 .52038 L
.44577 .52056 L
.44675 .52088 L
.44722 .52103 L
.44773 .5212 L
.44798 .52128 L
.44821 .52135 L
.44842 .52142 L
.44865 .51063 L
.44889 .51071 L
.44911 .51078 L
.4496 .51094 L
.45049 .51123 L
.45101 .5114 L
.45148 .51155 L
.45173 .51163 L
.45198 .50024 L
.45213 .50029 L
.45227 .50034 L
.45253 .50042 L
.45349 .50073 L
.45451 .50106 L
.45504 .50124 L
.45518 .50128 L
.45534 .50133 L
.45549 .48931 L
.45562 .48936 L
.45665 .48969 L
.45759 .49 L
Mistroke
.4581 .49016 L
.45835 .49025 L
.45859 .49032 L
.45881 .49039 L
.45904 .47782 L
.45927 .4779 L
.45953 .47798 L
.46038 .47826 L
.4614 .47859 L
.46169 .47869 L
.46197 .47878 L
.46222 .47886 L
.46236 .4789 L
.46249 .46575 L
.46272 .46583 L
.46294 .4659 L
.46344 .46606 L
.46445 .46639 L
.46537 .46669 L
.46563 .46677 L
.46577 .46682 L
.4659 .46686 L
.46615 .45323 L
.46638 .45331 L
.46744 .45365 L
.46842 .45397 L
.46885 .45411 L
.46907 .45418 L
.46926 .45425 L
.46947 .44012 L
.46969 .44019 L
.47016 .44035 L
.47115 .44067 L
.47205 .44096 L
.47228 .44104 L
.47253 .44112 L
.47277 .4412 L
.47299 .42664 L
.47322 .42671 L
.47348 .4268 L
.47399 .42696 L
.47493 .42727 L
.47579 .42755 L
.47604 .42763 L
.47617 .42767 L
.47631 .42772 L
.47657 .41278 L
.4768 .41286 L
.47789 .41322 L
.47892 .41355 L
Mistroke
.47941 .41371 L
.47964 .41378 L
.47986 .41385 L
.48008 .39857 L
.48031 .39865 L
.4808 .39881 L
.4817 .3991 L
.4822 .39926 L
.48273 .39943 L
.48297 .39951 L
.48323 .39959 L
.48345 .38403 L
.48369 .38411 L
.48459 .3844 L
.48555 .38471 L
.48601 .38486 L
.48624 .38494 L
.48646 .385 L
.48665 .38507 L
.48685 .36927 L
.48706 .36934 L
.48728 .36941 L
.48825 .36972 L
.48926 .37006 L
.48968 .37019 L
.48991 .37027 L
.49013 .37034 L
.49039 .3544 L
.49062 .35447 L
.49108 .35462 L
.49203 .35493 L
.49304 .35526 L
.4933 .35534 L
.49357 .35543 L
.49373 .35548 L
.49387 .33941 L
.49401 .33946 L
.49415 .3395 L
.49517 .33983 L
.49614 .34015 L
.49662 .3403 L
.49683 .34037 L
.49706 .34045 L
.49731 .32437 L
.49744 .32441 L
.49757 .32446 L
.49811 .32463 L
.49907 .32494 L
.49954 .3251 L
.49998 .32524 L
Mistroke
.50038 .32537 L
.5006 .32544 L
.50081 .30939 L
.50103 .30946 L
.50124 .30953 L
.50172 .30968 L
.50268 .31 L
.5036 .3103 L
.50386 .31038 L
.504 .31043 L
.50413 .31047 L
.50438 .29453 L
.50461 .2946 L
.50567 .29495 L
.50665 .29526 L
.50709 .29541 L
.50749 .29554 L
.5077 .29561 L
.50792 .27982 L
.50817 .2799 L
.50839 .27997 L
.51028 .28058 L
.51077 .28074 L
.511 .28082 L
.51122 .28089 L
.51145 .26533 L
.5117 .26541 L
.51222 .26558 L
.51315 .26588 L
.51402 .26616 L
.51426 .26624 L
.51448 .26631 L
.51474 .25104 L
.51497 .25111 L
.516 .25145 L
.517 .25177 L
.51753 .25195 L
.51782 .25204 L
.51796 .25209 L
.51809 .25213 L
.51834 .23719 L
.51847 .23723 L
.51861 .23728 L
.51908 .23743 L
.52 .23773 L
.52054 .23791 L
.52106 .23808 L
.52128 .23815 L
.52152 .23823 L
.52164 .23827 L
Mistroke
.52178 .22368 L
.52202 .22376 L
.52292 .22405 L
.52389 .22437 L
.52436 .22452 L
.52459 .2246 L
.5248 .22467 L
.525 .22473 L
.5252 .2106 L
.52541 .21067 L
.52564 .21075 L
.5266 .21106 L
.52762 .21139 L
.52804 .21153 L
.52827 .2116 L
.52849 .21167 L
.52874 .19805 L
.52898 .19812 L
.52944 .19827 L
.53039 .19858 L
.5314 .19891 L
.53166 .19899 L
.53193 .19908 L
.53209 .19913 L
.53223 .18599 L
.53237 .18603 L
.53251 .18608 L
.53353 .18641 L
.5345 .18673 L
.53498 .18688 L
.53519 .18695 L
.53542 .18703 L
.53567 .17446 L
.5358 .17451 L
.53593 .17455 L
.53647 .17472 L
.53743 .17504 L
.5379 .17519 L
.53834 .17533 L
.53874 .17546 L
.53896 .17554 L
.53917 .16353 L
.5394 .16361 L
.5396 .16368 L
.54008 .16383 L
.54104 .16414 L
.54201 .16446 L
.54228 .16455 L
.54243 .16459 L
.54256 .16464 L
Mistroke
.54269 .15321 L
.54283 .15325 L
.54308 .15333 L
.54402 .15364 L
.54501 .15396 L
.54545 .1541 L
.54569 .15418 L
.54591 .15426 L
.54604 .1543 L
.54618 .14348 L
.54643 .14356 L
.5469 .14372 L
.54865 .14428 L
.5491 .14443 L
.54934 .14451 L
.5496 .14459 L
.54982 .13442 L
.55006 .1345 L
.55049 .13464 L
.55156 .13499 L
.55253 .1353 L
.55278 .13539 L
.55291 .13543 L
.55306 .13548 L
.55318 .1259 L
.55332 .12594 L
.55356 .12602 L
.55466 .12638 L
.55516 .12654 L
.55569 .12671 L
.55594 .1268 L
.55619 .12688 L
.55641 .12695 L
.55665 .11803 L
.55677 .11807 L
.55691 .11811 L
.55715 .11819 L
.55769 .11837 L
.55868 .11869 L
.55955 .11897 L
.55979 .11905 L
.56005 .11913 L
.56029 .11083 L
.56051 .1109 L
.56153 .11123 L
.56206 .11141 L
.56263 .11159 L
.56312 .11175 L
.56326 .1118 L
.56341 .11184 L
Mistroke
.56354 .11189 L
.56367 .10415 L
.56389 .10423 L
.56414 .10431 L
.56463 .10447 L
.56567 .10481 L
.56618 .10497 L
.56641 .10504 L
.56665 .10512 L
.56687 .1052 L
.56708 .09808 L
.5673 .09815 L
.56753 .09822 L
.56849 .09853 L
.56901 .09871 L
.56959 .09889 L
.56985 .09898 L
.57013 .09907 L
.57037 .09915 L
.57051 .09919 L
.57064 .09262 L
.57088 .0927 L
.57113 .09278 L
.57158 .09293 L
.5726 .09326 L
.5731 .09342 L
.57358 .09358 L
.57379 .09365 L
.57401 .09372 L
.57425 .08773 L
.57447 .08781 L
.5755 .08814 L
.57647 .08846 L
.57689 .08859 L
.5771 .08866 L
.57729 .08873 L
.57752 .08326 L
.57776 .08334 L
.57818 .08348 L
.57917 .0838 L
.58007 .08409 L
.58055 .08425 L
.5808 .08433 L
.58094 .08438 L
.58107 .07939 L
.58121 .07943 L
.58134 .07948 L
.58159 .07956 L
.58214 .07974 L
.58316 .08007 L
Mistroke
.58361 .08021 L
.58384 .08029 L
.5841 .08037 L
.58433 .08045 L
.58454 .07596 L
.58474 .07603 L
.58495 .07609 L
.58585 .07639 L
.58684 .07671 L
.58732 .07687 L
.58752 .07693 L
.58775 .07701 L
.58798 .07297 L
.58821 .07305 L
.58871 .07321 L
.58962 .07351 L
.59012 .07367 L
.59066 .07384 L
.59092 .07393 L
.59116 .07401 L
.59138 .07408 L
.59163 .07047 L
.59187 .07055 L
.5921 .07062 L
.59253 .07076 L
.5935 .07108 L
.59433 .07135 L
.59456 .07142 L
.5948 .0715 L
.59501 .06827 L
.59523 .06834 L
.59626 .06867 L
.59724 .06899 L
.59766 .06913 L
.59812 .06928 L
.59835 .06935 L
.59861 .0665 L
.59885 .06657 L
.59907 .06665 L
.60003 .06696 L
.60105 .06729 L
.60158 .06746 L
.60172 .06751 L
.60188 .06756 L
.60202 .065 L
.60216 .06504 L
.60318 .06537 L
.60413 .06568 L
.60465 .06585 L
.60491 .06594 L
Mistroke
.60514 .06601 L
.60535 .06608 L
.60556 .06384 L
.60577 .06391 L
.606 .06399 L
.60695 .06429 L
.60798 .06463 L
.6085 .0648 L
.60864 .06484 L
.60879 .06489 L
.60894 .06291 L
.60907 .06295 L
.61002 .06326 L
.61103 .06359 L
.61155 .06376 L
.61181 .06384 L
.61204 .06392 L
.61225 .06399 L
.61248 .06228 L
.61271 .06236 L
.61296 .06244 L
.61474 .06302 L
.61526 .06319 L
.61552 .06327 L
.61575 .06335 L
.61589 .06184 L
.61603 .06188 L
.61632 .06198 L
.61684 .06215 L
.6178 .06246 L
.61881 .06279 L
.61905 .06287 L
.61918 .06291 L
.61931 .06295 L
.61946 .06165 L
.61959 .06169 L
.61986 .06178 L
.62083 .06209 L
.62187 .06243 L
.62216 .06253 L
.62246 .06263 L
.62259 .06267 L
.62272 .06271 L
.62287 .06159 L
.62301 .06163 L
.62402 .06196 L
.62508 .06231 L
.62552 .06245 L
.62598 .0626 L
.62612 .06265 L
Mistroke
.62625 .06269 L
.62649 .06176 L
.62672 .06183 L
.62697 .06191 L
.62787 .06221 L
.62883 .06252 L
.62911 .06261 L
.62938 .0627 L
.62962 .06278 L
.62976 .06282 L
.62989 .062 L
.63014 .06208 L
.63037 .06215 L
.63088 .06232 L
.6319 .06265 L
.63244 .06283 L
.63273 .06292 L
.633 .06301 L
.63325 .06309 L
.6335 .06243 L
.63365 .06248 L
.63379 .06252 L
.63405 .06261 L
.63501 .06292 L
.63591 .06321 L
.63616 .0633 L
.63643 .06338 L
.63668 .06346 L
.63691 .06291 L
.63717 .06299 L
.6374 .06307 L
.63794 .06324 L
.63893 .06356 L
.6394 .06372 L
.63984 .06386 L
.64004 .06393 L
.64024 .06399 L
.64047 .06353 L
.64068 .0636 L
.64165 .06392 L
.64254 .06421 L
.643 .06435 L
.64324 .06443 L
.6435 .06452 L
.64372 .06459 L
.64397 .06422 L
.64419 .06429 L
.6444 .06436 L
.64544 .0647 L
.6464 .06501 L
Mistroke
.64683 .06515 L
.64705 .06522 L
.64724 .06528 L
.64745 .06497 L
.64766 .06504 L
.64813 .06519 L
.65 .0658 L
.65376 .0667 L
.65784 .06754 L
.66587 .06982 L
.6736 .07211 L
.68104 .07453 L
.68895 .07711 L
.69657 .07959 L
.70467 .08223 L
.71247 .08477 L
.71998 .08722 L
.72796 .08982 L
.73565 .09233 L
.74382 .09499 L
.75169 .09756 L
.75927 .10003 L
.76732 .10265 L
.77508 .10518 L
.78254 .10761 L
.79049 .1102 L
.79813 .1127 L
.80626 .11535 L
.81409 .1179 L
.82162 .12036 L
.82963 .12297 L
.83735 .12548 L
.84476 .1279 L
.85266 .13048 L
.86027 .13296 L
.86835 .1356 L
.87613 .13814 L
.88362 .14058 L
.89159 .14318 L
.89926 .14568 L
.90742 .14835 L
.91527 .15091 L
.92283 .15338 L
.93087 .156 L
.93861 .15853 L
.94606 .16096 L
.95398 .16354 L
.96161 .16603 L
.96972 .16868 L
.97753 .17123 L
Mistroke
.98505 .17369 L
.99304 .1763 L
Mfstroke
.99304 .1763 m
1 .17857 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{562.125, 347.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008b0001Fb000`400?l00000o`00003oo`3ooooo
0?oooc@0oooo0000103oool000000000000000030?ooo`8000001@3oool010000000oooo0?ooo`3o
ool5000000<0oooo0`00000h0?ooo`<000000`3oool2000000D0oooo00@000000?ooo`3oool0oooo
1@0000020?ooo`<00000>P3oool3000000<0oooo0P0000050?ooo`040000003oool0oooo0?ooo`D0
00000P3oool3000008l0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`<0
00000P3oool5000003P0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`<0
0000103oool3000003T0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`<0
00000`3oool3000001X0oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`070?ooo`060000003oool0oooo0000003oool000000`3oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo000003T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`0G0?ooo`000P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo00@000000?ooo`3oool0oooo1@00000i0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000>`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000001000000j0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo000000030?ooo`030000003oool0
oooo01L0oooo00020?ooo`030000003oool0oooo0080oooo1000000:0?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`020?ooo`@000002P3oool0
0`000000oooo0?ooo`04000003/0oooo00<000000?ooo`3oool00P3oool4000000X0oooo00@00000
0?ooo`3oool0oooo0`00002@0?ooo`030000003oool0oooo0080oooo100000090?ooo`8000001@3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo100000090?ooo`8000000P3o
ool010000000oooo0?ooo`00000k0?ooo`030000003oool0oooo0080oooo100000090?ooo`800000
0P3oool4000001X0oooo00020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0000000j0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`070000003oool0oooo
0?ooo`000000oooo0000000n0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`050?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo
08d0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`0g0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`090?ooo`060000003oool0oooo0000003oool00000>`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000M0?oo
o`0000<0oooo0000000000000`3oool01@000000oooo0?ooo`3oool0000000L0oooo00D000000?oo
o`3oool0oooo000000030?ooo`800000>@3oool2000000<0oooo00D000000?ooo`3oool0oooo0000
00070?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0j0?ooo`800000
0`3oool01@000000oooo0?ooo`3oool0000000L0oooo00L000000?ooo`3oool0oooo0000003oool0
000000<0oooo00<000000?ooo`3oool0S03oool2000000<0oooo00D000000?ooo`3oool0oooo0000
00070?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo03H0
oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0
000000<0oooo0P00000j0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000L0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01X0oooo00020?ooo`030000003o
ool0oooo0080oooo0`0000090?ooo`<000001@3oool00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo0080oooo0`0000090?ooo`<00000103oool2000003/0oooo00<000000?ooo`3oool00P3o
ool3000000T0oooo0`0000030?ooo`<00000T03oool00`000000oooo0?ooo`020?ooo`<000002@3o
ool3000000<0oooo0`00000j0?ooo`030000003oool0oooo0080oooo0`0000090?ooo`<000001@3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0080oooo0`0000090?ooo`<00000103o
ool2000001X0oooo003o0?ooo`h0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3oool>0?oo
o`030000003oool0oooo0?l0oooo8`3oool00?l0oooo3P3oool00`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooo`h0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3oool>0?ooo`030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo3P3oool00`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
o`h0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3oool>0?ooo`030000003oool0oooo0?l0
oooo8`3oool000h0ooooo`00003o000002H00000000?0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool03`3oool000l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0?
0?ooo`003`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool0DP3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0540oooo00<000000?oo
o`3oool0DP3oool00`000000oooo0?ooo`0T0?ooo`003`3oool00`000000oooo0?ooo`1A0?ooo`03
0000003oool0oooo0580oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0T0?ooo`00
o`3oool>0?ooo`030000003oool0oooo0?l0oooo8`3oool00?l0oooo3P3oool00`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooo`h0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3oool>0?oo
o`030000003oool0oooo0?l0oooo8`3oool00?l0oooo3P3oool00`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooo`h0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3oool>0?ooo`030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo3P3oool00`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
o`h0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3oool>0?ooo`030000003oool0oooo0?l0
oooo8`3oool00?l0oooo3P3oool00`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooo`h0oooo00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3oool>0?ooo`<00000o`3ooolS0?ooo`00o`3oool>0?oo
o`030000003oool0oooo0?l0oooo8`3oool00?l0oooo3P3oool00`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooo`h0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3oool>0?ooo`030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo3P3oool00`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
o`h0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3oool>0?ooo`030000003oool0oooo0?l0
oooo8`3oool00?l0oooo3P3oool00`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooo`h0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0000000:00000<P0oooo003o0?ooo`h0oooo00<00000
0?ooo`3oool0B@3oool8000000D0oooo00<000000?ooo`0000001P0000330?ooo`00o`3oool>0?oo
o`030000003oool0oooo04L0oooo1@00000B0?ooo`D00000_`3oool00?l0oooo3P3oool00`000000
oooo0?ooo`150?ooo`<000006`3oool600000;T0oooo003o0?ooo`h0oooo00<000000?ooo`3oool0
@`3oool3000002<0oooo0`00002f0?ooo`00o`3oool>0?ooo`030000003oool0oooo0440oooo0`00
000X0?ooo`800000]03oool00?l0oooo3P3oool00`000000oooo0?ooo`0o0?ooo`<00000;03oool3
00000;40oooo003o0?ooo`h0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0000000_0?oo
o`D00000[03oool00?l0oooo3P3oool00`000000oooo0?ooo`0m0?ooo`<00000=P3oool300000:T0
oooo003o0?ooo`h0oooo0`00000m0?ooo`030000003oool0oooo03T0oooo0P00002W0?ooo`00o`3o
ool>0?ooo`030000003oool0oooo03`0oooo0P00000m0?ooo`<00000Y03oool00?l0oooo3P3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03l0oooo0`00002Q0?ooo`00o`3oool>0?oo
o`030000003oool0oooo03X0oooo0P0000150?ooo`800000W`3oool00?l0oooo3P3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo04H0oooo0`00002L0?ooo`00o`3oool>0?ooo`030000
003oool0oooo03P0oooo0P00001<0?ooo`D00000U`3oool00?l0oooo3P3oool00`000000oooo0?oo
o`0h0?ooo`800000D@3oool3000009@0oooo003o0?ooo`h0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`1C0?ooo`800000TP3oool00?l0oooo3P3oool00`000000oooo0?ooo`0f0?oo
o`<00000E`3oool4000008h0oooo003o0?ooo`h0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`1K0?ooo`<00000R`3oool00?l0oooo3P3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo05h0oooo0P0000290?ooo`00o`3oool>0?ooo`030000003oool0oooo03@0oooo0`00
001R0?ooo`<00000QP3oool00?l0oooo3P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo06D0oooo100000220?ooo`00o`3oool>0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0J@3oool3000007l0oooo003o0?ooo`h0oooo00<000000?ooo`3oool0<P3oool3000006h0
oooo0`00001l0?ooo`00o`3oool>0?ooo`030000003oool0oooo0380oooo0`00001a0?ooo`<00000
N@3oool00?l0oooo3P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo07@0oooo1000
001e0?ooo`00o`3oool>0?ooo`<00000<P3oool00`000000oooo0?ooo`1h0?ooo`<00000LP3oool0
0?l0oooo3P3oool00`000000oooo0?ooo`0`0?ooo`<00000O@3oool200000700oooo003o0?ooo`h0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1o0?ooo`@00000K03oool00?l0oooo
3P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo08<0oooo0`00001Y0?ooo`00o`3o
ool>0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0QP3oool2000006L0oooo003o
0?ooo`h0oooo00<000000?ooo`3oool0;P3oool3000008X0oooo0`00001T0?ooo`00o`3oool>0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0S@3oool400000600oooo003o0?ooo`h0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2A0?ooo`<00000G@3oool00?l0oooo
3P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo09@0oooo0`00001J0?ooo`00o`3o
ool>0?ooo`030000003oool0oooo02`0oooo0`00002I0?ooo`<00000E`3oool00?l0oooo3P3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0000009`0oooo0`00001D0?ooo`00o`3oool>0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0W`3oool200000580oooo003o0?ooo`h0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`2Q0?ooo`<00000C`3oool00?l0oooo
3P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0:@0oooo1@00001:0?ooo`00o`3o
ool>0?ooo`030000003oool0oooo02X0oooo0`00002[0?ooo`<00000A`3oool00?H0oooo0P000004
0?ooo`040000003oool0oooo0?ooo`D00000203oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo0:h0oooo0P0000150?ooo`00m@3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2`0?ooo`<00000
@P3oool00?D0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`080?ooo`@00000
:@3oool00`000000oooo0?ooo`2c0?ooo`@00000?P3oool00?D0oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
]`3oool3000003/0oooo003e0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0
oooo000000080?ooo`030000003oool0oooo02P0oooo0`00002l0?ooo`<00000>03oool00?D0oooo
00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`2o0?ooo`<00000=@3oool00?H0oooo0P0000090?ooo`<0
00002@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0<80oooo0`00000b0?ooo`00
o`3oool>0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0a@3oool200000300oooo
003o0?ooo`h0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`370?ooo`<00000;@3o
ool00?l0oooo3P3oool00`000000oooo0?ooo`0W0?ooo`800000c03oool5000002P0oooo003o0?oo
o`h0oooo00<000000?ooo`3oool09`3oool200000=40oooo0`00000U0?ooo`00o`3oool>0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0d`3oool2000002<0oooo003o0?ooo`h0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3E0?ooo`<00000803oool00?l0oooo3P3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0=T0oooo0`00000M0?ooo`00o`3oool>
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0g03oool2000001/0oooo003o0?oo
o`h0oooo00<000000?ooo`3oool09@3oool200000>00oooo1000000G0?ooo`00o`3oool>0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0h`3oool4000001<0oooo003o0?ooo`h0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3W0?ooo`<00000403oool00?l0oooo3P3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0>X0oooo0P00000>0?ooo`00o`3oool>
0?ooo`<000009@3oool00`000000oooo0?ooo`3/0?ooo`<000002`3oool00?l0oooo3P3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo0>l0oooo0`0000080?ooo`00o`3oool>0?ooo`03
0000003oool0oooo02<0oooo0`00003d0?ooo`<000001@3oool00?l0oooo3P3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo0?L0oooo0`0000020?ooo`00o`3oool>0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0nP3oool200000000o`3oool>0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0o03oool00?l0oooo3P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0?`0oooo003o0?ooo`h0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`3l0?ooo`00o`3oool>0?ooo`030000003oool0oooo0240oooo0`00003n0?ooo`00o`3o
ool>0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0oP3oool00?l0oooo3P3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?h0oooo003o0?ooo`h0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`3n0?ooo`00o`3oool>0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0oP3oool00?l0oooo3P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0?h0oooo003o0?ooo`h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0000
003o0?ooo`40oooo003o0?ooo`h0oooo00<000000?ooo`3oool07`3oool300000?l0oooo0@3oool0
0?l0oooo3P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0oooo0@3oool00?l0
oooo3P3oool3000001l0oooo00<000000?ooo`3oool0o`3oool10?ooo`00o`3oool>0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0o`3oool10?ooo`00o`3oool>0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0o`3oool10?ooo`00o`3oool>0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0o`3oool10?ooo`00o`3oool>0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`000000o`3oool30?ooo`00o`3oool>0?ooo`030000003oool0oooo01d0
oooo0`00003o0?ooo`<0oooo003o0?ooo`h0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo003o0?ooo`h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`3o0?ooo`<0oooo003o0?ooo`h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo003o0?ooo`h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?oo
o`<0oooo003o0?ooo`h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo003o0?ooo`h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
003o0?ooo`h0oooo00<000000?ooo`3oool06`3oool300000?l0oooo1@3oool00?l0oooo3P3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0oooo1@3oool00?l0oooo3P3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0oooo1@3oool00?l0oooo3P3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0oooo1@3oool00?l0oooo3P3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo0?l0oooo1@3oool00?l0oooo3P3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo0?l0oooo1@3oool00?l0oooo3P3oool3000001/0oooo00<00000
0?ooo`3oool0o`3oool50?ooo`00o`3oool>0?ooo`030000003oool0oooo01T0oooo0`00003o0?oo
o`L0oooo003o0?ooo`h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?ooo`L0
oooo003o0?ooo`h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo
003o0?ooo`h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo003o
0?ooo`h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo003o0?oo
o`h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo003o0?ooo`h0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo003o0?ooo`h0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0000003o0?ooo`T0oooo003o0?ooo`h0oooo00<0
00000?ooo`3oool05`3oool300000?l0oooo2@3oool00?l0oooo3P3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0?l0oooo2@3oool00?l0oooo3P3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo0?l0oooo2@3oool00?l0oooo3P3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo0?l0oooo2@3oool00?l0oooo3P3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo0?l0oooo2@3oool00?H0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0`00
00080?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0o`3oool90?ooo`00m@3oool0
10000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`3o0?ooo`T0oooo003e0?ooo`040000003oool0oooo000000L0oooo1@00
00080?ooo`030000003oool0oooo01D0oooo0`00003o0?ooo`/0oooo003e0?ooo`040000003oool0
oooo000000L0oooo00@000000?ooo`3oool000002@3oool4000001@0oooo0`00003o0?ooo`/0oooo
003e0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`0000002@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0?l0oooo2`3oool00?D0oooo00@000000?ooo`3oool00000
2@3oool2000000T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3o0?ooo`/0oooo
003f0?ooo`8000002`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0o`3oool;0?ooo`00o`3oool>0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0o`3oool;0?ooo`00o`3oool>0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0o`3oool;0?ooo`00o`3oool>0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0o`3oool;0?ooo`00o`3oool>0?ooo`030000003oool0oooo01@0oooo0P00003o0?ooo`d0oooo
003o0?ooo`h0oooo00<000000?ooo`3oool0503oool200000?l0oooo3@3oool00?l0oooo3P3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo303oool00?l0oooo3P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo303oool00?l0oooo3P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo303oool00?l0oooo3P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0?l0oooo3@3oool00?l0oooo3P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo0?l0oooo3@3oool00?l0oooo3P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0?l0oooo3@3oool00?l0oooo3P3oool00`000000oooo0?ooo`0B0?oo
o`800000o`3oool?0?ooo`00o`3oool>0?ooo`030000003oool0oooo0180oooo0P00003o0?ooo`l0
oooo003o0?ooo`h0oooo0`00000B0?ooo`030000003oool0oooo0?l0oooo3P3oool00?l0oooo3P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0oooo3P3oool00?l0oooo3P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0oooo3P3oool00?l0oooo3P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0oooo3`3oool00?l0oooo3P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0oooo3`3oool00?l0oooo3P3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0?l0oooo3`3oool00?l0oooo3P3oool00`000000oooo0?oo
o`0@0?ooo`800000o`3ooolA0?ooo`00o`3oool>0?ooo`030000003oool0oooo0100oooo0P00003o
0?oooa40oooo003o0?ooo`h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?oo
oa00oooo003o0?ooo`h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?oooa00
oooo003o0?ooo`h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?oooa00oooo
003o0?ooo`h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?oooa00oooo003o
0?ooo`h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?oooa00oooo003o0?oo
o`h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?oooa00oooo003o0?ooo`h0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?oooa00oooo003o0?ooo`h0oooo
00<000000?ooo`3oool03P3oool300000?l0oooo4P3oool00?l0oooo3P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0?l0oooo4P3oool00?l0oooo3P3oool3000000h0oooo00<00000
0?ooo`3oool0o`3ooolB0?ooo`00o`3oool>0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0o`3ooolB0?ooo`00o`3oool>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0o`3ooolB0?ooo`00o`3oool>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
o`3ooolB0?ooo`00o`3oool>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3o
oolB0?ooo`00o`3oool>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooolB
0?ooo`00o`3oool>0?ooo`030000003oool0oooo00`0oooo0`00003o0?oooa@0oooo003o0?ooo`h0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?oooa@0oooo003o0?ooo`h0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?oooa@0oooo003o0?ooo`h0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?oooa@0oooo003o0?ooo`h0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`3o0?oooa@0oooo003o0?ooo`h0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`3o0?oooa@0oooo003o0?ooo`h0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`3o0?oooa@0oooo003o0?ooo`h0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`3o0?oooa@0oooo003o0?ooo`h0oooo00<000000?ooo`3oool02P3o
ool300000?l0oooo5P3oool00?l0oooo3P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
00000?l0oooo5P3oool00?l0oooo3P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0?l0oooo5P3oool00?l0oooo3P3oool3000000X0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00
o`3oool>0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00o`3o
ool>0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00o`3oool>
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00o`3oool>0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00o`3oool>0?ooo`03
0000003oool0oooo00P0oooo0`00003o0?oooaP0oooo003o0?ooo`h0oooo00<000000?ooo`3oool0
203oool300000?l0oooo603oool00?l0oooo3P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0?l0oooo603oool00?l0oooo3P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0?l0oooo603oool00?l0oooo3P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0?l0oooo603oool00?l0oooo3P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0
oooo603oool00?l0oooo3P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo
603oool00?l0oooo3P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo603o
ool00?l0oooo3P3oool00`000000oooo0?ooo`060?ooo`<00000o`3ooolJ0?ooo`00o`3oool>0?oo
o`030000003oool0oooo00H0oooo0`00003o0?oooaX0oooo003f0?ooo`800000103oool00`000000
oooo0?ooo`020?ooo`<000002@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0
oooo6P3oool00?D0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool00000
00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?oooaX0oooo003e0?ooo`04
0000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`00m@3oool010000000oooo0?ooo`000007
0?ooo`@000002@3oool4000000D0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`00m@3oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`3o0?oooaX0oooo003e0?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo6P3oool0
0?H0oooo0P00000:0?ooo`8000002@3oool00`000000oooo0?ooo`040?ooo`<00000o`3ooolL0?oo
o`00o`3oool>0?ooo`030000003oool0oooo00@0oooo0`00003o0?oooa`0oooo003o0?ooo`h0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooa`0oooo003o0?ooo`h0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooa`0oooo003o0?ooo`h0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooa`0oooo003o0?ooo`h0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`3o0?oooa`0oooo003o0?ooo`h0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`3o0?oooa`0oooo003o0?ooo`h0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`3o0?oooa`0oooo003o0?ooo`h0oooo00<000000?ooo`3oool00P3o
ool300000?l0oooo7P3oool00?l0oooo3P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
00000?l0oooo7P3oool00?l0oooo3P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0?l0oooo7P3oool00?l0oooo3P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0
oooo7P3oool00?l0oooo3P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo
7P3oool00?l0oooo3P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo7P3o
ool00?l0oooo3P3oool300000080oooo00<000000?ooo`3oool0o`3ooolN0?ooo`00o`3oool>0?oo
o`060000003oool0oooo0000003oool00000o`3ooolP0?ooo`00o`3oool>0?ooo`030000003oool0
oooo00<00000o`3ooolP0?ooo`00o`3oool>0?ooo`040000003oool0oooo00000?l0oooo8P3oool0
0?l0oooo3P3oool010000000oooo0?ooo`00003o0?ooob80oooo003o0?ooo`h0oooo00@000000?oo
o`3oool00000o`3ooolR0?ooo`00o`3oool>0?ooo`040000003oool0oooo00000?l0oooo8P3oool0
0?l0oooo3P3oool010000000oooo0?ooo`00003o0?ooob80oooo003o0?ooo`h0oooo00@000000?oo
o`3oool00000o`3ooolR0?ooo`00o`3oool>0?ooo`040000003oool0000000000?l0oooo8P3oool0
0?l0oooo3P3oool00`000000oooo0000003o0?ooob<0oooo003o0?ooo`h0oooo00<000000?ooo`00
0000o`3ooolS0?ooo`00o`3oool>0?ooo`030000003oool000000?l0oooo8`3oool00?l0oooo3P3o
ool00`000000oooo0000003o0?ooob<0oooo003o0?ooo`h0oooo0P00003o0?ooob@0oooo003o0?oo
o`h0oooo0P00003o0?ooob@0oooo003o0?ooo`h0oooo0P00003o0?ooob@0oooo003o0?ooo`h0oooo
0`00003o0?ooob<0oooo003o0?ooo`h0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3oool>
0?ooo`030000003oool0oooo0?l0oooo8`3oool00?l0oooo3P3oool00`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooo`h0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3oool>0?ooo`030000
003oool0oooo0?l0oooo8`3oool00?l0oooo303oool300000?l0oooo9@3oool00?l0oooo303oool0
0`000000oooo0000003o0?ooobD0oooo003o0?ooo``0oooo00<000000?ooo`000000o`3ooolU0?oo
o`00o`3oool<0?ooo`030000003oool000000?l0oooo9@3oool00?l0oooo303oool00`000000oooo
0000003o0?ooobD0oooo003o0?ooo``0oooo00<000000?ooo`000000o`3ooolU0?ooo`00o`3oool:
0?ooo`050000003oool000000?ooo`000000o`3ooolU0?ooo`00o`3oool:0?ooo`<0000000<0oooo
0000003oool0o`3ooolT0?ooo`00o`3oool:0?ooo`050000003oool0oooo0?ooo`000000o`3ooolU
0?ooo`00o`3oool:0?ooo`050000003oool0oooo0?ooo`000000o`3ooolU0?ooo`00o`3oool:0?oo
o`050000003oool0oooo0?ooo`000000o`3ooolU0?ooo`00o`3oool:0?ooo`040000003oool0oooo
0?ooo`<00000o`3ooolS0?ooo`003P3oool00`000000oooo0?ooo`3h0?ooo`050000003oool0oooo
0?ooo`000000o`3ooolU0?ooo`003`3oool400000?@0oooo0`0000030?ooo`030000003oool0oooo
0?l0oooo8`3oool001<0oooo0`00003a0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0o`3ooolS0?ooo`005P3oool200000>l0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`3o0?ooob<0oooo000H0?ooo`<00000k03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0?l0oooo8`3oool001/0oooo0`00003Y0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0o`3ooolS0?ooo`007P3oool300000>H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3o0?ooob<0oooo000Q0?ooo`<00000h@3oool3000000D0oooo00<000000?ooo`3o
ool0o`3ooolS0?ooo`00903oool400000=d0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`3o0?ooob<0oooo000X0?ooo`<00000fP3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0?l0oooo8`3oool002/0oooo0P00003H0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0o`3ooolS0?ooo`00;@3oool300000=D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3o0?ooob<0oooo000`0?ooo`D00000cP3oool00`000000oooo000000070?ooo`03
0000003oool0oooo0?l0oooo8`3oool003D0oooo0`00003;0?ooo`<000001`3oool00`000000oooo
0?ooo`3o0?ooob<0oooo000h0?ooo`800000_03oool2000000@0oooo00<000000?ooo`3oool00P3o
ool3000000T0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00>P3oool300000;P0oooo00@00000
0?ooo`3oool000001`3oool00`000000oooo0?ooo`02000000P0oooo00<000000?ooo`3oool0o`3o
oolS0?ooo`00?@3oool300000;D0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?oo
o`02000000P0oooo1000003o0?ooob80oooo00100?ooo`800000/`3oool010000000oooo0?ooo`00
00080?ooo`<000002@3oool00`000000oooo0?ooo`3o0?ooob<0oooo00120?ooo`@00000[`3oool0
10000000oooo0?ooo`0000070?ooo`D00000203oool00`000000oooo0?ooo`3o0?ooob<0oooo0016
0?ooo`@00000Z`3oool010000000oooo0?ooo`0000070?ooo`8000000P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0?l0oooo8`3oool004X0oooo0`00002Y0?ooo`8000002@3oool3
000000T0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00C@3oool200000;80oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`3o0?ooob<0oooo001?0?ooo`@00000[P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo8`3oool005<0oooo0`00002Y0?ooo`<00000
2`3oool00`000000oooo0?ooo`3o0?ooob<0oooo001F0?ooo`800000Y`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0?l0oooo8`3oool005P0oooo0`00002T0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00F`3oool400000:00oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`3o0?ooob<0oooo001O0?ooo`<00000V`3oool3000000d0
oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00HP3oool3000009P0oooo0`00000=0?ooo`030000
003oool0oooo0?l0oooo8`3oool006D0oooo0`00002E0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0o`3ooolS0?ooo`00J03oool400000940oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`3o0?ooob<0oooo001/0?ooo`<00000SP3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0?l0oooo8`3oool006l0oooo0`0000290?ooo`<000003`3oool00`000000
oooo0?ooo`3o0?ooob<0oooo001b0?ooo`<00000QP3oool00`000000oooo0?ooo`0?0?ooo`<00000
o`3ooolS0?ooo`00M@3oool3000008<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`3o0?ooob<0oooo001h0?ooo`800000P@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0?l0oooo8`3oool007X0oooo0`00001m0?ooo`8000004@3oool00`000000oooo0?ooo`3o0?oo
ob<0oooo001m0?ooo`@00000N@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0
oooo8`3oool00840oooo0`00001f0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
o`3ooolS0?ooo`00Q03oool300000740oooo0P00000C0?ooo`030000003oool0oooo0?l0oooo8`3o
ool008L0oooo0`00001^0?ooo`8000004`3oool00`000000oooo0?ooo`3o0?ooob<0oooo002:0?oo
o`@00000JP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0oooo8`3oool008h0
oooo0`00001W0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00
T@3oool300000680oooo0`00000D0?ooo`030000003oool0oooo0?l0oooo8`3oool009@0oooo0`00
001O0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00U`3oool3
000005`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?ooob<0oooo002J0?oo
o`800000F03oool3000001H0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00W03oool3000005D0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?ooob<0oooo002O0?ooo`D00000
CP3oool3000001P0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00Y03oool3000004/0oooo0`00
000H0?ooo`030000003oool0oooo0?l0oooo8`3oool00:L0oooo0P0000190?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00Z@3oool3000004@0oooo0`00000J0?oo
o`<00000o`3ooolS0?ooo`00[03oool300000440oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`3o0?ooob<0oooo002_0?ooo`800000?@3oool3000001`0oooo00<000000?ooo`3oool0
o`3ooolS0?ooo`00/@3oool4000003T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`3o0?ooob<0oooo002e0?ooo`@00000<`3oool3000001h0oooo00<000000?ooo`3oool0o`3ooolS
0?ooo`00^@3oool3000002h0oooo0`00000P0?ooo`030000003oool0oooo0?l0oooo8`3oool00;`0
oooo0P00000/0?ooo`<00000803oool00`000000oooo0?ooo`3o0?ooob<0oooo002n0?ooo`<00000
9`3oool300000280oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00`@3oool500000200oooo0`00
000T0?ooo`030000003oool0oooo0?l0oooo8`3oool00<H0oooo1000000K0?ooo`8000009P3oool0
0`000000oooo0?ooo`3o0?ooob<0oooo003:0?ooo`@000004`3oool00`000000oooo000000020000
02L0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00cP3oool6000000030?ooo`000000oooo00@0
oooo00<000000?ooo`0000001P00000Y0?ooo`030000003oool0oooo0?l0oooo8`3oool00=<0oooo
3@00000]0?ooo`030000003oool0oooo0?l0oooo8`3oool00?l0oooo3P3oool00`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooo`h0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3oool>0?oo
o`030000003oool0oooo0?l0oooo8`3oool00?l0oooo3P3oool00`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooo`h0oooo0`00003o0?ooob<0oooo003o0?ooo`h0oooo00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3oool>0?ooo`030000003oool0oooo0?l0oooo8`3oool00?l0oooo3P3oool00`00
0000oooo0?ooo`3o0?ooob<0oooo0000\
\>"],
  ImageRangeCache->{{{0, 561.125}, {346.438, 0}} -> {19.2365, -0.0470471, \
0.00023597, 0.00290838}},
  CellTags->"Realistic Fresnel Lens Model"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[{
\tLineOfRays[20,NumberOfRays->101,MonteCarlo->Stratified],
\tMove[flens,100],
\tMove[Screen[100],200]},PlotType->TopView];\
\>", "Input",
  AspectRatioFixed->True,
  CellTags->{
  "genetic building-blocks", "creating new components", "Fresnel", 
    "fresnel lens", "Realistic Fresnel Lens Model"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.25 0.0047619 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.50028 .13095 m
.50952 .13095 L
.50952 .17063 L
.50025 .17063 L
.50028 .13095 L
F
.50025 .17063 m
.50952 .17063 L
.50952 .21032 L
.50016 .21032 L
.50025 .17063 L
F
.50016 .21032 m
.50952 .21032 L
.50952 .25 L
.5 .25 L
.50016 .21032 L
F
.5 .25 m
.50952 .25 L
.50952 .28968 L
.50016 .28968 L
.5 .25 L
F
.50016 .28968 m
.50952 .28968 L
.50952 .32937 L
.50025 .32937 L
.50016 .28968 L
F
.50025 .32937 m
.50952 .32937 L
.50952 .36905 L
.50028 .36905 L
.50025 .32937 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.50028 .13095 m
.50025 .17063 L
.50016 .21032 L
.5 .25 L
.50016 .28968 L
.50025 .32937 L
.50028 .36905 L
.50952 .36905 L
.50952 .32937 L
.50952 .28968 L
.50952 .25 L
.50952 .21032 L
.50952 .17063 L
.50952 .13095 L
.50028 .13095 L
s
.5 g
.50028 .25 m
.50952 .25 L
.50952 .25 L
.50025 .25 L
.50028 .25 L
F
.50025 .25 m
.50952 .25 L
.50952 .25 L
.50016 .25 L
.50025 .25 L
F
.50016 .25 m
.50952 .25 L
.50952 .25 L
.5 .25 L
.50016 .25 L
F
.5 .25 m
.50952 .25 L
.50952 .25 L
.50016 .25 L
.5 .25 L
F
.50016 .25 m
.50952 .25 L
.50952 .25 L
.50025 .25 L
.50016 .25 L
F
.50025 .25 m
.50952 .25 L
.50952 .25 L
.50028 .25 L
.50025 .25 L
F
0 g
.50028 .25 m
.50025 .25 L
.50016 .25 L
.5 .25 L
.50016 .25 L
.50025 .25 L
.50028 .25 L
.50952 .25 L
.50952 .25 L
.50952 .25 L
.50952 .25 L
.50952 .25 L
.50952 .25 L
.50952 .25 L
.50028 .25 L
s
.50022 .13095 m
.50952 .13095 L
.50952 .17063 L
.50025 .17063 L
.50022 .13095 L
s
.50025 .17063 m
.50952 .17063 L
.50952 .21032 L
.50053 .21032 L
.50025 .17063 L
s
.50053 .21032 m
.50952 .21032 L
.50952 .25 L
.50028 .25 L
.50053 .21032 L
s
.50028 .25 m
.50952 .25 L
.50952 .28968 L
.50053 .28968 L
.50028 .25 L
s
.50053 .28968 m
.50952 .28968 L
.50952 .32937 L
.50025 .32937 L
.50053 .28968 L
s
.50025 .32937 m
.50952 .32937 L
.50952 .36905 L
.50022 .36905 L
.50025 .32937 L
s
.50022 .36905 m
.50952 .36905 L
.50952 .36905 L
.50025 .36905 L
.50022 .36905 L
s
.50025 .36905 m
.50952 .36905 L
.50952 .36905 L
.50053 .36905 L
.50025 .36905 L
s
.50053 .36905 m
.50952 .36905 L
.50952 .36905 L
.50028 .36905 L
.50053 .36905 L
s
.50028 .36905 m
.50952 .36905 L
.50952 .36905 L
.50053 .36905 L
.50028 .36905 L
s
.50053 .36905 m
.50952 .36905 L
.50952 .36905 L
.50025 .36905 L
.50053 .36905 L
s
.50025 .36905 m
.50952 .36905 L
.50952 .36905 L
.50022 .36905 L
.50025 .36905 L
s
.50022 .36905 m
.50952 .36905 L
.50952 .32937 L
.50025 .32937 L
.50022 .36905 L
s
.50025 .32937 m
.50952 .32937 L
.50952 .28968 L
.50053 .28968 L
.50025 .32937 L
s
.50053 .28968 m
.50952 .28968 L
.50952 .25 L
.50028 .25 L
.50053 .28968 L
s
.50028 .25 m
.50952 .25 L
.50952 .21032 L
.50053 .21032 L
.50028 .25 L
s
.50053 .21032 m
.50952 .21032 L
.50952 .17063 L
.50025 .17063 L
.50053 .21032 L
s
.50025 .17063 m
.50952 .17063 L
.50952 .13095 L
.50022 .13095 L
.50025 .17063 L
s
.50022 .13095 m
.50952 .13095 L
.50952 .13095 L
.50025 .13095 L
.50022 .13095 L
s
.50025 .13095 m
.50952 .13095 L
.50952 .13095 L
.50053 .13095 L
.50025 .13095 L
s
.50053 .13095 m
.50952 .13095 L
.50952 .13095 L
.50028 .13095 L
.50053 .13095 L
s
.50028 .13095 m
.50952 .13095 L
.50952 .13095 L
.50053 .13095 L
.50028 .13095 L
s
.50053 .13095 m
.50952 .13095 L
.50952 .13095 L
.50025 .13095 L
.50053 .13095 L
s
.50025 .13095 m
.50952 .13095 L
.50952 .13095 L
.50022 .13095 L
.50025 .13095 L
s
.97619 .0119 m
.97619 .09127 L
.97619 .17063 L
.97619 .25 L
.97619 .32937 L
.97619 .40873 L
.97619 .4881 L
.97619 .4881 L
.97619 .40873 L
.97619 .32937 L
.97619 .25 L
.97619 .17063 L
.97619 .09127 L
.97619 .0119 L
.97619 .0119 L
s
.97619 .25 m
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
s
.97619 .4881 m
.97619 .47998 L
.97619 .4562 L
.97619 .41836 L
.97619 .36905 L
.97619 .31162 L
.97619 .25 L
.97619 .18838 L
.97619 .13095 L
.97619 .08164 L
.97619 .0438 L
.97619 .02002 L
.97619 .0119 L
.97619 .02002 L
.97619 .0438 L
.97619 .08164 L
.97619 .13095 L
.97619 .18838 L
.97619 .25 L
.97619 .31162 L
.97619 .36905 L
.97619 .41836 L
.97619 .4562 L
.97619 .47998 L
.97619 .4881 L
s
.039 .916 .04 r
.02381 .20207 m
.50015 .20207 L
s
0 0 0 r
2.5 Mabswid
.50015 .20207 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20341 m
.50012 .20341 L
s
0 0 0 r
2.5 Mabswid
.50012 .20341 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20458 m
.50012 .20458 L
s
0 0 0 r
2.5 Mabswid
.50012 .20458 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20536 m
.5002 .20536 L
s
0 0 0 r
2.5 Mabswid
.5002 .20536 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20641 m
.50002 .20641 L
s
0 0 0 r
2.5 Mabswid
.50002 .20641 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2076 m
.50002 .2076 L
s
0 0 0 r
2.5 Mabswid
.50002 .2076 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20771 m
.50018 .20771 L
s
0 0 0 r
2.5 Mabswid
.50018 .20771 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20902 m
.50018 .20902 L
s
0 0 0 r
2.5 Mabswid
.50018 .20902 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20997 m
.50002 .20997 L
s
0 0 0 r
2.5 Mabswid
.50002 .20997 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21125 m
.50002 .21125 L
s
0 0 0 r
2.5 Mabswid
.50002 .21125 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21237 m
.50002 .21237 L
s
0 0 0 r
2.5 Mabswid
.50002 .21237 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21306 m
.5001 .21306 L
s
0 0 0 r
2.5 Mabswid
.5001 .21306 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21378 m
.50016 .21378 L
s
0 0 0 r
2.5 Mabswid
.50016 .21378 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21483 m
.50001 .21483 L
s
0 0 0 r
2.5 Mabswid
.50001 .21483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21586 m
.50004 .21586 L
s
0 0 0 r
2.5 Mabswid
.50004 .21586 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2166 m
.5001 .2166 L
s
0 0 0 r
2.5 Mabswid
.5001 .2166 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21788 m
.50009 .21788 L
s
0 0 0 r
2.5 Mabswid
.50009 .21788 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21902 m
.50009 .21902 L
s
0 0 0 r
2.5 Mabswid
.50009 .21902 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21911 m
.50008 .21911 L
s
0 0 0 r
2.5 Mabswid
.50008 .21911 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22004 m
.50011 .22004 L
s
0 0 0 r
2.5 Mabswid
.50011 .22004 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22148 m
.50008 .22148 L
s
0 0 0 r
2.5 Mabswid
.50008 .22148 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22259 m
.50009 .22259 L
s
0 0 0 r
2.5 Mabswid
.50009 .22259 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2232 m
.50002 .2232 L
s
0 0 0 r
2.5 Mabswid
.50002 .2232 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22416 m
.50005 .22416 L
s
0 0 0 r
2.5 Mabswid
.50005 .22416 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22512 m
.50007 .22512 L
s
0 0 0 r
2.5 Mabswid
.50007 .22512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22585 m
.5001 .22585 L
s
0 0 0 r
2.5 Mabswid
.5001 .22585 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22719 m
.50009 .22719 L
s
0 0 0 r
2.5 Mabswid
.50009 .22719 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22833 m
.5001 .22833 L
s
0 0 0 r
2.5 Mabswid
.5001 .22833 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22919 m
.50002 .22919 L
s
0 0 0 r
2.5 Mabswid
.50002 .22919 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22967 m
.50008 .22967 L
s
0 0 0 r
2.5 Mabswid
.50008 .22967 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23091 m
.50007 .23091 L
s
0 0 0 r
2.5 Mabswid
.50007 .23091 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23169 m
.50001 .23169 L
s
0 0 0 r
2.5 Mabswid
.50001 .23169 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23256 m
.50004 .23256 L
s
0 0 0 r
2.5 Mabswid
.50004 .23256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23366 m
.50004 .23366 L
s
0 0 0 r
2.5 Mabswid
.50004 .23366 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23473 m
.50005 .23473 L
s
0 0 0 r
2.5 Mabswid
.50005 .23473 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23578 m
.50005 .23578 L
s
0 0 0 r
2.5 Mabswid
.50005 .23578 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23687 m
.50005 .23687 L
s
0 0 0 r
2.5 Mabswid
.50005 .23687 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23788 m
.50001 .23788 L
s
0 0 0 r
2.5 Mabswid
.50001 .23788 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23887 m
.50001 .23887 L
s
0 0 0 r
2.5 Mabswid
.50001 .23887 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23918 m
.50005 .23918 L
s
0 0 0 r
2.5 Mabswid
.50005 .23918 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24089 m
.50002 .24089 L
s
0 0 0 r
2.5 Mabswid
.50002 .24089 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24172 m
.50003 .24172 L
s
0 0 0 r
2.5 Mabswid
.50003 .24172 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24262 m
.5 .24262 L
s
0 0 0 r
2.5 Mabswid
.5 .24262 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24295 m
.50003 .24295 L
s
0 0 0 r
2.5 Mabswid
.50003 .24295 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24417 m
.50002 .24417 L
s
0 0 0 r
2.5 Mabswid
.50002 .24417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24484 m
.50001 .24484 L
s
0 0 0 r
2.5 Mabswid
.50001 .24484 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24609 m
.5 .24609 L
s
0 0 0 r
2.5 Mabswid
.5 .24609 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24736 m
.5 .24736 L
s
0 0 0 r
2.5 Mabswid
.5 .24736 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24762 m
.50001 .24762 L
s
0 0 0 r
2.5 Mabswid
.50001 .24762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24948 m
.5 .24948 L
s
0 0 0 r
2.5 Mabswid
.5 .24948 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25032 m
.5 .25032 L
s
0 0 0 r
2.5 Mabswid
.5 .25032 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25141 m
.5 .25141 L
s
0 0 0 r
2.5 Mabswid
.5 .25141 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25176 m
.5 .25176 L
s
0 0 0 r
2.5 Mabswid
.5 .25176 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25313 m
.50001 .25313 L
s
0 0 0 r
2.5 Mabswid
.50001 .25313 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2537 m
.5 .2537 L
s
0 0 0 r
2.5 Mabswid
.5 .2537 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25496 m
.5 .25496 L
s
0 0 0 r
2.5 Mabswid
.5 .25496 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2554 m
.50001 .2554 L
s
0 0 0 r
2.5 Mabswid
.50001 .2554 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25662 m
.50001 .25662 L
s
0 0 0 r
2.5 Mabswid
.50001 .25662 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25802 m
.50002 .25802 L
s
0 0 0 r
2.5 Mabswid
.50002 .25802 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25823 m
.50003 .25823 L
s
0 0 0 r
2.5 Mabswid
.50003 .25823 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25948 m
.50004 .25948 L
s
0 0 0 r
2.5 Mabswid
.50004 .25948 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26064 m
.50004 .26064 L
s
0 0 0 r
2.5 Mabswid
.50004 .26064 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26105 m
.50001 .26105 L
s
0 0 0 r
2.5 Mabswid
.50001 .26105 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26191 m
.50005 .26191 L
s
0 0 0 r
2.5 Mabswid
.50005 .26191 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26335 m
.50001 .26335 L
s
0 0 0 r
2.5 Mabswid
.50001 .26335 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26464 m
.50001 .26464 L
s
0 0 0 r
2.5 Mabswid
.50001 .26464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2651 m
.50003 .2651 L
s
0 0 0 r
2.5 Mabswid
.50003 .2651 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26657 m
.50006 .26657 L
s
0 0 0 r
2.5 Mabswid
.50006 .26657 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2668 m
.50007 .2668 L
s
0 0 0 r
2.5 Mabswid
.50007 .2668 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26837 m
.50002 .26837 L
s
0 0 0 r
2.5 Mabswid
.50002 .26837 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26949 m
.50001 .26949 L
s
0 0 0 r
2.5 Mabswid
.50001 .26949 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26969 m
.50003 .26969 L
s
0 0 0 r
2.5 Mabswid
.50003 .26969 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27061 m
.50001 .27061 L
s
0 0 0 r
2.5 Mabswid
.50001 .27061 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27222 m
.50004 .27222 L
s
0 0 0 r
2.5 Mabswid
.50004 .27222 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2725 m
.50007 .2725 L
s
0 0 0 r
2.5 Mabswid
.50007 .2725 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27352 m
.50005 .27352 L
s
0 0 0 r
2.5 Mabswid
.50005 .27352 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27504 m
.50008 .27504 L
s
0 0 0 r
2.5 Mabswid
.50008 .27504 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27528 m
.50011 .27528 L
s
0 0 0 r
2.5 Mabswid
.50011 .27528 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27689 m
.50003 .27689 L
s
0 0 0 r
2.5 Mabswid
.50003 .27689 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27762 m
.50011 .27762 L
s
0 0 0 r
2.5 Mabswid
.50011 .27762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27869 m
.5001 .27869 L
s
0 0 0 r
2.5 Mabswid
.5001 .27869 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27961 m
.50007 .27961 L
s
0 0 0 r
2.5 Mabswid
.50007 .27961 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28078 m
.50007 .28078 L
s
0 0 0 r
2.5 Mabswid
.50007 .28078 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28129 m
.50013 .28129 L
s
0 0 0 r
2.5 Mabswid
.50013 .28129 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28206 m
.50008 .28206 L
s
0 0 0 r
2.5 Mabswid
.50008 .28206 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28373 m
.50015 .28373 L
s
0 0 0 r
2.5 Mabswid
.50015 .28373 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28449 m
.50009 .28449 L
s
0 0 0 r
2.5 Mabswid
.50009 .28449 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2851 m
.50004 .2851 L
s
0 0 0 r
2.5 Mabswid
.50004 .2851 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28633 m
.50003 .28633 L
s
0 0 0 r
2.5 Mabswid
.50003 .28633 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28672 m
.50006 .28672 L
s
0 0 0 r
2.5 Mabswid
.50006 .28672 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28796 m
.50007 .28796 L
s
0 0 0 r
2.5 Mabswid
.50007 .28796 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28901 m
.50005 .28901 L
s
0 0 0 r
2.5 Mabswid
.50005 .28901 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .29 m
.50002 .29 L
s
0 0 0 r
2.5 Mabswid
.50002 .29 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .29073 m
.50014 .29073 L
s
0 0 0 r
2.5 Mabswid
.50014 .29073 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .29181 m
.50012 .29181 L
s
0 0 0 r
2.5 Mabswid
.50012 .29181 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .29264 m
.50005 .29264 L
s
0 0 0 r
2.5 Mabswid
.50005 .29264 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .29368 m
.50002 .29368 L
s
0 0 0 r
2.5 Mabswid
.50002 .29368 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2947 m
.5002 .2947 L
s
0 0 0 r
2.5 Mabswid
.5002 .2947 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .29551 m
.50014 .29551 L
s
0 0 0 r
2.5 Mabswid
.50014 .29551 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .29626 m
.50006 .29626 L
s
0 0 0 r
2.5 Mabswid
.50006 .29626 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .29769 m
.5001 .29769 L
s
0 0 0 r
2.5 Mabswid
.5001 .29769 Mdot
.039 .916 .04 r
.5 Mabswid
.50015 .20207 m
.50952 .2027 L
s
0 0 0 r
2.5 Mabswid
.50952 .2027 Mdot
.039 .916 .04 r
.5 Mabswid
.50012 .20341 m
.50952 .20403 L
s
0 0 0 r
2.5 Mabswid
.50952 .20403 Mdot
.039 .916 .04 r
.5 Mabswid
.50012 .20458 m
.50952 .20518 L
s
0 0 0 r
2.5 Mabswid
.50952 .20518 Mdot
.039 .916 .04 r
.5 Mabswid
.5002 .20536 m
.50952 .20593 L
s
0 0 0 r
2.5 Mabswid
.50952 .20593 Mdot
.039 .916 .04 r
.5 Mabswid
.50002 .20641 m
.50952 .2046 L
s
0 0 0 r
2.5 Mabswid
.50952 .2046 Mdot
.039 .916 .04 r
.5 Mabswid
.50002 .2076 m
.50952 .20709 L
s
0 0 0 r
2.5 Mabswid
.50952 .20709 Mdot
.039 .916 .04 r
.5 Mabswid
.50018 .20771 m
.50952 .20489 L
s
0 0 0 r
2.5 Mabswid
.50952 .20489 Mdot
.039 .916 .04 r
.5 Mabswid
.50018 .20902 m
.50952 .20956 L
s
0 0 0 r
2.5 Mabswid
.50952 .20956 Mdot
.039 .916 .04 r
.5 Mabswid
.50002 .20997 m
.50952 .2105 L
s
0 0 0 r
2.5 Mabswid
.50952 .2105 Mdot
.039 .916 .04 r
.5 Mabswid
.50002 .21125 m
.50952 .20882 L
s
0 0 0 r
2.5 Mabswid
.50952 .20882 Mdot
.039 .916 .04 r
.5 Mabswid
.50002 .21237 m
.50952 .21287 L
s
0 0 0 r
2.5 Mabswid
.50952 .21287 Mdot
.039 .916 .04 r
.5 Mabswid
.5001 .21306 m
.50952 .21354 L
s
0 0 0 r
2.5 Mabswid
.50952 .21354 Mdot
.039 .916 .04 r
.5 Mabswid
.50016 .21378 m
.50952 .21335 L
s
0 0 0 r
2.5 Mabswid
.50952 .21335 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .21483 m
.50952 .21517 L
s
0 0 0 r
2.5 Mabswid
.50952 .21517 Mdot
.039 .916 .04 r
.5 Mabswid
.50004 .21586 m
.50952 .21631 L
s
0 0 0 r
2.5 Mabswid
.50952 .21631 Mdot
.039 .916 .04 r
.5 Mabswid
.5001 .2166 m
.50952 .21704 L
s
0 0 0 r
2.5 Mabswid
.50952 .21704 Mdot
.039 .916 .04 r
.5 Mabswid
.50009 .21788 m
.50952 .21831 L
s
0 0 0 r
2.5 Mabswid
.50952 .21831 Mdot
.039 .916 .04 r
.5 Mabswid
.50009 .21902 m
.50952 .21942 L
s
0 0 0 r
2.5 Mabswid
.50952 .21942 Mdot
.039 .916 .04 r
.5 Mabswid
.50008 .21911 m
.50952 .21951 L
s
0 0 0 r
2.5 Mabswid
.50952 .21951 Mdot
.039 .916 .04 r
.5 Mabswid
.50011 .22004 m
.50952 .22043 L
s
0 0 0 r
2.5 Mabswid
.50952 .22043 Mdot
.039 .916 .04 r
.5 Mabswid
.50008 .22148 m
.50952 .22185 L
s
0 0 0 r
2.5 Mabswid
.50952 .22185 Mdot
.039 .916 .04 r
.5 Mabswid
.50009 .22259 m
.50952 .22295 L
s
0 0 0 r
2.5 Mabswid
.50952 .22295 Mdot
.039 .916 .04 r
.5 Mabswid
.50002 .2232 m
.50952 .22356 L
s
0 0 0 r
2.5 Mabswid
.50952 .22356 Mdot
.039 .916 .04 r
.5 Mabswid
.50005 .22416 m
.50952 .22451 L
s
0 0 0 r
2.5 Mabswid
.50952 .22451 Mdot
.039 .916 .04 r
.5 Mabswid
.50007 .22512 m
.50952 .22545 L
s
0 0 0 r
2.5 Mabswid
.50952 .22545 Mdot
.039 .916 .04 r
.5 Mabswid
.5001 .22585 m
.50952 .22371 L
s
0 0 0 r
2.5 Mabswid
.50952 .22371 Mdot
.039 .916 .04 r
.5 Mabswid
.50009 .22719 m
.50952 .22749 L
s
0 0 0 r
2.5 Mabswid
.50952 .22749 Mdot
.039 .916 .04 r
.5 Mabswid
.5001 .22833 m
.50952 .22857 L
s
0 0 0 r
2.5 Mabswid
.50952 .22857 Mdot
.039 .916 .04 r
.5 Mabswid
.50002 .22919 m
.50952 .22947 L
s
0 0 0 r
2.5 Mabswid
.50952 .22947 Mdot
.039 .916 .04 r
.5 Mabswid
.50008 .22967 m
.50952 .22994 L
s
0 0 0 r
2.5 Mabswid
.50952 .22994 Mdot
.039 .916 .04 r
.5 Mabswid
.50007 .23091 m
.50952 .23116 L
s
0 0 0 r
2.5 Mabswid
.50952 .23116 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .23169 m
.50952 .23193 L
s
0 0 0 r
2.5 Mabswid
.50952 .23193 Mdot
.039 .916 .04 r
.5 Mabswid
.50004 .23256 m
.50952 .23279 L
s
0 0 0 r
2.5 Mabswid
.50952 .23279 Mdot
.039 .916 .04 r
.5 Mabswid
.50004 .23366 m
.50952 .23388 L
s
0 0 0 r
2.5 Mabswid
.50952 .23388 Mdot
.039 .916 .04 r
.5 Mabswid
.50005 .23473 m
.50952 .23493 L
s
0 0 0 r
2.5 Mabswid
.50952 .23493 Mdot
.039 .916 .04 r
.5 Mabswid
.50005 .23578 m
.50952 .23596 L
s
0 0 0 r
2.5 Mabswid
.50952 .23596 Mdot
.039 .916 .04 r
.5 Mabswid
.50005 .23687 m
.50952 .23704 L
s
0 0 0 r
2.5 Mabswid
.50952 .23704 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .23788 m
.50952 .23641 L
s
0 0 0 r
2.5 Mabswid
.50952 .23641 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .23887 m
.50952 .23902 L
s
0 0 0 r
2.5 Mabswid
.50952 .23902 Mdot
.039 .916 .04 r
.5 Mabswid
.50005 .23918 m
.50952 .23902 L
s
0 0 0 r
2.5 Mabswid
.50952 .23902 Mdot
.039 .916 .04 r
.5 Mabswid
.50002 .24089 m
.50952 .24101 L
s
0 0 0 r
2.5 Mabswid
.50952 .24101 Mdot
.039 .916 .04 r
.5 Mabswid
.50003 .24172 m
.50952 .24183 L
s
0 0 0 r
2.5 Mabswid
.50952 .24183 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .24262 m
.50952 .24272 L
s
0 0 0 r
2.5 Mabswid
.50952 .24272 Mdot
.039 .916 .04 r
.5 Mabswid
.50003 .24295 m
.50952 .24304 L
s
0 0 0 r
2.5 Mabswid
.50952 .24304 Mdot
.039 .916 .04 r
.5 Mabswid
.50002 .24417 m
.50952 .24425 L
s
0 0 0 r
2.5 Mabswid
.50952 .24425 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .24484 m
.50952 .24491 L
s
0 0 0 r
2.5 Mabswid
.50952 .24491 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .24609 m
.50952 .24614 L
s
0 0 0 r
2.5 Mabswid
.50952 .24614 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .24736 m
.50952 .24739 L
s
0 0 0 r
2.5 Mabswid
.50952 .24739 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .24762 m
.50952 .24749 L
s
0 0 0 r
2.5 Mabswid
.50952 .24749 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .24948 m
.50952 .24948 L
s
0 0 0 r
2.5 Mabswid
.50952 .24948 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .25032 m
.50952 .25032 L
s
0 0 0 r
2.5 Mabswid
.50952 .25032 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .25141 m
.50952 .25139 L
s
0 0 0 r
2.5 Mabswid
.50952 .25139 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .25176 m
.50952 .25174 L
s
0 0 0 r
2.5 Mabswid
.50952 .25174 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .25313 m
.50952 .25309 L
s
0 0 0 r
2.5 Mabswid
.50952 .25309 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .2537 m
.50952 .25371 L
s
0 0 0 r
2.5 Mabswid
.50952 .25371 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .25496 m
.50952 .25489 L
s
0 0 0 r
2.5 Mabswid
.50952 .25489 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .2554 m
.50952 .25533 L
s
0 0 0 r
2.5 Mabswid
.50952 .25533 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .25662 m
.50952 .25653 L
s
0 0 0 r
2.5 Mabswid
.50952 .25653 Mdot
.039 .916 .04 r
.5 Mabswid
.50002 .25802 m
.50952 .25791 L
s
0 0 0 r
2.5 Mabswid
.50952 .25791 Mdot
.039 .916 .04 r
.5 Mabswid
.50003 .25823 m
.50952 .25812 L
s
0 0 0 r
2.5 Mabswid
.50952 .25812 Mdot
.039 .916 .04 r
.5 Mabswid
.50004 .25948 m
.50952 .25936 L
s
0 0 0 r
2.5 Mabswid
.50952 .25936 Mdot
.039 .916 .04 r
.5 Mabswid
.50004 .26064 m
.50952 .2605 L
s
0 0 0 r
2.5 Mabswid
.50952 .2605 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .26105 m
.50952 .26091 L
s
0 0 0 r
2.5 Mabswid
.50952 .26091 Mdot
.039 .916 .04 r
.5 Mabswid
.50005 .26191 m
.50952 .26175 L
s
0 0 0 r
2.5 Mabswid
.50952 .26175 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .26335 m
.50952 .26396 L
s
0 0 0 r
2.5 Mabswid
.50952 .26396 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .26464 m
.50952 .26445 L
s
0 0 0 r
2.5 Mabswid
.50952 .26445 Mdot
.039 .916 .04 r
.5 Mabswid
.50003 .2651 m
.50952 .2649 L
s
0 0 0 r
2.5 Mabswid
.50952 .2649 Mdot
.039 .916 .04 r
.5 Mabswid
.50006 .26657 m
.50952 .26636 L
s
0 0 0 r
2.5 Mabswid
.50952 .26636 Mdot
.039 .916 .04 r
.5 Mabswid
.50007 .2668 m
.50952 .26658 L
s
0 0 0 r
2.5 Mabswid
.50952 .26658 Mdot
.039 .916 .04 r
.5 Mabswid
.50002 .26837 m
.50952 .26812 L
s
0 0 0 r
2.5 Mabswid
.50952 .26812 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .26949 m
.50952 .26923 L
s
0 0 0 r
2.5 Mabswid
.50952 .26923 Mdot
.039 .916 .04 r
.5 Mabswid
.50003 .26969 m
.50952 .26943 L
s
0 0 0 r
2.5 Mabswid
.50952 .26943 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .27061 m
.50952 .2718 L
s
0 0 0 r
2.5 Mabswid
.50952 .2718 Mdot
.039 .916 .04 r
.5 Mabswid
.50004 .27222 m
.50952 .27193 L
s
0 0 0 r
2.5 Mabswid
.50952 .27193 Mdot
.039 .916 .04 r
.5 Mabswid
.50007 .2725 m
.50952 .2722 L
s
0 0 0 r
2.5 Mabswid
.50952 .2722 Mdot
.039 .916 .04 r
.5 Mabswid
.50005 .27352 m
.50952 .27322 L
s
0 0 0 r
2.5 Mabswid
.50952 .27322 Mdot
.039 .916 .04 r
.5 Mabswid
.50008 .27504 m
.50952 .27471 L
s
0 0 0 r
2.5 Mabswid
.50952 .27471 Mdot
.039 .916 .04 r
.5 Mabswid
.50011 .27528 m
.50952 .27495 L
s
0 0 0 r
2.5 Mabswid
.50952 .27495 Mdot
.039 .916 .04 r
.5 Mabswid
.50003 .27689 m
.50952 .27653 L
s
0 0 0 r
2.5 Mabswid
.50952 .27653 Mdot
.039 .916 .04 r
.5 Mabswid
.50011 .27762 m
.50952 .27726 L
s
0 0 0 r
2.5 Mabswid
.50952 .27726 Mdot
.039 .916 .04 r
.5 Mabswid
.5001 .27869 m
.50952 .27831 L
s
0 0 0 r
2.5 Mabswid
.50952 .27831 Mdot
.039 .916 .04 r
.5 Mabswid
.50007 .27961 m
.50952 .27923 L
s
0 0 0 r
2.5 Mabswid
.50952 .27923 Mdot
.039 .916 .04 r
.5 Mabswid
.50007 .28078 m
.50952 .28037 L
s
0 0 0 r
2.5 Mabswid
.50952 .28037 Mdot
.039 .916 .04 r
.5 Mabswid
.50013 .28129 m
.50952 .28089 L
s
0 0 0 r
2.5 Mabswid
.50952 .28089 Mdot
.039 .916 .04 r
.5 Mabswid
.50008 .28206 m
.50952 .28164 L
s
0 0 0 r
2.5 Mabswid
.50952 .28164 Mdot
.039 .916 .04 r
.5 Mabswid
.50015 .28373 m
.50952 .28329 L
s
0 0 0 r
2.5 Mabswid
.50952 .28329 Mdot
.039 .916 .04 r
.5 Mabswid
.50009 .28449 m
.50952 .28403 L
s
0 0 0 r
2.5 Mabswid
.50952 .28403 Mdot
.039 .916 .04 r
.5 Mabswid
.50004 .2851 m
.50952 .2888 L
s
0 0 0 r
2.5 Mabswid
.50952 .2888 Mdot
.039 .916 .04 r
.5 Mabswid
.50003 .28633 m
.50952 .28882 L
s
0 0 0 r
2.5 Mabswid
.50952 .28882 Mdot
.039 .916 .04 r
.5 Mabswid
.50006 .28672 m
.50952 .28623 L
s
0 0 0 r
2.5 Mabswid
.50952 .28623 Mdot
.039 .916 .04 r
.5 Mabswid
.50007 .28796 m
.50952 .28746 L
s
0 0 0 r
2.5 Mabswid
.50952 .28746 Mdot
.039 .916 .04 r
.5 Mabswid
.50005 .28901 m
.50952 .28849 L
s
0 0 0 r
2.5 Mabswid
.50952 .28849 Mdot
.039 .916 .04 r
.5 Mabswid
.50002 .29 m
.50952 .2897 L
s
0 0 0 r
2.5 Mabswid
.50952 .2897 Mdot
.039 .916 .04 r
.5 Mabswid
.50014 .29073 m
.50952 .2902 L
s
0 0 0 r
2.5 Mabswid
.50952 .2902 Mdot
.039 .916 .04 r
.5 Mabswid
.50012 .29181 m
.50952 .29126 L
s
0 0 0 r
2.5 Mabswid
.50952 .29126 Mdot
.039 .916 .04 r
.5 Mabswid
.50005 .29264 m
.50952 .29208 L
s
0 0 0 r
2.5 Mabswid
.50952 .29208 Mdot
.039 .916 .04 r
.5 Mabswid
.50002 .29368 m
.50952 .2931 L
s
0 0 0 r
2.5 Mabswid
.50952 .2931 Mdot
.039 .916 .04 r
.5 Mabswid
.5002 .2947 m
.50952 .2963 L
s
0 0 0 r
2.5 Mabswid
.50952 .2963 Mdot
.039 .916 .04 r
.5 Mabswid
.50014 .29551 m
.50952 .29491 L
s
0 0 0 r
2.5 Mabswid
.50952 .29491 Mdot
.039 .916 .04 r
.5 Mabswid
.50006 .29626 m
.50952 .29565 L
s
0 0 0 r
2.5 Mabswid
.50952 .29565 Mdot
.039 .916 .04 r
.5 Mabswid
.5001 .29769 m
.50952 .29706 L
s
0 0 0 r
2.5 Mabswid
.50952 .29706 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .2027 m
.97619 .25059 L
s
0 0 0 r
2.5 Mabswid
.97619 .25059 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .20403 m
.97619 .25052 L
s
0 0 0 r
2.5 Mabswid
.97619 .25052 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .20518 m
.97619 .25047 L
s
0 0 0 r
2.5 Mabswid
.97619 .25047 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .20593 m
.97619 .24942 L
s
0 0 0 r
2.5 Mabswid
.97619 .24942 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .2046 m
.97619 .06681 L
s
0 0 0 r
2.5 Mabswid
.97619 .06681 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .20709 m
.97619 .16881 L
s
0 0 0 r
2.5 Mabswid
.97619 .16881 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .20956 m
.97619 .2503 L
s
0 0 0 r
2.5 Mabswid
.97619 .2503 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .2105 m
.97619 .25028 L
s
0 0 0 r
2.5 Mabswid
.97619 .25028 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .20882 m
.97619 .01874 L
s
0 0 0 r
2.5 Mabswid
.97619 .01874 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .21287 m
.97619 .2502 L
s
0 0 0 r
2.5 Mabswid
.97619 .2502 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .21354 m
.97619 .25018 L
s
0 0 0 r
2.5 Mabswid
.97619 .25018 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .21335 m
.97619 .1807 L
s
0 0 0 r
2.5 Mabswid
.97619 .1807 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .21517 m
.97619 .24099 L
s
0 0 0 r
2.5 Mabswid
.97619 .24099 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .21631 m
.97619 .25012 L
s
0 0 0 r
2.5 Mabswid
.97619 .25012 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .21704 m
.97619 .2501 L
s
0 0 0 r
2.5 Mabswid
.97619 .2501 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .21831 m
.97619 .25008 L
s
0 0 0 r
2.5 Mabswid
.97619 .25008 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .21942 m
.97619 .25006 L
s
0 0 0 r
2.5 Mabswid
.97619 .25006 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .21951 m
.97619 .25005 L
s
0 0 0 r
2.5 Mabswid
.97619 .25005 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .22043 m
.97619 .25004 L
s
0 0 0 r
2.5 Mabswid
.97619 .25004 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .22185 m
.97619 .25002 L
s
0 0 0 r
2.5 Mabswid
.97619 .25002 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .22295 m
.97619 .25001 L
s
0 0 0 r
2.5 Mabswid
.97619 .25001 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .22356 m
.97619 .25 L
s
0 0 0 r
2.5 Mabswid
.97619 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .22451 m
.97619 .24999 L
s
0 0 0 r
2.5 Mabswid
.97619 .24999 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .22545 m
.97619 .24998 L
s
0 0 0 r
2.5 Mabswid
.97619 .24998 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .22371 m
.97619 .05776 L
s
0 0 0 r
2.5 Mabswid
.97619 .05776 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .22749 m
.97619 .24996 L
s
0 0 0 r
2.5 Mabswid
.97619 .24996 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .22857 m
.97619 .24675 L
s
0 0 0 r
2.5 Mabswid
.97619 .24675 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .22947 m
.97619 .24996 L
s
0 0 0 r
2.5 Mabswid
.97619 .24996 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .22994 m
.97619 .24995 L
s
0 0 0 r
2.5 Mabswid
.97619 .24995 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .23116 m
.97619 .24995 L
s
0 0 0 r
2.5 Mabswid
.97619 .24995 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .23193 m
.97619 .24995 L
s
0 0 0 r
2.5 Mabswid
.97619 .24995 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .23279 m
.97619 .24995 L
s
0 0 0 r
2.5 Mabswid
.97619 .24995 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .23388 m
.97619 .24994 L
s
0 0 0 r
2.5 Mabswid
.97619 .24994 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .23493 m
.97619 .24994 L
s
0 0 0 r
2.5 Mabswid
.97619 .24994 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .23596 m
.97619 .24994 L
s
0 0 0 r
2.5 Mabswid
.97619 .24994 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .23704 m
.97619 .24995 L
s
0 0 0 r
2.5 Mabswid
.97619 .24995 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .23641 m
.97619 .12534 L
s
0 0 0 r
2.5 Mabswid
.97619 .12534 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .23902 m
.97619 .24995 L
s
0 0 0 r
2.5 Mabswid
.97619 .24995 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .23902 m
.97619 .22747 L
s
0 0 0 r
2.5 Mabswid
.97619 .22747 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .24101 m
.97619 .24996 L
s
0 0 0 r
2.5 Mabswid
.97619 .24996 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .24183 m
.97619 .24996 L
s
0 0 0 r
2.5 Mabswid
.97619 .24996 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .24272 m
.97619 .24996 L
s
0 0 0 r
2.5 Mabswid
.97619 .24996 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .24304 m
.97619 .24996 L
s
0 0 0 r
2.5 Mabswid
.97619 .24996 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .24425 m
.97619 .24997 L
s
0 0 0 r
2.5 Mabswid
.97619 .24997 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .24491 m
.97619 .24997 L
s
0 0 0 r
2.5 Mabswid
.97619 .24997 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .24614 m
.97619 .24998 L
s
0 0 0 r
2.5 Mabswid
.97619 .24998 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .24739 m
.97619 .24999 L
s
0 0 0 r
2.5 Mabswid
.97619 .24999 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .24749 m
.97619 .23798 L
s
0 0 0 r
2.5 Mabswid
.97619 .23798 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .24948 m
.97619 .25 L
s
0 0 0 r
2.5 Mabswid
.97619 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .25032 m
.97619 .25 L
s
0 0 0 r
2.5 Mabswid
.97619 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .25139 m
.97619 .25001 L
s
0 0 0 r
2.5 Mabswid
.97619 .25001 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .25174 m
.97619 .25001 L
s
0 0 0 r
2.5 Mabswid
.97619 .25001 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .25309 m
.97619 .25002 L
s
0 0 0 r
2.5 Mabswid
.97619 .25002 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .25371 m
.97619 .25451 L
s
0 0 0 r
2.5 Mabswid
.97619 .25451 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .25489 m
.97619 .25003 L
s
0 0 0 r
2.5 Mabswid
.97619 .25003 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .25533 m
.97619 .25003 L
s
0 0 0 r
2.5 Mabswid
.97619 .25003 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .25653 m
.97619 .25003 L
s
0 0 0 r
2.5 Mabswid
.97619 .25003 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .25791 m
.97619 .25004 L
s
0 0 0 r
2.5 Mabswid
.97619 .25004 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .25812 m
.97619 .25004 L
s
0 0 0 r
2.5 Mabswid
.97619 .25004 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .25936 m
.97619 .25005 L
s
0 0 0 r
2.5 Mabswid
.97619 .25005 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .2605 m
.97619 .25005 L
s
0 0 0 r
2.5 Mabswid
.97619 .25005 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .26091 m
.97619 .25005 L
s
0 0 0 r
2.5 Mabswid
.97619 .25005 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .26175 m
.97619 .25005 L
s
0 0 0 r
2.5 Mabswid
.97619 .25005 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .26396 m
.97619 .30949 L
s
0 0 0 r
2.5 Mabswid
.97619 .30949 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .26445 m
.97619 .25006 L
s
0 0 0 r
2.5 Mabswid
.97619 .25006 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .2649 m
.97619 .25006 L
s
0 0 0 r
2.5 Mabswid
.97619 .25006 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .26636 m
.97619 .25006 L
s
0 0 0 r
2.5 Mabswid
.97619 .25006 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .26658 m
.97619 .25006 L
s
0 0 0 r
2.5 Mabswid
.97619 .25006 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .26812 m
.97619 .25005 L
s
0 0 0 r
2.5 Mabswid
.97619 .25005 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .26923 m
.97619 .25005 L
s
0 0 0 r
2.5 Mabswid
.97619 .25005 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .26943 m
.97619 .25005 L
s
0 0 0 r
2.5 Mabswid
.97619 .25005 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .2718 m
.97619 .3619 L
s
0 0 0 r
2.5 Mabswid
.97619 .3619 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .27193 m
.97619 .25004 L
s
0 0 0 r
2.5 Mabswid
.97619 .25004 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .2722 m
.97619 .25004 L
s
0 0 0 r
2.5 Mabswid
.97619 .25004 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .27322 m
.97619 .25003 L
s
0 0 0 r
2.5 Mabswid
.97619 .25003 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .27471 m
.97619 .25002 L
s
0 0 0 r
2.5 Mabswid
.97619 .25002 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .27495 m
.97619 .25002 L
s
0 0 0 r
2.5 Mabswid
.97619 .25002 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .27653 m
.97619 .25 L
s
0 0 0 r
2.5 Mabswid
.97619 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .27726 m
.97619 .24999 L
s
0 0 0 r
2.5 Mabswid
.97619 .24999 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .27831 m
.97619 .24998 L
s
0 0 0 r
2.5 Mabswid
.97619 .24998 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .27923 m
.97619 .24996 L
s
0 0 0 r
2.5 Mabswid
.97619 .24996 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .28037 m
.97619 .24995 L
s
0 0 0 r
2.5 Mabswid
.97619 .24995 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .28089 m
.97619 .24994 L
s
0 0 0 r
2.5 Mabswid
.97619 .24994 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .28164 m
.97619 .24992 L
s
0 0 0 r
2.5 Mabswid
.97619 .24992 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .28329 m
.97619 .2499 L
s
0 0 0 r
2.5 Mabswid
.97619 .2499 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .28403 m
.97619 .24988 L
s
0 0 0 r
2.5 Mabswid
.97619 .24988 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .28882 m
.97619 .48423 L
s
0 0 0 r
2.5 Mabswid
.97619 .48423 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .28623 m
.97619 .24982 L
s
0 0 0 r
2.5 Mabswid
.97619 .24982 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .28746 m
.97619 .24979 L
s
0 0 0 r
2.5 Mabswid
.97619 .24979 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .28849 m
.97619 .24976 L
s
0 0 0 r
2.5 Mabswid
.97619 .24976 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .2897 m
.97619 .26733 L
s
0 0 0 r
2.5 Mabswid
.97619 .26733 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .2902 m
.97619 .24971 L
s
0 0 0 r
2.5 Mabswid
.97619 .24971 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .29126 m
.97619 .24967 L
s
0 0 0 r
2.5 Mabswid
.97619 .24967 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .29208 m
.97619 .24964 L
s
0 0 0 r
2.5 Mabswid
.97619 .24964 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .2931 m
.97619 .24959 L
s
0 0 0 r
2.5 Mabswid
.97619 .24959 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .2963 m
.97619 .42063 L
s
0 0 0 r
2.5 Mabswid
.97619 .42063 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .29491 m
.97619 .24953 L
s
0 0 0 r
2.5 Mabswid
.97619 .24953 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .29565 m
.97619 .24949 L
s
0 0 0 r
2.5 Mabswid
.97619 .24949 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .29706 m
.97619 .24942 L
s
0 0 0 r
2.5 Mabswid
.97619 .24942 Mdot
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{835, 417.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=30001XB000`400?l00000o`00003oo`3ooooo
0?ooool0ooooAP3oool00?l0ooooo`3ooooo0?ooodH0oooo003o0?ooool0ooooo`3ooom60?ooo`00
o`3ooooo0?ooool0ooooAP3oool00?l0ooooo`3ooooo0?ooodH0oooo003o0?ooool0ooooo`3ooom6
0?ooo`00o`3ooooo0?ooool0ooooAP3oool00?l0ooooo`3ooooo0?ooodH0oooo003o0?ooool0oooo
o`3ooom60?ooo`00o`3ooooo0?ooool0ooooAP3oool00?l0ooooo`3ooooo0?oooc00oooo00<00000
0?ooo`3oool04`3oool00?l0ooooo`3ooooo0?oooc00oooo00<000000?ooo`3oool04`3oool00?l0
ooooo`3ooooo0?oooc00oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooooo0?oooc00oooo
00<000000?ooo`3oool04`3oool00?l0ooooo`3ooooo0?oooc00oooo00<000000?ooo`3oool04`3o
ool00?l0ooooo`3ooooo0?ooobl0oooo0P00000E0?ooo`00o`3ooooo0?ooool0oooo;`3oool20000
01D0oooo003o0?ooool0ooooo`3oool/0?ooo`<02NX:00<0oooo0000003oool0503oool00?l0oooo
o`3ooooo0?ooobX0oooo0P09jPX40?ooo`030000003oool0oooo01<0oooo003o0?ooool0ooooo`3o
oolW0?ooo`<02NX:1P3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?ooool0oooo9@3oool2
00WZ2PT0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooooo0?ooob80oooo0`09jPX;0?oo
o`030000003oool0oooo01<0oooo003o0?ooool0ooooo`3ooolP0?ooo`802NX:3P3oool00`000000
oooo0?ooo`0C0?ooo`00o`3ooooo0?ooool0oooo7P3oool200WZ2Q00oooo00<000000?ooo`3oool0
4`3oool00?l0ooooo`3ooooo0?oooa/0oooo0`09jPXB0?ooo`030000003oool0oooo01<0oooo003o
0?ooool0ooooo`3ooolI0?ooo`802NX:5@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?oo
ool0oooo5P3oool300WZ2QL0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooooo0?oooa@0
oooo0P09jPXJ0?ooo`030000003oool0oooo01<0oooo003o0?ooool0ooooo`3ooolA0?ooo`<02NX:
703oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?ooool0oooo3`3oool200WZ2Ql0oooo00<0
00000?ooo`3oool04`3oool00?l0ooooo`3ooooo0?ooo``0oooo0`09jPXQ0?ooo`030000003oool0
oooo01<0oooo003o0?ooool0ooooo`3oool:0?ooo`802NX:903oool00`000000oooo0?ooo`0C0?oo
o`00o`3ooooo0?ooool0oooo1`3oool300WZ2RH0oooo00<000000?ooo`3oool04`3oool00?l0oooo
o`3ooooo0?ooo`D0oooo0P09jPXY0?ooo`030000003oool0oooo01<0oooo003o0?ooool0ooooo`3o
ool20?ooo`<02NX::`3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?ooool0oooo0P09jPX^
0?ooo`030000003oool0oooo01<0oooo003o0?ooool0ooooo@3oool200WZ2S00oooo00<000000?oo
o`3oool04`3oool00?l0ooooo`3ooooj0?ooo`<02NX:<P3oool00`000000oooo0?ooo`0C0?ooo`00
o`3ooooo0?ooooP0oooo0P09jPXe0?ooo`030000003oool0oooo01<0oooo003o0?ooool0oooom@3o
ool300WZ2SL0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooooc0?ooo`802NX:>P3oool0
0`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?oooo00oooo0`09jPXl0?ooo`030000003oool0oooo
01<0oooo003o0?ooool0ooookP3oool200WZ2Sl0oooo00<000000?ooo`3oool04`3oool00?l0oooo
o`3oooo[0?ooo`<02NX:@@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?ooonT0oooo0P09
jPY40?ooo`030000003oool0oooo01<0oooo003o0?ooool0ooooiP3oool300WZ2TH0oooo00<00000
0?ooo`3oool04`3oool00?l0ooooo`3ooooT0?ooo`802NX:B@3oool00`000000oooo0?ooo`0C0?oo
o`00o`3ooooo0?ooon40oooo0`09jPY;0?ooo`030000003oool0oooo01<0oooo003o0?ooool0oooo
g`3oool200WZ2Td0oooo0P00000E0?ooo`00o`3ooooo0?ooomd0oooo0P09jPY<0?ooo`<02NX:0P00
000E0?ooo`00o`3ooooo0?ooomX0oooo0`09jPY;0?ooo`<02NX:103oool00`000000oooo0?ooo`0C
0?ooo`00o`3ooooo0?ooomP0oooo0P09jPY;0?ooo`<02NX:1`3oool00`000000oooo0?ooo`0C0?oo
o`00o`3ooooo0?ooomD0oooo0`09jPY:0?ooo`<02NX:2P3oool00`000000oooo0?ooo`0C0?ooo`00
o`3ooooo0?ooom<0oooo0P09jPY:0?ooo`<02NX:3@3oool00`000000oooo0?ooo`0C0?ooo`00o`3o
oooo0?ooom00oooo0`09jPY:0?ooo`802NX:403oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo
0?ooolh0oooo0P09jPY:0?ooo`<02NX:4@3oool2000001D0oooo003o0?ooool0oooob`3oool300WZ
2TT0oooo0`09jPXC0?ooo`0300WZ2P000000000001D0oooo003o0?ooool0oooob@3oool200WZ2TT0
oooo0`09jPXC0?ooo`<02NX:0P3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?ooolH0oooo
0`09jPY80?ooo`<02NX:4P3oool400WZ2PD0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3o
ooo40?ooo`802NX:B@3oool200WZ2Q80oooo0`09jPX90?ooo`030000003oool0oooo01<0oooo003o
0?ooool0oooo`@3oool300WZ2TP0oooo0`09jPXA0?ooo`<02NX:303oool00`000000oooo0?ooo`0C
0?ooo`00o`3ooooo0?oookl0oooo0P09jPY80?ooo`<02NX:403oool400WZ2Pl0oooo00<000000?oo
o`3oool04`3oool00?l0ooooo`3ooonm0?ooo`802NX:A`3oool300WZ2Q00oooo0`09jPXC0?ooo`03
0000003oool0oooo01<0oooo003o0?ooool0oooo^P3oool300WZ2TH0oooo0`09jPX?0?ooo`@02NX:
5P3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?oookP0oooo0P09jPY60?ooo`<02NX:3`3o
ool300WZ2QX0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooone0?ooo`<02NX:AP3oool2
00WZ2Pl0oooo0`09jPXM0?ooo`030000003oool0oooo01<0oooo003o0?ooool0oooo/`3oool200WZ
2TH0oooo0`09jPX=0?ooo`@02NX:803oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?oook00
oooo0`09jPY50?ooo`<02NX:3@3oool300WZ2R@0oooo00<000000?ooo`3oool04`3oool00?l0oooo
o`3ooon^0?ooo`802NX:A@3oool300WZ2P`0oooo1009jPXW0?ooo`030000003oool0oooo01<0oooo
003o0?ooool0ooooZ`3oool300WZ2T@0oooo0`09jPX<0?ooo`<02NX::`3oool00`000000oooo0?oo
o`0C0?ooo`00o`3ooooo0?ooojT0oooo0P09jPY50?ooo`802NX:303oool300WZ2Rh0oooo00<00000
0?ooo`3oool04`3oool00?l0ooooo`3ooonV0?ooo`<02NX:A03oool300WZ2PX0oooo1009jPXa0?oo
o`030000003oool0oooo01<0oooo003o0?ooool0ooooY03oool200WZ2T@0oooo0`09jPX:0?ooo`<0
2NX:=@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?oooj40oooo0`09jPY30?ooo`<02NX:
2@3oool400WZ2SP0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooonO0?ooo`802NX:@`3o
ool300WZ2PT0oooo0`09jPXl0?ooo`030000003oool0oooo01<0oooo003o0?ooool0ooooW@3oool2
00WZ2T80oooo0`09jPX80?ooo`@02NX:?`3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?oo
oiX0oooo0`09jPY20?ooo`802NX:203oool300WZ2T<0oooo00<000000?ooo`3oool04`3oool00?l0
ooooo`3ooonH0?ooo`802NX:@P3oool300WZ2PL0oooo0`09jPY60?ooo`030000003oool0oooo01<0
oooo003o0?ooool0ooooU@3oool300WZ2T40oooo0`09jPX60?ooo`@02NX:B@3oool00`000000oooo
0?ooo`0C0?ooo`00o`3ooooo0?oooi<0oooo0P09jPY10?ooo`<02NX:1P3oool300WZ2Td0oooo00<0
00000?ooo`3oool04`3oool00?l0ooooo`3ooon@0?ooo`<02NX:@03oool300WZ2PD0oooo1009jPY@
0?ooo`030000003oool0oooo01<0oooo003o0?ooool0ooooSP3oool200WZ2T40oooo0P09jPX50?oo
o`<02NX:E03oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?oooh/0oooo0`09jPY00?ooo`<0
2NX:103oool300WZ2UL0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooon90?ooo`802NX:
@03oool300WZ2P<0oooo1009jPYJ0?ooo`030000003oool0oooo01<0oooo003o0?ooool0ooooQP3o
ool300WZ2Sl0oooo0`09jPX30?ooo`<02NX:GP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo
0?oooh@0oooo0P09jPXo0?ooo`<02NX:0P3oool400WZ2V40oooo00<000000?ooo`3oool04`3oool0
0?l0ooooo`3ooon10?ooo`<02NX:?P3oool300WZ2P80oooo0`09jPYU0?ooo`030000003oool0oooo
01<0oooo003o0?ooool0ooooO`3oool200WZ2Sl0oooo0P09jPX20?ooo`<02NX:J03oool00`000000
oooo0?ooo`0C0?ooo`00o`3ooooo0?ooogd0oooo0P09jPXn0?ooo`L02NX:J`3oool00`000000oooo
0?ooo`0C0?ooo`00o`3ooooo0?ooogX0oooo0`09jPXm0?ooo`H02NX:K`3oool00`000000oooo0?oo
o`0C0?ooo`00o`3ooooo0?ooogP0oooo0P09jPXm0?ooo`H02NX:LP3oool00`000000oooo0?ooo`0C
0?ooo`00o`3ooooo0?ooogD0oooo0`09jPXl0?ooo`D02NX:MP3oool00`000000oooo0?ooo`0C0?oo
o`00o`3ooooo0?ooog<0oooo0P09jPXm0?ooo`@02NX:N@3oool00`000000oooo0?ooo`0C0?ooo`00
o`3ooooo0?ooog00oooo0`09jPXl0?ooo`<02NX:O@3oool00`000000oooo0?ooo`0C0?ooo`00o`3o
oooo0?ooofh0oooo0P09jPXl0?ooo`<02NX:P03oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo
0?ooof/0oooo0`09jPXj0?ooo`@02NX:P`3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?oo
ofT0oooo0P09jPXj0?ooo`@02NX:QP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?ooofH0
oooo0`09jPXh0?ooo`D02NX:R@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?ooof@0oooo
0P09jPXh0?ooo`D02NX:S03oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?ooof40oooo0`09
jPXg0?ooo`H02NX:SP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?oooel0oooo0P09jPXf
0?ooo`L02NX:T@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?oooe`0oooo0`09jPXe0?oo
o`<02NX:00@0oooo00WZ2P09jPX02NX:U03oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?oo
oeX0oooo0P09jPXd0?ooo`@02NX:00@0oooo00WZ2P09jPX02NX:U`3oool00`000000oooo0?ooo`0C
0?ooo`00o`3ooooo0?oooeP0oooo0P09jPXc0?ooo`<02NX:0`3oool200WZ2YX0oooo00<000000?oo
o`3oool04`3oool00?l0ooooo`3ooomE0?ooo`<02NX:<P3oool300WZ2P<0oooo0`09jPZJ0?ooo`03
00WZ2P000000000001D0oooo003o0?ooool0ooooD`3oool200WZ2S40oooo1009jPX30?ooo`<02NX:
V@3oool400WZ2P030?ooo`000000000001D0oooo003o0?ooool0ooooD03oool300WZ2S00oooo0`09
jPX40?ooo`<02NX:V03oool400WZ2PH0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooom>
0?ooo`802NX:;`3oool400WZ2P@0oooo0`09jPZF0?ooo`D02NX:2P3oool00`000000oooo0?ooo`0C
0?ooo`00o`3ooooo0?oood/0oooo0`09jPX^0?ooo`<02NX:1@3oool300WZ2YD0oooo1009jPX?0?oo
o`030000003oool0oooo01<0oooo003o0?oooj80oooo2@00002M0?ooo`802NX:;@3oool400WZ2PH0
oooo0P09jPZD0?ooo`@02NX:4`3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0V@3oool300WZ2R`0oooo0`09jPX70?ooo`<02NX:
TP3oool400WZ2QL0oooo00<000000?ooo`3oool04`3oool00?l0ooooXP3oool00`000000Ogmo07mo
O`0407moO`030000003oool0oooo09L0oooo0P09jPX/0?ooo`<02NX:1`3oool300WZ2Y40oooo1009
jPXK0?ooo`030000003oool0oooo01<0oooo003o0?oooj80oooo00<0000007moO`1oOgl0101oOgl0
0`000000oooo0?ooo`2D0?ooo`<02NX::P3oool400WZ2PL0oooo0`09jPZ?0?ooo`D02NX:7`3oool0
0`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?oo
o`3oool0TP3oool200WZ2RX0oooo0`09jPX80?ooo`<02NX:SP3oool400WZ2R@0oooo00<000000?oo
o`3oool04`3oool00?l0ooooXP3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo08l0
oooo0`09jPXX0?ooo`@02NX:2@3oool200WZ2Xd0oooo1009jPXX0?ooo`030000003oool0oooo01<0
oooo003o0?oooj80oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`2=0?ooo`802NX:
:03oool300WZ2PX0oooo0`09jPZ;0?ooo`@02NX:;03oool00`000000oooo0?ooo`0C0?ooo`00o`3o
oonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0R`3oool200WZ2RL0oooo0`09
jPX:0?ooo`<02NX:RP3oool400WZ2S00oooo00<000000?ooo`3oool04`3oool00?l0ooooXP3oool0
0`000000Ogmo07moO`0407moO`030000003oool0oooo08P0oooo0`09jPXU0?ooo`@02NX:2P3oool3
00WZ2XT0oooo1009jPXd0?ooo`030000003oool0oooo01<0oooo003o0?oooj80oooo00<0000007mo
O`1oOgl0101oOgl00`000000oooo0?ooo`260?ooo`802NX:9@3oool300WZ2P/0oooo0`09jPZ70?oo
o`D02NX:>03oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0
Ogmo00<000000?ooo`3oool0P`3oool300WZ2R<0oooo1009jPX;0?ooo`<02NX:QP3oool400WZ2Sd0
oooo00<000000?ooo`3oool04`3oool00?l0ooooXP3oool00`000000Ogmo07moO`0407moO`030000
003oool0oooo0840oooo0P09jPXS0?ooo`<02NX:3@3oool200WZ2XD0oooo1009jPY10?ooo`030000
003oool0oooo01<0oooo003o0?oooj80oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?oo
o`1n0?ooo`<02NX:8@3oool400WZ2Pd0oooo0`09jPZ30?ooo`@02NX:A@3oool00`000000oooo0?oo
o`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0O03oool2
00WZ2R40oooo0`09jPX>0?ooo`<02NX:PP3oool400WZ2TT0oooo00<000000?ooo`3oool04`3oool0
0?l0ooooXP3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo07T0oooo0`09jPXP0?oo
o`<02NX:3P3oool300WZ2X00oooo1@09jPY=0?ooo`030000003oool0oooo01<0oooo003o0?oooj80
oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1g0?ooo`802NX:7`3oool400WZ2Ph0
oooo0`09jPYo0?ooo`@02NX:DP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0M03oool300WZ2Qh0oooo0`09jPX@0?ooo`802NX:
OP3oool400WZ2UH0oooo00<000000?ooo`3oool04`3oool00?l0ooooXP3oool00`000000Ogmo07mo
O`0407moO`030000003oool0oooo0780oooo0P09jPXM0?ooo`@02NX:403oool300WZ2W`0oooo1009
jPYJ0?ooo`030000003oool0oooo01<0oooo003o0?oooj80oooo00<0000007moO`1oOgl0101oOgl0
0`000000oooo0?ooo`1_0?ooo`<02NX:703oool300WZ2Q40oooo0`09jPYk0?ooo`@02NX:GP3oool0
0`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?oo
o`3oool0K@3oool200WZ2Q`0oooo0`09jPXA0?ooo`<02NX:NP3oool400WZ2V80oooo00<000000?oo
o`3oool04`3oool00?l0ooooXP3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo06/0
oooo0P09jPXJ0?ooo`@02NX:4@3oool300WZ2WP0oooo1@09jPYV0?ooo`030000003oool0oooo01<0
oooo003o0?oooj80oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1X0?ooo`<02NX:
6@3oool300WZ2Q80oooo0`09jPYg0?ooo`@02NX:J`3oool00`000000oooo0?ooo`0C0?ooo`00o`3o
oonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0IP3oool200WZ2QP0oooo1009
jPXC0?ooo`802NX:MP3oool400WZ2Vl0oooo00<000000?ooo`3oool04`3oool00?l0ooooXP3oool0
0`000000Ogmo07moO`0407moO`030000003oool0oooo06<0oooo0`09jPXG0?ooo`<02NX:503oool3
00WZ2W@0oooo1009jPYc0?ooo`030000003oool0oooo01<0oooo003o0?oooj80oooo00<0000007mo
O`1oOgl0101oOgl00`000000oooo0?ooo`1Q0?ooo`802NX:5`3oool300WZ2Q@0oooo0`09jPYc0?oo
o`@02NX:M`3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0
Ogmo00<000000?ooo`3oool0GP3oool300WZ2QD0oooo1009jPXD0?ooo`<02NX:L@3oool500WZ2W/0
oooo00<000000?ooo`3oool04`3oool00?l0ooooXP3oool00`000000Ogmo07moO`0407moO`030000
003oool0oooo05`0oooo0P09jPXE0?ooo`<02NX:5@3oool300WZ2W00oooo1009jPZ00?ooo`030000
003oool0oooo01<0oooo003o0?oooj80oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?oo
o`1I0?ooo`<02NX:4`3oool400WZ2QH0oooo0P09jPY_0?ooo`@02NX:Q03oool00`000000oooo0?oo
o`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0E`3oool2
00WZ2Q<0oooo0`09jPXG0?ooo`<02NX:K@3oool400WZ2XP0oooo00<000000?ooo`3oool04`3oool0
0?l0ooooXP3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo05@0oooo0`09jPXA0?oo
o`@02NX:5`3oool300WZ2V`0oooo1009jPZ<0?ooo`030000003oool0oooo01<0oooo003o0?oooj80
oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1B0?ooo`802NX:4@3oool300WZ2QP0
oooo0`09jPY[0?ooo`@02NX:T03oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0C`3oool300WZ2Q00oooo0`09jPXH0?ooo`<02NX:
J@3oool500WZ2Y<0oooo0P00000E0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool0C@3oool200WZ2Pl0oooo1009jPXH0?ooo`<02NX:J03oool400WZ2Y<0oooo1@09
jPX2000001D0oooo003o0?oooj80oooo2000001=0?ooo`802NX:3P3oool300WZ2QX0oooo0P09jPYW
0?ooo`@02NX:R`3oool<00WZ2PH0oooo00<000000?ooo`3oool04`3oool00?l0ooooXP3oool00`00
0000Ogmo07moO`0407moO`030000003oool0oooo04P0oooo0`09jPX<0?ooo`@02NX:6P3oool300WZ
2VD0oooo1009jPZ30?ooo``02NX:4P3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`03
0000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0AP3oool200WZ2P`0oooo0`09jPXK0?ooo`<0
2NX:I03oool400WZ2WX0oooo3@09jPXN0?ooo`030000003oool0oooo01<0oooo003o0?oooj80oooo
00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`130?ooo`<02NX:2`3oool300WZ2Q/0oooo
0`09jPYR0?ooo`D02NX:LP3oool<00WZ2R/0oooo00<000000?ooo`3oool04`3oool00?l0ooooXP3o
ool00`000000Ogmo07moO`0407moO`030000003oool0oooo0440oooo0P09jPX:0?ooo`@02NX:6`3o
ool300WZ2V40oooo1009jPY[0?ooo``02NX:=`3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR
0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0?P3oool300WZ2PT0oooo0`09jPXM
0?ooo`802NX:H03oool400WZ2V<0oooo3009jPY30?ooo`030000003oool0oooo01<0oooo003o0?oo
oj80oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0l0?ooo`802NX:203oool400WZ
2Qd0oooo0`09jPYN0?ooo`@02NX:F`3oool<00WZ2Tl0oooo00<000000?ooo`3oool04`3oool00?l0
ooooXP3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo03T0oooo0`09jPX70?ooo`<0
2NX:7P3oool300WZ2Ud0oooo1009jPYC0?ooo``02NX:F`3oool00`000000oooo0?ooo`0C0?ooo`00
o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=`3oool200WZ2PL0oooo
0`09jPXN0?ooo`<02NX:F`3oool500WZ2T/0oooo3009jPYV0?ooo`8000005@3oool00?l0ooooXP3o
ool00`000000Ogmo07moO`0407moO`030000003oool0oooo03@0oooo0`09jPX50?ooo`@02NX:7P3o
ool300WZ2UX0oooo1009jPY30?ooo`d02NX:K03oool600WZ2P8000005@3oool00?l0ooooXP3oool0
0`000000Ogmo07moO`0407moO`030000003oool0oooo0380oooo0P09jPX50?ooo`<02NX:7`3oool3
00WZ2UT0oooo1009jPXk0?ooo``02NX:JP3oool?00WZ2PL0oooo00<000000?ooo`3oool04`3oool0
0?l0ooooXP3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo02l0oooo0`09jPX30?oo
o`@02NX:803oool200WZ2UP0oooo1009jPXc0?ooo``02NX:J03oool>00WZ2QH0oooo00<000000?oo
o`3oool04`3oool00?l0ooooXP3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo02d0
oooo0P09jPX30?ooo`<02NX:8@3oool300WZ2UH0oooo1009jPX[0?ooo``02NX:IP3oool>00WZ2R@0
oooo00<000000?ooo`3oool04`3oool00?l0ooooXP3oool00`000000Ogmo07moO`0407moO`030000
003oool0oooo02/0oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2R40oooo0`09jPYE0?ooo`@02NX:
8`3oool<00WZ2V<0oooo3`09jPXb0?ooo`030000003oool0oooo01<0oooo003o0?oooj80oooo00<0
000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0X0?ooo`H02NX:8P3oool300WZ2U<0oooo1@09
jPXK0?ooo``02NX:H@3oool>00WZ2T40oooo00<000000?ooo`3oool04`3oool00?l0ooooXP3oool0
0`000000Ogmo07moO`0407moO`030000003oool0oooo02H0oooo1@09jPXR0?ooo`<02NX:DP3oool4
00WZ2Q<0oooo3@09jPYN0?ooo`l02NX:C`3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?oo
o`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool08`3oool500WZ2R<0oooo0P09jPYA0?oo
o`@02NX:2`3oool<00WZ2Ud0oooo3P09jPYN0?ooo`030000003oool0oooo01<0oooo003o0?oooj80
oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0Q0?ooo`<02NX:903oool300WZ2Tl0
oooo1009jPX30?ooo``02NX:F`3oool>00WZ2V`0oooo00<000000?ooo`3oool04`3oool00?l0oooo
XP3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo01d0oooo1009jPXT0?ooo`<02NX:
C@3oool<00WZ2UP0oooo3`09jPYj0?ooo`030000003oool0oooo01<0oooo003o0?oooj80oooo00<0
000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0J0?ooo`@02NX:903oool300WZ2T@0oooo3@09
jPYE0?ooo`h02NX:R@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool05`3oool500WZ2R<0oooo0`09jPXk0?ooo``02NX:103oool4
00WZ2T/0oooo3`09jPZG0?ooo`030000003oool0oooo01<0oooo003o0?oooj80oooo00<0000007mo
O`1oOgl0101oOgl00`000000oooo0?ooo`0C0?ooo`H02NX:8`3oool300WZ2S40oooo3@09jPX<0?oo
o`@02NX:@@3oool>00WZ2ZH0oooo00<000000?ooo`3oool04`3oool00?l0ooooXP3oool00`000000
Ogmo07moO`0407moO`030000003oool0oooo0100oooo0`09jPX0103oool02NX:00WZ2P09jPXS0?oo
o`802NX::03oool<00WZ2QD0oooo1009jPXf0?ooo`l02NX:]03oool00`000000oooo0?ooo`0C0?oo
o`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0303oool400WZ2P80
oooo0P09jPXS0?ooo`<02NX:7P3oool<00WZ2Qd0oooo1009jPX/0?ooo`h02NX:``3oool00`000000
oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
2@3oool300WZ2P<0oooo0`09jPXR0?ooo`<02NX:5@3oool<00WZ2RD0oooo1009jPXR0?ooo`h02NX:
d@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool01P3oool300WZ2P@0oooo0P09jPXR0?ooo`<02NX:303oool<00WZ2R`0oooo1@09
jPXG0?ooo`l02NX:g`3oool00`000000oooo0?ooo`0C0?ooo`00503ooooo00WZ2Xd02NX:00<00000
00WZ2P09jPX00`09jPX207moO`030000003oool0oooo0080oooo1009jPX50?ooo`802NX:8@3oool3
00WZ2P<0oooo3009jPXd0?ooo`@02NX:3P3oool>00WZ2^h0oooo00<000000?ooo`3oool04`3oool0
01@0ooooo`09jPZ=00WZ2P0300000009jPX02NX:00/02NX:1@3oool300WZ2Qd0oooo3009jPXl0?oo
o`@02NX:0`3oool?00WZ2_`0oooo00<000000?ooo`3oool04`3oool001@0ooooo`09jPZ=00WZ2P03
00000009jPX02NX:01D02NX:3P3oool=00WZ2P040?ooo`09jPX02NX:00WZ2Sd0oooo3P09jP[o0?oo
o``0oooo00<000000?ooo`3oool04`3oool001@0ooooo`09jPZ=00WZ2P0300000009jPX02NX:02<0
2NX:2`3oool300WZ2S80oooo4@09jP[o0?oooaL0oooo00<000000?ooo`3oool04`3oool001@0oooo
o`09jPZ=00WZ2P0300000009jPX02NX:02P02NX:0`3oool300WZ2RH0oooo3`09jPX80?ooo`D02NX:
o`3ooolK0?ooo`030000003oool0oooo01<0oooo000D0?ooool02NX:S@09jPX00`0000002NX:00WZ
2P0b00WZ2Q@0oooo3P09jPXC0?ooo`@02NX:o`3ooolP0?ooo`030000003oool0oooo01<0oooo000D
0?ooool02NX:S@09jPX00`0000002NX:00WZ2P0600WZ2P030000003oool0oooo00d0oooo<009jPXM
0?ooo`@02NX:o`3ooolT0?ooo`030000003oool0oooo01<0oooo000D0?ooool02NX:S@09jPX00`00
00002NX:00WZ2P0<00WZ2QD0oooo9009jPXJ0?ooo`@02NX:o`3ooolX0?ooo`030000003oool0oooo
01<0oooo000D0?ooool02NX:S@09jPX00`0000002NX:00WZ2P0507moO`8000001@3oool<00WZ2P<0
oooo3P09jPX30?ooob<02NX:303oool400WZ2_l0oooo;03oool00`000000oooo0?ooo`0C0?ooo`00
503ooooo00WZ2Xd02NX:00<0000000WZ2P09jPX08`09jPXD0?ooob@02NX:o`3oool`0?ooo`030000
003oool0oooo01<0oooo000D0?ooool02NX:S@09jPX00`0000002NX:00WZ2P0I00WZ2P040?ooo`09
jPX02NX:00WZ2PH0oooo3009jPXB0?ooob402NX:o`3ooolY0?ooo`030000003oool0oooo01<0oooo
000D0?ooool02NX:S@09jPX00`0000002NX:00WZ2P0U00WZ2PX0oooo3009jPXA0?ooob002NX:o`3o
oolO0?ooo`030000003oool0oooo01<0oooo000D0?ooool02NX:S@09jPX00`0000002NX:00WZ2P0=
00WZ2P80oooo8`09jPX90?ooo``02NX:0`3oool400WZ2PT0oooo7`09jP[o0?oooaD0oooo00<00000
0?ooo`3oool04`3oool001@0ooooo`09jPZ=00WZ2P0300000009jPX02NX:01/02NX:1P3ooolM00WZ
2PP0oooo3@09jPX?0?oooah02NX:o`3oool;0?ooo`030000003oool0oooo01<0oooo000D0?ooool0
2NX:S@09jPX00`0000002NX:00WZ2P0Y00WZ2PT0oooo6@09jPX80?ooo`/02NX:3`3ooolL00WZ2_l0
oooo0P3oool00`000000oooo0?ooo`0C0?ooo`00503ooooo00WZ2Xd02NX:00<0000000WZ2P09jPX0
=`09jPX60?oooa/02NX:1P3oool<00WZ2Pd0oooo7009jP[g0?ooo`030000003oool0oooo01<0oooo
000D0?ooool02NX:S@09jPX00`0000002NX:00WZ2P1500WZ2PP0oooo6P09jPX30?ooo``02NX:303o
oolK00WZ2^d0oooo00<000000?ooo`3oool04`3oool001@0ooooo`09jPZ=00WZ2P0300000009jPX0
2NX:05802NX:203ooolX00WZ2P/0oooo6@09jP[T0?ooo`030000003oool0oooo01<0oooo000D0?oo
ool02NX:S@09jPX00`0000002NX:00WZ2P1P00WZ2PL0oooo9`09jPX:0?oooaP02NX:fP3oool00`00
0000oooo0?ooo`0C0?ooo`00503ooooo00WZ2Xd02NX:00<0000000WZ2P09jPX0KP09jPX60?oooaH0
2NX:00<0oooo00WZ2P09jPX03`09jPX70?oooaL02NX:d03oool00`000000oooo0?ooo`0C0?ooo`00
503ooooo00WZ2Xd02NX:00<0000000WZ2P09jPX0O009jPX50?oooaD02NX:0`3oool[00WZ2/H0oooo
00<000000?ooo`3oool04`3oool001@0ooooo`09jPZ=00WZ2P0300000009jPX02NX:08X02NX:103o
oolE00WZ2P80oooo:009jPZZ0?oooa802NX:0P00000E0?ooo`00503ooooo00WZ2Xd02NX:00<00000
00WZ2P09jPX0V009jPX30?oooa@02NX:0P3oool<00WZ2P<0oooo5`09jPYi0?ooobL02NX:4P3oool2
000001D0oooo000D0?ooool02NX:S@09jPX00`0000002NX:00WZ2P0A00WZ2P030?ooo`09jPX02NX:
09802NX:0P3ooolD00WZ2P030?ooo`09jPX02NX:00X02NX:1@3ooolE00WZ2TH0oooo9`09jPXj0?oo
o`030000003oool0oooo01<0oooo000D0?ooool02NX:S@09jPX00`0000002NX:00WZ2P0X00WZ2P80
ooooRP09jPX00`3oool02NX:00WZ2P0M00WZ2P@0oooo7@09jPX=0?ooobL02NX:H@3oool00`000000
oooo0?ooo`0C0?ooo`00503ooooo00WZ2Xd02NX:00<0000000WZ2P09jPX0?`09jPX40?oool<02NX:
Q03oool00`000000oooo0?ooo`0C0?ooo`00503ooooo00WZ2Xd02NX:00<0000000WZ2P09jPX0EP09
jPX50?oooj<02NX:203ooolB00WZ2W80oooo00<000000?ooo`3oool04`3oool001@0ooooo`09jPZ=
00WZ2P0300000009jPX02NX:06d02NX:1P3ooonE00WZ2Q00oooo4P09jPYP0?ooo`030000003oool0
oooo01<0oooo000D0?ooool02NX:S@09jPX00`0000002NX:00WZ2P3o00WZ2Q802NX:6@3ooolA00WZ
2Tl0oooo00<000000?ooo`3oool04`3oool001@0ooooo`09jPZ=00WZ2P0300000009jPX02NX:09/0
2NX:1@3ooomk00WZ2R00oooo4P09jPXm0?ooo`030000003oool0oooo01<0oooo000D0?ooool02NX:
S@09jPX00`0000002NX:00WZ2P0200WZ2P<0Ogmo0P00000A0?oooiX02NX:0P3oooma00WZ2RP0oooo
4P09jPXC0?oooaL02NX:0P00000E0?ooo`00503ooooo00WZ2Xd02NX:00<0000000WZ2P09jPX07009
jPXO0?oooo@02NX:4P3ooola00WZ2QL0oooo0P00000E0?ooo`00o`3ooonQ0?ooo`8000001P1oOgl2
000001D0oooo:`09jPXG0?ooon<02NX:;`3ooolB00WZ2PL0oooo0P00000E0?ooo`00503ooooo00WZ
2Xd02NX:00<0000000WZ2P09jPX08P09jPXU0?ooob/02NX:403oooo300WZ2Sd0oooo1`09jPX20000
01D0oooo000D0?ooool02NX:S@09jPX00`0000002NX:00WZ2P1I00WZ2QT0oooo:`09jPX80?oooj/0
2NX:>P3oool00`000000oooo0?ooo`0C0?ooo`00503ooooo00WZ2Xd02NX:00<0000000WZ2P09jPX0
o`09jPYK00WZ2S00oooo00<000000?ooo`3oool04`3oool001@0ooooo`09jPZ=00WZ2P0300000009
jPX02NX:0?l02NX:J009jPXS0?ooo`030000003oool0oooo01<0oooo000D0?ooool02NX:S@09jPX0
0`0000002NX:00WZ2P3o00WZ2X002NX:2P3oool2000001D0oooo000D0?ooool02NX:S@09jPX00`00
00002NX:00WZ2P3o00WZ2W`02NX:103oool:00WZ2P8000005@3oool00?l0ooooX@3oool2000000H0
Ogmo0P00001P0?ooool02NX:8009jPX40?ooo`030000003oool0oooo01<0oooo000D0?ooool02NX:
S@09jPX00`0000002NX:00WZ2P3o00WZ2XX02NX:0P00000E0?ooo`00503ooooo00WZ2Xd02NX:00<0
000000WZ2P09jPX0o`09jPZ600WZ2P040?ooo`09jPX02NX:00WZ2P8000005@3oool001@0ooooo`09
jPZ=00WZ2P0300000009jPX02NX:0?l02NX:O009jPX?0?ooo`030000003oool0oooo01<0oooo000D
0?ooool02NX:S@09jPX00`0000002NX:00WZ2P3o00WZ2W802NX:6@3oool00`000000oooo0?ooo`0C
0?ooo`00503ooooo00WZ2Xd02NX:00<0000000WZ2P09jPX0o`09jPZ:00WZ2P8000005@3oool001@0
ooooo`09jPZ=00WZ2P0300000009jPX02NX:0?l02NX:GP09jPX/0?ooo`8000005@3oool001@0oooo
o`09jPZ=00WZ2P0300000009jPX02NX:0;@02NX:0`3ooom=00WZ2P030?ooo`09jPX02NX:04`02NX:
=`3oool00`000000oooo0?ooo`0C0?ooo`00503ooooo00WZ2Xd02NX:00<0000000WZ2P09jPX0S@09
jPX:0?oooeD02NX:103ooomI00WZ2T40oooo00<000000?ooo`3oool04`3oool001@0ooooo`09jPZ=
00WZ2P0300000009jPX02NX:06H02NX:403ooomN00WZ2PP0ooooH`09jPY;0?ooo`030000003oool0
oooo01<0oooo000D0?ooool02NX:S@09jPX00`0000002NX:00WZ2P0o00WZ2QL0ooooI@09jPX<0?oo
ofh02NX:E@3oool00`000000oooo0?ooo`0C0?ooo`00503ooooo00WZ2Xd02NX:00<0000000WZ2P09
jPX06009jPXN0?ooofd02NX:403ooomh00WZ2Ul0oooo00<000000?ooo`3oool04`3oool001@0oooo
o`09jPZ=00WZ2P0300000009jPX02NX:00<02NX:0P1oOgl2000000h0ooooMP09jPXD0?oooh802NX:
J@3oool00`000000oooo0?ooo`0C0?ooo`00503ooooo00WZ2Xd02NX:00<0000000WZ2P09jPX0LP09
jPXH0?ooohd02NX:L`3oool00`000000oooo0?ooo`0C0?ooo`00503ooooo00WZ2Xd02NX:00<00000
00WZ2P09jPX0FP09jPXL0?oooiL02NX:O@3oool00`000000oooo0?ooo`0C0?ooo`00503ooooo00WZ
2Xd02NX:00<0000000WZ2P09jPX0@P09jPXO0?oooj802NX:QP3oool2000001D0oooo003o0?oooj40
oooo0P00000307moObP02NX:8`3ooon/00WZ2XH0oooo2P09jPX2000001D0oooo000D0?ooool02NX:
S@09jPX00`0000002NX:00WZ2P0A00WZ2QT0oooo2P09jPX40?oookL02NX:N`3ooolE00WZ2P/0oooo
00<000000?ooo`3oool04`3oool001@0ooooo`09jPZ=00WZ2P0300000009jPX02NX:00<02NX:0P1o
Ogl2000001d0ooooW@09jPX00`3oool02NX:00WZ2P0Q00WZ2Vl0oooo5P09jPXP0?ooo`030000003o
ool0oooo01<0oooo003o0?oooj40oooo0P00000407moO`H02NX:1P3ooonV00WZ2P030?ooo`09jPX0
2NX:02<02NX:H`3ooolF00WZ2SH0oooo00<000000?ooo`3oool04`3oool001@0ooooo`09jPZ=00WZ
2P0300000009jPX02NX:0:T02NX:0P3ooolV00WZ2UP0oooo5@09jPY<0?ooo`030000003oool0oooo
01<0oooo000D0?ooool02NX:S@09jPX00`0000002NX:00WZ2P2M00WZ2P80oooo6009jPX00`3oool0
2NX:00WZ2P0=00WZ2T`0oooo5P09jPYQ0?ooo`030000003oool0oooo01<0oooo000D0?ooool02NX:
S@09jPX00`0000002NX:00WZ2P2A00WZ2P<0oooo6009jPX20?oooa002NX:@03ooolE00WZ2WL0oooo
00<000000?ooo`3oool04`3oool00?l0ooooX@3oool2000000<0OgmoP`09jPX40?oooaT02NX:0P3o
ool@00WZ2S@0oooo5P09jPZ<0?ooo`030000003oool0oooo01<0oooo000D0?ooool02NX:S@09jPX0
0`0000002NX:00WZ2P1l00WZ2P030?ooo`09jPX02NX:01P02NX:0P3ooolA00WZ2RP0oooo5P09jPZR
0?ooo`030000003oool0oooo01<0oooo000D0?ooool02NX:S@09jPX00`0000002NX:00WZ2P1/00WZ
2PH0oooo6P09jPX30?oooa402NX:7@3ooolE00WZ2[P0oooo00<000000?ooo`3oool04`3oool001@0
ooooo`09jPZ=00WZ2P0300000009jPX02NX:06002NX:1P3ooolK00WZ2P@0oooo4@09jPXA0?oooaH0
2NX:c@3oool00`000000oooo0?ooo`0C0?ooo`00503ooooo00WZ2Xd02NX:00<0000000WZ2P09jPX0
E009jPX70?oooa/02NX:1@3ooolA00WZ2P@0oooo5`09jP[S0?ooo`030000003oool0oooo01<0oooo
000D0?ooool02NX:S@09jPX00`0000002NX:00WZ2P1800WZ2PL0oooo7@09jPX40?ooob402NX:2@3o
ool;00WZ2^D0oooo00<000000?ooo`3oool04`3oool001@0ooooo`09jPZ=00WZ2P0300000009jPX0
2NX:03`02NX:203ooolM00WZ2PD0oooo5P09jPXY0?ooo`X02NX:f`3oool00`000000oooo0?ooo`0C
0?ooo`00503ooooo00WZ2Xd02NX:00<0000000WZ2P09jPX0<009jPX80?ooocH02NX:@@3oool:00WZ
2]40oooo00<000000?ooo`3oool04`3oool00?l0ooooX@3oool20000000307moO`09jPX02NX:0240
2NX:2P3ooolT00WZ2P030?ooo`09jPX02NX:01002NX:E@3oool:00WZ2/L0oooo00<000000?ooo`3o
ool04`3oool001@0ooooo`09jPZ=00WZ2P0300000009jPX02NX:01L02NX:2`3ooolN00WZ2PL0oooo
4`09jPYY0?ooo`/02NX:_03oool00`000000oooo0?ooo`0C0?ooo`00503ooooo00WZ2Xd02NX:00<0
000000WZ2P09jPX02`09jPX50?ooobH02NX:1`3ooolD00WZ2Wd0oooo2P09jPZb0?ooo`030000003o
ool0oooo01<0oooo000D0?ooool02NX:S@09jPX00`0000002NX:00WZ2P0[00WZ2PP0oooo4`09jPX;
0?ooo`D02NX:PP3oool:00WZ2ZP0oooo00<000000?ooo`3oool04`3oool001@0ooooo`09jPZ=00WZ
2P0300000009jPX02NX:02002NX:2@3ooolC00WZ2QX0oooo1P09jPZ60?ooo`X02NX:WP3oool00`00
0000oooo0?ooo`0C0?ooo`00503ooooo00WZ2Xd02NX:00<0000000WZ2P09jPX05@09jPX:0?oooa<0
2NX::P3oool500WZ2X/0oooo2`09jPZC0?ooo`030000003oool0oooo01<0oooo000D0?ooool02NX:
S@09jPX00`0000002NX:00WZ2P0:00WZ2P80oooo0P09jPX60?oooa@02NX:>@3oool500WZ2Y40oooo
2P09jPZ90?ooo`030000003oool0oooo01<0oooo000D0?ooool02NX:S@09jPX00`0000002NX:00WZ
2P0200WZ2P<0Ogmo0P0000030?oooa@02NX:B03oool500WZ2YH0oooo2P09jPYo0?ooo`030000003o
ool0oooo01<0oooo000D0?ooool02NX:S@09jPX00`0000002NX:00WZ2P0D00WZ2UL0oooo1@09jPZK
0?ooo`X02NX:M@3oool00`000000oooo0?ooo`0C0?ooo`00503ooooo00WZ2Xd02NX:00<0000000WZ
2P09jPX02P09jPX90?ooo`<02NX:FP3oool600WZ2Yl0oooo2`09jPYZ0?ooo`030000003oool0oooo
01<0oooo000D0?ooool02NX:S@09jPX00`0000002NX:00WZ2P0200WZ2P<0Ogmo0P0000000`3oool0
2NX:00WZ2P0200WZ2PX0oooo0P09jPYN0?ooo`D02NX:Y@3oool:00WZ2V00oooo00<000000?ooo`3o
ool04`3oool00?l0ooooX@3oool2000000H0Ogmo00<000000?ooo`3oool0103oool300WZ2PT0oooo
0P09jPYQ0?ooo`D02NX:ZP3oool:00WZ2UH0oooo00<000000?ooo`3oool04`3oool00?l0ooooXP3o
ool00`000000Ogmo07moO`0407moO`030000003oool0oooo00L0oooo1009jPX70?ooo`<02NX:H`3o
ool500WZ2Zl0oooo2P09jPY<0?ooo`030000003oool0oooo01<0oooo003o0?oooj80oooo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`0;0?ooo`@02NX:1P3oool200WZ2VH0oooo1@09jPZd
0?ooo`X02NX:@P3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo
00@0Ogmo00<000000?ooo`3oool03`3oool400WZ2P@0oooo0`09jPYX0?ooo`D02NX:^@3oool;00WZ
2SL0oooo00<000000?ooo`3oool04`3oool00?l0ooooXP3oool00`000000Ogmo07moO`0407moO`03
0000003oool0oooo01<0oooo1009jPX30?ooo`802NX:J`3oool600WZ2[h0oooo2P09jPX]0?ooo`03
0000003oool0oooo01<0oooo003o0?oooj80oooo00<0000007moO`1oOgl0101oOgl00`000000oooo
0?ooo`0G0?ooo`<02NX:0P3oool200WZ2Vl0oooo1@09jP[30?ooo`X02NX:8`3oool00`000000oooo
0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool06P3o
ool700WZ2W40oooo1@09jP[80?ooo`X02NX:6@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR
0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool07P3oool500WZ2W@0oooo1@09jP[=
0?ooo`/02NX:3P3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo
00@0Ogmo00<000000?ooo`3oool08P3oool400WZ2WH0oooo1@09jP[C0?ooo`X02NX:103oool00`00
0000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3o
ool09P3oool300WZ2WP0oooo1P09jP[G0?ooo`<02NX:0P00000E0?ooo`00o`3ooonR0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0:03oool500WZ2WX0oooo1@09jP[E0?ooo`800000
5@3oool00?l0ooooXP3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo02X0oooo1`09
jPYk0?ooo`D02NX:d@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool0;@3oool200WZ2P80oooo1009jPYl0?ooo`D02NX:c03oool0
0`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?oo
o`3oool0;`3oool300WZ2P<0oooo1009jPYm0?ooo`D02NX:a`3oool00`000000oooo0?ooo`0C0?oo
o`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0<P3oool200WZ2PD0
oooo0`09jPYo0?ooo`H02NX:`@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=03oool200WZ2PH0oooo1009jPZ10?ooo`D02NX:
_03oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool0=P3oool300WZ2PL0oooo1009jPZ20?ooo`D02NX:]`3oool00`000000oooo0?oo
o`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0>@3oool2
00WZ2PT0oooo1009jPZ30?ooo`D02NX:/P3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?oo
o`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0>`3oool300WZ2PX0oooo0`09jPZ50?oo
o`D02NX:[@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0
Ogmo00<000000?ooo`3oool0?P3oool200WZ2P/0oooo1009jPZ60?ooo`D02NX:Z03oool00`000000
oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
@03oool200WZ2Pd0oooo1009jPZ70?ooo`H02NX:XP3oool00`000000oooo0?ooo`0C0?ooo`00o`3o
oonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0@P3oool300WZ2Ph0oooo1009
jPZ90?ooo`D02NX:W@3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool0A@3oool200WZ2Q00oooo1009jPZ:0?ooo`D02NX:V03oool0
0`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?oo
o`3oool0A`3oool300WZ2Q40oooo0`09jPZ<0?ooo`D02NX:T`3oool00`000000oooo0?ooo`0C0?oo
o`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0BP3oool200WZ2Q80
oooo1009jPZ=0?ooo`D02NX:SP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`P00000
CP3oool200WZ2Q@0oooo1009jPZ>0?ooo`H02NX:R03oool00`000000oooo0?ooo`0C0?ooo`00o`3o
oonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0CP3oool300WZ2QD0oooo1009
jPZ@0?ooo`D02NX:P`3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool0D@3oool200WZ2QL0oooo0`09jPZB0?ooo`D02NX:OP3oool0
0`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?oo
o`3oool0D`3oool300WZ2QL0oooo1009jPZC0?ooo`D02NX:N@3oool00`000000oooo0?ooo`0C0?oo
o`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0EP3oool200WZ2QT0
oooo1009jPZD0?ooo`D02NX:M03oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0F03oool200WZ2Q/0oooo1009jPZE0?ooo`D02NX:
K`3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool0FP3oool300WZ2Q`0oooo1009jPZF0?ooo`H02NX:J@3oool00`000000oooo0?oo
o`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0G@3oool2
00WZ2Qh0oooo0`09jPZI0?ooo`D02NX:I03oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?oo
o`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0G`3oool300WZ2Qh0oooo1009jPZJ0?oo
o`D02NX:G`3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0
Ogmo00<000000?ooo`3oool0HP3oool200WZ2R00oooo1009jPZK0?ooo`D02NX:FP3oool00`000000
oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
I03oool200WZ2R80oooo1009jPZL0?ooo`D02NX:E@3oool00`000000oooo0?ooo`0C0?ooo`00o`3o
oonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0IP3oool300WZ2R<0oooo0`09
jPZN0?ooo`H02NX:C`3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool0J@3oool200WZ2R@0oooo1009jPZP0?ooo`D02NX:BP3oool0
0`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?oo
o`3oool0J`3oool300WZ2RD0oooo1009jPZQ0?ooo`D02NX:A@3oool00`000000oooo0?ooo`0C0?oo
o`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0KP3oool200WZ2RL0
oooo1009jPZR0?ooo`D02NX:@03oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0L03oool200WZ2RT0oooo1009jPZS0?ooo`D02NX:
>`3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool0LP3oool300WZ2RX0oooo0`09jPZU0?ooo`H02NX:=@3oool00`000000oooo0?oo
o`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0M@3oool2
00WZ2R/0oooo1009jPZW0?ooo`D02NX:<03oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?oo
o`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0M`3oool300WZ2R`0oooo1009jPZX0?oo
o`D02NX::`3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0
Ogmo00<000000?ooo`3oool0NP3oool200WZ2Rh0oooo1009jPZY0?ooo`D02NX:9P3oool00`000000
oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
O03oool200WZ2S00oooo0`09jPZ[0?ooo`D02NX:8@3oool00`000000oooo0?ooo`0C0?ooo`00o`3o
oonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0OP3oool300WZ2S00oooo1009
jPZ/0?ooo`D02NX:703oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool0P@3oool200WZ2S80oooo1009jPZ]0?ooo`H02NX:5P3oool0
0`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?oo
o`3oool0P`3oool300WZ2S<0oooo1009jPZ_0?ooo`D02NX:4@3oool00`000000oooo0?ooo`0C0?oo
o`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0QP3oool200WZ2SD0
oooo1009jPZ`0?ooo`D02NX:303oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0R03oool200WZ2SL0oooo0`09jPZb0?ooo`D02NX:
1`3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool0RP3oool300WZ2SL0oooo1009jPZc0?ooo`D02NX:0P3oool00`000000oooo0?oo
o`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0S@3oool2
00WZ2ST0oooo1009jPZd0?ooo`0300WZ2P000000000001D0oooo003o0?oooj80oooo00<0000007mo
O`1oOgl0101oOgl00`000000oooo0?ooo`2?0?ooo`<02NX:>P3oool400WZ2[40oooo0P00000E0?oo
o`00o`3ooonR0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0TP3oool200WZ2S`0
oooo0`09jPZ_0?ooo`030000003oool0oooo01<0oooo003o0?oooj80oooo00<0000007moO`1oOgl0
101oOgl00`000000oooo0?ooo`2D0?ooo`802NX:?@3oool400WZ2Z/0oooo00<000000?ooo`3oool0
4`3oool00?l0ooooXP3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo09H0oooo0`09
jPXn0?ooo`@02NX:Y`3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooonR0?ooo`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool0V@3oool200WZ2T00oooo1009jPZS0?ooo`030000003oool0
oooo01<0oooo003o0?oooj80oooo2@00002L0?ooo`<02NX:@@3oool300WZ2Z00oooo00<000000?oo
o`3oool04`3oool00?l0ooooo`3ooom;0?ooo`802NX:@P3oool400WZ2Y`0oooo00<000000?ooo`3o
ool04`3oool00?l0ooooo`3ooom=0?ooo`802NX:A03oool400WZ2YP0oooo00<000000?ooo`3oool0
4`3oool00?l0ooooo`3ooom?0?ooo`<02NX:A@3oool400WZ2Y@0oooo00<000000?ooo`3oool04`3o
ool00?l0ooooo`3ooomB0?ooo`802NX:A`3oool400WZ2Y00oooo00<000000?ooo`3oool04`3oool0
0?l0ooooo`3ooomD0?ooo`<02NX:B03oool300WZ2Xd0oooo00<000000?ooo`3oool04`3oool00?l0
ooooo`3ooomG0?ooo`802NX:B@3oool400WZ2XT0oooo00<000000?ooo`3oool04`3oool00?l0oooo
o`3ooomI0?ooo`802NX:B`3oool400WZ2XD0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3o
oomK0?ooo`<02NX:C03oool400WZ2X40oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooomN
0?ooo`802NX:CP3oool300WZ2Wh0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooomP0?oo
o`<02NX:CP3oool400WZ2WX0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooomS0?ooo`80
2NX:D03oool400WZ2WH0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooomU0?ooo`802NX:
DP3oool400WZ2W80oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooomW0?ooo`<02NX:D`3o
ool400WZ2Vh0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooomZ0?ooo`802NX:E@3oool3
00WZ2V/0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooom/0?ooo`<02NX:E@3oool400WZ
2VL0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooom_0?ooo`802NX:E`3oool400WZ2V<0
oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3oooma0?ooo`<02NX:F03oool400WZ2Ul0oooo
00<000000?ooo`3oool04`3oool00?l0ooooo`3ooomd0?ooo`802NX:FP3oool300WZ2U`0oooo00<0
00000?ooo`3oool04`3oool00?l0ooooo`3ooomf0?ooo`802NX:F`3oool400WZ2UP0oooo00<00000
0?ooo`3oool04`3oool00?l0ooooo`3ooomh0?ooo`<02NX:G03oool400WZ2U@0oooo00<000000?oo
o`3oool04`3oool00?l0ooooo`3ooomk0?ooo`802NX:GP3oool400WZ2U00oooo00<000000?ooo`3o
ool04`3oool00?l0ooooo`3ooomm0?ooo`<02NX:G`3oool400WZ2T`0oooo00<000000?ooo`3oool0
4`3oool00?l0ooooo`3ooon00?ooo`802NX:H@3oool300WZ2TT0oooo00<000000?ooo`3oool04`3o
ool00?l0ooooo`3ooon20?ooo`802NX:HP3oool400WZ2TD0oooo00<000000?ooo`3oool04`3oool0
0?l0ooooo`3ooon40?ooo`<02NX:H`3oool400WZ2T40oooo00<000000?ooo`3oool04`3oool00?l0
ooooo`3ooon70?ooo`802NX:I@3oool400WZ2Sd0oooo00<000000?ooo`3oool04`3oool00?l0oooo
o`3ooon90?ooo`<02NX:IP3oool300WZ2SX0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3o
oon<0?ooo`802NX:I`3oool400WZ2SH0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooon>
0?ooo`802NX:J@3oool400WZ2S80oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooon@0?oo
o`<02NX:JP3oool400WZ2Rh0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooonC0?ooo`80
2NX:K03oool400WZ2RX0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooonE0?ooo`<02NX:
K@3oool300WZ2RL0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooonH0?ooo`802NX:KP3o
ool400WZ2R<0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooonJ0?ooo`802NX:L03oool4
00WZ2Ql0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooonL0?ooo`<02NX:L@3oool400WZ
2Q/0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooonO0?ooo`802NX:L`3oool300WZ2QP0
oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooonQ0?ooo`<02NX:L`3oool400WZ2Q@0oooo
00<000000?ooo`3oool04`3oool00?l0ooooo`3ooonT0?ooo`802NX:M@3oool400WZ2Q00oooo00<0
00000?ooo`3oool04`3oool00?l0ooooo`3ooonV0?ooo`802NX:M`3oool400WZ2P`0oooo00<00000
0?ooo`3oool04`3oool00?l0ooooo`3ooonX0?ooo`<02NX:N03oool400WZ2PP0oooo00<000000?oo
o`3oool04`3oool00?l0ooooo`3ooon[0?ooo`802NX:NP3oool300WZ2PD0oooo00<000000?ooo`3o
ool04`3oool00?l0ooooo`3ooon]0?ooo`<02NX:NP3oool400WZ2P030?ooo`000000oooo01@0oooo
003o0?ooool0oooo/03oool200WZ2W`0oooo0P00000E0?ooo`00o`3ooooo0?oook80oooo0P09jPYj
0?ooo`8000005@3oool00?l0ooooo`3ooond0?ooo`<02NX:N03oool00`000000oooo0?ooo`0C0?oo
o`00o`3ooooo0?oookL0oooo0P09jPYf0?ooo`030000003oool0oooo01<0oooo003o0?ooool0oooo
^@3oool300WZ2W<0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooonl0?ooo`802NX:L@3o
ool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?oookh0oooo0P09jPY_0?ooo`030000003oool0
oooo01<0oooo003o0?ooool0oooo`03oool300WZ2V`0oooo00<000000?ooo`3oool04`3oool00?l0
ooooo`3oooo30?ooo`802NX:JP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?ooolD0oooo
0`09jPYW0?ooo`030000003oool0oooo01<0oooo003o0?ooool0oooob03oool200WZ2VD0oooo00<0
00000?ooo`3oool04`3oool00?l0ooooo`3oooo:0?ooo`802NX:H`3oool00`000000oooo0?ooo`0C
0?ooo`00o`3ooooo0?oool`0oooo0`09jPYP0?ooo`030000003oool0oooo01<0oooo003o0?ooool0
ooooc`3oool200WZ2Uh0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooooA0?ooo`<02NX:
F`3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?ooom@0oooo0P09jPYI0?ooo`030000003o
ool0oooo01<0oooo003o0?ooool0ooooeP3oool200WZ2UL0oooo00<000000?ooo`3oool04`3oool0
0?l0ooooo`3ooooH0?ooo`<02NX:E03oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?ooom/0
oooo0P09jPYB0?ooo`030000003oool0oooo01<0oooo003o0?ooool0oooog@3oool300WZ2Tl0oooo
00<000000?ooo`3oool04`3oool00?l0ooooo`3ooooP0?ooo`802NX:C@3oool00`000000oooo0?oo
o`0C0?ooo`00o`3ooooo0?ooon80oooo0P09jPY;0?ooo`030000003oool0oooo01<0oooo003o0?oo
ool0ooooi03oool300WZ2TP0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooooW0?ooo`80
2NX:AP3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?ooonT0oooo0`09jPY30?ooo`030000
003oool0oooo01<0oooo003o0?ooool0ooook03oool200WZ2T40oooo00<000000?ooo`3oool04`3o
ool00?l0ooooo`3oooo^0?ooo`802NX:?`3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?oo
oo00oooo0`09jPXl0?ooo`030000003oool0oooo01<0oooo003o0?ooool0ooool`3oool200WZ2SX0
oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooooe0?ooo`<02NX:=`3oool00`000000oooo
0?ooo`0C0?ooo`00o`3ooooo0?ooooP0oooo0P09jPXe0?ooo`030000003oool0oooo01<0oooo003o
0?ooool0oooonP3oool200WZ2S<0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooool0?oo
o`<02NX:<03oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?ooool0oooo0P09jPX^0?ooo`03
0000003oool0oooo01<0oooo003o0?ooool0ooooo`3oool20?ooo`<02NX::`3oool00`000000oooo
0?ooo`0C0?ooo`00o`3ooooo0?ooool0oooo1@3oool200WZ2RT0oooo00<000000?ooo`3oool04`3o
ool00?l0ooooo`3ooooo0?ooo`L0oooo0P09jPXW0?ooo`030000003oool0oooo01<0oooo003o0?oo
ool0ooooo`3oool90?ooo`<02NX:903oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?ooool0
oooo303oool200WZ2R80oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooooo0?ooo`h0oooo
0`09jPXO0?ooo`030000003oool0oooo01<0oooo003o0?ooool0ooooo`3ooolA0?ooo`802NX:7@3o
ool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?ooool0oooo4`3oool200WZ2Q/0oooo00<00000
0?ooo`3oool04`3oool00?l0ooooo`3ooooo0?oooaD0oooo0`09jPXH0?ooo`030000003oool0oooo
01<0oooo003o0?ooool0ooooo`3ooolH0?ooo`802NX:5P3oool00`000000oooo0?ooo`0C0?ooo`00
o`3ooooo0?ooool0oooo6P3oool300WZ2Q<0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3o
oooo0?oooad0oooo0P09jPXA0?ooo`030000003oool0oooo01<0oooo003o0?ooool0ooooo`3ooolO
0?ooo`802NX:3`3oool00`000000oooo0?ooo`0C0?ooo`00o`3ooooo0?ooool0oooo8@3oool300WZ
2P`0oooo00<000000?ooo`3oool04`3oool00?l0ooooo`3ooooo0?ooob@0oooo0P09jPX:0?ooo`03
0000003oool0oooo01<0oooo003o0?ooool0ooooo`3ooolV0?ooo`<02NX:1`3oool00`000000oooo
0?ooo`0C0?ooo`00o`3ooooo0?ooool0oooo:@3oool200WZ2PD0oooo00<000000?ooo`3oool04`3o
ool00?l0ooooo`3ooooo0?ooob/0oooo0P09jPX30?ooo`030000003oool0oooo01<0oooo003o0?oo
ool0ooooo`3oool]0?ooo`<02NX:00<000000?ooo`3oool04`3oool00?l0ooooo`3ooooo0?ooobl0
oooo0P00000E0?ooo`00o`3ooooo0?ooool0oooo;`3oool2000001D0oooo003o0?ooool0ooooo`3o
ool`0?ooo`030000003oool0oooo01<0oooo003o0?ooool0ooooo`3oool`0?ooo`030000003oool0
oooo01<0oooo003o0?ooool0ooooo`3oool`0?ooo`030000003oool0oooo01<0oooo003o0?ooool0
ooooo`3ooom60?ooo`00o`3ooooo0?ooool0ooooAP3oool00?l0ooooo`3ooooo0?ooodH0oooo003o
0?ooool0ooooo`3ooom60?ooo`00o`3ooooo0?ooool0ooooAP3oool00?l0ooooo`3ooooo0?ooodH0
oooo003o0?ooool0ooooo`3ooom60?ooo`00o`3ooooo0?ooool0ooooAP3oool00?l0ooooo`3ooooo
0?ooodH0oooo0000\
\>"],
  ImageRangeCache->{{{0, 834}, {416.5, 0}} -> {-5.1271, -52.5006, 0.252104, \
0.252104}},
  CellTags->"Realistic Fresnel Lens Model"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Working with Rayica's Data Base", "Section",
  CellTags->"Rayica's Data Base"],

Cell[TextData[{
  "There are three main functions used in accessing the data base of \
information:\n",
  StyleBox["DataTo", "Input"],
  "Rayica",
  ", ",
  StyleBox["ReadData", "Input"],
  ", and ",
  StyleBox["SearchData", "Input"],
  "."
}], "Text",
  CellTags->"Rayica's Data Base"],

Cell[TextData[{
  "You basically enter various selection criteria to be searched. ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  " tries to find a match."
}], "Text",
  CellTags->"Rayica's Data Base"],

Cell[TextData[{
  "First we call LoadData to be sure that all database entries are loaded \
into ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{

Cell["LoadData[All]", "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    \({"Data/Elements/CoherentEaling.m", "Data/Elements/CompanyData.m", 
      "Data/Elements/CurvedMirrors.m", "Data/Elements/CylindricalLenses.m", 
      "Data/Elements/Edmund.m", "Data/Elements/JML.m", 
      "Data/Elements/Melles.m", "Data/Elements/Mirrors.m", 
      "Data/Elements/Newport.m", "Data/Elements/Oriel.m", 
      "Data/Elements/PolarizingElements.m", 
      "Data/Elements/PrismsBeamSplitters.m", 
      "Data/Elements/SpindlerJMLPrisms.m", "Data/Elements/Spindler.m", 
      "Data/Elements/ThorLabs.m", "Data/Materials/Crystals.m", 
      "Data/Materials/Misc.m", "Data/Materials/OHARA.m", 
      "Data/Materials/OliveOil.m", "Data/Materials/Plastics.m", 
      "Data/Materials/PolarizingMaterials.m", 
      "Data/Materials/Schott.m"}\)], "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[TextData[{
  StyleBox["DataToRayica", "Input"],
  StyleBox[" is used to turn the database information into an ", "Text"],
  StyleBox["Rayica",
    FontSlant->"Italic"],
  " definition."
}], "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{

Cell["DataToRayica[FocalLength->145]", "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    TagBox[
      StyleBox[
        TagBox[\(LensDoublet[
            91.80029999999998`, \(-61.4975`\), \(-259.4899999999999`\), 40, 
            9.`, 3.5`, SK11, SF5]\),
          HoldForm],
        FontColor->RGBColor[0, 0.392187, 0]],
      DisplayForm]], "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DataToRayica[PlanoConvexLens, FocalLength->145]", "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    TagBox[
      StyleBox[
        TagBox[\(PlanoConvexLens[140.9869999999999`, 62.99999999999998`, 
            10.`, {DesignWaveLength \[Rule] 0.5875599999999997`}]\),
          HoldForm],
        FontColor->RGBColor[0, 0.392187, 0]],
      DisplayForm]], "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[TextData[{
  StyleBox["ReadData", "Input"],
  StyleBox[" is used to examine specific categories of database information", 
    "Text"],
  ". Here we look for all focusing elements that have a focal length close to \
145."
}], "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{

Cell["ReadData[{FocalLength,RayicaFunction},FocalLength->145]", "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    TagBox[GridBox[{
          {"FocalLength", "RayicaFunction"},
          {"145", "LensDoublet"},
          {"144.4432", "SphericalLens"},
          {"146.", "SphericalLens"},
          {"146.1", "LensDoublet"},
          {"146.1", "LensDoublet"},
          {"146.2857", "BiConvexLens"}
          },
        ColumnAlignments->{Left},
        RowLines->{True, False},
        ColumnLines->True],
      DisplayForm]], "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[TextData[{
  "Note that focal length does not have to be an exact match. This is \
determined by the ",
  StyleBox["Tolerance", "Input"],
  " option. You can check the default ",
  StyleBox["Tolerance", "Input"],
  " setting of ",
  StyleBox["ReadData", "Input"],
  " with ",
  StyleBox["Options[ReadData]", "Input"],
  ":"
}], "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{

Cell["Options[ReadData]", "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    \({ReportedInterval \[Rule] 1000, Union \[Rule] Automatic, 
      Intersection \[Rule] True, GridBox \[Rule] Automatic, 
      Accuracy \[Rule] 5, Sort \[Rule] Automatic, 
      Tolerance \[Rule] 1\/100}\)], "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[TextData[{
  "Here we see that the default ",
  StyleBox["Tolerance", "Input"],
  " setting is 1/100, but you can use a larger ",
  StyleBox["Tolerance", "Input"],
  " setting to extend the range of reported values:"
}], "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{

Cell["\<\
ReadData[{FocalLength,RayicaFunction},FocalLength->145, Tolerance \
-> 1/50]\
\>", "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    TagBox[GridBox[{
          {"FocalLength", "RayicaFunction"},
          {"145", "LensDoublet"},
          {"144.4432", "SphericalLens"},
          {"146.", "SphericalLens"},
          {"146.1", "LensDoublet"},
          {"146.1", "LensDoublet"},
          {"146.2857", "BiConvexLens"},
          {"146.4944", "BiConvexLens"},
          {"146.9763", "BiConvexLens"},
          {"147.2359", "BiConvexLens"},
          {"147.3", "ParabolicMirror"},
          {"147.3436", "BiConvexLens"},
          {"147.638", "BiConvexLens"},
          {"147.8335", "BiConvexLens"}
          },
        ColumnAlignments->{Left},
        RowLines->{True, False},
        ColumnLines->True],
      DisplayForm]], "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[TextData[{
  "Sometimes you may want to check the database for all optical elements of a \
particular type. The best way to do this is to use the ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  " component function name that generates the desired optical element. Here \
we will search for all ",
  StyleBox["AsphericLens", "Input"],
  " database entries. "
}], "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{

Cell["\<\
ReadData[{FocalLength,ClearAperture,CatalogNumber,CompanyName,\
DesignWaveLength}, AsphericLens]\
\>", "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    TagBox[GridBox[{
          {"FocalLength", "ClearAperture", "CatalogNumber", "CompanyName", 
            "DesignWaveLength"},
          {"1.14", 
            "1.13", \(350200 \((unmounted)\) 
              C200TM \((mounted)\)\), \(\(ThorLabs &\) Geltech\), "1.3"},
          {"1.45", 
            "1.6", \(350140 \((unmounted)\) 
              C140TM \((mounted)\)\), \(\(ThorLabs &\) Geltech\), "0.78"},
          {"2.", 
            "2.", \(350150 \((unmounted)\) 
              C150TM \((mounted)\)\), \(\(ThorLabs &\) Geltech\), "0.78"},
          {"2.75", 
            "3.6", \(350390 \((unmounted)\) 
              C390TM \((mounted)\)\), \(\(ThorLabs &\) Geltech\), "0.83"},
          {"3.1", 
            "5.", \(350330 \((unmounted)\) 
              C330TM \((mounted)\)\), \(\(ThorLabs &\) Geltech\), "0.83"},
          {"4.5", 
            "3.7", \(350350 \((unmounted)\) 
              C350TM \((mounted)\)\), \(\(ThorLabs &\) Geltech\), "0.98"},
          {"4.51", 
            "4.95", \(350230 \((unmounted)\) 
              C390TM \((mounted)\)\), \(\(ThorLabs &\) Geltech\), "0.78"},
          {"5.", 
            "1.5", \(350430 \((unmounted)\) 
              C430TM \((mounted)\)\), \(\(ThorLabs &\) Geltech\), "1.55"},
          {"6.16", 
            "3.7", \(350170 \((unmounted)\) 
              C170TM \((mounted)\)\), \(\(ThorLabs &\) Geltech\), "0.78"},
          {"6.24", 
            "5.", \(350110 \((unmounted)\) 
              C110TM \((mounted)\)\), \(\(ThorLabs &\) Geltech\), "0.78"},
          {"8.", 
            "8.", \(350240 \((unmounted)\) 
              C240TM \((mounted)\)\), \(\(ThorLabs &\) Geltech\), "0.78"},
          {"11.", 
            "5.5", \(350220 \((unmounted)\) 
              C220TM \((mounted)\)\), \(\(ThorLabs &\) Geltech\), "0.633"},
          {"15.36", 
            "5.", \(350260 \((unmounted)\) 
              C390TM \((mounted)\)\), \(\(ThorLabs &\) Geltech\), "0.78"},
          {"18.4", 
            "5.5", \(350280 \((unmounted)\) 
              C280TM \((mounted)\)\), \(\(ThorLabs &\) Geltech\), "0.78"}
          },
        ColumnAlignments->{Left},
        RowLines->{True, False},
        ColumnLines->True],
      DisplayForm]], "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[TextData[{
  "Once you have chosen a particular database entry, you can then use its ",
  StyleBox["CatalogNumber", "Input"],
  ", as a character string, to look up all of its details with ",
  StyleBox["SearchData", "Input"],
  ". It is not necessary to provide the entire ",
  StyleBox["CatalogNumber", "Input"],
  " entry (",
  StyleBox["\"350140(unmounted)C140TM(mounted)\"", "Input"],
  " in this example). A fragment of the original string is sufficient."
}], "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{

Cell["SearchData[\"C140TM\"]", "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    \({{CatalogNumber \[Rule] "350140(unmounted)C140TM(mounted)", 
        ClearAperture \[Rule] 1.6`, CompanyName \[Rule] "ThorLabs&Geltech", 
        ComponentBoundary \[Rule] {{1.052632`, \(-0.522546`\), 0, 0, 
              0.012528`, \(-0.0397188`\), 0, 1.6`}, {\(-0.167741`\), 0, 0, 
              0.146106`, \(-0.27935`\), 0.199181`, 0, 1.2`}, 2.4`, 1.01`}, 
        ComponentLabel \[Rule] "aspheric lens manufactured by Geltech", 
        ComponentMedium \[Rule] CO550, Date \[Rule] {1999, 8, 2}, 
        DesignWaveLength \[Rule] 0.78`, 
        DiffractionLimitedRange \[Rule] {0.6`, 1.55`}, 
        EquivalentMagnification \[Rule] 110, EvenFunction \[Rule] True, 
        FileName \[Rule] "ThorLabs.m", FocalLength \[Rule] 1.45`, 
        HousingBoundary \[Rule] 6.24`, NA \[Rule] 0.55`, 
        RayicaFunction \[Rule] AsphericLens, SurfaceBoundary \[Rule] 2.4`, 
        SurfaceSeparation \[Rule] 1.01`, 
        WorkingDistance \[Rule] 0.88`}}\)], "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell["\<\
You can in fact search of any data field for any specific value. \
For you search, you can use a string, number, or symbol entry. In this case, \
however, the data entries have to be an exact match to what you are seeking. \
Here we look for all database items that contains the number 2.75. In this \
case, it does not distinguish the context in which the number is getting \
used.\
\>", "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{

Cell["ReadData[{RayicaFunction, CatalogNumber},2.75]", "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    TagBox[GridBox[{
          {"RayicaFunction", "CatalogNumber"},
          {"ModelRefractiveIndex", \({}\)},
          {"LinearPolarizer", \(03  FPI001\)},
          {"LinearPolarizer", \(03  FPI003\)},
          {"LinearPolarizer", \(03  FPI005\)},
          {"LinearPolarizer", \(03  FPI012\)},
          {"LinearPolarizer", \(03  FPI014\)},
          {"LinearPolarizer", \(03  FPI016\)},
          {"LinearPolarizer", "D46087"},
          {"LinearPolarizer", "D46088"},
          {"LinearPolarizer", "D46089"},
          {"LinearPolarizer", "D46090"},
          {"BallLens", "BL5"},
          {"BallLens", \(BL5 - 830\)},
          {"BiConvexLens", "A32016"},
          {"AsphericLens", \(350390 \((unmounted)\) C390TM \((mounted)\)\)},
          {"SellmeierFunction", \({}\)},
          {"SellmeierFunction", \({}\)},
          {"IndexFunction", \({}\)},
          {"PlanoConvexLens", "312316"},
          {"BiConvexLens", "311193"}
          },
        ColumnAlignments->{Left},
        RowLines->{True, False},
        ColumnLines->True],
      DisplayForm]], "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[TextData[{
  "If you are not sure about what parameters are available for a particular \
database item, you can use ",
  StyleBox["SearchData", "Input"],
  " with the name of the desired component function in ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  " that generates the item. In this case, we will search for a ",
  StyleBox["Mirror", "Input"],
  " entry. However, unless you restrict the number of reported items with ",
  StyleBox["ReportedInterval", "Input"],
  ", you can be overwhelmed by the response. Therefore, we will use the ",
  StyleBox["ReportedInterval -> 1", "Input"],
  " setting to receive only a single result."
}], "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{

Cell["SearchData[Mirror,ReportedInterval->1]", "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{\(CatalogNumber \[Rule] "05B20UF.20"\), 
          ",", \(ClearAperture \[Rule] 12.7`\), 
          ",", \(CompanyName \[Rule] "Newport"\), 
          ",", \(ComponentBoundary \[Rule] 12.7`\), 
          ",", \(ComponentLabel \[Rule] 
            "Ultrafast Laser High Reflecting Pump Mirrors"\), 
          ",", \(ComponentMedium \[Rule] BK7\), 
          ",", \(CurvatureTolerance \[Rule] 3\), 
          ",", \(Date \[Rule] {1999, 4, 18}\), 
          ",", \(FileName \[Rule] "CurvedMirrors.m"\), 
          ",", \(FlatSubstrate \[Rule] True\), ",", 
          RowBox[{"FocalLength", "\[Rule]", 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]}], 
          ",", \(InputEdgeThickness \[Rule] True\), 
          ",", \(RayicaFunction \[Rule] Mirror\), ",", 
          RowBox[{"RadiusOfCurvature", "\[Rule]", 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]}], ",", \(ScratchDig \[Rule] {15, 5}\), 
          ",", \(SurfaceAccuracy \[Rule] 1\/10\), 
          ",", \(SurfaceCoating \[Rule] SelectiveBroadBandDielectric\), 
          ",", \(CenterThickness \[Rule] 9.53`\), 
          ",", \(SurfaceSeparation \[Rule] 9.53`\), 
          ",", \(Units \[Rule] "mm"\), 
          ",", \(WaveLengthRange \[Rule] {1.457`, 1.55`, 
              1.658999999999998`}\)}], "}"}], "}"}]], "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[TextData[{
  "Now that we have seen the types data parameters available to us, we now \
decide that ",
  StyleBox["ComponentBoundary", "Input"],
  " and ",
  StyleBox["SurfaceAccuracy", "Input"],
  " are the most interesting to us."
}], "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{

Cell["DataToRayica[ComponentBoundary->50, SurfaceAccuracy->1/10]", "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    InterpretationBox[\(LEBG\[InvisibleSpace]" is not currently defined in \
Rayica's database at this time."\),
      SequenceForm[ 
      LEBG, " is not currently defined in Rayica's database at this time."],
      Editable->False]], "Print",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    InterpretationBox[\("Substituting a constant refractive index of 1.5 in \
place of "\[InvisibleSpace]LEBG\[InvisibleSpace]"."\),
      SequenceForm[ 
      "Substituting a constant refractive index of 1.5 in place of ", LEBG, 
        "."],
      Editable->False]], "Print",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    TagBox[
      StyleBox[
        TagBox[\(Mirror[50, 10, {ComponentMedium \[Rule] 1.5`}]\),
          HoldForm],
        FontColor->RGBColor[0, 0.392187, 0]],
      DisplayForm]], "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[TextData[{
  "An alternative way to learn about the available parameters is to pass ",
  StyleBox["All", "Input"],
  " to ",
  StyleBox["ReadData", "Input"],
  ". In this case, ",
  StyleBox["All", "Input"],
  " gives all parameters about the object."
}], "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{

Cell["ReadData[All,LensDoublet,ReportedInterval->10]", "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    TagBox[GridBox[{
          {"CatalogNumber", "CenterThickness", "CompanyName", 
            "ComponentBoundary", "ComponentLabel", "ComponentMedium", "Date", 
            "DesignRefractiveIndex", "DesignWaveLength", 
            "EntrancePupilDiameter", "FileName", "FocalLength", 
            "GlassCatalogs", "RadiusOfCurvature", "RayicaFunction", 
            "ReferenceWaveLengthNumber", "StopPosition", "SurfaceBoundary", 
            "SurfaceCurvature", "SurfaceLabel", "SurfaceSeparation"},
          {\(23 - 9319\), "9.5", \(Coherent - Ealing\), 
            "25.4", \(23 - 9319\ ACHRO - DOUBLET\ LensDoublet\), \({BK7, \ 
              SF5}\), \({1999, \ 4, \ 
              18}\), \({{1.5224, \ 1.5168, \ 1.5143}, \ {1.6875, \ 1.6727, \ 
                1.6666}}\), \({0.4861, \ 0.5876, \ 
              0.6563}\), \({22.86}\), \(CoherentEaling . m\), 
            "25.4", \({SCHOTT, \ MISC, \ 
              INFRARED}\), \({38.35, \ \(-26.81\), \ \(-71.89\)}\), 
            "LensDoublet", "2", 
            "1", \({25.4, \ 25.4, \ 
              25.4}\), \({0.0261, \ \(-0.0373\), \ \(-0.0139\)}\), \
\({SphericalShape, \ SphericalShape, \ SphericalShape}\), \({7.5, \ 2. }\)},
          {\(23 - 9335\), "8.2", \(Coherent - Ealing\), 
            "25.4", \(23 - 9335\ ACHRO - DOUBLET\ LensDoublet\), \({BK7, \ 
              SF5}\), \({1999, \ 4, \ 
              18}\), \({{1.5224, \ 1.5168, \ 1.5143}, \ {1.6875, \ 1.6727, \ 
                1.6666}}\), \({0.4861, \ 0.5876, \ 
              0.6563}\), \({22.86}\), \(CoherentEaling . m\), 
            "25.4", \({SCHOTT, \ MISC, \ 
              INFRARED}\), \({50.508, \ \(-35.37\), \ \(-98.26\)}\), 
            "LensDoublet", "2", 
            "1", \({25.4, \ 25.4, \ 
              25.4}\), \({0.0198, \ \(-0.0283\), \ \(-0.0102\)}\), \
\({SphericalShape, \ SphericalShape, \ SphericalShape}\), \({6.2, \ 2. }\)},
          {\(23 - 9350\), "7.2", \(Coherent - Ealing\), 
            "25.4", \(23 - 9350\ ACHRO - DOUBLET\ LensDoublet\), \({BK7, \ 
              SF5}\), \({1999, \ 4, \ 
              18}\), \({{1.5224, \ 1.5168, \ 1.5143}, \ {1.6875, \ 1.6727, \ 
                1.6666}}\), \({0.4861, \ 0.5876, \ 
              0.6563}\), \({22.86}\), \(CoherentEaling . m\), 
            "25.4", \({SCHOTT, \ MISC, \ 
              INFRARED}\), \({62.941, \ \(-43.927\), \ \(-123.78\)}\), 
            "LensDoublet", "2", 
            "1", \({25.4, \ 25.4, \ 
              25.4}\), \({0.0159, \ \(-0.0228\), \ \(-0.0081\)}\), \
\({SphericalShape, \ SphericalShape, \ SphericalShape}\), \({5.2, \ 2. }\)},
          {\(23 - 9368\), "7.2", \(Coherent - Ealing\), 
            "25.4", \(23 - 9368\ ACHRO - DOUBLET\ LensDoublet\), \({BK7, \ 
              SF5}\), \({1999, \ 4, \ 
              18}\), \({{1.5224, \ 1.5168, \ 1.5143}, \ {1.6875, \ 1.6727, \ 
                1.6666}}\), \({0.4861, \ 0.5876, \ 
              0.6563}\), \({22.86}\), \(CoherentEaling . m\), 
            "25.4", \({SCHOTT, \ MISC, \ 
              INFRARED}\), \({75.303, \ \(-52.35\), \ \(-148.88\)}\), 
            "LensDoublet", "2", 
            "1", \({25.4, \ 25.4, \ 
              25.4}\), \({0.0133, \ \(-0.0191\), \ \(-0.0067\)}\), \
\({SphericalShape, \ SphericalShape, \ SphericalShape}\), \({5.2, \ 2. }\)},
          {\(23 - 9459\), "5.", \(Coherent - Ealing\), 
            "12.5", \(23 - 9459\ ACHRO - DOUBLET\ LensDoublet\), \({BK7, \ 
              SF5}\), \({1999, \ 4, \ 
              18}\), \({{1.5224, \ 1.5168, \ 1.5143}, \ {1.6875, \ 1.6727, \ 
                1.6666}}\), \({0.4861, \ 0.5876, \ 
              0.6563}\), \({11.25}\), \(CoherentEaling . m\), 
            "12.5", \({SCHOTT, \ MISC, \ 
              INFRARED}\), \({22.12, \ \(-15.24\), \ \(-42.1199\)}\), 
            "LensDoublet", "2", 
            "1", \({12.5, \ 12.5, \ 
              12.5}\), \({0.0452, \ \(-0.0656\), \ \(-0.0237\)}\), \
\({SphericalShape, \ SphericalShape, \ SphericalShape}\), \({3.9, \ 1.1}\)},
          {\(23 - 9467\), "7.", \(Coherent - Ealing\), 
            "18.", \(23 - 9467\ ACHRO - DOUBLET\ LensDoublet\), \({BK7, \ 
              SF5}\), \({1999, \ 4, \ 
              18}\), \({{1.5224, \ 1.5168, \ 1.5143}, \ {1.6875, \ 1.6727, \ 
                1.6666}}\), \({0.4861, \ 0.5876, \ 
              0.6563}\), \({16.2}\), \(CoherentEaling . m\), 
            "18.", \({SCHOTT, \ MISC, \ 
              INFRARED}\), \({25.62, \ \(-18.02\), \ \(-47.836\)}\), 
            "LensDoublet", "2", 
            "1", \({18. , \ 18. , \ 
              18. }\), \({0.039, \ \(-0.0555\), \ \(-0.0209\)}\), \
\({SphericalShape, \ SphericalShape, \ SphericalShape}\), \({5.4, \ 1.6}\)},
          {\(23 - 9475\), "6.5", \(Coherent - Ealing\), 
            "18.", \(23 - 9475\ ACHRO - DOUBLET\ LensDoublet\), \({BK7, \ 
              SF5}\), \({1999, \ 4, \ 
              18}\), \({{1.5224, \ 1.5168, \ 1.5143}, \ {1.6875, \ 1.6727, \ 
                1.6666}}\), \({0.4861, \ 0.5876, \ 
              0.6563}\), \({16.2}\), \(CoherentEaling . m\), 
            "18.", \({SCHOTT, \ MISC, \ 
              INFRARED}\), \({31.7, \ \(-22. \), \ \(-60.45\)}\), 
            "LensDoublet", "2", 
            "1", \({18. , \ 18. , \ 
              18. }\), \({0.0315, \ \(-0.0455\), \ \(-0.0165\)}\), \
\({SphericalShape, \ SphericalShape, \ SphericalShape}\), \({4.9, \ 1.6}\)},
          {\(23 - 9483\), "6.", \(Coherent - Ealing\), 
            "18.", \(23 - 9483\ ACHRO - DOUBLET\ LensDoublet\), \({BK7, \ 
              SF5}\), \({1999, \ 4, \ 
              18}\), \({{1.5224, \ 1.5168, \ 1.5143}, \ {1.6875, \ 1.6727, \ 
                1.6666}}\), \({0.4861, \ 0.5876, \ 
              0.6563}\), \({16.2}\), \(CoherentEaling . m\), 
            "18.", \({SCHOTT, \ MISC, \ 
              INFRARED}\), \({37.84, \ \(-26.47\), \ \(-73.75\)}\), 
            "LensDoublet", "2", 
            "1", \({18. , \ 18. , \ 
              18. }\), \({0.0264, \ \(-0.0378\), \ \(-0.0136\)}\), \
\({SphericalShape, \ SphericalShape, \ SphericalShape}\), \({4.4, \ 1.6}\)},
          {\(23 - 9491\), "5.8", \(Coherent - Ealing\), 
            "18.", \(23 - 9491\ ACHRO - DOUBLET\ LensDoublet\), \({BK7, \ 
              SF5}\), \({1999, \ 4, \ 
              18}\), \({{1.5224, \ 1.5168, \ 1.5143}, \ {1.6875, \ 1.6727, \ 
                1.6666}}\), \({0.4861, \ 0.5876, \ 
              0.6563}\), \({16.2}\), \(CoherentEaling . m\), 
            "18.", \({SCHOTT, \ MISC, \ 
              INFRARED}\), \({50. , \ \(-34.9\), \ \(-99.55\)}\), 
            "LensDoublet", "2", 
            "1", \({18. , \ 18. , \ 
              18. }\), \({0.02, \ \(-0.0287\), \ \(-0.01\)}\), \
\({SphericalShape, \ SphericalShape, \ SphericalShape}\), \({4. , \ 1.8}\)},
          {\(23 - 9509\), "5.8", \(Coherent - Ealing\), 
            "18.", \(23 - 9509\ ACHRO - DOUBLET\ LensDoublet\), \({BK7, \ 
              SF5}\), \({1999, \ 4, \ 
              18}\), \({{1.5224, \ 1.5168, \ 1.5143}, \ {1.6875, \ 1.6727, \ 
                1.6666}}\), \({0.4861, \ 0.5876, \ 
              0.6563}\), \({16.2}\), \(CoherentEaling . m\), 
            "18.", \({SCHOTT, \ MISC, \ 
              INFRARED}\), \({62.367, \ \(-43.323\), \ \(-124.685\)}\), 
            "LensDoublet", "2", 
            "1", \({18. , \ 18. , \ 
              18. }\), \({0.016, \ \(-0.0231\), \ \(-0.008\)}\), \
\({SphericalShape, \ SphericalShape, \ SphericalShape}\), \({4. , \ 1.8}\)}
          },
        ColumnAlignments->{Left},
        RowLines->{True, False},
        ColumnLines->True],
      DisplayForm]], "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[TextData[{
  "This example limits the number of returned items with ",
  StyleBox["ReportedInterval->5", "Input"],
  "."
}], "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{

Cell["\<\
ReadData[{FocalLength,ComponentBoundary,CompanyName},LensDoublet,\
ReportedInterval->5]\
\>", "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    TagBox[GridBox[{
          {"FocalLength", "ComponentBoundary", "CompanyName"},
          {\(-100\), "25", "EdmundScientific"},
          {\(-50\), "12.5", "EdmundScientific"},
          {\(-50\), "25", "EdmundScientific"},
          {\(-25\), "12.5", "EdmundScientific"},
          {"6", "3", "EdmundScientific"}
          },
        ColumnAlignments->{Left},
        RowLines->{True, False},
        ColumnLines->True],
      DisplayForm]], "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[TextData[{
  "This example shows how you can search for all of the optical material \
names present in ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  "'s database. We use the ",
  StyleBox["Union->True", "Input"],
  " option remove any redundant information."
}], "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{

Cell["ReadData[OpticalMedium, Union->True]", "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    \({Acrylic, ADPe, ADPo, Ag3AsS3e, Ag3AsS3o, AgBr, AgCl, AgGaS2e, AgGaS2o, 
      AgGaSe2e, AgGaSe2o, Al2O3e, Al2O3o, AlAs, AlNe, AlNo, ALON, AlphaSiCe, 
      AlphaSiCo, AlphaSiO2e, AlphaSiO2o, AlphaZnSE, AlphaZnSo, BaF13, BaF2, 
      BaF3, BaF4, BaF50, BaF51, BaF52, BaF8, BaF9, BaFN10, BaFN11, BaFN6, 
      BaH10, BaH11, BaH13, BaH22, BaH26, BaH27, BaH28, BaH30, BaH32, BaH71, 
      BaH77, BaH78, BaK1, BaK2, BaK4, BaK5, BaK50, BaL11, BaL12, BaL14, 
      BaL15, BaL15Y, BaL2, BaL22, BaL3, BaL35, BaL35Y, BaL41, BaL5, BaL7, 
      BaLF4, BaLF5, BaLF50, BaLKN3, BaM12, BaM21, BaM23, BaM25, BaM3, BaM4, 
      BaM5, BaM8, BaM9, BaSF1, BaSF10, BaSF12, BaSF13, BaSF2, BaSF51, BaSF52, 
      BaSF54, BaSF56, BaSF57, BaSF6, BaSF64A, BaTiO3e, BaTiO3o, BBOe, BBOo, 
      BeOe, BeOo, BetaSiC, BetaZnS, BGO, BK1, BK10, BK3, BK6, BK7, BK8, BP, 
      BPH35, BPH40, BPH45, BPH5, BPH50, BPH8, BPM4, BPM51, BSL1, BSL21, 
      BSL22, BSL3, BSL7Y, BSM10, BSM14, BSM15, BSM16, BSM16C, BSM2, BSM21, 
      BSM22, BSM23, BSM24, BSM25, BSM28, BSM4, BSM51Y, BSM6, BSM7, BSM9, BSO, 
      C, CaCO3e, CaCO3o, CaF, CaF2, CalciteE, CalciteO, CalciumFluoride, 
      CaMoO4e, CaMoO4o, CaWO4e, CaWO4o, CdGeAs2e, CdGeAs2o, CdSE, CdSeE, 
      CdSeO, CdSO, CdTe, CsBr, CsCl, CsI, CuCl, CuGaS2e, CuGaS2o, Diamond, 
      F1, F13, F14, F15, F2, F3, F4, F5, F6, F7, F8, F9, FK3, FK5, FK51, 
      FK52, FK54, FN11, FSL3, FTL10, FTL8, FTM8, GaAs, GaNe, GaNo, GaP, Ge, 
      Germanium, HfO2Y2O3, HN22, HN32, HN38, HN42, InAs, InP, K10, K11, K3, 
      K4, K5, K50, K7, KBr, KCl, KDPe, KDPo, KF, KF3, KF6, KF9, KI, KNbO3x, 
      KNbO3y, KNbO3z, KRS5, KRS6, KTaO3, KTPx, KTPy, KTPz, KZFN1, KZFN2, 
      KZFS1, KZFS6, KZFS7A, KZFS8, KZFSN2, KZFSN4, KZFSN5, KZFSN9, LaF11A, 
      LaF13, LaF2, LaF20, LaF22A, LaF3, LaF3e, LaF3o, LaF9, LaFN10, LaFN21, 
      LaFN23, LaFN24, LaFN28, LaFN7, LaFN8, LaH71, LaH78, LaK10, LaK11, 
      LaK16A, LaK21, LaK23, LaK28, LaK31, LaK33, LaK8, LaK9, LaKL12, LaKL21, 
      LaKN12, LaKN13, LaKN14, LaKN22, LaKN6, LaKN7, LaL58, LaM51, LaM52, 
      LaM58, LaM59, LaM61, LaM7, LaSF14A, LaSF18A, LaSF3, LaSF32, LaSF33, 
      LaSF35, LaSF36A, LaSFN15, LaSFN30, LaSFN31, LaSFN9, LBOx, LBOy, LBOz, 
      LF5, LF7, LF8, LiF, LiIO3e, LiIO3o, LiNbO3e, LiNbO3o, LiYF4e, LiYF4o, 
      LLF1, LLF2, LLF6, LLF7, MgAl2O4, MgF2e, MgF2o, MgO, NaBr, NaCl, NaF, 
      NaI, NSL2, NSL3, NSL33, NSL36, NSL5, NSL7, OliveOil, {}}\)], "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[TextData[{
  "To retrieve an optical material from the database, you can pass its name \
to ",
  StyleBox["DataToRayica", "Input"],
  ". In normal practise, however, ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  " will do this for you automatically when you create an optical component \
with a new material name."
}], "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{

Cell["DataToRayica[OliveOil]", "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    \({"OliveOil is an optical material from user-specified data with a \
refractive index of 1.47667 at the 0.580828 micron wavelength, a \
corresponding V-number of 98.0011, a partial dispersion ratio of 0.305899, \
and a mean dispersion value of 0.00486388. The refractive index model for \
this OliveOil is valid from 0.486 to 0.656 microns of wavelength."}\)], \
"Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell["\<\
Here is how you can check refractive index specific values for a \
particular optical medium.\
\>", "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{

Cell["ModelRefractiveIndex[OliveOil][WaveLength->.532]", "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    \(1.4793100116379985`\)], "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModelRefractiveIndex[Water][WaveLength->.532]", "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    \(Water[WaveLength \[Rule] 0.532`]\)], "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[TextData[{
  StyleBox["GlassMap", "Input"],
  " offers a powerful way to search the database and compare the \
characteristics of the different optical materials."
}], "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{

Cell["?GlassMap", "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    \("GlassMap[selectionproperties, options] is used to illustrate \
dispersive properties of optical materials and to select new material models \
from the Rayica database. \n\nGlassMap uses ReadData internally to select the \
optical data for display. If no selectionproperties are given, then all \
loaded optical materials are displayed. GlassMap uses the option PlotType to \
specify the plotted parameters. In all cases, the optical materials are \
represented by distinct points on a graph. As an example of PlotType, with \
either PlotType -> RefractiveIndex or PlotType -> Automatic, GlassMap gives a \
plot of the refractive index, nd, versus the Abbe V-number for the selected \
database-stored optical materials. The Abbe V-number, Vd = (nd-1) / (nf-nc), \
is a measure of the chromatic aberration of the specified material in a lens \
component. The smaller the Abbe number, the greater will be the chromatic \
aberration contribution of the material to a lens. Here, nf, nd, and nc are \
the refractive index values for three different wavelengths specified in the \
SpectralRegion option of GlassMap. As an alternative, PlotType -> \
{RefractiveIndex, AbbeVNumber} can also be used for the same effect. \n\n\
Depending on the PlotType values given, GlassMap gives a number of different \
point-like representations for the refractive index and dispersive properties \
of optical materials. PlotType can hold either one or a list of two values. \
If a single value is given, then the chosen value is plotted on the vertical \
axis, and the horizontal axis shows the AbbeVNumber. Otherwise, PlotType -> \
{value1, value2} can be used to directly indicate the horizontal and vertical \
display parameters. PlotType values can include: Automatic, RefractiveIndex, \
PartialDispersionRatio, MeanDispersion, AbbeVNumber, and Function[{nf, nd, \
nc}, F[nf, nd, nc]] where F[nf, nd, nc] is a user-defined expression. When \
PlotType holds a list of two values, the value list order is usually not \
important. In particular, the MeanDispersion and AbbeVNumber parameters \
always take the horizontal axis regardless of their specified positions in \
PlotType, unless both get specified simultaneously. In such a case, the \
MeanDispersion parameter gets plotted on the vertical axis and the \
AbbeVNumber parameter remains plotted on the horizontal axis. However, in the \
case of two user-specified Function parameters, the first Function parameter \
takes the horizontal axis while the second Function parameter takes the \
vertical axis. \n\nGlassMap has two different modes of operation: rendering \
of data and creation of new optical material models. GlassMap is initially \
used to create a plot of optical material points. In its plotting mode, \
GlassMap uses ShowLabels -> True to indicate display of the Schott glass \
boundaries and ShowText -> True to indicate display of the material names \
with their corresponding points. Finally, GlassMap can be used to create new \
refractive index models in Rayica for specific selected materials. Once a \
plot has been generated in any PlotType format by one GlassMap function, the \
mouse-sampled coordinate points can then be copied and pasted as \
selectionproperties into a second GlassMap function having the same PlotType \
setting to generate new optical material models. When GlassMap receives one \
or more sets of coordinate points in selectionproperties, GlassMap identifies \
the corresponding optical material types and calls DataToRayica with the \
OpticalMedium names of each identified material. DataToRayica then creates a \
new refractive index model for each material and GlassMap reports a message \
about each newly defined material. \n\nSee also: SpectralRegion, \
DataToRayica, FindGlassNumbers, RefractiveIndex, AbbeVNumber, \
PartialDispersionRatio, MeanDispersion, SearchData, and ReadData."\)], "Print",\

  CellTags->{"Info3311851835-9430908", "Rayica's Data Base"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[GlassMap]", "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    \({SpectralRegion \[Rule] {0.4861`, 0.6563`}, 
      ShowLabels \[Rule] Automatic, ShowText \[Rule] Automatic, 
      PlotRange \[Rule] Automatic, PlotLabel \[Rule] Automatic, 
      FrameLabel \[Rule] Automatic, PlotType \[Rule] Automatic, 
      ReportedInterval \[Rule] 1000, Intersection \[Rule] True}\)], "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GlassMap[];", "Input",
  CellTags->"Rayica's Data Base"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.00895057 -0.93489 0.716517 [
[.08113 -0.0125 -9 -9 ]
[.08113 -0.0125 9 0 ]
[.26014 -0.0125 -6 -9 ]
[.26014 -0.0125 6 0 ]
[.43916 -0.0125 -6 -9 ]
[.43916 -0.0125 6 0 ]
[.61817 -0.0125 -6 -9 ]
[.61817 -0.0125 6 0 ]
[.79718 -0.0125 -6 -9 ]
[.79718 -0.0125 6 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -90 -18 ]
[.5 -0.0125 90 -9 ]
[-0.0125 .06823 -18 -4.5 ]
[-0.0125 .06823 0 4.5 ]
[-0.0125 .21154 -18 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .35484 -18 -4.5 ]
[-0.0125 .35484 0 4.5 ]
[-0.0125 .49814 -12 -4.5 ]
[-0.0125 .49814 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30 -4.5 ]
[-0.01875 .30902 -18 4.5 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -246 0 ]
[.5 .63053 246 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08113 0 m
.08113 .00625 L
s
[(100)] .08113 -0.0125 0 1 Mshowa
.26014 0 m
.26014 .00625 L
s
[(80)] .26014 -0.0125 0 1 Mshowa
.43916 0 m
.43916 .00625 L
s
[(60)] .43916 -0.0125 0 1 Mshowa
.61817 0 m
.61817 .00625 L
s
[(40)] .61817 -0.0125 0 1 Mshowa
.79718 0 m
.79718 .00625 L
s
[(20)] .79718 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.12589 0 m
.12589 .00375 L
s
.17064 0 m
.17064 .00375 L
s
.21539 0 m
.21539 .00375 L
s
.3049 0 m
.3049 .00375 L
s
.34965 0 m
.34965 .00375 L
s
.3944 0 m
.3944 .00375 L
s
.48391 0 m
.48391 .00375 L
s
.52866 0 m
.52866 .00375 L
s
.57341 0 m
.57341 .00375 L
s
.66292 0 m
.66292 .00375 L
s
.70767 0 m
.70767 .00375 L
s
.75243 0 m
.75243 .00375 L
s
.84193 0 m
.84193 .00375 L
s
.88668 0 m
.88668 .00375 L
s
.93144 0 m
.93144 .00375 L
s
.03638 0 m
.03638 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
[(Abbe V-number = \\(nd-1\\)/\\(nf-nc\\))] .5 -0.0125 0 -9 Mabsadd 0 1 Mshowa
0 .06823 m
.00625 .06823 L
s
[(1.4)] -0.0125 .06823 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(1.6)] -0.0125 .21154 1 0 Mshowa
0 .35484 m
.00625 .35484 L
s
[(1.8)] -0.0125 .35484 1 0 Mshowa
0 .49814 m
.00625 .49814 L
s
[(2.)] -0.0125 .49814 1 0 Mshowa
.125 Mabswid
0 .10406 m
.00375 .10406 L
s
0 .13989 m
.00375 .13989 L
s
0 .17571 m
.00375 .17571 L
s
0 .24736 m
.00375 .24736 L
s
0 .28319 m
.00375 .28319 L
s
0 .31902 m
.00375 .31902 L
s
0 .39067 m
.00375 .39067 L
s
0 .42649 m
.00375 .42649 L
s
0 .46232 m
.00375 .46232 L
s
0 .03241 m
.00375 .03241 L
s
0 .53397 m
.00375 .53397 L
s
0 .5698 m
.00375 .5698 L
s
0 .60562 m
.00375 .60562 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
[(nd)] -0.01875 .30902 -18 0 Mabsadd 1 0 Mshowa
.08113 .61178 m
.08113 .61803 L
s
.26014 .61178 m
.26014 .61803 L
s
.43916 .61178 m
.43916 .61803 L
s
.61817 .61178 m
.61817 .61803 L
s
.79718 .61178 m
.79718 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.12589 .61428 m
.12589 .61803 L
s
.17064 .61428 m
.17064 .61803 L
s
.21539 .61428 m
.21539 .61803 L
s
.3049 .61428 m
.3049 .61803 L
s
.34965 .61428 m
.34965 .61803 L
s
.3944 .61428 m
.3944 .61803 L
s
.48391 .61428 m
.48391 .61803 L
s
.52866 .61428 m
.52866 .61803 L
s
.57341 .61428 m
.57341 .61803 L
s
.66292 .61428 m
.66292 .61803 L
s
.70767 .61428 m
.70767 .61803 L
s
.75243 .61428 m
.75243 .61803 L
s
.84193 .61428 m
.84193 .61803 L
s
.88668 .61428 m
.88668 .61803 L
s
.93144 .61428 m
.93144 .61803 L
s
.03638 .61428 m
.03638 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06823 m
1 .06823 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .35484 m
1 .35484 L
s
.99375 .49814 m
1 .49814 L
s
.125 Mabswid
.99625 .10406 m
1 .10406 L
s
.99625 .13989 m
1 .13989 L
s
.99625 .17571 m
1 .17571 L
s
.99625 .24736 m
1 .24736 L
s
.99625 .28319 m
1 .28319 L
s
.99625 .31902 m
1 .31902 L
s
.99625 .39067 m
1 .39067 L
s
.99625 .42649 m
1 .42649 L
s
.99625 .46232 m
1 .46232 L
s
.99625 .03241 m
1 .03241 L
s
.99625 .53397 m
1 .53397 L
s
.99625 .5698 m
1 .5698 L
s
.99625 .60562 m
1 .60562 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(Refractive index versus Abbe number for {f,d,c} = {0.4861, 0.5876, 0.6563} \
microns)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.21539 .13272 m
.42125 .13272 L
.48391 .13989 L
.61817 .18646 L
.66292 .22229 L
.75243 .33335 L
.81508 .49814 L
s
.26014 .16855 m
.48391 .16855 L
.52866 .17571 L
.57341 .19004 L
.61817 .21154 L
.66292 .25095 L
.74348 .35484 L
.79718 .49814 L
s
.3049 .22945 m
.42125 .22945 L
.48391 .24736 L
.52866 .25811 L
.65397 .31185 L
.70767 .31185 L
s
.48391 .21154 m
.52866 .21154 L
s
.52866 .35484 m
.74348 .35484 L
s
.36755 .13272 m
.48391 .21154 L
s
.68313 .24736 m
.79718 .24736 L
s
.42125 .0969 m
.42125 .22945 L
s
.48391 .0969 m
.48391 .24736 L
s
.52866 .15541 m
.52866 .49814 L
s
.57341 .17094 m
.57341 .19004 L
s
.59132 .19864 m
.59132 .28498 L
s
.61817 .18646 m
.61817 .21154 L
s
.66292 .22229 m
.66292 .25095 L
s
.005 w
.02753 .05175 Mdot
.86504 .50056 Mdot
.86493 .51237 Mdot
.82481 .4818 Mdot
.80713 .44287 Mdot
.80351 .40816 Mdot
.794 .4641 Mdot
.78935 .44287 Mdot
.78948 .54603 Mdot
.78677 .43749 Mdot
.78573 .44287 Mdot
.78374 .43911 Mdot
.77256 .36064 Mdot
.76452 .25907 Mdot
.76484 .38827 Mdot
.76344 .38827 Mdot
.76344 .38827 Mdot
.76302 .33935 Mdot
.76249 .38827 Mdot
.76249 .38827 Mdot
.76303 .38827 Mdot
.76157 .34566 Mdot
.75193 .32295 Mdot
.749 .35855 Mdot
.74863 .35855 Mdot
.74863 .35855 Mdot
.74866 .35855 Mdot
.74872 .35855 Mdot
.74641 .34389 Mdot
.74571 .33234 Mdot
.74575 .34389 Mdot
.74614 .34389 Mdot
.74614 .34389 Mdot
.74287 .34387 Mdot
.74289 .34388 Mdot
.74097 .34387 Mdot
.74163 .34388 Mdot
.74163 .34388 Mdot
.73862 .32748 Mdot
.73862 .32748 Mdot
.73886 .32748 Mdot
.73894 .32748 Mdot
.73849 .49972 Mdot
.73735 .33675 Mdot
.73507 .32747 Mdot
.73366 .32746 Mdot
.73366 .32746 Mdot
.73278 .32274 Mdot
.72926 .3124 Mdot
.72944 .32274 Mdot
.73004 .32274 Mdot
.73004 .32274 Mdot
.73005 .32274 Mdot
.72753 .3124 Mdot
.72753 .3124 Mdot
.72757 .3124 Mdot
.72824 .31787 Mdot
.72487 .31242 Mdot
.72392 .31185 Mdot
.72303 .31185 Mdot
.72311 .31185 Mdot
.72314 .31185 Mdot
.72323 .5005 Mdot
.72201 .30343 Mdot
.72216 .35128 Mdot
.72227 .43613 Mdot
.72154 .30343 Mdot
.72156 .30343 Mdot
.72111 .33085 Mdot
.71954 .30346 Mdot
.71823 .49279 Mdot
.7162 .51393 Mdot
.71454 .2986 Mdot
.71465 .2986 Mdot
.7121 .29563 Mdot
.71214 .29563 Mdot
.71214 .29562 Mdot
.7086 .20112 Mdot
.70825 .4328 Mdot
.70718 .28244 Mdot
.70664 .28243 Mdot
.7067 .28243 Mdot
.7051 .28738 Mdot
.70423 .35734 Mdot
.70003 .20471 Mdot
.69908 .22336 Mdot
.6981 .27525 Mdot
.6981 .27525 Mdot
.69816 .27526 Mdot
.69726 .27526 Mdot
.69392 .42746 Mdot
.69249 .31184 Mdot
.69255 .32398 Mdot
.69244 .24236 Mdot
.68898 .26363 Mdot
.689 .26363 Mdot
.68801 .26362 Mdot
.68856 .30917 Mdot
.68837 .39085 Mdot
.68733 .39085 Mdot
.68663 .43615 Mdot
.6809 .2594 Mdot
.68135 .44848 Mdot
.68045 .2594 Mdot
.68053 .2594 Mdot
.67821 .45315 Mdot
.67633 .29644 Mdot
.67611 .6119 Mdot
.67518 .18284 Mdot
.67512 .25056 Mdot
.67376 .24571 Mdot
.67385 .24571 Mdot
.67336 .24571 Mdot
.67342 .24615 Mdot
.67155 .24457 Mdot
.67103 .28108 Mdot
.66983 .35911 Mdot
.66773 .24005 Mdot
.66783 .24005 Mdot
.6665 .29785 Mdot
.66473 .18821 Mdot
.66559 .29785 Mdot
.66349 .31866 Mdot
.66334 .35555 Mdot
.66346 .44112 Mdot
.66233 .35277 Mdot
.66028 .20631 Mdot
.66052 .31865 Mdot
.66056 .31865 Mdot
.66074 .40786 Mdot
.65968 .23759 Mdot
.66 .23759 Mdot
.65845 .20692 Mdot
.65803 .22971 Mdot
.65678 .23008 Mdot
.65678 .23008 Mdot
.65679 .23008 Mdot
.65578 .25772 Mdot
.65517 .22655 Mdot
.65563 .25772 Mdot
.65372 .22757 Mdot
.6525 .22656 Mdot
.65169 .2259 Mdot
.65175 .2259 Mdot
.65181 .2259 Mdot
.65082 .22589 Mdot
.64844 .22342 Mdot
.64848 .22342 Mdot
.64753 .25248 Mdot
.64511 .2208 Mdot
.64521 .2208 Mdot
.64481 .2208 Mdot
.6434 .34179 Mdot
.64372 .3792 Mdot
.64167 .26932 Mdot
.64109 .37076 Mdot
.64035 .26635 Mdot
.63772 .21558 Mdot
.63768 .33729 Mdot
.63609 .21399 Mdot
.63661 .29997 Mdot
.63667 .29997 Mdot
.63594 .21399 Mdot
.63597 .21399 Mdot
.63549 .22619 Mdot
.63522 .30019 Mdot
.6359 .29997 Mdot
.63556 .41073 Mdot
.63514 .22619 Mdot
.63413 .21254 Mdot
.63111 .28147 Mdot
.62935 .20832 Mdot
.6276 .23021 Mdot
.62535 .20832 Mdot
.62566 .20832 Mdot
.62533 .23021 Mdot
.62593 .24748 Mdot
.62547 .26168 Mdot
.62493 .20832 Mdot
.6251 .20832 Mdot
.62476 .26168 Mdot
.62377 .24747 Mdot
.62382 .28605 Mdot
.62202 .35799 Mdot
.62252 .57795 Mdot
.62111 .25031 Mdot
.62165 .25031 Mdot
.61745 .28462 Mdot
.61742 .32761 Mdot
.61596 .21667 Mdot
.61286 .36058 Mdot
.61144 .19824 Mdot
.61158 .19824 Mdot
.61163 .19824 Mdot
.61147 .41431 Mdot
.6107 .19824 Mdot
.611 .24342 Mdot
.60928 .28448 Mdot
.61003 .35921 Mdot
.60928 .41264 Mdot
.60866 .2038 Mdot
.60749 .28429 Mdot
.6072 .28429 Mdot
.60723 .28429 Mdot
.60485 .19363 Mdot
.60498 .19363 Mdot
.60498 .19363 Mdot
.60408 .30841 Mdot
.6013 .24842 Mdot
.60104 .25994 Mdot
.60107 .25994 Mdot
.60051 .29752 Mdot
.5986 .17403 Mdot
.59893 .2796 Mdot
.59841 .35449 Mdot
.59755 .21385 Mdot
.59527 .19226 Mdot
.59311 .18812 Mdot
.59395 .37978 Mdot
.59277 .18812 Mdot
.59298 .18812 Mdot
.58515 .21556 Mdot
.58516 .29752 Mdot
.5853 .29752 Mdot
.58476 .18605 Mdot
.58501 .21556 Mdot
.58394 .22114 Mdot
.58316 .21556 Mdot
.58295 .24269 Mdot
.58297 .34368 Mdot
.58071 .34473 Mdot
.57989 .22114 Mdot
.58014 .22114 Mdot
.57906 .13299 Mdot
.57949 .22092 Mdot
.5793 .36598 Mdot
.57802 .27081 Mdot
.57549 .31471 Mdot
.57609 .31472 Mdot
.57467 .2397 Mdot
.57472 .23969 Mdot
.5742 .24897 Mdot
.57369 .26092 Mdot
.57392 .26092 Mdot
.57095 .35125 Mdot
.56993 .17487 Mdot
.56656 .17438 Mdot
.56659 .17438 Mdot
.56687 .17438 Mdot
.5654 .16322 Mdot
.56616 .17438 Mdot
.56432 .29752 Mdot
.56123 .35712 Mdot
.56043 .19912 Mdot
.56085 .19912 Mdot
.56085 .19912 Mdot
.56068 .21769 Mdot
.55953 .3577 Mdot
.55908 .3663 Mdot
.55655 .2105 Mdot
.55568 .22855 Mdot
.55482 .22855 Mdot
.55471 .26171 Mdot
.55415 .16906 Mdot
.5536 .16906 Mdot
.55365 .16906 Mdot
.55342 .26171 Mdot
.55362 .26171 Mdot
.55239 .34624 Mdot
.55148 .34646 Mdot
.54842 .32417 Mdot
.54808 .24255 Mdot
.54832 .32403 Mdot
.54711 .24254 Mdot
.54709 .29537 Mdot
.54738 .29537 Mdot
.54602 .28319 Mdot
.54603 .28319 Mdot
.54483 .25335 Mdot
.54494 .27063 Mdot
.5439 .25934 Mdot
.54383 .25934 Mdot
.54275 .20365 Mdot
.54218 .20578 Mdot
.54297 .25934 Mdot
.54212 .28104 Mdot
.54189 .25355 Mdot
.54194 .28104 Mdot
.53992 .16261 Mdot
.53865 .16261 Mdot
.53922 .16261 Mdot
.53819 .16261 Mdot
.5361 .21676 Mdot
.53475 .31414 Mdot
.53244 .33513 Mdot
.53271 .3356 Mdot
.53209 .17653 Mdot
.53143 .27531 Mdot
.5305 .22423 Mdot
.53089 .22423 Mdot
.53035 .22423 Mdot
.52883 .34517 Mdot
.52686 .29751 Mdot
.52518 .29752 Mdot
.52169 .19075 Mdot
.52171 .19075 Mdot
.52238 .26735 Mdot
.52159 .27853 Mdot
.52162 .27853 Mdot
.52195 .31492 Mdot
.52233 .6087 Mdot
.52095 .25341 Mdot
.52099 .25341 Mdot
.52113 .25341 Mdot
.51971 .14789 Mdot
.51829 .20348 Mdot
.51836 .22217 Mdot
.51846 .22217 Mdot
.51658 .20361 Mdot
.51549 .15666 Mdot
.51569 .30755 Mdot
.51429 .16098 Mdot
.51343 .16098 Mdot
.51292 .30719 Mdot
.51104 .38075 Mdot
.50916 .15237 Mdot
.50865 .15669 Mdot
.50726 .15236 Mdot
.50807 .32259 Mdot
.5071 .15236 Mdot
.5071 .32186 Mdot
.506 .15515 Mdot
.5055 .2244 Mdot
.50564 .26222 Mdot
.50526 .31256 Mdot
.50229 .19101 Mdot
.50243 .19101 Mdot
.50179 .24629 Mdot
.50033 .22751 Mdot
.50049 .22751 Mdot
.50062 .22752 Mdot
.50017 .27853 Mdot
.49905 .27853 Mdot
.49748 .31006 Mdot
.49708 .17384 Mdot
.49694 .30182 Mdot
.49637 .17384 Mdot
.49567 .1969 Mdot
.49635 .21412 Mdot
.49384 .22386 Mdot
.49425 .2925 Mdot
.49456 .2925 Mdot
.49269 .22386 Mdot
.49165 .1817 Mdot
.48666 .1503 Mdot
.48677 .1503 Mdot
.48672 .27674 Mdot
.48697 .30408 Mdot
.4857 .27674 Mdot
.4842 .2216 Mdot
.48437 .2216 Mdot
.48479 .26735 Mdot
.48366 .22418 Mdot
.48284 .22418 Mdot
.48232 .26735 Mdot
.4807 .23915 Mdot
.48106 .26735 Mdot
.48044 .28089 Mdot
.48032 .23915 Mdot
.47935 .28089 Mdot
.4759 .21954 Mdot
.47613 .24817 Mdot
.47399 .1892 Mdot
.4737 .24808 Mdot
.47314 .14646 Mdot
.4715 .14087 Mdot
.47159 .14087 Mdot
.47191 .1892 Mdot
.47213 .1892 Mdot
.47161 .22139 Mdot
.47189 .22139 Mdot
.4714 .28085 Mdot
.46935 .21682 Mdot
.46879 .21888 Mdot
.468 .15136 Mdot
.46786 .21682 Mdot
.46786 .21682 Mdot
.46708 .22787 Mdot
.46686 .24091 Mdot
.46565 .22787 Mdot
.46574 .22787 Mdot
.46387 .25331 Mdot
.46264 .15346 Mdot
.46324 .25331 Mdot
.46278 .26084 Mdot
.46328 .26169 Mdot
.46214 .13398 Mdot
.4613 .19183 Mdot
.45941 .19183 Mdot
.45957 .19183 Mdot
.45744 .16364 Mdot
.45735 .18842 Mdot
.45761 .24199 Mdot
.45673 .22801 Mdot
.45595 .15157 Mdot
.45595 .15157 Mdot
.45595 .15157 Mdot
.45595 .15157 Mdot
.45578 .22801 Mdot
.45599 .22801 Mdot
.45543 .3469 Mdot
.45458 .20567 Mdot
.45396 .24198 Mdot
.45264 .24851 Mdot
.45234 .24851 Mdot
.4511 .18052 Mdot
.45119 .18052 Mdot
.45146 .18052 Mdot
.45085 .22065 Mdot
.45163 .22065 Mdot
.45057 .22065 Mdot
.4492 .15295 Mdot
.44902 .21785 Mdot
.44853 .15295 Mdot
.44862 .15295 Mdot
.44497 .19945 Mdot
.44496 .21676 Mdot
.444 .156 Mdot
.44418 .16851 Mdot
.44426 .16851 Mdot
.4443 .19945 Mdot
.44421 .21676 Mdot
.44198 .16852 Mdot
.44124 .156 Mdot
.44161 .24054 Mdot
.44085 .156 Mdot
.43831 .22616 Mdot
.43846 .24055 Mdot
.43871 .2402 Mdot
.43777 .15606 Mdot
.43705 .15313 Mdot
.43648 .22616 Mdot
.43659 .22651 Mdot
.43678 .22616 Mdot
.43694 .22616 Mdot
.4371 .22616 Mdot
.43574 .14785 Mdot
.43595 .15606 Mdot
.43503 .14785 Mdot
.43403 .21377 Mdot
.43315 .18563 Mdot
.43341 .18563 Mdot
.43307 .21377 Mdot
.43355 .21376 Mdot
.43364 .21377 Mdot
.43341 .2948 Mdot
.43223 .18563 Mdot
.42875 .14595 Mdot
.42888 .18261 Mdot
.4288 .20375 Mdot
.42922 .20375 Mdot
.42755 .17751 Mdot
.42804 .20375 Mdot
.42834 .20375 Mdot
.4265 .13998 Mdot
.4249 .12469 Mdot
.42013 .16219 Mdot
.41431 .22372 Mdot
.41159 .18913 Mdot
.41179 .18913 Mdot
.41108 .18913 Mdot
.40955 .22443 Mdot
.40837 .14712 Mdot
.40845 .17737 Mdot
.40823 .22597 Mdot
.40685 .14712 Mdot
.4064 .15432 Mdot
.40209 .15192 Mdot
.40231 .15159 Mdot
.40099 .15192 Mdot
.4014 .15159 Mdot
.39822 .2015 Mdot
.39766 .1581 Mdot
.39407 .13868 Mdot
.3944 .13867 Mdot
.39415 .15293 Mdot
.39428 .15293 Mdot
.39097 .21376 Mdot
.39067 .21369 Mdot
.38776 .11445 Mdot
.38624 .11445 Mdot
.3784 .14259 Mdot
.37744 .14259 Mdot
.37715 .13832 Mdot
.37421 .18111 Mdot
.35898 .11719 Mdot
.35381 .15226 Mdot
.35248 .1546 Mdot
.35027 .17163 Mdot
.35027 .17163 Mdot
.34779 .13092 Mdot
.34627 .13092 Mdot
.34673 .13092 Mdot
.34648 .38472 Mdot
.33641 .17853 Mdot
.33641 .17853 Mdot
.32317 .32625 Mdot
.31193 .17449 Mdot
.29739 .13009 Mdot
.28749 .16034 Mdot
.2688 .13021 Mdot
.26638 .30763 Mdot
.25299 .21444 Mdot
.25025 .13774 Mdot
.24919 .20918 Mdot
.24601 .1216 Mdot
.24665 .13773 Mdot
.24431 .12989 Mdot
.2204 .13026 Mdot
.22046 .13026 Mdot
.20134 .05978 Mdot
.18628 .01472 Mdot
.18049 .12303 Mdot
.1679 .10836 Mdot
.16468 .09474 Mdot
.15671 .09541 Mdot
.14187 .29653 Mdot
.13921 .10677 Mdot
.12627 .09249 Mdot
.12627 .09249 Mdot
.12627 .09249 Mdot
.12628 .096 Mdot
.10569 .06261 Mdot
.10142 .04127 Mdot
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(LaSF)] .73005 .41575 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(LaSF)] .57341 .39067 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(LaF)] .56446 .32618 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(LaF)] .67635 .33693 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(LaK)] .48391 .32618 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(LaK)] .42125 .26169 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(SF)] .78957 .45372 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(SF)] .75869 .37275 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(SF)] .69425 .27961 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(SK)] .44327 .20796 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(SSK)] .50629 .23877 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(BaSF)] .64609 .28677 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(BaF)] .57162 .23948 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(BaLF)] .50897 .18789 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(BaK)] .46601 .17571 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(BK)] .4123 .13989 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(PK)] .31385 .15422 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(PSK)] .34965 .19004 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(FK)] .2691 .11839 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(TiK)] .45258 .11839 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(TiSF)] .7211 .25811 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(TiF)] .67635 .22229 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(TiF)] .55551 .15063 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(LF)] .5949 .19004 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(LLF)] .55372 .175 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(KF)] .49814 .15887 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(K)] .45455 .14633 0 0 Mshowa
P
p
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12 scalefont setfont
[(F)] .6298 .20437 0 0 Mshowa
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{690.75, 426.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:b0001ZR000`400?l00000o`00003ooooooomf
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo0>cooooo003ooooooaCooooo0_l000000ooooooo0000o`000005o`00
00;ooooo1?l00003ooooo`?o00002_ooool00ol0003oooooooooo`07ooooo`?o000000?oooooo`00
0?l000000_ooool2o`000008ooooool0003o0000ooooool0003oooooo`000?ooool4o`0000?ooooo
0ol00002ooooo`?o00005_ooool00ol0003oooooooooo`02ooooo`?o000000Coooooo`000?l0003o
oooo1?l00008ooooo`?o00001Oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooo
ooooool00_ooool3o`000003ooooool0003o000000Go00001oooool3o`000004ooooool0003o0000
ooooo`?o00001Oooool00ol0003oooooooooo`3[ooooo`00oooooolDooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo
00003Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo00[o0000oooo
oooooooo0000ooooool0003oooooo`000?oooooo00000_ooool01_l0003oooooooooool0003ooooo
o`0000Kooooo00?o0000ooooooooool02?ooool5o`0000Sooooo00?o0000ooooooooool00oooool0
1_l0003oooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3[
ooooo`00oooooolDooooo`Go00000_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooo
ooooo`000?ooool01Ol00009ooooo`04o`000?ooooooooooooooo`Go00000_ooool01?l0003ooooo
ooooool00002ooooo`0:o`000?ooooooooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo
00Go0000oooooooooooo0000ooooo`05o`0000;ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`03ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`05
o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`04o`000?oo
ooooooooooooo`Go00000_ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000oooo
ooooool0joooool00?oooooo5Oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000002Oooool01?l0003oooooooooool00002ooooo`0:o`000?ooooooooooo`000?oo
oooo0000ooooool0003oooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03
o`000?oooooooooo00;o00002Oooool5o`0000Sooooo00?o0000ooooooooool00oooool01_l0003o
ooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool02?ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3[ooooo`00oooooolEooooo`03
o`000?oooooo000000?ooooo0ol00003ooooo`?o00000oooool3o`0000Wooooo00?o0000ooooool0
00002?ooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003ooooo
00;ooooo0ol00003ooooo`?o00000_ooool2o`000003ooooool0003o000001Cooooo00?o0000oooo
ooooool00_ooool4o`0000?ooooo0ol0000:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Cooooo1?l00003ooooo`Co00001oooool4
o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo0>_ooooo003ooooooaKooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ool000006oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01oooool2o`0000Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3/ooooo`00oooooolEoooo
o`;o00000oooool2o`0000Cooooo0_l0000@ooooo`Go00006Oooool2o`0002Gooooo00?o0000oooo
ooooool02?ooool2o`0000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool2o`0001Cooooo00?o0000oooo
ooooool0kOooool00?oooooooooooondooooo`00oooooooooooookCooooo001Qooooo`?o00001?oo
ool2o`0000Cooooo0_l0001Sooooo`?o00001?ooool2o`0006Kooooo0ol00004ooooo`;o0000Iooo
ool3o`0000?ooooo0_l0001Vooooo`Go00000oooool2o`0006[ooooo0_l0000Looooo`00H_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
HOooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000I?ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000Ioooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool0I?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0006Sooooo00Co0000oooooooooooo00006oooool006;ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00067ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0006Cooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0006Cooooo1Ol00002ooooo`04o`000?oooooo
ooooo`0006Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0001Xooooo`04o`00
0?ooooooooooo`0001_ooooo001Rooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0001Rooooo`?o00000oooool01?l0003oooooooooool0001T
ooooo`Co00000oooool01?l0003oooooooooool0001Tooooo`04o`000?ooooooooooo`0000?ooooo
00Co0000oooooooooooo0000J?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool0I_ooool01?l0003oooooooooool0000Kooooo`00H_ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000HOooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo0000I?ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0006Gooooo00?o0000ooooool000000oooool01?l0003oooooooooool0001U
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0001Xooooo`04o`00
0?ooooooooooo`0001_ooooo001Qooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`00067ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0006Gooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0001Vooooo`;o0000
0oooool01?l0003oooooooooool0001Uooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0001Xooooo`04o`000?ooooooooooo`0001_ooooo001Rooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o0000Hoooool3o`0000Cooooo0_l0001Wooooo`;o00001?ooool2
o`0006Sooooo00?o0000ooooooooool00_ooool2o`0006Oooooo0ol00004ooooo`;o0000J_ooool2
o`0001cooooo003ooooooooooooo]?ooool00?oooooooooooondooooo`00oooooooooooookCooooo
003ooooooooooooo]?ooool00?oooooooooooondooooo`00oooooooooooookCooooo003ooooooooo
oooo]?ooool00?oooooooooooondooooo`00=oooooooo`000?oo0000Kol0000>ooooo`00=oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
03Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo000gooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo06cooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
000gooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooooooo00cooooo000g
ooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooooooo00cooooo000goooo
o`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooooooo00cooooo000gooooo`03
o`000?oooooooooo06oooooo0ol0003oooooooSooooo00?o0000ooooooooool03?ooool003Oooooo
00?o0000ooooooooool0Koooool3o`000?oooooon?ooool00ol0003oooooooooo`0<ooooo`00=ooo
ool00ol0003oooooooooo`1_ooooo`?o0000ooooooohooooo`03o`000?oooooooooo00cooooo000g
ooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooooooo00cooooo000goooo
o`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooooooo00cooooo000gooooo`03
o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`00
0?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oo
oooooooo0?oooooooooooom[ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooo
oooo0?oooooooooooom[ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo
0?oooooooooooom[ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oo
oooooooooom[ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooo
oooooom[ooooo`03o`000?oooooooooo00cooooo000gooooo`?o0000ooooooooooooofWooooo0ol0
000>ooooo`00=oooool00ol0003oooooooooo`3oooooooooooooJoooool00ol0003oooooooooo`0<
ooooo`00=oooool00ol0003oooooooooo`3oooooooooooooJoooool00ol0003oooooooooo`0<oooo
o`00=oooool00ol0003oooooooooo`3oooooooooooooJoooool00ol0003oooooooooo`0<ooooo`00
=oooool00ol0003oooooooooo`3oooooooooooooJoooool00ol0003oooooooooo`0<ooooo`00=ooo
ool00ol0003oooooooooo`0kooooo`?o0000ooooooooooooobgooooo00?o0000ooooooooool03?oo
ool003Oooooo00?o0000ooooooooool0>oooool3o`000?ooooooooooool]ooooo`03o`000?oooooo
oooo00cooooo000gooooo`03o`000?oooooooooo03_ooooo0ol0003ooooooooooooo;Oooool00ol0
003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooooooooooJoooool00ol0003o
ooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooooooooooJoooool00ol0003ooooo
ooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooooooooooJoooool00ol0003ooooooooo
o`0<ooooo`00=oooool00ol0003oooooooooo`0=ooooo`?o0000oooooooooooooe_ooooo00?o0000
ooooooooool03?ooool003Oooooo00?o0000ooooooooool03Oooool3o`000?oooooooooooomKoooo
o`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo00gooooo0ol0003ooooooooo
ooooFoooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3ooooooooooooo
Joooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooooooooooJooo
ool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`1iooooo`?o0000ooooooo^
ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo07Wooooo0ol0003ooooo
onkooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0?_ooool3o`0003So
oooo0ol0003oooooonkooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0
?_ooool3o`000?oooooooooooolZooooo`03o`000?oooooooooo00cooooo000Nooooo`?o00001?oo
ool00ol0003oooooooooo`03ooooo`?o00002Oooool00ol0003oooooooooo`0nooooo`?o0000oooo
ooooooooob[ooooo00?o0000ooooooooool03?ooool001oooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooo
oooo00cooooo000Oooooo`03o`000?oooooooooo00Oooooo1Ol00009ooooo`03o`000?oooooooooo
0?oooooooooooom[ooooo`03o`000?oooooooooo00cooooo000Oooooo`03o`000?oooooooooo00Oo
oooo00Co0000oooooooooooo00002_ooool5o`000?oooooooooooomUooooo`Go00003_ooool001oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo0?oo
oooooooooom[ooooo`03o`000?oooooooooo00cooooo000Nooooo`;o00002oooool2o`0000[ooooo
00?o0000ooooooooool0ooooooooooooof_ooooo00?o0000ooooooooool03?ooool001oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooooooo
oom[ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooooooooom[
ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooooooooom[oooo
o`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03
o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`00
0?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oo
oooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooo
oooo00cooooo000gooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooooooo
00cooooo000gooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooooooo00co
oooo000gooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooooooo00cooooo
000gooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooooooo00cooooo000g
ooooo`03o`000?oooooooooo04[ooooo0ol0003ooooooooooooo7_ooool00ol0003oooooooooo`0<
ooooo`00=oooool00ol0003oooooooooo`1:ooooo`?o00005Oooool3o`000?ooooooooooool6oooo
o`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo04[ooooo0ol0000@ooooo`?o
00000_ooool3o`000?ooooooooooool6ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`00
0?oooooooooo04[ooooo0ol0000@ooooo`?o00000_ooool3o`0009gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`3oooooockooooo00?o0000ooooooooool03?ooool003Oooooo00?o
0000ooooooooool0B_ooool3o`00013ooooo0ol0002Rooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0oooooolnooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooo
oooo0?oooooo0oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0?oooooo?_ooool0
0ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooo`?ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`3oooooockooooo00?o0000ooooooooool03?ooool003Oo
oooo00?o0000ooooooooool0ooooool3ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0oooooolnooooo`03o`000?oooooooooo00cooooo000gooooo`?o0000ooooool3ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0oooooollooooo`?o00003_ooool003Oooooo00?o
0000ooooooooool0D_ooool3o`000:gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`3oooooockooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0D_ooool3
o`0000oooooo0ol0002Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0ooooooln
ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo05;ooooo0ol0000?oooo
o`?o0000Voooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0?oooooo?_ooool00ol0
003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`1Tooooo`?o0000Voooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo0?oooooo?_ooool00ol0003oooooooooo`0<ooooo`00
=oooool00ol0003oooooooooo`3/ooooo`?o00004oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo0?oooooo?_ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003ooooooooo
o`2Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`10ooooo`?o00004oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
oooooolnooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo09gooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000003;ooooo0ol0000>ooooo`?o0000
4oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000gooooo00?o0000ooooooooool0oooooolnooooo`03o`000?oooooooooo
00cooooo000gooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000003;ooooo0ol0000Tooooo`03o`000?oooooooooo00_ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003ooooooooo
o`3oooooockooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0WOooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0003?ooooo0ol0000Tooooo`03o`000?oo
oooooooo00_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000ko
oooo00?o0000ooooooooool0oooooolnooooo`03o`000?oooooooooo00cooooo000gooooo`03o`00
0?oooooooooo09Gooooo0ol00005ooooo`Ko000000Coooooo`000?l0003o0000Foooool00ol0003o
ooooooooo`0;ooooo`05o`000?ooooooooooooooool000000_ooool3o`0000oooooo00?o0000oooo
ooooool0oooooolnooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo06co
oooo0ol0000Vooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000005_o
oooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ool000003oooool00ol0003oooooooooo`3oooooockooooo00?o0000ooooooooool03?ooool003Oo
oooo00?o0000ooooooooool0K?ooool3o`0002Kooooo0ol00005ooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo0000F_ooool00ol0003oooooo`000002o`0000Wooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool0oooo
oolnooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo06cooooo0ol0000^
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00001Iooooo`03o`000?oo
oooo000000;o00002Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
3Oooool00ol0003oooooooooo`3oooooockooooo00?o0000ooooooooool03?ooool003Oooooo00?o
0000ooooooooool0WOooool6o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool0E_oo
ool00ol0003oooooo`000002o`0000Kooooo2?l00002ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`3oooooockooooo00?o0000ooooooooool03?oo
ool003Oooooo00?o0000ooooooooool0QOooool3o`0000cooooo0ol0000<ooooo`?o00003_ooool3
o`0004_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`3oooooockooooo00?o0000
ooooooooool03?ooool003Oooooo00?o0000ooooooooool0QOooool3o`0000cooooo0ol0000<oooo
o`?o00003_ooool3o`0001cooooo1?l0000[ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0oooooolnooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo08Go
oooo0ol0000<ooooo`?o00003?ooool3o`0000kooooo0ol0000Looooo`Co0000:oooool00ol0003o
ooooooooo`0Fooooo`?o00002oooool00ol0003oooooooooo`0gooooo`?o0000ooooool4ooooo`03
o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo08?oooooQOl0000Cooooo`?o0000
2oooool00ol0003oooooooooo`0gooooo`?o0000ooooool4ooooo`03o`000?oooooooooo00cooooo
000gooooo`03o`000?oooooooooo0>?ooooo00?o0000ooooooooool03oooool6o`0000?ooooo00Co
0000oooooooooooooooo0_l00004ooooo`[o00002Oooool3o`0000_ooooo00?o0000ooooooooool0
=oooool3o`000?oooooo1?ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003ooooooooo
o`2Eooooo`Go0000B_ooool5o`0000Oooooo1?l000000ooooooo0000ooooo`04ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool03Oooool9o`0000kooooo00?o0000ooooooooool0
oooooolnooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo09Gooooo1Ol0
001<ooooo`?o00001oooool4o`000003ooooool0003ooooo00Cooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`03o`0001?ooooo2_l00004ooooo`03o`000?oooooooooo0?oooooo
?_ooool00ol0003oooooooooo`0<ooooo`00=oooool3o`0009Gooooo1Ol0001<ooooo`?o00001ooo
ool4o`000003ooooool0003ooooo00Cooooo00Co0000oooooooooooo00000_ooool2o`0000;ooooo
0ol0000Hooooo`Co000000?oooooo`000?l000001?l0003oooooocgooooo0ol0000>ooooo`00=ooo
ool00ol0003oooooooooo`3Vooooo`Co00002oooool6o`0000?ooooo0ol000001?oooooo0000oooo
ooooool3o`0000cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`Co0000
1Oooool00ol0003oooooo`000002o`000?oooooo??ooool00ol0003oooooooooo`0<ooooo`00=ooo
ool00ol0003oooooooooo`3Vooooo`Ko00002Oooool00ol0003oooooooooo`03ooooo`08o`000?oo
ooooooooo`000?oooooo0000ooooool0000Aooooo`05o`000?ooooooooooooooool000001oooool4
o`0000Gooooo00?o0000ooooooooool00_ooool3o`000?oooooo>Oooool00ol0003oooooooooo`0<
ooooo`00=oooool00ol0003oooooooooo`3Vooooo`Co00000_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo0ol0000;
ooooo`05o`000?ooooooooooooooool000002?ooool3o`0000Gooooo00?o0000ooooooooool01Ooo
ool3o`000?oooooo=_ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3]
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?l00002ooooo`05o`000?oooooo
ooooooooool000000oooool3o`000004ooooool0003o0000o`0000Oooooo00Co0000oooooooooooo
00002Oooool3o`0000Gooooo00?o0000ooooooooool02?ooool3o`0000Oooooo0ol0000@ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000oooo
ooooool03?ooool003Oooooo00?o0000ooooooooool0k_ooool2o`0000Gooooo1ol00002ooooo`04
o`000?ooooooooooooooo`;o00000_ooool3o`000004ooooool0003o0000o`0000Oooooo0ol0000:
ooooo`?o00001Oooool00ol0003oooooooooo`0;ooooo`?o00001?ooool3o`00013ooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003ooooooooo
o`0<ooooo`00=oooool00ol0003oooooooooo`2iooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo1ol00006
ooooo`03o`000?oooooooooo00Gooooo0ol00007ooooo`03o`000?oooooo000000?o00001?ooool3
o`0000Sooooo1?l0000=ooooo`?o000000Coooooo`000?l0003o00004?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo00cooooo
000gooooo`03o`000?oooooooooo0;Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooo
oooooooo0000017ooooo0ol0000Fooooo`Co000000?oooooo`000?l000000_l00009ooooo`03o`00
0?oooooooooo00Kooooo0ol00004ooooo`Co000000Coooooo`000?l0003o00001?ooool3o`0000So
oooo1?l0000:ooooo`Co00000_ooool2o`0001;ooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003o
ooooooooo`2iooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000Aoooo
o`?o00005_ooool4o`000003ooooool0003o000000Co00001oooool00ol0003oooooooooo`06oooo
o`?o00001?ooool4o`000005ooooool0003o0000o`000?ooool01_l00008ooooo`Co00002_ooool4
o`0000Cooooo0ol0000?ooooo`05o`000?ooooooooooooooool000000_ooool6o`000?oooooo3?oo
ool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`2iooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooooooooo00004_ooool3o`0001Kooooo2ol00007ooooo`03o`000?oo
oooooooo00Gooooo3?l00003ooooo`03o`000?oooooo000000;o00002oooool00ol0003oooooo`00
0004ooooo`04o`000?ooooooooooo`0000;ooooo1Ol00007ooooo`?o00003?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo00co
oooo000gooooo`03o`000?oooooooooo0;Wooooo1Ol00003ooooo`?o00004oooool3o`0001Wooooo
1?l000001?oooooo0000o`000?l00007ooooo`03o`000?oooooooooo00Gooooo2?l00009ooooo`?o
00002oooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool4o`00
00;ooooo0ol00006ooooo`?o00002Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool0ooooool?ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo
0;Wooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0002oooooo0ol0
00000ooooooo0000o`000009ooooo`03o`000?oooooooooo00Gooooo2?l0000Gooooo`03o`000?oo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`Co00000_ooool3o`0000Kooooo
00?o0000ooooooooool00ol00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
ooooool?ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0:kooooo0ol0
0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`0/ooooo`?o00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`So
00001_ooool00ol0003oooooooooo`03ooooo`_o00000_ooool6o`000?oooooo3?ooool00ol0003o
ooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`2^ooooo`?o00002?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0<_ooool2o`0000Go
oooo0ol0000Uooooo`03o`000?oooooo000000;o00001Oooool6o`000003ooooool0003o000000;o
00001oooool00ol0003oooooooooo`02ooooo`Oo0000oooooolIooooo`03o`000?oooooooooo00co
oooo000gooooo`03o`000?oooooooooo0:kooooo0ol00008ooooo`Go00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool00_ooool3o`0001Cooooo
0ol0000>ooooo`05o`000?oooooo0000ooooool000001Oooool00ol0003oooooooooo`04ooooo`Co
00001oooool00ol0003oooooooooo`02ooooo`Co00000oooool3o`0000Oooooo0ol0003oooooo`co
oooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0oOooool2o`0000;ooooo
0ol0000Dooooo`?o00003_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`Co00001_ooool2o`0000Gooooo
0ol0003oooooo`cooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0oooo
ool01?l0003oooooooooool0000Eooooo`?o00003_ooool00ol0003oooooo`000003ooooo`05o`00
0?ooooooooooooooool000004Oooool00ol0003oooooooooo`0>ooooo`?o00000_ooool3o`000?oo
oooo3?ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooo`7ooooo
0ol0000;ooooo`Go00005_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Ko0000
3?ooool00ol0003oooooooooo`0;ooooo`Co00000_ooool3o`000?oooooo3_ooool00ol0003ooooo
ooooo`0<ooooo`00=oooool00ol0003oooooooooo`2Noooooi3o00005oooool00ol0003ooooooooo
o`0;ooooo`Co00001Oooool3o`000?oooooo2oooool00ol0003oooooooooo`0<ooooo`00=oooool0
0ol0003oooooooooo`3Eooooo`?o0000:_ooool3o`0000Wooooo1Ol000000ooooooo0000o`000004
o`0000?ooooo0_l000001Ooooooo0000o`000?oooooo000000Cooooo0_l00004ooooo`Oo00004?oo
ool00ol0003oooooooooo`03ooooo`Ko000000?oooooo`000?l000001?l000000ooooooo0000oooo
o`04ooooo`?o0000ooooool8ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooo
oooo0=Gooooo0ol0000Zooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003ooooooooooooooooo0000ooooool0
00001_ooool3o`0000;ooooo1ol00009ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo1?l0000:ooooo`?o
0000moooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`2mooooo`?o0000
5Oooool3o`0002[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo0000
00Kooooo0ol00009ooooo`Oo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000006o`0000?ooooo0ol00007oooo
o`?o0000moooool00ol0003oooooooooo`0<ooooo`00=oooool3o`000;gooooo0ol0000iooooo`?o
00001_ooool00ol0003oooooooooo`04o`0000_ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04oooo
o`?o00004?ooool6o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooo000000Ko00001_ooool2o`0000Gooooo0ol0003eooooo`?o00003_ooool003Oo
oooo00?o0000ooooooooool0_Oooool3o`0000gooooo0ol0000Yooooo`?o00001_ooool00ol0003o
ooooooooo`03o`000003ooooool0003ooooo00Wooooo1_l00006ooooo`03o`000?oooooooooo00?o
00000oooool00ol0003oooooooooo`0Iooooo`Oo00001_ooool00ol0003oooooooooo`04ooooo`Wo
00002?ooool3o`000?cooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0
cOooool3o`0002Wooooo0ol00006ooooo`03o`000?oooooooooo00?o00000_ooool2o`0000Sooooo
0ol00003ooooo`03o`000?oooooo000000?ooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo01Wooooo1?l00002ooooo`?o00001?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool3o`000?Wooooo00?o0000oooo
ooooool03?ooool003Oooooo00?o0000ooooooooool0cOooool3o`0001Cooooo0ol0000Kooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool3o`0000?ooooo00?o0000oooooooo
ool00ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooooooo0ol0000E
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ol000000ooooooo0000ooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool3o`000?Kooooo00?o0000
ooooooooool03?ooool003Oooooo00?o0000ooooooooool0i?ooool3o`0001_ooooo00Co0000oooo
oooooooooooo0ol00004ooooo`;o00001Oooool3o`0000?ooooo00?o0000ooooooooool01_ooool0
1ol0003ooooooooooooooooo0000ooooool000000oooool3o`0001Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00oooooo0ol0000Yooooo`?o0000aoooool00ol0003oooooooooo`0<ooooo`00=ooo
ool00ol0003oooooooooo`3Tooooo`?o00006oooool01?l0003oooooooooooooool6o`0000?ooooo
00?o0000ooooooooool00_ooool6o`0000Wooooo00?o0000ooooooooool00_ooool2o`000003oooo
ool0003o000000Co00000oooool2o`000004ooooool0003o0000ooooo`Ko000000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool0
00000_l00002ooooo`Ko00000_ooool00ol0003oooooooooo`0Booooo`?o00009_ooool3o`000<Oo
oooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0b_ooool00ol0003ooooo
ooooo`06ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo
00Co0000oooooooooooooooo1_l00004ooooo`;o00005oooool00ol0003oooooo`000005ooooo`03
o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`00000Aooooo`?o00001oooool00ol0003oooooooooo`03ooooo`Oo000000?oooooo`00
0?ooool02?ooool3o`0002?ooooo0ol00037ooooo`03o`000?oooooooooo00cooooo000gooooo`03
o`000?oooooooooo0<[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03oooo
o`Co00001_ooool00ol0003oooooooooo`03ooooo`?o00003_ooool00ol0003oooooo`000005oooo
o`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00001_ooool01Ol0003ooooooooooooo
oooo000001Cooooo0ol00004ooooo`03o`000?oooooooooo00?ooooo0ol00002ooooo`Co00003?oo
ool2o`0001[ooooo0ol0003>ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooo
oooo0<[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool06Oooool3o`0000Cooooo00?o0000ooooooooool03_oo
ool2o`0000?ooooo0ol00006ooooo`Co00001?ooool00ol0003oooooo`000005ooooo`03o`000?oo
oooooooo00Co00000_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
5oooool3o`000003ooooool0003ooooo00Cooooo0ol00002ooooo`Co00003?ooool00ol0003ooooo
o`00000Iooooo`?o0000c_ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003ooooooooo
o`3:ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`0Jooooo`?o00001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Go0000
1?ooool4o`0000Cooooo00?o0000ooooool000001Ol00003ooooo`Co00000_ooool00ol0003ooooo
ooooo`03ooooo`Oo00006Oooool3o`0000Gooooo00Co0000oooooooooooooooo1?l0000<ooooo`04
o`000?ooooooooooo`0001Sooooo0ol0003>ooooo`03o`000?oooooooooo00cooooo000gooooo`03
o`000?oooooooooo0<[ooooo1Ol00004ooooo`Go00000oooool3o`0001gooooo0ol00004ooooo`03
o`000?oooooooooo017ooooo0_l000000ooooooo0000o`000002o`0000Cooooo1?l00004ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooool000001?l00002ooooo`03o`000?oooooooooo00?o
oooo0ol00002ooooo`03o`000?oooooooooo01_ooooo0_l00003ooooo`03o`000?oooooooooo00;o
oooo2Ol00006ooooo`05o`000?ooooooooooooooool00000j?ooool00ol0003oooooooooo`0<oooo
o`00=oooool00ol0003oooooooooo`3:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooo`00000Tooooo`03o`000?oooooooooo01?ooooo1Ol0000<oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool00ol00003ooooo`03o`000?oooooooooo
00?ooooo0ol00002ooooo`03o`000?oooooooooo01gooooo0_l000000ooooooo0000ooooo`03oooo
o`?o00000oooool3o`0000Kooooo00?o0000ooooooooool00_ooool2o`000>Kooooo00?o0000oooo
ooooool03?ooool003Oooooo00?o0000ooooooooool0b_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo01Cooooo0_l0000>ooooo`03o`000?oooooo000000?ooooo0ol00008
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000Qooooo`;o00001?oo
ool3o`0000?ooooo0ol00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0hooo
ool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3:ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooo000000Ko00002?ooool00ol0003oooooooooo`04ooooo`Ko00008Oooool3o`0000Cooooo
00?o0000ooooooooool01Oooool3o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3Rooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0<[ooooo1Ol0
0004ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool02oooool3o`0000Wooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo0ol0
000Cooooo`03o`000?oooooooooo013ooooo0ol0000=ooooo`03o`000?oooooooooo00;o00000_oo
ool6o`0000;ooooo0ol00002ooooo`03o`000?oooooooooo00Kooooo0_l0003Rooooo`03o`000?oo
oooooooo00cooooo000gooooo`03o`000?oooooooooo0??ooooo0ol0000<ooooo`03o`000?oooooo
oooo00_ooooo0ol0000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0@ooooo`?o00004Oooool3o`0000Sooooo0ol00002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`?o0000/_ooool0
0ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3cooooo`?o00003?ooool00ol0
003oooooooooo`0;ooooo`?o00003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool04?ooool3o`00017ooooo00Co0000oooooooooooo00003?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:Oooool3
o`000;;ooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0loooool3o`00
00cooooo00?o0000ooooooooool02Ol00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool2o`0000Oooooo00?o0000ooooooooool04?ooool4o`0000Gooooo00?o0000oooo
ooooool01Oooool3o`0001cooooo00Co0000oooooooooooooooo0_l00004ooooo`?o00000oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08_ooool3
o`0000?ooooo0ol0002booooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo
0?oooooo0oooool00ol0003oooooooooo`04o`0000Gooooo00Co0000oooooooooooo00000oooool4
o`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`Co00001Oooool0
0ol0003oooooooooo`04ooooo`Co00007?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool3
o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`;o00002_ooool3
o`0001Gooooo0ol0002hooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo
0?oooooo0oooool00ol0003oooooooooo`04o`0000Gooooo00Co0000oooooooooooo00000oooool4
o`0000[ooooo0_l00004ooooo`03o`000?oooooooooo013ooooo1?l00005ooooo`03o`000?oooooo
oooo00Cooooo1?l0000Looooo`03o`000?oooooooooo00Gooooo1Ol00003ooooo`03o`000?oooooo
oooo00;ooooo1_l00005ooooo`03o`000?oooooooooo00Gooooo1Ol0000Eooooo`?o0000^?ooool0
0ol0003oooooooooo`0<ooooo`007_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
00[ooooo00?o0000ooooooooool0Uoooool3o`0006Sooooo00?o0000ooooooooool02Oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooo000000;o00003?ooool01Ol0003ooooooooooooo
oooo000001_ooooo00?o0000ooooooooool01?ooool3o`0001gooooo00?o0000ooooooooool01ooo
ool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00008ooooo`03o`000?oooooooooo00Cooooo
1Ol0003@ooooo`03o`000?oooooooooo00cooooo000Oooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo09Oooooo0ol0001Xooooo`03o`00
0?oooooooooo00Cooooo1Ol00003ooooo`?o00004_ooool2o`000003ooooool0003ooooo01[ooooo
00?o0000ooooooooool03Oooool3o`0001Cooooo00?o0000ooooooooool02Oooool2o`0000;ooooo
00Co0000oooooooooooooooo1Ol00009ooooo`03o`000?oooooooooo00?ooooo0ol0003Booooo`03
o`000?oooooooooo00cooooo000Oooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooo
ooooo`000009ooooo`03o`000?oooooooooo09Oooooo0ol0001Xooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooo`00000Dooooo`;o00006oooool00ol0003o
ooooooooo`0=ooooo`?o00005?ooool00ol0003oooooooooo`0;ooooo`?o00000oooool8o`0000Oo
oooo0_l0003Hooooo`03o`000?oooooooooo00cooooo000Oooooo`03o`000?oooooooooo00Oooooo
1?l0000:ooooo`Go0000Uoooool3o`0005;ooooo0ol0000Aooooo`03o`000?oooooooooo00?ooooo
1?l00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool04_oooolMo`0000oo
oooo0ol0000Dooooo`03o`000?oooooooooo00?o00002_ooool2o`0000?ooooo2Ol00007ooooo`03
o`000?oooooooooo0=7ooooo1Ol0000>ooooo`007oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0VOooool3o`0005;ooooo0ol0000Aooooo`03o`00
0?oooooooooo00?ooooo1?l00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`04ooooo`?o00004_ooool00ol0003oooooooooo`0Nooooo`Co
00000_ooool00ol0003oooooooooo`03o`0000cooooo00?o0000ooooooooool01?ooool6o`0000Oo
oooo00?o0000ooooooooool0e?ooool00ol0003oooooooooo`0<ooooo`007_ooool2o`0000[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Iooooo`?o0000D_ooool3o`00017ooooo
00?o0000ooooooooool01?ooool5o`0000;ooooo1ol00007ooooo`Co00001oooool00ol0003ooooo
ooooo`04ooooo`?o00004_ooool01?l0003oooooooooooooool3o`0000cooooo0ol0000;ooooo`Co
00000_ooool00ol0003oooooooooo`03o`0000Sooooo0ol00002ooooo`03o`000?oooooooooo00Co
oooo1Ol00008ooooo`;o0000e?ooool00ol0003oooooooooo`0<ooooo`007oooool00ol0003ooooo
ooooo`09ooooo`;o00002_ooool00ol0003oooooooooo`3oooooo`?ooooo00?o0000ooooooooool0
2oooool6o`0000Sooooo1?l00007ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo
oooo0ol0000<ooooo`?o00002oooool4o`0000;ooooo00?o0000ooooooooool02oooool3o`0000?o
oooo00?o0000ooooooooool01Oooool3o`0000[ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool0`oooool00ol0003oooooooooo`0<oooo
o`00=oooool00ol0003oooooooooo`3oooooo`?ooooo00?o0000ooooooooool02oooool7o`0000Oo
oooo1?l000001?oooooo0000o`000?l00003ooooo`03o`000?oooooooooo01Wooooo00Co0000oooo
oooooooooooo0ol0000<ooooo`?o00002?ooool3o`0000Kooooo00?o0000ooooooooool02oooool3
o`0000Cooooo00?o0000ooooooooool02?ooool3o`0000Oooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0`oooool00ol0003ooooooooo
o`0<ooooo`00=oooool00ol0003oooooooooo`3oooooo`?ooooo00?o0000ooooooooool03_ooool4
o`0000Sooooo1ol00002ooooo`?o00004oooool3o`0000Cooooo00?o0000ooooooooool06oooool6
o`0000?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`?o00002?ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`33ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?gooooo0ol00002
ooooo`03o`000?oooooooooo00kooooo1?l0000:ooooo`Go000000?oooooo`000?l000000_l00003
ooooo`?o00003Oooool3o`0000Cooooo0ol0000Kooooo`Ko00000oooool00ol0003oooooooooo`0D
ooooo`;o00001oooool5o`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000[ooooo0ol0002hooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oo
oooooooo0?[ooooo1_l00002ooooo`03o`000?oooooooooo01cooooo0ol00003ooooo`Co00000ooo
ool3o`0000Gooooo0ol00005ooooo`?o00001?ooool3o`0001cooooo1Ol00003ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool01_ooool5o`0000Gooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Ko00001Oooool3o`000;Sooooo00?o0000ooooooooool0
3?ooool003Oooooo00?o0000ooooooooool0nOooool7o`0000;ooooo00?o0000ooooooooool01_oo
ool4o`0001Sooooo1?l00003ooooo`?o000000?oooooo`000?l000001Ol0000<ooooo`?o00009?oo
ool00ol0003oooooooooo`0Gooooo`?o00001Oooool7o`0000?ooooo0_l00002ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`08ooooo`?o0000^?ooool00ol0003ooooo
ooooo`0<ooooo`00=oooool00ol0003oooooooooo`3iooooo`Co00001Oooool00ol0003ooooooooo
o`06ooooo`Co00002?ooool3o`0000?ooooo1?l00008ooooo`03o`000?oooooooooo00Kooooo1ol0
000<ooooo`03o`000?oooooooooo00cooooo1?l0000Dooooo`03o`000?oooooooooo01Oooooo0ol0
0007ooooo`Go00000oooool01Ol0003oooooo`000?oooooo000000?ooooo00Co0000oooooooooooo
0000aOooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3iooooo`?o0000
1_ooool00ol0003oooooooooo`06ooooo`Co00002?ooool3o`0000?ooooo1?l00008ooooo`03o`00
0?oooooooooo00Kooooo1?l0000?ooooo`03o`000?oooooooooo00cooooo1?l0000Dooooo`03o`00
0?oooooooooo017ooooo1?l00002ooooo`?o00002?ooool6o`000004ooooool0003oooooooooo`;o
00001_ooool00ol0003oooooooooo`33ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`00
0?oooooooooo0;[oooooBol0000Booooo`?o00000oooool4o`0000Sooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0<ooooo`Co00005?ooool00ol0003oooooooooo`0Aooooo`Co0000
1Oooool00ol0003oooooooooo`05ooooo`Ko000000?oooooo`000?l000001ol00002ooooo`Ko0000
`?ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooo`Kooooo0ol0
000Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Aooooo`Co00001_ooool2o`0000Oooooo1?l000000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo0<[ooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0ooooool9
ooooo`Co00007Oooool00ol0003oooooooooo`05o`0000Cooooo1Ol00003ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00009_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`39ooooo`03o`000?oo
oooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooo3Oooool3o`0001[ooooo00?o0000
ooooool000001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`00000@ooooo`Ko00000oooool2o`000005ooooool0003o0000oooo
ool000001_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo00cooooo000gooooo`03
o`000?oooooooooo0?oooooo4?ooool4o`0001Kooooo00?o0000ooooool000001Oooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
000@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo1?l0
0006ooooo`03o`000?oooooooooo0<Oooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000
ooooooooool0ooooool=ooooo`?o00001?ooool4o`0000oooooo1?l00007ooooo`03o`000?oooooo
oooo00Kooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool00oooool01?l0003oooooo`000?ooool3o`0000;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo
1?l000001?oooooo0000o`000?l00003ooooo`03o`000?oooooooooo0<Kooooo00?o0000oooooooo
ool03?ooool003Oooooo00?o0000ooooooooool0ooooool=ooooo`Go00001Oooool5o`0000?ooooo
0ol00005ooooo`Co00000_ooool5o`0000Cooooo1Ol00003ooooo`?o00001Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?l00002ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`Co0000
00Coooooo`000?l0003o00001?ooool00ol0003oooooooooo`35ooooo`03o`000?oooooooooo00co
oooo000gooooo`03o`000?oooooooooo0?oooooo3Oooool5o`0000Gooooo2ol00005ooooo`Co0000
00?oooooo`000?ooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo000000Gooooo
00?o0000ooooooooool01oooool4o`0000?ooooo1_l00004ooooo`?o00000_ooool6o`000003oooo
ool0003ooooo00Wooooo0ol0000Gooooo`;o00001Oooool00ol0003oooooo`000002o`0000Cooooo
00?o0000ooooooooool01_ooool3o`000;cooooo00?o0000ooooooooool03?ooool003Oooooo00?o
0000ooooooooool0ooooool=ooooo`Go00001Oooool5o`0000?ooooo0ol00008ooooo`03o`000?oo
oooo000000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool4o`0000?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Co00000oooool00ol0003o
ooooooooo`08ooooo`?o00006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo0ol00002ooooo`03o`000?oooooooooo00Gooooo0ol0002looooo`03o`000?oooooooooo00co
oooo000gooooo`03o`000?oooooooooo0?oooooo8_ooool4o`0000Cooooo00?o0000ooooool00000
1Oooool00ol0003oooooo`000002o`0000Cooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000Wooooo1?l00003ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00ol00003ooooo`Co00000oooool00ol0003oooooooooo`08ooooo`?o00006_ooool01Ol0
003ooooooooooooooooo000000Cooooo1?l00002ooooo`03o`000?oooooooooo00Cooooo0ol0002l
ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooo5_ooool3o`00
00[ooooo1_l000001?oooooo0000ooooooooool5o`0000;ooooo1ol00003ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`?o00002ooo
ool4o`0001;ooooo00Co0000oooooooooooo00001?ooool4o`0000?ooooo00?o0000ooooooooool0
`_ooool00ol0003oooooooooo`0<ooooo`00=oooool3o`000?oooooo5_ooool3o`0000[ooooo1?l0
0002ooooo`Co00001oooool3o`0000oooooo00?o0000ooooooooool03_ooool6o`0000Cooooo0ol0
0002ooooo`Ko000000?oooooo`000?ooool00oooool3o`0000_ooooo1?l0000Cooooo`03o`000?oo
oooo000000Gooooo0ol00004ooooodSo0000N_ooool3o`0000kooooo000gooooo`03o`000?oooooo
oooo0?oooooo5_ooool3o`0000[ooooo1?l00006ooooo`Go00005?ooool00ol0003oooooooooo`0H
ooooo`?o00002Oooool00ol0003oooooooooo`02ooooo`?o00002Oooool6o`0001Cooooo0_l00006
ooooo`?o00000oooool00ol0003oooooooooo`31ooooo`03o`000?oooooooooo00cooooo000goooo
o`03o`000?oooooooooo0?oooooo7?ooool4o`0001;ooooo1Ol0000?ooooo`03o`000?oooooooooo
00Kooooo0ol0000?ooooo`?o00002Oooool00ol0003oooooooooo`0>ooooo`Co00003Oooool3o`00
00Oooooo00?o0000ooooooooool01?ooool3o`0000Cooooo00?o0000ooooooooool0`?ooool00ol0
003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3ooooooacooooo1?l0000Gooooo`Co
00001Oooool3o`0000?ooooo00?o0000ooooooooool01?ooool5o`0001_ooooo00?o0000oooooooo
ool03_ooool4o`0000gooooo0ol00007ooooo`03o`000?oooooooooo00Cooooo0ol00005ooooo`03
o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000003ooooo`Go00000oooool00ol0
003oooooooooo`2Sooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oo
oooo7?ooool4o`0001_ooooo2?l00003ooooo`03o`000?oooooooooo00Cooooo1Ol0000Kooooo`03
o`000?oooooooooo01oooooo0ol00008ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool0002Uooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo
0?oooooo@?ooool5o`000003ooooool0003ooooo00Gooooo0ol0000Mooooo`03o`000?oooooooooo
02Cooooo0ol00004ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
002Uooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?Wooooo1_l00000
1?oooooo0000o`000?ooool2o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool0=_oo
ool3o`0000Kooooo0ol0000Looooo`03o`000?oooooooooo02Cooooo0ol00005ooooo`03o`000?oo
oooooooo00Cooooo0ol00004ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooooooo
o`000008ooooo`04o`000?ooooooooooo`0001;ooooo0ol0002@ooooo`03o`000?oooooooooo00co
oooo000gooooo`03o`000?oooooooooo0?Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02o`0000;ooooo00Go0000ooooooooooooooooo`00000@ooooo`?o00009oooool01?l0003o
ooooo`000?l00004ooooo`?o00004?ooool3o`0000Wooooo00?o0000ooooooooool00_ooool3o`00
01oooooo0ol00006ooooo`03o`000?oooooooooo00?ooooo0ol00005ooooo`03o`000?oooooooooo
00Kooooo00Go0000ooooooooooooooooo`000003ooooo`Go00000oooool6o`0000gooooo0ol0002@
ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?Wooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00
000@ooooo`?o00006?ooool3o`0000cooooo00Co0000oooooooooooooooo0ol000001?oooooo0000
o`000?l00003ooooo`Co00002Oooool3o`0000Wooooo00?o0000ooooooooool00_ooool3o`0000co
oooo0ol0000Iooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool04?ooool3o`00093ooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000oooooooo
ool0nOooool00ol0003oooooooooo`04ooooo`Co00000_ooool01?l0003oooooooooool0000Aoooo
o`?o00006?ooool3o`0000cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo1?l00009oooo
o`?o00002Oooool00ol0003oooooooooo`02ooooo`?o00003?ooool3o`0001[ooooo00?o0000oooo
ooooool01oooool3o`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0002Uooooo`03o`000?oo
oooooooo00cooooo000gooooo`03o`000?oooooooooo0?Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`03o`0001;ooooo0ol0000Hooooo`?o00003?ooool00ol0003oooooooooo`06
ooooo`;o00000oooool4o`0001Gooooo00?o0000ooooooooool04Oooool3o`0001_ooooo00?o0000
ooooooooool01_ooool3o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000YOooool00ol0003ooooooooo
o`0<ooooo`00=oooool00ol0003oooooooooo`3iooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooo000001gooooo1_l0000Dooooo`?o00000_oo
ool00ol0003oooooooooo`08ooooo`?o00006Oooool00ol0003oooooooooo`0Jooooo`?o00004ooo
ool00ol0003oooooooooo`05ooooo`?o00001?ooool00ol0003oooooo`000007o`0000?ooooo1Ol0
0003ooooo`Ko0000X?ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3i
ooooo`03o`000?oooooooooo00Cooooo0ol00003ooooo`04o`000?ooooooooooo`0001cooooo1_l0
000Dooooo`?o00000_ooool00ol0003oooooooooo`0;ooooo`;o00005oooool00ol0003ooooooooo
o`0Jooooo`Co00004_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0;Sooooo00?o
0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0nOooool00ol0003oooooooooo`0:
ooooo`05o`000?ooooooooooooooool000006oooool6o`0001Cooooo0ol00002ooooo`03o`000?oo
oooooooo00Kooooo0ol00004ooooo`;o00003?ooool3o`0000Kooooo00?o0000ooooooooool06_oo
ool4o`0001?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2gooooo`03o`000?oo
oooooooo00cooooo000gooooo`03o`000?oooooooooo0?Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool01_ooool3
o`0000Kooooo0ol00009ooooo`?o00001_ooool00ol0003oooooooooo`0Kooooo`?o00005?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0;Kooooo00?o0000ooooooooool03?ooool0
03Oooooo00?o0000ooooooooool0oooooom6ooooo`03o`000?oooooooooo00Kooooo0ol00009oooo
o`;o00001oooool3o`0000Kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo0;Gooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000oooooooo
ool0oooooom6ooooo`Co00004oooool2o`0000kooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`07ooooo`?o00000_ooool00ol0003oooooooooo`2dooooo`03o`000?oooooooooo00co
oooo000gooooo`03o`000?oooooooooo0?oooooo:_ooool4o`0001Sooooo1?l0000Eooooo`;o0000
3?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Go00000_ooool3o`0000;ooooo
00?o0000ooooooooool0]?ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003ooooooooo
o`3oooooob[ooooo1?l00005ooooo`?o00002oooool3o`0000;ooooo1?l0000Gooooo`?o00002Ooo
ool00ol0003oooooooooo`0eooooo`;o00001Oooool00ol0003oooooo`000002o`0000?ooooo00?o
0000ooooooooool0/oooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3o
ooooob[ooooo1?l00005ooooo`?o00002oooool3o`0000;ooooo00?o0000ooooooooool06oooool2
o`0000Oooooo00Co0000oooooooooooooooo0ol0000booooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00cooooo
000gooooo`03o`000?oooooooooo0?oooooo8Oooool3o`0000;ooooo1?l00009ooooo`?o00002ooo
ool3o`0000;ooooo00?o0000ooooooooool01?ooool3o`0001Kooooo0_l00005ooooo`04o`000?oo
ooooooooooooo`?o00004?ooool3o`0001Kooooo0ol00007ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00co
oooo000gooooo`03o`000?oooooooooo0?oooooo8Oooool3o`0000;ooooo1?l0000Looooo`03o`00
0?oooooooooo00Cooooo1_l0000Eooooo`?o00000_ooool01?l0003oooooooooooooool3o`0000co
oooo1ol00002ooooo`;o000000?oooooo`000?l000000_ooool5o`0000?ooooo00?o0000oooooooo
ool00_ooool3o`0000Oooooo1Ol00003ooooo`Wo0000/_ooool00ol0003oooooooooo`0<ooooo`00
=oooool3o`000?oooooo8Oooool3o`0000;ooooo1?l0000Looooo`03o`000?oooooooooo00Cooooo
1_l0000Hooooo`?o00002?ooool4o`0000;ooooo0ol000000ooooooo0000ooooo`02ooooo`?o0000
00Coooooo`000?oooooooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00001?ooool3o`0000Kooooo00?o0000ooooool000001_ooool01?l0003oooooooooooooool5
o`000;3ooooo0ol0000>ooooo`00=oooool00ol0003oooooooooo`3oooooodKooooo00?o0000oooo
ooooool01oooool3o`0001[ooooo0_l00007ooooo`Co00000_ooool3o`000004ooooool0003o0000
o`0000?ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003oooo
o`Co000000?oooooo`000?ooool0/?ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003o
ooooooooo`3oooooodKooooo00?o0000ooooooooool09_ooool2o`0000Gooooo1?l00002ooooo`?o
000000Coooooo`000?l0003o00000oooool00ol0003oooooooooo`04o`0000Sooooo00Co0000oooo
oooooooo00003Oooool01ol0003ooooooooooooooooo0000ooooool000000_ooool00ol0003ooooo
ooooo`03o`0000Cooooo00?o0000ooooooooool0[_ooool00ol0003oooooooooo`0<ooooo`00=ooo
ool00ol0003oooooooooo`3oooooodKooooo00?o0000ooooooooool0:?ooool3o`0000cooooo1_l0
0006ooooo`04o`000?ooooooooooooooo`Go00000oooool6o`0000Wooooo1Ol00003ooooo`Ko0000
1Oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oo
oooooooo0?ooooooA_ooool00ol0003oooooooooo`0[ooooo`;o00002_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00Cooooo0ol00006ooooo`03o`000?oooooooooo0:cooooo
00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0ooooool`ooooo`?o00004ooo
ool00ol0003oooooooooo`0]ooooo`;o00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?o00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0001?ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo00cooooo
000gooooo`03o`000?oooooooooo0?oooooo2_ooool3o`0002?ooooo0ol0000Cooooo`03o`000?oo
oooooooo02oooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oo
oooooooo05Cooooo0ol0002booooo`?o00008oooool3o`0001?ooooo00?o0000ooooooooool01ooo
ool4o`0002Oooooo0_l00003ooooo`Ko00002_ooool5o`0000?ooooo1_l00003ooooo`?o00002_oo
ool00ol0003oooooooooo`06ooooo`?o00000oooool00ol0003oooooooooo`2Zooooo`03o`000?oo
oooooooo00cooooo000gooooo`03o`000?oooooooooo05Cooooo0ol0002booooo`?o0000=_ooool4
o`0000Wooooo1?l00007ooooo`?o00002_ooool3o`0000Kooooo0ol00009ooooo`;o00006oooool3
o`0000Cooooo0ol0000:ooooo`03o`000?oooooooooo00Kooooo0ol00004ooooo`03o`000?oooooo
oooo0:Wooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0E?ooool3o`00
0>_ooooo1?l00009ooooo`Co00001oooool3o`0000[ooooo0ol00006ooooo`?o00002oooool3o`00
00Gooooo1?l0000?ooooo`?o00001?ooool3o`0000_ooooo00?o0000ooooooooool01Oooool4o`00
00Cooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003o
ooooooooo`3ooooood?ooooo1?l0000Dooooo`?o00002_ooool3o`0000Kooooo0ol0000>ooooo`;o
00000oooool4o`0000oooooo0ol0000Cooooo`03o`000?oooooooooo00Gooooo0ol00005ooooo`03
o`000?oooooooooo0:Oooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0
oooooolaooooo`?o00004_ooool00ol0003oooooooooo`0kooooo`;o000000?oooooo`000?l00000
0_l0000Vooooo`03o`000?oooooooooo00Cooooo0ol00005ooooo`03o`000?oooooooooo0:Oooooo
00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0ooooool[ooooo`?o00000ooo
ool3o`0001;ooooo00?o0000ooooooooool0?Oooool4o`0002Sooooo00?o0000ooooooooool01_oo
ool5o`000003ooooool0003ooooo0:Oooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000
ooooooooool0ooooool[ooooo`?o00000oooool3o`0001;ooooo00?o0000ooooooooool0?oooool3
o`0002Oooooo00?o0000ooooooooool01_ooool5o`0000;ooooo00?o0000ooooooooool0YOooool0
0ol0003oooooooooo`0<ooooo`003Oooool3o`000004ooooool0003o0000ooooo`Co00007oooool0
0ol0003oooooooooo`2Qooooo`?o0000Q_ooool3o`0000gooooo1Ol00006ooooo`03o`000?oooooo
oooo04;ooooo0_l0000Vooooo`03o`000?oooooooooo00Gooooo1Ol00003ooooo`03o`000?oooooo
oooo0:Cooooo00?o0000ooooooooool03?ooool000kooooo00Ko0000oooooooooooo0000ooooool0
0002ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0XOooool3o`0009Kooooo1Ol0
0006ooooo`03o`000?oooooooooo02_ooooo0ol0000Fooooo`;o00006Oooool3o`0000Wooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo00cooooo000>
ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo0:7ooooo0ol0002=ooooo`?o00001_ooool5o`0000Kooooo00?o0000ooooooooool0
:oooool3o`0001Sooooo0ol0000Fooooo`?o00002_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo0:?ooooo00?o0000ooooooooool03?ooool000kooooo00Ko0000oooooooooooo0000
ooooool00002ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0oooooolbooooo`?o
000000Coooooo`000?l0003o00003Oooool00ol0003oooooooooo`0[ooooo`?o00006oooool2o`00
01Cooooo1_l00008ooooo`03o`000?oooooooooo00Cooooo1ol000000ooooooo0000ooooo`2Soooo
o`03o`000?oooooooooo00cooooo000=ooooo`Co00000oooool3o`00023ooooo00?o0000oooooooo
ool0oooooolbooooo`?o000000Coooooo`000?l0003o00003Oooool00ol0003oooooooooo`03o`00
04Sooooo8ol00006ooooo`Oo00000_ooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo
00cooooo000Fooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0oooooolfooooo`?o
00002?ooool3o`0000;ooooo00?o0000ooooooooool00ol0000Fooooo`?o0000A_ooool3o`0000Wo
oooo00?o0000ooooooooool00oooool7o`0000?ooooo00?o0000ooooooooool0X?ooool00ol0003o
ooooooooo`0<ooooo`005Oooool2o`00023ooooo00?o0000ooooooooool0oooooom1ooooo`?o0000
0_ooool00ol0003oooooooooo`03o`0001Kooooo0ol0001Cooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0Woooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003ooooooooo
o`3ooooood7ooooo0ol00002ooooo`03o`000?oooooooooo01Wooooo0ol0000booooo`Go00007Ooo
ool00ol0003oooooooooo`05ooooo`?o00001?ooool00ol0003oooooooooo`2Oooooo`03o`000?oo
oooooooo00cooooo000gooooo`?o0000oooooom6ooooo`03o`000?oooooooooo04kooooo1Ol0000M
ooooo`03o`000?oooooooooo00Gooooo0ol00005ooooo`03o`000?oooooooooo09cooooo0ol0000>
ooooo`00=oooool00ol0003oooooooooo`3oooooocSooooo0ol0000;ooooo`03o`000?oooooooooo
04kooooo1Ol0000Nooooo`03o`000?oooooooooo00Cooooo0ol00006ooooo`03o`000?oooooooooo
09gooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0oooooolQooooo`Ko
000000Coooooo`000?l0003ooooo0_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo
00;ooooo0ol0000;ooooo`03o`000?oooooooooo00Sooooo2?l000001?oooooo0000o`000?ooool2
o`000003ooooool0003ooooo04Wooooo0ol0000=ooooo`03o`000?oooooooooo00?ooooo1_l00004
ooooo`04o`000?ooooooooooooooo`?o0000V?ooool00ol0003oooooooooo`0<ooooo`00=oooool0
0ol0003oooooooooo`3oooooob7ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
o`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`?o00002oooool00ol0003ooooooooo
o`08ooooo`?o00001Oooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool0B?oo
ool3o`0000kooooo00?o0000ooooooooool00_ooool6o`0000Gooooo00?o0000ooooooooool00ol0
002Hooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0<Cooooo0ol0001I
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000004oooool00ol0003oooooooooo`08ooooo`?o00001Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool0B?ooool3o`0000oooooo00Co0000oooooooo
oooooooo2Ol00003ooooo`03o`000?oooooo000000;o0000V?ooool00ol0003oooooooooo`0<oooo
o`00=oooool00ol0003oooooooooo`34ooooo`?o0000FOooool00ol0003oooooooooo`04ooooo`Co
00000_ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01?ooool4o`0000;ooooo00?o0000ooooooooool06Oooool3o`0003kooooo00?o0000oooo
ooooool01?ooool6o`0000?ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0<oooo
o`00=oooool00ol0003oooooooooo`34ooooo`?o0000FOooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00?o00005Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01_l0000Fooooo`?o0000?oooool00ol0003oooooooooo`03ooooo`Ko
00001?ooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo00cooooo000gooooo`03o`00
0?oooooooooo0?oooooo8Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooo`00000Eooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool06Oooool3o`00
03gooooo1?l0000?ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool03?ooool003Oo
oooo00?o0000ooooooooool0oooooolQooooo`03o`000?oooooooooo00Cooooo0ol00003ooooo`04
o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04oooo
o`?o00000oooool00ol0003oooooooooo`0fooooo`Ko000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000ooooo`0Dooooo`?o000000?oooooo`000?ooool02_ooool3o`000003ooooool0003o
oooo09Sooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0oooooolQoooo
o`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000Cooooo`Co00002Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool04oooool3o`000003ooooool0003o
oooo00[ooooo0ol00002ooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool03?ooool0
03Oooooo00?o0000ooooooooool0oooooolQooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0@ooooo`Co00002Oooool00ol0003oooooooooo`0:oooo
o`Ko0000<oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`?o00000_ooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo
0?ooooooA_ooool4o`0003oooooo0ol0000=ooooo`03o`000?oooooooooo00Cooooo1?l00002oooo
o`03o`000?oooooooooo01Wooooo00Co0000oooooooooooooooo0ol00009ooooo`03o`000?oooooo
oooo09Gooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0oooooom6oooo
o`Co0000?oooool3o`0000gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06o`00
01Oooooo00?o0000ooooooooool00ol00009ooooo`04o`000?ooooooooooooooo`?o0000TOooool0
0ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooodKooooo00?o0000oooo
ooooool0@?ooool6o`0000[ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`04o`000?oooooo
ooooooooo`?o0000TOooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3o
ooooodKooooo00?o0000ooooooooool0@oooool3o`0000[ooooo00?o0000ooooooooool01?ooool3
o`0000?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00?o0000TOooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3ooooo
odGooooo0ol0000Mooooo`Go00008_ooool3o`0000[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Looooo`04o`000?ooooooooooooooo`Ko00001?ooool00ol0003oooooooooo`2D
ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?ooooooAOooool3o`00
00_ooooo1?l0000>ooooo`Go0000;oooool00ol0003oooooooooo`0:ooooo`Ko00006_ooool00ol0
003oooooooooo`06o`0000Cooooo00?o0000ooooool000000_l0002Booooo`03o`000?oooooooooo
00cooooo000gooooo`03o`000?oooooooooo0?oooooo5oooool3o`0002_ooooo0ol0000;ooooo`Co
00003_ooool5o`0005gooooo00?o0000ooooool000001Ol00005ooooo`Co0000T_ooool00ol0003o
ooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3ooooooaOooooo0ol0000/ooooo`03o`00
0?oooooooooo00[ooooo1?l0001`ooooo`03o`000?oooooooooo00[ooooo1?l0002Booooo`03o`00
0?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooo5oooool3o`0002cooooo00?o
0000ooooooooool05_ooool3o`0005_ooooo0ol00008ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0T_ooool00ol0003oooooooooo`0<ooooo`007_ooool3o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000[ooooo00?o0000ooooooooool0oooooom6ooooo`03o`000?oooooo
oooo01Kooooo0ol0000fooooo`?o00008_ooool3o`0000Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`2Booooo`03o`000?oooooooooo00cooooo000Oooooo`03o`000?oooooooooo
00Oooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo0?ooooooA_ooool0
0ol0003oooooooooo`0Fooooo`?o00003_ooool3o`0002Gooooo0ol0000Rooooo`?o00002_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool03?ooool0
01oooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Wooooo1Ol0003o
ooooodCoooooQ_l0000:ooooo`03o`000?oooooooooo08gooooo1Ol0000>ooooo`007oooool00ol0
003oooooooooo`08ooooo`?o00002_ooool00ol0003oooooooooo`3oooooodKooooo00?o0000oooo
ooooool03oooool4o`0001Cooooo0ol0000<ooooo`?o00005_ooool3o`0001Oooooo0ol0000Foooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0<oooo
o`007oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002Oooool00ol0
003oooooooooo`3oooooodKooooo00?o0000ooooooooool03oooool4o`0001_ooooo0ol00005oooo
o`?o00005_ooool3o`000004ooooool0003o0000o`0001?ooooo0ol0000Gooooo`Go00001_ooool0
0ol0003oooooooooo`2@ooooo`03o`000?oooooooooo00cooooo000Nooooo`;o00002Oooool01Ol0
003ooooooooooooooooo000000Wooooo00?o0000ooooooooool0oooooom6ooooo`03o`000?oooooo
oooo00oooooo1?l0000Kooooo`Go00000oooool3o`0001[ooooo0ol0000Cooooo`?o00005oooool5
o`0000Kooooo00?o0000ooooooooool00_ooool3o`0008_ooooo00?o0000ooooooooool03?ooool0
01oooooo00?o0000ooooooooool02?ooool3o`0000[ooooo00?o0000ooooooooool0oooooom6oooo
o`03o`000?oooooooooo02kooooo1Ol0000Pooooo`?o0000;Oooool5o`0000Kooooo00?o0000oooo
ooooool00_ooool3o`0008_ooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000oooooooo
ool0oooooom6ooooo`03o`000?oooooooooo033ooooo0ol0001Aooooo`03o`000?oooooooooo00So
oooo00Co0000oooooooooooooooo0ol0002;ooooo`03o`000?oooooooooo00cooooo000gooooo`03
o`000?oooooooooo0?ooooooA_ooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool03?ooool003Oooooo
00?o0000ooooooooool0oooooom6ooooo`03o`000?oooooooooo00oooooo0ol00009ooooo`?o0000
I_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0
3?ooool003Oooooo00?o0000ooooooooool0oooooom6ooooo`03o`000?oooooooooo00oooooo0ol0
0009ooooo`?o0000Ioooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08kooooo00?o
0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0oooooom6ooooo`03o`000?oooooo
oooo00oooooo0ol0000`ooooo`?o0000@?ooool6o`0000?ooooo00?o0000ooooool00000T?ooool0
0ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooodKooooo00?o0000oooo
ooooool0@_ooool3o`00043ooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool0SOooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3ooooo
odKooooo00?o0000ooooooooool0@_ooool3o`00043ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0
003oooooooooo`3oooooodKooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`0<
ooooo`00=oooool00ol0003oooooooooo`3oooooodKooooo00?o0000ooooooooool0Q_ooool5o`00
00?ooooo1_l0002=ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oo
ooooA_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo000000Kooooo00Go0000oooooooo
ooooooooo`00002>ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oo
ooooA_ooool00ol0003oooooooooo`0Tooooo`?o00007?ooool3o`0003oooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo08_ooooo00?o0000
ooooooooool03?ooool003Oooooo00?o0000ooooooooool0ooooooljooooo`?o00002Oooool00ol0
003oooooooooo`0Tooooo`?o00007?ooool3o`0003oooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool03?oo
ool003Oooooo00?o0000ooooooooool0ooooooljooooo`?o00002Oooool00ol0003oooooooooo`0T
ooooo`?o00007?ooool3o`00043ooooo1Ol00003ooooo`Ko0000SOooool00ol0003oooooooooo`0<
ooooo`00=oooool00ol0003oooooooooo`3Cooooo`?o0000Hoooool3o`0000Wooooo00?o0000oooo
ooooool0ROooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08[ooooo00?o0000oooo
ooooool03?ooool003Oooooo00?o0000ooooooooool0doooool3o`0006oooooo00?o0000oooooooo
ool0ROooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08[ooooo00?o0000oooooooo
ool03?ooool003Oooooo00?o0000ooooooooool0doooool3o`0006oooooo00?o0000ooooooooool0
2oooool6o`000004ooooool0003o0000ooooo`;o00000_ooool5o`0000?ooooo00?o0000oooooooo
ool0IOooool01?l0003oooooooooooooool4o`0000?ooooo00?o0000ooooooooool0R_ooool00ol0
003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooodKooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0006Sooooo00?o0000ooooooooool01?l00004oooo
o`03o`000?oooooooooo08Wooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000oooooooo
ool0oooooom6ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000l
ooooo`Co0000:?ooool00ol0003oooooooooo`04o`0000Cooooo00?o0000ooooooooool0ROooool0
0ol0003oooooooooo`0<ooooo`00=oooool3o`000?ooooooA_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Cooooo1?l00008ooooo`04o`000?ooooooooooo`0003cooooo1?l0000Y
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Q_ooool3o`0000kooooo000goooo
o`03o`000?oooooooooo0?ooooooA_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Oooooo00Co0000oooooooooooooooo1Ol00003ooooo`Ko0000=oooool4o`0002Wooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo00cooooo000goooo
o`03o`000?oooooooooo0?ooooooA_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0Ioooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08Sooooo00?o0000
ooooooooool03?ooool003Oooooo00?o0000ooooooooool0oooooom6ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01?ooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool0001Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Qoooool0
0ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooodKooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo0000J_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08Oooooo00?o0000
ooooooooool03?ooool003Oooooo00?o0000ooooooooool0oooooom6ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool5o`0000?ooooo1_l0001Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003o
ooooooooo`3oooooodKooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo08Kooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0
oooooom6ooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`26ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?ooooooA_oo
ool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0QOoo
ool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooodKooooo00?o0000
ooooooooool0C_ooool3o`0003gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`25
ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?ooooooA_ooool00ol0
003oooooooooo`1>ooooo`?o0000?Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00[ooooo0ol0001hooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oo
ooooA_ooool00ol0003oooooooooo`0nooooo`?o00003Oooool3o`0003kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`?o0000N?ooool00ol0003oooooooooo`0<ooooo`00
=oooool00ol0003oooooooooo`3oooooodKooooo00?o0000ooooooooool0;_ooool3o`0000gooooo
0ol0000[ooooo`Ko000000Coooooo`000?l0003ooooo0_l00002ooooo`Go00000oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool3o`0007So
oooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0oooooom6ooooo`03o`00
0?oooooooooo02kooooo1?l0000<ooooo`?o0000:oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;o00000_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo00co
oooo000gooooo`03o`000?oooooooooo0?ooooooA_ooool00ol0003oooooooooo`0^ooooo`Co0000
>_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`23ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oo
ooooA_ooool00ol0003oooooooooo`0_ooooo`?o0000>_ooool00ol0003oooooooooo`04ooooo`Co
00002?ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0Poooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooodKo
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooooo
o`Go00000oooool6o`0000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?ooooooA_ooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000oooooooo
ool0oooooom6ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool01?ooool3o`0000?o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000>ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003o
ooooooooo`3oooooodKooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo087ooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000oooooooo
ool0oooooom6ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool02oooool5o`0000?o
oooo1_l0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0POooool00ol0003o
ooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooodKooooo00?o0000ooooooooool0
Toooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0
3?ooool003Oooooo0ol0003oooooodKooooo00?o0000ooooooooool0H_ooool3o`0002kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1nooooo`?o00003_ooool003Oooooo00?o0000
ooooooooool0oooooom6ooooo`03o`000?oooooooooo06;ooooo0ol0000^ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0
003oooooooooo`3oooooodKooooo00?o0000ooooooooool0H_ooool3o`0002oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00cooooo000gooooo`03
o`000?oooooooooo0?ooooooA_ooool00ol0003oooooooooo`1[ooooo`?o00009_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool03?ooool003Oooooo
00?o0000ooooooooool0oooooom6ooooo`03o`000?oooooooooo06_ooooo0ol0000Wooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0<ooooo`00=ooo
ool00ol0003oooooooooo`3oooooodKooooo00?o0000ooooooooool0G_ooool3o`0000[ooooo0ol0
0006ooooo`?o00007_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07kooooo00?o
0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0oooooom6ooooo`03o`000?oooooo
oooo05kooooo0ol0000Cooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`?o000000?ooooo
o`000?ooool0Ooooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3ooooo
odKooooo00?o0000ooooooooool0G_ooool3o`0001?ooooo0ol0000Oooooo`04o`000?oooooooooo
ooooo`Go00000_ooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo00cooooo000goooo
o`03o`000?oooooooooo0?ooooooA_ooool00ol0003oooooooooo`1@ooooo`?o0000@oooool01?l0
003oooooooooooooool5o`0000;ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`0<
ooooo`00=oooool00ol0003oooooooooo`3oooooodKooooo00?o0000ooooooooool0D?ooool3o`00
04?ooooo00Co0000oooooooooooooooo2?l00007ooooo`?o0000MOooool00ol0003oooooooooo`0<
ooooo`00=oooool00ol0003oooooooooo`3oooooodKooooo00?o0000ooooooooool0D?ooool3o`00
04Cooooo00Co0000oooooooooooooooo1_l000000ooooooo0000ooooo`05ooooo`?o0000MOooool0
0ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooodKooooo00?o0000oooo
ooooool0Uoooool01?l0003oooooooooooooool6o`000003ooooool0003ooooo00Gooooo0ol0001e
ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?ooooooA_ooool00ol0
003oooooooooo`2Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Noooool00ol0
003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooodKooooo00?o0000oooooooo
ool0Foooool3o`0003[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1kooooo`03
o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?ooooooA_ooool00ol0003ooooo
ooooo`1Kooooo`?o0000>_ooool6o`0000?ooooo00?o0000ooooool00000OOooool00ol0003ooooo
ooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooodKooooo00?o0000ooooooooool0FOoo
ool5o`0003[ooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
N_ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooodKooooo00?o
0000ooooooooool0FOooool3o`0003cooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003ooooooooo
o`3oooooodKooooo00?o0000ooooooooool0FOooool3o`0003gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0
3?ooool003Oooooo00?o0000ooooooooool0oooooom6ooooo`03o`000?oooooooooo09Wooooo1Ol0
0003ooooo`Ko0000N_ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3o
ooooodKooooo00?o0000ooooooooool0V?ooool00ol0003oooooo`000006ooooo`05o`000?oooooo
ooooooooool00000Noooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3o
ooooodKooooo00?o0000ooooooooool0V?ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0<ooooo`00=ooo
ool00ol0003oooooooooo`3oooooodKooooo00?o0000ooooooooool0V?ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0N?ooool00ol0003o
ooooooooo`0<ooooo`00=oooool3o`000?ooooooA_ooool00ol0003oooooooooo`2Iooooo`Go0000
0oooool6o`0007Sooooo0ol0000>ooooo`00=oooool00ol0003oooooooooo`3oooooodKooooo00?o
0000ooooooooool0W?ooool00ol0003oooooooooo`02ooooo`?o00000oooool00ol0003ooooooooo
o`1gooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?ooooooA_ooool0
0ol0003oooooooooo`2Looooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`03o`000?oooooo
oooo07Oooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0oooooom6oooo
o`03o`000?oooooooooo09gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1foooo
o`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?ooooooA_ooool00ol0003o
ooooooooo`2Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0M_ooool00ol0003o
ooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooodKooooo00?o0000ooooooooool0
WOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0
3?ooool003Oooooo00?o0000ooooooooool0oooooom6ooooo`03o`000?oooooooooo09kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo00cooooo000g
ooooo`03o`000?oooooooooo0?ooooooA_ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0
003oooooooooo`3oooooodKooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo07Gooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000oooooooo
ool0oooooom6ooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooo
A_ooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
M?ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooodKooooo00?o
0000ooooooooool0X?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo0ol0
001Zooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?ooooooA_ooool0
0ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool3
o`0006[ooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0oooooom6oooo
o`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06oooo
o`?o0000J_ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooodKo
oooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0oooooom6ooooo`03o`00
0?oooooooooo0:7ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1booooo`03o`00
0?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?ooooooA_ooool00ol0003ooooooooo
o`2Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`0<ooooo`00=oooool00ol0003oooooooooo`3oooooodKooooo00?o0000ooooooooool0X_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool03?ooool0
03Oooooo00?o0000ooooooooool0oooooom6ooooo`03o`000?oooooooooo07;ooooo0ol0000]oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0<oooo
o`00=oooool00ol0003oooooooooo`3oooooodKooooo00?o0000ooooooooool0L_ooool3o`0002ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00co
oooo000Sooooo`Go00000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo
A_ooool00ol0003oooooooooo`1booooo`?o0000;_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool03?ooool002Cooooo00Co0000oooooooooooo0000
3oooool00ol0003oooooooooo`3oooooodKooooo00?o0000ooooooooool0Xoooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool03?ooool002Gooooo00?o
0000ooooooooool03oooool5o`000?ooooooA?ooool00ol0003oooooooooo`1nooooo`?o00008ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06_ooooo1Ol0000>ooooo`009_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0?oooooo__ooool3o`0000Kooooo0ol0001<
ooooo`?o0000DOooool00ol0003oooooooooo`0<ooooo`008oooool01Ol0003ooooooooooooooooo
000000oooooo00?o0000ooooooooool0oooooonnooooo`?o00001_ooool3o`0004cooooo0ol0001A
ooooo`03o`000?oooooooooo00cooooo000Sooooo`05o`000?ooooooooooooooool000003oooool0
0ol0003oooooooooo`3ooooookkooooo0ol0001Eooooo`?o0000DOooool00ol0003oooooooooo`0<
ooooo`009?ooool3o`00013ooooo00?o0000ooooooooool0ooooooooooooof_ooooo00?o0000oooo
ooooool03?ooool003Oooooo00?o0000ooooooooool0ooooooooooooof_ooooo00?o0000oooooooo
ool03?ooool003Oooooo00?o0000ooooooooool0ooooooooooooof_ooooo00?o0000ooooooooool0
3?ooool003Oooooo00?o0000ooooooooool0ooooooooooooof_ooooo00?o0000ooooooooool03?oo
ool003Oooooo00?o0000ooooooooool0oooooooooooooaOooooo0ol0001Aooooo`03o`000?oooooo
oooo00cooooo000gooooo`03o`000?oooooooooo0?oooooo^Oooool3o`0005[ooooo0ol0001Aoooo
o`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooo^Oooool3o`0005[o
oooo0ol0001Aooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooo
^Oooool3o`000:kooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0oooo
ooooooooof_ooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0oooooooo
ooooof_ooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0oooooooooooo
of_ooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0ooooooooooooof_o
oooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0ooooooooooooof_ooooo
00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0ooooooooooooof_ooooo00?o
0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0ooooooooooooof_ooooo00?o0000
ooooooooool03?ooool003Oooooo00?o0000ooooooooool0ooooooooooooof_ooooo00?o0000oooo
ooooool03?ooool003Oooooo00?o0000ooooooooool0ooooooooooooof_ooooo00?o0000oooooooo
ool03?ooool003Oooooo00?o0000ooooooooool0ooooooooooooof_ooooo00?o0000ooooooooool0
3?ooool003Oooooo00?o0000ooooooooool0ooooooooooooof_ooooo00?o0000ooooooooool03?oo
ool003Oooooo0ol0003oooooooooooooJOooool3o`0000kooooo000gooooo`03o`000?oooooooooo
0?oooooooooooom[ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oo
oooooooooom[ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooo
oooooom[ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooooooo
oom[ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooooooooom[
ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?ooooooioooool3o`00
083ooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0oooooooWooooo`?o
0000P?ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooonOooooo
0ol00020ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooooooo
oom[ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooooooooom[
ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooooooooom[oooo
o`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03
o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`00
0?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oo
oooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooo
oooo00cooooo000gooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooooooo
00cooooo000gooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooooooo00co
oooo000gooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooooooo00cooooo
000gooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooooooo00cooooo000g
ooooo`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooooooo00cooooo000goooo
o`03o`000?oooooooooo0?oooooooooooom[ooooo`03o`000?oooooooooo00cooooo000gooooo`?o
0000ooooooooooooofWooooo0ol0000>ooooo`00=oooool00ol0003oooooooooo`3ooooooooooooo
Joooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooooooooooJooo
ool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooooooooooJoooool0
0ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooogoooooo0ol0003Xoooo
o`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?ooooooOoooool3o`000>So
oooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0oooooomoooooo`?o0000
j?ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooooooooooJooo
ool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooooooooooJoooool0
0ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooooooooooJoooool00ol0
003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooooooooooJoooool00ol0003o
ooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooooooooooJoooool00ol0003ooooo
ooooo`0<ooooo`00=oooool00ol0003oooooooooo`3oooooooooooooJoooool00ol0003ooooooooo
o`0<ooooo`00=oooool00ol0003oooooooooo`3oooooooooooooJoooool00ol0003oooooooooo`0<
ooooo`00=oooool00ol0003oooooooooo`3oooooooooooooJoooool00ol0003oooooooooo`0<oooo
o`00=oooool00ol0003oooooooooo`3oooooooooooooJoooool00ol0003oooooooooo`0<ooooo`00
=oooool00ol0003oooooooooo`3oooooooooooooJoooool00ol0003oooooooooo`0<ooooo`00=ooo
ool00ol0003oooooooooo`3oooooooooooooJoooool00ol0003oooooooooo`0<ooooo`00=oooool0
0ol0003oooooooooo`3oooooooooooooJoooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0
003oooooooooo`3oooooooooooooJoooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003o
ooooooooo`3oooooooooooooJoooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003ooooo
ooooo`3oooooooooooooJoooool00ol0003oooooooooo`0<ooooo`00=oooool3o`000?oooooooooo
oomYooooo`?o00003_ooool003Oooooo00?o0000ooooooooool0oooooom1ooooo`?o0000oooooolW
ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo0?oooooo@Oooool3o`00
0?oooooo9oooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`3ooooood7o
oooo0ol0001Looooo`?o0000aoooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0K?ooool00ol0003ooooo
ooooo`1/ooooo`03o`000?oooooooooo023ooooo0ol0001:ooooo`03o`000?oooooooooo06cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`04ooooo`?o00004_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo000g
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`00=oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool003Ooooooool0003oo`0006oo00003_ooool00?oooooooooooondooooo`00oooo
oooooooookCooooo003ooooooooooooo]?ooool00?oooooooooooondooooo`00oooooooooooookCo
oooo003ooooooooooooo]?ooool00?oooooooooooondooooo`00oooooom[ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0POooool00?ooooooJ_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo083ooooo001gooooo`?o00000_ooool00ol0003oooooo`000002o`0000;o
oooo1Ol000001?oooooo0000o`000?l00004ooooo`Co00000_ooool3o`0000Cooooo0_l00002oooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`?o00002?ooool5o`000005ooooool0003o0000
o`000?ooool00_l000000ooooooo0000o`000002o`0000;ooooo0ol00002ooooo`;o000000?ooooo
o`000?l000002Oooool00ol0003oooooooooo`02ooooo`?o00000_ooool3o`0000?ooooo1?l00004
ooooo`;o000000?oooooo`000?l000000ol00008ooooo`;o000000?oooooo`000?l000001Ol00002
ooooo`Co00000oooool3o`0000Sooooo0ol000000ooooooo0000o`000002ooooo`;o000000Sooooo
o`000?l0003oooooo`000?oooooo0000ooooo`Co00000oooool3o`0000;ooooo0ol00009ooooo`Go
00000_ooool3o`0000;ooooo0ol0000;ooooo`04o`000?ooooooooooooooo`Go00001?ooool01?l0
003oooooooooooooool4o`0000Cooooo00Co0000oooooooooooooooo0ol00004ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00ooo
ool3o`0000;ooooo0ol00003ooooo`?o00000oooool3o`0000Gooooo00?o0000ooooooooool02?oo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo0ol00004ooooo`03o`000?oo
oooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`03o`000?oo
oooooooo00;ooooo0ol00003ooooo`?o00000oooool3o`0000?ooooo0ol00004ooooo`03o`000?oo
oooooooo00Oooooo00Ko0000ooooool0003oooooo`000?ooool5o`0000;ooooo0ol00002ooooo`?o
00001?ooool3o`0000;ooooo0ol000000ooooooo0000o`000004o`00057ooooo001hooooo`06o`00
0?ooooooooooo`000?oooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00003Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooo000000[ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0000<ooooo`04o`00
0?ooooooooooo`0000;ooooo00[o0000oooooooooooo0000ooooool0003oooooo`000?oooooo0000
0_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00?o0000ooooooooool02_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00003?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool01oooool5o`0000Wooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000:ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooool000000oooool01Ol0003ooooooooooooooooo0000013ooooo00Co0000oooooooooooo0000
1oooool01ol0003ooooooooooooooooo0000ooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`04o`000?ooooooooooo`0000Oooooo
00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool000000oooool00ol0
003oooooo`000003ooooo`05o`000?ooooooooooooooool000002Oooool01Ol0003oooooo`000?oo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000Co
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool0C_ooool007Sooooo00?o0000ooooool000000_ooool5o`0000?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`?o00000_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000002oooo
o`Go00002Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000_oo
ool00ol0003oooooooooo`05o`0000?ooooo00?o0000ooooooooool02?ooool00ol0003oooooo`00
0002ooooo`Go00000_ooool00ol0003oooooooooo`03ooooo`?o00000oooool01?l0003ooooooooo
ool00002ooooo`?o00002?ooool5o`0000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003o
ooooooooool0003ooooo00Go00002?ooool01?l0003oooooooooool00002ooooo`0:o`000?oooooo
ooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo00Go0000oooooooooooo0000ooooo`05
o`0000;ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00007ooooo`Go000000?oooooo`00
0?ooool00_ooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000004?ooool0
1?l0003oooooooooool0000;ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooool000000oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0
003oooooo`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo0ol0001Aooooo`00N?ooool3o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00;ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooooooo
o`02ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0003oooooooooool00003oooo
o`06o`000?ooooooooooo`000?oooooo00002Oooool00ol0003oooooo`000002ooooo`05o`000?oo
ooooooooooooool000000_ooool2o`0000?ooooo00?o0000ooooooooool01?ooool01_l0003ooooo
ooooool0003oooooo`0000cooooo00?o0000ooooool000000oooool01?l0003oooooooooool00002
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`04o`00
0?ooooooooooo`0000;ooooo00[o0000oooooooooooo0000ooooool0003oooooo`000?oooooo0000
0_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_l0000;oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000Sooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Oooooo1Ol00009ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00003oooo
o`?o00000_ooool4o`0000Cooooo00?o0000ooooooooool03_ooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo00?o00001Oooool00ol0003oooooooooo`04o`0000oooooo00Co0000
oooooooooooo00001oooool4o`0000Kooooo00?o0000ooooool000000ol00004ooooo`;o00001?oo
ool00ol0003oooooooooo`07ooooo`05o`000?oooooo0000ooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00_l00003ooooo`05o`000?oooooooooooooo
ool000000_ooool01_l0003oooooooooool0003oooooo`0005Cooooo001hooooo`04o`000?oooooo
ooooo`0000;ooooo0ol00003ooooo`Co000000Coooooo`000?l0003ooooo0_l00002ooooo`;o0000
1?ooool3o`0000;ooooo1?l00002ooooo`?o00000oooool2o`000003ooooool0003o000000;ooooo
0ol00008ooooo`?o00000oooool4o`0000?ooooo0ol00003ooooo`?o00000_ooool2o`000003oooo
ool0003o000000Oooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool2o`000003oooo
ool0003o000000;ooooo1?l000001?oooooo0000o`000?ooool2o`0000;ooooo1?l00008ooooo`03
o`000?oooooo000000?ooooo0ol00003ooooo`?o00000oooool3o`0000Sooooo1?l00002ooooo`;o
000000Coooooo`000?l0003ooooo0_l000000ooooooo0000ooooo`02ooooo`?o00000oooool3o`00
00;ooooo0_l000000ooooooo0000o`000008ooooo`Co00000_ooool3o`0000;ooooo0_l000000ooo
oooo0000o`000009ooooo`03o`000?oooooooooo00;ooooo1?l00008ooooo`?o00002Oooool3o`00
00Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool00000
1oooool00ol0003oooooooooo`0>ooooo`04o`000?ooooooooooo`0000Oooooo1?l00002ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooo`00000Booooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool00oooool4o`0000;ooooo00?o0000ooooooooool01oooool0
1Ol0003ooooooooooooooooo000000Wooooo0_l000001?oooooo0000ooooooooool3o`0000Cooooo
0ol00002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo1?l00003ooooo`Co0000
D?ooool007Sooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Wooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooooooo`03ooooo`;o00004?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo00?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00Co0000oooooooooooo
00004Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`20ooooo`00Moooool4o`0000_ooooo0_l0000Dooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09ooooo`;o0000?oooool2o`00
00?ooooo0_l00004ooooo`;o00008_ooool2o`0001Wooooo0_l0000Fooooo`03o`000?oooooooooo
00?ooooo0_l00009ooooo`;o00003oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00;ooooo0_l0000;ooooo`04o`000?ooooooooooooooo`?o00001?ooool2o`0000Cooooo00?o0000
ooooooooool03oooool2o`0000Sooooo1Ol00002ooooo`?o00000_ooool5o`0000?ooooo0_l0000@
ooooo`;o00002_ooool2o`0000;ooooo1Ol00003ooooo`;o00000oooool3o`0000?ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`1^ooooo`00\
\>"],
  ImageRangeCache->{{{0, 689.75}, {425.938, 0}} -> {-119.047, 1.24683, \
0.180086, 0.00224959}},
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[TextData[{
  StyleBox["GlassMap", "Input"],
  " can even be used to retrieve specific materials from the database. This \
is accomplished by passing one or more ",
  StyleBox["GlassMap", "Input"],
  " coordinates to the ",
  StyleBox["GlassMap", "Input"],
  " function."
}], "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["GlassMap[", "Input"],
  "{-35.7038, 1.6676}",
  StyleBox["]", "Input"]
}], "Input",
  CellTags->"Rayica's Data Base"],

Cell[BoxData[
    \({{"PBM1 is an optical material from OHARA with a refractive index of \
1.62588 at the 0.5876 micron wavelength, a corresponding V-number of 35.6858, \
a partial dispersion ratio of 0.292834, and a mean dispersion value of \
0.0175386. The refractive index model for this glass is valid from 0.36 to \
1.014 microns of wavelength."}}\)], "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1920}, {0, 1174}},
PrintingStyleEnvironment->"Presentation",
WindowSize->{1194, 1099},
WindowMargins->{{23, Automatic}, {Automatic, 25}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Using RayTraceFunction"->{
    Cell[1776, 53, 79, 1, 56, "Section",
      CellTags->"Using RayTraceFunction"],
    Cell[1880, 58, 72, 1, 39, "Input",
      CellTags->"Using RayTraceFunction"],
    Cell[1955, 61, 888, 12, 147, "Print",
      CellTags->{"Info3252053846-2417689", "Using RayTraceFunction"}],
    Cell[2858, 76, 283, 5, 71, "Input",
      CellTags->"Using RayTraceFunction"],
    Cell[3166, 85, 120, 2, 39, "Input",
      CellTags->"Using RayTraceFunction"],
    Cell[3289, 89, 46437, 1391, 245, 13762, 982, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Using RayTraceFunction"],
    Cell[49763, 1485, 77, 1, 39, "Input",
      CellTags->"Using RayTraceFunction"],
    Cell[49843, 1488, 352, 6, 55, "Output",
      CellTags->"Using RayTraceFunction"],
    Cell[50232, 1499, 89, 1, 39, "Input",
      CellTags->"Using RayTraceFunction"],
    Cell[50324, 1502, 104, 2, 39, "Output",
      CellTags->"Using RayTraceFunction"],
    Cell[50465, 1509, 91, 1, 39, "Input",
      CellTags->"Using RayTraceFunction"],
    Cell[50559, 1512, 352, 6, 55, "Output",
      CellTags->"Using RayTraceFunction"],
    Cell[50948, 1523, 89, 1, 39, "Input",
      CellTags->"Using RayTraceFunction"],
    Cell[51040, 1526, 208, 4, 39, "Output",
      CellTags->"Using RayTraceFunction"]},
  "Info3252053846-2417689"->{
    Cell[1955, 61, 888, 12, 147, "Print",
      CellTags->{"Info3252053846-2417689", "Using RayTraceFunction"}]},
  "TurboPlot Examples"->{
    Cell[51297, 1536, 71, 1, 36, "Section",
      CellTags->"TurboPlot Examples"],
    Cell[51393, 1541, 195, 6, 84, "Input",
      CellTags->"TurboPlot Examples"],
    Cell[51591, 1549, 35540, 1347, 308, 13461, 1069, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"TurboPlot Examples"],
    Cell[87168, 2901, 110, 1, 39, "Input",
      CellTags->"TurboPlot Examples"],
    Cell[87281, 2904, 42935, 1438, 308, 13437, 1069, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"TurboPlot Examples"],
    Cell[130253, 4347, 102, 1, 39, "Input",
      CellTags->"TurboPlot Examples"],
    Cell[130358, 4350, 5321, 404, 308, 5079, 397, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"TurboPlot Examples"]},
  "Lens Optimizations"->{
    Cell[135728, 4760, 71, 1, 36, "Section",
      CellTags->"Lens Optimizations"],
    Cell[135824, 4765, 66, 1, 39, "Input",
      CellTags->"Lens Optimizations"],
    Cell[135893, 4768, 1131, 16, 184, "Print",
      CellTags->{"Info3252053709-8785867", "Lens Optimizations"}],
    Cell[137061, 4789, 74, 1, 39, "Input",
      CellTags->"Lens Optimizations"],
    Cell[137138, 4792, 807, 11, 139, "Print",
      CellTags->{"Info3252053717-8293308", "Lens Optimizations"}],
    Cell[137960, 4806, 279, 5, 71, "Input",
      CellTags->"Lens Optimizations"],
    Cell[138264, 4815, 129, 3, 39, "Input",
      CellTags->"Lens Optimizations"],
    Cell[138396, 4820, 28856, 1110, 146, 11721, 893, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Lens Optimizations"],
    Cell[167289, 5935, 85, 1, 39, "Input",
      CellTags->"Lens Optimizations"],
    Cell[167377, 5938, 291, 5, 38, "Output",
      CellTags->"Lens Optimizations"],
    Cell[167705, 5948, 96, 1, 39, "Input",
      CellTags->"Lens Optimizations"],
    Cell[167804, 5951, 25231, 1065, 139, 11745, 893, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Lens Optimizations"],
    Cell[193050, 7019, 203, 5, 54, "Input",
      CellTags->"Lens Optimizations"],
    Cell[193278, 7028, 205, 6, 84, "Input",
      CellTags->"Lens Optimizations"],
    Cell[193486, 7036, 33074, 2439, 444, 32816, 2432, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Lens Optimizations"],
    Cell[226597, 9480, 231, 8, 114, "Input",
      CellTags->"Lens Optimizations"],
    Cell[226831, 9490, 392, 7, 41, "Output",
      CellTags->"Lens Optimizations"],
    Cell[227260, 9502, 107, 1, 39, "Input",
      CellTags->"Lens Optimizations"],
    Cell[227370, 9505, 33280, 2439, 479, 33023, 2432, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Lens Optimizations"],
    Cell[260687, 11949, 214, 8, 114, "Input",
      CellTags->"Lens Optimizations"],
    Cell[260904, 11959, 398, 7, 55, "Output",
      CellTags->"Lens Optimizations"],
    Cell[261339, 11971, 107, 1, 39, "Input",
      CellTags->"Lens Optimizations"],
    Cell[261449, 11974, 33287, 2439, 514, 33033, 2432, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Lens Optimizations"]},
  "Info3252053709-8785867"->{
    Cell[135893, 4768, 1131, 16, 184, "Print",
      CellTags->{"Info3252053709-8785867", "Lens Optimizations"}]},
  "Info3252053717-8293308"->{
    Cell[137138, 4792, 807, 11, 139, "Print",
      CellTags->{"Info3252053717-8293308", "Lens Optimizations"}]},
  "Prism Examples"->{
    Cell[294785, 14419, 63, 1, 36, "Section",
      CellTags->"Prism Examples"],
    Cell[294873, 14424, 257, 7, 87, "Input",
      CellTags->"Prism Examples"],
    Cell[295133, 14433, 30189, 803, 207, 8805, 534, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Prism Examples"],
    Cell[325359, 15241, 170, 7, 87, "Input",
      CellTags->"Prism Examples"],
    Cell[325532, 15250, 16569, 514, 170, 5260, 369, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Prism Examples"],
    Cell[342138, 15769, 215, 7, 87, "Input",
      CellTags->"Prism Examples"],
    Cell[342356, 15778, 26724, 867, 165, 9019, 643, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Prism Examples"],
    Cell[369117, 16650, 244, 4, 75, "Input",
      CellTags->"Prism Examples"],
    Cell[369364, 16656, 10765, 263, 158, 2319, 154, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Prism Examples"],
    Cell[380166, 16924, 436, 12, 147, "Input",
      CellTags->"Prism Examples"],
    Cell[380605, 16938, 87597, 1968, 441, 16562, 1086, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Prism Examples"],
    Cell[468239, 18911, 176, 7, 87, "Input",
      CellTags->"Prism Examples"],
    Cell[468418, 18920, 37083, 758, 173, 5664, 365, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Prism Examples"],
    Cell[505538, 19683, 166, 7, 87, "Input",
      CellTags->"Prism Examples"],
    Cell[505707, 19692, 42023, 782, 281, 4866, 318, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Prism Examples"],
    Cell[547767, 20479, 161, 6, 72, "Input",
      CellTags->"Prism Examples"],
    Cell[547931, 20487, 83698, 1422, 400, 5478, 452, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Prism Examples"],
    Cell[631666, 21914, 81, 1, 27, "Input",
      CellTags->"Prism Examples"],
    Cell[631750, 21917, 51640, 1105, 296, 9458, 579, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Prism Examples"],
    Cell[683427, 23027, 211, 6, 72, "Input",
      CellTags->"Prism Examples"],
    Cell[683641, 23035, 41929, 1442, 202, 17132, 1131, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Prism Examples"],
    Cell[725607, 24482, 81, 1, 27, "Input",
      CellTags->"Prism Examples"],
    Cell[725691, 24485, 65512, 1745, 296, 16833, 1139, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Prism Examples"],
    Cell[791240, 26235, 140, 4, 27, "Input",
      CellTags->"Prism Examples"],
    Cell[791383, 26241, 21532, 377, 312, 1878, 130, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Prism Examples"],
    Cell[812952, 26623, 87, 1, 27, "Input",
      CellTags->"Prism Examples"],
    Cell[813042, 26626, 68238, 3426, 342, 34108, 3000, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Prism Examples"]},
  "Polarizing Elements"->{
    Cell[881329, 30058, 73, 1, 36, "Section",
      CellTags->"Polarizing Elements"],
    Cell[881427, 30063, 219, 6, 84, "Input",
      CellTags->"Polarizing Elements"],
    Cell[881649, 30071, 30670, 537, 295, 2544, 185, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Polarizing Elements"],
    Cell[912356, 30613, 276, 7, 99, "Input",
      CellTags->"Polarizing Elements"],
    Cell[912635, 30622, 17162, 357, 202, 2327, 169, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Polarizing Elements"],
    Cell[929834, 30984, 369, 9, 117, "Input",
      CellTags->"Polarizing Elements"],
    Cell[930228, 30997, 25048, 2117, 308, 24805, 2110, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Polarizing Elements"],
    Cell[955279, 33116, 4263, 298, 198, 4010, 291, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Polarizing Elements"],
    Cell[959591, 33420, 405, 9, 129, "Input",
      CellTags->"Polarizing Elements"],
    Cell[960021, 33433, 33530, 2944, 308, 33287, 2937, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Polarizing Elements"],
    Cell[993554, 36379, 4270, 298, 247, 4009, 291, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Polarizing Elements"]},
  "Solitaire Diamond Example"->{
    Cell[997885, 36684, 85, 1, 36, "Section",
      CellTags->"Solitaire Diamond Example"],
    Cell[997995, 36689, 94, 1, 39, "Input",
      CellTags->"Solitaire Diamond Example"],
    Cell[998092, 36692, 96, 2, 35, "Print",
      CellTags->"Solitaire Diamond Example"],
    Cell[998191, 36696, 425, 6, 71, "Output",
      CellTags->"Solitaire Diamond Example"],
    Cell[998653, 36707, 68, 1, 39, "Input",
      CellTags->"Solitaire Diamond Example"],
    Cell[998724, 36710, 889, 12, 147, "Print",
      CellTags->{"Info3252053805-1502543", "Solitaire Diamond Example"}],
    Cell[999650, 36727, 130, 4, 39, "Input",
      CellTags->"Solitaire Diamond Example"],
    Cell[999783, 36733, 96, 2, 35, "Print",
      CellTags->"Solitaire Diamond Example"],
    Cell[999882, 36737, 101, 2, 39, "Output",
      CellTags->"Solitaire Diamond Example"],
    Cell[1000020, 36744, 158, 6, 84, "Input",
      CellTags->"Solitaire Diamond Example"],
    Cell[1000181, 36752, 63856, 1532, 166, 12064, 888, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Solitaire Diamond Example"],
    Cell[1064074, 38289, 457, 14, 204, "Input",
      CellTags->"Solitaire Diamond Example"],
    Cell[1064534, 38305, 136281, 11515, 480, 136113, 11510, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Solitaire Diamond Example"],
    Cell[1200818, 49822, 102, 2, 39, "Output",
      CellTags->"Solitaire Diamond Example"],
    Cell[1200957, 49829, 152, 4, 39, "Input",
      CellTags->"Solitaire Diamond Example"],
    Cell[1201112, 49835, 136686, 11736, 607, 136518, 11731, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Solitaire Diamond Example"],
    Cell[1337835, 61576, 176, 4, 39, "Input",
      CellTags->"Solitaire Diamond Example"],
    Cell[1338014, 61582, 591720, 25579, 461, 252229, 21383, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Solitaire Diamond Example"],
    Cell[1929771, 87166, 213, 5, 54, "Input",
      CellTags->"Solitaire Diamond Example"],
    Cell[1929987, 87173, 642094, 26311, 482, 253737, 21512, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Solitaire Diamond Example"]},
  "Info3252053805-1502543"->{
    Cell[998724, 36710, 889, 12, 147, "Print",
      CellTags->{"Info3252053805-1502543", "Solitaire Diamond Example"}]},
  "Add Surface Roughness"->{
    Cell[2572130, 113490, 77, 1, 36, "Section",
      CellTags->"Add Surface Roughness"],
    Cell[2572210, 113493, 93, 1, 39, "Input",
      CellTags->"Add Surface Roughness"],
    Cell[2572328, 113498, 74, 1, 39, "Input",
      CellTags->"Add Surface Roughness"],
    Cell[2572405, 113501, 792, 11, 154, "Print",
      CellTags->{"Info3252053787-3333948", "Add Surface Roughness"}],
    Cell[2573234, 113517, 101, 1, 39, "Input",
      CellTags->"Add Surface Roughness"],
    Cell[2573338, 113520, 167, 4, 38, "Output",
      CellTags->"Add Surface Roughness"],
    Cell[2573542, 113529, 171, 4, 54, "Input",
      CellTags->"Add Surface Roughness"],
    Cell[2573716, 113535, 26008, 710, 323, 7235, 473, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Add Surface Roughness"],
    Cell[2599761, 114250, 185, 6, 84, "Input",
      CellTags->"Add Surface Roughness"],
    Cell[2599949, 114258, 8675, 598, 308, 8430, 591, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Add Surface Roughness"],
    Cell[2608661, 114861, 208, 6, 84, "Input",
      CellTags->"Add Surface Roughness"],
    Cell[2608872, 114869, 8728, 598, 420, 8483, 591, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Add Surface Roughness"],
    Cell[2617637, 115472, 209, 6, 84, "Input",
      CellTags->"Add Surface Roughness"],
    Cell[2617849, 115480, 59327, 3064, 308, 34315, 2749, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Add Surface Roughness"]},
  "Info3252053787-3333948"->{
    Cell[2572405, 113501, 792, 11, 154, "Print",
      CellTags->{"Info3252053787-3333948", "Add Surface Roughness"}]},
  "Realistic Fresnel Lens Model"->{
    Cell[2677225, 118550, 91, 1, 36, "Section",
      CellTags->"Realistic Fresnel Lens Model"],
    Cell[2677341, 118555, 69, 1, 39, "Input",
      CellTags->"Realistic Fresnel Lens Model"],
    Cell[2677413, 118558, 872, 12, 154, "Print",
      CellTags->{"Info3252053738-6121344", "Realistic Fresnel Lens Model"}],
    Cell[2678322, 118575, 75, 1, 39, "Input",
      CellTags->"Realistic Fresnel Lens Model"],
    Cell[2678400, 118578, 548, 8, 109, "Print",
      CellTags->{"Info3252053750-8945673", "Realistic Fresnel Lens Model"}],
    Cell[2678985, 118591, 144, 4, 39, "Input",
      CellTags->"Realistic Fresnel Lens Model"],
    Cell[2679132, 118597, 189, 4, 38, "Output",
      CellTags->"Realistic Fresnel Lens Model"],
    Cell[2679358, 118606, 114, 1, 39, "Input",
      CellTags->"Realistic Fresnel Lens Model"],
    Cell[2679475, 118609, 8099, 131, 558, "Output",
      CellTags->"Realistic Fresnel Lens Model"],
    Cell[2687611, 118745, 117, 1, 36, "Input",
      CellTags->"Realistic Fresnel Lens Model"],
    Cell[2687731, 118748, 95366, 1748, 391, 10637, 697, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Realistic Fresnel Lens Model"],
    Cell[2783134, 120501, 134, 4, 39, "Input",
      CellTags->"Realistic Fresnel Lens Model"],
    Cell[2783271, 120507, 46933, 1423, 368, 15824, 1034, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Realistic Fresnel Lens Model"],
    Cell[2830241, 121935, 320, 9, 84, "Input",
      CellTags->{
      "genetic building-blocks", "creating new components", "Fresnel", 
        "fresnel lens", "Realistic Fresnel Lens Model"}],
    Cell[2830564, 121946, 76770, 3283, 438, 34491, 2755, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Realistic Fresnel Lens Model"]},
  "Info3252053738-6121344"->{
    Cell[2677413, 118558, 872, 12, 154, "Print",
      CellTags->{"Info3252053738-6121344", "Realistic Fresnel Lens Model"}]},
  "Info3252053750-8945673"->{
    Cell[2678400, 118578, 548, 8, 109, "Print",
      CellTags->{"Info3252053750-8945673", "Realistic Fresnel Lens Model"}]},
  "genetic building-blocks"->{
    Cell[2830241, 121935, 320, 9, 84, "Input",
      CellTags->{
      "genetic building-blocks", "creating new components", "Fresnel", 
        "fresnel lens", "Realistic Fresnel Lens Model"}]},
  "creating new components"->{
    Cell[2830241, 121935, 320, 9, 84, "Input",
      CellTags->{
      "genetic building-blocks", "creating new components", "Fresnel", 
        "fresnel lens", "Realistic Fresnel Lens Model"}]},
  "Fresnel"->{
    Cell[2830241, 121935, 320, 9, 84, "Input",
      CellTags->{
      "genetic building-blocks", "creating new components", "Fresnel", 
        "fresnel lens", "Realistic Fresnel Lens Model"}]},
  "fresnel lens"->{
    Cell[2830241, 121935, 320, 9, 84, "Input",
      CellTags->{
      "genetic building-blocks", "creating new components", "Fresnel", 
        "fresnel lens", "Realistic Fresnel Lens Model"}]},
  "Rayica's Data Base"->{
    Cell[2907383, 125235, 84, 1, 36, "Section",
      CellTags->"Rayica's Data Base"],
    Cell[2907470, 125238, 286, 11, 50, "Text",
      CellTags->"Rayica's Data Base"],
    Cell[2907759, 125251, 205, 6, 32, "Text",
      CellTags->"Rayica's Data Base"],
    Cell[2907967, 125259, 198, 7, 32, "Text",
      CellTags->"Rayica's Data Base"],
    Cell[2908190, 125270, 64, 1, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2908257, 125273, 816, 14, 91, "Output",
      CellTags->"Rayica's Data Base"],
    Cell[2909088, 125290, 236, 7, 32, "Text",
      CellTags->"Rayica's Data Base"],
    Cell[2909349, 125301, 81, 1, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2909433, 125304, 317, 9, 27, "Output",
      CellTags->"Rayica's Data Base"],
    Cell[2909787, 125318, 98, 1, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2909888, 125321, 316, 8, 27, "Output",
      CellTags->"Rayica's Data Base"],
    Cell[2910219, 125332, 272, 7, 32, "Text",
      CellTags->"Rayica's Data Base"],
    Cell[2910516, 125343, 106, 1, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2910625, 125346, 475, 14, 133, "Output",
      CellTags->"Rayica's Data Base"],
    Cell[2911115, 125363, 374, 12, 32, "Text",
      CellTags->"Rayica's Data Base"],
    Cell[2911514, 125379, 68, 1, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2911585, 125382, 269, 5, 42, "Output",
      CellTags->"Rayica's Data Base"],
    Cell[2911869, 125390, 267, 7, 32, "Text",
      CellTags->"Rayica's Data Base"],
    Cell[2912161, 125401, 135, 4, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2912299, 125407, 754, 21, 245, "Output",
      CellTags->"Rayica's Data Base"],
    Cell[2913068, 125431, 412, 10, 50, "Text",
      CellTags->"Rayica's Data Base"],
    Cell[2913505, 125445, 155, 4, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2913663, 125451, 2264, 51, 261, "Output",
      CellTags->"Rayica's Data Base"],
    Cell[2915942, 125505, 512, 11, 50, "Text",
      CellTags->"Rayica's Data Base"],
    Cell[2916479, 125520, 73, 1, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2916555, 125523, 1020, 16, 91, "Output",
      CellTags->"Rayica's Data Base"],
    Cell[2917590, 125542, 440, 8, 50, "Text",
      CellTags->"Rayica's Data Base"],
    Cell[2918055, 125554, 97, 1, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2918155, 125557, 1126, 28, 357, "Output",
      CellTags->"Rayica's Data Base"],
    Cell[2919296, 125588, 692, 15, 50, "Text",
      CellTags->"Rayica's Data Base"],
    Cell[2920013, 125607, 89, 1, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2920105, 125610, 1457, 29, 109, "Output",
      CellTags->"Rayica's Data Base"],
    Cell[2921577, 125642, 283, 8, 32, "Text",
      CellTags->"Rayica's Data Base"],
    Cell[2921885, 125654, 109, 1, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2921997, 125657, 292, 6, 23, "Print",
      CellTags->"Rayica's Data Base"],
    Cell[2922292, 125665, 326, 7, 23, "Print",
      CellTags->"Rayica's Data Base"],
    Cell[2922621, 125674, 240, 7, 27, "Output",
      CellTags->"Rayica's Data Base"],
    Cell[2922876, 125684, 302, 9, 32, "Text",
      CellTags->"Rayica's Data Base"],
    Cell[2923203, 125697, 97, 1, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2923303, 125700, 7591, 134, 197, "Output",
      CellTags->"Rayica's Data Base"],
    Cell[2930909, 125837, 171, 5, 32, "Text",
      CellTags->"Rayica's Data Base"],
    Cell[2931105, 125846, 146, 4, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2931254, 125852, 504, 13, 117, "Output",
      CellTags->"Rayica's Data Base"],
    Cell[2931773, 125868, 315, 9, 32, "Text",
      CellTags->"Rayica's Data Base"],
    Cell[2932113, 125881, 87, 1, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2932203, 125884, 2482, 33, 251, "Output",
      CellTags->"Rayica's Data Base"],
    Cell[2934700, 125920, 371, 10, 32, "Text",
      CellTags->"Rayica's Data Base"],
    Cell[2935096, 125934, 73, 1, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2935172, 125937, 425, 7, 59, "Output",
      CellTags->"Rayica's Data Base"],
    Cell[2935612, 125947, 151, 4, 32, "Text",
      CellTags->"Rayica's Data Base"],
    Cell[2935788, 125955, 99, 1, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2935890, 125958, 87, 2, 27, "Output",
      CellTags->"Rayica's Data Base"],
    Cell[2936014, 125965, 96, 1, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2936113, 125968, 100, 2, 27, "Output",
      CellTags->"Rayica's Data Base"],
    Cell[2936228, 125973, 214, 5, 32, "Text",
      CellTags->"Rayica's Data Base"],
    Cell[2936467, 125982, 60, 1, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2936530, 125985, 3972, 53, 503, "Print",
      CellTags->{"Info3311851835-9430908", "Rayica's Data Base"}],
    Cell[2940539, 126043, 68, 1, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2940610, 126046, 371, 6, 43, "Output",
      CellTags->"Rayica's Data Base"],
    Cell[2941018, 126057, 62, 1, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[2941083, 126060, 115630, 2296, 435, 18992, 1098, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Rayica's Data Base"],
    Cell[3056728, 128359, 321, 9, 32, "Text",
      CellTags->"Rayica's Data Base"],
    Cell[3057074, 128372, 145, 5, 27, "Input",
      CellTags->"Rayica's Data Base"],
    Cell[3057222, 128379, 400, 6, 59, "Output",
      CellTags->"Rayica's Data Base"]},
  "Info3311851835-9430908"->{
    Cell[2936530, 125985, 3972, 53, 503, "Print",
      CellTags->{"Info3311851835-9430908", "Rayica's Data Base"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Using RayTraceFunction", 3058295, 128405},
  {"Info3252053846-2417689", 3059598, 128435},
  {"TurboPlot Examples", 3059738, 128438},
  {"Lens Optimizations", 3060539, 128457},
  {"Info3252053709-8785867", 3062919, 128512},
  {"Info3252053717-8293308", 3063064, 128515},
  {"Prism Examples", 3063200, 128518},
  {"Polarizing Elements", 3066104, 128586},
  {"Solitaire Diamond Example", 3067524, 128619},
  {"Info3252053805-1502543", 3069778, 128667},
  {"Add Surface Roughness", 3069929, 128670},
  {"Info3252053787-3333948", 3071543, 128706},
  {"Realistic Fresnel Lens Model", 3071699, 128709},
  {"Info3252053738-6121344", 3073533, 128746},
  {"Info3252053750-8945673", 3073690, 128749},
  {"genetic building-blocks", 3073847, 128752},
  {"creating new components", 3074074, 128757},
  {"Fresnel", 3074285, 128762},
  {"fresnel lens", 3074501, 128767},
  {"Rayica's Data Base", 3074723, 128772},
  {"Info3311851835-9430908", 3080363, 128902}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 79, 1, 56, "Section",
  CellTags->"Using RayTraceFunction"],

Cell[CellGroupData[{
Cell[1880, 58, 72, 1, 39, "Input",
  CellTags->"Using RayTraceFunction"],
Cell[1955, 61, 888, 12, 147, "Print",
  CellTags->{"Info3252053846-2417689", "Using RayTraceFunction"}]
}, Open  ]],
Cell[2858, 76, 283, 5, 71, "Input",
  CellTags->"Using RayTraceFunction"],

Cell[CellGroupData[{
Cell[3166, 85, 120, 2, 39, "Input",
  CellTags->"Using RayTraceFunction"],
Cell[3289, 89, 46437, 1391, 245, 13762, 982, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Using RayTraceFunction"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49763, 1485, 77, 1, 39, "Input",
  CellTags->"Using RayTraceFunction"],
Cell[49843, 1488, 352, 6, 55, "Output",
  CellTags->"Using RayTraceFunction"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50232, 1499, 89, 1, 39, "Input",
  CellTags->"Using RayTraceFunction"],
Cell[50324, 1502, 104, 2, 39, "Output",
  CellTags->"Using RayTraceFunction"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50465, 1509, 91, 1, 39, "Input",
  CellTags->"Using RayTraceFunction"],
Cell[50559, 1512, 352, 6, 55, "Output",
  CellTags->"Using RayTraceFunction"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50948, 1523, 89, 1, 39, "Input",
  CellTags->"Using RayTraceFunction"],
Cell[51040, 1526, 208, 4, 39, "Output",
  CellTags->"Using RayTraceFunction"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[51297, 1536, 71, 1, 36, "Section",
  CellTags->"TurboPlot Examples"],

Cell[CellGroupData[{
Cell[51393, 1541, 195, 6, 84, "Input",
  CellTags->"TurboPlot Examples"],
Cell[51591, 1549, 35540, 1347, 308, 13461, 1069, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"TurboPlot Examples"]
}, Open  ]],

Cell[CellGroupData[{
Cell[87168, 2901, 110, 1, 39, "Input",
  CellTags->"TurboPlot Examples"],
Cell[87281, 2904, 42935, 1438, 308, 13437, 1069, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"TurboPlot Examples"]
}, Open  ]],

Cell[CellGroupData[{
Cell[130253, 4347, 102, 1, 39, "Input",
  CellTags->"TurboPlot Examples"],
Cell[130358, 4350, 5321, 404, 308, 5079, 397, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"TurboPlot Examples"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[135728, 4760, 71, 1, 36, "Section",
  CellTags->"Lens Optimizations"],

Cell[CellGroupData[{
Cell[135824, 4765, 66, 1, 39, "Input",
  CellTags->"Lens Optimizations"],
Cell[135893, 4768, 1131, 16, 184, "Print",
  CellTags->{"Info3252053709-8785867", "Lens Optimizations"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[137061, 4789, 74, 1, 39, "Input",
  CellTags->"Lens Optimizations"],
Cell[137138, 4792, 807, 11, 139, "Print",
  CellTags->{"Info3252053717-8293308", "Lens Optimizations"}]
}, Open  ]],
Cell[137960, 4806, 279, 5, 71, "Input",
  CellTags->"Lens Optimizations"],

Cell[CellGroupData[{
Cell[138264, 4815, 129, 3, 39, "Input",
  CellTags->"Lens Optimizations"],
Cell[138396, 4820, 28856, 1110, 146, 11721, 893, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Lens Optimizations"]
}, Open  ]],

Cell[CellGroupData[{
Cell[167289, 5935, 85, 1, 39, "Input",
  CellTags->"Lens Optimizations"],
Cell[167377, 5938, 291, 5, 38, "Output",
  CellTags->"Lens Optimizations"]
}, Open  ]],

Cell[CellGroupData[{
Cell[167705, 5948, 96, 1, 39, "Input",
  CellTags->"Lens Optimizations"],
Cell[167804, 5951, 25231, 1065, 139, 11745, 893, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Lens Optimizations"]
}, Open  ]],
Cell[193050, 7019, 203, 5, 54, "Input",
  CellTags->"Lens Optimizations"],

Cell[CellGroupData[{
Cell[193278, 7028, 205, 6, 84, "Input",
  CellTags->"Lens Optimizations"],
Cell[193486, 7036, 33074, 2439, 444, 32816, 2432, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"Lens Optimizations"]
}, Open  ]],

Cell[CellGroupData[{
Cell[226597, 9480, 231, 8, 114, "Input",
  CellTags->"Lens Optimizations"],
Cell[226831, 9490, 392, 7, 41, "Output",
  CellTags->"Lens Optimizations"]
}, Open  ]],

Cell[CellGroupData[{
Cell[227260, 9502, 107, 1, 39, "Input",
  CellTags->"Lens Optimizations"],
Cell[227370, 9505, 33280, 2439, 479, 33023, 2432, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"Lens Optimizations"]
}, Open  ]],

Cell[CellGroupData[{
Cell[260687, 11949, 214, 8, 114, "Input",
  CellTags->"Lens Optimizations"],
Cell[260904, 11959, 398, 7, 55, "Output",
  CellTags->"Lens Optimizations"]
}, Open  ]],

Cell[CellGroupData[{
Cell[261339, 11971, 107, 1, 39, "Input",
  CellTags->"Lens Optimizations"],
Cell[261449, 11974, 33287, 2439, 514, 33033, 2432, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"Lens Optimizations"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[294785, 14419, 63, 1, 36, "Section",
  CellTags->"Prism Examples"],

Cell[CellGroupData[{
Cell[294873, 14424, 257, 7, 87, "Input",
  CellTags->"Prism Examples"],
Cell[295133, 14433, 30189, 803, 207, 8805, 534, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{
Cell[325359, 15241, 170, 7, 87, "Input",
  CellTags->"Prism Examples"],
Cell[325532, 15250, 16569, 514, 170, 5260, 369, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{
Cell[342138, 15769, 215, 7, 87, "Input",
  CellTags->"Prism Examples"],
Cell[342356, 15778, 26724, 867, 165, 9019, 643, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{
Cell[369117, 16650, 244, 4, 75, "Input",
  CellTags->"Prism Examples"],
Cell[369364, 16656, 10765, 263, 158, 2319, 154, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{
Cell[380166, 16924, 436, 12, 147, "Input",
  CellTags->"Prism Examples"],
Cell[380605, 16938, 87597, 1968, 441, 16562, 1086, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{
Cell[468239, 18911, 176, 7, 87, "Input",
  CellTags->"Prism Examples"],
Cell[468418, 18920, 37083, 758, 173, 5664, 365, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{
Cell[505538, 19683, 166, 7, 87, "Input",
  CellTags->"Prism Examples"],
Cell[505707, 19692, 42023, 782, 281, 4866, 318, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{
Cell[547767, 20479, 161, 6, 72, "Input",
  CellTags->"Prism Examples"],
Cell[547931, 20487, 83698, 1422, 400, 5478, 452, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{
Cell[631666, 21914, 81, 1, 27, "Input",
  CellTags->"Prism Examples"],
Cell[631750, 21917, 51640, 1105, 296, 9458, 579, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{
Cell[683427, 23027, 211, 6, 72, "Input",
  CellTags->"Prism Examples"],
Cell[683641, 23035, 41929, 1442, 202, 17132, 1131, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{
Cell[725607, 24482, 81, 1, 27, "Input",
  CellTags->"Prism Examples"],
Cell[725691, 24485, 65512, 1745, 296, 16833, 1139, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{
Cell[791240, 26235, 140, 4, 27, "Input",
  CellTags->"Prism Examples"],
Cell[791383, 26241, 21532, 377, 312, 1878, 130, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Prism Examples"]
}, Open  ]],

Cell[CellGroupData[{
Cell[812952, 26623, 87, 1, 27, "Input",
  CellTags->"Prism Examples"],
Cell[813042, 26626, 68238, 3426, 342, 34108, 3000, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Prism Examples"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[881329, 30058, 73, 1, 36, "Section",
  CellTags->"Polarizing Elements"],

Cell[CellGroupData[{
Cell[881427, 30063, 219, 6, 84, "Input",
  CellTags->"Polarizing Elements"],
Cell[881649, 30071, 30670, 537, 295, 2544, 185, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Polarizing Elements"]
}, Open  ]],

Cell[CellGroupData[{
Cell[912356, 30613, 276, 7, 99, "Input",
  CellTags->"Polarizing Elements"],
Cell[912635, 30622, 17162, 357, 202, 2327, 169, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Polarizing Elements"]
}, Open  ]],

Cell[CellGroupData[{
Cell[929834, 30984, 369, 9, 117, "Input",
  CellTags->"Polarizing Elements"],

Cell[CellGroupData[{
Cell[930228, 30997, 25048, 2117, 308, 24805, 2110, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"Polarizing Elements"],
Cell[955279, 33116, 4263, 298, 198, 4010, 291, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"Polarizing Elements"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[959591, 33420, 405, 9, 129, "Input",
  CellTags->"Polarizing Elements"],

Cell[CellGroupData[{
Cell[960021, 33433, 33530, 2944, 308, 33287, 2937, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"Polarizing Elements"],
Cell[993554, 36379, 4270, 298, 247, 4009, 291, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"Polarizing Elements"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[997885, 36684, 85, 1, 36, "Section",
  CellTags->"Solitaire Diamond Example"],

Cell[CellGroupData[{
Cell[997995, 36689, 94, 1, 39, "Input",
  CellTags->"Solitaire Diamond Example"],
Cell[998092, 36692, 96, 2, 35, "Print",
  CellTags->"Solitaire Diamond Example"],
Cell[998191, 36696, 425, 6, 71, "Output",
  CellTags->"Solitaire Diamond Example"]
}, Open  ]],

Cell[CellGroupData[{
Cell[998653, 36707, 68, 1, 39, "Input",
  CellTags->"Solitaire Diamond Example"],
Cell[998724, 36710, 889, 12, 147, "Print",
  CellTags->{"Info3252053805-1502543", "Solitaire Diamond Example"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[999650, 36727, 130, 4, 39, "Input",
  CellTags->"Solitaire Diamond Example"],
Cell[999783, 36733, 96, 2, 35, "Print",
  CellTags->"Solitaire Diamond Example"],
Cell[999882, 36737, 101, 2, 39, "Output",
  CellTags->"Solitaire Diamond Example"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1000020, 36744, 158, 6, 84, "Input",
  CellTags->"Solitaire Diamond Example"],
Cell[1000181, 36752, 63856, 1532, 166, 12064, 888, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Solitaire Diamond Example"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1064074, 38289, 457, 14, 204, "Input",
  CellTags->"Solitaire Diamond Example"],
Cell[1064534, 38305, 136281, 11515, 480, 136113, 11510, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"Solitaire Diamond Example"],
Cell[1200818, 49822, 102, 2, 39, "Output",
  CellTags->"Solitaire Diamond Example"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1200957, 49829, 152, 4, 39, "Input",
  CellTags->"Solitaire Diamond Example"],
Cell[1201112, 49835, 136686, 11736, 607, 136518, 11731, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"Solitaire Diamond Example"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1337835, 61576, 176, 4, 39, "Input",
  CellTags->"Solitaire Diamond Example"],
Cell[1338014, 61582, 591720, 25579, 461, 252229, 21383, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Solitaire Diamond Example"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1929771, 87166, 213, 5, 54, "Input",
  CellTags->"Solitaire Diamond Example"],
Cell[1929987, 87173, 642094, 26311, 482, 253737, 21512, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Solitaire Diamond Example"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2572130, 113490, 77, 1, 36, "Section",
  CellTags->"Add Surface Roughness"],
Cell[2572210, 113493, 93, 1, 39, "Input",
  CellTags->"Add Surface Roughness"],

Cell[CellGroupData[{
Cell[2572328, 113498, 74, 1, 39, "Input",
  CellTags->"Add Surface Roughness"],
Cell[2572405, 113501, 792, 11, 154, "Print",
  CellTags->{"Info3252053787-3333948", "Add Surface Roughness"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[2573234, 113517, 101, 1, 39, "Input",
  CellTags->"Add Surface Roughness"],
Cell[2573338, 113520, 167, 4, 38, "Output",
  CellTags->"Add Surface Roughness"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2573542, 113529, 171, 4, 54, "Input",
  CellTags->"Add Surface Roughness"],
Cell[2573716, 113535, 26008, 710, 323, 7235, 473, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Add Surface Roughness"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2599761, 114250, 185, 6, 84, "Input",
  CellTags->"Add Surface Roughness"],
Cell[2599949, 114258, 8675, 598, 308, 8430, 591, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"Add Surface Roughness"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2608661, 114861, 208, 6, 84, "Input",
  CellTags->"Add Surface Roughness"],
Cell[2608872, 114869, 8728, 598, 420, 8483, 591, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"Add Surface Roughness"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2617637, 115472, 209, 6, 84, "Input",
  CellTags->"Add Surface Roughness"],
Cell[2617849, 115480, 59327, 3064, 308, 34315, 2749, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"Add Surface Roughness"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2677225, 118550, 91, 1, 36, "Section",
  CellTags->"Realistic Fresnel Lens Model"],

Cell[CellGroupData[{
Cell[2677341, 118555, 69, 1, 39, "Input",
  CellTags->"Realistic Fresnel Lens Model"],
Cell[2677413, 118558, 872, 12, 154, "Print",
  CellTags->{"Info3252053738-6121344", "Realistic Fresnel Lens Model"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[2678322, 118575, 75, 1, 39, "Input",
  CellTags->"Realistic Fresnel Lens Model"],
Cell[2678400, 118578, 548, 8, 109, "Print",
  CellTags->{"Info3252053750-8945673", "Realistic Fresnel Lens Model"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[2678985, 118591, 144, 4, 39, "Input",
  CellTags->"Realistic Fresnel Lens Model"],
Cell[2679132, 118597, 189, 4, 38, "Output",
  CellTags->"Realistic Fresnel Lens Model"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2679358, 118606, 114, 1, 39, "Input",
  CellTags->"Realistic Fresnel Lens Model"],
Cell[2679475, 118609, 8099, 131, 558, "Output",
  CellTags->"Realistic Fresnel Lens Model"]
}, Closed]],

Cell[CellGroupData[{
Cell[2687611, 118745, 117, 1, 36, "Input",
  CellTags->"Realistic Fresnel Lens Model"],
Cell[2687731, 118748, 95366, 1748, 391, 10637, 697, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Realistic Fresnel Lens Model"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2783134, 120501, 134, 4, 39, "Input",
  CellTags->"Realistic Fresnel Lens Model"],
Cell[2783271, 120507, 46933, 1423, 368, 15824, 1034, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Realistic Fresnel Lens Model"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2830241, 121935, 320, 9, 84, "Input",
  CellTags->{
  "genetic building-blocks", "creating new components", "Fresnel", 
    "fresnel lens", "Realistic Fresnel Lens Model"}],
Cell[2830564, 121946, 76770, 3283, 438, 34491, 2755, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"Realistic Fresnel Lens Model"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2907383, 125235, 84, 1, 36, "Section",
  CellTags->"Rayica's Data Base"],
Cell[2907470, 125238, 286, 11, 50, "Text",
  CellTags->"Rayica's Data Base"],
Cell[2907759, 125251, 205, 6, 32, "Text",
  CellTags->"Rayica's Data Base"],
Cell[2907967, 125259, 198, 7, 32, "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{
Cell[2908190, 125270, 64, 1, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2908257, 125273, 816, 14, 91, "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],
Cell[2909088, 125290, 236, 7, 32, "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{
Cell[2909349, 125301, 81, 1, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2909433, 125304, 317, 9, 27, "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2909787, 125318, 98, 1, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2909888, 125321, 316, 8, 27, "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],
Cell[2910219, 125332, 272, 7, 32, "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{
Cell[2910516, 125343, 106, 1, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2910625, 125346, 475, 14, 133, "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],
Cell[2911115, 125363, 374, 12, 32, "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{
Cell[2911514, 125379, 68, 1, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2911585, 125382, 269, 5, 42, "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],
Cell[2911869, 125390, 267, 7, 32, "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{
Cell[2912161, 125401, 135, 4, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2912299, 125407, 754, 21, 245, "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],
Cell[2913068, 125431, 412, 10, 50, "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{
Cell[2913505, 125445, 155, 4, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2913663, 125451, 2264, 51, 261, "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],
Cell[2915942, 125505, 512, 11, 50, "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{
Cell[2916479, 125520, 73, 1, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2916555, 125523, 1020, 16, 91, "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],
Cell[2917590, 125542, 440, 8, 50, "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{
Cell[2918055, 125554, 97, 1, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2918155, 125557, 1126, 28, 357, "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],
Cell[2919296, 125588, 692, 15, 50, "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{
Cell[2920013, 125607, 89, 1, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2920105, 125610, 1457, 29, 109, "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],
Cell[2921577, 125642, 283, 8, 32, "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{
Cell[2921885, 125654, 109, 1, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2921997, 125657, 292, 6, 23, "Print",
  CellTags->"Rayica's Data Base"],
Cell[2922292, 125665, 326, 7, 23, "Print",
  CellTags->"Rayica's Data Base"],
Cell[2922621, 125674, 240, 7, 27, "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],
Cell[2922876, 125684, 302, 9, 32, "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{
Cell[2923203, 125697, 97, 1, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2923303, 125700, 7591, 134, 197, "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],
Cell[2930909, 125837, 171, 5, 32, "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{
Cell[2931105, 125846, 146, 4, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2931254, 125852, 504, 13, 117, "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],
Cell[2931773, 125868, 315, 9, 32, "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{
Cell[2932113, 125881, 87, 1, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2932203, 125884, 2482, 33, 251, "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],
Cell[2934700, 125920, 371, 10, 32, "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{
Cell[2935096, 125934, 73, 1, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2935172, 125937, 425, 7, 59, "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],
Cell[2935612, 125947, 151, 4, 32, "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{
Cell[2935788, 125955, 99, 1, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2935890, 125958, 87, 2, 27, "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2936014, 125965, 96, 1, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2936113, 125968, 100, 2, 27, "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],
Cell[2936228, 125973, 214, 5, 32, "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{
Cell[2936467, 125982, 60, 1, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2936530, 125985, 3972, 53, 503, "Print",
  CellTags->{"Info3311851835-9430908", "Rayica's Data Base"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[2940539, 126043, 68, 1, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2940610, 126046, 371, 6, 43, "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2941018, 126057, 62, 1, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[2941083, 126060, 115630, 2296, 435, 18992, 1098, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Rayica's Data Base"]
}, Open  ]],
Cell[3056728, 128359, 321, 9, 32, "Text",
  CellTags->"Rayica's Data Base"],

Cell[CellGroupData[{
Cell[3057074, 128372, 145, 5, 27, "Input",
  CellTags->"Rayica's Data Base"],
Cell[3057222, 128379, 400, 6, 59, "Output",
  CellTags->"Rayica's Data Base"]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

