(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1861153,      54084]*)
(*NotebookOutlinePosition[   1881654,      54533]*)
(*  CellTagsIndexPosition[   1881204,      54520]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Tracing Through a FresnelRhomb", "Section",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[CellGroupData[{

Cell["?FresnelRhomb", "Input",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[BoxData[
    \("FresnelRhomb[entranceface, options] is a special construction of \
RhomboidPrism that uses total-internal Fresnel reflections to perform an \
achromatic retardation of either 1/4 wave or 1/2 wave on the incident light \
for polarization applications. \n\nThe FullForm option is used to switch \
between half-wave and quarter-wave prism models. The default setting of \
FullForm->False gives a 1/4 wave retardation by modeling a single \
RhomboidPrism-type object to create two internal reflections. FullForm->True \
gives a 1/2 wave retardation by modeling a joined pair of RhomboidPrism-type \
objects to create four internal reflections. FresnelRhomb is aligned with its \
entrance face at x=0 and located in the x-y plane to maintain a parallel exit \
beam with the x-axis. The entranceface specifies the smaller thickness \
dimension of the entrance face (the longer slant dimension is then internally \
calculated). FresnelRhomb uses the DefaultAngleSetting option to set the \
entrance angle. DefaultAngleSetting->Automatic calculates the angle based on \
the given DesignWaveLength and ComponentMedium options. \n\nSee also: \
RhomboidPrism, Prism, PentaPrism, WedgePrism, and PellinBrocaPrism."\)], \
"Print",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[FresnelRhomb]", "Input",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(Labels \[Rule] "FresnelRhomb"\), 
        ",", \(LabelPositions \[Rule] Automatic\), 
        ",", \(ComponentDescription \[Rule] Automatic\), 
        ",", \(GraphicDesign \[Rule] Automatic\), 
        ",", \(ComponentMedium \[Rule] BK7\), ",", 
        RowBox[{"DesignWaveLength", "\[Rule]", 
          StyleBox["0.532000000000000028`",
            StyleBoxAutoDelete->True,
            PrintPrecision->3]}], 
        ",", \(DefaultAngleSetting \[Rule] 547\/10\), 
        ",", \(Temperature \[Rule] Temperature\), 
        ",", \(Tension \[Rule] Tension\), 
        ",", \(Transmittance \[Rule] Transmittance\), 
        ",", \(PolarizationCalculations \[Rule] True\), 
        ",", \(Automatic \[Rule] {SurfaceRendering \[Rule] Trace, 
            EdgeRendering \[Rule] Empty}\), 
        ",", \(Off \[Rule] {SurfaceRendering \[Rule] Empty, 
            EdgeRendering \[Rule] Empty}\), 
        ",", \(Sketch \[Rule] {SurfaceRendering \[Rule] Trace, 
            EdgeRendering \[Rule] Empty}\), 
        ",", \(Wire \[Rule] {SurfaceRendering \[Rule] Mesh, 
            EdgeRendering \[Rule] Empty}\), 
        ",", \(Solid \[Rule] {SurfaceRendering \[Rule] {{Fill, Trace}}, 
            EdgeRendering \[Rule] Empty}\)}], "}"}]], "Output",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FresnelRhomb[10, FullForm->True]", "Input",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[BoxData[
    TagBox[\(FresnelRhomb[
        10, {DefaultAngleSetting \[Rule] 55.4195168081208144`}]\),
      HoldForm]], "Output",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DrawSystem[\ FresnelRhomb[10, \ FullForm -> True], 
        PlotType -> TopView];\)\)], "Input",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .59891 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0199351 0.135323 0.0199351 [
[ 0 0 0 0 ]
[ 1 .59891 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .25639 m
.02381 .01426 L
.02381 .01426 L
.02381 .25639 L
.02381 .25639 L
s
.5 .58465 m
.02381 .25639 L
.02381 .25639 L
.5 .58465 L
.5 .58465 L
s
.5 .34252 m
.02381 .01426 L
.02381 .01426 L
.5 .34252 L
.5 .34252 L
s
.02381 .25639 m
.02381 .01426 L
.5 .34252 L
.5 .58465 L
.02381 .25639 L
s
.02381 .25639 m
.02381 .01426 L
.5 .34252 L
.5 .58465 L
.02381 .25639 L
s
.97619 .01426 m
.5 .34252 L
.5 .34252 L
.97619 .01426 L
.97619 .01426 L
s
.97619 .25639 m
.5 .58465 L
.5 .58465 L
.97619 .25639 L
.97619 .25639 L
s
.97619 .01426 m
.97619 .25639 L
.97619 .25639 L
.97619 .01426 L
.97619 .01426 L
s
.5 .34252 m
.5 .58465 L
.97619 .25639 L
.97619 .01426 L
.5 .34252 L
s
.5 .34252 m
.5 .58465 L
.97619 .25639 L
.97619 .01426 L
.5 .34252 L
s
0 0 m
1 0 L
1 .59891 L
0 .59891 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{339.938, 203.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005C0000bb000`400?l00000o`00003oo`3ooomD
0?ooo`00o`3ooomD0?ooo`00o`3ooomD0?ooo`00o`3ooomD0?ooo`00o`3ooomD0?ooo`00203oool2
00000?l0oooo@03oool2000000P0oooo00080?ooo`030000003oool000000?l0oooo?P3oool00`00
0000oooo000000080?ooo`00203oool00`000000oooo0?ooo`0200000?l0oooo>P3oool200000080
oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`3o0?ooocH0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`00203o
ool00`000000oooo0?ooo`030?ooo`800000o`3ooold0?ooo`8000001@3oool00`000000oooo0?oo
o`060?ooo`00203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo<03oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool000P0oooo00<000000?ooo`3oool01`3oool200000?l0oooo;03oool2000000T0
oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`00203o
ool00`000000oooo0?ooo`0:0?ooo`800000o`3ooolV0?ooo`800000303oool00`000000oooo0?oo
o`060?ooo`00203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo8P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo
00d0oooo0P00003o0?ooob00oooo0P00000?0?ooo`030000003oool0oooo00H0oooo00080?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0403oool200000?l0oooo
6P3oool200000180oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`3o0?oooaH0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`060?ooo`00203oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0oooo503oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo
01@0oooo0P00003o0?oooa80oooo0P00000F0?ooo`030000003oool0oooo00H0oooo00080?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3oool>0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool05`3oool200000?l0oooo
303oool2000001T0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`3o0?ooo`P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`060?ooo`00203oool00`000000oooo0?ooo`0J0?ooo`800000o`3oool60?ooo`800000703oool0
0`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0?l0oooo0P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo00080?ooo`03
0000003oool0oooo01d0oooo0P00003o0?ooo`8000007`3oool00`000000oooo0?ooo`060?ooo`00
203oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?/0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0P0?ooo`800000n@3o
ool200000280oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`3e0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01P3oool0
00P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3c0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0903oool200000?40
oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0k@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00H0oooo
00080?ooo`030000003oool0oooo02L0oooo0P00003[0?ooo`800000:@3oool00`000000oooo0?oo
o`060?ooo`00203oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0>L0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0Z0?oo
o`800000i@3oool2000002`0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`3Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool01P3oool000P0oooo00<000000?ooo`3oool0;@3oool200000=l0oooo0P00000_0?ooo`030000
003oool0oooo00H0oooo00080?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0f`3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo00H0oooo00080?ooo`030000003oool0oooo0340oooo0P00003G0?ooo`800000<`3oool00`00
0000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0=<0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo
0?ooo`0d0?ooo`800000d@3oool2000003H0oooo00<000000?ooo`3oool01P3oool000P0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0=`3oool200000</0oooo0P00000i
0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool0a`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00H0oooo00080?ooo`03
0000003oool0oooo03X0oooo0P0000350?ooo`800000?03oool00`000000oooo0?ooo`060?ooo`00
203oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0m0?ooo`800000_`3o
ool2000003l0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`2k0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool01P3oool0
00P0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0@@3oool200000;L0
oooo0P0000130?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo04<0oooo
00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00H0oooo
00080?ooo`030000003oool0oooo04@0oooo0P00002a0?ooo`800000AP3oool00`000000oooo0?oo
o`060?ooo`00203oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0:d0oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`170?oo
o`800000Z`3oool2000004T0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool01P3oool000P0oooo00<000000?ooo`3oool0BP3oool200000:D0oooo0P00001<0?ooo`030000
003oool0oooo00H0oooo00080?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0X@3o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0
oooo04d0oooo0P00002O0?ooo`800000C`3oool00`000000oooo0?ooo`060?ooo`00203oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo09T0
oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo
0?ooo`1A0?ooo`800000U`3oool2000005<0oooo00<000000?ooo`3oool01P3oool000P0oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0E03oool200000940oooo0P00001F
0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00H0oooo00080?ooo`03
0000003oool0oooo05L0oooo0P00002;0?ooo`800000F@3oool00`000000oooo0?ooo`060?ooo`00
203oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`1J0?ooo`800000Q@3o
ool2000005`0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool01P3oool0
00P0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo
05d0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0GP3oool2000007d0
oooo0P00001P0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo0600oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00H0oooo
00080?ooo`030000003oool0oooo0640oooo0P00001g0?ooo`800000H`3oool00`000000oooo0?oo
o`060?ooo`00203oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo07<0oooo00<00000
0?ooo`3oool0H`3oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`1T0?oo
o`800000L@3oool2000006H0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3o
ool0IP3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3o
ool01P3oool000P0oooo00<000000?ooo`3oool0I`3oool2000006/0oooo0P00001Y0?ooo`030000
003oool0oooo00H0oooo00080?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0
oooo06X0oooo0P00001U0?ooo`800000K03oool00`000000oooo0?ooo`060?ooo`00203oool00`00
0000oooo0?ooo`1/0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0K03oool00`00
0000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo05l0
oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo
0?ooo`1^0?ooo`800000G@3oool200000700oooo00<000000?ooo`3oool01P3oool000P0oooo00<0
00000?ooo`3oool0L03oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0700oooo00<0
00000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0L@3oool2000005L0oooo0P00001c
0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00H0oooo00080?ooo`80
0000M@3oool200000540oooo0P00001e0?ooo`800000203oool000X0oooo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
203oool000/0oooo0P00001e0?ooo`800000B`3oool2000007D0oooo0P00000;0?ooo`003@3oool0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`0;0?ooo`003P3oool2000007D0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`1c0?ooo`8000003P3oool00100oooo00<000000?ooo`3oool0L`3oool2000004<0
oooo0P00001e0?ooo`030000003oool0oooo00h0oooo000A0?ooo`030000003oool0oooo07@0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00l0oooo
000B0?ooo`800000M@3oool2000003d0oooo0P00001e0?ooo`8000004P3oool001@0oooo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool04P3oool001D0oooo0P00001e0?ooo`800000=`3oool2000007D0oooo0P00000E0?oo
o`005`3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`0E0?ooo`00603oool2000007D0oooo0P00000a0?ooo`800000
M@3oool2000001P0oooo000J0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo01P0oooo000K0?ooo`800000M@3oool2
000002/0oooo0P00001e0?ooo`8000006`3oool001d0oooo00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool06`3oool001h0
oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo07@0
oooo00<000000?ooo`3oool0703oool001l0oooo0P00001e0?ooo`8000008`3oool2000007D0oooo
0P00000O0?ooo`008@3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`0O0?ooo`008P3oool2000007D0oooo0P00000M
0?ooo`800000M@3oool200000280oooo000T0?ooo`030000003oool0oooo07@0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0280oooo000U0?ooo`80
0000M@3oool2000001L0oooo0P00001e0?ooo`8000009@3oool002L0oooo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P00001e0?ooo`8000004@3oool2000007D0oooo0P00000X0?ooo`00:P3oool0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`0X0?ooo`00:`3oool2000007D0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1c0?ooo`800000:`3oool002d0oooo00<000000?ooo`3oool0L`3oool2000000T0
oooo0P00001e0?ooo`030000003oool0oooo02/0oooo000^0?ooo`030000003oool0oooo07@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo02`0oooo
000_0?ooo`800000M@3oool2000000<0oooo0P00001e0?ooo`800000;`3oool00340oooo00<00000
0?ooo`3oool0M03oool00`000000oooo0000001f0?ooo`030000003oool0oooo02l0oooo000b0?oo
o`800000M@3oool00`000000oooo0?ooo`1c0?ooo`800000<P3oool003@0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0380oooo000e0?ooo`800000
LP3oool00`000000oooo0?ooo`1`0?ooo`800000=@3oool003L0oooo00<000000?ooo`3oool0K`3o
ool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo03D0oooo000h0?ooo`800000K`3oool0
0`000000oooo0?ooo`1]0?ooo`800000>03oool003X0oooo00<000000?ooo`3oool0K03oool00`00
0000oooo0?ooo`1/0?ooo`030000003oool0oooo03P0oooo000k0?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0i0?ooo`00?03oool2000006/0oooo
00<000000?ooo`3oool0J@3oool2000003`0oooo000n0?ooo`030000003oool0oooo06P0oooo00<0
00000?ooo`3oool0J03oool00`000000oooo0?ooo`0l0?ooo`00?`3oool2000006P0oooo00<00000
0?ooo`3oool0IP3oool2000003l0oooo00110?ooo`030000003oool0oooo06D0oooo00<000000?oo
o`3oool0I@3oool00`000000oooo0?ooo`0o0?ooo`00@P3oool2000006D0oooo00<000000?ooo`3o
ool0H`3oool200000480oooo00140?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0
HP3oool00`000000oooo0?ooo`120?ooo`00A@3oool200000680oooo00<000000?ooo`3oool0H03o
ool2000004D0oooo00170?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0G`3oool0
0`000000oooo0?ooo`150?ooo`00B03oool2000005l0oooo00<000000?ooo`3oool0G@3oool20000
04P0oooo001:0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0G03oool00`000000
oooo0?ooo`180?ooo`00B`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool0B@3oool004`0oooo0P00001K0?ooo`030000003oool0oooo05T0oooo0P00
001<0?ooo`00CP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0C03oool004l0oooo0P00001H0?ooo`030000003oool0oooo05H0oooo0P00001?0?oo
o`00D@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3o
ool0C`3oool00580oooo0P00001E0?ooo`030000003oool0oooo05<0oooo0P00001B0?ooo`00E03o
ool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0DP3o
ool005D0oooo0P00001B0?ooo`030000003oool0oooo0500oooo0P00001E0?ooo`00E`3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0E@3oool005P0
oooo0P00001?0?ooo`030000003oool0oooo04d0oooo0P00001H0?ooo`00FP3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0F03oool005/0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo05T0oooo001L
0?ooo`800000B`3oool00`000000oooo0?ooo`190?ooo`800000G03oool005h0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo05`0oooo001O0?ooo`80
0000B03oool00`000000oooo0?ooo`160?ooo`800000G`3oool00640oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo05l0oooo001R0?ooo`800000A@3o
ool00`000000oooo0?ooo`130?ooo`800000HP3oool006@0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo0680oooo001U0?ooo`800000@P3oool00`00
0000oooo0?ooo`100?ooo`800000I@3oool006L0oooo00<000000?ooo`3oool0?`3oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo06D0oooo001X0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`1V0?ooo`00J@3oool2000003h0oooo00<0
00000?ooo`3oool0?03oool2000006T0oooo001[0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`1Y0?ooo`00K03oool2000003/0oooo00<000000?oo
o`3oool0>@3oool2000006`0oooo001^0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`1/0?ooo`00K`3oool2000003P0oooo00<000000?ooo`3oool0
=P3oool2000006l0oooo001a0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`1_0?ooo`00LP3oool2000003D0oooo00<000000?ooo`3oool0<`3oool2
00000780oooo001d0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`1b0?ooo`00M@3oool200000380oooo00<000000?ooo`3oool0<03oool2000007D0
oooo001g0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`1e0?ooo`00N03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0MP3oool007T0oooo0P00000^0?ooo`030000003oool0oooo02`0oooo0P00001i
0?ooo`00N`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0N@3oool007`0oooo0P00000[0?ooo`030000003oool0oooo02T0oooo0P00001l0?ooo`00
OP3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
O03oool007l0oooo0P00000X0?ooo`030000003oool0oooo02H0oooo0P00001o0?ooo`00P@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0O`3oool0
0880oooo0P00000U0?ooo`030000003oool0oooo02<0oooo0P0000220?ooo`00Q03oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0PP3oool008D0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo08<0oooo
00260?ooo`8000008@3oool00`000000oooo0?ooo`0O0?ooo`800000QP3oool008P0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo08H0oooo00290?oo
o`8000007P3oool00`000000oooo0?ooo`0L0?ooo`800000R@3oool008/0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo08T0oooo002<0?ooo`800000
6`3oool00`000000oooo0?ooo`0I0?ooo`800000S03oool008h0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo08`0oooo002?0?ooo`800000603oool0
0`000000oooo0?ooo`0F0?ooo`800000S`3oool00940oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo08l0oooo002B0?ooo`8000005@3oool00`000000
oooo0?ooo`0C0?ooo`800000TP3oool009@0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0980oooo002E0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`2C0?ooo`00UP3oool200000140oooo00<00000
0?ooo`3oool03`3oool2000009H0oooo002H0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`2F0?ooo`00V@3oool2000000h0oooo00<000000?ooo`3o
ool0303oool2000009T0oooo002K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`2I0?ooo`00W03oool2000000/0oooo00<000000?ooo`3oool02@3o
ool2000009`0oooo002N0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`2L0?ooo`00W`3oool2000000P0oooo00<000000?ooo`3oool01P3oool20000
09l0oooo002Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`2O0?ooo`00XP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0X03oool00:<0oooo0P0000040?ooo`030000003oool0oooo0080oooo0P00
002S0?ooo`00Y@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0X`3o
ool00:H0oooo0P0000000`3oool000000?ooo`0200000:H0oooo002X0?ooo`<00000Z03oool00:T0
oooo00<000000?ooo`3oool0Y`3oool00?l0ooooE03oool00?l0ooooE03oool00?l0ooooE03oool0
0?l0ooooE03oool00001\
\>"],
  ImageRangeCache->{{{0, 338.938}, {202.562, 0}} -> {-1.24791, -6.78833, \
0.148316, 0.148316}},
  CellTags->"Tracing through a FresnelRhomb"],

Cell[BoxData[
    TagBox[\(DrawSystem[{FresnelRhomb[
            10, {DefaultAngleSetting \[Rule] 55.4195168081208144`, 
              FullForm \[Rule] True}]}, PlotType \[Rule] TopView]\),
      HoldForm]], "Print",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[BoxData[
    \("-rendered unpropagated system-"\)], "Output",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowSystem[%];\)\)], "Input",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .64867 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.00611 -0.14588 1.00611 [
[ 0 0 0 0 ]
[ 1 .64867 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .64867 L
0 .64867 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.60935 .41025 m
.8548 .14797 L
s
.61291 .54206 m
.60935 .41025 L
s
.5199 .30953 m
.60935 .41025 L
s
.60935 .41025 m
.15456 .38198 L
s
.15456 .38198 m
.04099 .27838 L
s
.14275 .51473 m
.15456 .38198 L
s
.86812 .28747 m
.61291 .54206 L
s
.52049 .44455 m
.61291 .54206 L
s
.61291 .54206 m
.14275 .51473 L
s
.14275 .51473 m
.02452 .41433 L
s
.04099 .27838 m
.5199 .30953 L
s
.5199 .30953 m
.52049 .44455 L
s
.76696 .01882 m
.5199 .30953 L
s
.04099 .27838 m
.02452 .41433 L
s
.02452 .41433 m
.52049 .44455 L
s
.77754 .16129 m
.52049 .44455 L
s
.8548 .14797 m
.76696 .01882 L
s
.86812 .28747 m
.8548 .14797 L
s
.86812 .28747 m
.77754 .16129 L
s
.76696 .01882 m
.77754 .16129 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 186.812},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000^R000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00f`3oool0
0`000000oooo0?ooo`120?ooo`00f`3oool00`000000oooo0?ooo`120?ooo`00fP3oool3000004<0
oooo003I0?ooo`050000003oool000000?ooo`000000@P3oool00=P0oooo00H000000?ooo`3oool0
00000?ooo`0000120?ooo`00e`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0?`3oool00=H0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000100?oo
o`00eP3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000?`3oool00=D0
oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000003l0oooo003D0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0l0?ooo`00
d`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
>`3oool00=80oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo03/0oooo003A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0j0?ooo`00d03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0>@3oool00=00oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo03T0oooo003?0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0h0?ooo`00cP3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00<d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03H0oooo003<0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0f0?oo
o`00b`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0=@3oool00</0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo03@0oooo003:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0d0?ooo`00b@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0<`3oool00<P0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0380oooo00370?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0a0?ooo`00aP3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0<@3oool00<D0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0300oooo0035
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0_
0?ooo`00a03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0;`3oool00<<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo02h0oooo00320?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0]0?ooo`00`@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0;@3oool00<00oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02`0oooo00300?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0[0?ooo`00_`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0:P3oool00;h0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02X0oooo
002m0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0Y0?ooo`00_03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0:03oool00;/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo02P0oooo002k0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool04P3oool2000002X0oooo002j0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0000000Z0?ooo`00^@3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo0100oooo00@000000?ooo`3oool00000:P3oool00;P0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`000000:P3oool00;L0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0000000?0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0:03oool00;H0oooo00<000000?ooo`3oool0903oool01@000000oooo0?ooo`3o
ool0000000d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`00]@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo02L0oooo002e0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool09`3oool00;@0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0W0?ooo`00/`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02L0oooo
002b0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool00;40oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`000000303o
ool00`000000oooo0?ooo`0W0?ooo`00/03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`0W0?ooo`00/03oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00h0oooo0P00000>0?ooo`030000003oool0oooo
02L0oooo002_0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03`3oool2000000h0
oooo00<000000?ooo`3oool09`3oool00:h0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0>0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool09`3oool00:d0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`00
00003@3oool00`000000oooo0?ooo`0W0?ooo`00[03oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo02L0oooo002[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09`3o
ool00:/0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0V0?ooo`00ZP3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo02H0oooo002Y0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool09P3oool00:P0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0V0?ooo`00Y`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02H0oooo002V
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool09P3oool00:D0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0V0?ooo`00Y@3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo02H0oooo002T0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
9P3oool00:<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0V0?ooo`00XP3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo02H0oooo002Q0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool09P3oool00:00oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo01X0oooo00D000000?ooo`3oool0oooo0000000X0?oo
o`00X03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo002O0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0M0?ooo`050000
003oool0oooo0?ooo`0000009`3oool009h0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo01l0oooo00@000000?ooo`3oool000009`3oool000`0oooo
2@0000280?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0000002L0oooo000<0?ooo`030000003oool0000000H0oooo3`00
001h0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0000002L0oooo000<0?ooo`040000003oool0oooo000001@0oooo3`00
001X0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0S0?ooo`8000009`3oool000`0oooo00D000000?ooo`3oool0oooo0000000R0?ooo`l00000F03o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0U0?ooo`00303oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo02h0oooo400000180?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02H0oooo000;0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0?@3oool?000003P0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool09`3oool000/0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1;0?ooo`l00000:03oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0X0?ooo`002`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05T0oooo
3`00000H0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo02T0oooo000;0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0I`3oool?000000P0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0:P3oool000/0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`1e0?ooo`P000008`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0:`3oool000/0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02`0oooo000;0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0NP3oool200000200oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02d0oooo000;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0000000N0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0^0?ooo`002P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo07P0oooo00@000000?ooo`3oool00000
703oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
;`3oool000X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1g0?ooo`050000003o
ool0oooo0?ooo`0000006`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0<03oool000X0oooo00<000000?ooo`3oool03`3oool2000007L0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0a0?ooo`002P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0b
0?ooo`002P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0c0?ooo`002P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0780oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0d0?ooo`00
2P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0e0?ooo`002@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0700oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0f0?ooo`002@3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0g0?ooo`002@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
06h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0h0?ooo`002@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0i0?ooo`002@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo06`0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0j0?ooo`002@3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0k0?ooo`002@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo06X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0l0?ooo`002@3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo06T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0m0?oo
o`00203oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3o
ool03@3oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0?P3oool000P0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo00h0oooo0P00000?0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0?`3oool000P0oooo00<000000?ooo`3oool08@3oool900000600oooo00<000000?ooo`3oool0
3P3oool2000000h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`100?ooo`00203o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo4000001@0?ooo`030000003o
ool0oooo00d0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo0440oooo00080?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool05P3o
oolA000003l0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000/0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`120?ooo`00203oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo02L0oooo4000000_0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0@`3oool000P0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0g
0?oooa0000007`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04@0oooo00080?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0A`3oool@000000l0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`150?ooo`001`3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo05L0oooo4@0000090?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3o
ool0oooo0000000V0?ooo`030000003oool0oooo04H0oooo00070?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0I`3oool00`000000oooo0000000?000000H0oooo00<000000?ooo`00
00009P3oool00`000000oooo0?ooo`170?ooo`001`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`P00000
9P3oool00`000000oooo0?ooo`180?ooo`001`3oool9000001/0oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`190?ooo`002@3oool00`000000oooo0?ooo`040?oooa0000002`3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo04X0oooo000:0?ooo`030000003oool0oooo
01<0oooo3`00001V0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo04/0oooo000;0?ooo`030000003oool0oooo01d0
oooo00@000000?ooo`3oool0oooo4000001F0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo04`0oooo000<0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool04@3oool@000004H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool0C@3oool000d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0Q0?oooa000000
=P3oool01@000000oooo0?ooo`3oool0000001@0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`1>0?ooo`003P3oool2000001/0oooo00<000000?ooo`3oool0<@3oool@000002H0oooo
00@000000?ooo`3oool000005@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04l0
oooo000@0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0@@3oool?000001L0oooo
00<000000?ooo`0000005P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0500oooo
000A0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0D03oool@000000L0oooo0P00
000G0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0D@3oool00180oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`1P0?ooo`P00000603oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo0580oooo000C0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0D`3oool001@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1Y0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1D0?ooo`00
5@3oool2000001<0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0E@3oool001L0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`1F0?ooo`00603oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo06`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo05L0oooo000I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0F03oool001X0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1I0?ooo`006`3oool2000000d0oooo
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0FP3oool001d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`1K0?ooo`007P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0740oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05`0oooo000O0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0G@3oool00200oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`1N0?ooo`008@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo07@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo05l0oooo000R0?ooo`8000001P3oool00`000000oooo0?ooo`1e0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1P0?ooo`00903oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0640oooo000U0?ooo`050000003oool0oooo
0?ooo`000000N@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0HP3oool002H0oooo00@000000?ooo`3oool00000NP3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0H`3oool002L0oooo00<000000?oo
o`000000N`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0I03oool002P0oooo0P00001l0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`1U0?ooo`00:@3oool9000007D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06H0oooo000b0?oooa400000I@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0I`3o
ool004<0oooo4@00001E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`1X0?ooo`00E03ooolA000004D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo06T0oooo001U0?oooa000000=P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0JP3oool007D0oooo4@00000V0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0J`3oool008H0oooo4@00000F0?ooo`05
0000003oool000000?ooo`000000KP3oool009L0oooo4@0000060?ooo`<00000K`3oool00:P0oooo
2000001`0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {185.812, 0}} -> {-0.000956555, 0.144991, \
0.00346983, 0.00346983}},
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[
\t{SingleRay[Polarization->{1,1,0}, IntrinsicMedium->Vacuum],
\tMove[FresnelRhomb[10, FullForm->True],10],
\tBoundary[75]},
\tPlotType->TopView, ThresholdIntensity->10];
MatrixForm[ReadRays[sys,{Intensity,RayTilt,Polarization}]]\
\>", "Input",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0126984 0.5 0.0126984 [
[.45412 .38479 -36 -4.5 ]
[.45412 .38479 36 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.15079 .57712 m
.15079 .42288 L
.15079 .42288 L
.15079 .57712 L
.15079 .57712 L
s
.45412 .78622 m
.15079 .57712 L
.15079 .57712 L
.45412 .78622 L
.45412 .78622 L
s
.45412 .63198 m
.15079 .42288 L
.15079 .42288 L
.45412 .63198 L
.45412 .63198 L
s
.15079 .57712 m
.15079 .42288 L
.45412 .63198 L
.45412 .78622 L
.15079 .57712 L
s
.15079 .57712 m
.15079 .42288 L
.45412 .63198 L
.45412 .78622 L
.15079 .57712 L
s
.75745 .57712 m
.45412 .78622 L
.45412 .78622 L
.75745 .57712 L
.75745 .57712 L
s
.75745 .42288 m
.45412 .63198 L
.45412 .63198 L
.75745 .42288 L
.75745 .42288 L
s
.75745 .42288 m
.75745 .57712 L
.75745 .57712 L
.75745 .42288 L
.75745 .42288 L
s
.45412 .63198 m
.45412 .78622 L
.75745 .57712 L
.75745 .42288 L
.45412 .63198 L
s
.45412 .63198 m
.45412 .78622 L
.75745 .57712 L
.75745 .42288 L
.45412 .63198 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.15079 .5 m
.26266 .5 L
s
0 0 0 r
2 Mabswid
.26266 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.26266 .5 m
.34225 .7091 L
s
0 0 0 r
2 Mabswid
.34225 .7091 Mdot
.039 .916 .04 r
.5 Mabswid
.34225 .7091 m
.56599 .7091 L
s
0 0 0 r
2 Mabswid
.56599 .7091 Mdot
.039 .916 .04 r
.5 Mabswid
.56599 .7091 m
.64558 .5 L
s
0 0 0 r
2 Mabswid
.64558 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.64558 .5 m
.75745 .5 L
s
0 0 0 r
2 Mabswid
.75745 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.75745 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(FresnelRhomb)] .45412 .38479 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->True,
  ImageSize->{201.812, 201.812},
  ImageMargins->{{43, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000390000bB000`400?l00000o`00003ob@3oool0
0<T0oooo00390?ooo`00b@3oool000@0oooo`@0000040?ooo`00103oool00`000000oooo0?ooo`2m
0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo0;d0oooo00<000000?oo
o`3oool00P3oool000@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`00
103oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003o
ool0oooo0;d0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0_@3oool0
0`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo
0080oooo00040?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool00P3oool000@0oooo
00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?oo
o`2m0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo0;d0oooo00<00000
0?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?oo
o`00103oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0080oooo00040?ooo`030000
003oool0oooo0;d0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0_@3o
ool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`2m0?ooo`030000003oool0
oooo0080oooo00040?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool00P3oool000@0
oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo
0?ooo`2m0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo0;d0oooo00<0
00000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`02
0?ooo`00103oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0080oooo00040?ooo`03
0000003oool0oooo0;d0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0
_@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`2m0?ooo`030000003o
ool0oooo0080oooo00040?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool00P3oool0
00@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000
oooo0?ooo`2m0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo0;d0oooo
00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?oo
o`020?ooo`00103oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0080oooo00040?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3o
ool0_@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`2m0?ooo`030000
003oool0oooo0080oooo00040?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool00P3o
ool000@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`00103oool00`00
0000oooo0?ooo`2m0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo0;d0
oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo
0?ooo`020?ooo`00103oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0080oooo0004
0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?oo
o`3oool0_@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`2m0?ooo`03
0000003oool0oooo0080oooo00040?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0
0P3oool000@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`00103oool0
0`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo
0;d0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0_@3oool00`000000
oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0080oooo
00040?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool00P3oool000@0oooo00<00000
0?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`2m0?oo
o`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3o
ool00P3oool000@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`00103o
ool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0
oooo0;d0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0_@3oool00`00
0000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0080
oooo00040?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool00P3oool000@0oooo00<0
00000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`2m
0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo0;d0oooo00<000000?oo
o`3oool00P3oool000@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`00
103oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003o
ool0oooo0;d0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0_@3oool0
0`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo
0080oooo00040?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool00P3oool000@0oooo
00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?oo
o`2m0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo03H0oooo0`000004
0?ooo`80000000@0oooo000000000000oooo0`0000020?ooo`050000003oool000000000003oool0
0P0000020?ooo`D000000P3oool2000000030?ooo`000000oooo0080000000@0oooo000000000000
00000P3oool010000000oooo0000003oool200000080oooo0`00001=0?ooo`030000003oool0oooo
0080oooo00040?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`030000003oool0
00000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`00001<0?ooo`030000003o
ool0oooo0080oooo00040?ooo`030000003oool0oooo03L0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo00000003000000030?ooo`00000000000080oooo00@000000?ooo`000000oooo
100000020?ooo`030000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo
0?ooo`00001<0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo03L0oooo
100000020?ooo`030000003oool000000080oooo0P0000040?ooo`050000003oool000000?ooo`00
00000P3oool01@000000oooo0?ooo`000000oooo00@000000`3oool01@000000oooo0000003oool0
000000<0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool0
0000C03oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0g0?ooo`050000
003oool0oooo0000003oool00`0000000`3oool00000000000020?ooo`H000000`3oool2000000<0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`02000000<0oooo0`0000000`3oool0
000000000003000000@0oooo0`00001=0?ooo`030000003oool0oooo0080oooo00040?ooo`030000
003oool0oooo03L0oooo00D000000?ooo`3oool0oooo0000000F0?ooo`030000003oool0000000<0
oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
0080oooo00040?ooo`030000003oool0oooo03H0oooo1P00000E0?ooo`L000000P3oool200000100
oooo0P00001?0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo0;d0oooo
00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?oo
o`020?ooo`00103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0G0?oo
o`800000M`3oool2000002/0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0000001e0?ooo`030000003oool0000002/0oooo00<000000?ooo`3o
ool00P3oool000@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0200000740oooo
0P0000020?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool00P3oool000@0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo0004
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00`3oool2000006/0oooo0P000005
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00040?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`00
103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00L0oooo0P00001S0?ooo`800000
2@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1O0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`00103oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00X0oooo0P00001M0?ooo`800000303oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00d0oooo0P00001G0?ooo`8000003`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo0100oooo0P00001A0?ooo`8000004P3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`00103ooolI00WZ2P0300000009jPX02NX:
01D02NX:00<000000?ooo`3oool0B@3ooolF00WZ2P0300000009jPX02NX:02T02NX:0P0000040?oo
o`00103oool00`000000oooo0?ooo`0F0?ooo`8000005@3oool00`09jPX00000000000190?ooo`<0
0000503oool2000002X0oooo0P0000040?ooo`00103oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo01@0oooo00<02NX:0?ooo`000000A`3oool00`0000002NX:0?ooo`0F0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo00800000@`3oool2000000030?ooo`09
jPX0oooo01H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`00103oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01@0oooo00<02NX:0?ooo`3oool00P3oool0
0`000000oooo0?ooo`0o0?ooo`050000003oool0oooo0?ooo`09jPX05`3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`020?ooo`800000?@3oool2000000<0oooo00<02NX:
0?ooo`3oool05P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00040?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool05@3oool00`09jPX0oooo0?ooo`040?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0F0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00D0oooo0P00000g0?ooo`80
00001P3oool00`09jPX0oooo0?ooo`0F0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool00P3oool000@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`0300WZ
2P3oool0oooo00H0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`050?ooo`0300WZ
2P3oool0oooo01L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`00103o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01H0oooo00<02NX:0?ooo`3oool01`3o
ool200000340oooo0P0000080?ooo`0300WZ2P3oool0oooo01L0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo01L0oooo00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00L0oooo00<02NX:0?ooo`3oool0603oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo0080oooo00040?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05`3oool00`09
jPX0oooo0?ooo`090?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0203oool00`09
jPX0oooo0?ooo`0H0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool00P3oool000@0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo00X0
oooo0P00000Y0?ooo`8000002`3oool00`09jPX0oooo0?ooo`0H0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0H0?ooo`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0:0?ooo`0300WZ2P3oool0oooo01T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01P0oooo00<0
2NX:0?ooo`3oool0303oool2000002<0oooo0P00000=0?ooo`0300WZ2P3oool0oooo01T0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo01T0oooo00<02NX:0?ooo`3oool03@3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00`0oooo00<02NX:0?ooo`3oool06P3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo01L0oooo0P00000J0?oo
o`0300WZ2P3oool0oooo00h0oooo0P00000M0?ooo`8000003`3oool00`09jPX0oooo0?ooo`0I0?oo
o`800000:`3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo01L0oooo00<02NX:0?ooo`3oool0403oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00l0oooo00<02NX:0?ooo`3oool0603oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo0080oooo00040?ooo`030000003oool0oooo01X0oooo0P00000H0?ooo`0300WZ
2P3oool0oooo0100oooo0P00000G0?ooo`8000004@3oool00`09jPX0oooo0?ooo`0G0?ooo`800000
;P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01D0oooo00<02NX:0?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo0140oooo00<02NX:0?ooo`3oool05P3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo0080oooo00040?ooo`030000003oool0oooo01d0oooo0P00000E0?ooo`0300WZ2P3oool0
oooo01<0oooo0P00000A0?ooo`800000503oool00`09jPX0oooo0?ooo`0D0?ooo`800000<@3oool0
0`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
01<0oooo00<02NX:0?ooo`3oool0503oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
01<0oooo00<02NX:0?ooo`3oool0503oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
0080oooo00040?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool04P3oool00`09jPX0
oooo0?ooo`0E0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0503oool00`09jPX0
oooo0?ooo`0C0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool00P3oool000@0oooo
00<000000?ooo`3oool08@3oool2000001<0oooo00<02NX:0?ooo`3oool05@3oool2000000T0oooo
0P00000F0?ooo`0300WZ2P3oool0oooo0180oooo0P00000e0?ooo`030000003oool0oooo0080oooo
00040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0403oool00`09jPX0oooo0?oo
o`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05P3oool00`09jPX0oooo0?oo
o`0A0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool00P3oool000@0oooo00<00000
0?ooo`3oool0903oool200000100oooo00<02NX:0?ooo`3oool0603oool2000000<0oooo0P00000I
0?ooo`0300WZ2P3oool0oooo00l0oooo0P00000h0?ooo`030000003oool0oooo0080oooo00040?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0I0?oo
o`<000006P3oool00`09jPX0oooo0?ooo`0?0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool00P3oool000@0oooo00<000000?ooo`3oool09`3oool2000000h0oooo00<02NX:0?ooo`3o
ool06P3oool00`000000oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo00d0oooo0P00000k0?ooo`03
0000003oool0oooo0080oooo00040?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<02NX:0?ooo`3oool0
303oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003o
ool0oooo02X0oooo0P00000<0?ooo`0300WZ2P3oool0oooo01T0oooo00<000000?ooo`3oool0603o
ool00`09jPX0oooo0?ooo`0;0?ooo`800000?P3oool00`000000oooo0?ooo`020?ooo`00103oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo00<02NX:0?ooo`3oool06@3oool0
0`000000oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo00X0oooo00<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0]0?ooo`8000002P3oool00`09
jPX0oooo0?ooo`0H0?ooo`030000003oool0oooo01L0oooo00<02NX:0?ooo`3oool02@3oool20000
0440oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`070?ooo`0300WZ2P3oool0oooo01P0oooo00<000000?ooo`3oool05`3oool00`09jPX0
oooo0?ooo`080?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool00P3oool000@0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01P0oooo
00<000000?ooo`3oool05`3oool00`09jPX0oooo0?ooo`070?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0<@3oool2000000L0oooo00<0
2NX:0?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo00H0oooo0P00
00150?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0G0?ooo`030000003oool0oooo01H0oooo00<02NX:
0?ooo`3oool01@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0080oooo00040?oo
o`030000003oool0oooo03@0oooo0P0000050?ooo`0300WZ2P3oool0oooo01H0oooo00<000000?oo
o`3oool05@3oool00`09jPX0oooo0?ooo`040?ooo`800000B03oool00`000000oooo0?ooo`020?oo
o`00103oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo00<02NX:0?ooo`3o
ool05P3oool00`000000oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00<0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0g0?ooo`800000
0P3oool00`09jPX0oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00@02NX:0?ooo`3oool0
oooo0P00001;0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo03T0oooo
00@000000?ooo`3oool02NX:5`3oool00`000000oooo0?ooo`0D0?ooo`0500WZ2P3oool0oooo0?oo
o`000000C@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0j0?ooo`80
000000<02NX:0?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`0400WZ2P3oool000000000
04h0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0?03oool00`09jPX0
oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo00<02NX:0000003oool0C`3oool00`000000
oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0m0?ooobh02NX:00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0m0?ooo`<00000503o
ool00`000000oooo0?ooo`0B0?ooo`<00000D@3oool00`000000oooo0?ooo`020?ooo`00103oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo
0440oooo0P00000A0?ooo`030000003oool0oooo00l0oooo0P00001E0?ooo`030000003oool0oooo
0080oooo00040?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool00P3oool000@0oooo
00<000000?ooo`3oool0A03oool2000000h0oooo00<000000?ooo`3oool0303oool2000005P0oooo
00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`020?ooo`00103oool00`000000oooo0?ooo`170?ooo`8000002`3oool00`000000oooo0?ooo`09
0?ooo`800000F`3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo04X0oooo0P0000080?ooo`03
0000003oool0oooo00H0oooo0P00001N0?ooo`030000003oool0oooo0080oooo00040?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0G`3o
ool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`1>0?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`800000HP3oool00`000000oooo0?ooo`020?ooo`00103oool00`00
0000oooo0?ooo`1@0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`1R
0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo0540oooo0P0000000`3o
ool000000?ooo`02000006D0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3o
ool0D`3oool3000006L0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003o
ool0oooo0;d0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0_@3oool0
0`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo
0080oooo00040?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool00P3oool000@0oooo
00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?oo
o`2m0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo0;d0oooo00<00000
0?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?oo
o`00103oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0080oooo00040?ooo`030000
003oool0oooo0;d0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0_@3o
ool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`2m0?ooo`030000003oool0
oooo0080oooo00040?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool00P3oool000@0
oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo
0?ooo`2m0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo0;d0oooo00<0
00000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`02
0?ooo`00103oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0080oooo00040?ooo`03
0000003oool0oooo0;d0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0
_@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`2m0?ooo`030000003o
ool0oooo0080oooo00040?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool00P3oool0
00@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000
oooo0?ooo`2m0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo0;d0oooo
00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?oo
o`020?ooo`00103oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0080oooo00040?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3o
ool0_@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`2m0?ooo`030000
003oool0oooo0080oooo00040?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool00P3o
ool000@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`00103oool00`00
0000oooo0?ooo`2m0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo0;d0
oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo
0?ooo`020?ooo`00103oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0080oooo0004
0?ooo`800000_P3oool00`000000oooo0?ooo`020?ooo`00103oooo1000000@0oooo00390?ooo`00
b@3oool00<T0oooo00390?ooo`00\
\>"],
  ImageRangeCache->{{{0, 200.812}, {200.812, 0}} -> {-1.87539, -39.3754, \
0.392161, 0.392161}},
  CellTags->{
  "Cell marked at {1999, 7, 1, 16, 44, 47}", "Tracing through a FresnelRhomb"}
    ],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {
              StyleBox["100.`",
                StyleBoxAutoDelete->True,
                PrintPrecision->16], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0", ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0"}], "}"}]},
            {
              StyleBox["95.7488562654227237`",
                StyleBoxAutoDelete->True,
                PrintPrecision->16], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0", ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.707106781186547728`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547728`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0"}], "}"}]},
            {"95.7488562654227237`", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.355743744081200485`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.934583537489875482`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.707106781186547461`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547461`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["45.0000000000000266`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}]},
            {"95.7488562654227237`", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0", ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.707106781186547728`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547461`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["90.0000000000000532`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}]},
            {"95.7488562654227237`", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.355743744081200485`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  RowBox[{"-", 
                    StyleBox["0.934583537489875482`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->16]}], ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.707106781186547728`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547372`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["135.000000000000097`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}]},
            {"95.7488562654227237`", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0", ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.707106781186547728`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547195`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["180.000000000000142`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}]},
            {
              StyleBox["91.6784347613658034`",
                StyleBoxAutoDelete->True,
                PrintPrecision->16], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0", ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.707106781186547728`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547195`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  RowBox[{"-", 
                    StyleBox["179.999999999999849`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->16]}]}], "}"}]}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[
\t{SingleRay[Polarization->{1,1,0}, IntrinsicMedium->Vacuum],
\tMove[FresnelRhomb[10, FullForm->True, SurfaceSeparation->2],10],
\tBoundary[75]},
\tPlotType->TopView, ThresholdIntensity->10];
MatrixForm[ReadRays[sys,{Intensity,RayTilt,Polarization}]]\
\>", "Input",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0126984 0.5 0.0126984 [
[.45412 .38479 -36 -4.5 ]
[.45412 .38479 36 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.15079 .57712 m
.15079 .42288 L
.15079 .42288 L
.15079 .57712 L
.15079 .57712 L
s
.45412 .78622 m
.15079 .57712 L
.15079 .57712 L
.45412 .78622 L
.45412 .78622 L
s
.45412 .63198 m
.15079 .42288 L
.15079 .42288 L
.45412 .63198 L
.45412 .63198 L
s
.45412 .78622 m
.45412 .63198 L
.45412 .63198 L
.45412 .78622 L
.45412 .78622 L
s
.15079 .57712 m
.15079 .42288 L
.45412 .63198 L
.45412 .78622 L
.15079 .57712 L
s
.15079 .57712 m
.15079 .42288 L
.45412 .63198 L
.45412 .78622 L
.15079 .57712 L
s
.47952 .63198 m
.47952 .78622 L
.47952 .78622 L
.47952 .63198 L
.47952 .63198 L
s
.78285 .57712 m
.47952 .78622 L
.47952 .78622 L
.78285 .57712 L
.78285 .57712 L
s
.78285 .42288 m
.47952 .63198 L
.47952 .63198 L
.78285 .42288 L
.78285 .42288 L
s
.78285 .42288 m
.78285 .57712 L
.78285 .57712 L
.78285 .42288 L
.78285 .42288 L
s
.47952 .63198 m
.47952 .78622 L
.78285 .57712 L
.78285 .42288 L
.47952 .63198 L
s
.47952 .63198 m
.47952 .78622 L
.78285 .57712 L
.78285 .42288 L
.47952 .63198 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.15079 .5 m
.26266 .5 L
s
0 0 0 r
2 Mabswid
.26266 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.26266 .5 m
.34225 .7091 L
s
0 0 0 r
2 Mabswid
.34225 .7091 Mdot
.039 .916 .04 r
.5 Mabswid
.34225 .7091 m
.45412 .7091 L
s
0 0 0 r
2 Mabswid
.45412 .7091 Mdot
.039 .916 .04 r
.5 Mabswid
.45412 .7091 m
.47952 .7091 L
s
0 0 0 r
2 Mabswid
.47952 .7091 Mdot
.039 .916 .04 r
.5 Mabswid
.47952 .7091 m
.59139 .7091 L
s
0 0 0 r
2 Mabswid
.59139 .7091 Mdot
.039 .916 .04 r
.5 Mabswid
.59139 .7091 m
.67098 .5 L
s
0 0 0 r
2 Mabswid
.67098 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.67098 .5 m
.78285 .5 L
s
0 0 0 r
2 Mabswid
.78285 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.78285 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(FresnelRhomb)] .45412 .38479 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1K0?ooo`<00000103oool2000000040?ooo`00
000000000?ooo`<000000P3oool01@000000oooo000000000000oooo008000000P3oool500000080
oooo0P0000000`3oool000000?ooo`02000000040?ooo`000000000000000080oooo00@000000?oo
o`000000oooo0P0000020?ooo`<00000NP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`1L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001P3oool01`00
0000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00@000000?ooo`3oool00000N@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`1L0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`000000
0`0000000`3oool00000000000020?ooo`040000003oool000000?ooo`@000000P3oool00`000000
oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool00000N@3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1L0?ooo`@000000P3oool00`000000
oooo000000020?ooo`800000103oool01@000000oooo0000003oool000000080oooo00D000000?oo
o`3oool000000?ooo`04000000<0oooo00D000000?ooo`000000oooo000000030?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000007T0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0G03oool01@000000oooo0?ooo`000000oooo
00<0000000<0oooo0000000000000P3oool6000000<0oooo0P0000030?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool00P0000030?ooo`<0000000<0oooo0000000000000`0000040?oo
o`<00000NP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1L0?ooo`05
0000003oool0oooo0?ooo`0000005P3oool00`000000oooo000000030?ooo`040000003oool0oooo
00000140oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`1K0?ooo`H000005@3oool700000080oooo0P00000@0?ooo`800000O03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0R0?ooo`800000
/P3oool2000003L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0000002`0?ooo`030000003oool0000003L0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0200000:`0oooo0P000002
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0:P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool00`3oool200000:H0oooo0P0000050?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2P0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo0P00002N0?ooo`8000002@3oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00X0oooo0P00002H0?ooo`800000303oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00d0oooo0P00002B0?ooo`8000003`3oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo0100oooo0P00002<0?ooo`8000004P3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0D0?ooo`800000Q03oool2000001H0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0G0?ooo`800000OP3oool2000001T0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0J0?ooo`800000N03oool2000001`0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0Q0?ooo`8000007P3oool2000007@0oooo0P00
000N0?ooo`800000=@3oool2000000L0oooo00060?ooob@02NX:00<0000000WZ2P09jPX07@09jPX0
0`0000002NX:0000001b0?ooo`0300000009jPX02NX:05D02NX:0P0000070?ooo`001P3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo01d0oooo00<02NX:0?ooo`000000L03oool00`00
0000oooo00WZ2P0O0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0N0?ooo`0400WZ2P3oool000000000
06`0oooo0P0000000`3oool02NX:0?ooo`0O0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0N0?ooo`05
00WZ2P3oool0oooo0?ooo`000000JP3oool01@000000oooo0?ooo`3oool02NX:0200oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo01h0oooo00<02NX:0?ooo`3oool00P3oool00`000000oooo0?ooo`1V0?oo
o`030000003oool0oooo0080oooo00<02NX:0?ooo`3oool07P3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool07`3oool00`09jPX0oooo0?ooo`020?ooo`800000I03oool2000000@0oooo00<02NX:0?ooo`3o
ool07`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`040?ooo`030000
003oool0oooo0600oooo00<000000?ooo`3oool0103oool00`09jPX0oooo0?ooo`0O0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo00D0oooo0P00001N0?ooo`8000001`3o
ool00`09jPX0oooo0?ooo`0O0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0P0?ooo`0300WZ2P3oool0
oooo00H0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`060?ooo`0300WZ2P3oool0
oooo0200oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo0200oooo00<02NX:0?ooo`3oool01`3oool20000
05P0oooo0P0000090?ooo`0300WZ2P3oool0oooo0200oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0240
oooo00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00P0
oooo00<02NX:0?ooo`3oool08@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08@3oool00`09jPX0oooo
0?ooo`090?ooo`800000DP3oool2000000/0oooo00<02NX:0?ooo`3oool08@3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool08@3oool00`09jPX0oooo0?ooo`0;0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0Q0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0R
0?ooo`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0;
0?ooo`0300WZ2P3oool0oooo0280oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<02NX:0?oo
o`3oool0303oool2000004X0oooo0P00000>0?ooo`0300WZ2P3oool0oooo0280oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo02<0oooo00<02NX:0?ooo`3oool03@3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo00d0oooo00<02NX:0?ooo`3oool08`3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
8`3oool00`09jPX0oooo0?ooo`0>0?ooo`800000A03oool200000100oooo00<02NX:0?ooo`3oool0
8`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool08`3oool00`09jPX0oooo0?ooo`0@0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0403oool00`09jPX0oooo0?ooo`0S0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0T0?ooo`0300WZ2P3oool0oooo0100oooo0P00000n0?ooo`8000004P3oool0
0`09jPX0oooo0?ooo`0T0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0T0?ooo`0300WZ2P3oool0oooo
0180oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo
02@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo02@0oooo00<02NX:0?ooo`3oool04`3oool2000003P0
oooo0P00000E0?ooo`0300WZ2P3oool0oooo02@0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02D0oooo
00<02NX:0?ooo`3oool0503oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01@0oooo
00<02NX:0?ooo`3oool09@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0280oooo0P00000V0?ooo`0300WZ2P3oool0oooo01D0oooo0P00
000b0?ooo`8000005`3oool00`09jPX0oooo0?ooo`0T0?ooo`800000=`3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02@0oooo00<02NX:
0?ooo`3oool05P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01H0oooo00<02NX:
0?ooo`3oool0903oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo02D0oooo0P00000T0?ooo`0300WZ2P3oool0oooo01L0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo0280oooo0P00000j0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool08@3oool00`09jPX0oooo0?ooo`0H0?ooo`800000:P3oool2000001X0oooo00<02NX:0?ooo`3o
ool08@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo02P0oooo0P00000R0?ooo`0300WZ2P3oool0oooo01T0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo0200oooo0P00000m0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool07`3o
ool00`09jPX0oooo0?ooo`0J0?ooo`800000903oool2000001`0oooo00<02NX:0?ooo`3oool07`3o
ool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0K0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool06`3oool00`09jPX0oooo0?ooo`0O0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0;03oool20000
01l0oooo00<02NX:0?ooo`3oool0703oool2000001h0oooo0P00000N0?ooo`0300WZ2P3oool0oooo
01d0oooo0P0000110?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0703oool00`09jPX0oooo0?ooo`0N0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool07P3oool00`09jPX0oooo0?ooo`0L0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0;`3oool2000001d0oooo
00<02NX:0?ooo`3oool07P3oool2000001P0oooo0P00000P0?ooo`0300WZ2P3oool0oooo01/0oooo
0P0000140?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool06P3oool00`09jPX0oooo0?ooo`0P0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0803oool00`09jPX0oooo0?ooo`0J0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0<P3oool2000001X0oooo00<02NX:
0?ooo`3oool08@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0240oooo00<02NX:
0?ooo`3oool0603oool2000004L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo0240oooo0P00000@0?oo
o`8000008`3oool00`09jPX0oooo0?ooo`0H0?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0=@3oool2000001P0oooo00<02NX:0?ooo`3o
ool08`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02<0oooo00<02NX:0?ooo`3o
ool05P3oool2000004X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo02<0oooo0P00000:0?ooo`800000
9@3oool00`09jPX0oooo0?ooo`0F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0E0?ooo`0300WZ2P3o
ool0oooo02D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0U0?ooo`0300WZ2P3o
ool0oooo01D0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`0i0?ooo`8000005@3oool00`09jPX0oooo0?ooo`0V0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool09P3oool00`09jPX0oooo0?ooo`0C0?ooo`800000CP3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
01<0oooo00<02NX:0?ooo`3oool09@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
02D0oooo00<02NX:0?ooo`3oool04`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo03`0oooo0P00000C0?ooo`0300WZ2P3oool0oooo02D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0U0?ooo`0300WZ2P3oool0oooo0140
oooo0P00001A0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0T0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0903oool00`09jPX0oooo0?ooo`0A0?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0?`3oool200000140oooo00<0
2NX:0?ooo`3oool0903oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02@0oooo00<0
2NX:0?ooo`3oool03`3oool2000005@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo02@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0T0?ooo`0300WZ2P3oool0oooo00h0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`120?oo
o`8000003`3oool00`09jPX0oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool08`3oool00`09jPX0oooo0?ooo`0=0?ooo`800000E`3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00`0oooo00<02NX:0?ooo`3o
ool08`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<02NX:0?ooo`3o
ool0303oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo04D0oooo0P00000<0?ooo`0300WZ2P3oool0oooo02<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0S0?ooo`0300WZ2P3oool0oooo00X0oooo0P00001J0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool02P3o
ool00`09jPX0oooo0?ooo`0R0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08P3o
ool00`09jPX0oooo0?ooo`0:0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`090?ooo`0300WZ2P3oool0
oooo0280oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`0300WZ2P3oool0
oooo00T0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`190?ooo`8000002P3oool00`09jPX0oooo0?ooo`0Q0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool08@3oool00`09jPX0oooo0?ooo`080?ooo`800000GP3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00L0
oooo00<02NX:0?ooo`3oool08@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0240
oooo00<02NX:0?ooo`3oool01`3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo04`0oooo0P0000070?ooo`0300WZ2P3oool0oooo0240oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`0300WZ2P3oool0oooo00D0oooo
0P00001Q0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0P0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0803oool00`09jPX0oooo0?ooo`050?ooo`030000003oool0oooo0640oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0C`3oool2000000D0oooo00<02NX:
0?ooo`3oool0803oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0200oooo00<02NX:
0?ooo`3oool00`3oool2000006@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01l0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo00<0oooo00<000000?oo
o`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1B0?ooo`80
00000`3oool00`09jPX0oooo0?ooo`0O0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool07`3oool01009jPX0oooo0?ooo`3oool2000006L0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0E03oool010000000oooo0?ooo`09jPXQ0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool07`3oool01009jPX0oooo0?ooo`00001Y0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo05D0oooo00@000000?ooo`3oool02NX:803oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo01h0oooo00@02NX:0?ooo`3oool00000JP3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1F0?ooo`80000000<02NX:
0?ooo`3oool07P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01h0oooo00<02NX:
000000000000J`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1H0?oo
o`0300WZ2P3oool0oooo01h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0N0?oo
o`0300WZ2P3oool0oooo06/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0F03oool00`0000002NX:00WZ2P0M00WZ2P0300000009jPX02NX:02H02NX:00<000000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1H0?ooo`800000
00<0oooo0000003oool06`3oool2000000H0oooo0P00000L0?ooo`040000003oool00000000006d0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0G03oool2000001/0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`800000L@3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0G`3oool2000001P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0F0?ooo`800000M03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo07@0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0HP3oool2000001D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0C0?ooo`800000M`3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo06H0oooo0P00000A0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool03`3oool2000007/0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo06T0oooo0P00000>0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0303oool2000007h0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo06`0oooo0P00000;0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02@3oool200000840oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0KP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo06l0oooo0P0000080?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01P3oool2000008@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0L@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0780oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`1c0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo0P0000280?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo07D0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`000000
RP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1f0?ooo`80000000<0
oooo0000003oool01@3oool010000000oooo00000000002;0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo07P0oooo0P0000060?ooo`800000S@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0S03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`800000o`3ooolA0?ooo`030000003o
ool0oooo00D0oooo00060?ooool00000500000070?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.87539, -39.3754, 0.274393, \
0.274393}},
  CellTags->"Tracing through a FresnelRhomb"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", 
              StyleBox["100.`",
                StyleBoxAutoDelete->True,
                PrintPrecision->16], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}]},
            {"2", 
              StyleBox["95.7488562654227237`",
                StyleBoxAutoDelete->True,
                PrintPrecision->16], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0", ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.707106781186547728`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547728`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0"}], "}"}]},
            {"3", "95.7488562654227237`", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.355743744081200485`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.934583537489875482`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.707106781186547461`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547461`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["45.0000000000000266`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}]},
            {"4", "95.7488562654227237`", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0", ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.707106781186547728`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547461`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["90.0000000000000532`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}]},
            {"5", 
              StyleBox["91.6784347613658212`",
                StyleBoxAutoDelete->True,
                PrintPrecision->16], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0", ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.70710678118654755`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547461`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["90.0000000000000532`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}]},
            {"6", 
              StyleBox["87.7810527260495021`",
                StyleBoxAutoDelete->True,
                PrintPrecision->16], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0", ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.70710678118654755`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547461`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["90.0000000000000532`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}]},
            {"7", "87.7810527260495021`", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.355743744081200485`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  RowBox[{"-", 
                    StyleBox["0.934583537489875482`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->16]}], ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.707106781186547372`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547372`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["135.000000000000097`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}]},
            {"8", "87.7810527260495021`", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0", ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.707106781186547372`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547372`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["180.000000000000142`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}]},
            {"9", 
              StyleBox["84.0493540029400776`",
                StyleBoxAutoDelete->True,
                PrintPrecision->16], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0", ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.707106781186547372`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547372`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  RowBox[{"-", 
                    StyleBox["179.999999999999849`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->16]}]}], "}"}]}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FresnelRhomb[10]", "Input",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[BoxData[
    TagBox[\(FresnelRhomb[
        10, {DefaultAngleSetting \[Rule] 55.2183200192534417`}]\),
      HoldForm]], "Output",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DrawSystem[\ FresnelRhomb[10], PlotType -> TopView]\)], "Input",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.19782 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0398701 0.270647 0.0398701 [
[ 0 0 0 0 ]
[ 1 1.19782 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .51277 m
.02381 .02852 L
.02381 .02852 L
.02381 .51277 L
.02381 .51277 L
s
.97619 .68504 m
.02381 .02852 L
.02381 .02852 L
.97619 .68504 L
.97619 .68504 L
s
.97619 1.1693 m
.97619 .68504 L
.97619 .68504 L
.97619 1.1693 L
.97619 1.1693 L
s
.97619 1.1693 m
.02381 .51277 L
.02381 .51277 L
.97619 1.1693 L
.97619 1.1693 L
s
.02381 .51277 m
.02381 .02852 L
.97619 .68504 L
.97619 1.1693 L
.02381 .51277 L
s
.02381 .51277 m
.02381 .02852 L
.97619 .68504 L
.97619 1.1693 L
.02381 .51277 L
s
0 0 m
1 0 L
1 1.19782 L
0 1.19782 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{176.375, 211.312},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002`0000db000`400?l00000o`00003o/03oool0
0;00oooo002`0?ooo`00/03oool00;00oooo00040?ooo`800000ZP3oool000@0oooo00<000000?oo
o`000000Z@3oool000@0oooo00<000000?ooo`3oool00P00002W0?ooo`00103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0:@0oooo00040?ooo`030000003oool0oooo00<0oooo0P00
002T0?ooo`00103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0:40oooo00040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0X03oool000@0oooo00<000000?ooo`3o
ool01`3oool200000:00oooo00040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
W@3oool000@0oooo00<000000?ooo`3oool02P3oool2000009d0oooo00040?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0VP3oool000@0oooo00<000000?ooo`3oool03@3oool20000
09X0oooo00040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0U`3oool000@0oooo
00<000000?ooo`3oool0403oool2000009L0oooo00040?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0U03oool000@0oooo00<000000?ooo`3oool04`3oool2000009@0oooo00040?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0T@3oool000@0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`2@0?ooo`00103oool00`000000oooo0?ooo`0G0?ooo`800000
T03oool000@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`2=0?ooo`00103oool0
0`000000oooo0?ooo`0J0?ooo`800000S@3oool000@0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`2:0?ooo`00103oool00`000000oooo0?ooo`0M0?ooo`800000RP3oool000@0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`270?ooo`00103oool00`000000oooo0?oo
o`0P0?ooo`800000Q`3oool000@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`24
0?ooo`00103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo08<0oooo00040?ooo`03
0000003oool0oooo02@0oooo0P0000230?ooo`00103oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo0800oooo00040?ooo`030000003oool0oooo02L0oooo0P0000200?ooo`00103oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo07d0oooo00040?ooo`030000003oool0oooo
02X0oooo0P00001m0?ooo`00103oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo07X0
oooo00040?ooo`030000003oool0oooo02d0oooo0P00001j0?ooo`00103oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo07L0oooo00040?ooo`030000003oool0oooo0300oooo0P00001g
0?ooo`00103oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo07@0oooo00040?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool0L`3oool000@0oooo00<000000?ooo`3oool0
=03oool2000007<0oooo00040?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0L03o
ool000@0oooo00<000000?ooo`3oool0=`3oool200000700oooo00040?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool0K@3oool000@0oooo00<000000?ooo`3oool0>P3oool2000006d0
oooo00040?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0JP3oool000@0oooo00<0
00000?ooo`3oool0?@3oool2000006X0oooo00040?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool0I`3oool000@0oooo00<000000?ooo`3oool0@03oool2000006L0oooo00040?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0I03oool000@0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`1S0?ooo`00103oool00`000000oooo0?ooo`140?ooo`800000H`3o
ool000@0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1P0?ooo`00103oool00`00
0000oooo0?ooo`170?ooo`800000H03oool000@0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`1M0?ooo`00103oool00`000000oooo0?ooo`1:0?ooo`800000G@3oool000@0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`1J0?ooo`00103oool00`000000oooo0?ooo`1=
0?ooo`800000FP3oool000@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1G0?oo
o`00103oool00`000000oooo0?ooo`1@0?ooo`800000E`3oool000@0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`1D0?ooo`00103oool00`000000oooo0?ooo`1C0?ooo`030000003o
ool0oooo05<0oooo00040?ooo`030000003oool0oooo05@0oooo0P00001C0?ooo`00103oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0500oooo00040?ooo`030000003oool0oooo05L0
oooo0P00001@0?ooo`00103oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo04d0oooo
00040?ooo`030000003oool0oooo05X0oooo0P00001=0?ooo`00103oool00`000000oooo0?ooo`1L
0?ooo`030000003oool0oooo04X0oooo00040?ooo`030000003oool0oooo05d0oooo0P00001:0?oo
o`00103oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo04L0oooo00040?ooo`030000
003oool0oooo0600oooo00<000000?ooo`3oool0AP3oool000@0oooo00<000000?ooo`3oool0H@3o
ool2000004H0oooo00040?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0@`3oool0
00@0oooo00<000000?ooo`3oool0I03oool2000004<0oooo00040?ooo`030000003oool0oooo06H0
oooo00<000000?ooo`3oool0@03oool000@0oooo00<000000?ooo`3oool0I`3oool200000400oooo
00040?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0?@3oool000@0oooo00<00000
0?ooo`3oool0JP3oool2000003d0oooo00040?ooo`030000003oool0oooo06`0oooo00<000000?oo
o`3oool0>P3oool000@0oooo00<000000?ooo`3oool0K@3oool2000003X0oooo00040?ooo`030000
003oool0oooo06l0oooo00<000000?ooo`3oool0=`3oool000@0oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`0f0?ooo`00103oool00`000000oooo0?ooo`1a0?ooo`800000=P3oool0
00@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0c0?ooo`00103oool00`000000
oooo0?ooo`1d0?ooo`800000<`3oool000@0oooo00<000000?ooo`3oool0MP3oool00`000000oooo
0?ooo`0`0?ooo`00103oool00`000000oooo0?ooo`1g0?ooo`800000<03oool000@0oooo0P00001j
0?ooo`030000003oool0oooo02d0oooo00060?ooo`030000003oool0oooo07P0oooo0P00000]0?oo
o`001`3oool2000007X0oooo00<000000?ooo`3oool0:P3oool000T0oooo00<000000?ooo`3oool0
N03oool2000002X0oooo000:0?ooo`800000NP3oool00`000000oooo0?ooo`0W0?ooo`00303oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo02H0oooo000=0?ooo`030000003oool0oooo
07P0oooo0P00000V0?ooo`003P3oool2000007X0oooo00<000000?ooo`3oool08`3oool00100oooo
00<000000?ooo`3oool0N03oool2000002<0oooo000A0?ooo`800000NP3oool00`000000oooo0?oo
o`0P0?ooo`004`3oool00`000000oooo0?ooo`1h0?ooo`800000803oool001@0oooo0P00001j0?oo
o`030000003oool0oooo01d0oooo000F0?ooo`030000003oool0oooo07P0oooo0P00000M0?ooo`00
5`3oool2000007X0oooo00<000000?ooo`3oool06P3oool001T0oooo00<000000?ooo`3oool0N03o
ool00`000000oooo0?ooo`0I0?ooo`006P3oool2000007T0oooo0P00000I0?ooo`00703oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo01H0oooo000M0?ooo`030000003oool0oooo07P0
oooo0P00000F0?ooo`007P3oool2000007X0oooo00<000000?ooo`3oool04`3oool00200oooo00<0
00000?ooo`3oool0N03oool2000001<0oooo000Q0?ooo`800000NP3oool00`000000oooo0?ooo`0@
0?ooo`008`3oool00`000000oooo0?ooo`1h0?ooo`800000403oool002@0oooo0P00001j0?ooo`03
0000003oool0oooo00d0oooo000V0?ooo`030000003oool0oooo07P0oooo0P00000=0?ooo`009`3o
ool2000007X0oooo00<000000?ooo`3oool02P3oool002T0oooo00<000000?ooo`3oool0N03oool0
0`000000oooo0?ooo`090?ooo`00:P3oool00`000000oooo0?ooo`1h0?ooo`8000002@3oool002/0
oooo0P00001j0?ooo`030000003oool0oooo00H0oooo000]0?ooo`030000003oool0oooo07P0oooo
0P0000060?ooo`00;P3oool2000007X0oooo00<000000?ooo`3oool00`3oool00300oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`020?ooo`00<@3oool2000007P0oooo00<000000?oo
o`3oool00P3oool003<0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`020?ooo`00
=03oool2000007D0oooo00<000000?ooo`3oool00P3oool003H0oooo00<000000?ooo`3oool0LP3o
ool00`000000oooo0?ooo`020?ooo`00=`3oool200000780oooo00<000000?ooo`3oool00P3oool0
03T0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`020?ooo`00>P3oool00`000000
oooo0?ooo`1^0?ooo`030000003oool0oooo0080oooo000k0?ooo`800000KP3oool00`000000oooo
0?ooo`020?ooo`00?@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0080oooo000n
0?ooo`800000J`3oool00`000000oooo0?ooo`020?ooo`00@03oool00`000000oooo0?ooo`1X0?oo
o`030000003oool0oooo0080oooo00110?ooo`800000J03oool00`000000oooo0?ooo`020?ooo`00
@`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0080oooo00140?ooo`800000I@3o
ool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0
oooo0080oooo00170?ooo`800000HP3oool00`000000oooo0?ooo`020?ooo`00B@3oool00`000000
oooo0?ooo`1O0?ooo`030000003oool0oooo0080oooo001:0?ooo`030000003oool0oooo05h0oooo
00<000000?ooo`3oool00P3oool004/0oooo0P00001N0?ooo`030000003oool0oooo0080oooo001=
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool004h0oooo0P00001K0?oo
o`030000003oool0oooo0080oooo001@0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool00P3oool00540oooo0P00001H0?ooo`030000003oool0oooo0080oooo001C0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool00P3oool005@0oooo0P00001E0?ooo`030000003oool0
oooo0080oooo001F0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool00P3oool005L0
oooo0P00001B0?ooo`030000003oool0oooo0080oooo001I0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool00P3oool005X0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`020?ooo`00F`3oool2000004h0oooo00<000000?ooo`3oool00P3oool005d0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`020?ooo`00GP3oool2000004/0oooo00<000000?ooo`3o
ool00P3oool00600oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`020?ooo`00H@3o
ool2000004P0oooo00<000000?ooo`3oool00P3oool006<0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`020?ooo`00I03oool2000004D0oooo00<000000?ooo`3oool00P3oool006H0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`020?ooo`00I`3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo0080oooo001X0?ooo`800000@@3oool00`000000oooo0?oo
o`020?ooo`00JP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0080oooo001[0?oo
o`800000?P3oool00`000000oooo0?ooo`020?ooo`00K@3oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo0080oooo001^0?ooo`800000>`3oool00`000000oooo0?ooo`020?ooo`00L03o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo001a0?ooo`800000>03oool0
0`000000oooo0?ooo`020?ooo`00L`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
0080oooo001d0?ooo`800000=@3oool00`000000oooo0?ooo`020?ooo`00MP3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0080oooo001g0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool00P3oool007P0oooo0P00000a0?ooo`030000003oool0oooo0080oooo001j0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool007/0oooo0P00000^0?ooo`03
0000003oool0oooo0080oooo001m0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
0P3oool007h0oooo0P00000[0?ooo`030000003oool0oooo0080oooo00200?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool00P3oool00840oooo0P00000X0?ooo`030000003oool0oooo
0080oooo00230?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool00P3oool008@0oooo
0P00000U0?ooo`030000003oool0oooo0080oooo00260?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool00P3oool008L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`02
0?ooo`00R03oool200000240oooo00<000000?ooo`3oool00P3oool008X0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`020?ooo`00R`3oool2000001h0oooo00<000000?ooo`3oool0
0P3oool008d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`020?ooo`00SP3oool2
000001/0oooo00<000000?ooo`3oool00P3oool00900oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`020?ooo`00T@3oool2000001P0oooo00<000000?ooo`3oool00P3oool009<0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`00U03oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo0080oooo002E0?ooo`800000503oool00`000000oooo0?ooo`02
0?ooo`00U`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo002H0?ooo`80
00004@3oool00`000000oooo0?ooo`020?ooo`00VP3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0080oooo002K0?ooo`8000003P3oool00`000000oooo0?ooo`020?ooo`00W@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo002N0?ooo`8000002`3oool00`00
0000oooo0?ooo`020?ooo`00X03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080
oooo002Q0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`00X`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo002T0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool00:D0oooo0P0000040?ooo`030000003oool0oooo0080oooo002W0?ooo`05
0000003oool0oooo0?ooo`000000103oool00:P0oooo0P0000000`3oool000000?ooo`030?ooo`00
ZP3oool2000000@0oooo002[0?ooo`030000003oool0oooo0080oooo002`0?ooo`00/03oool00;00
oooo002`0?ooo`00/03oool00001\
\>"],
  ImageRangeCache->{{{0, 175.375}, {210.312, 0}} -> {-0.597302, -6.80588, \
0.143018, 0.143018}},
  CellTags->"Tracing through a FresnelRhomb"],

Cell[BoxData[
    TagBox[\(DrawSystem[{FresnelRhomb[
            10, {DefaultAngleSetting \[Rule] 55.4195168081208144`}]}, 
        PlotType \[Rule] TopView]\),
      HoldForm]], "Print",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[BoxData[
    \("-rendered unpropagated system-"\)], "Output",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[
\t{SingleRay[Polarization->{1,1,0}, IntrinsicMedium->Vacuum],
\tMove[FresnelRhomb[10],10],
\tBoundary[50]},
\tPlotType->TopView, ThresholdIntensity->10];
MatrixForm[ReadRays[sys,{Intensity,RayTilt,Polarization}]]\
\>", "Input",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.5 0.0190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.21429 .61567 m
.21429 .38433 L
.21429 .38433 L
.21429 .61567 L
.21429 .61567 L
s
.66928 .92932 m
.66928 .69798 L
.66928 .69798 L
.66928 .92932 L
.66928 .92932 L
s
.66928 .92932 m
.21429 .61567 L
.21429 .61567 L
.66928 .92932 L
.66928 .92932 L
s
.66928 .69798 m
.21429 .38433 L
.21429 .38433 L
.66928 .69798 L
.66928 .69798 L
s
.21429 .61567 m
.21429 .38433 L
.66928 .69798 L
.66928 .92932 L
.21429 .61567 L
s
.21429 .61567 m
.21429 .38433 L
.66928 .69798 L
.66928 .92932 L
.21429 .61567 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .5 m
.38209 .5 L
s
0 0 0 r
2 Mabswid
.38209 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.38209 .5 m
.50148 .81365 L
s
0 0 0 r
2 Mabswid
.50148 .81365 Mdot
.039 .916 .04 r
.5 Mabswid
.50148 .81365 m
.66928 .81365 L
s
0 0 0 r
2 Mabswid
.66928 .81365 Mdot
.039 .916 .04 r
.5 Mabswid
.66928 .81365 m
.97619 .81365 L
s
0 0 0 r
2 Mabswid
.97619 .81365 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{287.875, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004O00017b000`400?l00000o`00003oo`3ooolP
0?ooo`00o`3ooolP0?ooo`00o`3ooolP0?ooo`00o`3ooolP0?ooo`00o`3ooolP0?ooo`00o`3ooolP
0?ooo`001P3ooooo000001@000001P3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0
oooo03@0oooo0P00003I0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`000000f03oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo00800000eP3oool00`000000oooo0?ooo`040?ooo`00
1P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
d`3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo00<0oooo0P00003C0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo00@0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`3?0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool01`3oool200000<l0oooo00<000000?ooo`3oool0103oool000H0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0<`0oooo
00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0:0?ooo`800000c03oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`04
0?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00d0oooo0P0000390?oo
o`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00@0oooo00060?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0403oool200000<H0oooo00<000000?ooo`3oool0
103oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0C0?ooo`800000``3oool00`000000oooo0?ooo`040?ooo`001P3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0`03oool00`00
0000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo01L0oooo0P00002o0?ooo`030000003oool0oooo00@0oooo
00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`2l0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool06P3oool200000;`0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0;T0oooo00<000000?oo
o`3oool0103oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`80
0000^@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`040?ooo`001P3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo0P00002f0?ooo`030000003o
ool0oooo00@0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`2c0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool08`3oool200000;<0oooo00<000000?ooo`3oool0103oool000H0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0;00
oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0103oool000H0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0W0?ooo`800000[`3oool00`000000oooo0?oo
o`040?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0[03oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo02X0oooo0P00002/0?ooo`030000003oool0oooo00@0oooo00060?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`2Y0?ooo`03
0000003oool0oooo00@0oooo00060?ooocH02NX:00<0000000WZ2P09jPX0;`09jPX00`000000oooo
0?ooo`2W0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo03<0oooo0P00
000_0?ooo`0300WZ2P00000000000:P0oooo00<000000?ooo`3oool0103oool000H0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0^0?ooo`0400WZ2P3oool0000000000:H0oooo00<0
00000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0^
0?ooo`0500WZ2P3oool0oooo0?ooo`000000Y@3oool00`000000oooo0?ooo`040?ooo`001P3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02h0oooo00<02NX:0?ooo`3oool00P3oool2
00000:<0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0_0?ooo`0300WZ2P3oool0oooo00<0oooo00<000000?ooo`3oool0X03oool00`00
0000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02l0
oooo00<02NX:0?ooo`3oool0103oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo00@0
oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0;`3oool00`09jPX0oooo
0?ooo`050?ooo`800000W`3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0300oooo00<02NX:0?ooo`3oool01P3oool00`000000oooo0?oo
o`2L0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0<03oool00`09jPX0oooo0?ooo`070?ooo`800000W03oool00`000000oooo0?ooo`04
0?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0340oooo00<02NX:0?oo
o`3oool0203oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00@0oooo00060?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0<@3oool00`09jPX0oooo0?ooo`090?ooo`80
0000V@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo0340oooo00<02NX:0?ooo`3oool02`3oool00`000000oooo0?ooo`2F0?ooo`030000
003oool0oooo00@0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0<P3o
ool00`09jPX0oooo0?ooo`0;0?ooo`800000UP3oool00`000000oooo0?ooo`040?ooo`001P3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0380oooo00<02NX:0?ooo`3oool03@3oool0
0`000000oooo0?ooo`2C0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0<P3oool00`09jPX0oooo0?ooo`0>0?ooo`800000T`3oool00`00
0000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03<0
oooo00<02NX:0?ooo`3oool03`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0
oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`09jPX0oooo
0?ooo`0@0?ooo`800000T03oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo03@0oooo00<02NX:0?ooo`3oool04@3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0=03oool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0d0?oo
o`0300WZ2P3oool0oooo01<0oooo0P00002<0?ooo`030000003oool0oooo00@0oooo00060?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0=@3oool00`09jPX0oooo0?ooo`0D0?ooo`03
0000003oool0oooo08T0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0e0?ooo`0300WZ2P3oool0oooo01D0oooo0P0000290?ooo`030000
003oool0oooo00@0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=P3o
ool00`09jPX0oooo0?ooo`0F0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0103o
ool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0f0?ooo`0300WZ2P3oool0
oooo01L0oooo0P0000260?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0=P3oool00`09jPX0oooo0?ooo`0I0?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0g0?ooo`0300WZ2P3oool0oooo01T0oooo0P0000230?ooo`030000003oool0oooo00@0
oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`09jPX0oooo
0?ooo`0K0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0103oool000H0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`0300WZ2P3oool0oooo01`0oooo0P00
00200?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0>03oool00`09jPX0oooo0?ooo`0M0?ooo`030000003oool0oooo07d0oooo00<00000
0?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0h0?oo
o`0300WZ2P3oool0oooo01h0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`040?oo
o`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03T0oooo00<02NX:0?ooo`3o
ool07P3oool2000007`0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0i0?ooo`0300WZ2P3oool0oooo0200oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`800000>P3o
ool00`09jPX0oooo0?ooo`0Q0?ooo`800000N@3oool00`000000oooo0?ooo`040?ooo`001P3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03P0oooo00<02NX:0?ooo`3oool08P3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo
03L0oooo0P00000h0?ooo`0300WZ2P3oool0oooo02<0oooo0P00001f0?ooo`030000003oool0oooo
00@0oooo00060?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0=@3oool00`09jPX0
oooo0?ooo`0U0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0103oool000H0oooo
00<000000?ooo`3oool0>P3oool2000003H0oooo00<02NX:0?ooo`3oool09@3oool2000007<0oooo
00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0c0?ooo`0300WZ2P3oool0oooo02L0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?oo
o`040?ooo`001P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03<0oooo00<02NX:
0?ooo`3oool09`3oool200000700oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?oo
o`3oool0?P3oool2000003<0oooo00<02NX:0?ooo`3oool0:@3oool00`000000oooo0?ooo`1]0?oo
o`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool0<03oool00`09jPX0oooo0?ooo`0Z0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3o
ool0103oool000H0oooo00<000000?ooo`3oool0@@3oool200000340oooo00<02NX:0?ooo`3oool0
:P3oool2000006`0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`0^0?ooo`0300WZ2P3oool0oooo02`0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`140?ooo`800000;P3oool0
0`09jPX0oooo0?ooo`0]0?ooo`800000J@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo02`0oooo00<02NX:0?ooo`3oool0;P3oool00`00
0000oooo0?ooo`1V0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo04L0
oooo0P00000/0?ooo`0300WZ2P3oool0oooo02l0oooo0P00001V0?ooo`030000003oool0oooo00@0
oooo00060?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0:P3oool00`09jPX0oooo
0?ooo`0`0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0103oool000H0oooo00<0
00000?ooo`3oool0BP3oool2000002X0oooo00<02NX:0?ooo`3oool0<@3oool2000006<0oooo00<0
00000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0W
0?ooo`0300WZ2P3oool0oooo03<0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`04
0?ooo`001P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo02L0oooo00<02NX:0?oo
o`3oool0<`3oool200000600oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3o
ool0CP3oool2000002L0oooo00<02NX:0?ooo`3oool0=@3oool00`000000oooo0?ooo`1M0?ooo`03
0000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
903oool00`09jPX0oooo0?ooo`0f0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
103oool000H0oooo00<000000?ooo`3oool0D@3oool2000002D0oooo00<02NX:0?ooo`3oool0=P3o
ool2000005`0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo03P0oooo00<000000?ooo`3oool0F@3oool0
0`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`1D0?ooo`8000008`3oool00`09
jPX0oooo0?ooo`0h0?ooo`800000F@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo0200oooo00<02NX:0?ooo`3oool0>P3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo05L0oooo
0P00000P0?ooo`0300WZ2P3oool0oooo03/0oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01h0oooo00<0
2NX:0?ooo`3oool0>P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00@0oooo0006
0?ooo`030000003oool0oooo05X0oooo0P00000N0?ooo`0300WZ2P3oool0oooo03X0oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`1L0?oo
o`030000003oool0oooo01/0oooo00<02NX:0?ooo`3oool0>P3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3o
ool06`3oool00`09jPX0oooo0?ooo`0i0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3o
ool0103oool000H0oooo00<000000?ooo`3oool0GP3oool2000001/0oooo00<02NX:0?ooo`3oool0
>@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003o
ool0oooo0600oooo00<000000?ooo`3oool06@3oool00`09jPX0oooo0?ooo`0h0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0H@3oool2
000001T0oooo00<02NX:0?ooo`3oool0>03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0
oooo00@0oooo00060?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool05P3oool00`09
jPX0oooo0?ooo`0h0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0103oool000H0
oooo00<000000?ooo`3oool0I03oool2000001L0oooo00<02NX:0?ooo`3oool0=`3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo06H0oooo
00<000000?ooo`3oool0503oool00`09jPX0oooo0?ooo`0g0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0I`3oool2000001D0oooo00<0
2NX:0?ooo`3oool0=P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00@0oooo0006
0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0f
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?oo
o`3oool0JP3oool200000180oooo00<02NX:0?ooo`3oool0=P3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3o
ool0403oool00`09jPX0oooo0?ooo`0e0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3o
ool0103oool000H0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0?0?ooo`0300WZ
2P3oool0oooo03D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`040?ooo`001P3o
ool00`000000oooo0?ooo`1^0?ooo`8000003`3oool00`09jPX0oooo0?ooo`0e0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0L03oool0
0`000000oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo03@0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`1a0?ooo`8000003@3oool00`09
jPX0oooo0?ooo`0d0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0103oool000H0
oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo03<0
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo
0?ooo`1d0?ooo`8000002`3oool00`09jPX0oooo0?ooo`0c0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?oo
o`080?ooo`0300WZ2P3oool0oooo03<0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`040?ooo`001P3oool00`000000oooo0?ooo`1g0?ooo`8000002@3oool00`09jPX0oooo0?ooo`0b
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`060?ooo`0300WZ2P3oool0oooo0380oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`1j0?ooo`80
00001P3oool00`09jPX0oooo0?ooo`0b0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3o
ool0103oool000H0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo0340oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`040?ooo`001P3o
ool00`000000oooo0?ooo`1m0?ooo`800000103oool00`09jPX0oooo0?ooo`0a0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0O`3oool0
0`000000oooo0?ooo`020?ooo`0300WZ2P3oool0oooo0300oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`200?ooo`050000003oool0oooo
0?ooo`09jPX0<P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00@0oooo00060?oo
o`030000003oool0oooo0840oooo0P0000000`3oool02NX:0?ooo`0a0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0P`3oool00`000000
oooo00WZ2P0a0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0103oool000H0oooo
00<000000?ooo`3oool0Q03oool00`0000002NX:0?ooo`0`0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0Q@3oool00`09jPX000000?oo
o`0_0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0103oool000H0oooo00<00000
0?ooo`3oool0QP3oool`00WZ2P0300000009jPX02NX:05D02NX:0P0000060?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`80000000<0oooo0000003oool0:`3oool2000005H0oooo0P0000060?oo
o`001P3oool00`000000oooo0?ooo`2:0?ooo`800000:`3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003o
ool0oooo08d0oooo0P00000X0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0103o
ool000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0103oool000H0
oooo00<000000?ooo`3oool0T@3oool2000002@0oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?oo
o`2D0?ooo`8000008@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00@0oooo0006
0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1E
0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo09L0oooo0P00000N0?oo
o`030000003oool0oooo05D0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3o
ool0V@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3o
ool0103oool000H0oooo00<000000?ooo`3oool0VP3oool2000001/0oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`2L0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`040?ooo`001P3oool0
0`000000oooo0?ooo`2M0?ooo`800000603oool00`000000oooo0?ooo`1E0?ooo`030000003oool0
oooo00@0oooo00060?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0:00
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00@0
oooo00060?ooo`030000003oool0oooo0:40oooo0P00000D0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0103oool000H0oooo00<00000
0?ooo`3oool0Y03oool200000140oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`04
0?ooo`001P3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`2W0?ooo`80
00003P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000
003oool0oooo0:T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1E0?ooo`030000
003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0:X0oooo0P00000;0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0[03oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0103oool0
00H0oooo00<000000?ooo`3oool0[@3oool2000000P0oooo00<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo
0?ooo`2`0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`2a0?ooo`800000103oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0;<0oooo00D00000
0?ooo`3oool0oooo0000001G0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0
oooo0;@0oooo0P0000000`3oool000000?ooo`1F0?ooo`030000003oool0oooo00@0oooo00060?oo
o`030000003oool0oooo0;H0oooo0P00001G0?ooo`030000003oool0oooo00@0oooo00060?ooo`03
0000003oool0oooo0;L0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`040?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`040?ooo`001P3oool200000?l0oooo4@3oool00`000000oooo0?ooo`04
0?ooo`001P3ooooo000001@000001P3oool00?l0oooo803oool00?l0oooo803oool00?l0oooo803o
ool00?l0oooo803oool00?l0oooo803oool00?l0oooo803oool00001\
\>"],
  ImageRangeCache->{{{0, 286.875}, {286.875, 0}} -> {-1.25026, -26.2503, \
0.183009, 0.183009}},
  CellTags->"Tracing through a FresnelRhomb"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", 
              StyleBox["100.`",
                StyleBoxAutoDelete->True,
                PrintPrecision->16], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}]},
            {"2", 
              StyleBox["95.7488562654227237`",
                StyleBoxAutoDelete->True,
                PrintPrecision->16], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0", ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.707106781186547728`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547728`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0"}], "}"}]},
            {"3", "95.7488562654227237`", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.355743744081200485`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.934583537489875482`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.707106781186547461`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547461`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["45.0000000000000266`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}]},
            {"4", "95.7488562654227237`", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0", ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.707106781186547728`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547461`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["90.0000000000000532`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}]},
            {"5", 
              StyleBox["91.6784347613658212`",
                StyleBoxAutoDelete->True,
                PrintPrecision->16], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0", ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.70710678118654755`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547461`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["90.0000000000000532`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}]}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{

Cell["?SpectralRegion", "Input",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[BoxData[
    \("SpectralRegion is the name of an option that specifies either two or \
three wavelength values, and is used in calculations of the Abbe V-number \
(AbbeVNumber) and the relative partial dispersion (PartialDispersionRatio) of \
an optical material. \n\nThe SpectralRegion wavelength values are \
conventionally chosen for the nominal visible range by the F-d-C spectral \
lines of hydrogen, helium, and hydrogen: .4861, .5876, and .6563 microns. \
However, SpectralRegion can also specify other parts of the spectrum as well. \
Usually the SpectralRegion option need only specify the lower and upper \
wavelength bounds and the middle wavelength is automatically determined later \
to keep the same relative fraction with the traditional values. Otherwise, \
all three wavelength values can be specified. See also: GlassMap, \
FindGlassNumbers, GlassCodeFunction, AbbeVNumber, MeanDispersion, and \
PartialDispersionRatio."\)], "Print",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[
\t{SingleRay[Polarization->{1,1,0},WaveLength->.588],
\tMove[FresnelRhomb[10,{DefaultAngleSetting\[Rule]54.7}],10],
\tBoundary[50]},
\tPlotType->TopView, ThresholdIntensity->10];
MatrixForm[ReadRays[sys,{Intensity,RayTilt,Polarization}]]\
\>", "Input",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.5 0.0190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.21429 .61669 m
.21429 .38331 L
.21429 .38331 L
.21429 .61669 L
.21429 .61669 L
s
.6534 .9276 m
.6534 .69422 L
.6534 .69422 L
.6534 .9276 L
.6534 .9276 L
s
.6534 .9276 m
.21429 .61669 L
.21429 .61669 L
.6534 .9276 L
.6534 .9276 L
s
.6534 .69422 m
.21429 .38331 L
.21429 .38331 L
.6534 .69422 L
.6534 .69422 L
s
.21429 .61669 m
.21429 .38331 L
.6534 .69422 L
.6534 .9276 L
.21429 .61669 L
s
.21429 .61669 m
.21429 .38331 L
.6534 .69422 L
.6534 .9276 L
.21429 .61669 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.939 .845 .017 r
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.939 .845 .017 r
.5 Mabswid
.21429 .5 m
.3791 .5 L
s
0 0 0 r
2 Mabswid
.3791 .5 Mdot
.939 .845 .017 r
.5 Mabswid
.3791 .5 m
.48859 .81091 L
s
0 0 0 r
2 Mabswid
.48859 .81091 Mdot
.939 .845 .017 r
.5 Mabswid
.48859 .81091 m
.6534 .81091 L
s
0 0 0 r
2 Mabswid
.6534 .81091 Mdot
.939 .845 .017 r
.5 Mabswid
.6534 .81091 m
.97619 .81091 L
s
0 0 0 r
2 Mabswid
.97619 .81091 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3H0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo0P00003I0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`000000f03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00800000
eP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0dP3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
00@0oooo0P00003B0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool01`3oool200000<l0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0</0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?oo
o`800000b`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00h0oooo0P0000380?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool04@3oool200000<D0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
0<80oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0E0?ooo`800000`@3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0_P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo01P0oooo0P00002n0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`2k0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0703oool200000;X0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo0;L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0O0?ooo`800000]`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0]03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0280
oooo0P00002d0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`2`0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool09P3oool200000;00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0:d0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Y0?ooo`80
0000[@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`800000
;03oool300000:X0oooo00<000000?ooo`3oool01@3oool000H0ooooI`3`f0@00`000000oooo0?oo
o`2X0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0;03oool00`3`f0@000000000002Y0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0;@3oool00`3`f0@0oooo0000002X0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0;@3oool00`3`f0@0oooo0?ooo`0200000:H0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0]0?ooo`030?3H103oool0oooo0080oooo
00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo02h0oooo00<0l=P40?ooo`3oool00P3oool200000:<0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0^
0?ooo`030?3H103oool0oooo00@0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02h0oooo00<0l=P40?oo
o`3oool01@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0;`3oool00`3`f0@0oooo0?ooo`050?ooo`80
0000W`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo02l0oooo00<0l=P40?ooo`3oool01`3oool00`000000oooo0?ooo`2L0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0;`3o
ool00`3`f0@0oooo0?ooo`080?ooo`800000W03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0300oooo00<0l=P40?ooo`3oool02@3oool0
0`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0<03oool00`3`f0@0oooo0?ooo`0:0?ooo`030000003oool0oooo
09P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0`0?ooo`030?3H103oool0oooo00/0oooo0P00002H0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0<@3oool00`3`f0@0oooo
0?ooo`0<0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0a0?ooo`030?3H103oool0oooo00d0oooo0P00
002E0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0<P3oool00`3`f0@0oooo0?ooo`0>0?ooo`030000003oool0oooo0980oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0b0?oo
o`030?3H103oool0oooo00l0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0380oooo00<0l=P40?ooo`3o
ool0403oool200000940oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0c0?ooo`030?3H103oool0oooo0140oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo03<0oooo00<0l=P40?ooo`3oool04P3oool2000008h0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030?3H103oool0
oooo01@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo03@0oooo00<0l=P40?ooo`3oool0503oool20000
08/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0d0?ooo`030?3H103oool0oooo01H0oooo00<000000?ooo`3oool0R03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03@0oooo
00<0l=P40?ooo`3oool05`3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=@3oool00`3`f0@0oooo0?oo
o`0G0?ooo`800000Q`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo03D0oooo00<0l=P40?ooo`3oool06@3oool00`000000oooo0?ooo`24
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0=P3oool00`3`f0@0oooo0?ooo`0I0?ooo`800000Q03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03H0oooo00<0l=P40?ooo`3o
ool06`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0=P3oool00`3`f0@0oooo0?ooo`0L0?ooo`030000
003oool0oooo0800oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0g0?ooo`030?3H103oool0oooo01`0oooo0P0000200?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool0
0`3`f0@0oooo0?ooo`0N0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`030?3H103oool0oooo
01l0oooo0P00001m0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0
oooo0P00000i0?ooo`030?3H103oool0oooo0200oooo00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03H0oooo
00<0l=P40?ooo`3oool08@3oool2000007X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0=`3oool2000003H0oooo00<0l=P40?ooo`3oool08`3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0=03oool00`3`f0@0oooo0?ooo`0S0?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0c0?oo
o`030?3H103oool0oooo02@0oooo0P00001f0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo03/0oooo0P00000c0?ooo`030?3H103oool0oooo02H0oooo00<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo0340oooo00<0l=P40?ooo`3oool09P3oool2000007<0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0?P3oool200000340oooo00<0l=P40?ooo`3oool0:03o
ool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0;`3oool00`3`f0@0oooo0?ooo`0X0?ooo`030000003oool0
oooo06l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`0^0?ooo`030?3H103oool0oooo02T0oooo0P00001_0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0480oooo0P00000^0?ooo`030?3H103oool0oooo02/0
oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo02`0oooo00<0l=P40?ooo`3oool0:`3oool2000006`0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0A@3oool2000002`0oooo00<0
l=P40?ooo`3oool0;@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0:@3oool00`3`f0@0oooo0?ooo`0^
0?ooo`800000J@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo02T0oooo00<0l=P40?ooo`3oool0;`3oool00`000000oooo0?ooo`1V0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04T0oooo0P00000Y0?ooo`03
0?3H103oool0oooo0300oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02H0oooo00<0l=P40?ooo`3oool0
<@3oool2000006D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0C03o
ool2000002L0oooo00<0l=P40?ooo`3oool0<P3oool00`000000oooo0?ooo`1R0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0903oool0
0`3`f0@0oooo0?ooo`0c0?ooo`800000HP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo02@0oooo00<0l=P40?ooo`3oool0=03oool00`00
0000oooo0?ooo`1O0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0500
oooo0P00000T0?ooo`030?3H103oool0oooo03D0oooo00<000000?ooo`3oool0GP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0240oooo
00<0l=P40?ooo`3oool0=P3oool2000005h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0D`3oool200000280oooo00<0l=P40?ooo`3oool0=`3oool2000005`0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0O
0?ooo`030?3H103oool0oooo03P0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01h0oooo00<0l=P40?oo
o`3oool0>03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo05L0oooo0P00000O0?ooo`030?3H103oool0oooo03L0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo01`0oooo00<0l=P40?ooo`3oool0=`3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo05X0oooo0P00000L0?ooo`030?3H103o
ool0oooo03L0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01X0oooo00<0l=P40?ooo`3oool0=P3oool0
0`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
05d0oooo00<000000?ooo`3oool06@3oool00`3`f0@0oooo0?ooo`0f0?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0GP3oool2000001T0
oooo00<0l=P40?ooo`3oool0=P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool05`3oool00`3`f0@0oooo
0?ooo`0e0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0H@3oool2000001L0oooo00<0l=P40?ooo`3oool0=@3oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo06<0oooo00<00000
0?ooo`3oool05@3oool00`3`f0@0oooo0?ooo`0d0?ooo`030000003oool0oooo05X0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0D0?oo
o`030?3H103oool0oooo03@0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`1U0?ooo`800000503oool00`3`f0@0oooo0?ooo`0d0?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
I`3oool00`000000oooo0?ooo`0B0?ooo`030?3H103oool0oooo03<0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1X0?ooo`8000004P3o
ool00`3`f0@0oooo0?ooo`0c0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0?0?ooo`030?3H103oool0
oooo03<0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo00l0oooo00<0l=P40?ooo`3oool0<P3oool00`00
0000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo06`0
oooo0P00000?0?ooo`030?3H103oool0oooo0380oooo00<000000?ooo`3oool0FP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo00`0oooo
00<0l=P40?ooo`3oool0<P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo06l0oooo0P00000=0?ooo`030?3H103oool0oooo0340oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1a
0?ooo`030000003oool0oooo00X0oooo00<0l=P40?ooo`3oool0<@3oool00`000000oooo0?ooo`1J
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0780oooo00<000000?oo
o`3oool02P3oool00`3`f0@0oooo0?ooo`0`0?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0L`3oool2000000X0oooo00<0l=P40?ooo`3o
ool0<03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo07D0oooo00<000000?ooo`3oool01`3oool00`3`f0@0oooo0?ooo`0`0?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0MP3o
ool2000000P0oooo00<0l=P40?ooo`3oool0;`3oool00`000000oooo0?ooo`1J0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool0
0`3`f0@0oooo0?ooo`0_0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`040?ooo`030?3H103oool0oooo
02l0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`1j0?ooo`8000001@3oool00`3`f0@0oooo0?ooo`0^0?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0O03oool00`000000oooo
0?ooo`020?ooo`030?3H103oool0oooo02h0oooo00<000000?ooo`3oool0FP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1m0?ooo`8000000P3oool00`3`f0@0oooo0?oo
o`0^0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0O`3oool010000000oooo0?ooo`3`f0@_0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?3H100_
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0P@3oool00`000000l=P40?ooo`0^0?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0PP3oool00`000000l=P40?3H10290?3H1080
00001`3oool000H0oooo00<000000?ooo`3oool0PP3oool4000002`0oooo0P00001J0?ooo`800000
1`3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo05X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0R03oool2000002P0oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`2;0?ooo`8000009@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08l0oooo0P00000Q0?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
TP3oool2000001h0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`2F0?ooo`8000006P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo09T0oooo
0P00000G0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0W@3oool2000001<0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2P0?ooo`800000
403oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0:80oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1J0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0:@0oooo0P00000<0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Y`3oool2000000T0oooo
00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`2Y0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2[0?oo
o`8000001@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0:d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:h0oooo0P0000020?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0/03o
ool00`000000oooo0000001L0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0;40oooo0P00001L0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0;80oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool200000?l0oooo4@3oool00`000000oooo0?ooo`050?ooo`001P3ooooo
000001@000001`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.25026, -26.2503, 0.182929, \
0.182929}},
  CellTags->"Tracing through a FresnelRhomb"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", 
              StyleBox["100.`",
                StyleBoxAutoDelete->True,
                PrintPrecision->16], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}]},
            {"2", 
              StyleBox["95.7837849178297773`",
                StyleBoxAutoDelete->True,
                PrintPrecision->16], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0", ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.70710678118654755`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.70710678118654755`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0"}], "}"}]},
            {"3", "95.7837849178297773`", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.332161131883703442`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.943222657947601028`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.707106781186547728`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547728`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["45.3055502392049724`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}]},
            {"4", "95.7837849178297773`", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0", ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.70710678118654755`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547728`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["90.6111004784099449`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}]},
            {"5", 
              StyleBox["91.7453345318507373`",
                StyleBoxAutoDelete->True,
                PrintPrecision->16], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", "0", ",", "0"}], "}"}], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.707106781186547461`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["0.707106781186547461`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16], ",", 
                  StyleBox["90.6111004784099272`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "}"}]}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[
\t{RainbowOfRays[{.35,.85},NumberOfRays->50,Polarization->{1,1,0}],
\tMove[FresnelRhomb[10,{DesignWaveLength->.5876}],10],
\tBoundary[50]},
\tPlotType->TopView, ThresholdIntensity->10];
pol = ReadRays[sys,{WaveLength,Polarization[[3]]},IntersectionNumber->5];
ListPlot[pol,PlotJoined->True];\
\>", "Input",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.5 0.0190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.21429 .61596 m
.21429 .38404 L
.21429 .38404 L
.21429 .61596 L
.21429 .61596 L
s
.66478 .92884 m
.66478 .69693 L
.66478 .69693 L
.66478 .92884 L
.66478 .92884 L
s
.66478 .92884 m
.21429 .61596 L
.21429 .61596 L
.66478 .92884 L
.66478 .92884 L
s
.66478 .69693 m
.21429 .38404 L
.21429 .38404 L
.66478 .69693 L
.66478 .69693 L
s
.21429 .61596 m
.21429 .38404 L
.66478 .69693 L
.66478 .92884 L
.21429 .61596 L
s
.21429 .61596 m
.21429 .38404 L
.66478 .69693 L
.66478 .92884 L
.21429 .61596 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.002 .018 .48 r
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.002 .02 .834 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.002 .022 .9 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.002 .025 .923 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.002 .028 .933 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.001 .032 .937 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.001 .038 .937 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.001 .045 .935 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
0 .055 .928 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
0 .072 .917 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.001 .099 .896 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.002 .152 .851 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.003 .282 .728 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.005 .569 .386 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.007 .775 .166 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.01 .853 .096 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.016 .889 .065 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.025 .907 .049 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.043 .917 .038 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.093 .922 .031 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.41 .923 .026 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.851 .918 .023 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.915 .905 .02 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.936 .869 .017 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.945 .726 .016 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.949 .221 .014 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.951 .077 .013 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.952 .04 .012 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.951 .024 .011 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.948 .015 .01 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.945 .01 .009 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.939 .007 .009 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.931 .005 .008 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.918 .003 .008 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.898 .002 .007 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.86 .001 .007 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.779 0 .006 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.569 0 .006 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.283 .001 .006 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.155 .001 .006 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.102 .001 .005 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.075 .002 .005 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.059 .002 .005 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.048 .002 .005 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.041 .002 .004 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.046 .002 .005 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.056 .002 .005 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.071 .002 .005 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.096 .001 .005 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.141 .001 .005 r
.5 Mabswid
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.002 .018 .48 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.002 .02 .834 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.002 .022 .9 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.002 .025 .923 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.002 .028 .933 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.001 .032 .937 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.001 .038 .937 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.001 .045 .935 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
0 .055 .928 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
0 .072 .917 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.001 .099 .896 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.002 .152 .851 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.003 .282 .728 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.005 .569 .386 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.007 .775 .166 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.01 .853 .096 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.016 .889 .065 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.025 .907 .049 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.043 .917 .038 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.093 .922 .031 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.41 .923 .026 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.851 .918 .023 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.915 .905 .02 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.936 .869 .017 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.945 .726 .016 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.949 .221 .014 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.951 .077 .013 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.952 .04 .012 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.951 .024 .011 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.948 .015 .01 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.945 .01 .009 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.939 .007 .009 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.931 .005 .008 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.918 .003 .008 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.898 .002 .007 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.86 .001 .007 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.779 0 .006 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.569 0 .006 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.283 .001 .006 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.155 .001 .006 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.102 .001 .005 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.075 .002 .005 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.059 .002 .005 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.048 .002 .005 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.041 .002 .004 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.046 .002 .005 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.056 .002 .005 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.071 .002 .005 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.096 .001 .005 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.141 .001 .005 r
.5 Mabswid
.21429 .5 m
.38124 .5 L
s
0 0 0 r
2 Mabswid
.38124 .5 Mdot
.002 .018 .48 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.002 .02 .834 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.002 .022 .9 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.002 .025 .923 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.002 .028 .933 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.001 .032 .937 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.001 .038 .937 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.001 .045 .935 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
0 .055 .928 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
0 .072 .917 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.001 .099 .896 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.002 .152 .851 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.003 .282 .728 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.005 .569 .386 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.007 .775 .166 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.01 .853 .096 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.016 .889 .065 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.025 .907 .049 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.043 .917 .038 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.093 .922 .031 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.41 .923 .026 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.851 .918 .023 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.915 .905 .02 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.936 .869 .017 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.945 .726 .016 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.949 .221 .014 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.951 .077 .013 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.952 .04 .012 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.951 .024 .011 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.948 .015 .01 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.945 .01 .009 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.939 .007 .009 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.931 .005 .008 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.918 .003 .008 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.898 .002 .007 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.86 .001 .007 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.779 0 .006 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.569 0 .006 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.283 .001 .006 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.155 .001 .006 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.102 .001 .005 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.075 .002 .005 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.059 .002 .005 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.048 .002 .005 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.041 .002 .004 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.046 .002 .005 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.056 .002 .005 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.071 .002 .005 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.096 .001 .005 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.141 .001 .005 r
.5 Mabswid
.38124 .5 m
.49783 .81289 L
s
0 0 0 r
2 Mabswid
.49783 .81289 Mdot
.002 .018 .48 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.002 .02 .834 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.002 .022 .9 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.002 .025 .923 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.002 .028 .933 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.001 .032 .937 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.001 .038 .937 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.001 .045 .935 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
0 .055 .928 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
0 .072 .917 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.001 .099 .896 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.002 .152 .851 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.003 .282 .728 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.005 .569 .386 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.007 .775 .166 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.01 .853 .096 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.016 .889 .065 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.025 .907 .049 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.043 .917 .038 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.093 .922 .031 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.41 .923 .026 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.851 .918 .023 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.915 .905 .02 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.936 .869 .017 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.945 .726 .016 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.949 .221 .014 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.951 .077 .013 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.952 .04 .012 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.951 .024 .011 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.948 .015 .01 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.945 .01 .009 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.939 .007 .009 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.931 .005 .008 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.918 .003 .008 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.898 .002 .007 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.86 .001 .007 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.779 0 .006 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.569 0 .006 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.283 .001 .006 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.155 .001 .006 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.102 .001 .005 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.075 .002 .005 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.059 .002 .005 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.048 .002 .005 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.041 .002 .004 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.046 .002 .005 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.056 .002 .005 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.071 .002 .005 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.096 .001 .005 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.141 .001 .005 r
.5 Mabswid
.49783 .81289 m
.66478 .81289 L
s
0 0 0 r
2 Mabswid
.66478 .81289 Mdot
.002 .018 .48 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.002 .02 .834 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.002 .022 .9 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.002 .025 .923 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.002 .028 .933 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.001 .032 .937 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.001 .038 .937 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.001 .045 .935 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
0 .055 .928 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
0 .072 .917 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.001 .099 .896 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.002 .152 .851 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.003 .282 .728 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.005 .569 .386 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.007 .775 .166 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.01 .853 .096 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.016 .889 .065 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.025 .907 .049 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.043 .917 .038 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.093 .922 .031 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.41 .923 .026 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.851 .918 .023 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.915 .905 .02 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.936 .869 .017 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.945 .726 .016 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.949 .221 .014 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.951 .077 .013 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.952 .04 .012 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.951 .024 .011 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.948 .015 .01 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.945 .01 .009 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.939 .007 .009 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.931 .005 .008 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.918 .003 .008 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.898 .002 .007 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.86 .001 .007 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.779 0 .006 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.569 0 .006 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.283 .001 .006 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.155 .001 .006 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.102 .001 .005 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.075 .002 .005 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.059 .002 .005 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.048 .002 .005 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.041 .002 .004 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.046 .002 .005 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.056 .002 .005 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.071 .002 .005 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.096 .001 .005 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
.141 .001 .005 r
.5 Mabswid
.66478 .81289 m
.97619 .81289 L
s
0 0 0 r
2 Mabswid
.97619 .81289 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3H0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo0P00003I0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`000000f03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00800000
eP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0dP3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
00@0oooo0P00003B0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool01`3oool200000<l0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0:0?ooo`800000c03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0b@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00h0oooo0P0000380?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool04@3oool200000<D0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
0<80oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0D0?ooo`800000`P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0_`3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01L0oooo0P00
002o0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`2k0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool06`3oool200000;/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0N0?ooo`800000^03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo0240oooo0P00002e0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`2b0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool09@3oool200000;40oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0X0?ooo`800000[P3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0Z`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`800000
;03oool300000:X0oooo00<000000?ooo`3oool01@3oool000H0ooooIP0T00400`00000090010?oo
o`2Y0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0;@3oool00`0T004000000?ooo`2X0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0;P3oool00`0T004000000000002W0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0;P3oool0100T0040oooo0?ooo`00002V0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0;P3oool0100T0040oooo0?ooo`3oool20000
0:@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0_0?ooo`0302@00@3oool0oooo0080oooo00<000000?ooo`3oool0X@3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02l0oooo
00<090010?ooo`3oool00`3oool200000:40oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0_0?ooo`0302@00@3oool0oooo00D0oooo00<0
00000?ooo`3oool0WP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0300oooo00<090010?ooo`3oool01@3oool00`000000oooo0?ooo`2M
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0<03oool00`0T0040oooo0?ooo`060?ooo`800000W@3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0300oooo00<090010?ooo`3o
ool0203oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0<@3oool00`0T0040oooo0?ooo`080?ooo`800000
VP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo0340oooo00<090010?ooo`3oool02P3oool00`000000oooo0?ooo`2G0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0<P3oool0
0`0T0040oooo0?ooo`0:0?ooo`800000U`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo0380oooo00<090010?ooo`3oool0303oool00`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0<P3oool00`0T0040oooo0?ooo`0=0?ooo`800000U03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo
00<090010?ooo`3oool03P3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`0T0040oooo0?oo
o`0?0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`0302@00@3oool0oooo0100oooo0P00002@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0=03oool00`0T0040oooo0?ooo`0A0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0d0?ooo`03
02@00@3oool0oooo0180oooo0P00002=0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0=@3oool00`0T0040oooo0?ooo`0C0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0e0?ooo`0302@00@3oool0oooo01@0oooo0P00002:0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=@3oool0
0`0T0040oooo0?ooo`0F0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0f0?ooo`0302@00@3oool0oooo
01H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo03H0oooo00<090010?ooo`3oool05`3oool2000008H0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0f0?ooo`0302@00@3oool0oooo01T0oooo00<000000?ooo`3oool0P`3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<0
90010?ooo`3oool06@3oool2000008<0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`0302@00@3oool0oooo01/0oooo00<00000
0?ooo`3oool0P03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo03L0oooo00<090010?ooo`3oool0703oool200000800oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0h0?ooo`03
02@00@3oool0oooo01d0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03P0oooo00<090010?ooo`3oool0
7P3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0>@3oool00`0T0040oooo0?ooo`0N0?ooo`800000O03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`800000>P3oool0
0`0T0040oooo0?ooo`0P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0g0?ooo`0302@00@3oool0oooo
0240oooo0P00001i0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03L0
oooo0P00000h0?ooo`0302@00@3oool0oooo0280oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03D0oooo
00<090010?ooo`3oool08`3oool2000007H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0d0?ooo`0302@00@3oool0oooo02D0oooo00<0
00000?ooo`3oool0L`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0k
0?ooo`800000=@3oool00`0T0040oooo0?ooo`0U0?ooo`030000003oool0oooo0780oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0b0?oo
o`0302@00@3oool0oooo02H0oooo0P00001b0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo03h0oooo0P00000b0?ooo`0302@00@3oool0oooo02P0oooo00<000000?ooo`3o
ool0K`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo0300oooo00<090010?ooo`3oool0:03oool2000006l0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0@@3oool200000300oooo00<090010?ooo`3oool0:P3o
ool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0;P3oool00`0T0040oooo0?ooo`0Z0?ooo`800000K03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
02d0oooo00<090010?ooo`3oool0;03oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo04D0oooo0P00000]0?ooo`0302@00@3oool0oooo02d0
oooo0P00001Y0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool0:`3oool00`0T0040oooo0?ooo`0^0?ooo`030000003oool0oooo06H0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0B03oool2000002/0oooo00<0
90010?ooo`3oool0;`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0:03oool00`0T0040oooo0?ooo`0`
0?ooo`800000I@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1;0?oo
o`800000:@3oool00`0T0040oooo0?ooo`0a0?ooo`030000003oool0oooo0680oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0V0?ooo`03
02@00@3oool0oooo0380oooo0P00001R0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo04h0oooo0P00000W0?ooo`0302@00@3oool0oooo03<0oooo00<000000?ooo`3oool0
G`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo02@0oooo00<090010?ooo`3oool0=03oool2000005l0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0S0?ooo`0302@00@3oool0
oooo03H0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`1B0?ooo`800000903oool00`0T0040oooo0?ooo`0f0?ooo`030000003oool0oooo
05/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`0Q0?ooo`0302@00@3oool0oooo03L0oooo0P00001K0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo05D0oooo0P00000Q0?ooo`0302@00@3oool0oooo03T0oooo
00<000000?ooo`000000F03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01l0oooo00<090010?ooo`3oool0>@3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo05P0oooo0P00000O
0?ooo`0302@00@3oool0oooo03T0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01`0oooo00<090010?oo
o`3oool0>@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool0703oool00`0T0040oooo0?ooo`0h0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
G03oool2000001`0oooo00<090010?ooo`3oool0>03oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool06P3o
ool00`0T0040oooo0?ooo`0g0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0G`3oool2000001X0oooo00<090010?ooo`3oool0=`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool05`3oool00`0T0040oooo0?ooo`0g0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0HP3oool2000001P0
oooo00<090010?ooo`3oool0=P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool05@3oool00`0T0040oooo
0?ooo`0f0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`0D0?ooo`0302@00@3oool0oooo03H0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1V
0?ooo`8000005@3oool00`0T0040oooo0?ooo`0e0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0B0?oo
o`0302@00@3oool0oooo03D0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`1Y0?ooo`8000004P3oool00`0T0040oooo0?ooo`0e0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
J`3oool00`000000oooo0?ooo`0@0?ooo`0302@00@3oool0oooo03@0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1/0?ooo`800000403o
ool00`0T0040oooo0?ooo`0d0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0>0?ooo`0302@00@3oool0
oooo03<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`1_0?ooo`030000003oool0oooo00d0oooo00<090010?ooo`3oool0<`3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0700
oooo0P00000=0?ooo`0302@00@3oool0oooo03<0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo00/0oooo
00<090010?ooo`3oool0<P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo07<0oooo0P00000;0?ooo`0302@00@3oool0oooo0380oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1e
0?ooo`030000003oool0oooo00P0oooo00<090010?ooo`3oool0<P3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo07H0oooo0P0000090?oo
o`0302@00@3oool0oooo0340oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00H0oooo00<090010?ooo`3o
ool0<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo07T0oooo0P0000070?ooo`0302@00@3oool0oooo0300oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1k0?ooo`030000003o
ool0oooo00@0oooo00<090010?ooo`3oool0<03oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool00`3oool0
0`0T0040oooo0?ooo`0`0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0O@3oool2000000@0oooo00<090010?ooo`3oool0;`3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo07l0
oooo00D000000?ooo`3oool0oooo02@00@0a0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0P03oool2000000030?ooo`0T0040oooo0300
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`220?ooo`030000003oool090010300oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`230?ooo`030000000T0040oooo02l0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`24
0?ooo`0302@00@000000000002h0oooo0P00001G0?ooo`8000001`3oool000H0oooo00<000000?oo
o`3oool0Q@3ooon902@00@8000001`3oool000H0oooo00<000000?ooo`3oool0Q`3oool2000002`0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`290?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2:0?ooo`800000:@3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08d0oooo0P00000V0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0T@3oool200000280oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`2D0?ooo`8000007`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo09L0oooo
0P00000L0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0V@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0V`3oool2000001P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2N0?ooo`800000
5@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0:00oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0:40oooo0P00000B0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0X`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0Y03oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`2W0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`8000002`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:X0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0:/0oooo0P0000080?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0[P3o
ool2000000D0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`2`0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2a0?ooo`050000003oool0oooo
0?ooo`000000F@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2b0?oo
o`80000000<0oooo0000003oool0F03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`2d0?ooo`800000F@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`2e0?ooo`800000F03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool200000?l0oooo4@3oool00`000000oooo0?ooo`050?ooo`001P3ooooo000001@0
00001`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.25026, -26.2503, 0.182929, \
0.182929}},
  CellTags->"Tracing through a FresnelRhomb"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.642857 1.90476 -19.0072 0.212967 [
[.30952 .1473 -9 -9 ]
[.30952 .1473 9 0 ]
[.5 .1473 -9 -9 ]
[.5 .1473 9 0 ]
[.69048 .1473 -9 -9 ]
[.69048 .1473 9 0 ]
[.88095 .1473 -9 -9 ]
[.88095 .1473 9 0 ]
[.10655 .05332 -24 -4.5 ]
[.10655 .05332 0 4.5 ]
[.10655 .26629 -24 -4.5 ]
[.10655 .26629 0 4.5 ]
[.10655 .37277 -12 -4.5 ]
[.10655 .37277 0 4.5 ]
[.10655 .47925 -24 -4.5 ]
[.10655 .47925 0 4.5 ]
[.10655 .58574 -12 -4.5 ]
[.10655 .58574 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.30952 .1598 m
.30952 .16605 L
s
[(0.5)] .30952 .1473 0 1 Mshowa
.5 .1598 m
.5 .16605 L
s
[(0.6)] .5 .1473 0 1 Mshowa
.69048 .1598 m
.69048 .16605 L
s
[(0.7)] .69048 .1473 0 1 Mshowa
.88095 .1598 m
.88095 .16605 L
s
[(0.8)] .88095 .1473 0 1 Mshowa
.125 Mabswid
.15714 .1598 m
.15714 .16355 L
s
.19524 .1598 m
.19524 .16355 L
s
.23333 .1598 m
.23333 .16355 L
s
.27143 .1598 m
.27143 .16355 L
s
.34762 .1598 m
.34762 .16355 L
s
.38571 .1598 m
.38571 .16355 L
s
.42381 .1598 m
.42381 .16355 L
s
.4619 .1598 m
.4619 .16355 L
s
.5381 .1598 m
.5381 .16355 L
s
.57619 .1598 m
.57619 .16355 L
s
.61429 .1598 m
.61429 .16355 L
s
.65238 .1598 m
.65238 .16355 L
s
.72857 .1598 m
.72857 .16355 L
s
.76667 .1598 m
.76667 .16355 L
s
.80476 .1598 m
.80476 .16355 L
s
.84286 .1598 m
.84286 .16355 L
s
.08095 .1598 m
.08095 .16355 L
s
.04286 .1598 m
.04286 .16355 L
s
.00476 .1598 m
.00476 .16355 L
s
.91905 .1598 m
.91905 .16355 L
s
.95714 .1598 m
.95714 .16355 L
s
.99524 .1598 m
.99524 .16355 L
s
.25 Mabswid
0 .1598 m
1 .1598 L
s
.11905 .05332 m
.1253 .05332 L
s
[(89.5)] .10655 .05332 1 0 Mshowa
.11905 .26629 m
.1253 .26629 L
s
[(90.5)] .10655 .26629 1 0 Mshowa
.11905 .37277 m
.1253 .37277 L
s
[(91)] .10655 .37277 1 0 Mshowa
.11905 .47925 m
.1253 .47925 L
s
[(91.5)] .10655 .47925 1 0 Mshowa
.11905 .58574 m
.1253 .58574 L
s
[(92)] .10655 .58574 1 0 Mshowa
.125 Mabswid
.11905 .07462 m
.1228 .07462 L
s
.11905 .09591 m
.1228 .09591 L
s
.11905 .11721 m
.1228 .11721 L
s
.11905 .13851 m
.1228 .13851 L
s
.11905 .1811 m
.1228 .1811 L
s
.11905 .2024 m
.1228 .2024 L
s
.11905 .22369 m
.1228 .22369 L
s
.11905 .24499 m
.1228 .24499 L
s
.11905 .28758 m
.1228 .28758 L
s
.11905 .30888 m
.1228 .30888 L
s
.11905 .33018 m
.1228 .33018 L
s
.11905 .35147 m
.1228 .35147 L
s
.11905 .39407 m
.1228 .39407 L
s
.11905 .41536 m
.1228 .41536 L
s
.11905 .43666 m
.1228 .43666 L
s
.11905 .45796 m
.1228 .45796 L
s
.11905 .50055 m
.1228 .50055 L
s
.11905 .52185 m
.1228 .52185 L
s
.11905 .54314 m
.1228 .54314 L
s
.11905 .56444 m
.1228 .56444 L
s
.11905 .03202 m
.1228 .03202 L
s
.11905 .01073 m
.1228 .01073 L
s
.11905 .60703 m
.1228 .60703 L
s
.25 Mabswid
.11905 0 m
.11905 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.04325 .56473 L
.06268 .52944 L
.08212 .49705 L
.10155 .46724 L
.12099 .43973 L
.14043 .41427 L
.15986 .39066 L
.1793 .3687 L
.19874 .34824 L
.21817 .32914 L
.23761 .31128 L
.25705 .29453 L
.27648 .27881 L
.29592 .26402 L
.31535 .2501 L
.33479 .23695 L
.35423 .22453 L
.37366 .21278 L
.3931 .20164 L
.41254 .19106 L
.43197 .18101 L
.45141 .17144 L
.47085 .16232 L
.49028 .15362 L
.50972 .14531 L
.52915 .13735 L
.54859 .12973 L
.56803 .12242 L
.58746 .11541 L
.6069 .10867 L
.62634 .10218 L
.64577 .09593 L
.66521 .0899 L
.68465 .08408 L
.70408 .07845 L
.72352 .07301 L
.74295 .06774 L
.76239 .06263 L
.78183 .05768 L
.80126 .05286 L
.8207 .04818 L
.84014 .04363 L
.85957 .03919 L
.87901 .03487 L
.89845 .03065 L
.91788 .02653 L
.93732 .02251 L
.95675 .01857 L
.97619 .01472 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003o8P3oool0
0`000000oooo0?ooo`3k0?ooo`008P3oool00`000000oooo0?ooo`3k0?ooo`008P3oool00`000000
oooo0?ooo`3k0?ooo`008P3oool200000?`0oooo000R0?ooo`030000003oool0oooo0?00oooo0`00
00080?ooo`008P3oool00`000000oooo0?ooo`3Z0?ooo`H000002`3oool00280oooo00<000000?oo
o`3oool0i@3oool500000140oooo000R0?ooo`030000003oool0oooo0=l0oooo1P00000F0?ooo`00
8P3oool00`000000oooo0?ooo`3K0?ooo`@00000703oool00280oooo0P00003I0?ooo`<00000803o
ool00280oooo00<000000?ooo`3oool0e03oool4000002<0oooo000R0?ooo`030000003oool0oooo
0<h0oooo1P00000W0?ooo`001`3oool3000000<0oooo0P0000050?ooo`030000003oool0oooo0080
oooo0`0000060?ooo`030000003oool0oooo0<T0oooo1@00000]0?ooo`001P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool00000
00D0oooo00<000000?ooo`3oool0a@3oool400000380oooo00060?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0`P3oool3000003H0oooo00070?ooo`<000000`3oool4000000/0oooo00<000000?ooo`3o
ool00`3oool300000;h0oooo1000000i0?ooo`001P3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`050?ooo`@000001P3oool00`000000oooo0?ooo`2h0?oo
o`H00000?@3oool000H0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;@0oooo10000013
0?ooo`001`3oool3000000<0oooo0`0000080?ooo`D000001@3oool00`000000oooo0?ooo`2a0?oo
o`<00000A`3oool00280oooo00<000000?ooo`3oool0[@3oool4000004X0oooo000R0?ooo`030000
003oool0oooo0:T0oooo1000001>0?ooo`008P3oool200000:L0oooo0`00001B0?ooo`008P3oool0
0`000000oooo0?ooo`2S0?ooo`<00000E@3oool00280oooo00<000000?ooo`3oool0X03oool30000
05P0oooo000R0?ooo`030000003oool0oooo09`0oooo1000001K0?ooo`008P3oool00`000000oooo
0?ooo`2H0?ooo`@00000G`3oool00280oooo00<000000?ooo`3oool0U@3oool3000006<0oooo000R
0?ooo`800000U03oool2000006H0oooo000R0?ooo`030000003oool0oooo0900oooo0`00001X0?oo
o`008P3oool00`000000oooo0?ooo`2=0?ooo`<00000J`3oool00280oooo00<000000?ooo`3oool0
RP3oool3000006h0oooo000R0?ooo`030000003oool0oooo08P0oooo0P00001a0?ooo`008P3oool0
0`000000oooo0?ooo`250?ooo`<00000L`3oool00280oooo0P0000230?ooo`<00000MP3oool00280
oooo00<000000?ooo`3oool0;03oool2000000@0oooo00<000000?ooo`3oool00P3oool3000002T0
oooo0P0000040?ooo`030000003oool0oooo0080oooo0`00000>0?ooo`<00000603oool2000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool00`000000
oooo0?ooo`020?ooo`<000007@3oool00280oooo00<000000?ooo`3oool0:`3oool010000000oooo
0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000009`3oool010000000oooo0?ooo`000007
0?ooo`050000003oool0oooo0?ooo`0000002P3oool3000001X0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3o
ool0oooo0000000L0?ooo`008P3oool00`000000oooo0?ooo`0[0?ooo`040000003oool0oooo0000
00/0oooo00<000000?ooo`3oool09@3oool010000000oooo0?ooo`0000070?ooo`050000003oool0
oooo0?ooo`0000001`3oool3000001d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`0U0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000L0?oo
o`008P3oool00`000000oooo0?ooo`0[0?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`3oool09@3oool010000000oooo0?ooo`0000070?ooo`@000001P3oool200000200oooo00@00000
0?ooo`3oool000002P3oool00`000000oooo0?ooo`0U0?ooo`040000003oool0oooo000000P0oooo
0`00000M0?ooo`008P3oool00`000000oooo0?ooo`0[0?ooo`040000003oool0oooo000000L0oooo
1000000X0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0103oool300000280
oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0T0?ooo`040000003oool0oooo
000000L0oooo00D000000?ooo`3oool0oooo0000000L0?ooo`008P3oool2000002`0oooo00@00000
0?ooo`3oool000001`3oool00`000000oooo0?ooo`0Y0?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool00`00000U0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3o
ool0oooo0000000V0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000
000L0?ooo`008P3oool00`000000oooo0?ooo`0/0?ooo`800000203oool5000002P0oooo0P000009
0?ooo`<00000:@3oool2000000P0oooo1@00000W0?ooo`8000002@3oool3000001d0oooo000R0?oo
o`030000003oool0oooo06`0oooo0P00002=0?ooo`008P3oool00`000000oooo0?ooo`1Z0?ooo`80
0000S`3oool00280oooo00<000000?ooo`3oool0J03oool200000940oooo000R0?ooo`030000003o
ool0oooo06H0oooo0P00002C0?ooo`00o`00000P00000040oooo00000`3oool000000?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool010000000oooo000000000007
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo0@0000010?ooo`40oooo000R0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool0:@3oool2000000T0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo0240oooo000R0?ooo`030000003oool0oooo05d0
oooo0P00002L0?ooo`008P3oool00`000000oooo0?ooo`1K0?ooo`800000WP3oool00280oooo00<0
00000?ooo`3oool0F03oool300000:00oooo000R0?ooo`800000E`3oool200000:<0oooo000R0?oo
o`030000003oool0oooo05@0oooo0P00002U0?ooo`008P3oool00`000000oooo0?ooo`1B0?ooo`80
0000Y`3oool00280oooo00<000000?ooo`3oool0D03oool200000:T0oooo000R0?ooo`030000003o
ool0oooo04h0oooo0P00002[0?ooo`008P3oool00`000000oooo0?ooo`1<0?ooo`800000[@3oool0
0280oooo00<000000?ooo`3oool0BP3oool200000:l0oooo000R0?ooo`800000B@3oool200000;40
oooo000R0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0/@3oool00280oooo00<0
00000?ooo`3oool0A@3oool200000;@0oooo000R0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0]03oool00280oooo00<000000?ooo`3oool0@P3oool200000;L0oooo000R0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0]`3oool00280oooo0P0000100?ooo`800000
^P3oool00280oooo00<000000?ooo`3oool0?@3oool200000;`0oooo000R0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool0_03oool00280oooo00<000000?ooo`3oool0>P3oool20000
0;l0oooo000R0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0_`3oool00280oooo
00<000000?ooo`3oool0=`3oool200000<80oooo000R0?ooo`800000=`3oool00`000000oooo0?oo
o`320?ooo`008P3oool00`000000oooo0?ooo`0d0?ooo`800000a@3oool00280oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`350?ooo`001`3oool2000000D0oooo0P0000040?ooo`03
0000003oool0oooo0080oooo0`0000060?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0aP3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0
oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0a`3oool000X0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;`3oool200000<X0oooo00070?ooo`@0
00000P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00<0oooo0`00000^0?oo
o`030000003oool0oooo0<X0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000070?ooo`@000001P3oool00`000000oooo0?ooo`0/0?ooo`800000c@3oool0
00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0<d0oooo0007
0?ooo`<00000103oool2000000P0oooo1@0000050?ooo`030000003oool0oooo02T0oooo0P00003@
0?ooo`008P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0=00oooo000R0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0d@3oool00280oooo0P00000W0?ooo`030000
003oool0oooo0=80oooo000R0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0d`3o
ool00280oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3D0?ooo`008P3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo0=D0oooo000R0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0eP3oool00280oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`3G0?ooo`008P3oool200000240oooo00<000000?ooo`3oool0f03oool00280oooo00<00000
0?ooo`3oool07P3oool200000=/0oooo000R0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0f`3oool00280oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3L0?ooo`00
8P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0=d0oooo000R0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0gP3oool00280oooo0P00000J0?ooo`030000003oool0
oooo0=l0oooo000R0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0h03oool00280
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3Q0?ooo`008P3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo0>80oooo000R0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0h`3oool00280oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3T
0?ooo`008P3oool2000001@0oooo00<000000?ooo`3oool0i@3oool00280oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`3V0?ooo`008P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0>L0oooo000R0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0j03o
ool001<0oooo0P0000040?ooo`<000001P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0>T0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0>X0oooo000F0?ooo`050000003oool0oooo0?oo
o`0000001`3oool3000000h0oooo00<000000?ooo`3oool0jP3oool001<0oooo100000030?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3[0?ooo`00
4P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0>`0oooo000B0?ooo`050000003oool0oooo0?ooo`00
00000P3oool2000000L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3]0?ooo`00
4`3oool3000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0>h0oooo000R0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0k`3o
ool00280oooo0P00000:0?ooo`030000003oool0oooo0>l0oooo000R0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0l03oool00280oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`3a0?ooo`008P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?80oooo
000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0l`3oool00280oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`3d0?ooo`008P3oool2000000@0oooo00<000000?oo
o`3oool0m@3oool00280oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3e0?ooo`00
8P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?H0oooo000R0?ooo`050000003o
ool0oooo0?ooo`000000n@3oool00280oooo00@000000?ooo`3oool00000nP3oool00280oooo00<0
00000?ooo`000000n`3oool00280oooo0P00003l0?ooo`008P3oool200000?`0oooo000R0?ooo`03
0000003oool0oooo0?/0oooo000Q0?ooo`800000o@3oool00200oooo00<000000?ooo`000000o@3o
ool00200oooo00<000000?ooo`000000o@3oool001l0oooo00@000000?ooo`3oool00000o@3oool0
01l0oooo00<000000?ooo`3oool00P00003l0?ooo`007P3oool01@000000oooo0?ooo`3oool00000
0?d0oooo000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0n`3oool000L0oooo
0P0000040?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`<0000000<0oooo0000003oool0
0`3oool00`000000oooo0?ooo`3k0?ooo`002@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00L0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0?/0oooo
000:0?ooo`050000003oool0oooo0?ooo`000000303oool2000000D0oooo00<000000?ooo`3oool0
n`3oool000L0oooo100000030?ooo`030000003oool0oooo00X0oooo0P0000050?ooo`<00000n`3o
ool000H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00L0oooo1000
00060?ooo`030000003oool0oooo0?/0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3o
ool2000000T0oooo0P0000080?ooo`030000003oool0oooo0?/0oooo00070?ooo`<00000103oool0
0`000000oooo0?ooo`070?ooo`D000001@3oool00`000000oooo0?ooo`3k0?ooo`00603oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0?/0oooo000G0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0n`3oool001L0oooo00<000000?ooo`3oool0203oool200000?`0oooo
000F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0n`3oool001H0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`3k0?ooo`005@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0?/0oooo000D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0n`3oool001@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3k0?ooo`004`3o
ool00`000000oooo0?ooo`0<0?ooo`800000o03oool001<0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`3k0?ooo`004P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0?/0oooo000B0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0n`3oool00140oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3k0?ooo`00403oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0?/0oooo000@0?ooo`030000003oool0oooo00l0oooo0P00003l
0?ooo`003`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?/0oooo000?0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0n`3oool000h0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`3k0?ooo`003@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0?/0oooo000=0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0n`3oool0
00`0oooo00<000000?ooo`3oool04`3oool200000?`0oooo000<0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0n`3oool000/0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`3k0?ooo`002`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?/0oooo000:
0?ooo`030000003oool0oooo00H0oooo0P0000030?ooo`D000001@3oool00`000000oooo0?ooo`3k
0?ooo`002P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0?/0oooo00090?ooo`030000003oool0oooo
00X0oooo00D000000?ooo`3oool0oooo000000070?ooo`<00000n`3oool000T0oooo00<000000?oo
o`3oool01`3oool4000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3k0?oo
o`002@3oool00`000000oooo0?ooo`060?ooo`070000003oool0oooo0?ooo`000000oooo00000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0n`3oool000P0oooo00<000000?oo
o`3oool01`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0?/0oooo00080?ooo`030000003oool0oooo00P0oooo0`000003
0?ooo`<000001P3oool00`000000oooo0?ooo`3k0?ooo`001`3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo0?/0oooo000R0?ooo`800000o03oool00280oooo00<000000?ooo`3oool0
n`3oool00280oooo00<000000?ooo`3oool0n`3oool00280oooo00<000000?ooo`3oool0n`3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.336849, 89.2495, \
0.00183381, 0.0164014}},
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[
\t{RainbowOfRays[{.35,.85},NumberOfRays->50,Polarization->{1,1,0}],
\tMove[FresnelRhomb[10,{DesignWaveLength->.5876,FullForm->True}],10],
\tBoundary[75]},
\tPlotType->TopView, ThresholdIntensity->10];
pol = ReadRays[sys,{WaveLength,Polarization[[3]]},IntersectionNumber->6];
ListPlot[pol,PlotJoined->True,AxesOrigin->{.4,180}];\
\>", "Input",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0126984 0.5 0.0126984 [
[.45112 .3846 -36 -4.5 ]
[.45112 .3846 36 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.15079 .5773 m
.15079 .4227 L
.15079 .4227 L
.15079 .5773 L
.15079 .5773 L
s
.45112 .7859 m
.15079 .5773 L
.15079 .5773 L
.45112 .7859 L
.45112 .7859 L
s
.45112 .63129 m
.15079 .4227 L
.15079 .4227 L
.45112 .63129 L
.45112 .63129 L
s
.15079 .5773 m
.15079 .4227 L
.45112 .63129 L
.45112 .7859 L
.15079 .5773 L
s
.15079 .5773 m
.15079 .4227 L
.45112 .63129 L
.45112 .7859 L
.15079 .5773 L
s
.75145 .5773 m
.45112 .7859 L
.45112 .7859 L
.75145 .5773 L
.75145 .5773 L
s
.75145 .4227 m
.45112 .63129 L
.45112 .63129 L
.75145 .4227 L
.75145 .4227 L
s
.75145 .4227 m
.75145 .5773 L
.75145 .5773 L
.75145 .4227 L
.75145 .4227 L
s
.45112 .63129 m
.45112 .7859 L
.75145 .5773 L
.75145 .4227 L
.45112 .63129 L
s
.45112 .63129 m
.45112 .7859 L
.75145 .5773 L
.75145 .4227 L
.45112 .63129 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.002 .018 .48 r
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.002 .02 .834 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.002 .022 .9 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.002 .025 .923 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.002 .028 .933 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.001 .032 .937 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.001 .038 .937 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.001 .045 .935 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
0 .055 .928 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
0 .072 .917 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.001 .099 .896 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.002 .152 .851 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.003 .282 .728 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.005 .569 .386 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.007 .775 .166 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.01 .853 .096 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.016 .889 .065 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.025 .907 .049 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.043 .917 .038 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.093 .922 .031 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.41 .923 .026 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.851 .918 .023 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.915 .905 .02 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.936 .869 .017 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.945 .726 .016 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.949 .221 .014 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.951 .077 .013 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.952 .04 .012 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.951 .024 .011 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.948 .015 .01 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.945 .01 .009 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.939 .007 .009 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.931 .005 .008 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.918 .003 .008 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.898 .002 .007 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.86 .001 .007 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.779 0 .006 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.569 0 .006 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.283 .001 .006 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.155 .001 .006 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.102 .001 .005 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.075 .002 .005 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.059 .002 .005 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.048 .002 .005 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.041 .002 .004 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.046 .002 .005 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.056 .002 .005 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.071 .002 .005 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.096 .001 .005 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.141 .001 .005 r
.5 Mabswid
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.002 .018 .48 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.002 .02 .834 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.002 .022 .9 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.002 .025 .923 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.002 .028 .933 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.001 .032 .937 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.001 .038 .937 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.001 .045 .935 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
0 .055 .928 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
0 .072 .917 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.001 .099 .896 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.002 .152 .851 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.003 .282 .728 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.005 .569 .386 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.007 .775 .166 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.01 .853 .096 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.016 .889 .065 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.025 .907 .049 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.043 .917 .038 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.093 .922 .031 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.41 .923 .026 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.851 .918 .023 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.915 .905 .02 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.936 .869 .017 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.945 .726 .016 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.949 .221 .014 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.951 .077 .013 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.952 .04 .012 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.951 .024 .011 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.948 .015 .01 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.945 .01 .009 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.939 .007 .009 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.931 .005 .008 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.918 .003 .008 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.898 .002 .007 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.86 .001 .007 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.779 0 .006 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.569 0 .006 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.283 .001 .006 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.155 .001 .006 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.102 .001 .005 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.075 .002 .005 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.059 .002 .005 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.048 .002 .005 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.041 .002 .004 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.046 .002 .005 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.056 .002 .005 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.071 .002 .005 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.096 .001 .005 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.141 .001 .005 r
.5 Mabswid
.15079 .5 m
.2621 .5 L
s
0 0 0 r
2 Mabswid
.2621 .5 Mdot
.002 .018 .48 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.002 .02 .834 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.002 .022 .9 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.002 .025 .923 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.002 .028 .933 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.001 .032 .937 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.001 .038 .937 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.001 .045 .935 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
0 .055 .928 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
0 .072 .917 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.001 .099 .896 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.002 .152 .851 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.003 .282 .728 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.005 .569 .386 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.007 .775 .166 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.01 .853 .096 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.016 .889 .065 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.025 .907 .049 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.043 .917 .038 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.093 .922 .031 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.41 .923 .026 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.851 .918 .023 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.915 .905 .02 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.936 .869 .017 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.945 .726 .016 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.949 .221 .014 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.951 .077 .013 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.952 .04 .012 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.951 .024 .011 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.948 .015 .01 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.945 .01 .009 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.939 .007 .009 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.931 .005 .008 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.918 .003 .008 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.898 .002 .007 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.86 .001 .007 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.779 0 .006 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.569 0 .006 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.283 .001 .006 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.155 .001 .006 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.102 .001 .005 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.075 .002 .005 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.059 .002 .005 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.048 .002 .005 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.041 .002 .004 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.046 .002 .005 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.056 .002 .005 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.071 .002 .005 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.096 .001 .005 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.141 .001 .005 r
.5 Mabswid
.2621 .5 m
.33982 .70859 L
s
0 0 0 r
2 Mabswid
.33982 .70859 Mdot
.002 .018 .48 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.002 .02 .834 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.002 .022 .9 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.002 .025 .923 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.002 .028 .933 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.001 .032 .937 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.001 .038 .937 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.001 .045 .935 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
0 .055 .928 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
0 .072 .917 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.001 .099 .896 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.002 .152 .851 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.003 .282 .728 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.005 .569 .386 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.007 .775 .166 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.01 .853 .096 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.016 .889 .065 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.025 .907 .049 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.043 .917 .038 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.093 .922 .031 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.41 .923 .026 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.851 .918 .023 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.915 .905 .02 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.936 .869 .017 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.945 .726 .016 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.949 .221 .014 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.951 .077 .013 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.952 .04 .012 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.951 .024 .011 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.948 .015 .01 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.945 .01 .009 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.939 .007 .009 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.931 .005 .008 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.918 .003 .008 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.898 .002 .007 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.86 .001 .007 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.779 0 .006 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.569 0 .006 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.283 .001 .006 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.155 .001 .006 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.102 .001 .005 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.075 .002 .005 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.059 .002 .005 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.048 .002 .005 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.041 .002 .004 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.046 .002 .005 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.056 .002 .005 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.071 .002 .005 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.096 .001 .005 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.141 .001 .005 r
.5 Mabswid
.33982 .70859 m
.56242 .70859 L
s
0 0 0 r
2 Mabswid
.56242 .70859 Mdot
.002 .018 .48 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.002 .02 .834 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.002 .022 .9 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.002 .025 .923 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.002 .028 .933 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.001 .032 .937 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.001 .038 .937 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.001 .045 .935 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
0 .055 .928 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
0 .072 .917 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.001 .099 .896 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.002 .152 .851 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.003 .282 .728 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.005 .569 .386 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.007 .775 .166 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.01 .853 .096 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.016 .889 .065 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.025 .907 .049 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.043 .917 .038 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.093 .922 .031 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.41 .923 .026 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.851 .918 .023 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.915 .905 .02 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.936 .869 .017 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.945 .726 .016 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.949 .221 .014 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.951 .077 .013 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.952 .04 .012 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.951 .024 .011 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.948 .015 .01 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.945 .01 .009 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.939 .007 .009 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.931 .005 .008 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.918 .003 .008 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.898 .002 .007 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.86 .001 .007 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.779 0 .006 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.569 0 .006 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.283 .001 .006 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.155 .001 .006 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.102 .001 .005 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.075 .002 .005 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.059 .002 .005 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.048 .002 .005 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.041 .002 .004 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.046 .002 .005 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.056 .002 .005 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.071 .002 .005 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.096 .001 .005 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.141 .001 .005 r
.5 Mabswid
.56242 .70859 m
.64015 .5 L
s
0 0 0 r
2 Mabswid
.64015 .5 Mdot
.002 .018 .48 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.002 .02 .834 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.002 .022 .9 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.002 .025 .923 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.002 .028 .933 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.001 .032 .937 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.001 .038 .937 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.001 .045 .935 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
0 .055 .928 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
0 .072 .917 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.001 .099 .896 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.002 .152 .851 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.003 .282 .728 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.005 .569 .386 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.007 .775 .166 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.01 .853 .096 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.016 .889 .065 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.025 .907 .049 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.043 .917 .038 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.093 .922 .031 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.41 .923 .026 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.851 .918 .023 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.915 .905 .02 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.936 .869 .017 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.945 .726 .016 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.949 .221 .014 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.951 .077 .013 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.952 .04 .012 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.951 .024 .011 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.948 .015 .01 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.945 .01 .009 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.939 .007 .009 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.931 .005 .008 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.918 .003 .008 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.898 .002 .007 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.86 .001 .007 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.779 0 .006 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.569 0 .006 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.283 .001 .006 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.155 .001 .006 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.102 .001 .005 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.075 .002 .005 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.059 .002 .005 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.048 .002 .005 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.041 .002 .004 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.046 .002 .005 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.056 .002 .005 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.071 .002 .005 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.096 .001 .005 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.141 .001 .005 r
.5 Mabswid
.64015 .5 m
.75145 .5 L
s
0 0 0 r
2 Mabswid
.75145 .5 Mdot
.002 .018 .48 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.002 .02 .834 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.002 .022 .9 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.002 .025 .923 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.002 .028 .933 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.001 .032 .937 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.001 .038 .937 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.001 .045 .935 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
0 .055 .928 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
0 .072 .917 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.001 .099 .896 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.002 .152 .851 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.003 .282 .728 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.005 .569 .386 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.007 .775 .166 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.01 .853 .096 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.016 .889 .065 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.025 .907 .049 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.043 .917 .038 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.093 .922 .031 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.41 .923 .026 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.851 .918 .023 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.915 .905 .02 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.936 .869 .017 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.945 .726 .016 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.949 .221 .014 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.951 .077 .013 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.952 .04 .012 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.951 .024 .011 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.948 .015 .01 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.945 .01 .009 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.939 .007 .009 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.931 .005 .008 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.918 .003 .008 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.898 .002 .007 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.86 .001 .007 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.779 0 .006 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.569 0 .006 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.283 .001 .006 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.155 .001 .006 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.102 .001 .005 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.075 .002 .005 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.059 .002 .005 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.048 .002 .005 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.041 .002 .004 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.046 .002 .005 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.056 .002 .005 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.071 .002 .005 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.096 .001 .005 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.141 .001 .005 r
.5 Mabswid
.75145 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(FresnelRhomb)] .45112 .3846 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo05X0oooo0`0000030?ooo`040000
003oool0oooo0?ooo`80000000<0oooo0000000000000P3oool5000000040?ooo`00000000000?oo
o`H0000000@0oooo000000000000oooo1@0000000`3oool00000000000020?ooo`L0000000@0oooo
0000000000000000O03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool020000000oooo0?oo
o`000000oooo0000003oool00000103oool010000000oooo0?ooo`0000020?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool000000080oooo00P000000?ooo`3oool000000?ooo`000000
oooo000000<0oooo00<000000?ooo`000000N`3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`000002
0?ooo`080000003oool0oooo0?ooo`000000oooo0000003oool300000080oooo00H000000?ooo`3o
ool000000?ooo`0000040?ooo`050000003oool000000?ooo`0000000P3oool020000000oooo0?oo
o`000000oooo0000003oool000000`3oool00`000000oooo0000001k0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo05/0oooo0`0000020?ooo`80000000H0oooo0000003o
ool000000?ooo`0000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0oooo00@000000`3oool01@000000oooo0000003oool000000080oooo00P000000?ooo`3o
ool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000N`3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`000000oooo000000030?ooo`80000000@0oooo00000000000000000`3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000`3oool20000
0080oooo1@0000040?ooo`800000O03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`1K0?ooo`040000003oool0oooo000001H0oooo00@000000?ooo`3oool000000`3oool0
10000000oooo0?ooo`00000A0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0FP3oool5000001D0oooo0P0000000`3oool0000000000003
00000080oooo0P00000@0?ooo`800000O@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool08P3oool200000:T0oooo0P0000100?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0280oooo00<000000?ooo`000000Y`3oool00`000000oooo0000
00100?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool00P00002S0?ooo`8000000P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`2O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`040?ooo`800000V`3oool2000000H0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0U`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`07
0?ooo`800000U@3oool2000000T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0:0?ooo`80
0000S`3oool2000000`0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
R`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo08T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03P3oool2
000008L0oooo0P00000@0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool04@3oool200000840
oooo0P00000C0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo07d0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0503oool2000007/0oooo0P00
000F0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool05`3oool2000007D0oooo0P00000I0?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1_0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`0Q0?ooo`8000007@3oool3000006/0oooo0`00000M0?ooo`800000?P3o
ool2000000L0oooo00060?ooob@0900100<0000002@00@0T00407@0T00400`00000090010?ooo`1Z
0?ooof0090010P0000070?ooo`001P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
01d0oooo00<09001000000000000I`3oool20000000302@00@3oool0oooo01d0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo01h0oooo00<090010?ooo`000000I@3oool00`000000oooo02@00@0P0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0N0?ooo`0302@00@3oool0oooo00800000H@3oool200000080oooo
00<090010?ooo`3oool07P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07P3oool00`0T0040oooo0?oo
o`020?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool00P3oool00`0T0040oooo0?oo
o`0N0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`0302@00@3oool0oooo0080oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`0302@00@3oool0oooo01l0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo01l0oooo00<090010?ooo`3oool00`3oool2000005T0oooo0P0000050?oo
o`0302@00@3oool0oooo01l0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<090010?ooo`3o
ool01@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00D0oooo00<090010?ooo`3o
ool07`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0803oool00`0T0040oooo0?ooo`050?ooo`800000
D`3oool2000000L0oooo00<090010?ooo`3oool0803oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0803o
ool00`0T0040oooo0?ooo`070?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01`3o
ool00`0T0040oooo0?ooo`0P0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0P0?ooo`0302@00@3oool0
oooo00P0oooo0P00001=0?ooo`8000002P3oool00`0T0040oooo0?ooo`0P0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0Q0?ooo`0302@00@3oool0oooo00T0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`090?ooo`0302@00@3oool0oooo0240oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0240
oooo00<090010?ooo`3oool02P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00X0
oooo00<090010?ooo`3oool08@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08P3oool00`0T0040oooo
0?ooo`0:0?ooo`800000A@3oool2000000`0oooo00<090010?ooo`3oool08P3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool08P3oool00`0T0040oooo0?ooo`0<0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0303oool00`0T0040oooo0?ooo`0R0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0R
0?ooo`0302@00@3oool0oooo00d0oooo0P00000o0?ooo`8000003`3oool00`0T0040oooo0?ooo`0R
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`0302@00@3oool0oooo00h0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`0>0?ooo`0302@00@3oool0oooo02<0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo02<0oooo00<090010?ooo`3oool03`3oool2000003T0oooo0P00000A0?ooo`03
02@00@3oool0oooo02<0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<090010?ooo`3oool0
4@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0140oooo00<090010?ooo`3oool0
8`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0903oool00`0T0040oooo0?ooo`0A0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool04@3oool00`0T0040oooo0?ooo`0T0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0T0?ooo`0302@00@3oool0oooo0180oooo0P00000a0?ooo`800000503oool0
0`0T0040oooo0?ooo`0T0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0U0?ooo`0302@00@3oool0oooo
01<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0C0?ooo`0302@00@3oool0oooo
02D0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`0R0?ooo`8000009P3oool00`0T0040oooo0?ooo`0D0?ooo`800000:`3oool2000001H0
oooo00<090010?ooo`3oool0903oool200000400oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0S0?ooo`0302@00@3oool0oooo01H0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0F0?ooo`0302@00@3oool0oooo02<0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`0U0?ooo`800000903oool00`0T0040oooo0?ooo`0F0?ooo`8000009@3oool2000001P0oooo00<0
90010?ooo`3oool08P3oool2000004<0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0Q0?ooo`0302@00@3oool0oooo01P0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0H0?ooo`0302@00@3oool0oooo0240oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo0200oooo00<090010?ooo`3oool06@3oool2000001l0oooo0P00000K0?oo
o`0302@00@3oool0oooo0200oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`0Y0?ooo`8000008@3oool00`0T0040oooo0?ooo`0J0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`0T0040oooo0?ooo`0O0?ooo`80
0000A`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo01h0oooo00<090010?ooo`3oool06`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo01/0oooo00<090010?ooo`3oool07P3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02`0oooo0P00000N0?ooo`0302@00@3o
ool0oooo01`0oooo0P00000G0?ooo`8000007P3oool00`0T0040oooo0?ooo`0L0?ooo`800000BP3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo01`0oooo00<090010?ooo`3oool07@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo01d0oooo00<090010?ooo`3oool0703oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo02l0oooo0P00000L0?ooo`0302@00@3oool0oooo
01h0oooo0P00000A0?ooo`800000803oool00`0T0040oooo0?ooo`0J0?ooo`800000C@3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01X0
oooo00<090010?ooo`3oool07`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01l0
oooo00<090010?ooo`3oool06P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool06@3oool00`0T0040oooo
0?ooo`0P0?ooo`8000002`3oool200000280oooo00<090010?ooo`3oool06@3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03<0oooo0P00
000I0?ooo`0302@00@3oool0oooo0280oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0R0?ooo`0302@00@3oool0oooo01L0oooo0P00001A0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool05`3oool00`0T0040oooo0?ooo`0R
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool00`0T0040oooo0?ooo`0G
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0=P3oool2000001L0oooo00<090010?ooo`3oool08`3oool2000000<0oooo0P00000U0?oo
o`0302@00@3oool0oooo01D0oooo0P00001D0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool0503oool00`0T0040oooo0?ooo`0U0?ooo`<0
00009`3oool00`0T0040oooo0?ooo`0D0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0>@3oool2000001D0oooo00<090010?ooo`3oool0
9@3oool00`000000oooo0?ooo`0U0?ooo`0302@00@3oool0oooo01<0oooo0P00001G0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool04P3o
ool00`0T0040oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<090010?ooo`3oool04P3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo03`0oooo0P00000B0?ooo`0302@00@3oool0oooo02D0oooo00<000000?ooo`3oool09@3oool0
0`0T0040oooo0?ooo`0@0?ooo`800000FP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo0100oooo00<090010?ooo`3oool0903oool00`00
0000oooo0?ooo`0T0?ooo`0302@00@3oool0oooo0100oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00l0
oooo00<090010?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`0302@00@3oool0oooo00l0
oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`100?ooo`800000403oool00`0T0040oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo
00<090010?ooo`3oool03P3oool2000005h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0=0?ooo`0302@00@3oool0oooo02<0oooo00<0
00000?ooo`3oool08`3oool00`0T0040oooo0?ooo`0=0?ooo`030000003oool0oooo05h0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0@`3oool2000000d0oooo00<09001
0?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`0302@00@3oool0oooo00/0oooo0P00001Q
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool02`3oool00`0T0040oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<090010?oo
o`3oool02`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo04H0oooo0P00000;0?ooo`0302@00@3oool0oooo0280oooo00<000000?ooo`3o
ool08P3oool00`0T0040oooo0?ooo`090?ooo`800000I03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00P0oooo00<090010?ooo`3oool0
8P3oool00`000000oooo0?ooo`0R0?ooo`0302@00@3oool0oooo00P0oooo00<000000?ooo`3oool0
I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo00P0oooo00<090010?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`0302@00@3o
ool0oooo00P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`1:0?ooo`800000203oool00`0T0040oooo0?ooo`0Q0?ooo`030000003oool0
oooo0240oooo00<090010?ooo`3oool01P3oool2000006P0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`060?ooo`0302@00@3oool0oooo
0200oooo00<000000?ooo`3oool0803oool00`0T0040oooo0?ooo`060?ooo`030000003oool0oooo
06P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0C@3oool2000000H0
oooo00<090010?ooo`3oool0803oool00`000000oooo0?ooo`0P0?ooo`0302@00@3oool0oooo00@0
oooo0P00001[0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool00`3oool00`0T0040oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo
00<090010?ooo`3oool00`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0500oooo0P0000040?ooo`0302@00@3oool0oooo01l0oooo00<0
00000?ooo`3oool07`3oool00`0T0040oooo0?ooo`020?ooo`800000KP3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`1B0?ooo`050000003oool0oooo0?ooo`0T00408@3o
ool00`000000oooo0?ooo`0O0?ooo`0502@00@3oool0oooo0?ooo`000000L03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1C0?ooo`040000003oool0oooo02@00B40oooo
00<000000?ooo`3oool07`3oool0100T0040oooo0?ooo`00001a0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo05@0oooo0P0000000`3oool090010?ooo`0O0?ooo`030000
003oool0oooo01h0oooo00@090010?ooo`0000000000LP3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`1F0?ooo`030000000T0040oooo01l0oooo00<000000?ooo`3oool0
7P3oool00`0T004000000?ooo`1c0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo05L0oooo00<090010000000000007P3oool00`000000oooo0?ooo`0L0?ooo`80000000<0
90010?ooo`3oool0L`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1H
0?ooocl0900100<0000002@00@3oool0M@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`1J0?ooo`800000703oool00`000000oooo0?ooo`0J0?ooo`800000N03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0GP3oool2000001P0oooo00<000000?ooo`3oool05P3oool2000007`0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`1Q0?ooo`8000005@3oool00`000000oooo0?ooo`0C0?oo
o`800000O`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1o0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo06@0oooo0P00000B0?ooo`030000
003oool0oooo0100oooo0P0000220?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo06H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0880oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0I`3oool2
000000l0oooo00<000000?ooo`3oool03@3oool2000008D0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`1Z0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo06/0oooo
0P00000;0?ooo`030000003oool0oooo00T0oooo0P0000290?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0KP3oool2000000P0oooo00<000000?ooo`3oool01P3oool2000008`0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`1a0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`80
0000S`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo07@0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0M@3oool2000000030?ooo`000000oooo00800000T`3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`1g0?ooo`<00000U@3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo09@0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool200000?l0oooo4@3oool00`000000oooo0?ooo`050?ooo`001P3ooooo0000
01@000001`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.87539, -39.3754, 0.274393, \
0.274393}},
  CellTags->"Tracing through a FresnelRhomb"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.642857 1.90476 -19.0072 0.106484 [
[.30952 .1473 -9 -9 ]
[.30952 .1473 9 0 ]
[.5 .1473 -9 -9 ]
[.5 .1473 9 0 ]
[.69048 .1473 -9 -9 ]
[.69048 .1473 9 0 ]
[.88095 .1473 -9 -9 ]
[.88095 .1473 9 0 ]
[.10655 .05332 -18 -4.5 ]
[.10655 .05332 0 4.5 ]
[.10655 .26629 -18 -4.5 ]
[.10655 .26629 0 4.5 ]
[.10655 .37277 -18 -4.5 ]
[.10655 .37277 0 4.5 ]
[.10655 .47925 -18 -4.5 ]
[.10655 .47925 0 4.5 ]
[.10655 .58574 -18 -4.5 ]
[.10655 .58574 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.30952 .1598 m
.30952 .16605 L
s
[(0.5)] .30952 .1473 0 1 Mshowa
.5 .1598 m
.5 .16605 L
s
[(0.6)] .5 .1473 0 1 Mshowa
.69048 .1598 m
.69048 .16605 L
s
[(0.7)] .69048 .1473 0 1 Mshowa
.88095 .1598 m
.88095 .16605 L
s
[(0.8)] .88095 .1473 0 1 Mshowa
.125 Mabswid
.15714 .1598 m
.15714 .16355 L
s
.19524 .1598 m
.19524 .16355 L
s
.23333 .1598 m
.23333 .16355 L
s
.27143 .1598 m
.27143 .16355 L
s
.34762 .1598 m
.34762 .16355 L
s
.38571 .1598 m
.38571 .16355 L
s
.42381 .1598 m
.42381 .16355 L
s
.4619 .1598 m
.4619 .16355 L
s
.5381 .1598 m
.5381 .16355 L
s
.57619 .1598 m
.57619 .16355 L
s
.61429 .1598 m
.61429 .16355 L
s
.65238 .1598 m
.65238 .16355 L
s
.72857 .1598 m
.72857 .16355 L
s
.76667 .1598 m
.76667 .16355 L
s
.80476 .1598 m
.80476 .16355 L
s
.84286 .1598 m
.84286 .16355 L
s
.08095 .1598 m
.08095 .16355 L
s
.04286 .1598 m
.04286 .16355 L
s
.00476 .1598 m
.00476 .16355 L
s
.91905 .1598 m
.91905 .16355 L
s
.95714 .1598 m
.95714 .16355 L
s
.99524 .1598 m
.99524 .16355 L
s
.25 Mabswid
0 .1598 m
1 .1598 L
s
.11905 .05332 m
.1253 .05332 L
s
[(179)] .10655 .05332 1 0 Mshowa
.11905 .26629 m
.1253 .26629 L
s
[(181)] .10655 .26629 1 0 Mshowa
.11905 .37277 m
.1253 .37277 L
s
[(182)] .10655 .37277 1 0 Mshowa
.11905 .47925 m
.1253 .47925 L
s
[(183)] .10655 .47925 1 0 Mshowa
.11905 .58574 m
.1253 .58574 L
s
[(184)] .10655 .58574 1 0 Mshowa
.125 Mabswid
.11905 .07462 m
.1228 .07462 L
s
.11905 .09591 m
.1228 .09591 L
s
.11905 .11721 m
.1228 .11721 L
s
.11905 .13851 m
.1228 .13851 L
s
.11905 .1811 m
.1228 .1811 L
s
.11905 .2024 m
.1228 .2024 L
s
.11905 .22369 m
.1228 .22369 L
s
.11905 .24499 m
.1228 .24499 L
s
.11905 .28758 m
.1228 .28758 L
s
.11905 .30888 m
.1228 .30888 L
s
.11905 .33018 m
.1228 .33018 L
s
.11905 .35147 m
.1228 .35147 L
s
.11905 .39407 m
.1228 .39407 L
s
.11905 .41536 m
.1228 .41536 L
s
.11905 .43666 m
.1228 .43666 L
s
.11905 .45796 m
.1228 .45796 L
s
.11905 .50055 m
.1228 .50055 L
s
.11905 .52185 m
.1228 .52185 L
s
.11905 .54314 m
.1228 .54314 L
s
.11905 .56444 m
.1228 .56444 L
s
.11905 .03202 m
.1228 .03202 L
s
.11905 .01073 m
.1228 .01073 L
s
.11905 .60703 m
.1228 .60703 L
s
.25 Mabswid
.11905 0 m
.11905 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.04325 .56473 L
.06268 .52944 L
.08212 .49705 L
.10155 .46724 L
.12099 .43973 L
.14043 .41427 L
.15986 .39066 L
.1793 .3687 L
.19874 .34824 L
.21817 .32914 L
.23761 .31128 L
.25705 .29453 L
.27648 .27881 L
.29592 .26402 L
.31535 .2501 L
.33479 .23695 L
.35423 .22453 L
.37366 .21278 L
.3931 .20164 L
.41254 .19106 L
.43197 .18101 L
.45141 .17144 L
.47085 .16232 L
.49028 .15362 L
.50972 .14531 L
.52915 .13735 L
.54859 .12973 L
.56803 .12242 L
.58746 .11541 L
.6069 .10867 L
.62634 .10218 L
.64577 .09593 L
.66521 .0899 L
.68465 .08408 L
.70408 .07845 L
.72352 .07301 L
.74295 .06774 L
.76239 .06263 L
.78183 .05768 L
.80126 .05286 L
.8207 .04818 L
.84014 .04363 L
.85957 .03919 L
.87901 .03487 L
.89845 .03065 L
.91788 .02653 L
.93732 .02251 L
.95675 .01857 L
.97619 .01472 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{366.312, 226.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005^0000hR000`400?l00000o`00003o:`3oool0
0`000000oooo0?ooo`3o0?oood40oooo000[0?ooo`030000003oool0oooo0?l0oooo@@3oool002/0
oooo00<000000?ooo`3oool0o`3ooom10?ooo`00:`3oool00`000000oooo0?ooo`3o0?oood40oooo
000[0?ooo`<00000o`3ooom10?ooo`00:`3oool00`000000oooo0?ooo`3o0?ooocD0oooo0`000009
0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooc80oooo0`00000<0?ooo`00:`3oool00`000000
oooo0?ooo`3o0?ooobd0oooo1@00000?0?ooo`00:`3oool00`000000oooo0?ooo`3o0?ooobL0oooo
1P00000D0?ooo`00:`3oool00`000000oooo0?ooo`3o0?ooob@0oooo0`00000J0?ooo`00:`3oool0
0`000000oooo0?ooo`3o0?oooah0oooo1P00000M0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oo
oaP0oooo1P00000S0?ooo`00:`3oool300000?l0oooo5@3oool3000002T0oooo000[0?ooo`030000
003oool0oooo0?l0oooo403oool5000002`0oooo000[0?ooo`030000003oool0oooo0?l0oooo2P3o
ool600000340oooo000[0?ooo`030000003oool0oooo0?l0oooo1`3oool3000003L0oooo000[0?oo
o`030000003oool0oooo0?l0oooo0`3oool4000003X0oooo000F0?ooo`<00000103oool00`000000
oooo0?ooo`020?ooo`8000001`3oool00`000000oooo0?ooo`3o0?ooo`<00000?P3oool001L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0nP3oool500000440oooo000G0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?@0oooo1P00
00160?ooo`005`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`@000001@3o
ool400000?00oooo0`00001<0?ooo`005`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3]0?ooo`@00000C`3oool0
01H0oooo0P0000030?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0jP3oool3000005<0oooo000G0?ooo`040000003oool0
oooo0?ooo`D000000P3oool3000000H0oooo00<000000?ooo`3oool0iP3oool4000005H0oooo000[
0?ooo`030000003oool0oooo0><0oooo0`00001J0?ooo`00:`3oool00`000000oooo0?ooo`3O0?oo
o`@00000G@3oool002/0oooo00<000000?ooo`3oool0g03oool300000640oooo000[0?ooo`<00000
f03oool4000006@0oooo000[0?ooo`030000003oool0oooo0=D0oooo0`00001X0?ooo`00:`3oool0
0`000000oooo0?ooo`3A0?ooo`@00000J`3oool002/0oooo00<000000?ooo`3oool0c@3oool40000
06l0oooo000[0?ooo`030000003oool0oooo0<T0oooo1000001c0?ooo`00:`3oool00`000000oooo
0?ooo`360?ooo`<00000M`3oool002/0oooo00<000000?ooo`3oool0`P3oool4000007X0oooo000[
0?ooo`030000003oool0oooo0;l0oooo0`00001n0?ooo`00:`3oool300000;/0oooo100000210?oo
o`00:`3oool00`000000oooo0?ooo`2h0?ooo`<00000Q@3oool002/0oooo00<000000?ooo`3oool0
]@3oool3000008P0oooo000[0?ooo`030000003oool0oooo0;80oooo0`00002;0?ooo`00:`3oool0
0`000000oooo0?ooo`2`0?ooo`800000SP3oool002/0oooo00<000000?ooo`3oool0[@3oool30000
0900oooo000[0?ooo`030000003oool0oooo0:X0oooo0`00002C0?ooo`00:`3oool00`000000oooo
0?ooo`2W0?ooo`<00000UP3oool002/0oooo0`00002T0?ooo`<00000V@3oool002/0oooo00<00000
0?ooo`3oool0XP3oool2000009`0oooo000[0?ooo`030000003oool0oooo09l0oooo0`00002N0?oo
o`00:`3oool00`000000oooo0?ooo`0l0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<0
0000=`3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000d0oooo0`00000X0?ooo`80
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03H0oooo0P0000040?ooo`03
0000003oool0oooo0080oooo0`00000V0?ooo`00:`3oool00`000000oooo0?ooo`0k0?ooo`040000
003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000e0?ooo`040000003oool0oooo
000000L0oooo00D000000?ooo`3oool0oooo000000090?ooo`<00000:P3oool010000000oooo0?oo
o`0000090?ooo`030000003oool0oooo03D0oooo00@000000?ooo`3oool000001`3oool01@000000
oooo0?ooo`3oool0000002D0oooo000[0?ooo`030000003oool0oooo03/0oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`0c0?ooo`040000003oool0oooo000000L0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`<00000;@3oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo03@0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool00000
02D0oooo000[0?ooo`030000003oool0oooo03/0oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo0?ooo`0c0?ooo`040000003oool0oooo000000L0oooo100000050?ooo`800000<03oool0
10000000oooo0?ooo`00000:0?ooo`030000003oool0oooo03@0oooo00@000000?ooo`3oool00000
203oool3000002H0oooo000[0?ooo`030000003oool0oooo03/0oooo00@000000?ooo`3oool00000
1`3oool4000003H0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`040?ooo`80
0000<P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo03<0oooo00@000000?oo
o`3oool000001`3oool01@000000oooo0?ooo`3oool0000002D0oooo000[0?ooo`<00000>`3oool0
10000000oooo0?ooo`0000070?ooo`030000003oool0oooo03L0oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`03000003@0oooo00@000000?ooo`3oool000001`3oool01@000000
oooo0?ooo`3oool0000003D0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3o
ool0000002D0oooo000[0?ooo`030000003oool0oooo03`0oooo0P0000080?ooo`D00000=P3oool2
000000X0oooo0P00000h0?ooo`800000203oool5000003H0oooo0P0000090?ooo`<000009P3oool0
02/0oooo00<000000?ooo`3oool0R`3oool200000;<0oooo000[0?ooo`030000003oool0oooo08P0
oooo0`00002e0?ooo`00:`3oool00`000000oooo0?ooo`260?ooo`800000^03oool002/0oooo00<0
00000?ooo`3oool0Q03oool200000;X0oooo000[0?ooo`030000003oool0oooo0840oooo0`00002l
0?ooo`00o`00001^00000040oooo00020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo008000002@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool3000000/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool100000040oooo0@3oool002/0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`0c0?ooo`8000003@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0M`3oool200000<L0oooo000[0?oo
o`030000003oool0oooo07D0oooo0P0000390?ooo`00:`3oool00`000000oooo0?ooo`1b0?ooo`<0
0000b`3oool002/0oooo00<000000?ooo`3oool0L03oool200000<h0oooo000[0?ooo`<00000KP3o
ool200000=00oooo000[0?ooo`030000003oool0oooo06`0oooo0P00003B0?ooo`00:`3oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo0=80oooo000[0?ooo`030000003oool0oooo06T0
oooo0P00003E0?ooo`00:`3oool00`000000oooo0?ooo`1W0?ooo`800000e`3oool002/0oooo00<0
00000?ooo`3oool0I@3oool200000=T0oooo000[0?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool0f@3oool002/0oooo00<000000?ooo`3oool0HP3oool200000=`0oooo000[0?ooo`<0
0000H03oool200000=h0oooo000[0?ooo`030000003oool0oooo05h0oooo0P00003P0?ooo`00:`3o
ool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0>00oooo000[0?ooo`030000003oool0
oooo05/0oooo0P00003S0?ooo`00:`3oool00`000000oooo0?ooo`1I0?ooo`800000i@3oool002/0
oooo00<000000?ooo`3oool0E`3oool200000>L0oooo000[0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool0i`3oool002/0oooo00<000000?ooo`3oool0E03oool200000>X0oooo000[
0?ooo`<00000DP3oool200000>`0oooo000[0?ooo`030000003oool0oooo0540oooo00<000000?oo
o`3oool0k03oool002/0oooo00<000000?ooo`3oool0C`3oool200000>l0oooo000[0?ooo`030000
003oool0oooo04h0oooo00<000000?ooo`3oool0k`3oool002/0oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`3`0?ooo`00:`3oool00`000000oooo0?ooo`1;0?ooo`800000l`3oool0
02/0oooo00<000000?ooo`3oool0B@3oool200000?D0oooo000[0?ooo`<00000B03oool00`000000
oooo0?ooo`3e0?ooo`00:`3oool00`000000oooo0?ooo`160?ooo`800000n03oool002/0oooo00<0
00000?ooo`3oool0A03oool200000?X0oooo000[0?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool0nP3oool002/0oooo00<000000?ooo`3oool0@@3oool200000?d0oooo000[0?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool0o@3oool001H0oooo0`0000030?ooo`<00000
0`3oool3000000H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`3n0?ooo`005`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000070?ooo`03
0000003oool0oooo03d0oooo0P00003o0?ooo`80oooo000G0?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000L0oooo1000000k0?ooo`030000003oool0oooo
0?l0oooo0P3oool001L0oooo00<000000?ooo`3oool00P3oool3000000@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0oooo0`3oool001L0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000001`3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo0?l0oooo103oool001H0oooo0P0000030?ooo`05
0000003oool0oooo0?ooo`0000000P3oool2000000L0oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`3o0?ooo`D0oooo000G0?ooo`030000003oool0oooo0080oooo0`0000040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`3o0?ooo`H0
oooo000[0?ooo`030000003oool0oooo03H0oooo0P00003o0?ooo`T0oooo000[0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0o`3oool90?ooo`00:`3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0?l0oooo2P3oool002/0oooo0`00000c0?ooo`030000003oool0oooo
0?l0oooo2`3oool002/0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3o0?ooo``0
oooo000[0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0o`3oool=0?ooo`00:`3o
ool00`000000oooo0?ooo`0_0?ooo`800000o`3oool@0?ooo`00:`3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0?l0oooo403oool002/0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`3o0?oooa40oooo000[0?ooo`030000003oool0oooo02/0oooo0P00003o0?oooa@0
oooo000[0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`00:`3o
ool3000002T0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`00:`3oool00`000000oooo0?ooo`0W
0?ooo`800000o`3ooolH0?ooo`00:`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
0?l0oooo603oool002/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?oooaT0
oooo000[0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`00:`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0?l0oooo6`3oool002/0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?oooa`0oooo000[0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0o`3ooolM0?ooo`00:`3oool300000200oooo00<000000?ooo`3o
ool0o`3ooolN0?ooo`00:`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0oooo
7`3oool002/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?ooob00oooo000[
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`00:`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0oooo8P3oool002/0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`3o0?ooob<0oooo000[0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0o`3ooolT0?ooo`00:`3oool3000001X0oooo00<000000?ooo`3oool0o`3o
oolT0?ooo`00:`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0oooo9@3oool0
02/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3o0?ooobH0oooo000[0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`00:`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo0?l0oooo:03oool002/0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`3o0?ooobT0oooo000F0?ooo`<000000`3oool300000080oooo1@000005
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`005`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3oool[0?ooo`005`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000070?ooo`@00000
4P3oool00`000000oooo0?ooo`3o0?ooob/0oooo000G0?ooo`030000003oool0oooo0080oooo0`00
00050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`3o0?ooob`0oooo000G0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0000
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`3o0?ooobd0oooo000F0?ooo`8000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
o`3oool^0?ooo`005`3oool00`000000oooo0?ooo`020?ooo`<000000`3oool3000000H0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooobl0oooo000[0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0o`3oool`0?ooo`00:`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0?l0oooo<@3oool002/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`3o0?oooc80oooo000[0?ooo`<00000303oool00`000000oooo0?ooo`3o0?oooc80oooo
000[0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`00:`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo=03oool002/0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`3o0?ooocD0oooo000[0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0o`3ooolf0?ooo`00:`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0?l0oooo=`3oool002/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`3o0?ooocP0oooo000[0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oooli
0?ooo`00:`3oool3000000D0oooo00<000000?ooo`3oool0o`3oooli0?ooo`00:`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo>P3oool002/0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`3o0?oooc/0oooo000[0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0o`3oooll0?ooo`00:`3oool01@000000oooo0?ooo`3oool000000?l0oooo?`3o
ool002/0oooo00D000000?ooo`3oool0oooo0000003o0?ooocl0oooo000[0?ooo`040000003oool0
oooo00000?l0oooo@03oool002/0oooo0`00003o0?oood40oooo000[0?ooo`800000o`3ooom20?oo
o`00:`3oool200000?l0oooo@P3oool002/0oooo00<000000?ooo`3oool0o`3ooom10?ooo`00:P3o
ool200000?l0oooo@`3oool002X0oooo0P00003o0?oood<0oooo000Y0?ooo`030000003oool00000
0?l0oooo@`3oool002P0oooo00@000000?ooo`3oool00000o`3ooom30?ooo`00:03oool00`000000
oooo0?ooo`0300000?l0oooo@@3oool002L0oooo00D000000?ooo`3oool0oooo0000003o0?oood<0
oooo000W0?ooo`050000003oool0oooo0?ooo`000000o`3ooom30?ooo`009P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0?l0oooo@@3oool002D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`3o0?oood40oooo000F0?ooo`<000000`3oool3000000<0oooo10000005
0?ooo`030000003oool0oooo0?l0oooo@@3oool001L0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool000000080oooo0P0000050?ooo`030000003oool0oooo0?l0oooo@@3oool0
01L0oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo
000000050?ooo`030000003oool0oooo0?l0oooo@@3oool001L0oooo00<000000?ooo`3oool00P3o
ool3000000@0oooo0P0000060?ooo`@00000o`3ooom00?ooo`005`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0?l0oooo@@3oool001H0oooo0P0000030?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooom10?ooo`00
5`3oool00`000000oooo0?ooo`020?ooo`<0000000<0oooo0000003oool00`0000060?ooo`030000
003oool0oooo0?l0oooo@@3oool00200oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`3o0?oood40oooo000O0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooom1
0?ooo`007P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo@@3oool001h0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oood40oooo000M0?ooo`030000
003oool0oooo00/0oooo0`00003o0?oood40oooo000M0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0o`3ooom10?ooo`00703oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0?l0oooo@@3oool001/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oo
od40oooo000K0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooom10?ooo`00
6P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo@@3oool001X0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?oood40oooo000I0?ooo`030000003oool0
oooo00l0oooo0`00003o0?oood40oooo000H0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0o`3ooom10?ooo`00603oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0
oooo@@3oool001L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?oood40oooo
000G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooom10?ooo`005P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0oooo@@3oool001H0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`3o0?oood40oooo000E0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0o`3ooom10?ooo`005@3oool00`000000oooo0?ooo`0C0?ooo`<00000
o`3ooom10?ooo`00503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo@@3o
ool001<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3o0?oood40oooo000C0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooom10?ooo`004P3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0oooo@@3oool00180oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`3o0?oood40oooo000A0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0o`3ooom10?ooo`004@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo0?l0oooo@@3oool00100oooo00<000000?ooo`3oool0603oool300000?l0oooo@@3oool00100
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3o0?oood40oooo000?0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0o`3ooom10?ooo`003`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo0?l0oooo@@3oool000h0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`3o0?oood40oooo000>0?ooo`030000003oool0oooo00D0oooo0`0000030?oo
o`<00000103oool3000000D0oooo00<000000?ooo`3oool0o`3ooom10?ooo`003@3oool00`000000
oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooom10?ooo`003@3oool00`000000
oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000040000
00D0oooo00<000000?ooo`3oool0o`3ooom10?ooo`00303oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo0`0000020?ooo`040000003oool0oooo000000H0oooo1000003o0?oo
od00oooo000<0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000030?oo
o`060000003oool0oooo0000003oool000001P3oool00`000000oooo0?ooo`3o0?oood40oooo000;
0?ooo`030000003oool0oooo00P0oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool2000000H0oooo00<000000?ooo`3oool0o`3ooom10?ooo`002`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0o`3ooom10?ooo`002P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
0?l0oooo@@3oool000X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?oood40
oooo00090?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3ooom10?ooo`00:`3o
ool300000?l0oooo@@3oool002/0oooo00<000000?ooo`3oool0o`3ooom10?ooo`00:`3oool00`00
0000oooo0?ooo`3o0?oood40oooo000[0?ooo`030000003oool0oooo0?l0oooo@@3oool002/0oooo
00<000000?ooo`3oool0o`3ooom10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 365.312}, {225.375, 0}} -> {0.337033, 178.498, \
0.00143969, 0.0257528}},
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["LinearPolarizer", "Section",
  CellTags->"LinearPolarizer"],

Cell[CellGroupData[{

Cell["Options[LinearPolarizer]", "Input",
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    \({Labels \[Rule] "LP", LabelPositions \[Rule] Automatic, 
      ComponentMedium \[Rule] CrownGlass, 
      ComponentDescription \[Rule] Automatic, Transmittance \[Rule] {100, 0}, 
      GraphicDesign \[Rule] Automatic, SplitRays \[Rule] False, 
      CenterThickness \[Rule] 0, Centered \[Rule] True, 
      Automatic \[Rule] {SurfaceRendering \[Rule] Empty, 
          EdgeRendering \[Rule] Mesh, 
          CrossRendering \[Rule] {{Fill, Trace}}}, 
      Off \[Rule] {SurfaceRendering \[Rule] Empty, 
          EdgeRendering \[Rule] Empty, CrossRendering \[Rule] Empty}, 
      Sketch \[Rule] {SurfaceRendering \[Rule] Trace, 
          EdgeRendering \[Rule] Empty, 
          CrossRendering \[Rule] {{Fill, Trace}}}, 
      Wire \[Rule] {SurfaceRendering \[Rule] Mesh, 
          EdgeRendering \[Rule] Mesh, 
          CrossRendering \[Rule] {{Fill, Trace}}}, 
      Solid \[Rule] {SurfaceRendering \[Rule] {{Fill, Trace}}, 
          EdgeRendering \[Rule] Fill, 
          CrossRendering \[Rule] Empty}}\)], "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[LinearPolarizer[90,100,5]]", "Input",
  CellTags->"LinearPolarizer"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.32308 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.629266 2.37025 0 2.37025 [
[ 0 0 0 0 ]
[ 1 2.32308 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 2.32308 L
0 2.32308 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.82471 1.22951 m
.79908 1.13803 L
s
.79908 1.13803 m
.83176 1.12764 L
s
.79908 1.13803 m
.76924 1.04754 L
s
.76924 1.04754 m
.80186 1.03693 L
s
.76924 1.04754 m
.73552 .95908 L
s
.84584 1.32097 m
.82471 1.22951 L
s
.82471 1.22951 m
.85751 1.21933 L
s
.85751 1.21933 m
.83176 1.12764 L
s
.83176 1.12764 m
.8646 1.1172 L
s
.83176 1.12764 m
.80186 1.03693 L
s
.73552 .95908 m
.76814 .94823 L
s
.73552 .95908 m
.69829 .87365 L
s
.80186 1.03693 m
.83464 1.02627 L
s
.80186 1.03693 m
.76814 .94823 L
s
.8788 1.31097 m
.85751 1.21933 L
s
.85751 1.21933 m
.89046 1.20909 L
s
.8646 1.1172 m
.89046 1.20909 L
s
.83464 1.02627 m
.8646 1.1172 L
s
.76814 .94823 m
.80092 .93733 L
s
.76814 .94823 m
.73096 .86255 L
s
.86216 1.41135 m
.84584 1.32097 L
s
.84584 1.32097 m
.8788 1.31097 L
s
.80092 .93733 m
.83464 1.02627 L
s
.89046 1.20909 m
.91192 1.30091 L
s
.69829 .87365 m
.73096 .86255 L
s
.69829 .87365 m
.65793 .79229 L
s
.76379 .8514 m
.80092 .93733 L
s
.89534 1.40151 m
.8788 1.31097 L
s
.8788 1.31097 m
.91192 1.30091 L
s
.73096 .86255 m
.76379 .8514 L
s
.73096 .86255 m
.69071 .78092 L
s
.91192 1.30091 m
.92869 1.39162 L
s
.87341 1.49957 m
.86216 1.41135 L
s
.86216 1.41135 m
.89534 1.40151 L
s
.72364 .7695 m
.76379 .8514 L
s
.90686 1.48987 m
.89534 1.40151 L
s
.89534 1.40151 m
.92869 1.39162 L
s
.65793 .79229 m
.69071 .78092 L
s
.65793 .79229 m
.61486 .71602 L
s
.92869 1.39162 m
.94048 1.48013 L
s
.69071 .78092 m
.72364 .7695 L
s
.69071 .78092 m
.64779 .70438 L
s
.87341 1.49957 m
.90686 1.48987 L
s
.68089 .69268 m
.72364 .7695 L
s
.90686 1.48987 m
.94048 1.48013 L
s
.61486 .71602 m
.64779 .70438 L
s
.61486 .71602 m
.56953 .64591 L
s
.64779 .70438 m
.68089 .69268 L
s
.64779 .70438 m
.60268 .63398 L
s
.63598 .62199 m
.68089 .69268 L
s
.82399 1.52484 m .91311 1.57495 L .87934 1.58453 L .656 .751 .92 r
F
0 g
.87934 1.58453 m
.87973 1.66508 L
s
.87341 1.49957 m
.87726 1.55479 L
s
.85814 1.51497 m .94705 1.56533 L .91311 1.57495 L .656 .751 .92 r
F
0 g
.90686 1.48987 m
.9109 1.54485 L
s
.82399 1.52484 m .85814 1.51497 L .91311 1.57495 L .656 .751 .92 r
F
0 g
.87934 1.58453 m
.91311 1.57495 L
s
.91311 1.57495 m
.91387 1.6556 L
s
.56953 .64591 m
.60268 .63398 L
s
.85814 1.51497 m .89247 1.50505 L .94705 1.56533 L .656 .751 .92 r
F
0 g
.94705 1.56533 m
.94817 1.64607 L
s
.91311 1.57495 m
.94705 1.56533 L
s
.94048 1.48013 m
.94705 1.56533 L
s
.60268 .63398 m
.63598 .62199 L
s
.8744 1.74003 m
.87973 1.66508 L
s
.87973 1.66508 m
.91387 1.6556 L
s
.90894 1.73063 m
.91387 1.6556 L
s
.91387 1.6556 m
.94817 1.64607 L
s
.76692 1.4633 m .85814 1.51497 L .82399 1.52484 L .656 .751 .92 r
F
0 g
.82399 1.52484 m
.87934 1.58453 L
s
.52246 .58302 m .55586 .66655 L .52203 .67869 L .544 .324 .532 r
F
.52246 .58302 m .55586 .5708 L .55586 .66655 L F
0 g
.55586 .62764 m
.56953 .64591 L
s
.4742 .52842 m
.52246 .58302 L
s
.94817 1.64607 m
.94366 1.72117 L
s
.80146 1.45312 m .89247 1.50505 L .85814 1.51497 L .656 .751 .92 r
F
.76692 1.4633 m .80146 1.45312 L .85814 1.51497 L F
0 g
.85814 1.51497 m
.91311 1.57495 L
s
.55586 .5708 m .58986 .65435 L .55586 .66655 L .544 .324 .532 r
F
.55586 .5708 m .58943 .55851 L .58986 .65435 L F
0 g
.58943 .55851 m
.63598 .62199 L
s
.58969 .61646 m
.60268 .63398 L
s
.52246 .58302 m
.55586 .5708 L
s
.55586 .5708 m
.58943 .55851 L
s
.50791 .5159 m
.55586 .5708 L
s
.80146 1.45312 m .83617 1.44288 L .89247 1.50505 L .656 .751 .92 r
F
0 g
.89247 1.50505 m
.94705 1.56533 L
s
.54178 .50332 m
.58943 .55851 L
s
.8632 1.80818 m
.8744 1.74003 L
s
.8744 1.74003 m
.90894 1.73063 L
s
.89819 1.79882 m
.90894 1.73063 L
s
.90894 1.73063 m
.94366 1.72117 L
s
.94366 1.72117 m
.93336 1.78941 L
s
.4742 .52842 m
.50791 .5159 L
s
.4742 .52842 m
.42537 .48318 L
s
.52203 .67869 m .55586 .76481 L .52159 .77686 L .544 .324 .532 r
F
.52203 .67869 m .55586 .66655 L .55586 .76481 L F
0 g
.52203 .67869 m
.52246 .58302 L
s
.50791 .5159 m
.54178 .50332 L
s
.50791 .5159 m
.45943 .47037 L
s
.55586 .66655 m .59031 .75271 L .55586 .76481 L .544 .324 .532 r
F
.55586 .66655 m .58986 .65435 L .59031 .75271 L F
0 g
.55586 .5708 m
.55586 .66655 L
s
.58943 .55851 m
.58986 .65435 L
s
.70804 1.39981 m .80146 1.45312 L .76692 1.4633 L .656 .751 .92 r
F
0 g
.76692 1.4633 m
.82399 1.52484 L
s
.49366 .45749 m
.54178 .50332 L
s
.74298 1.3893 m .83617 1.44288 L .80146 1.45312 L .656 .751 .92 r
F
.70804 1.39981 m .74298 1.3893 L .80146 1.45312 L F
0 g
.80146 1.45312 m
.85814 1.51497 L
s
.74298 1.3893 m .77809 1.37874 L .83617 1.44288 L .656 .751 .92 r
F
0 g
.83617 1.44288 m
.89247 1.50505 L
s
.84606 1.86826 m
.8632 1.80818 L
s
.8632 1.80818 m
.89819 1.79882 L
s
.88152 1.85891 m
.89819 1.79882 L
s
.89819 1.79882 m
.93336 1.78941 L
s
.52159 .77686 m .55586 .8657 L .52113 .87764 L .544 .324 .532 r
F
.52159 .77686 m .55586 .76481 L .55586 .8657 L F
0 g
.52159 .77686 m
.52203 .67869 L
s
.93336 1.78941 m
.91717 1.84952 L
s
.42537 .48318 m
.45943 .47037 L
s
.42537 .48318 m
.37664 .44836 L
s
.55586 .76481 m .59077 .85369 L .55586 .8657 L .544 .324 .532 r
F
.55586 .76481 m .59031 .75271 L .59077 .85369 L F
0 g
.55586 .66655 m
.55586 .76481 L
s
.58986 .65435 m
.59031 .75271 L
s
.45943 .47037 m
.49366 .45749 L
s
.45943 .47037 m
.4111 .43526 L
s
.64727 1.33428 m .74298 1.3893 L .70804 1.39981 L .656 .751 .92 r
F
0 g
.70804 1.39981 m
.76692 1.4633 L
s
.44573 .4221 m
.49366 .45749 L
s
.68261 1.32344 m .77809 1.37874 L .74298 1.3893 L .656 .751 .92 r
F
.64727 1.33428 m .68261 1.32344 L .74298 1.3893 L F
0 g
.74298 1.3893 m
.80146 1.45312 L
s
.82296 1.91902 m
.84606 1.86826 L
s
.84606 1.86826 m
.88152 1.85891 L
s
.68261 1.32344 m .71814 1.31253 L .77809 1.37874 L .656 .751 .92 r
F
0 g
.77809 1.37874 m
.83617 1.44288 L
s
.85892 1.90966 m
.88152 1.85891 L
s
.88152 1.85891 m
.91717 1.84952 L
s
.52113 .87764 m .55586 .9693 L .52066 .98114 L .544 .324 .532 r
F
.52113 .87764 m .55586 .8657 L .55586 .9693 L F
0 g
.52113 .87764 m
.52159 .77686 L
s
.91717 1.84952 m
.89508 1.90025 L
s
.55586 .8657 m .59124 .9574 L .55586 .9693 L .544 .324 .532 r
F
.55586 .8657 m .59077 .85369 L .59124 .9574 L F
0 g
.55586 .76481 m
.55586 .8657 L
s
.59031 .75271 m
.59077 .85369 L
s
.37664 .44836 m
.4111 .43526 L
s
.37664 .44836 m
.32878 .42497 L
s
.4111 .43526 m
.44573 .4221 L
s
.4111 .43526 m
.36366 .4116 L
s
.58452 1.26662 m .68261 1.32344 L .64727 1.33428 L .656 .751 .92 r
F
0 g
.64727 1.33428 m
.70804 1.39981 L
s
.39873 .39816 m
.44573 .4221 L
s
.62027 1.25541 m .71814 1.31253 L .68261 1.32344 L .656 .751 .92 r
F
.58452 1.26662 m .62027 1.25541 L .68261 1.32344 L F
0 g
.68261 1.32344 m
.74298 1.3893 L
s
.79398 1.95923 m
.82296 1.91902 L
s
.82296 1.91902 m
.85892 1.90966 L
s
.62027 1.25541 m .65622 1.24415 L .71814 1.31253 L .656 .751 .92 r
F
0 g
.71814 1.31253 m
.77809 1.37874 L
s
.52066 .98114 m .55586 1.07574 L .52018 1.08745 L .544 .324 .532 r
F
.52066 .98114 m .55586 .9693 L .55586 1.07574 L F
0 g
.52066 .98114 m
.52113 .87764 L
s
.83046 1.94982 m
.85892 1.90966 L
s
.85892 1.90966 m
.89508 1.90025 L
s
.55586 .9693 m .59173 1.06396 L .55586 1.07574 L .544 .324 .532 r
F
.55586 .9693 m .59124 .9574 L .59173 1.06396 L F
0 g
.55586 .8657 m
.55586 .9693 L
s
.59077 .85369 m
.59124 .9574 L
s
.89508 1.90025 m
.86714 1.94036 L
s
.32878 .42497 m
.36366 .4116 L
s
.32878 .42497 m
.28257 .41394 L
s
.36366 .4116 m
.39873 .39816 L
s
.36366 .4116 m
.31792 .40031 L
s
.35345 .38661 m
.39873 .39816 L
s
.51969 1.19671 m .62027 1.25541 L .58452 1.26662 L .656 .751 .92 r
F
0 g
.58452 1.26662 m
.64727 1.33428 L
s
.55586 1.18513 m .65622 1.24415 L .62027 1.25541 L .656 .751 .92 r
F
.51969 1.19671 m .55586 1.18513 L .62027 1.25541 L F
0 g
.62027 1.25541 m
.68261 1.32344 L
s
.52018 1.08745 m .55586 1.18513 L .51969 1.19671 L .544 .324 .532 r
F
.52018 1.08745 m .55586 1.07574 L .55586 1.18513 L F
0 g
.52018 1.08745 m
.52066 .98114 L
s
.83046 1.94982 m
.79398 1.95923 L
s
.75929 1.98768 m
.79398 1.95923 L
s
.55586 1.18513 m .59223 1.17348 L .65622 1.24415 L .656 .751 .92 r
F
0 g
.65622 1.24415 m
.71814 1.31253 L
s
.55586 1.07574 m .59223 1.17348 L .55586 1.18513 L .544 .324 .532 r
F
.55586 1.07574 m .59173 1.06396 L .59223 1.17348 L F
0 g
.55586 .9693 m
.55586 1.07574 L
s
.59124 .9574 m
.59173 1.06396 L
s
.86714 1.94036 m
.83046 1.94982 L
s
.79631 1.97819 m
.83046 1.94982 L
s
.86714 1.94036 m
.83352 1.96865 L
s
.28257 .41394 m
.31792 .40031 L
s
.28257 .41394 m
.23889 .41608 L
s
.31792 .40031 m
.35345 .38661 L
s
.31792 .40031 m
.27473 .40223 L
s
.51969 1.19671 m .55586 1.29759 L .51918 1.30903 L .544 .324 .532 r
F
.51969 1.19671 m .55586 1.18513 L .55586 1.29759 L F
0 g
.55586 1.23571 m
.58452 1.26662 L
s
.45267 1.12444 m .55586 1.18513 L .51969 1.19671 L .656 .751 .92 r
F
0 g
.51984 1.16394 m
.52018 1.08745 L
s
.31076 .3883 m
.35345 .38661 L
s
.55586 1.18513 m .59274 1.28609 L .55586 1.29759 L .544 .324 .532 r
F
.55586 1.18513 m .59223 1.17348 L .59274 1.28609 L F
0 g
.59246 1.22507 m
.62027 1.25541 L
s
.48927 1.11246 m .59223 1.17348 L .55586 1.18513 L .656 .751 .92 r
F
0 g
.55586 1.07574 m
.55586 1.15193 L
s
.45267 1.12444 m .48927 1.11246 L .55586 1.18513 L .656 .751 .92 r
F
0 g
.71922 2.00327 m
.75929 1.98768 L
s
.75929 1.98768 m
.79631 1.97819 L
s
.48927 1.11246 m .52607 1.10042 L .59223 1.17348 L .656 .751 .92 r
F
0 g
.59223 1.17348 m
.65622 1.24415 L
s
.59173 1.06396 m
.59223 1.17348 L
s
.75676 1.99366 m
.79631 1.97819 L
s
.79631 1.97819 m
.83352 1.96865 L
s
.83352 1.96865 m
.79451 1.984 L
s
.23889 .41608 m
.27473 .40223 L
s
.23889 .41608 m
.19864 .43205 L
s
.51918 1.30903 m .55586 1.41326 L .51866 1.42454 L .544 .324 .532 r
F
.51918 1.30903 m .55586 1.29759 L .55586 1.41326 L F
0 g
.51918 1.30903 m
.51969 1.19671 L
s
.27473 .40223 m
.31076 .3883 L
s
.27473 .40223 m
.23498 .418 L
s
.55586 1.29759 m .59327 1.40192 L .55586 1.41326 L .544 .324 .532 r
F
.55586 1.29759 m .59274 1.28609 L .59327 1.40192 L F
0 g
.55586 1.18513 m
.55586 1.29759 L
s
.59223 1.17348 m
.59274 1.28609 L
s
.38335 1.04969 m .48927 1.11246 L .45267 1.12444 L .656 .751 .92 r
F
0 g
.45267 1.12444 m
.51969 1.19671 L
s
.27153 .40387 m
.31076 .3883 L
s
.42038 1.0373 m .52607 1.10042 L .48927 1.11246 L .656 .751 .92 r
F
.38335 1.04969 m .42038 1.0373 L .48927 1.11246 L F
0 g
.48927 1.11246 m
.55586 1.18513 L
s
.42038 1.0373 m .45763 1.02484 L .52607 1.10042 L .656 .751 .92 r
F
0 g
.52607 1.10042 m
.59223 1.17348 L
s
.67421 2.00506 m
.71922 2.00327 L
s
.71922 2.00327 m
.75676 1.99366 L
s
.71227 1.99528 m
.75676 1.99366 L
s
.75676 1.99366 m
.79451 1.984 L
s
.79451 1.984 m
.75054 1.98546 L
s
.51866 1.42454 m .55586 1.53228 L .51813 1.54338 L .544 .324 .532 r
F
.51866 1.42454 m .55586 1.41326 L .55586 1.53228 L F
0 g
.51866 1.42454 m
.51918 1.30903 L
s
.19864 .43205 m
.23498 .418 L
s
.19864 .43205 m
.16276 .46226 L
s
.55586 1.41326 m .59381 1.52111 L .55586 1.53228 L .544 .324 .532 r
F
.55586 1.41326 m .59327 1.40192 L .59381 1.52111 L F
0 g
.55586 1.29759 m
.55586 1.41326 L
s
.59274 1.28609 m
.59327 1.40192 L
s
.23498 .418 m
.27153 .40387 L
s
.23498 .418 m
.19961 .44806 L
s
.31161 .97233 m .42038 1.0373 L .38335 1.04969 L .656 .751 .92 r
F
0 g
.38335 1.04969 m
.45267 1.12444 L
s
.23668 .43378 m
.27153 .40387 L
s
.31161 .97233 m .34909 .9595 L .42038 1.0373 L .656 .751 .92 r
F
.34909 .9595 m .45763 1.02484 L .42038 1.0373 L F
0 g
.42038 1.0373 m
.48927 1.11246 L
s
.62486 1.99227 m
.67421 2.00506 L
s
.67421 2.00506 m
.71227 1.99528 L
s
.34909 .9595 m .38678 .9466 L .45763 1.02484 L .656 .751 .92 r
F
0 g
.45763 1.02484 m
.52607 1.10042 L
s
.66342 1.9823 m
.71227 1.99528 L
s
.71227 1.99528 m
.75054 1.98546 L
s
.51813 1.54338 m .55586 1.65479 L .51757 1.66571 L .544 .324 .532 r
F
.51813 1.54338 m .55586 1.53228 L .55586 1.65479 L F
0 g
.51813 1.54338 m
.51866 1.42454 L
s
.75054 1.98546 m
.70219 1.97227 L
s
.55586 1.53228 m .59437 1.64381 L .55586 1.65479 L .544 .324 .532 r
F
.55586 1.53228 m .59381 1.52111 L .59437 1.64381 L F
0 g
.55586 1.41326 m
.55586 1.53228 L
s
.59327 1.40192 m
.59381 1.52111 L
s
.16276 .46226 m
.19961 .44806 L
s
.16276 .46226 m
.13215 .50687 L
s
.19961 .44806 m
.23668 .43378 L
s
.19961 .44806 m
.16953 .49256 L
s
.23732 .89222 m .34909 .9595 L .31161 .97233 L .656 .751 .92 r
F
0 g
.31161 .97233 m
.38335 1.04969 L
s
.20713 .47817 m
.23668 .43378 L
s
.27525 .87893 m .38678 .9466 L .34909 .9595 L .656 .751 .92 r
F
.23732 .89222 m .27525 .87893 L .34909 .9595 L F
0 g
.34909 .9595 m
.42038 1.0373 L
s
.57195 1.96444 m
.62486 1.99227 L
s
.62486 1.99227 m
.66342 1.9823 L
s
.27525 .87893 m .3134 .86557 L .38678 .9466 L .656 .751 .92 r
F
0 g
.38678 .9466 m
.45763 1.02484 L
s
.51757 1.66571 m .55586 1.78095 L .517 1.79166 L .544 .324 .532 r
F
.51757 1.66571 m .55586 1.65479 L .55586 1.78095 L F
0 g
.51757 1.66571 m
.51813 1.54338 L
s
.61097 1.95423 m
.66342 1.9823 L
s
.66342 1.9823 m
.70219 1.97227 L
s
.55586 1.65479 m .59494 1.77017 L .55586 1.78095 L .544 .324 .532 r
F
.55586 1.65479 m .59437 1.64381 L .59494 1.77017 L F
0 g
.55586 1.53228 m
.55586 1.65479 L
s
.59381 1.52111 m
.59437 1.64381 L
s
.70219 1.97227 m
.65022 1.94395 L
s
.13215 .50687 m
.16953 .49256 L
s
.13215 .50687 m
.10773 .56568 L
s
.16953 .49256 m
.20713 .47817 L
s
.16953 .49256 m
.14562 .55131 L
s
.18374 .53687 m
.20713 .47817 L
s
.16034 .80921 m .27525 .87893 L .23732 .89222 L .656 .751 .92 r
F
0 g
.23732 .89222 m
.31161 .97233 L
s
.16034 .80921 m .19873 .79544 L .27525 .87893 L .656 .751 .92 r
F
.19873 .79544 m .3134 .86557 L .27525 .87893 L F
0 g
.27525 .87893 m
.34909 .9595 L
s
.517 1.79166 m .55586 1.91093 L .51642 1.92142 L .544 .324 .532 r
F
.517 1.79166 m .55586 1.78095 L .55586 1.91093 L F
0 g
.517 1.79166 m
.51757 1.66571 L
s
.51642 1.92142 m
.517 1.79166 L
s
.51642 1.92142 m
.57195 1.96444 L
s
.57195 1.96444 m
.61097 1.95423 L
s
.19873 .79544 m .23735 .78158 L .3134 .86557 L .656 .751 .92 r
F
0 g
.3134 .86557 m
.38678 .9466 L
s
.55586 1.78095 m .59554 1.90037 L .55586 1.91093 L .544 .324 .532 r
F
.55586 1.78095 m .59494 1.77017 L .59554 1.90037 L F
0 g
.55586 1.65479 m
.55586 1.78095 L
s
.55586 1.78095 m
.55586 1.91093 L
s
.59437 1.64381 m
.59494 1.77017 L
s
.55586 1.91093 m
.61097 1.95423 L
s
.61097 1.95423 m
.65022 1.94395 L
s
.59494 1.77017 m
.59554 1.90037 L
s
.59554 1.90037 m
.65022 1.94395 L
s
.10773 .56568 m
.14562 .55131 L
s
.10773 .56568 m
.09029 .6381 L
s
.14562 .55131 m
.18374 .53687 L
s
.14562 .55131 m
.12868 .62375 L
s
.1673 .60931 m
.18374 .53687 L
s
.51642 1.92142 m
.55586 1.91093 L
s
.45935 1.86346 m
.51642 1.92142 L
s
.08052 .72314 m .19873 .79544 L .16034 .80921 L .656 .751 .92 r
F
0 g
.16034 .80921 m
.23732 .89222 L
s
.55586 1.91093 m
.59554 1.90037 L
s
.49916 1.85265 m
.55586 1.91093 L
s
.08052 .72314 m .11939 .70886 L .19873 .79544 L .656 .751 .92 r
F
.11939 .70886 m .23735 .78158 L .19873 .79544 L F
0 g
.19873 .79544 m
.27525 .87893 L
s
.09029 .6381 m
.12868 .62375 L
s
.08052 .72314 m
.09029 .6381 L
s
.53921 1.84177 m
.59554 1.90037 L
s
.11939 .70886 m .15848 .69448 L .23735 .78158 L .656 .751 .92 r
F
0 g
.23735 .78158 m
.3134 .86557 L
s
.08052 .72314 m
.16034 .80921 L
s
.11939 .70886 m
.19873 .79544 L
s
.15848 .69448 m
.23735 .78158 L
s
.12868 .62375 m
.1673 .60931 L
s
.11939 .70886 m
.12868 .62375 L
s
.15848 .69448 m
.1673 .60931 L
s
.40198 1.79125 m
.45935 1.86346 L
s
.45935 1.86346 m
.49916 1.85265 L
s
.44209 1.78009 m
.49916 1.85265 L
s
.49916 1.85265 m
.53921 1.84177 L
s
.08052 .72314 m
.11939 .70886 L
s
.07896 .81935 m
.08052 .72314 L
s
.53921 1.84177 m
.48244 1.76886 L
s
.11939 .70886 m
.15848 .69448 L
s
.11826 .8052 m
.11939 .70886 L
s
.15779 .79095 m
.15848 .69448 L
s
.34561 1.70596 m
.40198 1.79125 L
s
.40198 1.79125 m
.44209 1.78009 L
s
.38596 1.69443 m
.44209 1.78009 L
s
.44209 1.78009 m
.48244 1.76886 L
s
.07896 .81935 m
.11826 .8052 L
s
.07896 .81935 m
.08592 .92485 L
s
.48244 1.76886 m
.42654 1.68282 L
s
.11826 .8052 m
.15779 .79095 L
s
.11826 .8052 m
.1256 .91088 L
s
.29163 1.60922 m
.34561 1.70596 L
s
.34561 1.70596 m
.38596 1.69443 L
s
.16552 .89684 m
.15779 .79095 L
s
.33212 1.5973 m
.38596 1.69443 L
s
.38596 1.69443 m
.42654 1.68282 L
s
.08592 .92485 m
.1256 .91088 L
s
.08592 .92485 m
.10145 1.03736 L
s
.42654 1.68282 m
.37287 1.58531 L
s
.1256 .91088 m
.16552 .89684 L
s
.1256 .91088 m
.14146 1.02365 L
s
.2414 1.50311 m
.29163 1.60922 L
s
.29163 1.60922 m
.33212 1.5973 L
s
.18171 1.00985 m
.16552 .89684 L
s
.10145 1.03736 m
.14146 1.02365 L
s
.10145 1.03736 m
.12537 1.1543 L
s
.28196 1.4908 m
.33212 1.5973 L
s
.33212 1.5973 m
.37287 1.58531 L
s
.14146 1.02365 m
.18171 1.00985 L
s
.14146 1.02365 m
.16563 1.14088 L
s
.1962 1.39007 m
.2414 1.50311 L
s
.2414 1.50311 m
.28196 1.4908 L
s
.37287 1.58531 m
.32277 1.47841 L
s
.12537 1.1543 m
.16563 1.14088 L
s
.12537 1.1543 m
.1572 1.27284 L
s
.1572 1.27284 m
.1962 1.39007 L
s
.1962 1.39007 m
.23674 1.37737 L
s
.20614 1.12739 m
.18171 1.00985 L
s
.23674 1.37737 m
.28196 1.4908 L
s
.28196 1.4908 m
.32277 1.47841 L
s
.1572 1.27284 m
.19764 1.25977 L
s
.16563 1.14088 m
.20614 1.12739 L
s
.16563 1.14088 m
.19764 1.25977 L
s
.19764 1.25977 m
.23674 1.37737 L
s
.23674 1.37737 m
.27754 1.36459 L
s
.32277 1.47841 m
.27754 1.36459 L
s
.19764 1.25977 m
.23833 1.24661 L
s
.23833 1.24661 m
.20614 1.12739 L
s
.27754 1.36459 m
.23833 1.24661 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{123.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001k000182000`400?l00000o`00003oN`3oool0
07/0oooo001k0?ooo`00N`3oool007/0oooo001k0?ooo`00N`3oool007/0oooo001k0?ooo`00N`3o
ool007/0oooo001k0?ooo`00N`3oool007/0oooo001k0?ooo`00N`3oool007/0oooo001k0?ooo`00
N`3oool007/0oooo001k0?ooo`00N`3oool007/0oooo001k0?ooo`00N`3oool007/0oooo001k0?oo
o`00N`3oool007/0oooo001k0?ooo`00N`3oool007/0oooo001k0?ooo`00N`3oool007/0oooo001k
0?ooo`00N`3oool007/0oooo001k0?ooo`00N`3oool007/0oooo001k0?ooo`00N`3oool007/0oooo
001k0?ooo`00N`3oool007/0oooo001k0?ooo`00N`3oool002D0oooo2P00001<0?ooo`008P3oool7
000000H0oooo100000180?ooo`007`3oool7000000<0oooo0`000000103oool00000000000000003
0?ooo`800000AP3oool001`0oooo2P0000040?ooo`@000001`3oool00`000000oooo0?ooo`130?oo
o`006@3oool400000080oooo00<000000?ooo`3oool0103oool4000000@0oooo0P0000050?ooo`<0
0000@`3oool001P0oooo0`0000030?ooo`030000003oool0oooo00T0oooo0P0000040?ooo`800000
00<0oooo0000000000000`3oool00`000000oooo0?ooo`100?ooo`005`3oool010000000oooo0000
003oool3000000h0oooo0P0000020?ooo`@000001@3oool200000400oooo000F0?ooo`D000000P3o
ool00`000000oooo0?ooo`0>0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo03d0oooo000E0?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000?P3oool001@0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`00000000000P3oool00`000000oooo0?ooo`0k0?ooo`00503oool00`000000oooo00000003
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<00000
0?ooo`3oool0>P3oool001<0oooo00D000000?ooo`3oool000000?ooo`02000001T0oooo00@00000
0?ooo`00000000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03T0oooo000B
0?ooo`030000003oool0oooo00<0000000<0oooo0000003oool06@3oool2000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0h0?ooo`004P3oool3000000<0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0=`3oool00140oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000>03oool00100oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080
oooo00H000000?ooo`00000000000?ooo`00000h0?ooo`00403oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool00`0000040?ooo`030000003oool0
oooo03D0oooo000?0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0803oool2
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0d0?ooo`003`3oool01000
0000oooo0?ooo`0000020?ooo`8000008`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0<`3oool000h0oooo00@000000?ooo`3oool0oooo0`000000
0`3oool000000?ooo`0S0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0b0?ooo`003P3oool010000000oooo0000000000040?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0340oooo000>0?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`00000b0?ooo`003@3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`020?oo
o`<000000P2;DXP00`000000oooo0?ooo`0`0?ooo`003@3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo02L0oooo00H000000?ooo`000000000008]BR000000308]BR0800000<@3o
ool000d0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0X0?ooo`050000002;
DXP0Re:808]BR00000000`2;DXP00`000000oooo0000000`0?ooo`00303oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool0:03oool01@000000Re:808]BR02;DXP0000000<0
Re:800@000000?ooo`3oool00000;`3oool000`0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo02T0oooo00D0000008]BR02;DXP0Re:80000000308]BR0040000003oool0
oooo000002l0oooo000<0?ooo`050000003oool0oooo0?ooo`0000000P3oool2000002/0oooo00D0
000008]BR02;DXP0Re:80000000308]BR0050000003oool0oooo0?ooo`000000;P3oool000`0oooo
00<000000?ooo`3oool0100000000`3oool000000?ooo`0Z0?ooo`050000002;DXP0Re:808]BR000
00000`2;DXP00`000000oooo0?ooo`020?ooo`030000003oool0oooo02/0oooo000<0?ooo`040000
003oool00000000000@0oooo00<000000?ooo`3oool0:@3oool01@000000Re:808]BR02;DXP00000
00<0Re:80P0000020?ooo`<00000;03oool000/0oooo0`0000000`3oool000000?ooo`030?ooo`03
0000003oool0oooo02T0oooo00D0000008]BR02;DXP0Re:80000000308]BR0@000000P3oool00`00
0000oooo0?ooo`0Z0?ooo`002`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool0:@3oool01@000000Re:808]BR02;DXP0000000<0Re:800<000000?ooo`000000103oool0
0`000000oooo0?ooo`0Y0?ooo`002`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0:@3oool01@000000Re:808]BR02;DXP0000000<0Re:800@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0X0?ooo`002`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool0:P3oool01@000000Re:808]BR02;DXP0000000<0Re:800@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`0X0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000;03oool01@000000Re:808]BR02;DXP0000000<0Re:800D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02L0oooo000:0?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`0Z0?ooo`050000002;DXP0Re:808]BR0000000
0`2;DXP00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000:@3oool000X0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02X0oooo00D0000008]BR02;
DXP0Re:80000000308]BR0030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0V0?ooo`002P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool0:P3oool01@000000Re:808]BR02;DXP0000000<0Re:80P0000040?ooo`040000003oool0
oooo0?ooo`8000009`3oool000X0oooo00D000000?ooo`3oool0oooo000000020?ooo`<00000;03o
ool01@000000Re:808]BR02;DXP0000000<0Re:80P0000040?ooo`060000003oool000000000003o
ool000009`3oool000T0oooo00@000000?ooo`3oool0oooo100000020:O0j`800000:`3oool01@00
0000Re:808]BR02;DXP0000000<0Re:800<000000?ooo`0000000P3oool3000000@0oooo00<00000
0?ooo`3oool0903oool000T0oooo100000000`2W`>/000000:O0j`030:O0j`030000002W`>/00000
02X0oooo00D0000008]BR02;DXP0Re:80000000308]BR0030000003oool0oooo008000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo00090?ooo`030000002W`>/0Yl3[
0080Yl3[0P0000030:O0j`040000002W`>/0Yl3[000002T0oooo00D0000008]BR02;DXP0Re:80000
000308]BR0040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0S0?ooo`002@3oool00`000000Yl3[0:O0j`020:O0j`030000002W`>/000000080Yl3[00D0
00000:O0j`2W`>/0Yl3[0000000X0?ooo`050000002;DXP0Re:808]BR00000000`2;DXP01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0S0?oo
o`002@3oool2000000<0Yl3[00H000000:O0j`2W`>/000000:O0j`0000040:O0j`030000003oool0
oooo02D0oooo00D0000008]BR02;DXP0Re:80000000308]BR0050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00090?ooo`030000003o
ool000000080Yl3[00@000000:O0j`2W`>/0Yl3[0P0000050:O0j`030000003oool0oooo02@0oooo
00D0000008]BR02;DXP0Re:80000000308]BR0030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000002@0oooo00090?ooo`060000003oool0oooo0000
002W`>/00000102W`>/00`000000Yl3[0:O0j`040:O0j`030000003oool0oooo02<0oooo00D00000
08]BR02;DXP0Re:80000000308]BR0030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00090?ooo`040000003oool0
oooo0?ooo`800000102W`>/2000000H0Yl3[00<000000?ooo`3oool08P3oool01@000000Re:808]B
R02;DXP0000000<0Re:800<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000008`3oool000T0oooo00<000000?ooo`3oool00P3oool00`000000Yl3[
0:O0j`020:O0j`030000002W`>/0000000H0Yl3[00<000000?ooo`3oool08@3oool01@000000Re:8
08]BR02;DXP0000000<0Re:800<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<000008P3oool000T0oooo00<000000?ooo`3oool00P3oool2000000<0Yl3[
00@000000:O0j`2W`>/000001P2W`>/00`000000oooo0?ooo`0P0?ooo`050000002;DXP0Re:808]B
R00000000`2;DXP00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<000000P3oool0
0`000000oooo0?ooo`0P0?ooo`002@3oool00`000000oooo0?ooo`020?ooo`040000003oool00000
0:O0j`8000000`2W`>/00`000000Yl3[0:O0j`030:O0j`030000003oool0oooo0200oooo00D00000
08]BR02;DXP0Re:80000000308]BR0030000003oool0oooo00@0oooo00H000000?ooo`0000000000
0?ooo`0000040?ooo`030000003oool0oooo01l0oooo00090?ooo`030000003oool0oooo0080oooo
100000000`2W`>/000000:O0j`030:O0j`030000002W`>/0Yl3[00<0Yl3[00<000000?ooo`3oool0
7`3oool01@000000Re:808]BR02;DXP0000000<0Re:800<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000008@3oool000T0oooo00@000000?ooo`3o
ool0oooo0P0000030?ooo`800000102W`>/00`000000Yl3[0:O0j`040:O0j`030000003oool0oooo
01h0oooo00D0000008]BR02;DXP0Re:80000000308]BR0030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo00090?oo
o`@0000000<0oooo0000003oool00`3oool00`000000Yl3[0:O0j`030:O0j`030000002W`>/0Yl3[
00@0Yl3[00<000000?ooo`3oool07@3oool01@000000Re:808]BR02;DXP0000000<0Re:800<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000803o
ool000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`8000001@2W`>/0
0`000000Yl3[0:O0j`040:O0j`030000003oool0oooo01`0oooo00D0000008]BR02;DXP0Re:80000
000308]BR0030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01d0oooo00090?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000050:O0j`030000002W`>/0Yl3[00@0Yl3[00<00000
0?ooo`3oool06`3oool01@000000Re:808]BR02;DXP0000000<0Re:800<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000007`3oool000T0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0Yl3[
00<000000:O0j`2W`>/00`2W`>/00`000000oooo0?ooo`0K0?ooo`050000002;DXP0Re:808]BR000
00000`2;DXP00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0L0?ooo`002@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000001@2W`>/00`000000Yl3[0:O0j`030:O0j`03
0000003oool0oooo01X0oooo00D0000008]BR02;DXP0Re:80000000308]BR0030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000001h0oooo00090?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
000000D0Yl3[00<000000:O0j`2W`>/00`2W`>/00`000000oooo0?ooo`0I0?ooo`050000002;DXP0
Re:808]BR00000000`2;DXP00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`00000M0?ooo`002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000Yl3[0:O0j`030:O0j`030000002W`>/0
Yl3[00<0Yl3[00<000000?ooo`3oool0603oool01@000000Re:808]BR02;DXP0000000<0Re:800<0
00000?ooo`3oool02@3oool010000000oooo0?ooo`3oool300000080oooo00<000000?ooo`3oool0
6`3oool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000:O0j`2W`>/00`2W`>/00`000000Yl3[0:O0j`030:O0j`030000003o
ool0oooo01L0oooo00D0000008]BR02;DXP0Re:80000000308]BR0030000003oool0oooo00T0oooo
00H000000?ooo`00000000000?ooo`0000040?ooo`030000003oool0oooo01X0oooo000:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000002W`>/0Yl3[00<0Yl3[00<000000:O0j`2W`>/00P2W`>/00`000000oooo0?ooo`0G0?ooo`05
0000002;DXP0Re:808]BR00000000`2;DXP00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo0000000L0?ooo`002P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000Yl3[0:O0j`020:O0
j`030000002W`>/0Yl3[00<0Yl3[00<000000?ooo`3oool05P3oool01@000000Re:808]BR02;DXP0
000000<0Re:800<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool06@3oool000X0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`3oool2000000P0oooo00<000000:O0j`2W`>/00P2W`>/00`000000Yl3[0:O0j`03
0:O0j`030000003oool0oooo01D0oooo00D0000008]BR02;DXP0Re:80000000308]BR0030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000001/0oooo
000:0?ooo`030000003oool0oooo0080oooo100000000`3oool000000?ooo`070?ooo`030000002W
`>/0Yl3[00<0Yl3[00<000000:O0j`2W`>/00`2W`>/00`000000oooo0?ooo`0D0?ooo`050000002;
DXP0Re:808]BR00000000`2;DXP00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`002P3oool010000000oooo0?oo
o`3oool2000000@0oooo00<000000?ooo`3oool01`3oool00`000000Yl3[0:O0j`030:O0j`030000
002W`>/0Yl3[00<0Yl3[00<000000?ooo`3oool04`3oool01@000000Re:808]BR02;DXP0000000<0
Re:800<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000006P3oool000X0oooo100000000`3oool000000?ooo`030?ooo`030000003oool0oooo00P0
oooo00<000000:O0j`2W`>/00`2W`>/00`000000Yl3[0:O0j`030:O0j`030000003oool0oooo0180
oooo00D0000008]BR02;DXP0Re:80000000308]BR0030000003oool0oooo00`0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo000:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`03
0000002W`>/0Yl3[00<0Yl3[00<000000:O0j`2W`>/00`2W`>/00`000000oooo0?ooo`0A0?ooo`05
0000002;DXP0Re:808]BR00000000`2;DXP00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`0G0?ooo`002P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000Yl3[0:O0j`030:O0
j`030000002W`>/0Yl3[00<0Yl3[00<000000?ooo`3oool0403oool01@000000Re:808]BR02;DXP0
000000<0Re:800<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo0?ooo`800000603oool000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00X0oooo00<000000:O0j`2W`>/00`2W`>/00`000000Yl3[0:O0j`03
0:O0j`030000003oool0oooo00l0oooo00D0000008]BR02;DXP0Re:80000000308]BR0030000003o
ool0oooo00h0oooo00H000000?ooo`3oool0oooo0000003oool2000000030?ooo`000000oooo01L0
oooo000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0;0?ooo`030000002W`>/0Yl3[00<0Yl3[00<000000:O0j`2W`>/00`2W`>/00`000000oooo
0?ooo`0>0?ooo`050000002;DXP0Re:808]BR00000000`2;DXP00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00<00000103oool00`000000oooo0?ooo`0E0?ooo`002`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000Yl3[
0:O0j`030:O0j`030000002W`>/0Yl3[00<0Yl3[00<000000?ooo`3oool03@3oool01@000000Re:8
08]BR02;DXP0000000<0Re:800<000000?ooo`3oool03`3oool200000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0E0?ooo`002`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000Yl3[0:O0j`020:O0j`030000
002W`>/0Yl3[00@0Yl3[00<000000?ooo`3oool0303oool01@000000Re:808]BR02;DXP0000000<0
Re:800<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000005`3oool000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00h0oooo00<000000:O0j`2W`>/00P2W`>/00`000000Yl3[0:O0j`040:O0j`03
0000003oool0oooo00/0oooo00D0000008]BR02;DXP0Re:80000000308]BR0030000003oool0oooo
0100oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo01@0oooo000;0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?oo
o`030000002W`>/0Yl3[0080Yl3[00<000000:O0j`2W`>/0102W`>/00`000000oooo0?ooo`0:0?oo
o`050000002;DXP0Re:808]BR00000000`2;DXP00`000000oooo0?ooo`0@0?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`0D0?ooo`002`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool00`000000Yl3[0:O0j`02
0:O0j`030000002W`>/0Yl3[00@0Yl3[00<000000?ooo`3oool02@3oool01@000000Re:808]BR02;
DXP0000000<0Re:800<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000005P3oool000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo00<000000:O0j`2W`>/00P2W`>/00`000000Yl3[0:O0
j`040:O0j`030000003oool0oooo00P0oooo00D0000008]BR02;DXP0Re:80000000308]BR0030000
003oool0oooo0140oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo01<0
oooo000;0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P00000C0?ooo`03
0000002W`>/0Yl3[0080Yl3[00<000000:O0j`2W`>/0102W`>/00`000000oooo0?ooo`070?ooo`05
0000002;DXP0Re:808]BR00000000`2;DXP00`000000oooo0?ooo`0A0?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`0C0?ooo`00303oool00`000000oooo0?ooo`020?oo
o`@0000000<0oooo0000003oool04`3oool00`000000Yl3[0:O0j`020:O0j`030000002W`>/0Yl3[
00@0Yl3[00<000000?ooo`3oool01P3oool01@000000Re:808]BR02;DXP0000000<0Re:800<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000005@3o
ool000`0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`030000003oool0oooo01<0oooo00<0
00000:O0j`2W`>/00P2W`>/00`000000Yl3[0:O0j`040:O0j`030000003oool0oooo00D0oooo00D0
000008]BR02;DXP0Re:80000000308]BR0030000003oool0oooo0180oooo00D000000?ooo`3oool0
oooo000000030?ooo`800000503oool000`0oooo100000000`3oool000000?ooo`040?ooo`030000
003oool0oooo01<0oooo00<000000:O0j`2W`>/00P2W`>/00`000000Yl3[0:O0j`030:O0j`030000
003oool0oooo00D0oooo00D0000008]BR02;DXP0Re:80000000308]BR0030000003oool0oooo0180
oooo00H000000?ooo`3oool0oooo0000003oool2000000030?ooo`000000oooo01<0oooo000<0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?oo
o`030000002W`>/0Yl3[0080Yl3[00<000000:O0j`2W`>/00`2W`>/00`000000oooo0?ooo`030?oo
o`030000002;DXP0Re:80080Re:800D0000008]BR02;DXP0Re:80000000D0?ooo`030000003oool0
oooo00<00000103oool00`000000oooo0?ooo`0A0?ooo`00303oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool00`000000Yl3[0:O0j`020:O0
j`030000002W`>/0Yl3[00<0Yl3[00<000000?ooo`3oool00P3oool00`000000Re:808]BR00208]B
R0050000002;DXP0Re:808]BR00000005@3oool200000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0A0?ooo`00303oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool05@3oool00`000000Yl3[0:O0j`030:O0j`030000002W`>/0Yl3[
00<0Yl3[00D000000?ooo`3oool0oooo0000000408]BR0050000002;DXP0Re:808]BR00000005@3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000004`3oool000d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo00<0
00000:O0j`2W`>/00`2W`>/00`000000Yl3[0:O0j`030:O0j`040000003oool0oooo000000@0Re:8
00D0000008]BR02;DXP0Re:80000000F0?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`0@0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool05P3oool00`000000Yl3[0:O0j`030:O0j`030000002W`>/0Yl3[00<0
Yl3[00<000000?ooo`000000102;DXP01@000000Re:808]BR02;DXP0000001H0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0100oooo000=0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000002W`>/0Yl3[
00<0Yl3[00<000000:O0j`2W`>/00`2W`>/2000000@0Re:800D0000008]BR02;DXP0Re:80000000F
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000B0?ooo`003@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool0
0`000000Yl3[0:O0j`030:O0j`030000002W`>/0Yl3[00<0Yl3[00<0000008]BR02;DXP00P2;DXP0
1@000000Re:808]BR02;DXP0000001L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo00l0oooo000=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0I0?ooo`030000002W`>/0Yl3[00<0Yl3[00<000000:O0j`2W`>/00`2W
`>/01@000000Re:808]BR02;DXP0000000<0Re:800<000000?ooo`3oool05@3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool03`3oool000h0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo00<000000:O0j`2W`>/0
0`2W`>/00`000000Yl3[0:O0j`020:O0j`050000002;DXP0Re:808]BR00000000`2;DXP00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000A0?oo
o`003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool06P3oool00`000000Yl3[0:O0j`030:O0j`030000002W`>/0Yl3[0080Yl3[00@0000008]BR02;
DXP000000`2;DXP00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`0>0?ooo`003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool06`3oool00`000000Yl3[0:O0j`020:O0j`030000002W`>/0Yl3[
00<0Yl3[00<0000008]BR00000000`2;DXP00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo
0?ooo`0000000P3oool300000100oooo000>0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`00000M0?ooo`030000002W`>/0Yl3[00<0Yl3[00<000000:O0j`2W`>/00`2W`>/20000
00<0Re:800<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0400000080oooo00<000000?oo
o`3oool03P3oool000h0oooo00<000000?ooo`3oool00P3oool400000080oooo00<000000?ooo`3o
ool0703oool00`000000Yl3[0:O0j`030:O0j`030000002W`>/0Yl3[00<0Yl3[00D0000008]BR02;
DXP0Re:80000000I0?ooo`8000000P3oool01@000000oooo0?ooo`3oool000000100oooo000?0?oo
o`@0000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0M0?ooo`030000002W`>/0Yl3[
00<0Yl3[00<000000:O0j`2W`>/00`2W`>/010000000Re:808]BR000000I0?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000Yl3[0:O0j`03
0:O0j`090000002W`>/0Yl3[0:O0j`000000Yl3[0000002;DXP0000001T0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000l0oooo000?0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0N0?ooo`030000002W`>/0Yl3[00<0
Yl3[00<000000:O0j`2W`>/00`2W`>/2000001X0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0O0?ooo`030000002W`>/0Yl3[00<0Yl3[00<000000:O0j`2W
`>/00`2W`>/00`000000oooo0?ooo`0H0?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`0<0?ooo`00403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool07`3oool00`000000Yl3[0:O0j`030:O0j`060000002W`>/0Yl3[0:O0
j`2;DXP000006P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000003P3o
ool00100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0200oooo00<000000:O0j`2W`>/00`2W`>/010000000Re:808]BR02;DXP2000001X0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00`0oooo000@0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000002W
`>/0Yl3[0080Re:800L0000008]BR02;DXP0Re:80000002W`>/0000001T0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00`0oooo000@0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000002;DXP0Re:80080
Re:800D0000008]BR02;DXP0Re:8000000020:O0j`030000003oool0oooo01H0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00/0oooo000A0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0P0?ooo`030000002;DXP0Re:8
0080Re:800D0000008]BR02;DXP0Re:8000000030:O0j`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo00000002000000d0oooo000A0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0P0?ooo`030000002;DXP0Re:8
0080Re:800D0000008]BR02;DXP0Re:8000000040:O0j`030000003oool0oooo01D0oooo00<00000
0?ooo`0000000`0000020?ooo`030000003oool0oooo00/0oooo000A0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0P0?ooo`030000002;DXP0Re:8
0080Re:800D0000008]BR02;DXP0Re:8000000050:O0j`030000003oool0oooo01@0oooo0P000002
0?ooo`050000003oool0oooo0?ooo`0000003@3oool00180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<0000008]BR02;DXP00P2;DXP0
10000000Re:808]BR02;DXP2000000D0Yl3[00<000000?ooo`3oool04`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool02P3oool00180oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`8000008@3oool00`000000Re:808]BR00208]BR0070000002;
DXP0Re:808]BR0000000Yl3[000000050:O0j`030000003oool0oooo0180oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000`0oooo000B0?ooo`030000003oool0oooo00<0
oooo100000000`3oool000000?ooo`0P0?ooo`030000002;DXP0Re:80080Re:800D0000008]BR02;
DXP0Re:8000000020:O0j`030000002W`>/0Yl3[0080Yl3[00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000303oool00180oooo00<000000?oo
o`3oool00P3oool2000000D0oooo00<000000?ooo`3oool07P3oool00`000000Re:808]BR00208]B
R0050000002;DXP0Re:808]BR00000000`2W`>/00`000000Yl3[0:O0j`020:O0j`030000003oool0
oooo0180oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00T0oooo000C
0?ooo`@0000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0N0?ooo`030000002;DXP0
Re:80080Re:800D0000008]BR02;DXP0Re:8000000030:O0j`030000002W`>/0Yl3[00<0Yl3[00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
2`3oool001<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01h0oooo00<0000008]BR02;DXP00P2;DXP01@000000Re:808]BR02;DXP0000000@0Yl3[
00<000000:O0j`2W`>/00`2W`>/00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo0000000;0?ooo`004`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000Re:808]BR00208]BR0040000
002;DXP0Re:808]BR0800000102W`>/00`000000Yl3[0:O0j`030:O0j`030000003oool0oooo00l0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000/0oooo000D0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`03
0000002;DXP0Re:80080Re:800L0000008]BR02;DXP0Re:80000003oool0000000@0Yl3[00<00000
0:O0j`2W`>/00`2W`>/00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`00503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool07@3oool00`000000Re:808]BR00208]B
R0050000002;DXP0Re:808]BR00000000P3oool00`000000Yl3[0:O0j`020:O0j`030000002W`>/0
Yl3[00<0Yl3[00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
0000008000002P3oool001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01`0oooo00<0000008]BR02;DXP00P2;DXP01@000000Re:808]BR02;DXP0
000000<0oooo00<000000:O0j`2W`>/00P2W`>/00`000000Yl3[0:O0j`030:O0j`030000003oool0
oooo00d0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`030000003oool0oooo00P0oooo000E
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L
0?ooo`030000002;DXP0Re:80080Re:800D0000008]BR02;DXP0Re:8000000040?ooo`030000002W
`>/0Yl3[0080Yl3[00<000000:O0j`2W`>/00`2W`>/00`000000oooo0?ooo`0<0?ooo`@0000000<0
oooo0000003oool00P3oool00`000000oooo0?ooo`080?ooo`005@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0703oool00`000000Re:808]BR002
08]BR0050000002;DXP0Re:808]BR00000001@3oool00`000000Yl3[0:O0j`020:O0j`030000002W
`>/0Yl3[0080Yl3[00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000002P3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01/0oooo00<0000008]BR02;DXP00P2;DXP01@000000Re:808]B
R02;DXP0000000H0oooo00<000000:O0j`2W`>/00P2W`>/00`000000Yl3[0:O0j`020:O0j`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo000F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0K0?ooo`030000002;DXP0Re:80080Re:800D0000008]BR02;DXP0Re:8
000000070?ooo`030000002W`>/0Yl3[0080Yl3[00<000000:O0j`2W`>/00P2W`>/00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000090?ooo`00
5P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
6`3oool00`000000Re:808]BR00208]BR0050000002;DXP0Re:808]BR0000000203oool00`000000
Yl3[0:O0j`020:O0j`030000002W`>/0Yl3[0080Yl3[00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000002@3oool001H0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo00<0000008]BR02;
DXP00P2;DXP01@000000Re:808]BR02;DXP0000000T0oooo00<000000:O0j`2W`>/00P2W`>/00`00
0000Yl3[0:O0j`020:O0j`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000T0oooo000G0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool2000001`0oooo00<0000008]BR02;DXP00P2;DXP01@000000Re:808]BR02;DXP0
000000X0oooo00<000000:O0j`2W`>/00P2W`>/00`000000Yl3[0:O0j`020:O0j`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0oooo000G
0?ooo`030000003oool0oooo00<0oooo100000000`3oool000000?ooo`0K0?ooo`030000002;DXP0
Re:80080Re:800D0000008]BR02;DXP0Re:80000000;0?ooo`030000002W`>/0Yl3[0080Yl3[00<0
00000:O0j`2W`>/00P2W`>/00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`005`3oool010000000oooo0?ooo`3o
ool3000000D0oooo00<000000?ooo`3oool06@3oool00`000000Re:808]BR00208]BR0050000002;
DXP0Re:808]BR0000000303oool00`000000Yl3[0:O0j`020:O0j`030000002W`>/0Yl3[0080Yl3[
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
0000203oool001P0oooo0`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
6@3oool00`000000Re:808]BR00208]BR0050000002;DXP0Re:808]BR00000003@3oool00`000000
Yl3[0:O0j`020:O0j`050000002W`>/0Yl3[0:O0j`000000203oool00`000000oooo0?ooo`030?oo
o`030000003oool0000000800000203oool001P0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo00<0000008]BR02;DXP00P2;DXP01@000000
Re:808]BR02;DXP0000000h0oooo00D000000:O0j`2W`>/0Yl3[000000040:O0j`030000003oool0
oooo00H0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`030000003oool0oooo00H0oooo000I
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0H
0?ooo`030000002;DXP0Re:80080Re:800D0000008]BR02;DXP0Re:80000000>0?ooo`030000002W
`>/0Yl3[0080Yl3[00<000000:O0j`2W`>/00P2W`>/00`000000oooo0?ooo`050?ooo`@0000000<0
oooo0000003oool00P3oool00`000000oooo0?ooo`060?ooo`006@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0603oool00`000000Re:808]BR002
08]BR0050000002;DXP0Re:808]BR00000003`3oool00`000000Yl3[0:O0j`020:O0j`030000002W
`>/0Yl3[0080Yl3[00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000203oool001T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01P0oooo00<0000008]BR02;DXP00P2;DXP01@000000Re:808]B
R02;DXP000000100oooo00<000000:O0j`2W`>/00P2W`>/00`000000Yl3[0:O0j`020:O0j`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000P0
oooo000J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0G0?ooo`030000002;DXP0Re:80080Re:800D0000008]BR02;DXP0Re:80000000A0?ooo`03
0000002W`>/0Yl3[0080Yl3[00<000000:O0j`2W`>/00P2W`>/00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000080?ooo`006P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool00`000000
Re:808]BR00208]BR0050000002;DXP0Re:808]BR00000004P3oool00`000000Yl3[0:O0j`020:O0
j`030000002W`>/0Yl3[0080Yl3[00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01@3oool001X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00<0000008]BR02;DXP00P2;DXP01@00
0000Re:808]BR02;DXP0000001<0oooo00<000000:O0j`2W`>/00P2W`>/00`000000Yl3[0:O0j`02
0:O0j`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000L0oooo
000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0F0?ooo`030000002;DXP0Re:80080Re:800D0000008]BR02;DXP0Re:80000000D0?ooo`030000
002W`>/0Yl3[0080Yl3[00<000000:O0j`2W`>/00P2W`>/010000000oooo0?ooo`0000040?ooo`05
0000003oool0oooo0?ooo`0000001`3oool001/0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo00<0000008]BR02;DXP00P2;DXP01@000000
Re:808]BR02;DXP0000001D0oooo00<000000:O0j`2W`>/00P2W`>/00`000000Yl3[0:O0j`020:O0
j`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000070?ooo`006`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool00`00
0000Re:808]BR00208]BR0030000002;DXP0Re:80080Re:800<000000?ooo`3oool04P3oool00`00
0000Yl3[0:O0j`030:O0j`030000002W`>/0Yl3[0080Yl3[0P0000040?ooo`050000003oool0oooo
0?ooo`0000001`3oool001`0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool3
000001L0oooo00<0000008]BR02;DXP00P2;DXP00`000000Re:808]BR00208]BR0030000003oool0
oooo01<0oooo00<000000:O0j`2W`>/00`2W`>/00`000000Yl3[0:O0j`020:O0j`030000003oool0
oooo0080oooo00<000000?ooo`0000000P0000070?ooo`00703oool00`000000oooo0?ooo`020?oo
o`@000000P3oool00`000000oooo0?ooo`0E0?ooo`030000002;DXP0Re:80080Re:800<0000008]B
R02;DXP00P2;DXP00`000000oooo0?ooo`0D0?ooo`030000002W`>/0Yl3[00<0Yl3[00<000000:O0
j`2W`>/00P2W`>/00`000000oooo0?ooo`0300000080oooo00<000000?ooo`3oool01@3oool001`0
oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01@0
oooo00<0000008]BR02;DXP00P2;DXP00`000000Re:808]BR00208]BR0030000003oool0oooo01D0
oooo00<000000:O0j`2W`>/00`2W`>/00`000000Yl3[0:O0j`020:O0j`80000000<0oooo0000003o
ool00P3oool00`000000oooo0?ooo`050?ooo`007@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0503oool00`000000Re:808]BR00208]BR0030000
002;DXP0Re:80080Re:800<000000?ooo`3oool05P3oool00`000000Yl3[0:O0j`030:O0j`030000
002W`>/0Yl3[0080Yl3[00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`007@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3o
ool00`000000Re:808]BR00208]BR0030000002;DXP0Re:80080Re:800<000000?ooo`3oool05`3o
ool00`000000Yl3[0:O0j`030:O0j`070000002W`>/0Yl3[0:O0j`000000oooo000000030?ooo`03
0000003oool0oooo00D0oooo000N0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0C0?ooo`030000002;DXP0Re:80080Re:800<0000008]BR02;DXP0
0P2;DXP00`000000oooo0?ooo`0H0?ooo`030000002W`>/0Yl3[0080Yl3[00<000000:O0j`2W`>/0
0P2W`>/2000000<0oooo00<000000?ooo`3oool01@3oool001h0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0180oooo00<0000008]BR02;DXP00P2;
DXP00`000000Re:808]BR00208]BR0030000003oool0oooo01T0oooo00<000000:O0j`2W`>/00P2W
`>/00`000000Yl3[0:O0j`020:O0j`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool001l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0180oooo00<0000008]BR02;DXP00P2;DXP00`000000Re:808]BR00208]BR0030000003oool0
oooo01X0oooo00<000000:O0j`2W`>/00P2W`>/00`000000Yl3[0:O0j`020:O0j`050000003oool0
oooo0?ooo`0000001P3oool001l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0180oooo00<0000008]BR02;DXP00P2;DXP00`000000Re:808]BR002
08]BR0030000003oool0oooo01/0oooo00<000000:O0j`2W`>/00P2W`>/01P000000Yl3[0:O0j`00
0000Yl3[00000080oooo00<000000?ooo`3oool0103oool00200oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo00<0000008]BR02;DXP00P2;
DXP00`000000Re:808]BR00208]BR0030000003oool0oooo01`0oooo00<000000:O0j`2W`>/00P2W
`>/00`000000Yl3[0:O0j`020:O0j`030000003oool0000000H0oooo000P0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`030000002;DXP0
Re:80080Re:800<0000008]BR02;DXP00P2;DXP00`000000oooo0?ooo`0M0?ooo`030000002W`>/0
Yl3[0080Yl3[00<000000:O0j`2W`>/00P2W`>/2000000H0oooo000P0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`030000002;DXP0Re:8
0080Re:800<0000008]BR02;DXP00P2;DXP00`000000oooo0?ooo`0N0?ooo`030000002W`>/0Yl3[
0080Yl3[00<000000:O0j`2W`>/00`0000060?ooo`008@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000Re:808]BR00208]BR003
0000002;DXP0Re:80080Re:800<000000?ooo`3oool07`3oool00`000000Yl3[0:O0j`0400000080
oooo00<000000?ooo`3oool0103oool00240oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`8000004@3oool00`000000Re:808]BR00208]BR0030000002;DXP0Re:80080Re:8
00<000000?ooo`3oool0803oool200000080oooo00D000000?ooo`3oool0oooo000000060?ooo`00
8P3oool00`000000oooo0?ooo`020?ooo`030000003oool000000080000000<0oooo0000003oool0
403oool00`000000Re:808]BR00208]BR0030000002;DXP0Re:80080Re:800<000000?ooo`3oool0
803oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00280oooo
00@000000?ooo`3oool0oooo0`0000050?ooo`030000003oool0oooo00h0oooo00<0000008]BR02;
DXP00P2;DXP00`000000Re:808]BR00208]BR0030000003oool0oooo0200oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00@0oooo000S0?ooo`<000000P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<0000008]BR02;DXP00P2;DXP00`000000
Re:808]BR00208]BR0030000003oool0oooo0200oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo00@0oooo000S0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0=0?ooo`030000002;DXP0Re:80080Re:800<0000008]BR02;
DXP00P2;DXP00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`00903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0303oool00`000000Re:808]BR00208]BR0030000002;DXP0Re:80080
Re:800<000000?ooo`3oool0803oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool0103oool002@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00`0oooo00<0000008]BR02;DXP00P2;DXP00`000000Re:808]BR00208]BR003
0000003oool0oooo0200oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00@0oooo000U0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0;0?ooo`030000002;DXP0Re:80080Re:800<0000008]BR02;DXP00P2;DXP00`000000
oooo0?ooo`0P0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?oo
o`009P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02`3oool00`000000Re:808]BR00208]BR0030000002;DXP0Re:80080Re:800<000000?ooo`3o
ool0803oool01P000000oooo0?ooo`3oool000000?ooo`<000001P3oool002H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<0000008]B
R02;DXP00P2;DXP00`000000Re:808]BR00208]BR0030000003oool0oooo0200oooo00<000000?oo
o`0000000`0000020?ooo`030000003oool0oooo00@0oooo000W0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000002;DXP0Re:80080
Re:800<0000008]BR02;DXP00P2;DXP00`000000oooo0?ooo`0P0?ooo`8000000P3oool01@000000
oooo0?ooo`3oool0000000H0oooo000W0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`090?ooo`030000002;DXP0Re:80080Re:800<0000008]BR02;
DXP00P2;DXP00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`00:03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo0P00000:0?ooo`030000002;DXP0Re:80080Re:800<0000008]BR02;DXP00P2;DXP00`000000
oooo0?ooo`0P0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?oo
o`00:@3oool00`000000oooo0?ooo`020?ooo`030000003oool000000080000000<0oooo0000003o
ool02@3oool00`000000Re:808]BR00208]BR0030000002;DXP0Re:80080Re:800<000000?ooo`3o
ool0803oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool002T0
oooo00@000000?ooo`3oool0oooo0`0000050?ooo`030000003oool0oooo00L0oooo00<0000008]B
R02;DXP00P2;DXP00`000000Re:808]BR00208]BR0030000003oool0oooo0200oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`040?ooo`00:P3oool300000080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`060?ooo`030000002;DXP0Re:80080Re:800<0000008]B
R02;DXP00P2;DXP00`000000oooo0?ooo`0O0?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`040?ooo`00:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01P3oool00`000000Re:808]BR00208]BR0030000002;DXP0Re:8
0080Re:800<000000?ooo`3oool07`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0103oool002/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo00<0000008]BR02;DXP00P2;DXP00`000000Re:808]BR00208]B
R0030000003oool0oooo01l0oooo00D000000?ooo`3oool0oooo000000020?ooo`<000001P3oool0
02`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<0000008]BR02;DXP00P2;DXP00`000000Re:808]BR00208]BR0030000003oool0oooo
01l0oooo00<000000?ooo`000000100000020?ooo`030000003oool0oooo00@0oooo000/0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000002;DXP0Re:80080Re:800<0000008]BR02;DXP00P2;DXP00`000000oooo0?ooo`0O0?ooo`80
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo000]0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
002;DXP0Re:80080Re:800<0000008]BR02;DXP00P2;DXP00`000000oooo0?ooo`0O0?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00;P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000Re:8
08]BR00208]BR0030000002;DXP0Re:80080Re:800<000000?ooo`3oool07`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01@3oool002l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0000008]BR02;DXP0
0P2;DXP00`000000Re:808]BR00208]BR0030000003oool0oooo01l0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo00D0oooo000_0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool0oooo0`0000030?ooo`030000002;DXP0Re:80080Re:800<0000008]BR02;
DXP00P2;DXP00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool01@3oool00300oooo00@000000?ooo`3oool0oooo1@0000020?ooo`050000003oool0oooo
0?ooo`000000102;DXP00`000000Re:808]BR00208]BR0030000003oool0oooo01h0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00H0oooo000a0?ooo`<000000P3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0Re:800<0000008]BR02;DXP00P2;
DXP00`000000oooo0?ooo`0N0?ooo`060000003oool0oooo0?ooo`000000oooo0`0000080?ooo`00
<@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000
102;DXP00`000000Re:808]BR00208]BR0030000003oool0oooo01h0oooo00<000000?ooo`000000
0`0000020?ooo`030000003oool0oooo00H0oooo000b0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool2000000@0Re:800<0000008]BR02;DXP00P2;DXP00`000000oooo0?oo
o`0N0?ooo`8000000P3oool01@000000oooo0?ooo`3oool0000000P0oooo000c0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000Re:808]BR00208]BR0030000002;
DXP0Re:80080Re:800<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000002;DXP0Re:80080Re:800<0000008]BR02;DXP00P2;DXP00`000000oooo0?oo
o`0N0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01`3oool003D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`8000000`2;DXP00`000000Re:808]B
R00208]BR0030000003oool0oooo01d0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00<0oooo00L000000?ooo`3oool0oooo
0000002;DXP000000080Re:800<0000008]BR02;DXP00P2;DXP00`000000oooo0?ooo`0M0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`070?ooo`00=P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0000000<0Re:80000002;DXP00`2;DXP00`000000
oooo0?ooo`0M0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`00=`3oool010000000oooo0?ooo`3oool5000000<0Re:80P00000408]BR0030000003oool0oooo
01d0oooo00D000000?ooo`3oool000000?ooo`03000000X0oooo000h0?ooo`<000000`3oool20000
00@0Re:800<0000008]BR02;DXP00P2;DXP00`000000oooo0?ooo`0L0?ooo`030000003oool00000
00<000000P3oool00`000000oooo0?ooo`080?ooo`00>@3oool00`000000oooo0?ooo`030?ooo`03
0000002;DXP0Re:80080Re:80P00000308]BR0030000003oool0oooo01`0oooo0P0000020?ooo`04
0000003oool0oooo000000/0oooo000j0?ooo`030000003oool0oooo0080oooo0P00000308]BR003
0000002;DXP000000080Re:800<000000?ooo`3oool0703oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00T0oooo000k0?ooo`070000003oool0oooo0?ooo`000000Re:800000002
08]BR0060000002;DXP0Re:80000002;DXP000007@3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool02@3oool003`0oooo00@000000?ooo`3oool000000P2;DXP00`000000
Re:80000000308]BR08000007@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00X0oooo000m0?ooo`030000003oool0000000<0Re:80P00000208]BR0@000006`3oool01P000000
oooo0?ooo`3oool000000?ooo`<00000303oool003h0oooo0P00000208]BR0D00000103oool00`00
0000oooo0?ooo`0H0?ooo`H000000P3oool00`000000oooo0?ooo`0:0?ooo`00?`3oool3000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`8000000P3oool01@000000
oooo0?ooo`3oool0000000d0oooo00110?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`03
0000003oool0oooo01D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0<0?oo
o`00@P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool04`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00d0oooo00130?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01000000B0?ooo`040000003oool0oooo0?oo
o`@00000403oool004@0oooo00<000000?ooo`3oool00`3oool3000000@0oooo0P00000?0?ooo`03
0000003oool0000000@000004P3oool004D0oooo00<000000?ooo`0000000P0000030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool400000080oooo00<000000?ooo`3oool0
4@3oool004H0oooo0P0000060?ooo`800000103oool2000000X0oooo00@000000?ooo`000000oooo
0`00000D0?ooo`00B03oool2000000H0oooo00@000000?ooo`3oool0oooo1P0000050?ooo`H00000
5P3oool004X0oooo0P0000030?ooo`H000001@3oool8000001T0oooo001<0?ooo`<000001P3oool:
000001`0oooo001?0?ooo`<0000000<0oooo0000000000001P00000P0?ooo`00DP3oool3000002H0
oooo001k0?ooo`00N`3oool007/0oooo001k0?ooo`00N`3oool007/0oooo001k0?ooo`00N`3oool0
07/0oooo001k0?ooo`00N`3oool007/0oooo001k0?ooo`00N`3oool007/0oooo001k0?ooo`00N`3o
ool007/0oooo001k0?ooo`00N`3oool007/0oooo001k0?ooo`00N`3oool007/0oooo001k0?ooo`00
N`3oool007/0oooo001k0?ooo`00N`3oool007/0oooo001k0?ooo`00N`3oool007/0oooo001k0?oo
o`00N`3oool007/0oooo001k0?ooo`00N`3oool007/0oooo0000\
\>"],
  ImageRangeCache->{{{0, 122.938}, {287, 0}} -> {0.265483, -0.00241808, \
0.00343183, 0.00343183}},
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    TagBox[\(DrawSystem[{LinearPolarizer[90, 100, 5]}]\),
      HoldForm]], "Print",
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    \("-rendered unpropagated system-"\)], "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[LinearPolarizer[90,100]]", "Input",
  CellTags->"LinearPolarizer"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.43055 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.681087 2.47576 2.22045e-16 2.47576 [
[ 0 0 0 0 ]
[ 1 2.43055 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 2.43055 L
0 2.43055 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.8473 1.17735 m
.87442 1.27389 L
s
.81582 1.08184 m
.8473 1.17735 L
s
.78032 .98844 m
.81582 1.08184 L
s
.87442 1.27389 m
.89684 1.37039 L
s
.74117 .89822 m
.78032 .98844 L
s
.89684 1.37039 m
.91426 1.46572 L
s
.69878 .81227 m
.74117 .89822 L
s
.91426 1.46572 m
.92639 1.55877 L
s
.65359 .73167 m
.69878 .81227 L
s
.92639 1.55877 m
.93297 1.64835 L
s
.60609 .65755 m
.65359 .73167 L
s
.93297 1.64835 m
.93376 1.73327 L
s
.93297 1.64835 m
.87509 1.58519 L
s
.93297 1.64835 m
.93297 1.64835 L
s
.55679 .59101 m
.60609 .65755 L
s
.93376 1.73327 m
.92858 1.81227 L
s
.87509 1.58519 m
.8154 1.52006 L
s
.5063 .53321 m
.55679 .59101 L
s
.55679 .59101 m
.55679 .59101 L
s
.55679 .59101 m
.55679 .69184 L
s
.92858 1.81227 m
.91725 1.88407 L
s
.45525 .48527 m
.5063 .53321 L
s
.55679 .69184 m
.55679 .79531 L
s
.8154 1.52006 m
.75382 1.45287 L
s
.91725 1.88407 m
.8997 1.94736 L
s
.55679 .79531 m
.55679 .90153 L
s
.40436 .4483 m
.45525 .48527 L
s
.75382 1.45287 m
.69026 1.38352 L
s
.8997 1.94736 m
.87591 2.00079 L
s
.55679 .90153 m
.55679 1.01062 L
s
.35441 .42338 m
.40436 .4483 L
s
.69026 1.38352 m
.62462 1.31189 L
s
.87591 2.00079 m
.84594 2.04308 L
s
.55679 1.01062 m
.55679 1.1227 L
s
.30625 .4115 m
.35441 .42338 L
s
.62462 1.31189 m
.55679 1.23788 L
s
.55679 1.1227 m
.55679 1.23788 L
s
.84594 2.04308 m
.80997 2.07295 L
s
.26077 .41352 m
.30625 .4115 L
s
.55679 1.23788 m
.55679 1.3563 L
s
.55679 1.23788 m
.48667 1.16137 L
s
.80997 2.07295 m
.76833 2.08924 L
s
.21892 .43012 m
.26077 .41352 L
s
.55679 1.3563 m
.55679 1.4781 L
s
.48667 1.16137 m
.41414 1.08222 L
s
.76833 2.08924 m
.72148 2.09095 L
s
.55679 1.4781 m
.55679 1.60342 L
s
.18168 .46178 m
.21892 .43012 L
s
.41414 1.08222 m
.33907 1.0003 L
s
.72148 2.09095 m
.67005 2.07728 L
s
.55679 1.60342 m
.55679 1.73242 L
s
.15 .50863 m
.18168 .46178 L
s
.33907 1.0003 m
.26132 .91547 L
s
.67005 2.07728 m
.61482 2.04772 L
s
.55679 1.73242 m
.55679 1.86526 L
s
.12483 .5705 m
.15 .50863 L
s
.26132 .91547 m
.18075 .82755 L
s
.55679 1.86526 m
.55679 2.00212 L
s
.61482 2.04772 m
.55679 2.00212 L
s
.10699 .64677 m
.12483 .5705 L
s
.55679 2.00212 m
.55679 2.00212 L
s
.55679 2.00212 m
.49709 1.94076 L
s
.18075 .82755 m
.0972 .73639 L
s
.0972 .73639 m
.10699 .64677 L
s
.49709 1.94076 m
.437 1.86436 L
s
.09601 .83783 m
.0972 .73639 L
s
.0972 .73639 m
.0972 .73639 L
s
.437 1.86436 m
.37789 1.77415 L
s
.10374 .94911 m
.09601 .83783 L
s
.37789 1.77415 m
.32121 1.67188 L
s
.12044 1.06785 m
.10374 .94911 L
s
.32121 1.67188 m
.26838 1.55974 L
s
.1459 1.19129 m
.12044 1.06785 L
s
.26838 1.55974 m
.22077 1.44031 L
s
.1796 1.31648 m
.1459 1.19129 L
s
.22077 1.44031 m
.1796 1.31648 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{118.438, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001f000182000`400?l00000o`00003oMP3oool0
07H0oooo001f0?ooo`00MP3oool007H0oooo001f0?ooo`00MP3oool007H0oooo001f0?ooo`00MP3o
ool007H0oooo001f0?ooo`00MP3oool007H0oooo001f0?ooo`00MP3oool007H0oooo001f0?ooo`00
MP3oool007H0oooo001f0?ooo`00MP3oool007H0oooo001f0?ooo`00MP3oool007H0oooo001f0?oo
o`00MP3oool007H0oooo001f0?ooo`00MP3oool007H0oooo001f0?ooo`00MP3oool007H0oooo001f
0?ooo`00MP3oool007H0oooo001f0?ooo`00MP3oool007H0oooo001f0?ooo`00MP3oool007H0oooo
001f0?ooo`00MP3oool007H0oooo001f0?ooo`00MP3oool007H0oooo000M0?ooo`X00000C`3oool0
01X0oooo0`00000:0?ooo`@00000B`3oool001T0oooo00<000000?ooo`3oool03`3oool2000004T0
oooo000H0?ooo`030000003oool0oooo0180oooo0P0000170?ooo`005`3oool00`000000oooo0?oo
o`0E0?ooo`800000A@3oool001H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`12
0?ooo`005@3oool00`000000oooo0?ooo`0J0?ooo`800000@P3oool001D0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0o0?ooo`00503oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo03h0oooo000C0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0?@3o
ool00180oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0l0?ooo`004@3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo03/0oooo000A0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0>P3oool00100oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0i0?ooo`00403oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03P0oooo000?
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0>03oool000l0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0g0?ooo`003`3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo03H0oooo000>0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
=@3oool000h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0d0?ooo`003P3oool0
0`000000oooo0?ooo`0_0?ooo`800000=03oool000d0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0b0?ooo`003@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0380
oooo000=0?ooo`030000003oool0oooo0340oooo0P00000c0?ooo`003@3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool000000380oooo000=0?ooo`030000003oool0oooo0340oooo00@00000
0?ooo`3oool00000<@3oool000`0oooo00<000000?ooo`3oool0<P3oool010000000oooo0?ooo`00
000a0?ooo`00303oool00`000000oooo0?ooo`0b0?ooo`050000003oool0oooo0?ooo`000000<03o
ool000`0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo02d0oooo000<0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0/0?ooo`00303oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0;03oool000`0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo02/0oooo000<0?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0Z0?ooo`002`3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:P3oool000/0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02T0oooo000;0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Y0?ooo`00
2`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
:03oool000/0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo02L0oooo000;0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0W0?ooo`002`3oool2000003@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0V0?ooo`002`3oool00`000000oooo0000000c0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool09@3oool000/0oooo00@000000?ooo`3oool00000<P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo02D0oooo000;0?ooo`050000003oool0oooo0?ooo`00
0000<@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02@0oooo000;0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo02@0oooo000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02<0oooo000;0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0280oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0280oooo000;0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0240
oooo000;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0240oooo000;0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0200oooo000;
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0200oooo000;0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01l0oooo000;0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo01l0oooo000;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01h0oooo000;0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo01h0oooo000;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01d0oooo000;0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
01d0oooo000<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01`0oooo000<0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01`0oooo
000<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01/0oooo000<0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01/0oooo000<0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01/0oooo000<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01X0oooo000<0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo01X0oooo000<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01T0oooo000<0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo01T0oooo000<0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo01T0oooo000=0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01P0
oooo000=0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo01P0oooo000=0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0oooo000=
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo01L0oooo000=0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0oooo000=0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo01H0oooo000=0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01H0oooo000>0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01H0oooo000>0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01D0oooo000>0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01D0oooo000>0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo01D0oooo000>0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01@0oooo
000>0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo01@0oooo000?0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0oooo000?0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo01<0oooo000?0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0oooo000?0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0180oooo000?0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo0180oooo000@0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo0140oooo000@0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0140
oooo000@0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo0140oooo000@0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0100oooo000A
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo0100oooo000A0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0100oooo000A0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0100oooo000A0?ooo`030000003oool0oooo02T0oooo00D000000?ooo`3oool0
oooo0000000R0?ooo`030000003oool0oooo00l0oooo000B0?ooo`030000003oool0oooo02T0oooo
00@000000?ooo`3oool000008P3oool00`000000oooo0?ooo`0?0?ooo`004P3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool000000280oooo00<000000?ooo`3oool03`3oool00180oooo00<0
00000?ooo`3oool0:`3oool2000002<0oooo00<000000?ooo`3oool03P3oool00180oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00h0oooo000C0?oo
o`030000003oool0oooo02/0oooo0P00000R0?ooo`030000003oool0oooo00h0oooo000C0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`0>0?ooo`00
4`3oool00`000000oooo0?ooo`0[0?ooo`040000003oool0oooo00000240oooo00<000000?ooo`3o
ool03@3oool001@0oooo00<000000?ooo`3oool0:P3oool01@000000oooo0?ooo`3oool000000200
oooo00<000000?ooo`3oool03@3oool001@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool03@3oool001@0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool03@3oool001@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0303oool001D0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0303oool001D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0303oool001D0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
2`3oool001D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool02`3oool001H0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02`3oool0
01H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool02`3oool001H0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02P3oool001L0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool02P3oool001L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool001L0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool02P3oool001L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool02P3oool001P0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool02@3oool001P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool001P0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02@3o
ool001T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02@3oool001T0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0203oool001X0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool001X0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0203oool001/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool001/0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0203oool001/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool001`0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
203oool001`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0203oool001d0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool0
01d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool01`3oool001h0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool001h0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool001h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool001l0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01`3oool001l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00200oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01`3oool00200oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00240oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool00240oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01`3oool00240oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00280
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0U0?ooo`050000003oool0oooo0?oo
o`000000203oool00280oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0V0?ooo`04
0000003oool0oooo000000P0oooo000S0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo000000080?ooo`008`3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo02P0oooo0P0000080?ooo`00903oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool01P3oool002@0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00H0oooo000T0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`060?ooo`009@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01P3oool002D0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00H0oooo
000V0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`060?ooo`009P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool01P3oool002L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00H0oooo000X0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`060?ooo`00:03oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool01P3oool002T0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00H0oooo000Y0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01P3oool002/0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00H0
oooo000[0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00H0oooo000]0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`060?ooo`00;P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool01P3oool002h0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00H0oooo000_0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`060?ooo`00<03oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01P3oool0
0340oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00L0oooo000a0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`070?ooo`00<P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool01`3oool003<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo00L0oooo000c0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool003D0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`00=`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203o
ool003L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00T0oooo000h0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`090?ooo`00>@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool02@3oool003X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00X0oooo000k0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02P3oool003d0oooo00D000000?oo
o`3oool0oooo0000000V0?ooo`030000003oool0oooo00/0oooo000n0?ooo`040000003oool0oooo
000002H0oooo00<000000?ooo`3oool02`3oool003l0oooo00<000000?ooo`0000009@3oool00`00
0000oooo0?ooo`0<0?ooo`00@03oool2000002D0oooo00<000000?ooo`3oool0303oool00440oooo
0P00000S0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool03@3oool004@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0>
0?ooo`00A@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00l0oooo00160?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool03`3oool004L0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0@0?ooo`00B03oool2000001P0oooo00<000000?ooo`3oool04@3o
ool004X0oooo0P00000E0?ooo`030000003oool0oooo0180oooo001<0?ooo`8000004P3oool00`00
0000oooo0?ooo`0C0?ooo`00CP3oool3000000d0oooo0P00000F0?ooo`00D@3oool3000000L0oooo
0`00000H0?ooo`00E03oool7000001/0oooo001f0?ooo`00MP3oool007H0oooo001f0?ooo`00MP3o
ool007H0oooo001f0?ooo`00MP3oool007H0oooo001f0?ooo`00MP3oool007H0oooo001f0?ooo`00
MP3oool007H0oooo001f0?ooo`00MP3oool007H0oooo001f0?ooo`00MP3oool007H0oooo001f0?oo
o`00MP3oool007H0oooo001f0?ooo`00MP3oool007H0oooo001f0?ooo`00MP3oool007H0oooo001f
0?ooo`00MP3oool007H0oooo001f0?ooo`00MP3oool007H0oooo001f0?ooo`00MP3oool007H0oooo
001f0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 117.438}, {287, 0}} -> {0.2751, -0.00269161, \
0.00343945, 0.00343945}},
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    TagBox[\(DrawSystem[{LinearPolarizer[90, 100]}]\),
      HoldForm]], "Print",
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    \("-rendered unpropagated system-"\)], "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
LinearPolarizer[90, 100, 20, CenterThickness->2, Centered->0], \
PlotType->TopView];\
\>", "Input",
  CellTags->"LinearPolarizer"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 2.5 0.047619 [
[ 0 0 0 0 ]
[ 1 5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.02381 .11905 m
.11905 .11905 L
.11905 .51587 L
.02381 .51587 L
.02381 .11905 L
F
.02381 .51587 m
.11905 .51587 L
.11905 .9127 L
.02381 .9127 L
.02381 .51587 L
F
.02381 .9127 m
.11905 .9127 L
.11905 1.30952 L
.02381 1.30952 L
.02381 .9127 L
F
.02381 1.30952 m
.11905 1.30952 L
.11905 1.70635 L
.02381 1.70635 L
.02381 1.30952 L
F
.02381 1.70635 m
.11905 1.70635 L
.11905 2.10317 L
.02381 2.10317 L
.02381 1.70635 L
F
.02381 2.10317 m
.11905 2.10317 L
.11905 2.5 L
.02381 2.5 L
.02381 2.10317 L
F
.02381 2.5 m
.11905 2.5 L
.11905 2.89683 L
.02381 2.89683 L
.02381 2.5 L
F
.02381 2.89683 m
.11905 2.89683 L
.11905 3.29365 L
.02381 3.29365 L
.02381 2.89683 L
F
.02381 3.29365 m
.11905 3.29365 L
.11905 3.69048 L
.02381 3.69048 L
.02381 3.29365 L
F
.02381 3.69048 m
.11905 3.69048 L
.11905 4.0873 L
.02381 4.0873 L
.02381 3.69048 L
F
.02381 4.0873 m
.11905 4.0873 L
.11905 4.48413 L
.02381 4.48413 L
.02381 4.0873 L
F
.02381 4.48413 m
.11905 4.48413 L
.11905 4.88095 L
.02381 4.88095 L
.02381 4.48413 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .11905 m
.02381 .51587 L
.02381 .9127 L
.02381 1.30952 L
.02381 1.70635 L
.02381 2.10317 L
.02381 2.5 L
.02381 2.89683 L
.02381 3.29365 L
.02381 3.69048 L
.02381 4.0873 L
.02381 4.48413 L
.02381 4.88095 L
.11905 4.88095 L
.11905 4.48413 L
.11905 4.0873 L
.11905 3.69048 L
.11905 3.29365 L
.11905 2.89683 L
.11905 2.5 L
.11905 2.10317 L
.11905 1.70635 L
.11905 1.30952 L
.11905 .9127 L
.11905 .51587 L
.11905 .11905 L
.02381 .11905 L
s
.5 g
.02381 2.5 m
.11905 2.5 L
.11905 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.11905 2.5 L
.11905 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.11905 2.5 L
.11905 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.11905 2.5 L
.11905 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.11905 2.5 L
.11905 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.11905 2.5 L
.11905 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.11905 2.5 L
.11905 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.11905 2.5 L
.11905 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.11905 2.5 L
.11905 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.11905 2.5 L
.11905 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.11905 2.5 L
.11905 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.11905 2.5 L
.11905 2.5 L
.02381 2.5 L
.02381 2.5 L
F
0 g
.02381 2.5 m
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.02381 2.5 L
s
.5 g
.11905 .11905 m
.97619 .11905 L
.97619 .51587 L
.11905 .51587 L
.11905 .11905 L
F
.11905 .51587 m
.97619 .51587 L
.97619 .9127 L
.11905 .9127 L
.11905 .51587 L
F
.11905 .9127 m
.97619 .9127 L
.97619 1.30952 L
.11905 1.30952 L
.11905 .9127 L
F
.11905 1.30952 m
.97619 1.30952 L
.97619 1.70635 L
.11905 1.70635 L
.11905 1.30952 L
F
.11905 1.70635 m
.97619 1.70635 L
.97619 2.10317 L
.11905 2.10317 L
.11905 1.70635 L
F
.11905 2.10317 m
.97619 2.10317 L
.97619 2.5 L
.11905 2.5 L
.11905 2.10317 L
F
.11905 2.5 m
.97619 2.5 L
.97619 2.89683 L
.11905 2.89683 L
.11905 2.5 L
F
.11905 2.89683 m
.97619 2.89683 L
.97619 3.29365 L
.11905 3.29365 L
.11905 2.89683 L
F
.11905 3.29365 m
.97619 3.29365 L
.97619 3.69048 L
.11905 3.69048 L
.11905 3.29365 L
F
.11905 3.69048 m
.97619 3.69048 L
.97619 4.0873 L
.11905 4.0873 L
.11905 3.69048 L
F
.11905 4.0873 m
.97619 4.0873 L
.97619 4.48413 L
.11905 4.48413 L
.11905 4.0873 L
F
.11905 4.48413 m
.97619 4.48413 L
.97619 4.88095 L
.11905 4.88095 L
.11905 4.48413 L
F
0 g
.11905 .11905 m
.11905 .51587 L
.11905 .9127 L
.11905 1.30952 L
.11905 1.70635 L
.11905 2.10317 L
.11905 2.5 L
.11905 2.89683 L
.11905 3.29365 L
.11905 3.69048 L
.11905 4.0873 L
.11905 4.48413 L
.11905 4.88095 L
.97619 4.88095 L
.97619 4.48413 L
.97619 4.0873 L
.97619 3.69048 L
.97619 3.29365 L
.97619 2.89683 L
.97619 2.5 L
.97619 2.10317 L
.97619 1.70635 L
.97619 1.30952 L
.97619 .9127 L
.97619 .51587 L
.97619 .11905 L
.11905 .11905 L
s
.5 g
.11905 2.5 m
.97619 2.5 L
.97619 2.5 L
.11905 2.5 L
.11905 2.5 L
F
.11905 2.5 m
.97619 2.5 L
.97619 2.5 L
.11905 2.5 L
.11905 2.5 L
F
.11905 2.5 m
.97619 2.5 L
.97619 2.5 L
.11905 2.5 L
.11905 2.5 L
F
.11905 2.5 m
.97619 2.5 L
.97619 2.5 L
.11905 2.5 L
.11905 2.5 L
F
.11905 2.5 m
.97619 2.5 L
.97619 2.5 L
.11905 2.5 L
.11905 2.5 L
F
.11905 2.5 m
.97619 2.5 L
.97619 2.5 L
.11905 2.5 L
.11905 2.5 L
F
.11905 2.5 m
.97619 2.5 L
.97619 2.5 L
.11905 2.5 L
.11905 2.5 L
F
.11905 2.5 m
.97619 2.5 L
.97619 2.5 L
.11905 2.5 L
.11905 2.5 L
F
.11905 2.5 m
.97619 2.5 L
.97619 2.5 L
.11905 2.5 L
.11905 2.5 L
F
.11905 2.5 m
.97619 2.5 L
.97619 2.5 L
.11905 2.5 L
.11905 2.5 L
F
.11905 2.5 m
.97619 2.5 L
.97619 2.5 L
.11905 2.5 L
.11905 2.5 L
F
.11905 2.5 m
.97619 2.5 L
.97619 2.5 L
.11905 2.5 L
.11905 2.5 L
F
0 g
.11905 2.5 m
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.11905 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.11905 2.5 L
s
.02381 4.88095 m
.02381 4.86058 L
.02381 4.79982 L
.02381 4.69971 L
.02381 4.56197 L
.02381 4.38894 L
.02381 4.18359 L
.02381 3.94943 L
.02381 3.69048 L
.02381 3.41115 L
.02381 3.11624 L
.02381 2.81078 L
.02381 2.5 L
.02381 2.18922 L
.02381 1.88376 L
.02381 1.58885 L
.02381 1.30952 L
.02381 1.05057 L
.02381 .81641 L
.02381 .61106 L
.02381 .43803 L
.02381 .30029 L
.02381 .20018 L
.02381 .13942 L
.02381 .11905 L
.02381 .13942 L
.02381 .20018 L
.02381 .30029 L
.02381 .43803 L
.02381 .61106 L
.02381 .81641 L
.02381 1.05057 L
.02381 1.30952 L
.02381 1.58885 L
.02381 1.88376 L
.02381 2.18922 L
.02381 2.5 L
.02381 2.81078 L
.02381 3.11624 L
.02381 3.41115 L
.02381 3.69048 L
.02381 3.94943 L
.02381 4.18359 L
.02381 4.38894 L
.02381 4.56197 L
.02381 4.69971 L
.02381 4.79982 L
.02381 4.86058 L
.02381 4.88095 L
s
.11905 4.88095 m
.11905 4.86058 L
.11905 4.79982 L
.11905 4.69971 L
.11905 4.56197 L
.11905 4.38894 L
.11905 4.18359 L
.11905 3.94943 L
.11905 3.69048 L
.11905 3.41115 L
.11905 3.11624 L
.11905 2.81078 L
.11905 2.5 L
.11905 2.18922 L
.11905 1.88376 L
.11905 1.58885 L
.11905 1.30952 L
.11905 1.05057 L
.11905 .81641 L
.11905 .61106 L
.11905 .43803 L
.11905 .30029 L
.11905 .20018 L
.11905 .13942 L
.11905 .11905 L
.11905 .13942 L
.11905 .20018 L
.11905 .30029 L
.11905 .43803 L
.11905 .61106 L
.11905 .81641 L
.11905 1.05057 L
.11905 1.30952 L
.11905 1.58885 L
.11905 1.88376 L
.11905 2.18922 L
.11905 2.5 L
.11905 2.81078 L
.11905 3.11624 L
.11905 3.41115 L
.11905 3.69048 L
.11905 3.94943 L
.11905 4.18359 L
.11905 4.38894 L
.11905 4.56197 L
.11905 4.69971 L
.11905 4.79982 L
.11905 4.86058 L
.11905 4.88095 L
s
.97619 4.88095 m
.97619 4.86058 L
.97619 4.79982 L
.97619 4.69971 L
.97619 4.56197 L
.97619 4.38894 L
.97619 4.18359 L
.97619 3.94943 L
.97619 3.69048 L
.97619 3.41115 L
.97619 3.11624 L
.97619 2.81078 L
.97619 2.5 L
.97619 2.18922 L
.97619 1.88376 L
.97619 1.58885 L
.97619 1.30952 L
.97619 1.05057 L
.97619 .81641 L
.97619 .61106 L
.97619 .43803 L
.97619 .30029 L
.97619 .20018 L
.97619 .13942 L
.97619 .11905 L
.97619 .13942 L
.97619 .20018 L
.97619 .30029 L
.97619 .43803 L
.97619 .61106 L
.97619 .81641 L
.97619 1.05057 L
.97619 1.30952 L
.97619 1.58885 L
.97619 1.88376 L
.97619 2.18922 L
.97619 2.5 L
.97619 2.81078 L
.97619 3.11624 L
.97619 3.41115 L
.97619 3.69048 L
.97619 3.94943 L
.97619 4.18359 L
.97619 4.38894 L
.97619 4.56197 L
.97619 4.69971 L
.97619 4.79982 L
.97619 4.86058 L
.97619 4.88095 L
s
.02381 4.88095 m
.11905 4.88095 L
.11905 4.86058 L
.02381 4.86058 L
.02381 4.88095 L
s
.02381 4.86058 m
.11905 4.86058 L
.11905 4.79982 L
.02381 4.79982 L
.02381 4.86058 L
s
.02381 4.79982 m
.11905 4.79982 L
.11905 4.69971 L
.02381 4.69971 L
.02381 4.79982 L
s
.02381 4.69971 m
.11905 4.69971 L
.11905 4.56197 L
.02381 4.56197 L
.02381 4.69971 L
s
.02381 4.56197 m
.11905 4.56197 L
.11905 4.38894 L
.02381 4.38894 L
.02381 4.56197 L
s
.02381 4.38894 m
.11905 4.38894 L
.11905 4.18359 L
.02381 4.18359 L
.02381 4.38894 L
s
.02381 4.18359 m
.11905 4.18359 L
.11905 3.94943 L
.02381 3.94943 L
.02381 4.18359 L
s
.02381 3.94943 m
.11905 3.94943 L
.11905 3.69048 L
.02381 3.69048 L
.02381 3.94943 L
s
.02381 3.69048 m
.11905 3.69048 L
.11905 3.41115 L
.02381 3.41115 L
.02381 3.69048 L
s
.02381 3.41115 m
.11905 3.41115 L
.11905 3.11624 L
.02381 3.11624 L
.02381 3.41115 L
s
.02381 3.11624 m
.11905 3.11624 L
.11905 2.81078 L
.02381 2.81078 L
.02381 3.11624 L
s
.02381 2.81078 m
.11905 2.81078 L
.11905 2.5 L
.02381 2.5 L
.02381 2.81078 L
s
.02381 2.5 m
.11905 2.5 L
.11905 2.18922 L
.02381 2.18922 L
.02381 2.5 L
s
.02381 2.18922 m
.11905 2.18922 L
.11905 1.88376 L
.02381 1.88376 L
.02381 2.18922 L
s
.02381 1.88376 m
.11905 1.88376 L
.11905 1.58885 L
.02381 1.58885 L
.02381 1.88376 L
s
.02381 1.58885 m
.11905 1.58885 L
.11905 1.30952 L
.02381 1.30952 L
.02381 1.58885 L
s
.02381 1.30952 m
.11905 1.30952 L
.11905 1.05057 L
.02381 1.05057 L
.02381 1.30952 L
s
.02381 1.05057 m
.11905 1.05057 L
.11905 .81641 L
.02381 .81641 L
.02381 1.05057 L
s
.02381 .81641 m
.11905 .81641 L
.11905 .61106 L
.02381 .61106 L
.02381 .81641 L
s
.02381 .61106 m
.11905 .61106 L
.11905 .43803 L
.02381 .43803 L
.02381 .61106 L
s
.02381 .43803 m
.11905 .43803 L
.11905 .30029 L
.02381 .30029 L
.02381 .43803 L
s
.02381 .30029 m
.11905 .30029 L
.11905 .20018 L
.02381 .20018 L
.02381 .30029 L
s
.02381 .20018 m
.11905 .20018 L
.11905 .13942 L
.02381 .13942 L
.02381 .20018 L
s
.02381 .13942 m
.11905 .13942 L
.11905 .11905 L
.02381 .11905 L
.02381 .13942 L
s
.02381 .11905 m
.11905 .11905 L
.11905 .13942 L
.02381 .13942 L
.02381 .11905 L
s
.02381 .13942 m
.11905 .13942 L
.11905 .20018 L
.02381 .20018 L
.02381 .13942 L
s
.02381 .20018 m
.11905 .20018 L
.11905 .30029 L
.02381 .30029 L
.02381 .20018 L
s
.02381 .30029 m
.11905 .30029 L
.11905 .43803 L
.02381 .43803 L
.02381 .30029 L
s
.02381 .43803 m
.11905 .43803 L
.11905 .61106 L
.02381 .61106 L
.02381 .43803 L
s
.02381 .61106 m
.11905 .61106 L
.11905 .81641 L
.02381 .81641 L
.02381 .61106 L
s
.02381 .81641 m
.11905 .81641 L
.11905 1.05057 L
.02381 1.05057 L
.02381 .81641 L
s
.02381 1.05057 m
.11905 1.05057 L
.11905 1.30952 L
.02381 1.30952 L
.02381 1.05057 L
s
.02381 1.30952 m
.11905 1.30952 L
.11905 1.58885 L
.02381 1.58885 L
.02381 1.30952 L
s
.02381 1.58885 m
.11905 1.58885 L
.11905 1.88376 L
.02381 1.88376 L
.02381 1.58885 L
s
.02381 1.88376 m
.11905 1.88376 L
.11905 2.18922 L
.02381 2.18922 L
.02381 1.88376 L
s
.02381 2.18922 m
.11905 2.18922 L
.11905 2.5 L
.02381 2.5 L
.02381 2.18922 L
s
.02381 2.5 m
.11905 2.5 L
.11905 2.81078 L
.02381 2.81078 L
.02381 2.5 L
s
.02381 2.81078 m
.11905 2.81078 L
.11905 3.11624 L
.02381 3.11624 L
.02381 2.81078 L
s
.02381 3.11624 m
.11905 3.11624 L
.11905 3.41115 L
.02381 3.41115 L
.02381 3.11624 L
s
.02381 3.41115 m
.11905 3.41115 L
.11905 3.69048 L
.02381 3.69048 L
.02381 3.41115 L
s
.02381 3.69048 m
.11905 3.69048 L
.11905 3.94943 L
.02381 3.94943 L
.02381 3.69048 L
s
.02381 3.94943 m
.11905 3.94943 L
.11905 4.18359 L
.02381 4.18359 L
.02381 3.94943 L
s
.02381 4.18359 m
.11905 4.18359 L
.11905 4.38894 L
.02381 4.38894 L
.02381 4.18359 L
s
.02381 4.38894 m
.11905 4.38894 L
.11905 4.56197 L
.02381 4.56197 L
.02381 4.38894 L
s
.02381 4.56197 m
.11905 4.56197 L
.11905 4.69971 L
.02381 4.69971 L
.02381 4.56197 L
s
.02381 4.69971 m
.11905 4.69971 L
.11905 4.79982 L
.02381 4.79982 L
.02381 4.69971 L
s
.02381 4.79982 m
.11905 4.79982 L
.11905 4.86058 L
.02381 4.86058 L
.02381 4.79982 L
s
.02381 4.86058 m
.11905 4.86058 L
.11905 4.88095 L
.02381 4.88095 L
.02381 4.86058 L
s
.11905 4.88095 m
.97619 4.88095 L
.97619 4.86058 L
.11905 4.86058 L
.11905 4.88095 L
s
.11905 4.86058 m
.97619 4.86058 L
.97619 4.79982 L
.11905 4.79982 L
.11905 4.86058 L
s
.11905 4.79982 m
.97619 4.79982 L
.97619 4.69971 L
.11905 4.69971 L
.11905 4.79982 L
s
.11905 4.69971 m
.97619 4.69971 L
.97619 4.56197 L
.11905 4.56197 L
.11905 4.69971 L
s
.11905 4.56197 m
.97619 4.56197 L
.97619 4.38894 L
.11905 4.38894 L
.11905 4.56197 L
s
.11905 4.38894 m
.97619 4.38894 L
.97619 4.18359 L
.11905 4.18359 L
.11905 4.38894 L
s
.11905 4.18359 m
.97619 4.18359 L
.97619 3.94943 L
.11905 3.94943 L
.11905 4.18359 L
s
.11905 3.94943 m
.97619 3.94943 L
.97619 3.69048 L
.11905 3.69048 L
.11905 3.94943 L
s
.11905 3.69048 m
.97619 3.69048 L
.97619 3.41115 L
.11905 3.41115 L
.11905 3.69048 L
s
.11905 3.41115 m
.97619 3.41115 L
.97619 3.11624 L
.11905 3.11624 L
.11905 3.41115 L
s
.11905 3.11624 m
.97619 3.11624 L
.97619 2.81078 L
.11905 2.81078 L
.11905 3.11624 L
s
.11905 2.81078 m
.97619 2.81078 L
.97619 2.5 L
.11905 2.5 L
.11905 2.81078 L
s
.11905 2.5 m
.97619 2.5 L
.97619 2.18922 L
.11905 2.18922 L
.11905 2.5 L
s
.11905 2.18922 m
.97619 2.18922 L
.97619 1.88376 L
.11905 1.88376 L
.11905 2.18922 L
s
.11905 1.88376 m
.97619 1.88376 L
.97619 1.58885 L
.11905 1.58885 L
.11905 1.88376 L
s
.11905 1.58885 m
.97619 1.58885 L
.97619 1.30952 L
.11905 1.30952 L
.11905 1.58885 L
s
.11905 1.30952 m
.97619 1.30952 L
.97619 1.05057 L
.11905 1.05057 L
.11905 1.30952 L
s
.11905 1.05057 m
.97619 1.05057 L
.97619 .81641 L
.11905 .81641 L
.11905 1.05057 L
s
.11905 .81641 m
.97619 .81641 L
.97619 .61106 L
.11905 .61106 L
.11905 .81641 L
s
.11905 .61106 m
.97619 .61106 L
.97619 .43803 L
.11905 .43803 L
.11905 .61106 L
s
.11905 .43803 m
.97619 .43803 L
.97619 .30029 L
.11905 .30029 L
.11905 .43803 L
s
.11905 .30029 m
.97619 .30029 L
.97619 .20018 L
.11905 .20018 L
.11905 .30029 L
s
.11905 .20018 m
.97619 .20018 L
.97619 .13942 L
.11905 .13942 L
.11905 .20018 L
s
.11905 .13942 m
.97619 .13942 L
.97619 .11905 L
.11905 .11905 L
.11905 .13942 L
s
.11905 .11905 m
.97619 .11905 L
.97619 .13942 L
.11905 .13942 L
.11905 .11905 L
s
.11905 .13942 m
.97619 .13942 L
.97619 .20018 L
.11905 .20018 L
.11905 .13942 L
s
.11905 .20018 m
.97619 .20018 L
.97619 .30029 L
.11905 .30029 L
.11905 .20018 L
s
.11905 .30029 m
.97619 .30029 L
.97619 .43803 L
.11905 .43803 L
.11905 .30029 L
s
.11905 .43803 m
.97619 .43803 L
.97619 .61106 L
.11905 .61106 L
.11905 .43803 L
s
.11905 .61106 m
.97619 .61106 L
.97619 .81641 L
.11905 .81641 L
.11905 .61106 L
s
.11905 .81641 m
.97619 .81641 L
.97619 1.05057 L
.11905 1.05057 L
.11905 .81641 L
s
.11905 1.05057 m
.97619 1.05057 L
.97619 1.30952 L
.11905 1.30952 L
.11905 1.05057 L
s
.11905 1.30952 m
.97619 1.30952 L
.97619 1.58885 L
.11905 1.58885 L
.11905 1.30952 L
s
.11905 1.58885 m
.97619 1.58885 L
.97619 1.88376 L
.11905 1.88376 L
.11905 1.58885 L
s
.11905 1.88376 m
.97619 1.88376 L
.97619 2.18922 L
.11905 2.18922 L
.11905 1.88376 L
s
.11905 2.18922 m
.97619 2.18922 L
.97619 2.5 L
.11905 2.5 L
.11905 2.18922 L
s
.11905 2.5 m
.97619 2.5 L
.97619 2.81078 L
.11905 2.81078 L
.11905 2.5 L
s
.11905 2.81078 m
.97619 2.81078 L
.97619 3.11624 L
.11905 3.11624 L
.11905 2.81078 L
s
.11905 3.11624 m
.97619 3.11624 L
.97619 3.41115 L
.11905 3.41115 L
.11905 3.11624 L
s
.11905 3.41115 m
.97619 3.41115 L
.97619 3.69048 L
.11905 3.69048 L
.11905 3.41115 L
s
.11905 3.69048 m
.97619 3.69048 L
.97619 3.94943 L
.11905 3.94943 L
.11905 3.69048 L
s
.11905 3.94943 m
.97619 3.94943 L
.97619 4.18359 L
.11905 4.18359 L
.11905 3.94943 L
s
.11905 4.18359 m
.97619 4.18359 L
.97619 4.38894 L
.11905 4.38894 L
.11905 4.18359 L
s
.11905 4.38894 m
.97619 4.38894 L
.97619 4.56197 L
.11905 4.56197 L
.11905 4.38894 L
s
.11905 4.56197 m
.97619 4.56197 L
.97619 4.69971 L
.11905 4.69971 L
.11905 4.56197 L
s
.11905 4.69971 m
.97619 4.69971 L
.97619 4.79982 L
.11905 4.79982 L
.11905 4.69971 L
s
.11905 4.79982 m
.97619 4.79982 L
.97619 4.86058 L
.11905 4.86058 L
.11905 4.79982 L
s
.11905 4.86058 m
.97619 4.86058 L
.97619 4.88095 L
.11905 4.88095 L
.11905 4.86058 L
s
0 0 m
1 0 L
1 5 L
0 5 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{57.5625, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40000i000182000`400?l00000o`00003o>@3oool0
03T0oooo000i0?ooo`00>@3oool003T0oooo000i0?ooo`00>@3oool003T0oooo000i0?ooo`0000<0
oooo000000000000=@0000010?ooo`0000<0oooo000000000000=@0000010?ooo`0000<0oooo0000
001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0
Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000
001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo000000000000=@0000010?ooo`0000<0oooo
0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo
00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`03
0000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo
07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1o
Ogl100000040oooo00000`3oool000000000000e00000040oooo00000`3oool0000007moO`0307mo
O`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000
Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0
;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@00
00010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool0
00030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0
00000000000e00000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo
0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3o
ool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3o
ool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001o
Ogl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo
00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001o
Ogl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^
07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl10000
0040oooo00000`3oool000000000000e00000040oooo00000`3oool0000007moO`0307moO`030000
001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07mo
O`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl1
00000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?oo
o`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?oo
o`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007mo
O`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl0
0`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007mo
O`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0
Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`400000
0@3oool000030?ooo`000000000003D000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<00000
07moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo
02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`40
00000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo
00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo
0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo
00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`03
0000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo
07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1o
Ogl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@000001
0?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool00003
0?ooo`000000000003D000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0
;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@00
00010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool0
00030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0
000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl0
0`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0
000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0
Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07mo
O`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040
oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0
oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000
Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307mo
O`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo000000000000=@0000010?ooo`00
00<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`00
0000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`03
07moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`00
0000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1o
Ogl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo
0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3o
ool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3o
ool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001o
Ogl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo
00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001o
Ogl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^
07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl10000
0040oooo00000`3oool000000000000e00000040oooo00000`3oool0000007moO`0307moO`030000
001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07mo
O`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl1
00000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?oo
o`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?oo
o`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007mo
O`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl0
0`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007mo
O`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0
Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`400000
0@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo0000
0`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000
001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0
Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000
001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo000000000000=@0000010?ooo`0000<0oooo
0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo
00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`03
0000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo
07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1o
Ogl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@000001
0?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool00003
0?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool00000
07moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1o
Ogl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<00000
07moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo
02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`40
00000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo
00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo
0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`0000000000
03D000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040
oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0
oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000
Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307mo
O`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000
Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0
;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@00
00010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool0
00030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0
000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl0
0`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0
000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0
Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07mo
O`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040
oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0
oooo000000000000=@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^
07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl10000
0040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`00
00<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`00
0000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`03
07moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`00
0000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1o
Ogl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo
0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3o
ool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3o
ool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001o
Ogl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo
00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001o
Ogl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^
07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl10000
0040oooo00000`3oool000000000000e00000040oooo00000`3oool0000007moO`0307moO`030000
001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07mo
O`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl1
00000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?oo
o`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?oo
o`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007mo
O`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl0
0`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007mo
O`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0
Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`400000
0@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo0000
0`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000
001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0
Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000
001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo000000000000=@0000010?ooo`0000<0oooo
0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo
00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`03
0000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo
07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1o
Ogl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@000001
0?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool00003
0?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool00000
07moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1o
Ogl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<00000
07moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo
02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`40
00000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo
00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo
0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`0000000000
03D000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040
oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0
oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000
Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307mo
O`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000
Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0
;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@00
00010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool0
00030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0
000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl0
0`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0
000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0
Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo000000000000=@0000010?ooo`0000<0oooo0000001o
Ogl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo
00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001o
Ogl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^
07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl10000
0040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`00
00<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`00
0000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`03
07moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`00
0000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1o
Ogl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo
0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3o
ool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3o
ool000000000000e00000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0
Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`400000
0@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo0000
0`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000
001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0
Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000
001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07mo
O`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl1
00000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?oo
o`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?oo
o`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool000000000
000e00000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@000001
0?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool00003
0?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool00000
07moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1o
Ogl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<00000
07moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo
02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`40
00000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo
00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo
0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`0000000000
03D000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040
oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0
oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000
Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307mo
O`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000
Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0
;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@00
00010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool0
00030?ooo`000000000003D000000@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1o
Ogl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo
0@0000010?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3o
ool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3o
ool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000001o
Ogl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000000003D00000
0@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo0000
0`3oool0000007moO`0307moO`030000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo0000
001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo00<0
Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`030000
001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo000000000000=@0000010?ooo`0000<0oooo
0000001oOgl00`1oOgl00`000000Ogmo07moO`0^07moO`4000000@3oool000030?ooo`000000Ogmo
00<0Ogmo00<0000007moO`1oOgl0;P1oOgl100000040oooo00000`3oool0000007moO`0307moO`03
0000001oOgl0Ogmo02h0Ogmo0@0000010?ooo`0000<0oooo000000000000=@0000010?ooo`0000<0
oooo000000000000=@0000010?ooo`00>@3oool003T0oooo000i0?ooo`00>@3oool003T0oooo000i
0?ooo`00>@3oool003T0oooo0000\
\>"],
  ImageRangeCache->{{{0, 56.5625}, {287, 0}} -> {-0.500105, -53.2779, \
0.371275, 0.371275}},
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[LinearPolarizer[90, 100, -20, CenterThickness->2, \
Centered->0]];\
\>", "Input",
  CellTags->"LinearPolarizer"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.87418 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.414588 1.93032 1.11022e-16 1.93032 [
[ 0 0 0 0 ]
[ 1 1.87418 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.87418 L
0 1.87418 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65432 .95571 m
.67399 1.02641 L
s
.87881 .88435 m
.65432 .95571 L
s
.63124 .88584 m
.65432 .95571 L
s
.85532 .81296 m
.63124 .88584 L
s
.60501 .81758 m
.63124 .88584 L
s
.67399 1.02641 m
.69 1.09713 L
s
.89925 .95643 m
.67399 1.02641 L
s
.82906 .74307 m
.60501 .81758 L
s
.57589 .75173 m
.60501 .81758 L
s
.69 1.09713 m
.70214 1.16706 L
s
.91641 1.02842 m
.69 1.09713 L
s
.80029 .67549 m
.57589 .75173 L
s
.5442 .68908 m
.57589 .75173 L
s
.70214 1.16706 m
.71019 1.23537 L
s
.93006 1.09948 m
.70214 1.16706 L
s
.76932 .611 m
.5442 .68908 L
s
.51026 .63042 m
.5442 .68908 L
s
.87838 .96292 m
.858 .89096 L
s
.858 .89096 m
.87881 .88435 L
s
.858 .89096 m
.83456 .81971 L
s
.83456 .81971 m
.85532 .81296 L
s
.8083 .74998 m
.83456 .81971 L
s
.89543 1.03479 m
.87838 .96292 L
s
.87838 .96292 m
.89925 .95643 L
s
.47443 .57658 m
.51026 .63042 L
s
.89925 .95643 m
.87881 .88435 L
s
.87881 .88435 m
.85532 .81296 L
s
.87881 .88435 m
.87881 .88435 L
s
.85532 .81296 m
.82906 .74307 L
s
.85532 .81296 m
.85532 .81296 L
s
.8083 .74998 m
.82906 .74307 L
s
.8083 .74998 m
.7795 .68255 L
s
.91641 1.02842 m
.89925 .95643 L
s
.89925 .95643 m
.89925 .95643 L
s
.82906 .74307 m
.80029 .67549 L
s
.82906 .74307 m
.82906 .74307 L
s
.90894 1.10574 m
.89543 1.03479 L
s
.89543 1.03479 m
.91641 1.02842 L
s
.7795 .68255 m
.80029 .67549 L
s
.7795 .68255 m
.74846 .61824 L
s
.93006 1.09948 m
.91641 1.02842 L
s
.91641 1.02842 m
.91641 1.02842 L
s
.90451 1.18769 m .71398 1.3012 L .94597 1.23542 L .656 .751 .92 r
F
.90451 1.18769 m .66991 1.2555 L .71398 1.3012 L F
0 g
.71019 1.23537 m
.71067 1.24372 L
s
.71019 1.23537 m
.93998 1.16877 L
s
.71334 1.36366 m
.71398 1.3012 L
s
.80029 .67549 m
.76932 .611 L
s
.80029 .67549 m
.80029 .67549 L
s
.91868 1.17494 m
.90894 1.10574 L
s
.90894 1.10574 m
.93006 1.09948 L
s
.93998 1.16877 m
.93006 1.09948 L
s
.93006 1.09948 m
.93006 1.09948 L
s
.74846 .61824 m
.76932 .611 L
s
.74846 .61824 m
.7155 .55786 L
s
.76932 .611 m
.73647 .55044 L
s
.76932 .611 m
.76932 .611 L
s
.91868 1.17494 m
.92148 1.20723 L
s
.91868 1.17494 m
.93998 1.16877 L
s
.71334 1.36366 m
.70814 1.42183 L
s
.71334 1.36366 m
.94784 1.29855 L
s
.93998 1.16877 m
.93998 1.16877 L
s
.7155 .55786 m
.73647 .55044 L
s
.7155 .55786 m
.68098 .50223 L
s
.66655 .44442 m .43711 .52838 L .43566 .60264 L .544 .324 .532 r
F
0 g
.39875 .48664 m
.43711 .52838 L
s
.47417 .57625 m
.47443 .57658 L
s
.47443 .57658 m
.70208 .49463 L
s
.51026 .63042 m
.73647 .55044 L
s
.86175 1.13845 m .66991 1.2555 L .90451 1.18769 L .656 .751 .92 r
F
.86175 1.13845 m .62447 1.2084 L .66991 1.2555 L F
0 g
.66991 1.2555 m
.71398 1.3012 L
s
.73647 .55044 m
.70208 .49463 L
s
.73647 .55044 m
.73647 .55044 L
s
.88276 1.19398 m .94597 1.23542 L .92446 1.24152 L .656 .751 .92 r
F
0 g
.92446 1.24152 m
.92609 1.30458 L
s
.88276 1.19398 m .90451 1.18769 L .94597 1.23542 L .656 .751 .92 r
F
0 g
.94597 1.23542 m
.94784 1.29855 L
s
.94597 1.23542 m
.94597 1.23542 L
s
.93998 1.16877 m
.94597 1.23542 L
s
.71398 1.3012 m
.94597 1.23542 L
s
.92446 1.24152 m
.94597 1.23542 L
s
.70814 1.42183 m
.69828 1.47476 L
s
.94543 1.35721 m
.70814 1.42183 L
s
.68098 .50223 m
.70208 .49463 L
s
.70208 .49463 m
.70208 .49463 L
s
.35982 .45218 m
.39875 .48664 L
s
.66807 .51925 m .43566 .60264 L .43417 .67883 L .544 .324 .532 r
F
.66655 .44442 m .43566 .60264 L .66807 .51925 L F
0 g
.43566 .60264 m
.43711 .52838 L
s
.39875 .48664 m
.6303 .40064 L
s
.66734 .48312 m
.68098 .50223 L
s
.81762 1.08763 m .62447 1.2084 L .86175 1.13845 L .656 .751 .92 r
F
.81762 1.08763 m .57761 1.15981 L .62447 1.2084 L F
0 g
.62447 1.2084 m
.66991 1.2555 L
s
.92342 1.3632 m
.92609 1.30458 L
s
.92609 1.30458 m
.94784 1.29855 L
s
.94543 1.35721 m
.94784 1.29855 L
s
.94784 1.29855 m
.94784 1.29855 L
s
.64527 .4522 m .66807 .51925 L .64651 .52699 L .544 .324 .532 r
F
.64527 .4522 m .66655 .44442 L .66807 .51925 L F
0 g
.43711 .52838 m
.66655 .44442 L
s
.66655 .44442 m
.70208 .49463 L
s
.60882 .40862 m
.64527 .4522 L
s
.64527 .4522 m
.66655 .44442 L
s
.83974 1.14494 m .90451 1.18769 L .88276 1.19398 L .656 .751 .92 r
F
0 g
.88276 1.19398 m
.92446 1.24152 L
s
.69828 1.47476 m
.6837 1.52149 L
s
.93863 1.41045 m
.69828 1.47476 L
s
.6303 .40064 m
.66655 .44442 L
s
.66655 .44442 m
.66655 .44442 L
s
.83974 1.14494 m .86175 1.13845 L .90451 1.18769 L .656 .751 .92 r
F
0 g
.90451 1.18769 m
.94597 1.23542 L
s
.66963 .59607 m .43417 .67883 L .43264 .75703 L .544 .324 .532 r
F
.66807 .51925 m .43417 .67883 L .66963 .59607 L F
0 g
.43417 .67883 m
.43566 .60264 L
s
.35982 .45218 m
.5938 .36417 L
s
.32087 .42581 m
.35982 .45218 L
s
.91633 1.41641 m
.92342 1.3632 L
s
.92342 1.3632 m
.94543 1.35721 L
s
.93863 1.41045 m
.94543 1.35721 L
s
.94543 1.35721 m
.94543 1.35721 L
s
.77206 1.03515 m .57761 1.15981 L .81762 1.08763 L .656 .751 .92 r
F
.77206 1.03515 m .52926 1.10968 L .57761 1.15981 L F
0 g
.57761 1.15981 m
.62447 1.2084 L
s
.60882 .40862 m
.6303 .40064 L
s
.60882 .40862 m
.57209 .37233 L
s
.64651 .52699 m .66963 .59607 L .64779 .60375 L .544 .324 .532 r
F
.64651 .52699 m .66807 .51925 L .66963 .59607 L F
0 g
.64527 .4522 m
.64651 .52699 L
s
.66655 .44442 m
.66807 .51925 L
s
.6303 .40064 m
.5938 .36417 L
s
.6303 .40064 m
.6303 .40064 L
s
.79535 1.09433 m .86175 1.13845 L .83974 1.14494 L .656 .751 .92 r
F
0 g
.83974 1.14494 m
.88276 1.19398 L
s
.6837 1.52149 m
.66442 1.56105 L
s
.92733 1.45729 m
.6837 1.52149 L
s
.79535 1.09433 m .81762 1.08763 L .86175 1.13845 L .656 .751 .92 r
F
0 g
.86175 1.13845 m
.90451 1.18769 L
s
.67124 .67496 m .43264 .75703 L .43106 .83731 L .544 .324 .532 r
F
.66963 .59607 m .43264 .75703 L .67124 .67496 L F
0 g
.43264 .75703 m
.43417 .67883 L
s
.90472 1.46325 m
.91633 1.41641 L
s
.91633 1.41641 m
.93863 1.41045 L
s
.55757 .33583 m
.32087 .42581 L
s
.28249 .40831 m
.32087 .42581 L
s
.92733 1.45729 m
.93863 1.41045 L
s
.93863 1.41045 m
.93863 1.41045 L
s
.64779 .60375 m .67124 .67496 L .64909 .68258 L .544 .324 .532 r
F
.64779 .60375 m .66963 .59607 L .67124 .67496 L F
0 g
.64651 .52699 m
.64779 .60375 L
s
.66807 .51925 m
.66963 .59607 L
s
.72498 .98094 m .52926 1.10968 L .77206 1.03515 L .656 .751 .92 r
F
.72498 .98094 m .47934 1.05793 L .52926 1.10968 L F
0 g
.52926 1.10968 m
.57761 1.15981 L
s
.57209 .37233 m
.5938 .36417 L
s
.57209 .37233 m
.5356 .34418 L
s
.5938 .36417 m
.55757 .33583 L
s
.5938 .36417 m
.5938 .36417 L
s
.66442 1.56105 m
.64051 1.59248 L
s
.9115 1.49674 m
.66442 1.56105 L
s
.74952 1.04207 m .81762 1.08763 L .79535 1.09433 L .656 .751 .92 r
F
0 g
.79535 1.09433 m
.83974 1.14494 L
s
.67288 .756 m .43106 .83731 L .42945 .91976 L .544 .324 .532 r
F
.67124 .67496 m .43106 .83731 L .67288 .756 L F
0 g
.43106 .83731 m
.43264 .75703 L
s
.74952 1.04207 m .77206 1.03515 L .81762 1.08763 L .656 .751 .92 r
F
0 g
.81762 1.08763 m
.86175 1.13845 L
s
.88856 1.50271 m
.90472 1.46325 L
s
.90472 1.46325 m
.92733 1.45729 L
s
.52216 .31645 m
.28249 .40831 L
s
.24533 .40038 m
.28249 .40831 L
s
.9115 1.49674 m
.92733 1.45729 L
s
.92733 1.45729 m
.92733 1.45729 L
s
.64909 .68258 m .67288 .756 L .65043 .76355 L .544 .324 .532 r
F
.64909 .68258 m .67124 .67496 L .67288 .756 L F
0 g
.64779 .60375 m
.64909 .68258 L
s
.66963 .59607 m
.67124 .67496 L
s
.5356 .34418 m
.55757 .33583 L
s
.5356 .34418 m
.4999 .32497 L
s
.67632 .92491 m .47934 1.05793 L .72498 .98094 L .656 .751 .92 r
F
.67632 .92491 m .42779 1.00447 L .47934 1.05793 L F
0 g
.47934 1.05793 m
.52926 1.10968 L
s
.55757 .33583 m
.52216 .31645 L
s
.55757 .33583 m
.55757 .33583 L
s
.67458 .83928 m .42945 .91976 L .42779 1.00447 L .544 .324 .532 r
F
.67288 .756 m .42945 .91976 L .67458 .83928 L F
0 g
.42945 .91976 m
.43106 .83731 L
s
.64051 1.59248 m
.89118 1.52783 L
s
.64051 1.59248 m
.61214 1.61484 L
s
.70217 .98809 m .77206 1.03515 L .74952 1.04207 L .656 .751 .92 r
F
0 g
.74952 1.04207 m
.79535 1.09433 L
s
.70217 .98809 m .72498 .98094 L .77206 1.03515 L .656 .751 .92 r
F
0 g
.77206 1.03515 m
.81762 1.08763 L
s
.8679 1.53384 m
.88856 1.50271 L
s
.88856 1.50271 m
.9115 1.49674 L
s
.65043 .76355 m .67458 .83928 L .65181 .84676 L .544 .324 .532 r
F
.65043 .76355 m .67288 .756 L .67458 .83928 L F
0 g
.64909 .68258 m
.65043 .76355 L
s
.67124 .67496 m
.67288 .756 L
s
.48818 .30676 m
.24533 .40038 L
s
.21006 .40264 m
.24533 .40038 L
s
.89118 1.52783 m
.9115 1.49674 L
s
.9115 1.49674 m
.9115 1.49674 L
s
.4999 .32497 m
.52216 .31645 L
s
.4999 .32497 m
.46562 .31546 L
s
.65323 .9323 m .72498 .98094 L .70217 .98809 L .656 .751 .92 r
F
.65323 .9323 m .67632 .92491 L .72498 .98094 L F
.67632 .92491 m .42779 1.00447 L .42608 1.09154 L .544 .324 .532 r
F
0 g
.47825 1.0568 m
.47934 1.05793 L
s
.67458 .83928 m .42779 1.00447 L .67632 .92491 L .544 .324 .532 r
F
.65181 .84676 m .67632 .92491 L .65323 .9323 L F
.62599 .86695 m .42779 1.00447 L .67632 .92491 L .656 .751 .92 r
F
.62599 .86695 m .37451 .94923 L .42779 1.00447 L F
0 g
.42922 .93133 m
.42945 .91976 L
s
.52216 .31645 m
.48818 .30676 L
s
.52216 .31645 m
.52216 .31645 L
s
.70217 .98809 m
.74952 1.04207 L
s
.72498 .98094 m
.77206 1.03515 L
s
.61214 1.61484 m
.57958 1.62729 L
s
.86645 1.54962 m
.61214 1.61484 L
s
.65181 .84676 m .67458 .83928 L .67632 .92491 L .544 .324 .532 r
F
0 g
.65043 .76355 m
.65181 .84676 L
s
.65181 .84676 m
.65266 .89766 L
s
.67288 .756 m
.67458 .83928 L
s
.89118 1.52783 m
.8679 1.53384 L
s
.84283 1.55568 m
.8679 1.53384 L
s
.45628 .30745 m
.21006 .40264 L
s
.17742 .41557 m
.21006 .40264 L
s
.89118 1.52783 m
.89118 1.52783 L
s
.86645 1.54962 m
.89118 1.52783 L
s
.67811 1.01296 m .42608 1.09154 L .42433 1.18105 L .544 .324 .532 r
F
.67632 .92491 m .42608 1.09154 L .67811 1.01296 L F
0 g
.42608 1.09154 m
.42779 1.00447 L
s
.67702 .95942 m
.70217 .98809 L
s
.46562 .31546 m
.48818 .30676 L
s
.46562 .31546 m
.4334 .31629 L
s
.5739 .80697 m .37451 .94923 L .62599 .86695 L .656 .751 .92 r
F
.5739 .80697 m .31942 .89211 L .37451 .94923 L F
0 g
.37451 .94923 m
.42779 1.00447 L
s
.48818 .30676 m
.45628 .30745 L
s
.48818 .30676 m
.48818 .30676 L
s
.65323 .9323 m .67811 1.01296 L .65469 1.02026 L .544 .324 .532 r
F
.65323 .9323 m .67632 .92491 L .67811 1.01296 L F
.60262 .87459 m .67632 .92491 L .65323 .9323 L .656 .751 .92 r
F
0 g
.57958 1.62729 m
.5432 1.62909 L
s
.83754 1.56124 m
.57958 1.62729 L
s
.60262 .87459 m .62599 .86695 L .67632 .92491 L .656 .751 .92 r
F
0 g
.67632 .92491 m
.72498 .98094 L
s
.67458 .83928 m
.67632 .92491 L
s
.81356 1.56738 m
.84283 1.55568 L
s
.84283 1.55568 m
.86645 1.54962 L
s
.67811 1.01296 m .42433 1.18105 L .67995 1.10356 L .544 .324 .532 r
F
.67995 1.10356 m .42433 1.18105 L .42253 1.27313 L F
0 g
.42433 1.18105 m
.42608 1.09154 L
s
.42713 .31904 m
.17742 .41557 L
s
.14814 .43949 m
.17742 .41557 L
s
.83754 1.56124 m
.86645 1.54962 L
s
.86645 1.54962 m
.86645 1.54962 L
s
.51997 .74487 m .31942 .89211 L .5739 .80697 L .656 .751 .92 r
F
.51997 .74487 m .26242 .83302 L .31942 .89211 L F
0 g
.31942 .89211 m
.37451 .94923 L
s
.4334 .31629 m
.45628 .30745 L
s
.4334 .31629 m
.40392 .32801 L
s
.65469 1.02026 m .67995 1.10356 L .65619 1.11077 L .544 .324 .532 r
F
.65469 1.02026 m .67811 1.01296 L .67995 1.10356 L F
0 g
.65323 .9323 m
.65469 1.02026 L
s
.67632 .92491 m
.67811 1.01296 L
s
.45628 .30745 m
.42713 .31904 L
s
.45628 .30745 m
.45628 .30745 L
s
.55025 .81489 m .62599 .86695 L .60262 .87459 L .656 .751 .92 r
F
0 g
.60262 .87459 m
.65323 .9323 L
s
.5432 1.62909 m
.5035 1.61966 L
s
.80473 1.56194 m
.5432 1.62909 L
s
.55025 .81489 m .5739 .80697 L .62599 .86695 L .656 .751 .92 r
F
0 g
.62599 .86695 m
.67632 .92491 L
s
.67995 1.10356 m .42253 1.27313 L .68184 1.19682 L .544 .324 .532 r
F
.68184 1.19682 m .42253 1.27313 L .42067 1.36787 L F
0 g
.42253 1.27313 m
.42433 1.18105 L
s
.78042 1.56818 m
.81356 1.56738 L
s
.81356 1.56738 m
.83754 1.56124 L
s
.40143 .34189 m
.14814 .43949 L
s
.12297 .47449 m
.14814 .43949 L
s
.80473 1.56194 m
.83754 1.56124 L
s
.83754 1.56124 m
.83754 1.56124 L
s
.65619 1.11077 m .68184 1.19682 L .65773 1.20391 L .544 .324 .532 r
F
.65619 1.11077 m .67995 1.10356 L .68184 1.19682 L F
0 g
.65469 1.02026 m
.65619 1.11077 L
s
.67811 1.01296 m
.67995 1.10356 L
s
.4641 .68052 m .26242 .83302 L .51997 .74487 L .656 .751 .92 r
F
.4641 .68052 m .20342 .77184 L .26242 .83302 L F
0 g
.26242 .83302 m
.31942 .89211 L
s
.40392 .32801 m
.42713 .31904 L
s
.40392 .32801 m
.37788 .35097 L
s
.42713 .31904 m
.40143 .34189 L
s
.42713 .31904 m
.42713 .31904 L
s
.5035 1.61966 m
.46111 1.59862 L
s
.49602 .75307 m .5739 .80697 L .55025 .81489 L .656 .751 .92 r
F
0 g
.55025 .81489 m
.60262 .87459 L
s
.68379 1.29284 m .42067 1.36787 L .41876 1.4654 L .544 .324 .532 r
F
.68184 1.19682 m .42067 1.36787 L .68379 1.29284 L F
0 g
.42067 1.36787 m
.42253 1.27313 L
s
.49602 .75307 m .51997 .74487 L .5739 .80697 L .656 .751 .92 r
F
0 g
.5739 .80697 m
.62599 .86695 L
s
.74382 1.5575 m
.78042 1.56818 L
s
.78042 1.56818 m
.80473 1.56194 L
s
.37986 .37616 m
.12297 .47449 L
s
.10263 .52041 m
.12297 .47449 L
s
.76846 1.55112 m
.80473 1.56194 L
s
.80473 1.56194 m
.80473 1.56194 L
s
.65773 1.20391 m .68379 1.29284 L .65932 1.29982 L .544 .324 .532 r
F
.65773 1.20391 m .68184 1.19682 L .68379 1.29284 L F
0 g
.65619 1.11077 m
.65773 1.20391 L
s
.67995 1.10356 m
.68184 1.19682 L
s
.37788 .35097 m
.40143 .34189 L
s
.35596 .3853 m
.37788 .35097 L
s
.40617 .61381 m .20342 .77184 L .4641 .68052 L .656 .751 .92 r
F
.40617 .61381 m .1423 .70848 L .20342 .77184 L F
0 g
.20342 .77184 m
.26242 .83302 L
s
.40143 .34189 m
.40143 .34189 L
s
.37986 .37616 m
.40143 .34189 L
s
.68379 1.29284 m .41876 1.4654 L .6858 1.39177 L .544 .324 .532 r
F
.6858 1.39177 m .41876 1.4654 L .41679 1.56585 L F
0 g
.41876 1.4654 m
.42067 1.36787 L
s
.5035 1.61966 m
.76846 1.55112 L
s
.43984 .68902 m .51997 .74487 L .49602 .75307 L .656 .751 .92 r
F
0 g
.49602 .75307 m
.55025 .81489 L
s
.43984 .68902 m .4641 .68052 L .51997 .74487 L .656 .751 .92 r
F
0 g
.51997 .74487 m
.5739 .80697 L
s
.36306 .42171 m
.10263 .52041 L
s
.70433 1.53495 m
.74382 1.5575 L
s
.74382 1.5575 m
.76846 1.55112 L
s
.65932 1.29982 m .6858 1.39177 L .66096 1.39862 L .544 .324 .532 r
F
.65932 1.29982 m .68379 1.29284 L .6858 1.39177 L F
0 g
.65773 1.20391 m
.65932 1.29982 L
s
.68184 1.19682 m
.68379 1.29284 L
s
.72928 1.52842 m
.76846 1.55112 L
s
.76846 1.55112 m
.76846 1.55112 L
s
.35596 .3853 m
.37986 .37616 L
s
.35596 .3853 m
.33883 .43089 L
s
.34607 .5446 m .1423 .70848 L .40617 .61381 L .656 .751 .92 r
F
.34607 .5446 m .07895 .6428 L .1423 .70848 L F
0 g
.1423 .70848 m
.20342 .77184 L
s
.08777 .57677 m
.10263 .52041 L
s
.6858 1.39177 m .41679 1.56585 L .68787 1.49372 L .544 .324 .532 r
F
0 g
.37142 1.52154 m
.41679 1.56585 L
s
.46111 1.59862 m
.72928 1.52842 L
s
.41679 1.56585 m
.46111 1.59862 L
s
.41679 1.56585 m
.41876 1.4654 L
s
.07895 .6428 m
.1423 .70848 L
s
.37986 .37616 m
.36306 .42171 L
s
.37986 .37616 m
.37986 .37616 L
s
.07895 .6428 m
.08777 .57677 L
s
.38161 .62262 m .4641 .68052 L .43984 .68902 L .656 .751 .92 r
F
0 g
.43984 .68902 m
.49602 .75307 L
s
.38161 .62262 m .40617 .61381 L .4641 .68052 L .656 .751 .92 r
F
0 g
.4641 .68052 m
.51997 .74487 L
s
.66096 1.39862 m .68787 1.49372 L .66264 1.50044 L .544 .324 .532 r
F
.66096 1.39862 m .6858 1.39177 L .68787 1.49372 L F
0 g
.41679 1.56585 m
.68787 1.49372 L
s
.65932 1.29982 m
.66096 1.39862 L
s
.66096 1.39862 m
.66264 1.50044 L
s
.68379 1.29284 m
.6858 1.39177 L
s
.66264 1.50044 m
.70433 1.53495 L
s
.70433 1.53495 m
.72928 1.52842 L
s
.6858 1.39177 m
.68787 1.49372 L
s
.68787 1.49372 m
.72928 1.52842 L
s
.72928 1.52842 m
.72928 1.52842 L
s
.37142 1.52154 m
.32598 1.46622 L
s
.37142 1.52154 m
.64504 1.44724 L
s
.33883 .43089 m
.36306 .42171 L
s
.33883 .43089 m
.32707 .4873 L
s
.36306 .42171 m
.35164 .47811 L
s
.36306 .42171 m
.36306 .42171 L
s
.07663 .71735 m
.07895 .6428 L
s
.66264 1.50044 m
.68787 1.49372 L
s
.61956 1.45416 m
.66264 1.50044 L
s
.32119 .55375 m .40617 .61381 L .38161 .62262 L .656 .751 .92 r
F
0 g
.38161 .62262 m
.43984 .68902 L
s
.32598 1.46622 m
.28151 1.40078 L
s
.32598 1.46622 m
.60168 1.38953 L
s
.68787 1.49372 m
.68787 1.49372 L
s
.32119 .55375 m .34607 .5446 L .40617 .61381 L .656 .751 .92 r
F
0 g
.08777 .57677 m
.35164 .47811 L
s
.40617 .61381 m
.4641 .68052 L
s
.07895 .6428 m
.34607 .5446 L
s
.32119 .55375 m
.38161 .62262 L
s
.34607 .5446 m
.40617 .61381 L
s
.64504 1.44724 m
.68787 1.49372 L
s
.32707 .4873 m
.35164 .47811 L
s
.32119 .55375 m
.32707 .4873 L
s
.07663 .71735 m
.34672 .62006 L
s
.08105 .79898 m
.07663 .71735 L
s
.34607 .5446 m
.35164 .47811 L
s
.35164 .47811 m
.35164 .47811 L
s
.28151 1.40078 m
.2391 1.32648 L
s
.5588 1.32153 m
.28151 1.40078 L
s
.576 1.39667 m
.61956 1.45416 L
s
.61956 1.45416 m
.64504 1.44724 L
s
.08105 .79898 m
.35378 .70301 L
s
.09231 .88592 m
.08105 .79898 L
s
.60168 1.38953 m
.64504 1.44724 L
s
.64504 1.44724 m
.64504 1.44724 L
s
.32119 .55375 m
.32156 .62912 L
s
.32119 .55375 m
.34607 .5446 L
s
.2391 1.32648 m
.19982 1.24489 L
s
.51743 1.24455 m
.2391 1.32648 L
s
.34607 .5446 m
.34607 .5446 L
s
.34607 .5446 m
.34672 .62006 L
s
.36728 .79167 m
.09231 .88592 L
s
.11027 .97618 m
.09231 .88592 L
s
.19982 1.24489 m
.16467 1.1579 L
s
.47862 1.16025 m
.19982 1.24489 L
s
.53297 1.32891 m
.576 1.39667 L
s
.576 1.39667 m
.60168 1.38953 L
s
.38701 .88399 m
.11027 .97618 L
s
.13458 1.06759 m
.11027 .97618 L
s
.16467 1.1579 m
.13458 1.06759 L
s
.44336 1.07059 m
.16467 1.1579 L
s
.41257 .97774 m
.13458 1.06759 L
s
.5588 1.32153 m
.60168 1.38953 L
s
.60168 1.38953 m
.60168 1.38953 L
s
.32156 .62912 m
.34672 .62006 L
s
.32156 .62912 m
.32838 .71195 L
s
.34672 .62006 m
.35378 .70301 L
s
.34672 .62006 m
.34672 .62006 L
s
.4915 1.25219 m
.53297 1.32891 L
s
.53297 1.32891 m
.5588 1.32153 L
s
.51743 1.24455 m
.5588 1.32153 L
s
.5588 1.32153 m
.5588 1.32153 L
s
.32838 .71195 m
.35378 .70301 L
s
.32838 .71195 m
.34166 .80045 L
s
.35378 .70301 m
.36728 .79167 L
s
.35378 .70301 m
.35378 .70301 L
s
.45264 1.16814 m
.4915 1.25219 L
s
.4915 1.25219 m
.51743 1.24455 L
s
.34166 .80045 m
.36728 .79167 L
s
.36122 .89258 m
.34166 .80045 L
s
.47862 1.16025 m
.51743 1.24455 L
s
.51743 1.24455 m
.51743 1.24455 L
s
.36728 .79167 m
.38701 .88399 L
s
.36728 .79167 m
.36728 .79167 L
s
.41739 1.07873 m
.45264 1.16814 L
s
.45264 1.16814 m
.47862 1.16025 L
s
.36122 .89258 m
.38701 .88399 L
s
.36122 .89258 m
.38666 .98611 L
s
.44336 1.07059 m
.47862 1.16025 L
s
.47862 1.16025 m
.47862 1.16025 L
s
.38666 .98611 m
.41739 1.07873 L
s
.41739 1.07873 m
.44336 1.07059 L
s
.38666 .98611 m
.41257 .97774 L
s
.38701 .88399 m
.41257 .97774 L
s
.38701 .88399 m
.38701 .88399 L
s
.41257 .97774 m
.44336 1.07059 L
s
.44336 1.07059 m
.44336 1.07059 L
s
.41257 .97774 m
.41257 .97774 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{153.625, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002I000182000`400?l00000o`00003oVOooool0
09Wooooo002Iooooo`00VOooool009Wooooo002Iooooo`00VOooool009Wooooo002Iooooo`00VOoo
ool009Wooooo002Iooooo`00VOooool009Wooooo002Iooooo`00VOooool009Wooooo002Iooooo`00
VOooool009Wooooo002Iooooo`00VOooool009Wooooo002Iooooo`00VOooool009Wooooo002Ioooo
o`00VOooool009Wooooo002Iooooo`00VOooool009Wooooo002Iooooo`00VOooool009Wooooo002I
ooooo`00VOooool009Wooooo002Iooooo`00VOooool009Wooooo002Iooooo`00VOooool009Wooooo
002Iooooo`00VOooool009Wooooo002Iooooo`00A?ooool:o`0004_ooooo0011ooooo`So00001Ooo
ool3o`0004Sooooo000nooooo`Co000000Coooooo`000?l0003o00000oooool5o`0000?ooooo0_l0
0016ooooo`00??ooool4o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000005
ooooo`;o0000A?ooool003Wooooo1?l000001?oooooo0000o`000?l00005ooooo`?o00001Oooool2
o`0000Cooooo0_l00013ooooo`00=_ooool4o`000004ooooool0003o0000o`0000Gooooo0ol0000:
ooooo`Co00000_ooool00ol0003oooooooooo`10ooooo`00=?ooool3o`0000;ooooo0ol000000ooo
oooo0000ooooo`02ooooo`;o00002oooool5o`0000Cooooo00?o0000ooooooooool0?oooool0037o
oooo1?l000000ooooooo0000o`000002o`0000;ooooo00?o0000ooooool000000_l0000;ooooo`;o
00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03kooooo000_ooooo`?o0000
0_ooool2o`0000?ooooo00?o0000ooooool000000_l0000;ooooo`?o00002?ooool2o`0000?ooooo
0_l0000nooooo`00;?ooool3o`0000;ooooo0ol00004ooooo`Co00002_ooool3o`0000gooooo00?o
0000ooooooooool00ol0000mooooo`00:Oooool4o`000004ooooool0003o0000o`0000Kooooo1?l0
0009ooooo`;o00004?ooool3o`0000?ooooo00?o0000ooooooooool0>_ooool002Oooooo0ol00002
ooooo`?o00001Oooool4o`000003ooooool0003ooooo00Kooooo0ol0000?ooooo`?o00000_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Wooooo000Tooooo`?o00000_ooool3o`00
00Gooooo1?l000001Ooooooo0000oooooooooooo000000Gooooo0_l0000?ooooo`?o00001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Sooooo000Qooooo`?o00000_ooool3o`00
00Kooooo0ol00004ooooo`03o`000?oooooo000000?ooooo0ol0000?ooooo`;o00002_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03Oooooo000Oooooo`[o00000oooool4o`0000Go
oooo00?o0000ooooooooool01?l0000?ooooo`?o00003Oooool00ol0003oooooooooo`03o`0003So
oooo000Looooo`?o00000oooool2o`0000Gooooo1?l00008ooooo`04o`000?oooooo0000o`0000oo
oooo0ol0000Aooooo`?o000000?oooooo`000?ooool0=oooool001[ooooo0_l00003ooooo`?o0000
1_ooool3o`0000;ooooo0_l00005ooooo`Co00003Oooool3o`00017ooooo1?l00004ooooo`03o`00
0?oooooooooo03Gooooo000Iooooo`03o`000?oooooooooo00?o00001_ooool3o`0000Oooooo00?o
0000ooooool000000ol000000ooooooo0000o`00000:ooooo`?o00004Oooool3o`0000Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0dooooo`006?ooool01?l0003oooooo`000?l0
0007ooooo`;o00002oooool2o`000006ooooool0003o0000o`000?oooooo00002?ooool2o`0001;o
oooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<oooool001Oooooo
0ol00006ooooo`?o00003Oooool4o`0000?ooooo00?o0000ooooooooool00oooool3o`00017ooooo
0ol0000;ooooo`05o`000?ooooooooooooooool00000=Oooool001Kooooo00?o0000ooooooooool0
1Oooool2o`0000kooooo0_l00003ooooo`;o000000?oooooo`000?ooool00_ooool3o`00017ooooo
0ol0000?ooooo`05o`000?ooooooooooooooool00000=?ooool001Kooooo00?o0000ooooooooool0
0_ooool3o`0000gooooo0ol00005ooooo`03o`000?oooooo000000Co00004Oooool3o`0001?ooooo
00?o0000ooooooooool00_l0000cooooo`005Oooool00ol0003oooooooooo`03o`0000gooooo0ol0
0007ooooo`04o`000?ooooooooooooooo`;o00004?ooool3o`0001Kooooo0ol000000on;DXSo0000
ooooo`0booooo`005?ooool01?l0003oooooo`000?l0000>ooooo`;o00002_ooool01ol0003ooooo
oooooooooooo0000ooooool000003Oooool2o`0001Kooooo0ol000001?n;DXSo0000oh]BR?n;DXP2
o`0003;ooooo000Cooooo`?o00003Oooool3o`0000cooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo00Oooooo0ol0000Fooooo`;o00001?n;DXP01_l0003oRe:8oh]BR?l0
003oooooo`00037ooooo000Booooo`03o`000?oooooooooo00_ooooo0ol0000?ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool00oooool3o`0001Kooooo0ol00006oh]BR004o`00
0?n;DXSoRe:8o`0000;ooooo00?o0000ooooooooool0;_ooool001;ooooo00?o0000ooooooooool0
2Oooool2o`00017ooooo00?o0000ooooool000000_l00005ooooo`03o`000?oooooo000000;o0000
5_ooool3o`0000WoRe:800Co0000oh]BR?n;DXSo00000oooool00ol0003oooooooooo`0]ooooo`00
4Oooool00ol0003oooooooooo`07ooooo`?o00004oooool3o`000003ooooool0003ooooo00Gooooo
00?o0000ooooooooool05?ooool3o`0000coRe:800Co0000oh]BR?n;DXSo00001?ooool00ol0003o
ooooooooo`0/ooooo`004Oooool00ol0003oooooooooo`04ooooo`?o00004oooool4o`0000?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`;o00003on;DXP01?l0003oRe:8
oh]BR?l00004ooooo`;o0000;Oooool0013ooooo00?o0000ooooooooool00oooool2o`0001Cooooo
0_l00003ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0>ooooo`?o
00004On;DXP00ol0003oRe:8oh]BR005o`000003ooooool0003ooooo02cooooo000@ooooo`03o`00
0?oooooooooo00?o00004oooool3o`0000Gooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00[ooooo0ol0000Doh]BR003o`000?n;DXSoRe:800?o00001?ooool00ol0003o
ooooooooo`0Zooooo`004?ooool3o`0001?ooooo0ol00008ooooo`05o`000?ooooooooooooooool0
00002Oooool00ol0003oooooooooo`07ooooo`;o00005on;DXP01_l0003oRe:8oh]BR?l0003ooooo
o`0000Cooooo00?o0000ooooooooool0:_ooool000oooooo00?o0000ooooooooool04_ooool2o`00
00_ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`03ooooo`?o00006On;DXP0
1?l0003oRe:8oh]BR?l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:Ooo
ool000oooooo00?o0000ooooooooool03oooool3o`0000gooooo00Co0000oooooooooooo00003?oo
ool00ol0003oooooo`000002o`0001coRe:800Co0000oh]BR?n;DXSo00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02Sooooo000?ooooo`03o`000?oooooooooo00cooooo0ol0
000@ooooo`04o`000?ooooooooooo`0000gooooo00?o0000oh]BR?n;DXP07On;DXP01?l0003oRe:8
oh]BR?l00004ooooo`05o`000?ooooooooooooooool00000:_ooool000kooooo00?o0000oooooooo
ool02oooool2o`0001?ooooo00Co0000oooooooooooo00003Oooool00ol0003oRe:8oh]BR00Moh]B
R004o`000?n;DXSoRe:8o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0W
ooooo`003_ooool00ol0003oooooooooo`08ooooo`?o00005Oooool00ol0003oooooo`000002o`00
00cooooo00?o0000oh]BR?n;DXP07On;DXP01?l0003oRe:8oh]BR?l00005ooooo`05o`000?oooooo
ooooooooool00000:Oooool000kooooo00?o0000ooooooooool01Oooool3o`0001Oooooo0ol00000
0onW`>_o0000ooooo`0<ooooo`03o`000?n;DXSoRe:801goRe:800Co0000oh]BR?n;DXSo00001_oo
ool00ol0003oooooooooo`02o`0002Sooooo000>ooooo`03o`000?oooooooooo00?ooooo0_l0000G
ooooo`?o000000CoYl3[o`000?nW`>_oYl3[0_l0000<ooooo`03o`000?n;DXSoRe:801goRe:800Co
0000oh]BR?n;DXSo00001_ooool3o`000003ooooool0003ooooo02Oooooo000>ooooo`03o`000?oo
oooooooo00?o00005oooool2o`0000CoYl3[0_l000001?nW`>_o0000ojO0jol0000;ooooo`03o`00
0?n;DXSoRe:801goRe:800Go0000oh]BR?n;DXSoRe:8o`000002ooooo`?o000000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`0Uooooo`003Oooool4o`0001Oooooo0ol00006ojO0j`04o`00
0?nW`>_o0000o`0000;oYl3[00?o0000ooooooooool02?ooool00ol0003oRe:8oh]BR004oh]BR003
o`000?n;DXSoRe:801KoRe:800Co0000oh]BR?n;DXSoRe:80ol00005ooooo`04o`000?oooooooooo
o`0002Oooooo000=ooooo`03o`000?oooooooooo01Gooooo0ol00009ojO0j`04o`000?nW`>_oYl3[
o`0000?oYl3[00?o0000ooooooooool01oooool00ol0003oRe:8oh]BR003oh]BR003o`000?n;DXSo
Re:801OoRe:800Go0000oh]BR?n;DXSoRe:8o`000007ooooo`05o`000?ooooooooooooooool00000
9_ooool000gooooo00?o0000ooooooooool04oooool2o`0000coYl3[00?o0000ojO0jonW`>/00_l0
0003ojO0j`03o`000?oooooooooo00Kooooo00?o0000oh]BR?n;DXP07On;DXP01Ol0003oRe:8oh]B
R?n;DXSo000000Sooooo00Go0000ooooooooooooooooo`00000Uooooo`003Oooool00ol0003ooooo
ooooo`0@ooooo`?o00003_nW`>/01_l0003oYl3[ojO0jol0003oYl3[o`0000;oYl3[00?o0000oooo
ooooool01_ooool00ol0003oRe:8oh]BR00Moh]BR005o`000?n;DXSoRe:8oh]BR?l000002Oooool0
1?l0003oooooooooool0000Uooooo`003Oooool00ol0003oooooooooo`0=ooooo`?o00004OnW`>/0
1_l0003oYl3[ojO0jol0003oYl3[o`0000?oYl3[00?o0000ooooooooool01Oooool00ol0003oRe:8
oh]BR00Moh]BR005o`000?n;DXSoRe:8oh]BR?l000002Oooool01Ol0003ooooooooooooooooo0000
02Cooooo000=ooooo`03o`000?oooooooooo00_ooooo0_l0000DojO0j`04o`000?nW`>_oYl3[o`00
00;oYl3[00Go0000ojO0jonW`>_oYl3[o`000006ooooo`03o`000?n;DXSoRe:801goRe:800Go0000
oh]BR?n;DXSoRe:8o`00000:ooooo`04o`000?ooooooooooo`0002Cooooo000=ooooo`03o`000?oo
oooooooo00Sooooo0ol0000FojO0j`04o`000?nW`>_oYl3[o`0000?oYl3[00Go0000ojO0jonW`>_o
Yl3[o`000005ooooo`03o`000?n;DXSoRe:801goRe:800Go0000oh]BR?n;DXSoRe:8o`00000:oooo
o`03o`000?oooooooooo00;o00008oooool000cooooo00?o0000ooooooooool01_ooool3o`0001Wo
Yl3[00?o0000ojO0jonW`>/00_l00003ojO0j`05o`000?nW`>_oYl3[ojO0jol000001?ooool00ol0
003oRe:8oh]BR00Moh]BR005o`000?n;DXSoRe:8oh]BR?l000002_ooool3o`000003ooooool0003o
oooo02;ooooo000<ooooo`03o`000?oooooooooo00Cooooo0_l0000LojO0j`04o`000?nW`>_o0000
o`0000GoYl3[00Co0000ojO0jonW`>_o00001?ooool00ol0003oRe:8oh]BR00Moh]BR005o`000?n;
DXSoRe:8oh]BR?l000001oooool3o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
8?ooool000cooooo00Co0000oooooooooooooooo0ol0000MojO0j`?o000000?oYl3[o`000?nW`>/0
1?nW`>/01Ol0003oYl3[ojO0jonW`>_o000000?ooooo00?o0000oh]BR?n;DXP07On;DXP01Ol0003o
Re:8oh]BR?n;DXSo000000Cooooo0ol00005ooooo`04o`000?ooooooooooo`0002;ooooo000<oooo
o`Co00007OnW`>/3o`000005ojO0jol0003oYl3[ojO0jol000001_nW`>/01Ol0003oYl3[ojO0jonW
`>_o000000;ooooo00?o0000oh]BR?n;DXP07On;DXP01_l0003oRe:8oh]BR?n;DXSo0000ooooo`?o
00002?ooool01Ol0003ooooooooooooooooo0000027ooooo000<ooooo`03o`000?nW`>_oYl3[01_o
Yl3[0ol00004ojO0j`04o`000?nW`>_oYl3[o`0000OoYl3[00Oo0000ojO0jonW`>_oYl3[o`000?oo
oooo000001ooRe:800Co0000oh]BR?n;DXSoRe:80_l0000;ooooo`05o`000?ooooooooooooooool0
00008Oooool000cooooo00?o0000ojO0jonW`>/06?nW`>/3o`0000OoYl3[00Co0000ojO0jonW`>_o
00002?nW`>/01?l0003oYl3[ojO0jonW`>/2o`00023oRe:800Co0000oh]BR?n;DXSo00003Oooool0
1Ol0003ooooooooooooooooo0000023ooooo000<ooooo`;o00005_nW`>/3o`0000[oYl3[00Co0000
ojO0jonW`>_o00002OnW`>/01Ol0003oYl3[ojO0jonW`>_o0000023oRe:800Co0000oh]BR?n;DXSo
00003Oooool01Ol0003ooooooooooooooooo0000023ooooo000<ooooo`03o`000?oooooo000001;o
Yl3[0ol0000=ojO0j`04o`000?nW`>_oYl3[o`0000[oYl3[00Go0000ojO0jonW`>_oYl3[o`00000O
oh]BR004o`000?n;DXSoRe:8o`0000kooooo00Go0000ooooooooooooooooo`00000Oooooo`003?oo
ool01?l0003oooooooooool0000>ojO0j`?o00004?nW`>/01Ol0003oYl3[ojO0jonW`>_o000000[o
Yl3[00Go0000ojO0jonW`>_oYl3[o`00000Noh]BR004o`000?n;DXSoRe:8o`0000kooooo00Go0000
ooooooooooooooooo`00000Oooooo`003?ooool01Ol0003ooooooooooooooooo000000[oYl3[0ol0
000DojO0j`04o`000?nW`>_oYl3[o`0000_oYl3[00Go0000ojO0jonW`>_oYl3[o`00000Moh]BR004
o`000?n;DXSoRe:8o`0000kooooo00?o0000ooooooooool00ol0000Nooooo`002oooool00ol0003o
ooooooooo`03ooooo`03o`000?nW`>_oYl3[00CoYl3[0ol0000GojO0j`04o`000?nW`>_oYl3[o`00
00coYl3[00Go0000ojO0jonW`>_oYl3[o`00000Loh]BR004o`000?n;DXSoRe:8o`0000oooooo0ol0
00000ooooooo0000ooooo`0Mooooo`002oooool00ol0003oooooooooo`04ooooo`03o`000?nW`>_o
Yl3[00?o00006_nW`>/01?l0003oYl3[ojO0jol0000=ojO0j`04o`000?nW`>_oYl3[o`0001coRe:8
00Co0000oh]BR?n;DXSo00003?ooool4o`0000Cooooo00?o0000ooooooooool06oooool000_ooooo
00?o0000ooooooooool01?ooool3o`0001goYl3[00Co0000ojO0jonW`>_o00003OnW`>/01Ol0003o
Yl3[ojO0jonW`>_o000001_oRe:800Co0000oh]BR?n;DXSo00002Oooool3o`0000Cooooo00Go0000
ooooooooooooooooo`00000Mooooo`002oooool01?l0003oooooooooooooool3o`0000;ooooo00?o
0000ojO0jonW`>/06onW`>/00ol0003oYl3[o`000002o`0000goYl3[00Go0000ojO0jonW`>_oYl3[
o`00000Joh]BR004o`000?n;DXSoRe:8o`0000Kooooo0ol00007ooooo`05o`000?oooooooooooooo
ool000007Oooool000_ooooo1?l00006ooooo`03o`000?nW`>_oYl3[01WoYl3[0ol000000onW`>_o
0000ojO0j`0>ojO0j`05o`000?nW`>_oYl3[ojO0jol000006On;DXP01?l0003oRe:8oh]BR?l00003
ooooo`?o00002oooool01Ol0003ooooooooooooooooo000001cooooo000;ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ojO0jonW`>/05OnW`>/3o`000005ojO0jol0003oYl3[ojO0jol000004?nW
`>/01Ol0003oYl3[ojO0jonW`>_o000001SoRe:800?o0000oh]BR?n;DXP01?l0000>ooooo`05o`00
0?ooooooooooooooool000007?ooool000_ooooo00?o0000ooooooooool02Oooool00ol0003oYl3[
ojO0j`0AojO0j`?o00001?nW`>/01Ol0003oYl3[ojO0jonW`>_o0000013oYl3[00Go0000ojO0jonW
`>_oYl3[o`00000Goh]BR004o`000?n;DXSoRe:8o`0001;ooooo00Go0000ooooooooooooooooo`00
000Kooooo`002oooool00ol0003oooooooooo`0:ooooo`03o`000?nW`>_oYl3[00koYl3[0_l00007
ojO0j`05o`000?nW`>_oYl3[ojO0jol000004?nW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?n;
DXSoRe:801CoRe:800Co0000oh]BR?n;DXSo00004_ooool01Ol0003ooooooooooooooooo000001_o
oooo000;ooooo`03o`000?oooooooooo00_ooooo00?o0000ojO0jonW`>/02_nW`>/3o`0000WoYl3[
00Go0000ojO0jonW`>_oYl3[o`00000AojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000oh]BR?n;
DXP04on;DXP01?l0003oRe:8oh]BR?l0000Cooooo`04o`000?ooooooooooo`0001_ooooo000;oooo
o`03o`000?oooooooooo00cooooo00?o0000ojO0jonW`>/01_nW`>/3o`0000goYl3[00Co0000ojO0
jonW`>_o00004_nW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?n;DXSoRe:801;oRe:800Co0000
oh]BR?n;DXSo00004oooool00ol0003oooooooooo`02o`0001[ooooo000;ooooo`03o`000?oooooo
oooo00gooooo00?o0000ojO0jonW`>/00_nW`>/3o`00013oYl3[00Co0000ojO0jonW`>_o00004onW
`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?n;DXSoRe:8017oRe:800Co0000oh]BR?n;DXSo0000
4oooool3o`000003ooooool0003ooooo01Wooooo000;ooooo`03o`000?oooooooooo00kooooo00Co
0000ojO0jol0003o00004onW`>/01Ol0003oYl3[ojO0jonW`>_o000001?oYl3[00Go0000ojO0jonW
`>_oYl3[o`00000Coh]BR004o`000?n;DXSoRe:8o`00013ooooo0ol000000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo01Oooooo000<ooooo`03o`000?oooooooooo00cooooo0ol0000EojO0
j`05o`000?nW`>_oYl3[ojO0jol000004onW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?n;DXSo
Re:8013oRe:800Co0000oh]BR?n;DXSo00003Oooool3o`0000Gooooo00Co0000oooooooooooo0000
6Oooool000cooooo00?o0000ooooooooool02Oooool3o`0000?ooooo00?o0000ojO0jonW`>/04_nW
`>/01Ol0003oYl3[ojO0jonW`>_o000001CoYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0003oRe:8
oh]BR00?oh]BR004o`000?n;DXSoRe:8o`0000[ooooo0ol00008ooooo`04o`000?ooooooooooo`00
01Wooooo000<ooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`03o`000?nW`>_oYl3[017o
Yl3[00Go0000ojO0jonW`>_oYl3[o`00000EojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000oh]B
R?n;DXP03_n;DXP01?l0003oRe:8oh]BR?l00007ooooo`?o00002oooool01Ol0003ooooooooooooo
oooo000001Sooooo000<ooooo`03o`000?oooooooooo00Cooooo0ol0000:ooooo`03o`000?nW`>_o
Yl3[013oYl3[00Go0000ojO0jonW`>_oYl3[o`00000FojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o
0000oh]BR?n;DXP03On;DXP01?l0003oRe:8oh]BR?l00005ooooo`;o00003oooool01?l0003ooooo
ooooool0000Hooooo`003?ooool01?l0003oooooooooooooool3o`0000kooooo00?o0000ojO0jonW
`>/04?nW`>/01Ol0003oYl3[ojO0jonW`>_o000001KoYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0
003oRe:8oh]BR00<oh]BR004o`000?n;DXSoRe:8o`0000;ooooo0ol0000Aooooo`04o`000?oooooo
ooooo`0001Sooooo000<ooooo`Co00004_ooool00ol0003oYl3[ojO0j`0?ojO0j`03o`000?nW`>_o
000000;o00005onW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?n;DXSoRe:800_oRe:800?o0000
oh]BR?n;DXP00ol0000Dooooo`05o`000?ooooooooooooooool000005oooool000cooooo00?o0000
ooooooooool05?ooool00ol0003oYl3[ojO0j`0>ojO0j`?o000000?oYl3[o`000?nW`>/05onW`>/0
0ol0003oYl3[ojO0j`02ojO0j`03o`000?n;DXSoRe:800[oRe:800Co0000oh]BR?n;DXSo00005ooo
ool01?l0003oooooooooool0000Gooooo`003?ooool00ol0003oooooooooo`0Eooooo`03o`000?nW
`>_oYl3[00[oYl3[1?l00003ojO0j`03o`000?nW`>_oYl3[01OoYl3[00?o0000ojO0jonW`>/00_nW
`>/00ol0003oRe:8oh]BR009oh]BR004o`000?n;DXSoRe:8o`0001Oooooo00Co0000oooooooooooo
00005oooool000cooooo00?o0000ooooooooool05_ooool00ol0003oYl3[ojO0j`06ojO0j`?o0000
0onW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?nW`>_oYl3[01OoYl3[00Go0000ojO0jonW`>_o
Yl3[o`00000;oh]BR004o`000?n;DXSoRe:8o`0001Oooooo00?o0000ooooool000000_l0000Foooo
o`003?ooool00ol0003oooooooooo`0Gooooo`03o`000?nW`>_oYl3[00;oYl3[0ol00007ojO0j`05
o`000?nW`>_oYl3[ojO0jol000006OnW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?n;DXSoRe:8
00SoRe:800Co0000oh]BR?n;DXSo00005_ooool4o`000003ooooool0003ooooo01Gooooo000=oooo
o`03o`000?oooooooooo01Oooooo1?l0000:ojO0j`05o`000?nW`>_oYl3[ojO0jol000006_nW`>/0
0ol0003oYl3[ojO0j`02ojO0j`03o`000?n;DXSoRe:800OoRe:800Co0000oh]BR?n;DXSo00004ooo
ool3o`0000;ooooo00Go0000ooooooooooooooooo`00000Eooooo`003Oooool00ol0003ooooooooo
o`0Eooooo`Co00003?nW`>/01Ol0003oYl3[ojO0jonW`>_o000001_oYl3[00?o0000ojO0jonW`>/0
0_nW`>/00ol0003oRe:8oh]BR006oh]BR004o`000?n;DXSoRe:8o`00013ooooo0ol00005ooooo`05
o`000?ooooooooooooooool000005Oooool000gooooo00?o0000ooooooooool04_ooool3o`0000?o
oooo00?o0000ojO0jonW`>/02_nW`>/01Ol0003oYl3[ojO0jonW`>_o000001coYl3[00?o0000ojO0
jonW`>/00_nW`>/00ol0003oRe:8oh]BR005oh]BR004o`000?n;DXSoRe:8o`0000gooooo0ol00009
ooooo`04o`000?ooooooooooo`0001Gooooo000=ooooo`03o`000?oooooooooo00oooooo0ol00007
ooooo`03o`000?nW`>_oYl3[00WoYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0003oYl3[ojO0j`0J
ojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000oh]BR?n;DXP01?n;DXP01?l0003oRe:8oh]BR?l0
000:ooooo`?o00003?ooool01Ol0003ooooooooooooooooo000001Cooooo000=ooooo`03o`000?oo
oooooooo00cooooo0ol0000;ooooo`03o`000?nW`>_oYl3[00WoYl3[00Go0000ojO0jonW`>_oYl3[
o`00000MojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000oh]BR?n;DXP00on;DXP01?l0003oRe:8
oh]BR?l00007ooooo`?o00003oooool01Ol0003ooooooooooooooooo000001Cooooo000=ooooo`03
o`000?oooooooooo00Wooooo0ol0000?ooooo`03o`000?nW`>_oYl3[00SoYl3[00Go0000ojO0jonW
`>_oYl3[o`00000NojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000oh]BR?n;DXP00_n;DXP01?l0
003oRe:8oh]BR?l00004ooooo`?o00004oooool01?l0003oooooooooool0000Dooooo`003Oooool0
0ol0003oooooooooo`06ooooo`?o00004oooool00ol0003oYl3[ojO0j`07ojO0j`05o`000?nW`>_o
Yl3[ojO0jol000007onW`>/00ol0003oYl3[ojO0j`02ojO0j`05o`000?n;DXSoRe:8oh]BR?l00000
0_n;DXP00ol0003oooooo`000002o`0001Kooooo00Go0000ooooooooooooooooo`00000Cooooo`00
3_ooool00ol0003oooooooooo`02ooooo`?o00005oooool00ol0003oYl3[ojO0j`06ojO0j`05o`00
0?nW`>_oYl3[ojO0jol000008?nW`>/01Ol0003oYl3[ojO0jonW`>_o000000?oRe:800?o0000oh]B
R?n;DXP00_l0000Iooooo`05o`000?ooooooooooooooool000004oooool000kooooo00?o0000oooo
ool000000_l0000Kooooo`03o`000?nW`>_oYl3[00GoYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0
003oYl3[ojO0j`0MojO0j`03o`000?nW`>_oYl3[00;oYl3[00Co0000oh]BR?n;DXSo00000_n;DXP0
0ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000004oooool000kooooo0_l0000O
ooooo`03o`000?nW`>_oYl3[00GoYl3[00?o0000ojO0jol000000_l0000PojO0j`03o`000?nW`>_o
Yl3[00;oYl3[00?o0000oh]BR?l000000on;DXP00ol0003oooooooooo`0Hooooo`03o`000?oooooo
000000;o00004_ooool000kooooo00?o0000ooooooooool07oooool00ol0003oYl3[ojO0j`03ojO0
j`?o00000_nW`>/00ol0003oYl3[ojO0j`0OojO0j`03o`000?nW`>_oYl3[00;oYl3[0_l00003oh]B
R003o`000?oooooooooo01Oooooo0ol00002ooooo`03o`000?oooooooooo013ooooo000>ooooo`03
o`000?oooooooooo023ooooo00?o0000ojO0jol000000_l000000onW`>_o0000ojO0j`02ojO0j`03
o`000?nW`>_oYl3[023oYl3[00?o0000ojO0jonW`>/00_nW`>/01Ol0003oRe:8oh]BR?n;DXSo0000
01Kooooo0ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo013ooooo000>ooooo`03
o`000?oooooooooo01oooooo0ol00004ojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000ojO0jonW
`>/08?nW`>/00ol0003oYl3[ojO0j`02ojO0j`04o`000?n;DXSoRe:8o`0001?ooooo0ol00005oooo
o`05o`000?ooooooooooooooool000004Oooool000oooooo00?o0000ooooooooool06oooool3o`00
00?ooooo00?o0000ojO0jonW`>/00_nW`>/01Ol0003oYl3[ojO0jonW`>_o000002?oYl3[00?o0000
ojO0jonW`>/00_nW`>/00ol0003oRe:8o`00000@ooooo`?o00002?ooool01Ol0003ooooooooooooo
oooo0000017ooooo000?ooooo`03o`000?oooooooooo01Sooooo0ol00007ooooo`05o`000?nW`>_o
Yl3[ojO0jol000000onW`>/00ol0003oYl3[ojO0j`0RojO0j`03o`000?nW`>_oYl3[00;oYl3[0_l0
000<ooooo`Co00002oooool01Ol0003ooooooooooooooooo0000017ooooo000?ooooo`03o`000?oo
oooooooo01Gooooo0ol0000;ooooo`04o`000?nW`>_oYl3[o`0000?oYl3[00?o0000ojO0jonW`>/0
8onW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?oooooooooo00Oooooo0ol0000@ooooo`05o`00
0?ooooooooooooooool000004?ooool000oooooo00?o0000ooooooooool04_ooool3o`0000oooooo
00Co0000ojO0jonW`>_o00000_nW`>/00ol0003oYl3[ojO0j`0TojO0j`05o`000?nW`>_oRe:8oh]B
R?l000001_ooool3o`0001?ooooo00Go0000ooooooooooooooooo`00000@ooooo`003oooool00ol0
003oooooooooo`0?ooooo`?o00004oooool00ol0003oYl3[o`000003ojO0j`03o`000?nW`>_oYl3[
02;oYl3[00?oRe:8o`000?n;DXP00_n;DXP2o`0000;ooooo0ol0000Fooooo`05o`000?oooooooooo
ooooool000004?ooool000oooooo00?o0000ooooooooool03?ooool3o`0001Oooooo0_l00003ojO0
j`03o`000?nW`>_oYl3[01ooYl3[1?n;DXP01_l0003oRe:8oh]BR?n;DXSo0000ojO0j`;o00006_oo
ool01?l0003oooooooooool0000@ooooo`003oooool00ol0003oooooooooo`09ooooo`?o00006ooo
ool01Ol0003oYl3[ojO0jonW`>_o000001koYl3[1on;DXP01Ol0003oRe:8oh]BR?n;DXSo000000;o
Yl3[00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000oooooo000@ooooo`03
o`000?oooooooooo00Gooooo0ol0000Oooooo`04o`000?nW`>_oYl3[o`0001_oYl3[2_n;DXP01Ol0
003oRe:8oh]BR?n;DXSo000000?oYl3[00?o0000ooooooooool05oooool00ol0003oooooo`000002
o`0000oooooo000@ooooo`03o`000?oooooooooo00;ooooo0ol0000Rooooo`;o000000?oYl3[o`00
0?nW`>/05onW`>/=oh]BR005o`000?n;DXSoRe:8oh]BR?l000000onW`>/00ol0003oooooooooo`0F
ooooo`Co000000?oooooo`000?ooool03_ooool0013ooooo00?o0000ooooool000000_l0000Uoooo
o`05o`000?oooooo0000ojO0jol000004onW`>/Aoh]BR004o`000?n;DXSoRe:8oh]BR0;o00000onW
`>/00ol0003oooooooooo`0Booooo`?o00000_ooool01?l0003oooooooooool0000?ooooo`004?oo
ool2o`0002Wooooo00?o0000ooooool000000_l0000?ojO0jaCoRe:800Oo0000oh]BR?n;DXSoRe:8
o`000?nW`>_o000000?oYl3[00?o0000ooooooooool03_ooool3o`0000Gooooo00Co0000oooooooo
oooo00003oooool0013ooooo00?o0000ooooooooool09oooool3o`000003ooooool0003oYl3[00co
Yl3[5on;DXP01Ol0003oRe:8oh]BR?n;DXSo000000;oYl3[00Go0000ojO0jonW`>_oYl3[o`00000<
ooooo`?o00002?ooool01Ol0003ooooooooooooooooo000000kooooo000@ooooo`03o`000?oooooo
oooo02Cooooo0ol000000ooooooo0000ooooo`02ooooo`03o`000?nW`>_oYl3[00OoYl3[6_n;DXP0
1Ol0003oRe:8oh]BR?n;DXSo000000?oYl3[00Co0000ojO0jonW`>_o00002?ooool4o`0000cooooo
00Co0000oooooooooooo00003_ooool0017ooooo00?o0000ooooooooool08?ooool3o`0000Cooooo
00Co0000oooooooooooooooo0_l00005ojO0jagoRe:800Go0000oh]BR?n;DXSoRe:8o`000003ojO0
j`05o`000?nW`>_oYl3[ojO0jol000001?ooool3o`00013ooooo00Co0000oooooooooooo00003_oo
ool0017ooooo00?o0000ooooooooool07Oooool3o`0000Sooooo00Oo0000oooooooooooo0000oooo
ool0003oYl3[023oRe:800Go0000oh]BR?n;DXSoRe:8o`000004ojO0j`04o`000?nW`>_oYl3[ojO0
j`Co00004oooool01?l0003oooooooooool0000>ooooo`004Oooool00ol0003oooooooooo`0Joooo
o`?o00002oooool01?l0003oooooooooooooool2o`00027oRe:800Go0000oh]BR?n;DXSoRe:8o`00
0005ojO0j`05o`000?nW`>_oYl3[ojO0jol000005Oooool01?l0003oooooooooool0000>ooooo`00
4_ooool00ol0003oooooooooo`0Fooooo`?o00003_ooool01?l0003oooooooooooooool2o`00027o
Re:800Go0000oh]BR?n;DXSoRe:8o`000006ojO0j`05o`000?nW`>_oYl3[ojO0jol000005?ooool0
1Ol0003ooooooooooooooooo000000gooooo000Booooo`03o`000?oooooooooo01?ooooo0ol0000A
ooooo`04o`000?ooooooooooooooo`;o00008On;DXP01Ol0003oRe:8oh]BR?n;DXSo000000OoYl3[
00Go0000ojO0jonW`>_oYl3[o`00000Dooooo`04o`000?ooooooooooo`0000gooooo000Booooo`03
o`000?oooooooooo013ooooo0ol0000Eooooo`05o`000?ooooooooooooooool000008On;DXP01Ol0
003oRe:8oh]BR?n;DXSo000000SoYl3[00Go0000ojO0jonW`>_oYl3[o`00000Cooooo`Go00003?oo
ool001;ooooo00?o0000ooooooooool03Oooool3o`0001Sooooo00Go0000ooooooooooooooooo`00
000Qoh]BR005o`000?n;DXSoRe:8oh]BR?l000002OnW`>/01Ol0003oYl3[ojO0jonW`>_o0000013o
oooo1?l000000ooooooo0000ooooo`0<ooooo`004oooool00ol0003oooooooooo`09ooooo`?o0000
6oooool01Ol0003ooooooooooooooooo0000027oRe:800Go0000oh]BR?n;DXSoRe:8o`00000:ojO0
j`04o`000?nW`>_oYl3[o`0000cooooo1?l00002ooooo`04o`000?ooooooooooo`0000gooooo000C
ooooo`03o`000?oooooooooo00Kooooo0ol0000Oooooo`03o`000?oooooooooo00;o00008?n;DXP0
1Ol0003oRe:8oh]BR?n;DXSo000000[oYl3[00Go0000ojO0jonW`>_oYl3[o`000008ooooo`?o0000
1_ooool01?l0003oooooooooool0000=ooooo`004oooool00ol0003oooooooooo`03ooooo`?o0000
8_ooool00ol0003oooooooooo`02o`0000GoRe:80_l0000Ioh]BR005o`000?n;DXSoRe:8oh]BR?l0
00002onW`>/01Ol0003oYl3[ojO0jonW`>_o000000Cooooo0ol00009ooooo`05o`000?oooooooooo
ooooool000003?ooool001Cooooo00?o0000ooooool000000_l0000Uooooo`03o`000?oooooooooo
00;o00008?n;DXP01Ol0003oRe:8oh]BR?n;DXSo000000coYl3[00Co0000ojO0jonW`>_oYl3[1?l0
000=ooooo`04o`000?ooooooooooo`0000cooooo000Dooooo`;o0000:?ooool00ol0003ooooooooo
o`03o`0001ooRe:800Go0000oh]BR?n;DXSoRe:8o`00000=ojO0j`05o`000?nW`>_oYl3[ojO0jol0
00003oooool01?l0003oooooooooool0000<ooooo`005?ooool00ol0003oooooooooo`0Xooooo`?o
000000?oRe:8o`000?n;DXP07on;DXP01?l0003oRe:8oh]BR?l0000>ojO0j`05o`000?nW`>_oYl3[
ojO0jol000003_ooool01?l0003oooooooooool0000<ooooo`005Oooool00ol0003oooooooooo`0T
ooooo`Co000000Goooooo`000?n;DXSoRe:8o`00000Ooh]BR004o`000?n;DXSoRe:8o`0000ooYl3[
00Go0000ojO0jonW`>_oYl3[o`00000=ooooo`04o`000?ooooooooooo`0000cooooo000Eooooo`03
o`000?oooooooooo027ooooo0ol00003ooooo`03o`000?oooooo000000;oRe:800?o0000oh]BR?n;
DXP07On;DXP01?l0003oRe:8oh]BR?l0000@ojO0j`05o`000?nW`>_oYl3[ojO0jol000003?ooool0
1Ol0003ooooooooooooooooo000000_ooooo000Eooooo`03o`000?oooooooooo01kooooo0ol00007
ooooo`;o00000on;DXP00ol0003oRe:8oh]BR00Loh]BR004o`000?n;DXSoRe:8o`00017oYl3[00Co
0000ojO0jonW`>_o00003Oooool01?l0003oooooooooool0000;ooooo`005_ooool00ol0003ooooo
ooooo`0Jooooo`?o00002_ooool2o`0000?oRe:800?o0000oh]BR?n;DXP07?n;DXP01?l0003oRe:8
oh]BR?l0000AojO0j`05o`000?nW`>_oYl3[ojO0jol000003?ooool5o`0000[ooooo000Fooooo`03
o`000?oooooooooo01Oooooo0ol0000>ooooo`05o`000?n;DXSoRe:8oh]BR?l000007_n;DXP01?l0
003oRe:8oh]BR?l0000BojO0j`05o`000?nW`>_oYl3[ojO0jol000002Oooool4o`000003ooooool0
003ooooo00[ooooo000Fooooo`03o`000?oooooooooo01Cooooo0ol0000Aooooo`03o`000?n;DXSo
Re:800;oRe:800?o0000oh]BR?n;DXP06on;DXP01?l0003oRe:8oh]BR?l0000CojO0j`05o`000?nW
`>_oYl3[ojO0jol000001?ooool4o`0000;ooooo00Co0000oooooooooooo00002oooool001Oooooo
00?o0000ooooooooool04?ooool3o`0001Cooooo0_l00003oh]BR003o`000?n;DXSoRe:801_oRe:8
00Co0000oh]BR?n;DXSo00005?nW`>/01?l0003oYl3[ojO0jonW`>/4o`0000Kooooo00Go0000oooo
ooooooooooooo`00000:ooooo`005oooool00ol0003oooooooooo`0=ooooo`?o00005oooool2o`00
00CoRe:800?o0000oh]BR?n;DXP06_n;DXP01?l0003oRe:8oh]BR?l0000EojO0j`05o`000?nW`>_o
Yl3[ojO0jol000002Oooool01?l0003oooooooooool0000:ooooo`005oooool00ol0003ooooooooo
o`0:ooooo`?o00006_ooool2o`0000CoRe:800?o0000oh]BR?n;DXP06_n;DXP01?l0003oRe:8oh]B
R?l0000FojO0j`05o`000?nW`>_oYl3[ojO0jol000002?ooool01?l0003oooooooooool0000:oooo
o`006?ooool00ol0003oooooooooo`06ooooo`?o00007?ooool01?l0003oRe:8oh]BR?l00004oh]B
R003o`000?n;DXSoRe:801WoRe:800Co0000oh]BR?n;DXSo00005onW`>/01Ol0003oYl3[ojO0jonW
`>_o000000Oooooo00Co0000oooooooooooo00002_ooool001Sooooo00?o0000ooooooooool00ooo
ool3o`0001oooooo00Co0000oh]BR?n;DXSo00001?n;DXP00ol0003oRe:8oh]BR00Ioh]BR004o`00
0?n;DXSoRe:8o`0001SoYl3[00Go0000ojO0jonW`>_oYl3[o`000006ooooo`04o`000?oooooooooo
o`0000[ooooo000Hooooo`03o`000?oooooooooo00?o00008_ooool01Ol0003oRe:8oh]BR?n;DXSo
000000?oRe:800?o0000oh]BR?n;DXP06On;DXP01Ol0003oRe:8oh]BR?n;DXSo000001OoYl3[00?o
0000ojO0jonW`>/00_nW`>/00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
2Oooool001Wooooo0_l0000Uooooo`05o`000?n;DXSoRe:8oh]BR?l000000_n;DXP3o`0001[oRe:8
00Go0000oh]BR?n;DXSoRe:8o`00000HojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000oooooooo
ool00oooool01?l0003oooooooooool00009ooooo`006Oooool00ol0003oooooooooo`0Tooooo`04
o`000?n;DXSoRe:8oh]BR0?o00000_n;DXP00ol0003oRe:8oh]BR00Hoh]BR005o`000?n;DXSoRe:8
oh]BR?l000006OnW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?oooooooooo00;ooooo1?l00009
ooooo`006_ooool00ol0003oooooooooo`0Sooooo`Co000000?oRe:8o`000?n;DXP00on;DXP00ol0
003oRe:8oh]BR00Goh]BR005o`000?n;DXSoRe:8oh]BR?l000006_nW`>/00ol0003oYl3[ojO0j`02
ojO0j`03o`000?oooooo000000?o000000?oooooo`000?ooool02?ooool001[ooooo00?o0000oooo
ooooool08?ooool4o`0000GoRe:800Go0000oh]BR?n;DXSoRe:8o`00000Ioh]BR005o`000?n;DXSo
Re:8oh]BR?l000006onW`>/00ol0003oYl3[ojO0j`02ojO0j`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool01oooool001[ooooo00?o0000ooooooooool07Oooool3o`0000?ooooo00?o
0000oh]BR?n;DXP00on;DXP01Ol0003oRe:8oh]BR?n;DXSo000001WoRe:800Go0000oh]BR?n;DXSo
Re:8o`00000LojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000ooooool000000_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Iooooo`?o00001_ooool00ol0003oRe:8
oh]BR004oh]BR005o`000?n;DXSoRe:8oh]BR?l000006?n;DXP01Ol0003oRe:8oh]BR?n;DXSo0000
01goYl3[00Oo0000ojO0jonW`>_oYl3[o`000?oooooo000000;ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool05Oooool4o`0000Wooooo00?o0000oh]BR?n;DXP01?n;DXP0
1Ol0003oRe:8oh]BR?n;DXSo000001SoRe:800Go0000oh]BR?n;DXSoRe:8o`00000NojO0j`04o`00
0?nW`>_oYl3[ojO0j`;o00000_ooool00ol0003oooooooooo`07ooooo`007?ooool00ol0003ooooo
ooooo`0Aooooo`?o00003Oooool00ol0003oRe:8oh]BR005oh]BR005o`000?n;DXSoRe:8oh]BR?l0
00005on;DXP01Ol0003oRe:8oh]BR?n;DXSo000001ooYl3[00Go0000ojO0jonW`>_oYl3[o`000003
ooooo`03o`000?oooooooooo00Kooooo000Looooo`03o`000?oooooooooo00kooooo0ol0000@oooo
o`03o`000?n;DXSoRe:800GoRe:800Go0000oh]BR?n;DXSoRe:8o`00000Goh]BR005o`000?n;DXSo
Re:8oh]BR?l000008?nW`>/01Ol0003oYl3[ojO0jonW`>_o000000;ooooo00?o0000ooooooooool0
1_ooool001cooooo00?o0000ooooooooool02oooool3o`0001?ooooo00?o0000oh]BR?n;DXP01On;
DXP01Ol0003oRe:8oh]BR?n;DXSo000001OoRe:800Go0000oh]BR?n;DXSoRe:8o`00000QojO0j`04
o`000?nW`>_oYl3[o`0000;ooooo00?o0000ooooooooool01_ooool001gooooo00?o0000oooooooo
ool01_ooool4o`0001Kooooo00?o0000oh]BR?n;DXP01_n;DXP01Ol0003oRe:8oh]BR?n;DXSo0000
01KoRe:800Go0000oh]BR?n;DXSoRe:8o`00000RojO0j`06o`000?nW`>_oYl3[o`000?oooooo0000
2?ooool001gooooo00?o0000ooooooooool00oooool3o`0001[ooooo00?o0000oh]BR?n;DXP01_n;
DXP01Ol0003oRe:8oh]BR?n;DXSo000001KoRe:800Go0000oh]BR?n;DXSoRe:8o`00000SojO0j`03
o`000?nW`>_oYl3[00;o00002?ooool001gooooo00?o0000ooooooooool00ol0000Mooooo`03o`00
0?n;DXSoRe:800OoRe:800Co0000oh]BR?n;DXSo00005_n;DXP01Ol0003oRe:8oh]BR?n;DXSo0000
02CoYl3[1?l00008ooooo`007_ooool2o`00023ooooo00?o0000oh]BR?n;DXP01on;DXP00ol0003o
Re:8o`000003o`0001CoRe:800Go0000oh]BR?n;DXSoRe:8o`00000RojO0j`?o00000_ooool00ol0
003oooooooooo`06ooooo`007_ooool00ol0003oooooooooo`0Oooooo`03o`000?n;DXSoRe:800Ko
Re:81?l000000on;DXSo0000oh]BR00Doh]BR005o`000?n;DXSoRe:8oh]BR?l000007_nW`>/4o`00
00;ooooo00Co0000oooooooooooo00002?ooool001oooooo00?o0000ooooooooool07_ooool00ol0
003oRe:8oh]BR002oh]BR0Co00000_n;DXP01Ol0003oRe:8oh]BR?n;DXSo000001CoRe:800Go0000
oh]BR?n;DXSoRe:8o`00000JojO0j`Co00001_ooool01?l0003oooooooooool00008ooooo`007ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?n;DXSo000000;o00001on;DXP01?l0003oRe:8oh]B
R?l0000Doh]BR005o`000?n;DXSoRe:8oh]BR?l000005onW`>/3o`0000[ooooo00Co0000oooooooo
oooo00002?ooool0023ooooo00?o0000ooooooooool06oooool4o`0000[oRe:800Go0000oh]BR?n;
DXSoRe:8o`00000Coh]BR005o`000?n;DXSoRe:8oh]BR?l000004onW`>/4o`0000gooooo00Co0000
oooooooooooo00002?ooool0023ooooo00?o0000ooooooooool06?ooool3o`0000;ooooo00?o0000
oh]BR?n;DXP02_n;DXP01Ol0003oRe:8oh]BR?n;DXSo000001;oRe:800Go0000oh]BR?n;DXSoRe:8
o`00000@ojO0j`?o00004Oooool01?l0003oooooooooool00008ooooo`008Oooool00ol0003ooooo
ooooo`0Cooooo`Co00001Oooool00ol0003oRe:8oh]BR00:oh]BR005o`000?n;DXSoRe:8oh]BR?l0
00004_n;DXP01?l0003oRe:8oh]BR?n;DXP2o`0000_oYl3[1?l0000Dooooo`04o`000?oooooooooo
o`0000Sooooo000Qooooo`03o`000?oooooooooo013ooooo0ol00009ooooo`03o`000?n;DXSoRe:8
00_oRe:800Go0000oh]BR?n;DXSoRe:8o`00000Aoh]BR007o`000?n;DXSoRe:8oh]BR?l0003ooooo
o`000006ojO0j`Co00006?ooool01?l0003oooooooooool00008ooooo`008_ooool00ol0003ooooo
ooooo`0;ooooo`Co00003?ooool00ol0003oRe:8oh]BR00;oh]BR005o`000?n;DXSoRe:8oh]BR?l0
00004On;DXP01Ol0003oRe:8oh]BR?n;DXSo000000;ooooo00?o0000ojO0jonW`>/00ol0000Loooo
o`Co00002?ooool002;ooooo00?o0000ooooooooool02?ooool3o`00013ooooo00?o0000oh]BR?n;
DXP03?n;DXP01Ol0003oRe:8oh]BR?n;DXSo0000013oRe:800Go0000oh]BR?n;DXSoRe:8o`000003
ooooo`;o00007Oooool4o`000003ooooool0003ooooo00Oooooo000Sooooo`03o`000?oooooooooo
00?ooooo1?l0000Cooooo`03o`000?n;DXSoRe:800coRe:800?o0000oh]BR?n;DXP00_n;DXP00ol0
003oRe:8oh]BR00=oh]BR005o`000?n;DXSoRe:8oh]BR?l000000oooool00ol0003oooooooooo`0H
ooooo`Co00000_ooool01?l0003oooooooooool00008ooooo`008oooool00ol0003oooooooooo`03
o`0001Oooooo00?o0000oh]BR?n;DXP03On;DXP01?l0003oRe:8oh]BR?n;DXP2o`0000koRe:800Go
0000oh]BR?n;DXSoRe:8o`000003ooooo`03o`000?oooooooooo01Cooooo1?l00006ooooo`04o`00
0?ooooooooooo`0000Sooooo000Tooooo`;o00006_ooool00ol0003oRe:8oh]BR00=oh]BR003o`00
0?n;DXSoRe:800?o00003_n;DXP01Ol0003oRe:8oh]BR?n;DXSo000000?ooooo00?o0000oooooooo
ool04Oooool3o`0000[ooooo00Co0000oooooooooooo00002?ooool002Cooooo00?o0000oooooooo
ool06Oooool00ol0003oRe:8oh]BR00=oh]BR0?o00000_n;DXP00ol0003oRe:8oh]BR00<oh]BR005
o`000?n;DXSoRe:8oh]BR?l000000oooool00ol0003oooooooooo`0=ooooo`Co00003Oooool01?l0
003oooooooooool00008ooooo`009Oooool00ol0003oooooooooo`0Hooooo`03o`000?n;DXSoRe:8
00WoRe:81?l000000on;DXSo0000oh]BR003oh]BR003o`000?n;DXSoRe:800_oRe:800Go0000oh]B
R?n;DXSoRe:8o`000003ooooo`03o`000?oooooooooo00[ooooo0ol0000@ooooo`05o`000?oooooo
ooooooooool000002?ooool002Gooooo00?o0000ooooooooool06?ooool00ol0003oRe:8oh]BR005
oh]BR0Co00001_n;DXP00ol0003oRe:8oh]BR002oh]BR003o`000?n;DXSoRe:800[oRe:800Go0000
oh]BR?n;DXSoRe:8o`000003ooooo`03o`000?oooooooooo00Kooooo1?l0000Cooooo`05o`000?oo
ooooooooooooool000002?ooool002Kooooo00?o0000ooooooooool05oooool00ol0003oRe:8oh]B
R002oh]BR0?o00002on;DXP01Ol0003oRe:8oh]BR?n;DXSo000000coRe:800Go0000oh]BR?n;DXSo
Re:8o`000003ooooo`03o`000?oooooooooo00;ooooo1?l0000Gooooo`05o`000?oooooooooooooo
ool000002?ooool002Kooooo00?o0000ooooooooool05oooool5o`0000koRe:800?o0000oh]BR?n;
DXP00_n;DXP00ol0003oRe:8oh]BR009oh]BR005o`000?n;DXSoRe:8oh]BR?l000000oooool00ol0
003oooooo`000002o`0001_ooooo00?o0000ooooool000000_l00008ooooo`009oooool00ol0003o
ooooooooo`0Dooooo`?o00004on;DXP01Ol0003oRe:8oh]BR?n;DXSo000000_oRe:800Go0000oh]B
R?n;DXSoRe:8o`000003ooooo`;o00007Oooool3o`0000;ooooo00?o0000ooooooooool01_ooool0
02Oooooo00?o0000ooooooooool04?ooool4o`0000;ooooo00?o0000oh]BR?n;DXP04On;DXP00ol0
003oRe:8oh]BR002oh]BR003o`000?n;DXSoRe:800SoRe:800Go0000oh]BR?n;DXSoRe:8o`000003
ooooo`03o`000?oooooooooo01Sooooo1?l000000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Kooooo000Xooooo`03o`000?oooooooooo00cooooo0ol00006ooooo`03o`000?n;DXSoRe:8
01;oRe:800?o0000oh]BR?n;DXP00_n;DXP00ol0003oRe:8oh]BR007oh]BR005o`000?n;DXSoRe:8
oh]BR?l000000oooool00ol0003oooooooooo`0Dooooo`Co00001Oooool01Ol0003ooooooooooooo
oooo000000Sooooo000Xooooo`03o`000?oooooooooo00Sooooo1?l00009ooooo`03o`000?n;DXSo
Re:801?oRe:800Go0000oh]BR?n;DXSoRe:8o`000009oh]BR005o`000?n;DXSoRe:8oh]BR?l00000
0oooool00ol0003oooooooooo`0Aooooo`?o00002Oooool01Ol0003ooooooooooooooooo000000So
oooo000Yooooo`03o`000?oooooooooo00?ooooo1?l0000=ooooo`03o`000?n;DXSoRe:801?oRe:8
00?o0000oh]BR?n;DXP01?l00007oh]BR005o`000?n;DXSoRe:8oh]BR?l000000oooool00ol0003o
ooooooooo`0=ooooo`Co00003?ooool01?l0003oooooooooool00009ooooo`00:Oooool00ol0003o
ooooooooo`03o`00017ooooo00?o0000oh]BR?n;DXP04on;DXP3o`0000;oRe:800?o0000oh]BR?n;
DXP01_n;DXP01Ol0003oRe:8oh]BR?n;DXSo000000?ooooo00?o0000ooooooooool02_ooool3o`00
00oooooo00Go0000ooooooooooooooooo`000009ooooo`00:_ooool2o`0001Cooooo00?o0000oh]B
R?n;DXP03on;DXP4o`000003oh]BR?l0003oRe:800?oRe:800?o0000oh]BR?n;DXP01On;DXP01Ol0
003oRe:8oh]BR?n;DXSo000000?ooooo00?o0000ooooooooool01_ooool4o`0001;ooooo00Go0000
ooooooooooooooooo`000009ooooo`00:_ooool00ol0003oooooooooo`0Cooooo`03o`000?n;DXSo
Re:800coRe:80ol00006oh]BR003o`000?n;DXSoRe:800;oRe:800?o0000oh]BR?n;DXP01?n;DXP0
1Ol0003oRe:8oh]BR?n;DXSo000000?ooooo00?o0000ooooooooool00_ooool4o`0001Kooooo00?o
0000ooooool000000_l00009ooooo`00:oooool00ol0003oooooooooo`0Booooo`03o`000?n;DXSo
Re:800SoRe:81?l0000:oh]BR003o`000?n;DXSoRe:800;oRe:800?o0000oh]BR?n;DXP00on;DXP0
1Ol0003oRe:8oh]BR?n;DXSo000000?ooooo00?o0000ooooool000000_l0000Hooooo`Co00000_oo
ool00ol0003oooooooooo`07ooooo`00;?ooool00ol0003oooooooooo`0@ooooo`03o`000?n;DXSo
Re:800KoRe:80ol0000?oh]BR003o`000?n;DXSoRe:800;oRe:800?o0000oh]BR?n;DXP00_n;DXP0
1Ol0003oRe:8oh]BR?n;DXSo000000?ooooo0_l0000Hooooo`?o00000_ooool01Ol0003ooooooooo
oooooooo000000Wooooo000/ooooo`03o`000?oooooooooo013ooooo00?o0000oh]BR?n;DXP00_n;
DXP4o`0001?oRe:800Go0000oh]BR?n;DXSoRe:8o`000004oh]BR005o`000?n;DXSoRe:8oh]BR?l0
00000oooool00ol0003oooooooooo`0Cooooo`Co00001Oooool01?l0003oooooooooool0000:oooo
o`00;Oooool00ol0003oooooooooo`0?ooooo`03o`000?n;DXSo000000;o00005on;DXP00ol0003o
Re:8oh]BR002oh]BR005o`000?n;DXSoRe:8oh]BR?l000000on;DXP01Ol0003ooooooooooooooooo
0000017ooooo1?l00009ooooo`04o`000?ooooooooooo`0000[ooooo000^ooooo`03o`000?oooooo
oooo00cooooo1?l0000Koh]BR003o`000?n;DXSoRe:800;oRe:800Co0000oh]BR?n;DXSo00000on;
DXP01?l0003oooooooooool0000?ooooo`?o00003?ooool01Ol0003ooooooooooooooooo000000[o
oooo000_ooooo`03o`000?oooooooooo00Sooooo0ol00002ooooo`03o`000?n;DXSoRe:801_oRe:8
00?o0000oh]BR?n;DXP00ol000000on;DXSo0000oh]BR002oh]BR004o`000?ooooooooooo`0000_o
oooo1?l0000?ooooo`04o`000?ooooooooooo`0000_ooooo000_ooooo`03o`000?oooooooooo00Co
oooo1?l00005ooooo`03o`000?n;DXSoRe:801[oRe:81?l00002oh]BR004o`000?n;DXSoRe:8o`00
00;oRe:800Co0000oooooooooooo00001oooool4o`0001?ooooo1?l0000;ooooo`00<?ooool00ol0
003oooooooooo`03o`0000Wooooo00?o0000oh]BR?n;DXP05_n;DXP4o`0000?oRe:800Oo0000oh]B
R?n;DXSoRe:8o`000?n;DXSo000000;oRe:800Co0000oooooooooooo00001?ooool3o`0001Cooooo
1Ol000000ooooooo0000ooooo`0:ooooo`00<Oooool2o`0000cooooo00?o0000oh]BR?n;DXP04on;
DXP3o`0000SoRe:800Co0000oh]BR?n;DXSoRe:80_l00002oh]BR004o`000?oooooo0000ooooo`Co
00005?ooool3o`0000?ooooo00?o0000ooooool000003?ooool0037ooooo00?o0000ooooooooool0
2oooool00ol0003oRe:8oh]BR00?oh]BR0Co00003?n;DXP01Ol0003oRe:8oh]BR?n;DXSo000000;o
Re:800Co0000ooooool0003o00005?ooool4o`0000Gooooo00Co0000oooooooooooo00003?ooool0
03;ooooo00?o0000ooooooooool02_ooool00ol0003oRe:8oh]BR00;oh]BR0Co00004On;DXP00ol0
003oRe:8oh]BR002o`000004oh]BR?l0003oooooo`00017ooooo1?l00009ooooo`04o`000?oooooo
ooooo`0000cooooo000cooooo`03o`000?oooooooooo00Wooooo00?o0000oh]BR?n;DXP01on;DXP4
o`0001KoRe:800Co0000oh]BR?l0003oRe:80_l000000ooooooo0000ooooo`0=ooooo`?o00003?oo
ool01?l0003oooooooooool0000=ooooo`00=?ooool00ol0003oooooooooo`08ooooo`03o`000?n;
DXSoRe:800?oRe:81?l0000Koh]BR0Ko00002oooool4o`0000oooooo1?l0000=ooooo`00=Oooool0
0ol0003oooooooooo`07ooooo`03o`000?n;DXSoRe:800?o00007On;DXP5o`0000;ooooo0_l00006
ooooo`Co00004?ooool4o`0000;ooooo00?o0000ooooooooool02oooool003Kooooo00?o0000oooo
ooooool01Oooool4o`0001goRe:80ol00005ooooo`04o`000?oooooo0000ooooo`;o000000Cooooo
o`000?l0003o00004?ooool4o`0000;ooooo00Co0000oooooooooooo00003_ooool003Oooooo00?o
0000ooooooooool01?l000000ooooooo0000oh]BR00Joh]BR0Co00002Oooool00ol0003oooooo`00
0003o`00013ooooo0ol00005ooooo`04o`000?ooooooooooo`0000oooooo000hooooo`;o00001Ooo
ool00ol0003oRe:8oh]BR00Eoh]BR0Co00003Oooool2o`0000Cooooo00?o0000ooooooooool02Ooo
ool4o`0000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`00>Oooool00ol0003ooooooooo
o`03ooooo`03o`000?n;DXSoRe:8017oRe:81?l0000Aooooo`03o`000?oooooo000000;ooooo1?l0
0005ooooo`Co00002oooool4o`00013ooooo000jooooo`03o`000?oooooooooo00;ooooo00?o0000
oh]BR?n;DXP03_n;DXP3o`0001Cooooo00?o0000ooooool000000ol00004ooooo`Go00003?ooool5
o`0001;ooooo000kooooo`05o`000?ooooooooooooooool000003?n;DXP4o`0001Kooooo0ol00004
ooooo`Oo00002_ooool5o`0000;ooooo00?o0000ooooooooool04Oooool003cooooo00Co0000oooo
oooooooo00002?n;DXP4o`0001Kooooo1Ol00004ooooo`Go00001?ooool2o`0000Cooooo1?l00003
ooooo`Co00005?ooool003gooooo00?o0000ooooool000001On;DXP3o`0001Kooooo1?l00004oooo
o`Go00001Oooool00ol0003oooooooooo`07o`0000Cooooo1Ol0000Fooooo`00?_ooool2o`000003
oh]BR?l0003o000000;o00005Oooool4o`0000Oooooo0_l00008ooooo`Oo00000_ooool9o`0001So
oooo000oooooo`;o00005_ooool3o`0000_ooooo00?o0000ooooooooool00oooool8o`0000;ooooo
2Ol0000Kooooo`00@Oooool00ol0003oooooooooo`0?ooooo`Co00003Oooool00ol0003ooooooooo
o`08o`0000;ooooo2?l0000Pooooo`00@_ooool2o`0000_ooooo1?l0000@ooooo`So00000_ooool8
o`0002Cooooo0014ooooo`03o`000?oooooooooo00Gooooo0ol0000?ooooo`Wo00000oooool7o`00
02Sooooo0015ooooo`03o`000?oooooooooo00Co00003_ooool4o`0000;ooooo0ol00003ooooo`Oo
0000;?ooool004Kooooo0_l0000>ooooo`Co00001Oooool00ol0003oooooooooo`08o`0002oooooo
0018ooooo`;o00002?ooool4o`0000Sooooo2?l0000cooooo`00B_ooool2o`0000;ooooo1?l00009
ooooo`Oo0000=oooool004cooooo0ol00008ooooo`Oo0000>oooool004oooooo0ol00002ooooo`Ko
0000?oooool005;ooooo0ol00014ooooo`00VOooool009Wooooo002Iooooo`00VOooool009Wooooo
002Iooooo`00VOooool009Wooooo002Iooooo`00VOooool009Wooooo002Iooooo`00VOooool009Wo
oooo002Iooooo`00VOooool009Wooooo002Iooooo`00VOooool009Wooooo002Iooooo`00VOooool0
09Wooooo002Iooooo`00VOooool009Wooooo002Iooooo`00VOooool009Wooooo002Iooooo`00VOoo
ool009Wooooo002Iooooo`00VOooool009Wooooo002Iooooo`00VOooool00001\
\>"],
  ImageRangeCache->{{{0, 152.625}, {287, 0}} -> {0.214774, -0.00162271, \
0.00339429, 0.00339429}},
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[LinearPolarizer[90, 100, 20, CenterThickness->2, \
Centered->1],PlotType->TopView];\
\>", "Input",
  CellTags->"LinearPolarizer"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 2.5 0.047619 [
[ 0 0 0 0 ]
[ 1 5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.02381 .11905 m
.88095 .11905 L
.88095 .51587 L
.02381 .51587 L
.02381 .11905 L
F
.02381 .51587 m
.88095 .51587 L
.88095 .9127 L
.02381 .9127 L
.02381 .51587 L
F
.02381 .9127 m
.88095 .9127 L
.88095 1.30952 L
.02381 1.30952 L
.02381 .9127 L
F
.02381 1.30952 m
.88095 1.30952 L
.88095 1.70635 L
.02381 1.70635 L
.02381 1.30952 L
F
.02381 1.70635 m
.88095 1.70635 L
.88095 2.10317 L
.02381 2.10317 L
.02381 1.70635 L
F
.02381 2.10317 m
.88095 2.10317 L
.88095 2.5 L
.02381 2.5 L
.02381 2.10317 L
F
.02381 2.5 m
.88095 2.5 L
.88095 2.89683 L
.02381 2.89683 L
.02381 2.5 L
F
.02381 2.89683 m
.88095 2.89683 L
.88095 3.29365 L
.02381 3.29365 L
.02381 2.89683 L
F
.02381 3.29365 m
.88095 3.29365 L
.88095 3.69048 L
.02381 3.69048 L
.02381 3.29365 L
F
.02381 3.69048 m
.88095 3.69048 L
.88095 4.0873 L
.02381 4.0873 L
.02381 3.69048 L
F
.02381 4.0873 m
.88095 4.0873 L
.88095 4.48413 L
.02381 4.48413 L
.02381 4.0873 L
F
.02381 4.48413 m
.88095 4.48413 L
.88095 4.88095 L
.02381 4.88095 L
.02381 4.48413 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .11905 m
.02381 .51587 L
.02381 .9127 L
.02381 1.30952 L
.02381 1.70635 L
.02381 2.10317 L
.02381 2.5 L
.02381 2.89683 L
.02381 3.29365 L
.02381 3.69048 L
.02381 4.0873 L
.02381 4.48413 L
.02381 4.88095 L
.88095 4.88095 L
.88095 4.48413 L
.88095 4.0873 L
.88095 3.69048 L
.88095 3.29365 L
.88095 2.89683 L
.88095 2.5 L
.88095 2.10317 L
.88095 1.70635 L
.88095 1.30952 L
.88095 .9127 L
.88095 .51587 L
.88095 .11905 L
.02381 .11905 L
s
.5 g
.02381 2.5 m
.88095 2.5 L
.88095 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.88095 2.5 L
.88095 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.88095 2.5 L
.88095 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.88095 2.5 L
.88095 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.88095 2.5 L
.88095 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.88095 2.5 L
.88095 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.88095 2.5 L
.88095 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.88095 2.5 L
.88095 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.88095 2.5 L
.88095 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.88095 2.5 L
.88095 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.88095 2.5 L
.88095 2.5 L
.02381 2.5 L
.02381 2.5 L
F
.02381 2.5 m
.88095 2.5 L
.88095 2.5 L
.02381 2.5 L
.02381 2.5 L
F
0 g
.02381 2.5 m
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.02381 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.02381 2.5 L
s
.5 g
.88095 .11905 m
.97619 .11905 L
.97619 .51587 L
.88095 .51587 L
.88095 .11905 L
F
.88095 .51587 m
.97619 .51587 L
.97619 .9127 L
.88095 .9127 L
.88095 .51587 L
F
.88095 .9127 m
.97619 .9127 L
.97619 1.30952 L
.88095 1.30952 L
.88095 .9127 L
F
.88095 1.30952 m
.97619 1.30952 L
.97619 1.70635 L
.88095 1.70635 L
.88095 1.30952 L
F
.88095 1.70635 m
.97619 1.70635 L
.97619 2.10317 L
.88095 2.10317 L
.88095 1.70635 L
F
.88095 2.10317 m
.97619 2.10317 L
.97619 2.5 L
.88095 2.5 L
.88095 2.10317 L
F
.88095 2.5 m
.97619 2.5 L
.97619 2.89683 L
.88095 2.89683 L
.88095 2.5 L
F
.88095 2.89683 m
.97619 2.89683 L
.97619 3.29365 L
.88095 3.29365 L
.88095 2.89683 L
F
.88095 3.29365 m
.97619 3.29365 L
.97619 3.69048 L
.88095 3.69048 L
.88095 3.29365 L
F
.88095 3.69048 m
.97619 3.69048 L
.97619 4.0873 L
.88095 4.0873 L
.88095 3.69048 L
F
.88095 4.0873 m
.97619 4.0873 L
.97619 4.48413 L
.88095 4.48413 L
.88095 4.0873 L
F
.88095 4.48413 m
.97619 4.48413 L
.97619 4.88095 L
.88095 4.88095 L
.88095 4.48413 L
F
0 g
.88095 .11905 m
.88095 .51587 L
.88095 .9127 L
.88095 1.30952 L
.88095 1.70635 L
.88095 2.10317 L
.88095 2.5 L
.88095 2.89683 L
.88095 3.29365 L
.88095 3.69048 L
.88095 4.0873 L
.88095 4.48413 L
.88095 4.88095 L
.97619 4.88095 L
.97619 4.48413 L
.97619 4.0873 L
.97619 3.69048 L
.97619 3.29365 L
.97619 2.89683 L
.97619 2.5 L
.97619 2.10317 L
.97619 1.70635 L
.97619 1.30952 L
.97619 .9127 L
.97619 .51587 L
.97619 .11905 L
.88095 .11905 L
s
.5 g
.88095 2.5 m
.97619 2.5 L
.97619 2.5 L
.88095 2.5 L
.88095 2.5 L
F
.88095 2.5 m
.97619 2.5 L
.97619 2.5 L
.88095 2.5 L
.88095 2.5 L
F
.88095 2.5 m
.97619 2.5 L
.97619 2.5 L
.88095 2.5 L
.88095 2.5 L
F
.88095 2.5 m
.97619 2.5 L
.97619 2.5 L
.88095 2.5 L
.88095 2.5 L
F
.88095 2.5 m
.97619 2.5 L
.97619 2.5 L
.88095 2.5 L
.88095 2.5 L
F
.88095 2.5 m
.97619 2.5 L
.97619 2.5 L
.88095 2.5 L
.88095 2.5 L
F
.88095 2.5 m
.97619 2.5 L
.97619 2.5 L
.88095 2.5 L
.88095 2.5 L
F
.88095 2.5 m
.97619 2.5 L
.97619 2.5 L
.88095 2.5 L
.88095 2.5 L
F
.88095 2.5 m
.97619 2.5 L
.97619 2.5 L
.88095 2.5 L
.88095 2.5 L
F
.88095 2.5 m
.97619 2.5 L
.97619 2.5 L
.88095 2.5 L
.88095 2.5 L
F
.88095 2.5 m
.97619 2.5 L
.97619 2.5 L
.88095 2.5 L
.88095 2.5 L
F
.88095 2.5 m
.97619 2.5 L
.97619 2.5 L
.88095 2.5 L
.88095 2.5 L
F
0 g
.88095 2.5 m
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.88095 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.97619 2.5 L
.88095 2.5 L
s
.02381 4.88095 m
.02381 4.86058 L
.02381 4.79982 L
.02381 4.69971 L
.02381 4.56197 L
.02381 4.38894 L
.02381 4.18359 L
.02381 3.94943 L
.02381 3.69048 L
.02381 3.41115 L
.02381 3.11624 L
.02381 2.81078 L
.02381 2.5 L
.02381 2.18922 L
.02381 1.88376 L
.02381 1.58885 L
.02381 1.30952 L
.02381 1.05057 L
.02381 .81641 L
.02381 .61106 L
.02381 .43803 L
.02381 .30029 L
.02381 .20018 L
.02381 .13942 L
.02381 .11905 L
.02381 .13942 L
.02381 .20018 L
.02381 .30029 L
.02381 .43803 L
.02381 .61106 L
.02381 .81641 L
.02381 1.05057 L
.02381 1.30952 L
.02381 1.58885 L
.02381 1.88376 L
.02381 2.18922 L
.02381 2.5 L
.02381 2.81078 L
.02381 3.11624 L
.02381 3.41115 L
.02381 3.69048 L
.02381 3.94943 L
.02381 4.18359 L
.02381 4.38894 L
.02381 4.56197 L
.02381 4.69971 L
.02381 4.79982 L
.02381 4.86058 L
.02381 4.88095 L
s
.88095 4.88095 m
.88095 4.86058 L
.88095 4.79982 L
.88095 4.69971 L
.88095 4.56197 L
.88095 4.38894 L
.88095 4.18359 L
.88095 3.94943 L
.88095 3.69048 L
.88095 3.41115 L
.88095 3.11624 L
.88095 2.81078 L
.88095 2.5 L
.88095 2.18922 L
.88095 1.88376 L
.88095 1.58885 L
.88095 1.30952 L
.88095 1.05057 L
.88095 .81641 L
.88095 .61106 L
.88095 .43803 L
.88095 .30029 L
.88095 .20018 L
.88095 .13942 L
.88095 .11905 L
.88095 .13942 L
.88095 .20018 L
.88095 .30029 L
.88095 .43803 L
.88095 .61106 L
.88095 .81641 L
.88095 1.05057 L
.88095 1.30952 L
.88095 1.58885 L
.88095 1.88376 L
.88095 2.18922 L
.88095 2.5 L
.88095 2.81078 L
.88095 3.11624 L
.88095 3.41115 L
.88095 3.69048 L
.88095 3.94943 L
.88095 4.18359 L
.88095 4.38894 L
.88095 4.56197 L
.88095 4.69971 L
.88095 4.79982 L
.88095 4.86058 L
.88095 4.88095 L
s
.97619 4.88095 m
.97619 4.86058 L
.97619 4.79982 L
.97619 4.69971 L
.97619 4.56197 L
.97619 4.38894 L
.97619 4.18359 L
.97619 3.94943 L
.97619 3.69048 L
.97619 3.41115 L
.97619 3.11624 L
.97619 2.81078 L
.97619 2.5 L
.97619 2.18922 L
.97619 1.88376 L
.97619 1.58885 L
.97619 1.30952 L
.97619 1.05057 L
.97619 .81641 L
.97619 .61106 L
.97619 .43803 L
.97619 .30029 L
.97619 .20018 L
.97619 .13942 L
.97619 .11905 L
.97619 .13942 L
.97619 .20018 L
.97619 .30029 L
.97619 .43803 L
.97619 .61106 L
.97619 .81641 L
.97619 1.05057 L
.97619 1.30952 L
.97619 1.58885 L
.97619 1.88376 L
.97619 2.18922 L
.97619 2.5 L
.97619 2.81078 L
.97619 3.11624 L
.97619 3.41115 L
.97619 3.69048 L
.97619 3.94943 L
.97619 4.18359 L
.97619 4.38894 L
.97619 4.56197 L
.97619 4.69971 L
.97619 4.79982 L
.97619 4.86058 L
.97619 4.88095 L
s
.02381 4.88095 m
.88095 4.88095 L
.88095 4.86058 L
.02381 4.86058 L
.02381 4.88095 L
s
.02381 4.86058 m
.88095 4.86058 L
.88095 4.79982 L
.02381 4.79982 L
.02381 4.86058 L
s
.02381 4.79982 m
.88095 4.79982 L
.88095 4.69971 L
.02381 4.69971 L
.02381 4.79982 L
s
.02381 4.69971 m
.88095 4.69971 L
.88095 4.56197 L
.02381 4.56197 L
.02381 4.69971 L
s
.02381 4.56197 m
.88095 4.56197 L
.88095 4.38894 L
.02381 4.38894 L
.02381 4.56197 L
s
.02381 4.38894 m
.88095 4.38894 L
.88095 4.18359 L
.02381 4.18359 L
.02381 4.38894 L
s
.02381 4.18359 m
.88095 4.18359 L
.88095 3.94943 L
.02381 3.94943 L
.02381 4.18359 L
s
.02381 3.94943 m
.88095 3.94943 L
.88095 3.69048 L
.02381 3.69048 L
.02381 3.94943 L
s
.02381 3.69048 m
.88095 3.69048 L
.88095 3.41115 L
.02381 3.41115 L
.02381 3.69048 L
s
.02381 3.41115 m
.88095 3.41115 L
.88095 3.11624 L
.02381 3.11624 L
.02381 3.41115 L
s
.02381 3.11624 m
.88095 3.11624 L
.88095 2.81078 L
.02381 2.81078 L
.02381 3.11624 L
s
.02381 2.81078 m
.88095 2.81078 L
.88095 2.5 L
.02381 2.5 L
.02381 2.81078 L
s
.02381 2.5 m
.88095 2.5 L
.88095 2.18922 L
.02381 2.18922 L
.02381 2.5 L
s
.02381 2.18922 m
.88095 2.18922 L
.88095 1.88376 L
.02381 1.88376 L
.02381 2.18922 L
s
.02381 1.88376 m
.88095 1.88376 L
.88095 1.58885 L
.02381 1.58885 L
.02381 1.88376 L
s
.02381 1.58885 m
.88095 1.58885 L
.88095 1.30952 L
.02381 1.30952 L
.02381 1.58885 L
s
.02381 1.30952 m
.88095 1.30952 L
.88095 1.05057 L
.02381 1.05057 L
.02381 1.30952 L
s
.02381 1.05057 m
.88095 1.05057 L
.88095 .81641 L
.02381 .81641 L
.02381 1.05057 L
s
.02381 .81641 m
.88095 .81641 L
.88095 .61106 L
.02381 .61106 L
.02381 .81641 L
s
.02381 .61106 m
.88095 .61106 L
.88095 .43803 L
.02381 .43803 L
.02381 .61106 L
s
.02381 .43803 m
.88095 .43803 L
.88095 .30029 L
.02381 .30029 L
.02381 .43803 L
s
.02381 .30029 m
.88095 .30029 L
.88095 .20018 L
.02381 .20018 L
.02381 .30029 L
s
.02381 .20018 m
.88095 .20018 L
.88095 .13942 L
.02381 .13942 L
.02381 .20018 L
s
.02381 .13942 m
.88095 .13942 L
.88095 .11905 L
.02381 .11905 L
.02381 .13942 L
s
.02381 .11905 m
.88095 .11905 L
.88095 .13942 L
.02381 .13942 L
.02381 .11905 L
s
.02381 .13942 m
.88095 .13942 L
.88095 .20018 L
.02381 .20018 L
.02381 .13942 L
s
.02381 .20018 m
.88095 .20018 L
.88095 .30029 L
.02381 .30029 L
.02381 .20018 L
s
.02381 .30029 m
.88095 .30029 L
.88095 .43803 L
.02381 .43803 L
.02381 .30029 L
s
.02381 .43803 m
.88095 .43803 L
.88095 .61106 L
.02381 .61106 L
.02381 .43803 L
s
.02381 .61106 m
.88095 .61106 L
.88095 .81641 L
.02381 .81641 L
.02381 .61106 L
s
.02381 .81641 m
.88095 .81641 L
.88095 1.05057 L
.02381 1.05057 L
.02381 .81641 L
s
.02381 1.05057 m
.88095 1.05057 L
.88095 1.30952 L
.02381 1.30952 L
.02381 1.05057 L
s
.02381 1.30952 m
.88095 1.30952 L
.88095 1.58885 L
.02381 1.58885 L
.02381 1.30952 L
s
.02381 1.58885 m
.88095 1.58885 L
.88095 1.88376 L
.02381 1.88376 L
.02381 1.58885 L
s
.02381 1.88376 m
.88095 1.88376 L
.88095 2.18922 L
.02381 2.18922 L
.02381 1.88376 L
s
.02381 2.18922 m
.88095 2.18922 L
.88095 2.5 L
.02381 2.5 L
.02381 2.18922 L
s
.02381 2.5 m
.88095 2.5 L
.88095 2.81078 L
.02381 2.81078 L
.02381 2.5 L
s
.02381 2.81078 m
.88095 2.81078 L
.88095 3.11624 L
.02381 3.11624 L
.02381 2.81078 L
s
.02381 3.11624 m
.88095 3.11624 L
.88095 3.41115 L
.02381 3.41115 L
.02381 3.11624 L
s
.02381 3.41115 m
.88095 3.41115 L
.88095 3.69048 L
.02381 3.69048 L
.02381 3.41115 L
s
.02381 3.69048 m
.88095 3.69048 L
.88095 3.94943 L
.02381 3.94943 L
.02381 3.69048 L
s
.02381 3.94943 m
.88095 3.94943 L
.88095 4.18359 L
.02381 4.18359 L
.02381 3.94943 L
s
.02381 4.18359 m
.88095 4.18359 L
.88095 4.38894 L
.02381 4.38894 L
.02381 4.18359 L
s
.02381 4.38894 m
.88095 4.38894 L
.88095 4.56197 L
.02381 4.56197 L
.02381 4.38894 L
s
.02381 4.56197 m
.88095 4.56197 L
.88095 4.69971 L
.02381 4.69971 L
.02381 4.56197 L
s
.02381 4.69971 m
.88095 4.69971 L
.88095 4.79982 L
.02381 4.79982 L
.02381 4.69971 L
s
.02381 4.79982 m
.88095 4.79982 L
.88095 4.86058 L
.02381 4.86058 L
.02381 4.79982 L
s
.02381 4.86058 m
.88095 4.86058 L
.88095 4.88095 L
.02381 4.88095 L
.02381 4.86058 L
s
.88095 4.88095 m
.97619 4.88095 L
.97619 4.86058 L
.88095 4.86058 L
.88095 4.88095 L
s
.88095 4.86058 m
.97619 4.86058 L
.97619 4.79982 L
.88095 4.79982 L
.88095 4.86058 L
s
.88095 4.79982 m
.97619 4.79982 L
.97619 4.69971 L
.88095 4.69971 L
.88095 4.79982 L
s
.88095 4.69971 m
.97619 4.69971 L
.97619 4.56197 L
.88095 4.56197 L
.88095 4.69971 L
s
.88095 4.56197 m
.97619 4.56197 L
.97619 4.38894 L
.88095 4.38894 L
.88095 4.56197 L
s
.88095 4.38894 m
.97619 4.38894 L
.97619 4.18359 L
.88095 4.18359 L
.88095 4.38894 L
s
.88095 4.18359 m
.97619 4.18359 L
.97619 3.94943 L
.88095 3.94943 L
.88095 4.18359 L
s
.88095 3.94943 m
.97619 3.94943 L
.97619 3.69048 L
.88095 3.69048 L
.88095 3.94943 L
s
.88095 3.69048 m
.97619 3.69048 L
.97619 3.41115 L
.88095 3.41115 L
.88095 3.69048 L
s
.88095 3.41115 m
.97619 3.41115 L
.97619 3.11624 L
.88095 3.11624 L
.88095 3.41115 L
s
.88095 3.11624 m
.97619 3.11624 L
.97619 2.81078 L
.88095 2.81078 L
.88095 3.11624 L
s
.88095 2.81078 m
.97619 2.81078 L
.97619 2.5 L
.88095 2.5 L
.88095 2.81078 L
s
.88095 2.5 m
.97619 2.5 L
.97619 2.18922 L
.88095 2.18922 L
.88095 2.5 L
s
.88095 2.18922 m
.97619 2.18922 L
.97619 1.88376 L
.88095 1.88376 L
.88095 2.18922 L
s
.88095 1.88376 m
.97619 1.88376 L
.97619 1.58885 L
.88095 1.58885 L
.88095 1.88376 L
s
.88095 1.58885 m
.97619 1.58885 L
.97619 1.30952 L
.88095 1.30952 L
.88095 1.58885 L
s
.88095 1.30952 m
.97619 1.30952 L
.97619 1.05057 L
.88095 1.05057 L
.88095 1.30952 L
s
.88095 1.05057 m
.97619 1.05057 L
.97619 .81641 L
.88095 .81641 L
.88095 1.05057 L
s
.88095 .81641 m
.97619 .81641 L
.97619 .61106 L
.88095 .61106 L
.88095 .81641 L
s
.88095 .61106 m
.97619 .61106 L
.97619 .43803 L
.88095 .43803 L
.88095 .61106 L
s
.88095 .43803 m
.97619 .43803 L
.97619 .30029 L
.88095 .30029 L
.88095 .43803 L
s
.88095 .30029 m
.97619 .30029 L
.97619 .20018 L
.88095 .20018 L
.88095 .30029 L
s
.88095 .20018 m
.97619 .20018 L
.97619 .13942 L
.88095 .13942 L
.88095 .20018 L
s
.88095 .13942 m
.97619 .13942 L
.97619 .11905 L
.88095 .11905 L
.88095 .13942 L
s
.88095 .11905 m
.97619 .11905 L
.97619 .13942 L
.88095 .13942 L
.88095 .11905 L
s
.88095 .13942 m
.97619 .13942 L
.97619 .20018 L
.88095 .20018 L
.88095 .13942 L
s
.88095 .20018 m
.97619 .20018 L
.97619 .30029 L
.88095 .30029 L
.88095 .20018 L
s
.88095 .30029 m
.97619 .30029 L
.97619 .43803 L
.88095 .43803 L
.88095 .30029 L
s
.88095 .43803 m
.97619 .43803 L
.97619 .61106 L
.88095 .61106 L
.88095 .43803 L
s
.88095 .61106 m
.97619 .61106 L
.97619 .81641 L
.88095 .81641 L
.88095 .61106 L
s
.88095 .81641 m
.97619 .81641 L
.97619 1.05057 L
.88095 1.05057 L
.88095 .81641 L
s
.88095 1.05057 m
.97619 1.05057 L
.97619 1.30952 L
.88095 1.30952 L
.88095 1.05057 L
s
.88095 1.30952 m
.97619 1.30952 L
.97619 1.58885 L
.88095 1.58885 L
.88095 1.30952 L
s
.88095 1.58885 m
.97619 1.58885 L
.97619 1.88376 L
.88095 1.88376 L
.88095 1.58885 L
s
.88095 1.88376 m
.97619 1.88376 L
.97619 2.18922 L
.88095 2.18922 L
.88095 1.88376 L
s
.88095 2.18922 m
.97619 2.18922 L
.97619 2.5 L
.88095 2.5 L
.88095 2.18922 L
s
.88095 2.5 m
.97619 2.5 L
.97619 2.81078 L
.88095 2.81078 L
.88095 2.5 L
s
.88095 2.81078 m
.97619 2.81078 L
.97619 3.11624 L
.88095 3.11624 L
.88095 2.81078 L
s
.88095 3.11624 m
.97619 3.11624 L
.97619 3.41115 L
.88095 3.41115 L
.88095 3.11624 L
s
.88095 3.41115 m
.97619 3.41115 L
.97619 3.69048 L
.88095 3.69048 L
.88095 3.41115 L
s
.88095 3.69048 m
.97619 3.69048 L
.97619 3.94943 L
.88095 3.94943 L
.88095 3.69048 L
s
.88095 3.94943 m
.97619 3.94943 L
.97619 4.18359 L
.88095 4.18359 L
.88095 3.94943 L
s
.88095 4.18359 m
.97619 4.18359 L
.97619 4.38894 L
.88095 4.38894 L
.88095 4.18359 L
s
.88095 4.38894 m
.97619 4.38894 L
.97619 4.56197 L
.88095 4.56197 L
.88095 4.38894 L
s
.88095 4.56197 m
.97619 4.56197 L
.97619 4.69971 L
.88095 4.69971 L
.88095 4.56197 L
s
.88095 4.69971 m
.97619 4.69971 L
.97619 4.79982 L
.88095 4.79982 L
.88095 4.69971 L
s
.88095 4.79982 m
.97619 4.79982 L
.97619 4.86058 L
.88095 4.86058 L
.88095 4.79982 L
s
.88095 4.86058 m
.97619 4.86058 L
.97619 4.88095 L
.88095 4.88095 L
.88095 4.86058 L
s
0 0 m
1 0 L
1 5 L
0 5 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{73, 365},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000190001KB000`400?l00000o`00003oBOooool0
04Wooooo0019ooooo`00BOooool004Wooooo0019ooooo`00BOooool004Wooooo0019ooooo`00BOoo
ool004Wooooo00000ooooooo0000o`000014o`0000;ooooo00000ooooooo0000ogmoO`0logmoO`03
o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000o`000014o`0000;ooooo
00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo0000
0ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooo
oooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo
0000o`000014o`0000;ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo
0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol0
0001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001
ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001oooo
o`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7o
oooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo
00000ooooooo0000o`000014o`0000;ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgoo
Ogmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo
00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00Co
Ogmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo
0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol0
0001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001
ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001oooo
o`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7o
oooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo
00000ooooooo0000o`000014o`0000;ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgoo
Ogmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo
00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00Co
Ogmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo
0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol0
0001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001
ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001oooo
o`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7o
oooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo
00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo0000
0ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooo
oooo0000o`000014o`0000;ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00Co
Ogmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo
0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol0
0001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001
ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001oooo
o`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7o
oooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo
00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo0000
0ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooo
oooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo
0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000
ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmo
O`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0l
ogmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000o`000014o`00
00;ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7o
oooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo
00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo0000
0ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooo
oooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo
0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000
ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmo
O`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0l
ogmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmo
O`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03
o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`00
0?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?mo
OgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgoo
Ogmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo
00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00Co
Ogmo0Ol00001ooooo`7ooooo00000ooooooo0000o`000014o`0000;ooooo00000ooooooo0000ogmo
O`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0l
ogmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmo
O`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03
o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`00
0?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?mo
OgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgoo
Ogmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo
00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00Co
Ogmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo
0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol0
0001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001
ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001oooo
o`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7o
oooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo
00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo0000
0ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooo
oooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo
0000o`000014o`0000;ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo
0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol0
0001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001
ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001oooo
o`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7o
oooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo
00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo0000
0ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooo
oooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo
0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000
ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmo
O`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0l
ogmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmo
O`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03
o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`00
0?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?mo
OgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgoo
Ogmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo
00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000o`000014o`0000;ooooo00000ooooooo0000
ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmo
O`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0l
ogmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmo
O`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03
o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`00
0?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?mo
OgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgoo
Ogmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo
00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00Co
Ogmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo
0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol0
0001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001
ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001oooo
o`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7o
oooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo
00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo0000
0ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooo
oooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo
0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000
o`000014o`0000;ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol0
0001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001
ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001oooo
o`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7o
oooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo
00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo0000
0ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooo
oooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo
0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000
ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmo
O`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0l
ogmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmo
O`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03
o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`00
0?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?mo
OgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgoo
Ogmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo
00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00Co
Ogmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo
0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol0
0001ooooo`7ooooo00000ooooooo0000o`000014o`0000;ooooo00000ooooooo0000ogmoO`0logmo
O`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03
o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`00
0?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?mo
OgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgoo
Ogmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo
00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00Co
Ogmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo
0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol0
0001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001
ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001oooo
o`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7o
oooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo
00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo0000
0ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooo
oooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo
0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000
ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmo
O`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0l
ogmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmo
O`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000o`000014o`0000;o
oooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo
00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo0000
0ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooo
oooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo
0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000
ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmo
O`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0l
ogmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmo
O`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03
o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`00
0?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?mo
OgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgoo
Ogmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo
00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00Co
Ogmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo
0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol0
0001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001
ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001oooo
o`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7o
oooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo
00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo0000
0ooooooo0000o`000014o`0000;ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo
00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00Co
Ogmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo
0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol0
0001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001
ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001oooo
o`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7o
oooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo
00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo0000
0ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooo
oooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo
0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000
ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmo
O`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0l
ogmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmo
O`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03
o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`00
0?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?mo
OgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgoo
Ogmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo
00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000o`000014o`0000;ooooo00000ooooooo0000
ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmo
O`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0l
ogmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmo
O`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03
o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`00
0?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?mo
OgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgoo
Ogmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo
00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00Co
Ogmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo
0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol0
0001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001
ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001oooo
o`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7o
oooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo
00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo0000
0ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooo
oooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo
0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000
o`000014o`0000;ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol0
0001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001
ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001oooo
o`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7o
oooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo
00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo0000
0ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooo
oooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo
0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000
ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmo
O`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0l
ogmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmo
O`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03
o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`00
0?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?mo
OgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgoo
Ogmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo
00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00Co
Ogmo0Ol00001ooooo`7ooooo00000ooooooo0000o`000014o`0000;ooooo00000ooooooo0000ogmo
O`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0l
ogmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmo
O`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03
o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`00
0?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?mo
OgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgoo
Ogmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo
00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00Co
Ogmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo
0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol0
0001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001
ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001oooo
o`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7o
oooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo
00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo0000
0ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooo
oooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo
0000o`000014o`0000;ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo
0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol0
0001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001
ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001oooo
o`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7o
oooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo
00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo0000
0ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooo
oooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo
0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000
ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmo
O`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0l
ogmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmo
O`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03
o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`00
0?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000o`000014o`0000;ooooo0000
0ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooo
oooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo
0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000
ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmo
O`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0l
ogmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmo
O`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03
o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`00
0?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?mo
OgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgoo
Ogmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo
00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00Co
Ogmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo
0Ol00001ooooo`7ooooo00000ooooooo0000o`000014o`0000;ooooo00000ooooooo0000ogmoO`0l
ogmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmo
O`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03
o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`00
0?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?mo
OgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgoo
Ogmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo
00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00Co
Ogmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo
0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol0
0001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001
ooooo`7ooooo00000ooooooo0000o`000014o`0000;ooooo00000ooooooo0000ogmoO`0logmoO`03
o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`00
0?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?mo
OgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgoo
Ogmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo
00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00Co
Ogmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo
0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol0
0001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001
ooooo`7ooooo00000ooooooo0000o`000014o`0000;ooooo00000ooooooo0000ogmoO`0logmoO`03
o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`00
0?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?mo
OgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgoo
Ogmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo
00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00Co
Ogmo0Ol00001ooooo`7ooooo00000ooooooo0000o`000014o`0000;ooooo00000ooooooo0000ogmo
O`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0l
ogmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000ogmoO`0logmo
O`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo00000ooooooo0000o`000014o`0000;o
oooo00000ooooooo0000ogmoO`0logmoO`03o`000?moOgooOgmo00CoOgmo0Ol00001ooooo`7ooooo
00000ooooooo0000o`000014o`0000;ooooo0019ooooo`00BOooool004Wooooo0019ooooo`00BOoo
ool004Wooooo0019ooooo`00BOooool004Wooooo0019ooooo`00\
\>"],
  ImageRangeCache->{{{0, 72}, {364, 0}} -> {-0.500105, -53.0839, 0.29167, \
0.29167}},
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DataToRayica[OpticalMedium->HN38]", "Input",
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    \({"HN38 is an optical material from Polaroid with a transmittance of \
{77.2352, 0.00242455} at the 0.5876 micron wavelength. The transmittance \
model for this Polaroid Type HN38 Polarizing Material is valid from 0.4 to \
0.76 microns of wavelength.\n\nHN38 also has a refractive index of 1.5163 at \
the 0.5876 micron wavelength, a corresponding V-number of 58.1235, a partial \
dispersion ratio of 0.294864, and a mean dispersion value of 0.00888289. The \
refractive index model for this Polaroid Type HN38 Polarizing Material is \
valid from 0.46 to 1.06 microns of wavelength."}\)], "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SearchData[OpticalMedium->HN38]", "Input",
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    \({{CompanyName \[Rule] "Polaroid", 
        ComponentLabel \[Rule] "Polaroid Type HN38 Polarizing Material", 
        FileName \[Rule] "PolarizingMaterials.m", Date \[Rule] {1999, 4, 18}, 
        OpticaFunction \[Rule] IndexFunction, OpticalMedium \[Rule] HN38, 
        WaveLengthRange \[Rule] {{0.4`, 
              0.759999999999999964`}, {0.460000000000000053`, 
              1.06000000000000005`}}, 
        ModelIntensity \[Rule] {{{0.4`, 
                65.3120291299999955`}, {0.409999999999999964`, 
                69.6600924400000032`}, {0.420000000000000017`, 
                72.2839956400000005`}, {0.429999999999999982`, 
                74.4647640400000021`}, {0.440000000000000035`, 
                76.2140230100000071`}, {0.45`, 
                77.6288576000000052`}, {0.460000000000000053`, 
                78.3416455899999952`}, {0.469999999999999928`, 
                79.2446786600000052`}, {0.479999999999999982`, 
                80.3483113900000134`}, {0.490000000000000035`, 
                81.0920859199999988`}, {0.5`, 
                81.2770935700000052`}, {0.509999999999999964`, 
                80.5356288299999967`}, {0.520000000000000017`, 
                80.5356910499999933`}, {0.530000000000000071`, 
                80.3492338300000064`}, {0.540000000000000035`, 
                79.7997486700000013`}, {0.55`, 
                79.2464507800000017`}, {0.560000000000000053`, 
                78.7019689600000038`}, {0.569999999999999928`, 
                78.523883010000004`}, {0.579999999999999982`, 
                77.2657761300000078`}, {0.589999999999999946`, 
                77.2010347400000007`}, {0.6`, 
                75.9473515200000015`}, {0.609999999999999964`, 
                75.8551260900000023`}, {0.620000000000000017`, 
                75.8551253200000008`}, {0.629999999999999982`, 
                75.3392295899999986`}, {0.640000000000000035`, 
                75.8551279200000028`}, {0.65`, 
                76.3806236500000057`}, {0.660000000000000053`, 
                76.6420233200000033`}, {0.670000000000000017`, 
                77.8074537499999951`}, {0.680000000000000071`, 
                77.9871791500000011`}, {0.689999999999999946`, 
                79.2464522300000062`}, {0.7`, 
                79.9874974599999966`}, {0.709999999999999964`, 
                81.0925376600000014`}, {0.719999999999999928`, 
                82.219217449999995`}, {0.729999999999999982`, 
                83.5583622300000072`}, {0.740000000000000035`, 
                84.7230773499999934`}, {0.75`, 
                84.9234825699999973`}, {0.759999999999999964`, 
                86.3017424599999927`}}, {{0.4`, 
                4.04213440000000012`}, {0.409999999999999964`, 
                3.93338554000000009`}, {0.420000000000000017`, 
                3.32023703999999986`}, {0.429999999999999982`, 
                2.6455465600000001`}, {0.440000000000000035`, 
                1.85005324000000008`}, {0.45`, 
                1.32682616999999991`}, {0.460000000000000053`, 
                0.765876180000000061`}, {0.469999999999999928`, 
                0.530004040000000031`}, {0.479999999999999982`, 
                0.385820180000000014`}, {0.490000000000000035`, 
                0.27129650999999999`}, {0.5`, 
                0.184553839999999986`}, {0.509999999999999964`, 
                0.111751779999999989`}, {0.520000000000000017`, 
                0.0496674199999999999`}, {0.530000000000000071`, 
                0.0248913399999999995`}, {0.540000000000000035`, 
                0.0112782300000000001`}, {0.55`, 
                0.00504753999999999969`}, {0.560000000000000053`, 
                0.00381184999999999973`}, {0.569999999999999928`, 
                0.0025469999999999997`}, {0.579999999999999982`, 
                0.00257552999999999965`}, {0.589999999999999946`, 
                0.00237042999999999981`}, {0.6`, 
                0.00223838999999999987`}, {0.609999999999999964`, 
                0.00218838000000000043`}, {0.620000000000000017`, 
                0.00216202000000000049`}, {0.629999999999999982`, 
                0.00207062999999999997`}, {0.640000000000000035`, 
                0.0020433699999999999`}, {0.65`, 
                0.00200313000000000007`}, {0.660000000000000053`, 
                0.00197019999999999999`}, {0.670000000000000017`, 
                0.00195354000000000027`}, {0.680000000000000071`, 
                0.00189774999999999991`}, {0.689999999999999946`, 
                0.00184234999999999971`}, {0.7`, 
                0.00191280000000000001`}, {0.709999999999999964`, 
                0.00209637000000000028`}, {0.719999999999999928`, 
                0.00276091000000000041`}, {0.729999999999999982`, 
                0.00501445999999999969`}, {0.740000000000000035`, 
                0.0129834800000000004`}, {0.75`, 
                0.0459236900000000058`}, {0.759999999999999964`, 
                0.0961741899999999994`}}}, 
        IndexCoefficients \[Rule] {32521585\/14394003, \
\(-\(1159271\/5022099617\)\), 
            2321057\/155773164, \(-\(7581701\/7106696504\)\), 
            1527973\/4895977498, \(-\(510277\/18766313439\)\)}}}\)], "Output",\

  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{Move[SingleRay[],10],
Move[LinearPolarizer[45,50,5,ComponentMedium->HN38],50], \
Boundary[100]},PlotType->TopView]\
\>", "Input",
  CellTags->"LinearPolarizer"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.52381 .22381 -6 -4.5 ]
[.52381 .22381 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .2619 m
.5 .30159 L
.5 .34127 L
.5 .38095 L
.5 .42063 L
.5 .46032 L
.5 .5 L
.5 .53968 L
.5 .57937 L
.5 .61905 L
.5 .65873 L
.5 .69841 L
.5 .7381 L
.54762 .7381 L
.54762 .69841 L
.54762 .65873 L
.54762 .61905 L
.54762 .57937 L
.54762 .53968 L
.54762 .5 L
.54762 .46032 L
.54762 .42063 L
.54762 .38095 L
.54762 .34127 L
.54762 .30159 L
.54762 .2619 L
.5 .2619 L
s
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.5 .5 L
s
.5 .7381 m
.5 .73606 L
.5 .72998 L
.5 .71997 L
.5 .7062 L
.5 .68889 L
.5 .66836 L
.5 .64494 L
.5 .61905 L
.5 .59112 L
.5 .56162 L
.5 .53108 L
.5 .5 L
.5 .46892 L
.5 .43838 L
.5 .40888 L
.5 .38095 L
.5 .35506 L
.5 .33164 L
.5 .31111 L
.5 .2938 L
.5 .28003 L
.5 .27002 L
.5 .26394 L
.5 .2619 L
.5 .26394 L
.5 .27002 L
.5 .28003 L
.5 .2938 L
.5 .31111 L
.5 .33164 L
.5 .35506 L
.5 .38095 L
.5 .40888 L
.5 .43838 L
.5 .46892 L
.5 .5 L
.5 .53108 L
.5 .56162 L
.5 .59112 L
.5 .61905 L
.5 .64494 L
.5 .66836 L
.5 .68889 L
.5 .7062 L
.5 .71997 L
.5 .72998 L
.5 .73606 L
.5 .7381 L
s
.54762 .7381 m
.54762 .73606 L
.54762 .72998 L
.54762 .71997 L
.54762 .7062 L
.54762 .68889 L
.54762 .66836 L
.54762 .64494 L
.54762 .61905 L
.54762 .59112 L
.54762 .56162 L
.54762 .53108 L
.54762 .5 L
.54762 .46892 L
.54762 .43838 L
.54762 .40888 L
.54762 .38095 L
.54762 .35506 L
.54762 .33164 L
.54762 .31111 L
.54762 .2938 L
.54762 .28003 L
.54762 .27002 L
.54762 .26394 L
.54762 .2619 L
.54762 .26394 L
.54762 .27002 L
.54762 .28003 L
.54762 .2938 L
.54762 .31111 L
.54762 .33164 L
.54762 .35506 L
.54762 .38095 L
.54762 .40888 L
.54762 .43838 L
.54762 .46892 L
.54762 .5 L
.54762 .53108 L
.54762 .56162 L
.54762 .59112 L
.54762 .61905 L
.54762 .64494 L
.54762 .66836 L
.54762 .68889 L
.54762 .7062 L
.54762 .71997 L
.54762 .72998 L
.54762 .73606 L
.54762 .7381 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.11905 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.54762 .5 L
s
0 0 0 r
2 Mabswid
.54762 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.54762 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(LP)] .52381 .22381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool500000004
0?ooo`0000000000000007l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0R03oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo07h0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`030?ooo`<00000OP3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
O@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`280?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000O@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`270?ooo`<000000`3oool4000007h0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo3`00001j0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo0P00000;0?ooo`800000N@3oool2000000L0oooo00060?ooo`030000003oool0
oooo01T0ooooNP09jPX00`0000002NX:00WZ2P1h00WZ2P8000001`3oool000H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool?000007X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`800000o`3ooolA0?ooo`030000003oool0oooo00D0oooo00060?ooool00000500000070?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    TagBox[
      RowBox[{"DrawSystem", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"Move", "[", 
                RowBox[{
                  RowBox[{"SingleRay", "[", 
                    RowBox[{
                      RowBox[{"Ray", "[", 
                        RowBox[{\(OpticalMedium \[Rule] Vacuum\), ",", 
                          RowBox[{"RayLineRGB", "\[Rule]", 
                            RowBox[{"{", 
                              RowBox[{
                                StyleBox["0.0387474297047988933`",
                                  StyleBoxAutoDelete->True,
                                  PrintPrecision->16], ",", 
                                StyleBox["0.916161755242403863`",
                                  StyleBoxAutoDelete->True,
                                  PrintPrecision->16], ",", 
                                StyleBox["0.0398472122691814192`",
                                  StyleBoxAutoDelete->True,
                                  PrintPrecision->16]}], "}"}]}], 
                          ",", \(RefractiveIndex \[Rule] 1\)}], "]"}], ",", 
                      "1"}], "]"}], ",", 
                  StyleBox["10.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "]"}], ",", 
              RowBox[{"Move", "[", 
                
                RowBox[{\(LinearPolarizer[45, 50, 
                    5, {ComponentMedium \[Rule] HN38}]\), ",", 
                  StyleBox["50.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "]"}], 
              ",", \(Boundary[{0, \(-50\), \(-50\)}, {100, 50, 50}]\)}], 
            "}"}], ",", \(PlotType \[Rule] TopView\)}], "]"}],
      HoldForm]], "Print",
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    \("-3 ray/surface intersections-"\)], "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{Move[SingleRay[],10],
Move[LinearPolarizer[45,50,5,ComponentMedium->HN38],50], \
Boundary[100]},PlotType->TopView];
ReadRays[sys,{{ComponentNumber,SurfaceNumber},RefractiveIndex,RayTilt,\
Intensity,Polarization}]\
\>", "Input",
  CellTags->"LinearPolarizer"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.52381 .22381 -6 -4.5 ]
[.52381 .22381 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.5 .2619 m
.52381 .2619 L
.52381 .30159 L
.5 .30159 L
.5 .2619 L
F
.5 .30159 m
.52381 .30159 L
.52381 .34127 L
.5 .34127 L
.5 .30159 L
F
.5 .34127 m
.52381 .34127 L
.52381 .38095 L
.5 .38095 L
.5 .34127 L
F
.5 .38095 m
.52381 .38095 L
.52381 .42063 L
.5 .42063 L
.5 .38095 L
F
.5 .42063 m
.52381 .42063 L
.52381 .46032 L
.5 .46032 L
.5 .42063 L
F
.5 .46032 m
.52381 .46032 L
.52381 .5 L
.5 .5 L
.5 .46032 L
F
.5 .5 m
.52381 .5 L
.52381 .53968 L
.5 .53968 L
.5 .5 L
F
.5 .53968 m
.52381 .53968 L
.52381 .57937 L
.5 .57937 L
.5 .53968 L
F
.5 .57937 m
.52381 .57937 L
.52381 .61905 L
.5 .61905 L
.5 .57937 L
F
.5 .61905 m
.52381 .61905 L
.52381 .65873 L
.5 .65873 L
.5 .61905 L
F
.5 .65873 m
.52381 .65873 L
.52381 .69841 L
.5 .69841 L
.5 .65873 L
F
.5 .69841 m
.52381 .69841 L
.52381 .7381 L
.5 .7381 L
.5 .69841 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.5 .2619 m
.5 .30159 L
.5 .34127 L
.5 .38095 L
.5 .42063 L
.5 .46032 L
.5 .5 L
.5 .53968 L
.5 .57937 L
.5 .61905 L
.5 .65873 L
.5 .69841 L
.5 .7381 L
.52381 .7381 L
.52381 .69841 L
.52381 .65873 L
.52381 .61905 L
.52381 .57937 L
.52381 .53968 L
.52381 .5 L
.52381 .46032 L
.52381 .42063 L
.52381 .38095 L
.52381 .34127 L
.52381 .30159 L
.52381 .2619 L
.5 .2619 L
s
.5 g
.5 .5 m
.52381 .5 L
.52381 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.52381 .5 L
.52381 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.52381 .5 L
.52381 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.52381 .5 L
.52381 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.52381 .5 L
.52381 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.52381 .5 L
.52381 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.52381 .5 L
.52381 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.52381 .5 L
.52381 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.52381 .5 L
.52381 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.52381 .5 L
.52381 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.52381 .5 L
.52381 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.52381 .5 L
.52381 .5 L
.5 .5 L
.5 .5 L
F
0 g
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.5 .5 L
s
.5 g
.52381 .2619 m
.54762 .2619 L
.54762 .30159 L
.52381 .30159 L
.52381 .2619 L
F
.52381 .30159 m
.54762 .30159 L
.54762 .34127 L
.52381 .34127 L
.52381 .30159 L
F
.52381 .34127 m
.54762 .34127 L
.54762 .38095 L
.52381 .38095 L
.52381 .34127 L
F
.52381 .38095 m
.54762 .38095 L
.54762 .42063 L
.52381 .42063 L
.52381 .38095 L
F
.52381 .42063 m
.54762 .42063 L
.54762 .46032 L
.52381 .46032 L
.52381 .42063 L
F
.52381 .46032 m
.54762 .46032 L
.54762 .5 L
.52381 .5 L
.52381 .46032 L
F
.52381 .5 m
.54762 .5 L
.54762 .53968 L
.52381 .53968 L
.52381 .5 L
F
.52381 .53968 m
.54762 .53968 L
.54762 .57937 L
.52381 .57937 L
.52381 .53968 L
F
.52381 .57937 m
.54762 .57937 L
.54762 .61905 L
.52381 .61905 L
.52381 .57937 L
F
.52381 .61905 m
.54762 .61905 L
.54762 .65873 L
.52381 .65873 L
.52381 .61905 L
F
.52381 .65873 m
.54762 .65873 L
.54762 .69841 L
.52381 .69841 L
.52381 .65873 L
F
.52381 .69841 m
.54762 .69841 L
.54762 .7381 L
.52381 .7381 L
.52381 .69841 L
F
0 g
.52381 .2619 m
.52381 .30159 L
.52381 .34127 L
.52381 .38095 L
.52381 .42063 L
.52381 .46032 L
.52381 .5 L
.52381 .53968 L
.52381 .57937 L
.52381 .61905 L
.52381 .65873 L
.52381 .69841 L
.52381 .7381 L
.54762 .7381 L
.54762 .69841 L
.54762 .65873 L
.54762 .61905 L
.54762 .57937 L
.54762 .53968 L
.54762 .5 L
.54762 .46032 L
.54762 .42063 L
.54762 .38095 L
.54762 .34127 L
.54762 .30159 L
.54762 .2619 L
.52381 .2619 L
s
.5 g
.52381 .5 m
.54762 .5 L
.54762 .5 L
.52381 .5 L
.52381 .5 L
F
.52381 .5 m
.54762 .5 L
.54762 .5 L
.52381 .5 L
.52381 .5 L
F
.52381 .5 m
.54762 .5 L
.54762 .5 L
.52381 .5 L
.52381 .5 L
F
.52381 .5 m
.54762 .5 L
.54762 .5 L
.52381 .5 L
.52381 .5 L
F
.52381 .5 m
.54762 .5 L
.54762 .5 L
.52381 .5 L
.52381 .5 L
F
.52381 .5 m
.54762 .5 L
.54762 .5 L
.52381 .5 L
.52381 .5 L
F
.52381 .5 m
.54762 .5 L
.54762 .5 L
.52381 .5 L
.52381 .5 L
F
.52381 .5 m
.54762 .5 L
.54762 .5 L
.52381 .5 L
.52381 .5 L
F
.52381 .5 m
.54762 .5 L
.54762 .5 L
.52381 .5 L
.52381 .5 L
F
.52381 .5 m
.54762 .5 L
.54762 .5 L
.52381 .5 L
.52381 .5 L
F
.52381 .5 m
.54762 .5 L
.54762 .5 L
.52381 .5 L
.52381 .5 L
F
.52381 .5 m
.54762 .5 L
.54762 .5 L
.52381 .5 L
.52381 .5 L
F
0 g
.52381 .5 m
.52381 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.52381 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.52381 .5 L
s
.5 .7381 m
.52381 .7381 L
.52381 .73606 L
.5 .73606 L
.5 .7381 L
s
.5 .73606 m
.52381 .73606 L
.52381 .72998 L
.5 .72998 L
.5 .73606 L
s
.5 .72998 m
.52381 .72998 L
.52381 .71997 L
.5 .71997 L
.5 .72998 L
s
.5 .71997 m
.52381 .71997 L
.52381 .7062 L
.5 .7062 L
.5 .71997 L
s
.5 .7062 m
.52381 .7062 L
.52381 .68889 L
.5 .68889 L
.5 .7062 L
s
.5 .68889 m
.52381 .68889 L
.52381 .66836 L
.5 .66836 L
.5 .68889 L
s
.5 .66836 m
.52381 .66836 L
.52381 .64494 L
.5 .64494 L
.5 .66836 L
s
.5 .64494 m
.52381 .64494 L
.52381 .61905 L
.5 .61905 L
.5 .64494 L
s
.5 .61905 m
.52381 .61905 L
.52381 .59112 L
.5 .59112 L
.5 .61905 L
s
.5 .59112 m
.52381 .59112 L
.52381 .56162 L
.5 .56162 L
.5 .59112 L
s
.5 .56162 m
.52381 .56162 L
.52381 .53108 L
.5 .53108 L
.5 .56162 L
s
.5 .53108 m
.52381 .53108 L
.52381 .5 L
.5 .5 L
.5 .53108 L
s
.5 .5 m
.52381 .5 L
.52381 .46892 L
.5 .46892 L
.5 .5 L
s
.5 .46892 m
.52381 .46892 L
.52381 .43838 L
.5 .43838 L
.5 .46892 L
s
.5 .43838 m
.52381 .43838 L
.52381 .40888 L
.5 .40888 L
.5 .43838 L
s
.5 .40888 m
.52381 .40888 L
.52381 .38095 L
.5 .38095 L
.5 .40888 L
s
.5 .38095 m
.52381 .38095 L
.52381 .35506 L
.5 .35506 L
.5 .38095 L
s
.5 .35506 m
.52381 .35506 L
.52381 .33164 L
.5 .33164 L
.5 .35506 L
s
.5 .33164 m
.52381 .33164 L
.52381 .31111 L
.5 .31111 L
.5 .33164 L
s
.5 .31111 m
.52381 .31111 L
.52381 .2938 L
.5 .2938 L
.5 .31111 L
s
.5 .2938 m
.52381 .2938 L
.52381 .28003 L
.5 .28003 L
.5 .2938 L
s
.5 .28003 m
.52381 .28003 L
.52381 .27002 L
.5 .27002 L
.5 .28003 L
s
.5 .27002 m
.52381 .27002 L
.52381 .26394 L
.5 .26394 L
.5 .27002 L
s
.5 .26394 m
.52381 .26394 L
.52381 .2619 L
.5 .2619 L
.5 .26394 L
s
.5 .2619 m
.52381 .2619 L
.52381 .26394 L
.5 .26394 L
.5 .2619 L
s
.5 .26394 m
.52381 .26394 L
.52381 .27002 L
.5 .27002 L
.5 .26394 L
s
.5 .27002 m
.52381 .27002 L
.52381 .28003 L
.5 .28003 L
.5 .27002 L
s
.5 .28003 m
.52381 .28003 L
.52381 .2938 L
.5 .2938 L
.5 .28003 L
s
.5 .2938 m
.52381 .2938 L
.52381 .31111 L
.5 .31111 L
.5 .2938 L
s
.5 .31111 m
.52381 .31111 L
.52381 .33164 L
.5 .33164 L
.5 .31111 L
s
.5 .33164 m
.52381 .33164 L
.52381 .35506 L
.5 .35506 L
.5 .33164 L
s
.5 .35506 m
.52381 .35506 L
.52381 .38095 L
.5 .38095 L
.5 .35506 L
s
.5 .38095 m
.52381 .38095 L
.52381 .40888 L
.5 .40888 L
.5 .38095 L
s
.5 .40888 m
.52381 .40888 L
.52381 .43838 L
.5 .43838 L
.5 .40888 L
s
.5 .43838 m
.52381 .43838 L
.52381 .46892 L
.5 .46892 L
.5 .43838 L
s
.5 .46892 m
.52381 .46892 L
.52381 .5 L
.5 .5 L
.5 .46892 L
s
.5 .5 m
.52381 .5 L
.52381 .53108 L
.5 .53108 L
.5 .5 L
s
.5 .53108 m
.52381 .53108 L
.52381 .56162 L
.5 .56162 L
.5 .53108 L
s
.5 .56162 m
.52381 .56162 L
.52381 .59112 L
.5 .59112 L
.5 .56162 L
s
.5 .59112 m
.52381 .59112 L
.52381 .61905 L
.5 .61905 L
.5 .59112 L
s
.5 .61905 m
.52381 .61905 L
.52381 .64494 L
.5 .64494 L
.5 .61905 L
s
.5 .64494 m
.52381 .64494 L
.52381 .66836 L
.5 .66836 L
.5 .64494 L
s
.5 .66836 m
.52381 .66836 L
.52381 .68889 L
.5 .68889 L
.5 .66836 L
s
.5 .68889 m
.52381 .68889 L
.52381 .7062 L
.5 .7062 L
.5 .68889 L
s
.5 .7062 m
.52381 .7062 L
.52381 .71997 L
.5 .71997 L
.5 .7062 L
s
.5 .71997 m
.52381 .71997 L
.52381 .72998 L
.5 .72998 L
.5 .71997 L
s
.5 .72998 m
.52381 .72998 L
.52381 .73606 L
.5 .73606 L
.5 .72998 L
s
.5 .73606 m
.52381 .73606 L
.52381 .7381 L
.5 .7381 L
.5 .73606 L
s
.52381 .7381 m
.54762 .7381 L
.54762 .73606 L
.52381 .73606 L
.52381 .7381 L
s
.52381 .73606 m
.54762 .73606 L
.54762 .72998 L
.52381 .72998 L
.52381 .73606 L
s
.52381 .72998 m
.54762 .72998 L
.54762 .71997 L
.52381 .71997 L
.52381 .72998 L
s
.52381 .71997 m
.54762 .71997 L
.54762 .7062 L
.52381 .7062 L
.52381 .71997 L
s
.52381 .7062 m
.54762 .7062 L
.54762 .68889 L
.52381 .68889 L
.52381 .7062 L
s
.52381 .68889 m
.54762 .68889 L
.54762 .66836 L
.52381 .66836 L
.52381 .68889 L
s
.52381 .66836 m
.54762 .66836 L
.54762 .64494 L
.52381 .64494 L
.52381 .66836 L
s
.52381 .64494 m
.54762 .64494 L
.54762 .61905 L
.52381 .61905 L
.52381 .64494 L
s
.52381 .61905 m
.54762 .61905 L
.54762 .59112 L
.52381 .59112 L
.52381 .61905 L
s
.52381 .59112 m
.54762 .59112 L
.54762 .56162 L
.52381 .56162 L
.52381 .59112 L
s
.52381 .56162 m
.54762 .56162 L
.54762 .53108 L
.52381 .53108 L
.52381 .56162 L
s
.52381 .53108 m
.54762 .53108 L
.54762 .5 L
.52381 .5 L
.52381 .53108 L
s
.52381 .5 m
.54762 .5 L
.54762 .46892 L
.52381 .46892 L
.52381 .5 L
s
.52381 .46892 m
.54762 .46892 L
.54762 .43838 L
.52381 .43838 L
.52381 .46892 L
s
.52381 .43838 m
.54762 .43838 L
.54762 .40888 L
.52381 .40888 L
.52381 .43838 L
s
.52381 .40888 m
.54762 .40888 L
.54762 .38095 L
.52381 .38095 L
.52381 .40888 L
s
.52381 .38095 m
.54762 .38095 L
.54762 .35506 L
.52381 .35506 L
.52381 .38095 L
s
.52381 .35506 m
.54762 .35506 L
.54762 .33164 L
.52381 .33164 L
.52381 .35506 L
s
.52381 .33164 m
.54762 .33164 L
.54762 .31111 L
.52381 .31111 L
.52381 .33164 L
s
.52381 .31111 m
.54762 .31111 L
.54762 .2938 L
.52381 .2938 L
.52381 .31111 L
s
.52381 .2938 m
.54762 .2938 L
.54762 .28003 L
.52381 .28003 L
.52381 .2938 L
s
.52381 .28003 m
.54762 .28003 L
.54762 .27002 L
.52381 .27002 L
.52381 .28003 L
s
.52381 .27002 m
.54762 .27002 L
.54762 .26394 L
.52381 .26394 L
.52381 .27002 L
s
.52381 .26394 m
.54762 .26394 L
.54762 .2619 L
.52381 .2619 L
.52381 .26394 L
s
.52381 .2619 m
.54762 .2619 L
.54762 .26394 L
.52381 .26394 L
.52381 .2619 L
s
.52381 .26394 m
.54762 .26394 L
.54762 .27002 L
.52381 .27002 L
.52381 .26394 L
s
.52381 .27002 m
.54762 .27002 L
.54762 .28003 L
.52381 .28003 L
.52381 .27002 L
s
.52381 .28003 m
.54762 .28003 L
.54762 .2938 L
.52381 .2938 L
.52381 .28003 L
s
.52381 .2938 m
.54762 .2938 L
.54762 .31111 L
.52381 .31111 L
.52381 .2938 L
s
.52381 .31111 m
.54762 .31111 L
.54762 .33164 L
.52381 .33164 L
.52381 .31111 L
s
.52381 .33164 m
.54762 .33164 L
.54762 .35506 L
.52381 .35506 L
.52381 .33164 L
s
.52381 .35506 m
.54762 .35506 L
.54762 .38095 L
.52381 .38095 L
.52381 .35506 L
s
.52381 .38095 m
.54762 .38095 L
.54762 .40888 L
.52381 .40888 L
.52381 .38095 L
s
.52381 .40888 m
.54762 .40888 L
.54762 .43838 L
.52381 .43838 L
.52381 .40888 L
s
.52381 .43838 m
.54762 .43838 L
.54762 .46892 L
.52381 .46892 L
.52381 .43838 L
s
.52381 .46892 m
.54762 .46892 L
.54762 .5 L
.52381 .5 L
.52381 .46892 L
s
.52381 .5 m
.54762 .5 L
.54762 .53108 L
.52381 .53108 L
.52381 .5 L
s
.52381 .53108 m
.54762 .53108 L
.54762 .56162 L
.52381 .56162 L
.52381 .53108 L
s
.52381 .56162 m
.54762 .56162 L
.54762 .59112 L
.52381 .59112 L
.52381 .56162 L
s
.52381 .59112 m
.54762 .59112 L
.54762 .61905 L
.52381 .61905 L
.52381 .59112 L
s
.52381 .61905 m
.54762 .61905 L
.54762 .64494 L
.52381 .64494 L
.52381 .61905 L
s
.52381 .64494 m
.54762 .64494 L
.54762 .66836 L
.52381 .66836 L
.52381 .64494 L
s
.52381 .66836 m
.54762 .66836 L
.54762 .68889 L
.52381 .68889 L
.52381 .66836 L
s
.52381 .68889 m
.54762 .68889 L
.54762 .7062 L
.52381 .7062 L
.52381 .68889 L
s
.52381 .7062 m
.54762 .7062 L
.54762 .71997 L
.52381 .71997 L
.52381 .7062 L
s
.52381 .71997 m
.54762 .71997 L
.54762 .72998 L
.52381 .72998 L
.52381 .71997 L
s
.52381 .72998 m
.54762 .72998 L
.54762 .73606 L
.52381 .73606 L
.52381 .72998 L
s
.52381 .73606 m
.54762 .73606 L
.54762 .7381 L
.52381 .7381 L
.52381 .73606 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.11905 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.52381 .5 L
s
0 0 0 r
2 Mabswid
.52381 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.52381 .5 m
.54762 .5 L
s
0 0 0 r
2 Mabswid
.54762 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.54762 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(LP)] .52381 .22381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool500000004
0?ooo`0000000000000007l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0R03oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo07h0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`030?ooo`<00000OP3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
O@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`280?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000O@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`270?ooo`<000000`3oool4000007h0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo3`00001j0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0407moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0QP3oool?000007X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo3`00001j0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo3`00001j0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo07P0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`04
07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool?000007X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo3`00001j0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`l00000
NP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo3`00001j0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`03
0000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool?000007X0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`03
0000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`l00000NP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`03
0000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool?000007X0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0
Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`03
0000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`800000101o
Ogl2000000D0Ogmo0P00001i0?ooo`8000001`3oool000H0oooo00<000000?ooo`3oool06@3ooomc
00WZ2P0300000009jPX02NX:00@02NX:00<0000000WZ2P09jPX0N009jPX2000000L0oooo00060?oo
o`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo07P0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`l00000NP3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo07P0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool?000007X0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`l00000NP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo3`00001j0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool?000007X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
3`00001j0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`03
0000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`l00000NP3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0
Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo3`00
001j0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo3`00001j0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0N03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`l00000NP3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo3`00001j0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool200000?l0oooo4@3oool00`000000oooo0?ooo`050?ooo`001P3ooooo000001@0
00001`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{\({1, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", \({1.`, 0.`, 0.`}\), ",", 
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 2}\), ",", 
            StyleBox["1.51926803816985422`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "100.`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 3}\), ",", 
            StyleBox["1.51926803816985422`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "40.1391404022400255`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.695468472160417316`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.718556611709094639`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({2, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "40.1391404022400255`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.695468472160417316`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.718556611709094639`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{Move[SingleRay[],10],
Move[LinearPolarizer[Function[0], 45, 50, CenterThickness->1], 50], \
Boundary[100]},PlotType->TopView];
ReadRays[sys,{{ComponentNumber,SurfaceNumber},RefractiveIndex,RayTilt,\
Intensity,Polarization}]\
\>", "Input",
  CellTags->"LinearPolarizer"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.50476 .22381 -6 -4.5 ]
[.50476 .22381 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.5 .2619 m
.50476 .2619 L
.50476 .30159 L
.5 .30159 L
.5 .2619 L
F
.5 .30159 m
.50476 .30159 L
.50476 .34127 L
.5 .34127 L
.5 .30159 L
F
.5 .34127 m
.50476 .34127 L
.50476 .38095 L
.5 .38095 L
.5 .34127 L
F
.5 .38095 m
.50476 .38095 L
.50476 .42063 L
.5 .42063 L
.5 .38095 L
F
.5 .42063 m
.50476 .42063 L
.50476 .46032 L
.5 .46032 L
.5 .42063 L
F
.5 .46032 m
.50476 .46032 L
.50476 .5 L
.5 .5 L
.5 .46032 L
F
.5 .5 m
.50476 .5 L
.50476 .53968 L
.5 .53968 L
.5 .5 L
F
.5 .53968 m
.50476 .53968 L
.50476 .57937 L
.5 .57937 L
.5 .53968 L
F
.5 .57937 m
.50476 .57937 L
.50476 .61905 L
.5 .61905 L
.5 .57937 L
F
.5 .61905 m
.50476 .61905 L
.50476 .65873 L
.5 .65873 L
.5 .61905 L
F
.5 .65873 m
.50476 .65873 L
.50476 .69841 L
.5 .69841 L
.5 .65873 L
F
.5 .69841 m
.50476 .69841 L
.50476 .7381 L
.5 .7381 L
.5 .69841 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.5 .2619 m
.5 .30159 L
.5 .34127 L
.5 .38095 L
.5 .42063 L
.5 .46032 L
.5 .5 L
.5 .53968 L
.5 .57937 L
.5 .61905 L
.5 .65873 L
.5 .69841 L
.5 .7381 L
.50476 .7381 L
.50476 .69841 L
.50476 .65873 L
.50476 .61905 L
.50476 .57937 L
.50476 .53968 L
.50476 .5 L
.50476 .46032 L
.50476 .42063 L
.50476 .38095 L
.50476 .34127 L
.50476 .30159 L
.50476 .2619 L
.5 .2619 L
s
.5 g
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
0 g
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.5 .5 L
s
.5 g
.50476 .2619 m
.50952 .2619 L
.50952 .30159 L
.50476 .30159 L
.50476 .2619 L
F
.50476 .30159 m
.50952 .30159 L
.50952 .34127 L
.50476 .34127 L
.50476 .30159 L
F
.50476 .34127 m
.50952 .34127 L
.50952 .38095 L
.50476 .38095 L
.50476 .34127 L
F
.50476 .38095 m
.50952 .38095 L
.50952 .42063 L
.50476 .42063 L
.50476 .38095 L
F
.50476 .42063 m
.50952 .42063 L
.50952 .46032 L
.50476 .46032 L
.50476 .42063 L
F
.50476 .46032 m
.50952 .46032 L
.50952 .5 L
.50476 .5 L
.50476 .46032 L
F
.50476 .5 m
.50952 .5 L
.50952 .53968 L
.50476 .53968 L
.50476 .5 L
F
.50476 .53968 m
.50952 .53968 L
.50952 .57937 L
.50476 .57937 L
.50476 .53968 L
F
.50476 .57937 m
.50952 .57937 L
.50952 .61905 L
.50476 .61905 L
.50476 .57937 L
F
.50476 .61905 m
.50952 .61905 L
.50952 .65873 L
.50476 .65873 L
.50476 .61905 L
F
.50476 .65873 m
.50952 .65873 L
.50952 .69841 L
.50476 .69841 L
.50476 .65873 L
F
.50476 .69841 m
.50952 .69841 L
.50952 .7381 L
.50476 .7381 L
.50476 .69841 L
F
0 g
.50476 .2619 m
.50476 .30159 L
.50476 .34127 L
.50476 .38095 L
.50476 .42063 L
.50476 .46032 L
.50476 .5 L
.50476 .53968 L
.50476 .57937 L
.50476 .61905 L
.50476 .65873 L
.50476 .69841 L
.50476 .7381 L
.50952 .7381 L
.50952 .69841 L
.50952 .65873 L
.50952 .61905 L
.50952 .57937 L
.50952 .53968 L
.50952 .5 L
.50952 .46032 L
.50952 .42063 L
.50952 .38095 L
.50952 .34127 L
.50952 .30159 L
.50952 .2619 L
.50476 .2619 L
s
.5 g
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
0 g
.50476 .5 m
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50476 .5 L
s
.5 .7381 m
.5 .73606 L
.5 .72998 L
.5 .71997 L
.5 .7062 L
.5 .68889 L
.5 .66836 L
.5 .64494 L
.5 .61905 L
.5 .59112 L
.5 .56162 L
.5 .53108 L
.5 .5 L
.5 .46892 L
.5 .43838 L
.5 .40888 L
.5 .38095 L
.5 .35506 L
.5 .33164 L
.5 .31111 L
.5 .2938 L
.5 .28003 L
.5 .27002 L
.5 .26394 L
.5 .2619 L
.5 .26394 L
.5 .27002 L
.5 .28003 L
.5 .2938 L
.5 .31111 L
.5 .33164 L
.5 .35506 L
.5 .38095 L
.5 .40888 L
.5 .43838 L
.5 .46892 L
.5 .5 L
.5 .53108 L
.5 .56162 L
.5 .59112 L
.5 .61905 L
.5 .64494 L
.5 .66836 L
.5 .68889 L
.5 .7062 L
.5 .71997 L
.5 .72998 L
.5 .73606 L
.5 .7381 L
s
.50476 .7381 m
.50476 .73606 L
.50476 .72998 L
.50476 .71997 L
.50476 .7062 L
.50476 .68889 L
.50476 .66836 L
.50476 .64494 L
.50476 .61905 L
.50476 .59112 L
.50476 .56162 L
.50476 .53108 L
.50476 .5 L
.50476 .46892 L
.50476 .43838 L
.50476 .40888 L
.50476 .38095 L
.50476 .35506 L
.50476 .33164 L
.50476 .31111 L
.50476 .2938 L
.50476 .28003 L
.50476 .27002 L
.50476 .26394 L
.50476 .2619 L
.50476 .26394 L
.50476 .27002 L
.50476 .28003 L
.50476 .2938 L
.50476 .31111 L
.50476 .33164 L
.50476 .35506 L
.50476 .38095 L
.50476 .40888 L
.50476 .43838 L
.50476 .46892 L
.50476 .5 L
.50476 .53108 L
.50476 .56162 L
.50476 .59112 L
.50476 .61905 L
.50476 .64494 L
.50476 .66836 L
.50476 .68889 L
.50476 .7062 L
.50476 .71997 L
.50476 .72998 L
.50476 .73606 L
.50476 .7381 L
s
.50952 .7381 m
.50952 .73606 L
.50952 .72998 L
.50952 .71997 L
.50952 .7062 L
.50952 .68889 L
.50952 .66836 L
.50952 .64494 L
.50952 .61905 L
.50952 .59112 L
.50952 .56162 L
.50952 .53108 L
.50952 .5 L
.50952 .46892 L
.50952 .43838 L
.50952 .40888 L
.50952 .38095 L
.50952 .35506 L
.50952 .33164 L
.50952 .31111 L
.50952 .2938 L
.50952 .28003 L
.50952 .27002 L
.50952 .26394 L
.50952 .2619 L
.50952 .26394 L
.50952 .27002 L
.50952 .28003 L
.50952 .2938 L
.50952 .31111 L
.50952 .33164 L
.50952 .35506 L
.50952 .38095 L
.50952 .40888 L
.50952 .43838 L
.50952 .46892 L
.50952 .5 L
.50952 .53108 L
.50952 .56162 L
.50952 .59112 L
.50952 .61905 L
.50952 .64494 L
.50952 .66836 L
.50952 .68889 L
.50952 .7062 L
.50952 .71997 L
.50952 .72998 L
.50952 .73606 L
.50952 .7381 L
s
.5 .7381 m
.50476 .7381 L
.50476 .73606 L
.5 .73606 L
.5 .7381 L
s
.5 .73606 m
.50476 .73606 L
.50476 .72998 L
.5 .72998 L
.5 .73606 L
s
.5 .72998 m
.50476 .72998 L
.50476 .71997 L
.5 .71997 L
.5 .72998 L
s
.5 .71997 m
.50476 .71997 L
.50476 .7062 L
.5 .7062 L
.5 .71997 L
s
.5 .7062 m
.50476 .7062 L
.50476 .68889 L
.5 .68889 L
.5 .7062 L
s
.5 .68889 m
.50476 .68889 L
.50476 .66836 L
.5 .66836 L
.5 .68889 L
s
.5 .66836 m
.50476 .66836 L
.50476 .64494 L
.5 .64494 L
.5 .66836 L
s
.5 .64494 m
.50476 .64494 L
.50476 .61905 L
.5 .61905 L
.5 .64494 L
s
.5 .61905 m
.50476 .61905 L
.50476 .59112 L
.5 .59112 L
.5 .61905 L
s
.5 .59112 m
.50476 .59112 L
.50476 .56162 L
.5 .56162 L
.5 .59112 L
s
.5 .56162 m
.50476 .56162 L
.50476 .53108 L
.5 .53108 L
.5 .56162 L
s
.5 .53108 m
.50476 .53108 L
.50476 .5 L
.5 .5 L
.5 .53108 L
s
.5 .5 m
.50476 .5 L
.50476 .46892 L
.5 .46892 L
.5 .5 L
s
.5 .46892 m
.50476 .46892 L
.50476 .43838 L
.5 .43838 L
.5 .46892 L
s
.5 .43838 m
.50476 .43838 L
.50476 .40888 L
.5 .40888 L
.5 .43838 L
s
.5 .40888 m
.50476 .40888 L
.50476 .38095 L
.5 .38095 L
.5 .40888 L
s
.5 .38095 m
.50476 .38095 L
.50476 .35506 L
.5 .35506 L
.5 .38095 L
s
.5 .35506 m
.50476 .35506 L
.50476 .33164 L
.5 .33164 L
.5 .35506 L
s
.5 .33164 m
.50476 .33164 L
.50476 .31111 L
.5 .31111 L
.5 .33164 L
s
.5 .31111 m
.50476 .31111 L
.50476 .2938 L
.5 .2938 L
.5 .31111 L
s
.5 .2938 m
.50476 .2938 L
.50476 .28003 L
.5 .28003 L
.5 .2938 L
s
.5 .28003 m
.50476 .28003 L
.50476 .27002 L
.5 .27002 L
.5 .28003 L
s
.5 .27002 m
.50476 .27002 L
.50476 .26394 L
.5 .26394 L
.5 .27002 L
s
.5 .26394 m
.50476 .26394 L
.50476 .2619 L
.5 .2619 L
.5 .26394 L
s
.5 .2619 m
.50476 .2619 L
.50476 .26394 L
.5 .26394 L
.5 .2619 L
s
.5 .26394 m
.50476 .26394 L
.50476 .27002 L
.5 .27002 L
.5 .26394 L
s
.5 .27002 m
.50476 .27002 L
.50476 .28003 L
.5 .28003 L
.5 .27002 L
s
.5 .28003 m
.50476 .28003 L
.50476 .2938 L
.5 .2938 L
.5 .28003 L
s
.5 .2938 m
.50476 .2938 L
.50476 .31111 L
.5 .31111 L
.5 .2938 L
s
.5 .31111 m
.50476 .31111 L
.50476 .33164 L
.5 .33164 L
.5 .31111 L
s
.5 .33164 m
.50476 .33164 L
.50476 .35506 L
.5 .35506 L
.5 .33164 L
s
.5 .35506 m
.50476 .35506 L
.50476 .38095 L
.5 .38095 L
.5 .35506 L
s
.5 .38095 m
.50476 .38095 L
.50476 .40888 L
.5 .40888 L
.5 .38095 L
s
.5 .40888 m
.50476 .40888 L
.50476 .43838 L
.5 .43838 L
.5 .40888 L
s
.5 .43838 m
.50476 .43838 L
.50476 .46892 L
.5 .46892 L
.5 .43838 L
s
.5 .46892 m
.50476 .46892 L
.50476 .5 L
.5 .5 L
.5 .46892 L
s
.5 .5 m
.50476 .5 L
.50476 .53108 L
.5 .53108 L
.5 .5 L
s
.5 .53108 m
.50476 .53108 L
.50476 .56162 L
.5 .56162 L
.5 .53108 L
s
.5 .56162 m
.50476 .56162 L
.50476 .59112 L
.5 .59112 L
.5 .56162 L
s
.5 .59112 m
.50476 .59112 L
.50476 .61905 L
.5 .61905 L
.5 .59112 L
s
.5 .61905 m
.50476 .61905 L
.50476 .64494 L
.5 .64494 L
.5 .61905 L
s
.5 .64494 m
.50476 .64494 L
.50476 .66836 L
.5 .66836 L
.5 .64494 L
s
.5 .66836 m
.50476 .66836 L
.50476 .68889 L
.5 .68889 L
.5 .66836 L
s
.5 .68889 m
.50476 .68889 L
.50476 .7062 L
.5 .7062 L
.5 .68889 L
s
.5 .7062 m
.50476 .7062 L
.50476 .71997 L
.5 .71997 L
.5 .7062 L
s
.5 .71997 m
.50476 .71997 L
.50476 .72998 L
.5 .72998 L
.5 .71997 L
s
.5 .72998 m
.50476 .72998 L
.50476 .73606 L
.5 .73606 L
.5 .72998 L
s
.5 .73606 m
.50476 .73606 L
.50476 .7381 L
.5 .7381 L
.5 .73606 L
s
.50476 .7381 m
.50952 .7381 L
.50952 .73606 L
.50476 .73606 L
.50476 .7381 L
s
.50476 .73606 m
.50952 .73606 L
.50952 .72998 L
.50476 .72998 L
.50476 .73606 L
s
.50476 .72998 m
.50952 .72998 L
.50952 .71997 L
.50476 .71997 L
.50476 .72998 L
s
.50476 .71997 m
.50952 .71997 L
.50952 .7062 L
.50476 .7062 L
.50476 .71997 L
s
.50476 .7062 m
.50952 .7062 L
.50952 .68889 L
.50476 .68889 L
.50476 .7062 L
s
.50476 .68889 m
.50952 .68889 L
.50952 .66836 L
.50476 .66836 L
.50476 .68889 L
s
.50476 .66836 m
.50952 .66836 L
.50952 .64494 L
.50476 .64494 L
.50476 .66836 L
s
.50476 .64494 m
.50952 .64494 L
.50952 .61905 L
.50476 .61905 L
.50476 .64494 L
s
.50476 .61905 m
.50952 .61905 L
.50952 .59112 L
.50476 .59112 L
.50476 .61905 L
s
.50476 .59112 m
.50952 .59112 L
.50952 .56162 L
.50476 .56162 L
.50476 .59112 L
s
.50476 .56162 m
.50952 .56162 L
.50952 .53108 L
.50476 .53108 L
.50476 .56162 L
s
.50476 .53108 m
.50952 .53108 L
.50952 .5 L
.50476 .5 L
.50476 .53108 L
s
.50476 .5 m
.50952 .5 L
.50952 .46892 L
.50476 .46892 L
.50476 .5 L
s
.50476 .46892 m
.50952 .46892 L
.50952 .43838 L
.50476 .43838 L
.50476 .46892 L
s
.50476 .43838 m
.50952 .43838 L
.50952 .40888 L
.50476 .40888 L
.50476 .43838 L
s
.50476 .40888 m
.50952 .40888 L
.50952 .38095 L
.50476 .38095 L
.50476 .40888 L
s
.50476 .38095 m
.50952 .38095 L
.50952 .35506 L
.50476 .35506 L
.50476 .38095 L
s
.50476 .35506 m
.50952 .35506 L
.50952 .33164 L
.50476 .33164 L
.50476 .35506 L
s
.50476 .33164 m
.50952 .33164 L
.50952 .31111 L
.50476 .31111 L
.50476 .33164 L
s
.50476 .31111 m
.50952 .31111 L
.50952 .2938 L
.50476 .2938 L
.50476 .31111 L
s
.50476 .2938 m
.50952 .2938 L
.50952 .28003 L
.50476 .28003 L
.50476 .2938 L
s
.50476 .28003 m
.50952 .28003 L
.50952 .27002 L
.50476 .27002 L
.50476 .28003 L
s
.50476 .27002 m
.50952 .27002 L
.50952 .26394 L
.50476 .26394 L
.50476 .27002 L
s
.50476 .26394 m
.50952 .26394 L
.50952 .2619 L
.50476 .2619 L
.50476 .26394 L
s
.50476 .2619 m
.50952 .2619 L
.50952 .26394 L
.50476 .26394 L
.50476 .2619 L
s
.50476 .26394 m
.50952 .26394 L
.50952 .27002 L
.50476 .27002 L
.50476 .26394 L
s
.50476 .27002 m
.50952 .27002 L
.50952 .28003 L
.50476 .28003 L
.50476 .27002 L
s
.50476 .28003 m
.50952 .28003 L
.50952 .2938 L
.50476 .2938 L
.50476 .28003 L
s
.50476 .2938 m
.50952 .2938 L
.50952 .31111 L
.50476 .31111 L
.50476 .2938 L
s
.50476 .31111 m
.50952 .31111 L
.50952 .33164 L
.50476 .33164 L
.50476 .31111 L
s
.50476 .33164 m
.50952 .33164 L
.50952 .35506 L
.50476 .35506 L
.50476 .33164 L
s
.50476 .35506 m
.50952 .35506 L
.50952 .38095 L
.50476 .38095 L
.50476 .35506 L
s
.50476 .38095 m
.50952 .38095 L
.50952 .40888 L
.50476 .40888 L
.50476 .38095 L
s
.50476 .40888 m
.50952 .40888 L
.50952 .43838 L
.50476 .43838 L
.50476 .40888 L
s
.50476 .43838 m
.50952 .43838 L
.50952 .46892 L
.50476 .46892 L
.50476 .43838 L
s
.50476 .46892 m
.50952 .46892 L
.50952 .5 L
.50476 .5 L
.50476 .46892 L
s
.50476 .5 m
.50952 .5 L
.50952 .53108 L
.50476 .53108 L
.50476 .5 L
s
.50476 .53108 m
.50952 .53108 L
.50952 .56162 L
.50476 .56162 L
.50476 .53108 L
s
.50476 .56162 m
.50952 .56162 L
.50952 .59112 L
.50476 .59112 L
.50476 .56162 L
s
.50476 .59112 m
.50952 .59112 L
.50952 .61905 L
.50476 .61905 L
.50476 .59112 L
s
.50476 .61905 m
.50952 .61905 L
.50952 .64494 L
.50476 .64494 L
.50476 .61905 L
s
.50476 .64494 m
.50952 .64494 L
.50952 .66836 L
.50476 .66836 L
.50476 .64494 L
s
.50476 .66836 m
.50952 .66836 L
.50952 .68889 L
.50476 .68889 L
.50476 .66836 L
s
.50476 .68889 m
.50952 .68889 L
.50952 .7062 L
.50476 .7062 L
.50476 .68889 L
s
.50476 .7062 m
.50952 .7062 L
.50952 .71997 L
.50476 .71997 L
.50476 .7062 L
s
.50476 .71997 m
.50952 .71997 L
.50952 .72998 L
.50476 .72998 L
.50476 .71997 L
s
.50476 .72998 m
.50952 .72998 L
.50952 .73606 L
.50476 .73606 L
.50476 .72998 L
s
.50476 .73606 m
.50952 .73606 L
.50952 .7381 L
.50476 .7381 L
.50476 .73606 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.11905 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.50476 .5 L
s
0 0 0 r
2 Mabswid
.50476 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.50476 .5 m
.50952 .5 L
s
0 0 0 r
2 Mabswid
.50952 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(LP)] .50476 .22381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool500000004
0?ooo`0000000000000008D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0PP3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo08@0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo08@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`030?ooo`<00000Q03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`220?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
P`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000P`3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`210?ooo`<000000`3oool4000008@0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo100000250?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`24
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1o
Ogl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo100000250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl00000
0?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P00
00000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?oo
o`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P000000
0`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`24
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1o
Ogl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl0
00000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl00000
0?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P00
00000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl00000
0?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo1000
00250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P000000
0`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?oo
o`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P000000
0`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`24
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1o
Ogl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`24
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo100000250?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl0
00000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl0
00000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo100000240?ooo`8000001`3oool000H0oooo00<000000?ooo`3oool06@3ooom_
00WZ2P0300000009jPX02NX:08<02NX:0P0000070?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo
0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`@00000Q@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000
003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80
000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000
003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80
000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`@00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003o
ool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`800000
00<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`@00000Q@3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0
Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0
Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0
Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`@00000Q@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo
0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo
0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`@00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000
003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80
000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`@00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003o
ool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`800000
00<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`@00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0
Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`@00000Q@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo
0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`@00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`@00000Q@3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003o
ool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`@00000
Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo0P00003o0?oooa40oooo00<000000?oo
o`3oool01@3oool000H0ooooo`00000D000000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{\({1, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", \({1.`, 0.`, 0.`}\), ",", 
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 2}\), ",", 
            StyleBox["1.52584130859896438`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "100.`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 3}\), ",", 
            StyleBox["1.52584130859896438`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "50.0000000000000177`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.707106781186547461`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.70710678118654755`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({2, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "50.0000000000000177`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.707106781186547461`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.70710678118654755`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{Move[SingleRay[],10],
Move[LinearPolarizer[45,50,ComponentMedium->HN38],50], \
Boundary[100]},PlotType->TopView];
ReadRays[sys,{{ComponentNumber,SurfaceNumber},RefractiveIndex,RayTilt,\
Intensity,Polarization}]\
\>", "Input",
  CellTags->"LinearPolarizer"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.5 .22381 -6 -4.5 ]
[.5 .22381 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.5 .2619 m
.5 .2619 L
.5 .30159 L
.5 .30159 L
.5 .2619 L
F
.5 .30159 m
.5 .30159 L
.5 .34127 L
.5 .34127 L
.5 .30159 L
F
.5 .34127 m
.5 .34127 L
.5 .38095 L
.5 .38095 L
.5 .34127 L
F
.5 .38095 m
.5 .38095 L
.5 .42063 L
.5 .42063 L
.5 .38095 L
F
.5 .42063 m
.5 .42063 L
.5 .46032 L
.5 .46032 L
.5 .42063 L
F
.5 .46032 m
.5 .46032 L
.5 .5 L
.5 .5 L
.5 .46032 L
F
.5 .5 m
.5 .5 L
.5 .53968 L
.5 .53968 L
.5 .5 L
F
.5 .53968 m
.5 .53968 L
.5 .57937 L
.5 .57937 L
.5 .53968 L
F
.5 .57937 m
.5 .57937 L
.5 .61905 L
.5 .61905 L
.5 .57937 L
F
.5 .61905 m
.5 .61905 L
.5 .65873 L
.5 .65873 L
.5 .61905 L
F
.5 .65873 m
.5 .65873 L
.5 .69841 L
.5 .69841 L
.5 .65873 L
F
.5 .69841 m
.5 .69841 L
.5 .7381 L
.5 .7381 L
.5 .69841 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.5 .2619 m
.5 .30159 L
.5 .34127 L
.5 .38095 L
.5 .42063 L
.5 .46032 L
.5 .5 L
.5 .53968 L
.5 .57937 L
.5 .61905 L
.5 .65873 L
.5 .69841 L
.5 .7381 L
.5 .7381 L
.5 .69841 L
.5 .65873 L
.5 .61905 L
.5 .57937 L
.5 .53968 L
.5 .5 L
.5 .46032 L
.5 .42063 L
.5 .38095 L
.5 .34127 L
.5 .30159 L
.5 .2619 L
.5 .2619 L
s
.5 g
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
0 g
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
s
.5 .7381 m
.5 .73606 L
.5 .72998 L
.5 .71997 L
.5 .7062 L
.5 .68889 L
.5 .66836 L
.5 .64494 L
.5 .61905 L
.5 .59112 L
.5 .56162 L
.5 .53108 L
.5 .5 L
.5 .46892 L
.5 .43838 L
.5 .40888 L
.5 .38095 L
.5 .35506 L
.5 .33164 L
.5 .31111 L
.5 .2938 L
.5 .28003 L
.5 .27002 L
.5 .26394 L
.5 .2619 L
.5 .26394 L
.5 .27002 L
.5 .28003 L
.5 .2938 L
.5 .31111 L
.5 .33164 L
.5 .35506 L
.5 .38095 L
.5 .40888 L
.5 .43838 L
.5 .46892 L
.5 .5 L
.5 .53108 L
.5 .56162 L
.5 .59112 L
.5 .61905 L
.5 .64494 L
.5 .66836 L
.5 .68889 L
.5 .7062 L
.5 .71997 L
.5 .72998 L
.5 .73606 L
.5 .7381 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.11905 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(LP)] .5 .22381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P03oool500000004
0?ooo`0000000000000008H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0P@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`030?ooo`<00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000Q03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`200?ooo`<000000`3oool4000008D0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`800000QP3oool2000000L0oooo0006
0?ooo`030000003oool0oooo01T0oooom@09jPX2000000L0oooo00060?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`800000o`3ooolA0?oo
o`030000003oool0oooo00D0oooo00060?ooool00000500000070?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{\({1, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", \({1.`, 0.`, 0.`}\), ",", 
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({2, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", \({1.`, 0.`, 0.`}\), ",", 
            "40.1391404022400255`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.695468472160417316`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.718556611709094639`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{Move[SingleRay[],10],
Move[LinearPolarizer[45,50,ComponentMedium->HN38,CenterThickness->1],50], \
Boundary[100]},PlotType->TopView];
ReadRays[sys,{{ComponentNumber,SurfaceNumber},RefractiveIndex,RayTilt,\
Intensity,Polarization}]\
\>", "Input",
  CellTags->"LinearPolarizer"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.50476 .22381 -6 -4.5 ]
[.50476 .22381 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.5 .2619 m
.50476 .2619 L
.50476 .30159 L
.5 .30159 L
.5 .2619 L
F
.5 .30159 m
.50476 .30159 L
.50476 .34127 L
.5 .34127 L
.5 .30159 L
F
.5 .34127 m
.50476 .34127 L
.50476 .38095 L
.5 .38095 L
.5 .34127 L
F
.5 .38095 m
.50476 .38095 L
.50476 .42063 L
.5 .42063 L
.5 .38095 L
F
.5 .42063 m
.50476 .42063 L
.50476 .46032 L
.5 .46032 L
.5 .42063 L
F
.5 .46032 m
.50476 .46032 L
.50476 .5 L
.5 .5 L
.5 .46032 L
F
.5 .5 m
.50476 .5 L
.50476 .53968 L
.5 .53968 L
.5 .5 L
F
.5 .53968 m
.50476 .53968 L
.50476 .57937 L
.5 .57937 L
.5 .53968 L
F
.5 .57937 m
.50476 .57937 L
.50476 .61905 L
.5 .61905 L
.5 .57937 L
F
.5 .61905 m
.50476 .61905 L
.50476 .65873 L
.5 .65873 L
.5 .61905 L
F
.5 .65873 m
.50476 .65873 L
.50476 .69841 L
.5 .69841 L
.5 .65873 L
F
.5 .69841 m
.50476 .69841 L
.50476 .7381 L
.5 .7381 L
.5 .69841 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.5 .2619 m
.5 .30159 L
.5 .34127 L
.5 .38095 L
.5 .42063 L
.5 .46032 L
.5 .5 L
.5 .53968 L
.5 .57937 L
.5 .61905 L
.5 .65873 L
.5 .69841 L
.5 .7381 L
.50476 .7381 L
.50476 .69841 L
.50476 .65873 L
.50476 .61905 L
.50476 .57937 L
.50476 .53968 L
.50476 .5 L
.50476 .46032 L
.50476 .42063 L
.50476 .38095 L
.50476 .34127 L
.50476 .30159 L
.50476 .2619 L
.5 .2619 L
s
.5 g
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
0 g
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.5 .5 L
s
.5 g
.50476 .2619 m
.50952 .2619 L
.50952 .30159 L
.50476 .30159 L
.50476 .2619 L
F
.50476 .30159 m
.50952 .30159 L
.50952 .34127 L
.50476 .34127 L
.50476 .30159 L
F
.50476 .34127 m
.50952 .34127 L
.50952 .38095 L
.50476 .38095 L
.50476 .34127 L
F
.50476 .38095 m
.50952 .38095 L
.50952 .42063 L
.50476 .42063 L
.50476 .38095 L
F
.50476 .42063 m
.50952 .42063 L
.50952 .46032 L
.50476 .46032 L
.50476 .42063 L
F
.50476 .46032 m
.50952 .46032 L
.50952 .5 L
.50476 .5 L
.50476 .46032 L
F
.50476 .5 m
.50952 .5 L
.50952 .53968 L
.50476 .53968 L
.50476 .5 L
F
.50476 .53968 m
.50952 .53968 L
.50952 .57937 L
.50476 .57937 L
.50476 .53968 L
F
.50476 .57937 m
.50952 .57937 L
.50952 .61905 L
.50476 .61905 L
.50476 .57937 L
F
.50476 .61905 m
.50952 .61905 L
.50952 .65873 L
.50476 .65873 L
.50476 .61905 L
F
.50476 .65873 m
.50952 .65873 L
.50952 .69841 L
.50476 .69841 L
.50476 .65873 L
F
.50476 .69841 m
.50952 .69841 L
.50952 .7381 L
.50476 .7381 L
.50476 .69841 L
F
0 g
.50476 .2619 m
.50476 .30159 L
.50476 .34127 L
.50476 .38095 L
.50476 .42063 L
.50476 .46032 L
.50476 .5 L
.50476 .53968 L
.50476 .57937 L
.50476 .61905 L
.50476 .65873 L
.50476 .69841 L
.50476 .7381 L
.50952 .7381 L
.50952 .69841 L
.50952 .65873 L
.50952 .61905 L
.50952 .57937 L
.50952 .53968 L
.50952 .5 L
.50952 .46032 L
.50952 .42063 L
.50952 .38095 L
.50952 .34127 L
.50952 .30159 L
.50952 .2619 L
.50476 .2619 L
s
.5 g
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
0 g
.50476 .5 m
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50476 .5 L
s
.5 .7381 m
.50476 .7381 L
.50476 .73606 L
.5 .73606 L
.5 .7381 L
s
.5 .73606 m
.50476 .73606 L
.50476 .72998 L
.5 .72998 L
.5 .73606 L
s
.5 .72998 m
.50476 .72998 L
.50476 .71997 L
.5 .71997 L
.5 .72998 L
s
.5 .71997 m
.50476 .71997 L
.50476 .7062 L
.5 .7062 L
.5 .71997 L
s
.5 .7062 m
.50476 .7062 L
.50476 .68889 L
.5 .68889 L
.5 .7062 L
s
.5 .68889 m
.50476 .68889 L
.50476 .66836 L
.5 .66836 L
.5 .68889 L
s
.5 .66836 m
.50476 .66836 L
.50476 .64494 L
.5 .64494 L
.5 .66836 L
s
.5 .64494 m
.50476 .64494 L
.50476 .61905 L
.5 .61905 L
.5 .64494 L
s
.5 .61905 m
.50476 .61905 L
.50476 .59112 L
.5 .59112 L
.5 .61905 L
s
.5 .59112 m
.50476 .59112 L
.50476 .56162 L
.5 .56162 L
.5 .59112 L
s
.5 .56162 m
.50476 .56162 L
.50476 .53108 L
.5 .53108 L
.5 .56162 L
s
.5 .53108 m
.50476 .53108 L
.50476 .5 L
.5 .5 L
.5 .53108 L
s
.5 .5 m
.50476 .5 L
.50476 .46892 L
.5 .46892 L
.5 .5 L
s
.5 .46892 m
.50476 .46892 L
.50476 .43838 L
.5 .43838 L
.5 .46892 L
s
.5 .43838 m
.50476 .43838 L
.50476 .40888 L
.5 .40888 L
.5 .43838 L
s
.5 .40888 m
.50476 .40888 L
.50476 .38095 L
.5 .38095 L
.5 .40888 L
s
.5 .38095 m
.50476 .38095 L
.50476 .35506 L
.5 .35506 L
.5 .38095 L
s
.5 .35506 m
.50476 .35506 L
.50476 .33164 L
.5 .33164 L
.5 .35506 L
s
.5 .33164 m
.50476 .33164 L
.50476 .31111 L
.5 .31111 L
.5 .33164 L
s
.5 .31111 m
.50476 .31111 L
.50476 .2938 L
.5 .2938 L
.5 .31111 L
s
.5 .2938 m
.50476 .2938 L
.50476 .28003 L
.5 .28003 L
.5 .2938 L
s
.5 .28003 m
.50476 .28003 L
.50476 .27002 L
.5 .27002 L
.5 .28003 L
s
.5 .27002 m
.50476 .27002 L
.50476 .26394 L
.5 .26394 L
.5 .27002 L
s
.5 .26394 m
.50476 .26394 L
.50476 .2619 L
.5 .2619 L
.5 .26394 L
s
.5 .2619 m
.50476 .2619 L
.50476 .26394 L
.5 .26394 L
.5 .2619 L
s
.5 .26394 m
.50476 .26394 L
.50476 .27002 L
.5 .27002 L
.5 .26394 L
s
.5 .27002 m
.50476 .27002 L
.50476 .28003 L
.5 .28003 L
.5 .27002 L
s
.5 .28003 m
.50476 .28003 L
.50476 .2938 L
.5 .2938 L
.5 .28003 L
s
.5 .2938 m
.50476 .2938 L
.50476 .31111 L
.5 .31111 L
.5 .2938 L
s
.5 .31111 m
.50476 .31111 L
.50476 .33164 L
.5 .33164 L
.5 .31111 L
s
.5 .33164 m
.50476 .33164 L
.50476 .35506 L
.5 .35506 L
.5 .33164 L
s
.5 .35506 m
.50476 .35506 L
.50476 .38095 L
.5 .38095 L
.5 .35506 L
s
.5 .38095 m
.50476 .38095 L
.50476 .40888 L
.5 .40888 L
.5 .38095 L
s
.5 .40888 m
.50476 .40888 L
.50476 .43838 L
.5 .43838 L
.5 .40888 L
s
.5 .43838 m
.50476 .43838 L
.50476 .46892 L
.5 .46892 L
.5 .43838 L
s
.5 .46892 m
.50476 .46892 L
.50476 .5 L
.5 .5 L
.5 .46892 L
s
.5 .5 m
.50476 .5 L
.50476 .53108 L
.5 .53108 L
.5 .5 L
s
.5 .53108 m
.50476 .53108 L
.50476 .56162 L
.5 .56162 L
.5 .53108 L
s
.5 .56162 m
.50476 .56162 L
.50476 .59112 L
.5 .59112 L
.5 .56162 L
s
.5 .59112 m
.50476 .59112 L
.50476 .61905 L
.5 .61905 L
.5 .59112 L
s
.5 .61905 m
.50476 .61905 L
.50476 .64494 L
.5 .64494 L
.5 .61905 L
s
.5 .64494 m
.50476 .64494 L
.50476 .66836 L
.5 .66836 L
.5 .64494 L
s
.5 .66836 m
.50476 .66836 L
.50476 .68889 L
.5 .68889 L
.5 .66836 L
s
.5 .68889 m
.50476 .68889 L
.50476 .7062 L
.5 .7062 L
.5 .68889 L
s
.5 .7062 m
.50476 .7062 L
.50476 .71997 L
.5 .71997 L
.5 .7062 L
s
.5 .71997 m
.50476 .71997 L
.50476 .72998 L
.5 .72998 L
.5 .71997 L
s
.5 .72998 m
.50476 .72998 L
.50476 .73606 L
.5 .73606 L
.5 .72998 L
s
.5 .73606 m
.50476 .73606 L
.50476 .7381 L
.5 .7381 L
.5 .73606 L
s
.50476 .7381 m
.50952 .7381 L
.50952 .73606 L
.50476 .73606 L
.50476 .7381 L
s
.50476 .73606 m
.50952 .73606 L
.50952 .72998 L
.50476 .72998 L
.50476 .73606 L
s
.50476 .72998 m
.50952 .72998 L
.50952 .71997 L
.50476 .71997 L
.50476 .72998 L
s
.50476 .71997 m
.50952 .71997 L
.50952 .7062 L
.50476 .7062 L
.50476 .71997 L
s
.50476 .7062 m
.50952 .7062 L
.50952 .68889 L
.50476 .68889 L
.50476 .7062 L
s
.50476 .68889 m
.50952 .68889 L
.50952 .66836 L
.50476 .66836 L
.50476 .68889 L
s
.50476 .66836 m
.50952 .66836 L
.50952 .64494 L
.50476 .64494 L
.50476 .66836 L
s
.50476 .64494 m
.50952 .64494 L
.50952 .61905 L
.50476 .61905 L
.50476 .64494 L
s
.50476 .61905 m
.50952 .61905 L
.50952 .59112 L
.50476 .59112 L
.50476 .61905 L
s
.50476 .59112 m
.50952 .59112 L
.50952 .56162 L
.50476 .56162 L
.50476 .59112 L
s
.50476 .56162 m
.50952 .56162 L
.50952 .53108 L
.50476 .53108 L
.50476 .56162 L
s
.50476 .53108 m
.50952 .53108 L
.50952 .5 L
.50476 .5 L
.50476 .53108 L
s
.50476 .5 m
.50952 .5 L
.50952 .46892 L
.50476 .46892 L
.50476 .5 L
s
.50476 .46892 m
.50952 .46892 L
.50952 .43838 L
.50476 .43838 L
.50476 .46892 L
s
.50476 .43838 m
.50952 .43838 L
.50952 .40888 L
.50476 .40888 L
.50476 .43838 L
s
.50476 .40888 m
.50952 .40888 L
.50952 .38095 L
.50476 .38095 L
.50476 .40888 L
s
.50476 .38095 m
.50952 .38095 L
.50952 .35506 L
.50476 .35506 L
.50476 .38095 L
s
.50476 .35506 m
.50952 .35506 L
.50952 .33164 L
.50476 .33164 L
.50476 .35506 L
s
.50476 .33164 m
.50952 .33164 L
.50952 .31111 L
.50476 .31111 L
.50476 .33164 L
s
.50476 .31111 m
.50952 .31111 L
.50952 .2938 L
.50476 .2938 L
.50476 .31111 L
s
.50476 .2938 m
.50952 .2938 L
.50952 .28003 L
.50476 .28003 L
.50476 .2938 L
s
.50476 .28003 m
.50952 .28003 L
.50952 .27002 L
.50476 .27002 L
.50476 .28003 L
s
.50476 .27002 m
.50952 .27002 L
.50952 .26394 L
.50476 .26394 L
.50476 .27002 L
s
.50476 .26394 m
.50952 .26394 L
.50952 .2619 L
.50476 .2619 L
.50476 .26394 L
s
.50476 .2619 m
.50952 .2619 L
.50952 .26394 L
.50476 .26394 L
.50476 .2619 L
s
.50476 .26394 m
.50952 .26394 L
.50952 .27002 L
.50476 .27002 L
.50476 .26394 L
s
.50476 .27002 m
.50952 .27002 L
.50952 .28003 L
.50476 .28003 L
.50476 .27002 L
s
.50476 .28003 m
.50952 .28003 L
.50952 .2938 L
.50476 .2938 L
.50476 .28003 L
s
.50476 .2938 m
.50952 .2938 L
.50952 .31111 L
.50476 .31111 L
.50476 .2938 L
s
.50476 .31111 m
.50952 .31111 L
.50952 .33164 L
.50476 .33164 L
.50476 .31111 L
s
.50476 .33164 m
.50952 .33164 L
.50952 .35506 L
.50476 .35506 L
.50476 .33164 L
s
.50476 .35506 m
.50952 .35506 L
.50952 .38095 L
.50476 .38095 L
.50476 .35506 L
s
.50476 .38095 m
.50952 .38095 L
.50952 .40888 L
.50476 .40888 L
.50476 .38095 L
s
.50476 .40888 m
.50952 .40888 L
.50952 .43838 L
.50476 .43838 L
.50476 .40888 L
s
.50476 .43838 m
.50952 .43838 L
.50952 .46892 L
.50476 .46892 L
.50476 .43838 L
s
.50476 .46892 m
.50952 .46892 L
.50952 .5 L
.50476 .5 L
.50476 .46892 L
s
.50476 .5 m
.50952 .5 L
.50952 .53108 L
.50476 .53108 L
.50476 .5 L
s
.50476 .53108 m
.50952 .53108 L
.50952 .56162 L
.50476 .56162 L
.50476 .53108 L
s
.50476 .56162 m
.50952 .56162 L
.50952 .59112 L
.50476 .59112 L
.50476 .56162 L
s
.50476 .59112 m
.50952 .59112 L
.50952 .61905 L
.50476 .61905 L
.50476 .59112 L
s
.50476 .61905 m
.50952 .61905 L
.50952 .64494 L
.50476 .64494 L
.50476 .61905 L
s
.50476 .64494 m
.50952 .64494 L
.50952 .66836 L
.50476 .66836 L
.50476 .64494 L
s
.50476 .66836 m
.50952 .66836 L
.50952 .68889 L
.50476 .68889 L
.50476 .66836 L
s
.50476 .68889 m
.50952 .68889 L
.50952 .7062 L
.50476 .7062 L
.50476 .68889 L
s
.50476 .7062 m
.50952 .7062 L
.50952 .71997 L
.50476 .71997 L
.50476 .7062 L
s
.50476 .71997 m
.50952 .71997 L
.50952 .72998 L
.50476 .72998 L
.50476 .71997 L
s
.50476 .72998 m
.50952 .72998 L
.50952 .73606 L
.50476 .73606 L
.50476 .72998 L
s
.50476 .73606 m
.50952 .73606 L
.50952 .7381 L
.50476 .7381 L
.50476 .73606 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.11905 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.50476 .5 L
s
0 0 0 r
2 Mabswid
.50476 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.50476 .5 m
.50952 .5 L
s
0 0 0 r
2 Mabswid
.50952 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(LP)] .50476 .22381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{370, 370},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005b0001LR000`400?l00000o`00003oo`3ooomc
0?ooo`00o`3ooomc0?ooo`00o`3ooomc0?ooo`00o`3ooomc0?ooo`00o`3ooomc0?ooo`00o`3ooomc
0?ooo`00o`3ooomc0?ooo`00o`3ooomc0?ooo`00o`3ooomc0?ooo`00203ooooo0000068000002@3o
ool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?oo
o`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000
oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0
o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3o
ool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<00000
0?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo
00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00
203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<0
00000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0
oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oo
oeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`03
0000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo
0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3o
ool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?oo
o`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000
oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0
o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3o
ool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<00000
0?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo
00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00
203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<0
00000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0
oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oo
oeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`03
0000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo
0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3o
ool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?oo
o`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000
oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0
o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3o
ool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<00000
0?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo
00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00
203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<0
00000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0
oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oo
oeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`03
0000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo
0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3o
ool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?oo
o`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000
oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0
o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3o
ool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<00000
0?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo
00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00
203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<0
00000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0
oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oo
oeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`03
0000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo
0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3o
ool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?oo
o`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000
oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0
o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3o
ool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<00000
0?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo
00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00
203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<0
00000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0
oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2Y0?oo
o`D0000000@0oooo0000000000000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`00
0000oooo0?ooo`2Z0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0ZP3oool0
0`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000
oooo0?ooo`2Z0?ooo`030000003oool0oooo00<0oooo0`00002Z0?ooo`030000003oool0oooo00L0
oooo00080?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`00002Y0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0:X0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00002Y0?ooo`030000003oool0oooo00L0
oooo00080?ooo`030000003oool0oooo0:T0oooo0`0000030?ooo`@00000ZP3oool00`000000oooo
0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3o
ool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?oo
o`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000
oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0
o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3o
ool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<00000
0?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo
00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00
203oool00`000000oooo0?ooo`2]0?ooo`D00000Z`3oool00`000000oooo0?ooo`070?ooo`00203o
ool00`000000oooo0?ooo`2]0?ooo`D00000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool0
0`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?oo
o`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`D00000Z`3oool00`000000oooo0?ooo`07
0?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool0
0`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl00000
07moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?oo
o`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`00
0000oooo0?ooo`2]0?ooo`D00000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000
oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?oo
o`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`00
0000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007mo
O`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`05
0000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000
oooo0?ooo`2]0?ooo`D00000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo
0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00
203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000
oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`00
0000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000
001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo
0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00
203oool00`000000oooo0?ooo`2]0?ooo`D00000Z`3oool00`000000oooo0?ooo`070?ooo`00203o
ool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo
0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000
Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001o
Ogl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?oo
o`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203o
ool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo
0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000
Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001o
Ogl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?oo
o`2]0?ooo`D00000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]
0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool0
0`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?oo
o`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3o
ool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0
000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]
0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool0
0`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?oo
o`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3o
ool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0
000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]
0?ooo`D00000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?oo
o`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`00
0000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`07
0?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool0
0`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl00000
07moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?oo
o`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`00
0000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`07
0?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool0
0`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl00000
07moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?oo
o`D00000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`05
0000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000
oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?oo
o`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`00
0000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007mo
O`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`05
0000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000
oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?oo
o`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`00
0000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007mo
O`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`05
0000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000
oooo0?ooo`2]0?ooo`D00000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo
0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00
203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000
oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`00
0000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000
001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo
0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00
203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000
oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`00
0000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000
001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo
0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00
203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000
oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`D00000Z`3oool00`000000oooo
0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000
Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001o
Ogl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?oo
o`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203o
ool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo
0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000
Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001o
Ogl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?oo
o`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203o
ool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo
0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000
Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001o
Ogl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?oo
o`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203o
ool00`000000oooo0?ooo`2]0?ooo`D00000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool0
0`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?oo
o`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3o
ool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0
000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]
0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool0
0`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?oo
o`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3o
ool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`050000001oOgl0
000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2]
0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`070?ooo`00203oool0
0`000000oooo0?ooo`2]0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?oo
o`070?ooo`00203oool00`000000oooo0?ooo`2]0?ooo`D00000ZP3oool2000000T0oooo00080?oo
o`030000003oool0oooo0200ooooSP09jPX00`0000002NX:0000002[00WZ2P8000002@3oool000P0
oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?oo
o`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl00000
0:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000
Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3o
ool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0
oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?oo
o`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl00000
0:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000
Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3o
ool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0
oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?oo
o`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl00000
0:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool500000:/0
oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo
0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0
[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo
00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3o
ool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0
oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo
0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0
[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo
00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3o
ool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0
oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo
0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0
[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo
00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3o
ool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool500000:/0oooo00<000000?ooo`3oool0
1`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo
00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000
001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3o
ool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<0
00000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool0
1`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo
00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000
001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3o
ool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<0
00000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool0
1`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo
00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000
001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3o
ool500000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool0
1@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<00000
0?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3o
ool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<0
00000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001o
Ogl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool0
1@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<00000
0?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3o
ool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<0
00000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001o
Ogl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool0
1@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<00000
0?ooo`3oool0[@3oool500000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?oo
o`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool0
00P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<00000
0?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl0
00000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@00
0000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?oo
o`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool0
00P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<00000
0?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl0
00000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@00
0000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?oo
o`3oool0[@3oool500000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3o
ool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0
oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?oo
o`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl00000
0:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000
Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3o
ool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0
oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?oo
o`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl00000
0:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000
Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3o
ool0[@3oool500000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0
[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo
00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3o
ool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0
oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo
0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0
[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo
00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3o
ool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0
oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool500000:/0oooo
00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000
001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3o
ool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<0
00000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool0
1`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo
00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000
001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3o
ool500000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool0
1@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<00000
0?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3o
ool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<0
00000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001o
Ogl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool5
00000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@00
0000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?oo
o`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<000000?ooo`3oool01`3oool0
00P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl000000:/0oooo00<00000
0?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool500000:/0oooo00<000000?oo
o`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool01@000000Ogmo0000001oOgl00000
0:/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool500000:/0
oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0[@3oool500000:/0oooo
00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003o
ool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`07
0?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0
oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000
003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?oo
o`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN
0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`00
0000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3o
ool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo
00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool0
0`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?oo
o`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0
ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo
00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003o
ool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`07
0?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0
oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000
003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?oo
o`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN
0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`00
0000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3o
ool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo
00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool0
0`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?oo
o`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0
ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo
00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003o
ool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`07
0?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0
oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000
003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?oo
o`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN
0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`00
0000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3o
ool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo
00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool0
0`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?oo
o`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0
ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo
00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003o
ool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`07
0?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0
oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000
003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?oo
o`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN
0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`00
0000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3o
ool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo
00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool0
0`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?oo
o`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0
ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo
00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003o
ool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`07
0?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0
oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000
003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?oo
o`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN
0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`00
0000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3o
ool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo
00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool0
0`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?oo
o`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0
ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo
00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003o
ool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`07
0?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0
oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000
003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?oo
o`3o0?oooeh0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN
0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`00
0000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3o
ool01`3oool000P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00L0oooo
00080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`070?ooo`00203oool2
00000?l0ooooG`3oool00`000000oooo0?ooo`070?ooo`00203ooooo0000068000002@3oool00?l0
ooooL`3oool00?l0ooooL`3oool00?l0ooooL`3oool00?l0ooooL`3oool00?l0ooooL`3oool00?l0
ooooL`3oool00?l0ooooL`3oool00?l0ooooL`3oool00001\
\>"],
  ImageRangeCache->{{{0, 369}, {369, 0}} -> {-2.50052, -52.5005, 0.284556, \
0.284556}},
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{\({1, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", \({1.`, 0.`, 0.`}\), ",", 
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 2}\), ",", 
            StyleBox["1.51926803816985422`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "100.`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 3}\), ",", 
            StyleBox["1.51926803816985422`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "40.1391404022400255`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.695468472160417316`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.718556611709094639`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({2, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "40.1391404022400255`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.695468472160417316`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.718556611709094639`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{Move[SingleRay[],10],
Move[LinearPolarizer[45,50,CenterThickness->1],50], \
Boundary[100]},PlotType->TopView];
ReadRays[sys,{{ComponentNumber,SurfaceNumber},RefractiveIndex,RayTilt,\
Intensity,Polarization}]\
\>", "Input",
  CellTags->"LinearPolarizer"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.50476 .22381 -6 -4.5 ]
[.50476 .22381 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.5 .2619 m
.50476 .2619 L
.50476 .30159 L
.5 .30159 L
.5 .2619 L
F
.5 .30159 m
.50476 .30159 L
.50476 .34127 L
.5 .34127 L
.5 .30159 L
F
.5 .34127 m
.50476 .34127 L
.50476 .38095 L
.5 .38095 L
.5 .34127 L
F
.5 .38095 m
.50476 .38095 L
.50476 .42063 L
.5 .42063 L
.5 .38095 L
F
.5 .42063 m
.50476 .42063 L
.50476 .46032 L
.5 .46032 L
.5 .42063 L
F
.5 .46032 m
.50476 .46032 L
.50476 .5 L
.5 .5 L
.5 .46032 L
F
.5 .5 m
.50476 .5 L
.50476 .53968 L
.5 .53968 L
.5 .5 L
F
.5 .53968 m
.50476 .53968 L
.50476 .57937 L
.5 .57937 L
.5 .53968 L
F
.5 .57937 m
.50476 .57937 L
.50476 .61905 L
.5 .61905 L
.5 .57937 L
F
.5 .61905 m
.50476 .61905 L
.50476 .65873 L
.5 .65873 L
.5 .61905 L
F
.5 .65873 m
.50476 .65873 L
.50476 .69841 L
.5 .69841 L
.5 .65873 L
F
.5 .69841 m
.50476 .69841 L
.50476 .7381 L
.5 .7381 L
.5 .69841 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.5 .2619 m
.5 .30159 L
.5 .34127 L
.5 .38095 L
.5 .42063 L
.5 .46032 L
.5 .5 L
.5 .53968 L
.5 .57937 L
.5 .61905 L
.5 .65873 L
.5 .69841 L
.5 .7381 L
.50476 .7381 L
.50476 .69841 L
.50476 .65873 L
.50476 .61905 L
.50476 .57937 L
.50476 .53968 L
.50476 .5 L
.50476 .46032 L
.50476 .42063 L
.50476 .38095 L
.50476 .34127 L
.50476 .30159 L
.50476 .2619 L
.5 .2619 L
s
.5 g
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
0 g
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.5 .5 L
s
.5 g
.50476 .2619 m
.50952 .2619 L
.50952 .30159 L
.50476 .30159 L
.50476 .2619 L
F
.50476 .30159 m
.50952 .30159 L
.50952 .34127 L
.50476 .34127 L
.50476 .30159 L
F
.50476 .34127 m
.50952 .34127 L
.50952 .38095 L
.50476 .38095 L
.50476 .34127 L
F
.50476 .38095 m
.50952 .38095 L
.50952 .42063 L
.50476 .42063 L
.50476 .38095 L
F
.50476 .42063 m
.50952 .42063 L
.50952 .46032 L
.50476 .46032 L
.50476 .42063 L
F
.50476 .46032 m
.50952 .46032 L
.50952 .5 L
.50476 .5 L
.50476 .46032 L
F
.50476 .5 m
.50952 .5 L
.50952 .53968 L
.50476 .53968 L
.50476 .5 L
F
.50476 .53968 m
.50952 .53968 L
.50952 .57937 L
.50476 .57937 L
.50476 .53968 L
F
.50476 .57937 m
.50952 .57937 L
.50952 .61905 L
.50476 .61905 L
.50476 .57937 L
F
.50476 .61905 m
.50952 .61905 L
.50952 .65873 L
.50476 .65873 L
.50476 .61905 L
F
.50476 .65873 m
.50952 .65873 L
.50952 .69841 L
.50476 .69841 L
.50476 .65873 L
F
.50476 .69841 m
.50952 .69841 L
.50952 .7381 L
.50476 .7381 L
.50476 .69841 L
F
0 g
.50476 .2619 m
.50476 .30159 L
.50476 .34127 L
.50476 .38095 L
.50476 .42063 L
.50476 .46032 L
.50476 .5 L
.50476 .53968 L
.50476 .57937 L
.50476 .61905 L
.50476 .65873 L
.50476 .69841 L
.50476 .7381 L
.50952 .7381 L
.50952 .69841 L
.50952 .65873 L
.50952 .61905 L
.50952 .57937 L
.50952 .53968 L
.50952 .5 L
.50952 .46032 L
.50952 .42063 L
.50952 .38095 L
.50952 .34127 L
.50952 .30159 L
.50952 .2619 L
.50476 .2619 L
s
.5 g
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
0 g
.50476 .5 m
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50476 .5 L
s
.5 .7381 m
.50476 .7381 L
.50476 .73606 L
.5 .73606 L
.5 .7381 L
s
.5 .73606 m
.50476 .73606 L
.50476 .72998 L
.5 .72998 L
.5 .73606 L
s
.5 .72998 m
.50476 .72998 L
.50476 .71997 L
.5 .71997 L
.5 .72998 L
s
.5 .71997 m
.50476 .71997 L
.50476 .7062 L
.5 .7062 L
.5 .71997 L
s
.5 .7062 m
.50476 .7062 L
.50476 .68889 L
.5 .68889 L
.5 .7062 L
s
.5 .68889 m
.50476 .68889 L
.50476 .66836 L
.5 .66836 L
.5 .68889 L
s
.5 .66836 m
.50476 .66836 L
.50476 .64494 L
.5 .64494 L
.5 .66836 L
s
.5 .64494 m
.50476 .64494 L
.50476 .61905 L
.5 .61905 L
.5 .64494 L
s
.5 .61905 m
.50476 .61905 L
.50476 .59112 L
.5 .59112 L
.5 .61905 L
s
.5 .59112 m
.50476 .59112 L
.50476 .56162 L
.5 .56162 L
.5 .59112 L
s
.5 .56162 m
.50476 .56162 L
.50476 .53108 L
.5 .53108 L
.5 .56162 L
s
.5 .53108 m
.50476 .53108 L
.50476 .5 L
.5 .5 L
.5 .53108 L
s
.5 .5 m
.50476 .5 L
.50476 .46892 L
.5 .46892 L
.5 .5 L
s
.5 .46892 m
.50476 .46892 L
.50476 .43838 L
.5 .43838 L
.5 .46892 L
s
.5 .43838 m
.50476 .43838 L
.50476 .40888 L
.5 .40888 L
.5 .43838 L
s
.5 .40888 m
.50476 .40888 L
.50476 .38095 L
.5 .38095 L
.5 .40888 L
s
.5 .38095 m
.50476 .38095 L
.50476 .35506 L
.5 .35506 L
.5 .38095 L
s
.5 .35506 m
.50476 .35506 L
.50476 .33164 L
.5 .33164 L
.5 .35506 L
s
.5 .33164 m
.50476 .33164 L
.50476 .31111 L
.5 .31111 L
.5 .33164 L
s
.5 .31111 m
.50476 .31111 L
.50476 .2938 L
.5 .2938 L
.5 .31111 L
s
.5 .2938 m
.50476 .2938 L
.50476 .28003 L
.5 .28003 L
.5 .2938 L
s
.5 .28003 m
.50476 .28003 L
.50476 .27002 L
.5 .27002 L
.5 .28003 L
s
.5 .27002 m
.50476 .27002 L
.50476 .26394 L
.5 .26394 L
.5 .27002 L
s
.5 .26394 m
.50476 .26394 L
.50476 .2619 L
.5 .2619 L
.5 .26394 L
s
.5 .2619 m
.50476 .2619 L
.50476 .26394 L
.5 .26394 L
.5 .2619 L
s
.5 .26394 m
.50476 .26394 L
.50476 .27002 L
.5 .27002 L
.5 .26394 L
s
.5 .27002 m
.50476 .27002 L
.50476 .28003 L
.5 .28003 L
.5 .27002 L
s
.5 .28003 m
.50476 .28003 L
.50476 .2938 L
.5 .2938 L
.5 .28003 L
s
.5 .2938 m
.50476 .2938 L
.50476 .31111 L
.5 .31111 L
.5 .2938 L
s
.5 .31111 m
.50476 .31111 L
.50476 .33164 L
.5 .33164 L
.5 .31111 L
s
.5 .33164 m
.50476 .33164 L
.50476 .35506 L
.5 .35506 L
.5 .33164 L
s
.5 .35506 m
.50476 .35506 L
.50476 .38095 L
.5 .38095 L
.5 .35506 L
s
.5 .38095 m
.50476 .38095 L
.50476 .40888 L
.5 .40888 L
.5 .38095 L
s
.5 .40888 m
.50476 .40888 L
.50476 .43838 L
.5 .43838 L
.5 .40888 L
s
.5 .43838 m
.50476 .43838 L
.50476 .46892 L
.5 .46892 L
.5 .43838 L
s
.5 .46892 m
.50476 .46892 L
.50476 .5 L
.5 .5 L
.5 .46892 L
s
.5 .5 m
.50476 .5 L
.50476 .53108 L
.5 .53108 L
.5 .5 L
s
.5 .53108 m
.50476 .53108 L
.50476 .56162 L
.5 .56162 L
.5 .53108 L
s
.5 .56162 m
.50476 .56162 L
.50476 .59112 L
.5 .59112 L
.5 .56162 L
s
.5 .59112 m
.50476 .59112 L
.50476 .61905 L
.5 .61905 L
.5 .59112 L
s
.5 .61905 m
.50476 .61905 L
.50476 .64494 L
.5 .64494 L
.5 .61905 L
s
.5 .64494 m
.50476 .64494 L
.50476 .66836 L
.5 .66836 L
.5 .64494 L
s
.5 .66836 m
.50476 .66836 L
.50476 .68889 L
.5 .68889 L
.5 .66836 L
s
.5 .68889 m
.50476 .68889 L
.50476 .7062 L
.5 .7062 L
.5 .68889 L
s
.5 .7062 m
.50476 .7062 L
.50476 .71997 L
.5 .71997 L
.5 .7062 L
s
.5 .71997 m
.50476 .71997 L
.50476 .72998 L
.5 .72998 L
.5 .71997 L
s
.5 .72998 m
.50476 .72998 L
.50476 .73606 L
.5 .73606 L
.5 .72998 L
s
.5 .73606 m
.50476 .73606 L
.50476 .7381 L
.5 .7381 L
.5 .73606 L
s
.50476 .7381 m
.50952 .7381 L
.50952 .73606 L
.50476 .73606 L
.50476 .7381 L
s
.50476 .73606 m
.50952 .73606 L
.50952 .72998 L
.50476 .72998 L
.50476 .73606 L
s
.50476 .72998 m
.50952 .72998 L
.50952 .71997 L
.50476 .71997 L
.50476 .72998 L
s
.50476 .71997 m
.50952 .71997 L
.50952 .7062 L
.50476 .7062 L
.50476 .71997 L
s
.50476 .7062 m
.50952 .7062 L
.50952 .68889 L
.50476 .68889 L
.50476 .7062 L
s
.50476 .68889 m
.50952 .68889 L
.50952 .66836 L
.50476 .66836 L
.50476 .68889 L
s
.50476 .66836 m
.50952 .66836 L
.50952 .64494 L
.50476 .64494 L
.50476 .66836 L
s
.50476 .64494 m
.50952 .64494 L
.50952 .61905 L
.50476 .61905 L
.50476 .64494 L
s
.50476 .61905 m
.50952 .61905 L
.50952 .59112 L
.50476 .59112 L
.50476 .61905 L
s
.50476 .59112 m
.50952 .59112 L
.50952 .56162 L
.50476 .56162 L
.50476 .59112 L
s
.50476 .56162 m
.50952 .56162 L
.50952 .53108 L
.50476 .53108 L
.50476 .56162 L
s
.50476 .53108 m
.50952 .53108 L
.50952 .5 L
.50476 .5 L
.50476 .53108 L
s
.50476 .5 m
.50952 .5 L
.50952 .46892 L
.50476 .46892 L
.50476 .5 L
s
.50476 .46892 m
.50952 .46892 L
.50952 .43838 L
.50476 .43838 L
.50476 .46892 L
s
.50476 .43838 m
.50952 .43838 L
.50952 .40888 L
.50476 .40888 L
.50476 .43838 L
s
.50476 .40888 m
.50952 .40888 L
.50952 .38095 L
.50476 .38095 L
.50476 .40888 L
s
.50476 .38095 m
.50952 .38095 L
.50952 .35506 L
.50476 .35506 L
.50476 .38095 L
s
.50476 .35506 m
.50952 .35506 L
.50952 .33164 L
.50476 .33164 L
.50476 .35506 L
s
.50476 .33164 m
.50952 .33164 L
.50952 .31111 L
.50476 .31111 L
.50476 .33164 L
s
.50476 .31111 m
.50952 .31111 L
.50952 .2938 L
.50476 .2938 L
.50476 .31111 L
s
.50476 .2938 m
.50952 .2938 L
.50952 .28003 L
.50476 .28003 L
.50476 .2938 L
s
.50476 .28003 m
.50952 .28003 L
.50952 .27002 L
.50476 .27002 L
.50476 .28003 L
s
.50476 .27002 m
.50952 .27002 L
.50952 .26394 L
.50476 .26394 L
.50476 .27002 L
s
.50476 .26394 m
.50952 .26394 L
.50952 .2619 L
.50476 .2619 L
.50476 .26394 L
s
.50476 .2619 m
.50952 .2619 L
.50952 .26394 L
.50476 .26394 L
.50476 .2619 L
s
.50476 .26394 m
.50952 .26394 L
.50952 .27002 L
.50476 .27002 L
.50476 .26394 L
s
.50476 .27002 m
.50952 .27002 L
.50952 .28003 L
.50476 .28003 L
.50476 .27002 L
s
.50476 .28003 m
.50952 .28003 L
.50952 .2938 L
.50476 .2938 L
.50476 .28003 L
s
.50476 .2938 m
.50952 .2938 L
.50952 .31111 L
.50476 .31111 L
.50476 .2938 L
s
.50476 .31111 m
.50952 .31111 L
.50952 .33164 L
.50476 .33164 L
.50476 .31111 L
s
.50476 .33164 m
.50952 .33164 L
.50952 .35506 L
.50476 .35506 L
.50476 .33164 L
s
.50476 .35506 m
.50952 .35506 L
.50952 .38095 L
.50476 .38095 L
.50476 .35506 L
s
.50476 .38095 m
.50952 .38095 L
.50952 .40888 L
.50476 .40888 L
.50476 .38095 L
s
.50476 .40888 m
.50952 .40888 L
.50952 .43838 L
.50476 .43838 L
.50476 .40888 L
s
.50476 .43838 m
.50952 .43838 L
.50952 .46892 L
.50476 .46892 L
.50476 .43838 L
s
.50476 .46892 m
.50952 .46892 L
.50952 .5 L
.50476 .5 L
.50476 .46892 L
s
.50476 .5 m
.50952 .5 L
.50952 .53108 L
.50476 .53108 L
.50476 .5 L
s
.50476 .53108 m
.50952 .53108 L
.50952 .56162 L
.50476 .56162 L
.50476 .53108 L
s
.50476 .56162 m
.50952 .56162 L
.50952 .59112 L
.50476 .59112 L
.50476 .56162 L
s
.50476 .59112 m
.50952 .59112 L
.50952 .61905 L
.50476 .61905 L
.50476 .59112 L
s
.50476 .61905 m
.50952 .61905 L
.50952 .64494 L
.50476 .64494 L
.50476 .61905 L
s
.50476 .64494 m
.50952 .64494 L
.50952 .66836 L
.50476 .66836 L
.50476 .64494 L
s
.50476 .66836 m
.50952 .66836 L
.50952 .68889 L
.50476 .68889 L
.50476 .66836 L
s
.50476 .68889 m
.50952 .68889 L
.50952 .7062 L
.50476 .7062 L
.50476 .68889 L
s
.50476 .7062 m
.50952 .7062 L
.50952 .71997 L
.50476 .71997 L
.50476 .7062 L
s
.50476 .71997 m
.50952 .71997 L
.50952 .72998 L
.50476 .72998 L
.50476 .71997 L
s
.50476 .72998 m
.50952 .72998 L
.50952 .73606 L
.50476 .73606 L
.50476 .72998 L
s
.50476 .73606 m
.50952 .73606 L
.50952 .7381 L
.50476 .7381 L
.50476 .73606 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.11905 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.50476 .5 L
s
0 0 0 r
2 Mabswid
.50476 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.50476 .5 m
.50952 .5 L
s
0 0 0 r
2 Mabswid
.50952 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(LP)] .50476 .22381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool500000004
0?ooo`0000000000000008D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0PP3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo08@0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo08@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`030?ooo`<00000Q03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`220?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
P`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000P`3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`210?ooo`<000000`3oool4000008@0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo100000250?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`24
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1o
Ogl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo100000250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl00000
0?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P00
00000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?oo
o`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P000000
0`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`24
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1o
Ogl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl0
00000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl00000
0?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P00
00000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl00000
0?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo1000
00250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P000000
0`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?oo
o`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P000000
0`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`24
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1o
Ogl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`24
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo100000250?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl0
00000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl0
00000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo100000240?ooo`8000001`3oool000H0oooo00<000000?ooo`3oool06@3ooom_
00WZ2P0300000009jPX02NX:08<02NX:0P0000070?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo
0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`@00000Q@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000
003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80
000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000
003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80
000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`@00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003o
ool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`800000
00<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`@00000Q@3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0
Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0
Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0
Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`@00000Q@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo
0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo
0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`@00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000
003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80
000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`@00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003o
ool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`800000
00<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`@00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0
Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`@00000Q@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo
0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`@00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`@00000Q@3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003o
ool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`@00000
Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo0P00003o0?oooa40oooo00<000000?oo
o`3oool01@3oool000H0ooooo`00000D000000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{\({1, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", \({1.`, 0.`, 0.`}\), ",", 
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 2}\), ",", 
            StyleBox["1.52584130859896438`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "100.`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 3}\), ",", 
            StyleBox["1.52584130859896438`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "50.0000000000000177`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.707106781186547461`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.70710678118654755`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({2, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "50.0000000000000177`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.707106781186547461`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.70710678118654755`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{Move[SingleRay[],10],
Move[LinearPolarizer[45,50,1],50], Boundary[100]},PlotType->TopView];
ReadRays[sys,{{ComponentNumber,SurfaceNumber},RefractiveIndex,RayTilt,\
Intensity,Polarization}]\
\>", "Input",
  CellTags->"LinearPolarizer"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.50476 .22381 -6 -4.5 ]
[.50476 .22381 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.5 .2619 m
.50476 .2619 L
.50476 .30159 L
.5 .30159 L
.5 .2619 L
F
.5 .30159 m
.50476 .30159 L
.50476 .34127 L
.5 .34127 L
.5 .30159 L
F
.5 .34127 m
.50476 .34127 L
.50476 .38095 L
.5 .38095 L
.5 .34127 L
F
.5 .38095 m
.50476 .38095 L
.50476 .42063 L
.5 .42063 L
.5 .38095 L
F
.5 .42063 m
.50476 .42063 L
.50476 .46032 L
.5 .46032 L
.5 .42063 L
F
.5 .46032 m
.50476 .46032 L
.50476 .5 L
.5 .5 L
.5 .46032 L
F
.5 .5 m
.50476 .5 L
.50476 .53968 L
.5 .53968 L
.5 .5 L
F
.5 .53968 m
.50476 .53968 L
.50476 .57937 L
.5 .57937 L
.5 .53968 L
F
.5 .57937 m
.50476 .57937 L
.50476 .61905 L
.5 .61905 L
.5 .57937 L
F
.5 .61905 m
.50476 .61905 L
.50476 .65873 L
.5 .65873 L
.5 .61905 L
F
.5 .65873 m
.50476 .65873 L
.50476 .69841 L
.5 .69841 L
.5 .65873 L
F
.5 .69841 m
.50476 .69841 L
.50476 .7381 L
.5 .7381 L
.5 .69841 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.5 .2619 m
.5 .30159 L
.5 .34127 L
.5 .38095 L
.5 .42063 L
.5 .46032 L
.5 .5 L
.5 .53968 L
.5 .57937 L
.5 .61905 L
.5 .65873 L
.5 .69841 L
.5 .7381 L
.50476 .7381 L
.50476 .69841 L
.50476 .65873 L
.50476 .61905 L
.50476 .57937 L
.50476 .53968 L
.50476 .5 L
.50476 .46032 L
.50476 .42063 L
.50476 .38095 L
.50476 .34127 L
.50476 .30159 L
.50476 .2619 L
.5 .2619 L
s
.5 g
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50476 .5 L
.50476 .5 L
.5 .5 L
.5 .5 L
F
0 g
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.5 .5 L
s
.5 g
.50476 .2619 m
.50952 .2619 L
.50952 .30159 L
.50476 .30159 L
.50476 .2619 L
F
.50476 .30159 m
.50952 .30159 L
.50952 .34127 L
.50476 .34127 L
.50476 .30159 L
F
.50476 .34127 m
.50952 .34127 L
.50952 .38095 L
.50476 .38095 L
.50476 .34127 L
F
.50476 .38095 m
.50952 .38095 L
.50952 .42063 L
.50476 .42063 L
.50476 .38095 L
F
.50476 .42063 m
.50952 .42063 L
.50952 .46032 L
.50476 .46032 L
.50476 .42063 L
F
.50476 .46032 m
.50952 .46032 L
.50952 .5 L
.50476 .5 L
.50476 .46032 L
F
.50476 .5 m
.50952 .5 L
.50952 .53968 L
.50476 .53968 L
.50476 .5 L
F
.50476 .53968 m
.50952 .53968 L
.50952 .57937 L
.50476 .57937 L
.50476 .53968 L
F
.50476 .57937 m
.50952 .57937 L
.50952 .61905 L
.50476 .61905 L
.50476 .57937 L
F
.50476 .61905 m
.50952 .61905 L
.50952 .65873 L
.50476 .65873 L
.50476 .61905 L
F
.50476 .65873 m
.50952 .65873 L
.50952 .69841 L
.50476 .69841 L
.50476 .65873 L
F
.50476 .69841 m
.50952 .69841 L
.50952 .7381 L
.50476 .7381 L
.50476 .69841 L
F
0 g
.50476 .2619 m
.50476 .30159 L
.50476 .34127 L
.50476 .38095 L
.50476 .42063 L
.50476 .46032 L
.50476 .5 L
.50476 .53968 L
.50476 .57937 L
.50476 .61905 L
.50476 .65873 L
.50476 .69841 L
.50476 .7381 L
.50952 .7381 L
.50952 .69841 L
.50952 .65873 L
.50952 .61905 L
.50952 .57937 L
.50952 .53968 L
.50952 .5 L
.50952 .46032 L
.50952 .42063 L
.50952 .38095 L
.50952 .34127 L
.50952 .30159 L
.50952 .2619 L
.50476 .2619 L
s
.5 g
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
.50476 .5 m
.50952 .5 L
.50952 .5 L
.50476 .5 L
.50476 .5 L
F
0 g
.50476 .5 m
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50476 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50476 .5 L
s
.5 .7381 m
.50476 .7381 L
.50476 .73606 L
.5 .73606 L
.5 .7381 L
s
.5 .73606 m
.50476 .73606 L
.50476 .72998 L
.5 .72998 L
.5 .73606 L
s
.5 .72998 m
.50476 .72998 L
.50476 .71997 L
.5 .71997 L
.5 .72998 L
s
.5 .71997 m
.50476 .71997 L
.50476 .7062 L
.5 .7062 L
.5 .71997 L
s
.5 .7062 m
.50476 .7062 L
.50476 .68889 L
.5 .68889 L
.5 .7062 L
s
.5 .68889 m
.50476 .68889 L
.50476 .66836 L
.5 .66836 L
.5 .68889 L
s
.5 .66836 m
.50476 .66836 L
.50476 .64494 L
.5 .64494 L
.5 .66836 L
s
.5 .64494 m
.50476 .64494 L
.50476 .61905 L
.5 .61905 L
.5 .64494 L
s
.5 .61905 m
.50476 .61905 L
.50476 .59112 L
.5 .59112 L
.5 .61905 L
s
.5 .59112 m
.50476 .59112 L
.50476 .56162 L
.5 .56162 L
.5 .59112 L
s
.5 .56162 m
.50476 .56162 L
.50476 .53108 L
.5 .53108 L
.5 .56162 L
s
.5 .53108 m
.50476 .53108 L
.50476 .5 L
.5 .5 L
.5 .53108 L
s
.5 .5 m
.50476 .5 L
.50476 .46892 L
.5 .46892 L
.5 .5 L
s
.5 .46892 m
.50476 .46892 L
.50476 .43838 L
.5 .43838 L
.5 .46892 L
s
.5 .43838 m
.50476 .43838 L
.50476 .40888 L
.5 .40888 L
.5 .43838 L
s
.5 .40888 m
.50476 .40888 L
.50476 .38095 L
.5 .38095 L
.5 .40888 L
s
.5 .38095 m
.50476 .38095 L
.50476 .35506 L
.5 .35506 L
.5 .38095 L
s
.5 .35506 m
.50476 .35506 L
.50476 .33164 L
.5 .33164 L
.5 .35506 L
s
.5 .33164 m
.50476 .33164 L
.50476 .31111 L
.5 .31111 L
.5 .33164 L
s
.5 .31111 m
.50476 .31111 L
.50476 .2938 L
.5 .2938 L
.5 .31111 L
s
.5 .2938 m
.50476 .2938 L
.50476 .28003 L
.5 .28003 L
.5 .2938 L
s
.5 .28003 m
.50476 .28003 L
.50476 .27002 L
.5 .27002 L
.5 .28003 L
s
.5 .27002 m
.50476 .27002 L
.50476 .26394 L
.5 .26394 L
.5 .27002 L
s
.5 .26394 m
.50476 .26394 L
.50476 .2619 L
.5 .2619 L
.5 .26394 L
s
.5 .2619 m
.50476 .2619 L
.50476 .26394 L
.5 .26394 L
.5 .2619 L
s
.5 .26394 m
.50476 .26394 L
.50476 .27002 L
.5 .27002 L
.5 .26394 L
s
.5 .27002 m
.50476 .27002 L
.50476 .28003 L
.5 .28003 L
.5 .27002 L
s
.5 .28003 m
.50476 .28003 L
.50476 .2938 L
.5 .2938 L
.5 .28003 L
s
.5 .2938 m
.50476 .2938 L
.50476 .31111 L
.5 .31111 L
.5 .2938 L
s
.5 .31111 m
.50476 .31111 L
.50476 .33164 L
.5 .33164 L
.5 .31111 L
s
.5 .33164 m
.50476 .33164 L
.50476 .35506 L
.5 .35506 L
.5 .33164 L
s
.5 .35506 m
.50476 .35506 L
.50476 .38095 L
.5 .38095 L
.5 .35506 L
s
.5 .38095 m
.50476 .38095 L
.50476 .40888 L
.5 .40888 L
.5 .38095 L
s
.5 .40888 m
.50476 .40888 L
.50476 .43838 L
.5 .43838 L
.5 .40888 L
s
.5 .43838 m
.50476 .43838 L
.50476 .46892 L
.5 .46892 L
.5 .43838 L
s
.5 .46892 m
.50476 .46892 L
.50476 .5 L
.5 .5 L
.5 .46892 L
s
.5 .5 m
.50476 .5 L
.50476 .53108 L
.5 .53108 L
.5 .5 L
s
.5 .53108 m
.50476 .53108 L
.50476 .56162 L
.5 .56162 L
.5 .53108 L
s
.5 .56162 m
.50476 .56162 L
.50476 .59112 L
.5 .59112 L
.5 .56162 L
s
.5 .59112 m
.50476 .59112 L
.50476 .61905 L
.5 .61905 L
.5 .59112 L
s
.5 .61905 m
.50476 .61905 L
.50476 .64494 L
.5 .64494 L
.5 .61905 L
s
.5 .64494 m
.50476 .64494 L
.50476 .66836 L
.5 .66836 L
.5 .64494 L
s
.5 .66836 m
.50476 .66836 L
.50476 .68889 L
.5 .68889 L
.5 .66836 L
s
.5 .68889 m
.50476 .68889 L
.50476 .7062 L
.5 .7062 L
.5 .68889 L
s
.5 .7062 m
.50476 .7062 L
.50476 .71997 L
.5 .71997 L
.5 .7062 L
s
.5 .71997 m
.50476 .71997 L
.50476 .72998 L
.5 .72998 L
.5 .71997 L
s
.5 .72998 m
.50476 .72998 L
.50476 .73606 L
.5 .73606 L
.5 .72998 L
s
.5 .73606 m
.50476 .73606 L
.50476 .7381 L
.5 .7381 L
.5 .73606 L
s
.50476 .7381 m
.50952 .7381 L
.50952 .73606 L
.50476 .73606 L
.50476 .7381 L
s
.50476 .73606 m
.50952 .73606 L
.50952 .72998 L
.50476 .72998 L
.50476 .73606 L
s
.50476 .72998 m
.50952 .72998 L
.50952 .71997 L
.50476 .71997 L
.50476 .72998 L
s
.50476 .71997 m
.50952 .71997 L
.50952 .7062 L
.50476 .7062 L
.50476 .71997 L
s
.50476 .7062 m
.50952 .7062 L
.50952 .68889 L
.50476 .68889 L
.50476 .7062 L
s
.50476 .68889 m
.50952 .68889 L
.50952 .66836 L
.50476 .66836 L
.50476 .68889 L
s
.50476 .66836 m
.50952 .66836 L
.50952 .64494 L
.50476 .64494 L
.50476 .66836 L
s
.50476 .64494 m
.50952 .64494 L
.50952 .61905 L
.50476 .61905 L
.50476 .64494 L
s
.50476 .61905 m
.50952 .61905 L
.50952 .59112 L
.50476 .59112 L
.50476 .61905 L
s
.50476 .59112 m
.50952 .59112 L
.50952 .56162 L
.50476 .56162 L
.50476 .59112 L
s
.50476 .56162 m
.50952 .56162 L
.50952 .53108 L
.50476 .53108 L
.50476 .56162 L
s
.50476 .53108 m
.50952 .53108 L
.50952 .5 L
.50476 .5 L
.50476 .53108 L
s
.50476 .5 m
.50952 .5 L
.50952 .46892 L
.50476 .46892 L
.50476 .5 L
s
.50476 .46892 m
.50952 .46892 L
.50952 .43838 L
.50476 .43838 L
.50476 .46892 L
s
.50476 .43838 m
.50952 .43838 L
.50952 .40888 L
.50476 .40888 L
.50476 .43838 L
s
.50476 .40888 m
.50952 .40888 L
.50952 .38095 L
.50476 .38095 L
.50476 .40888 L
s
.50476 .38095 m
.50952 .38095 L
.50952 .35506 L
.50476 .35506 L
.50476 .38095 L
s
.50476 .35506 m
.50952 .35506 L
.50952 .33164 L
.50476 .33164 L
.50476 .35506 L
s
.50476 .33164 m
.50952 .33164 L
.50952 .31111 L
.50476 .31111 L
.50476 .33164 L
s
.50476 .31111 m
.50952 .31111 L
.50952 .2938 L
.50476 .2938 L
.50476 .31111 L
s
.50476 .2938 m
.50952 .2938 L
.50952 .28003 L
.50476 .28003 L
.50476 .2938 L
s
.50476 .28003 m
.50952 .28003 L
.50952 .27002 L
.50476 .27002 L
.50476 .28003 L
s
.50476 .27002 m
.50952 .27002 L
.50952 .26394 L
.50476 .26394 L
.50476 .27002 L
s
.50476 .26394 m
.50952 .26394 L
.50952 .2619 L
.50476 .2619 L
.50476 .26394 L
s
.50476 .2619 m
.50952 .2619 L
.50952 .26394 L
.50476 .26394 L
.50476 .2619 L
s
.50476 .26394 m
.50952 .26394 L
.50952 .27002 L
.50476 .27002 L
.50476 .26394 L
s
.50476 .27002 m
.50952 .27002 L
.50952 .28003 L
.50476 .28003 L
.50476 .27002 L
s
.50476 .28003 m
.50952 .28003 L
.50952 .2938 L
.50476 .2938 L
.50476 .28003 L
s
.50476 .2938 m
.50952 .2938 L
.50952 .31111 L
.50476 .31111 L
.50476 .2938 L
s
.50476 .31111 m
.50952 .31111 L
.50952 .33164 L
.50476 .33164 L
.50476 .31111 L
s
.50476 .33164 m
.50952 .33164 L
.50952 .35506 L
.50476 .35506 L
.50476 .33164 L
s
.50476 .35506 m
.50952 .35506 L
.50952 .38095 L
.50476 .38095 L
.50476 .35506 L
s
.50476 .38095 m
.50952 .38095 L
.50952 .40888 L
.50476 .40888 L
.50476 .38095 L
s
.50476 .40888 m
.50952 .40888 L
.50952 .43838 L
.50476 .43838 L
.50476 .40888 L
s
.50476 .43838 m
.50952 .43838 L
.50952 .46892 L
.50476 .46892 L
.50476 .43838 L
s
.50476 .46892 m
.50952 .46892 L
.50952 .5 L
.50476 .5 L
.50476 .46892 L
s
.50476 .5 m
.50952 .5 L
.50952 .53108 L
.50476 .53108 L
.50476 .5 L
s
.50476 .53108 m
.50952 .53108 L
.50952 .56162 L
.50476 .56162 L
.50476 .53108 L
s
.50476 .56162 m
.50952 .56162 L
.50952 .59112 L
.50476 .59112 L
.50476 .56162 L
s
.50476 .59112 m
.50952 .59112 L
.50952 .61905 L
.50476 .61905 L
.50476 .59112 L
s
.50476 .61905 m
.50952 .61905 L
.50952 .64494 L
.50476 .64494 L
.50476 .61905 L
s
.50476 .64494 m
.50952 .64494 L
.50952 .66836 L
.50476 .66836 L
.50476 .64494 L
s
.50476 .66836 m
.50952 .66836 L
.50952 .68889 L
.50476 .68889 L
.50476 .66836 L
s
.50476 .68889 m
.50952 .68889 L
.50952 .7062 L
.50476 .7062 L
.50476 .68889 L
s
.50476 .7062 m
.50952 .7062 L
.50952 .71997 L
.50476 .71997 L
.50476 .7062 L
s
.50476 .71997 m
.50952 .71997 L
.50952 .72998 L
.50476 .72998 L
.50476 .71997 L
s
.50476 .72998 m
.50952 .72998 L
.50952 .73606 L
.50476 .73606 L
.50476 .72998 L
s
.50476 .73606 m
.50952 .73606 L
.50952 .7381 L
.50476 .7381 L
.50476 .73606 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.11905 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.50476 .5 L
s
0 0 0 r
2 Mabswid
.50476 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.50476 .5 m
.50952 .5 L
s
0 0 0 r
2 Mabswid
.50952 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(LP)] .50476 .22381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool500000004
0?ooo`0000000000000008D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0PP3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo08@0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo08@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`030?ooo`<00000Q03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`220?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
P`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000P`3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`210?ooo`<000000`3oool4000008@0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo100000250?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`24
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1o
Ogl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo100000250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl00000
0?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P00
00000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?oo
o`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P000000
0`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`24
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1o
Ogl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl0
00000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl00000
0?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P00
00000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl00000
0?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo1000
00250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P000000
0`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?oo
o`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P000000
0`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo100000250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`24
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1o
Ogl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`24
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo100000250?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl0
00000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl000000?ooo`240?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo0P0000000`1oOgl0
00000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
0P0000000`1oOgl000000?ooo`240?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo100000240?ooo`8000001`3oool000H0oooo00<000000?ooo`3oool06@3ooom_
00WZ2P0300000009jPX02NX:08<02NX:0P0000070?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo
0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`@00000Q@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000
003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80
000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000
003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80
000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`@00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003o
ool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`800000
00<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`@00000Q@3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0
Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0
Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0
Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`@00000Q@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo
0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo
0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`@00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000
003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80
000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`@00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003o
ool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`800000
00<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`@00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0
Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`@00000Q@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo
0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`@00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003oool0Q03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`@00000Q@3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`80000000<0Ogmo0000003o
ool0Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`@00000
Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo0P00003o0?oooa40oooo00<000000?oo
o`3oool01@3oool000H0ooooo`00000D000000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{\({1, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", \({1.`, 0.`, 0.`}\), ",", 
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 2}\), ",", 
            StyleBox["1.52584130859896438`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "100.`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 3}\), ",", 
            StyleBox["1.52584130859896438`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "50.0000000000000177`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.707106781186547461`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.70710678118654755`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({2, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "50.0000000000000177`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.707106781186547461`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.70710678118654755`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{Move[SingleRay[],10],
Move[LinearPolarizer[45,50,5, CenterThickness->1, \
ComponentMedium->{HN38,CrownGlass}, Centered->False],50], \
Boundary[100]},PlotType->TopView];
ReadRays[sys,{{ComponentNumber,SurfaceNumber},RefractiveIndex,RayTilt,\
Intensity,Polarization}]\
\>", "Input",
  CellTags->"LinearPolarizer"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.50476 .22381 -6 -4.5 ]
[.50476 .22381 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.5 .2619 m
.50952 .2619 L
.50952 .30159 L
.5 .30159 L
.5 .2619 L
F
.5 .30159 m
.50952 .30159 L
.50952 .34127 L
.5 .34127 L
.5 .30159 L
F
.5 .34127 m
.50952 .34127 L
.50952 .38095 L
.5 .38095 L
.5 .34127 L
F
.5 .38095 m
.50952 .38095 L
.50952 .42063 L
.5 .42063 L
.5 .38095 L
F
.5 .42063 m
.50952 .42063 L
.50952 .46032 L
.5 .46032 L
.5 .42063 L
F
.5 .46032 m
.50952 .46032 L
.50952 .5 L
.5 .5 L
.5 .46032 L
F
.5 .5 m
.50952 .5 L
.50952 .53968 L
.5 .53968 L
.5 .5 L
F
.5 .53968 m
.50952 .53968 L
.50952 .57937 L
.5 .57937 L
.5 .53968 L
F
.5 .57937 m
.50952 .57937 L
.50952 .61905 L
.5 .61905 L
.5 .57937 L
F
.5 .61905 m
.50952 .61905 L
.50952 .65873 L
.5 .65873 L
.5 .61905 L
F
.5 .65873 m
.50952 .65873 L
.50952 .69841 L
.5 .69841 L
.5 .65873 L
F
.5 .69841 m
.50952 .69841 L
.50952 .7381 L
.5 .7381 L
.5 .69841 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.5 .2619 m
.5 .30159 L
.5 .34127 L
.5 .38095 L
.5 .42063 L
.5 .46032 L
.5 .5 L
.5 .53968 L
.5 .57937 L
.5 .61905 L
.5 .65873 L
.5 .69841 L
.5 .7381 L
.50952 .7381 L
.50952 .69841 L
.50952 .65873 L
.50952 .61905 L
.50952 .57937 L
.50952 .53968 L
.50952 .5 L
.50952 .46032 L
.50952 .42063 L
.50952 .38095 L
.50952 .34127 L
.50952 .30159 L
.50952 .2619 L
.5 .2619 L
s
.5 g
.5 .5 m
.50952 .5 L
.50952 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50952 .5 L
.50952 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50952 .5 L
.50952 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50952 .5 L
.50952 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50952 .5 L
.50952 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50952 .5 L
.50952 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50952 .5 L
.50952 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50952 .5 L
.50952 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50952 .5 L
.50952 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50952 .5 L
.50952 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50952 .5 L
.50952 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50952 .5 L
.50952 .5 L
.5 .5 L
.5 .5 L
F
0 g
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.5 .5 L
s
.5 g
.50952 .2619 m
.50952 .2619 L
.50952 .30159 L
.50952 .30159 L
.50952 .2619 L
F
.50952 .30159 m
.50952 .30159 L
.50952 .34127 L
.50952 .34127 L
.50952 .30159 L
F
.50952 .34127 m
.50952 .34127 L
.50952 .38095 L
.50952 .38095 L
.50952 .34127 L
F
.50952 .38095 m
.50952 .38095 L
.50952 .42063 L
.50952 .42063 L
.50952 .38095 L
F
.50952 .42063 m
.50952 .42063 L
.50952 .46032 L
.50952 .46032 L
.50952 .42063 L
F
.50952 .46032 m
.50952 .46032 L
.50952 .5 L
.50952 .5 L
.50952 .46032 L
F
.50952 .5 m
.50952 .5 L
.50952 .53968 L
.50952 .53968 L
.50952 .5 L
F
.50952 .53968 m
.50952 .53968 L
.50952 .57937 L
.50952 .57937 L
.50952 .53968 L
F
.50952 .57937 m
.50952 .57937 L
.50952 .61905 L
.50952 .61905 L
.50952 .57937 L
F
.50952 .61905 m
.50952 .61905 L
.50952 .65873 L
.50952 .65873 L
.50952 .61905 L
F
.50952 .65873 m
.50952 .65873 L
.50952 .69841 L
.50952 .69841 L
.50952 .65873 L
F
.50952 .69841 m
.50952 .69841 L
.50952 .7381 L
.50952 .7381 L
.50952 .69841 L
F
0 g
.50952 .2619 m
.50952 .30159 L
.50952 .34127 L
.50952 .38095 L
.50952 .42063 L
.50952 .46032 L
.50952 .5 L
.50952 .53968 L
.50952 .57937 L
.50952 .61905 L
.50952 .65873 L
.50952 .69841 L
.50952 .7381 L
.50952 .7381 L
.50952 .69841 L
.50952 .65873 L
.50952 .61905 L
.50952 .57937 L
.50952 .53968 L
.50952 .5 L
.50952 .46032 L
.50952 .42063 L
.50952 .38095 L
.50952 .34127 L
.50952 .30159 L
.50952 .2619 L
.50952 .2619 L
s
.5 g
.50952 .5 m
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
F
0 g
.50952 .5 m
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
s
.5 g
.50952 .2619 m
.54762 .2619 L
.54762 .30159 L
.50952 .30159 L
.50952 .2619 L
F
.50952 .30159 m
.54762 .30159 L
.54762 .34127 L
.50952 .34127 L
.50952 .30159 L
F
.50952 .34127 m
.54762 .34127 L
.54762 .38095 L
.50952 .38095 L
.50952 .34127 L
F
.50952 .38095 m
.54762 .38095 L
.54762 .42063 L
.50952 .42063 L
.50952 .38095 L
F
.50952 .42063 m
.54762 .42063 L
.54762 .46032 L
.50952 .46032 L
.50952 .42063 L
F
.50952 .46032 m
.54762 .46032 L
.54762 .5 L
.50952 .5 L
.50952 .46032 L
F
.50952 .5 m
.54762 .5 L
.54762 .53968 L
.50952 .53968 L
.50952 .5 L
F
.50952 .53968 m
.54762 .53968 L
.54762 .57937 L
.50952 .57937 L
.50952 .53968 L
F
.50952 .57937 m
.54762 .57937 L
.54762 .61905 L
.50952 .61905 L
.50952 .57937 L
F
.50952 .61905 m
.54762 .61905 L
.54762 .65873 L
.50952 .65873 L
.50952 .61905 L
F
.50952 .65873 m
.54762 .65873 L
.54762 .69841 L
.50952 .69841 L
.50952 .65873 L
F
.50952 .69841 m
.54762 .69841 L
.54762 .7381 L
.50952 .7381 L
.50952 .69841 L
F
0 g
.50952 .2619 m
.50952 .30159 L
.50952 .34127 L
.50952 .38095 L
.50952 .42063 L
.50952 .46032 L
.50952 .5 L
.50952 .53968 L
.50952 .57937 L
.50952 .61905 L
.50952 .65873 L
.50952 .69841 L
.50952 .7381 L
.54762 .7381 L
.54762 .69841 L
.54762 .65873 L
.54762 .61905 L
.54762 .57937 L
.54762 .53968 L
.54762 .5 L
.54762 .46032 L
.54762 .42063 L
.54762 .38095 L
.54762 .34127 L
.54762 .30159 L
.54762 .2619 L
.50952 .2619 L
s
.5 g
.50952 .5 m
.54762 .5 L
.54762 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.54762 .5 L
.54762 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.54762 .5 L
.54762 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.54762 .5 L
.54762 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.54762 .5 L
.54762 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.54762 .5 L
.54762 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.54762 .5 L
.54762 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.54762 .5 L
.54762 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.54762 .5 L
.54762 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.54762 .5 L
.54762 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.54762 .5 L
.54762 .5 L
.50952 .5 L
.50952 .5 L
F
.50952 .5 m
.54762 .5 L
.54762 .5 L
.50952 .5 L
.50952 .5 L
F
0 g
.50952 .5 m
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.50952 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.50952 .5 L
s
.5 .7381 m
.50952 .7381 L
.50952 .73606 L
.5 .73606 L
.5 .7381 L
s
.5 .73606 m
.50952 .73606 L
.50952 .72998 L
.5 .72998 L
.5 .73606 L
s
.5 .72998 m
.50952 .72998 L
.50952 .71997 L
.5 .71997 L
.5 .72998 L
s
.5 .71997 m
.50952 .71997 L
.50952 .7062 L
.5 .7062 L
.5 .71997 L
s
.5 .7062 m
.50952 .7062 L
.50952 .68889 L
.5 .68889 L
.5 .7062 L
s
.5 .68889 m
.50952 .68889 L
.50952 .66836 L
.5 .66836 L
.5 .68889 L
s
.5 .66836 m
.50952 .66836 L
.50952 .64494 L
.5 .64494 L
.5 .66836 L
s
.5 .64494 m
.50952 .64494 L
.50952 .61905 L
.5 .61905 L
.5 .64494 L
s
.5 .61905 m
.50952 .61905 L
.50952 .59112 L
.5 .59112 L
.5 .61905 L
s
.5 .59112 m
.50952 .59112 L
.50952 .56162 L
.5 .56162 L
.5 .59112 L
s
.5 .56162 m
.50952 .56162 L
.50952 .53108 L
.5 .53108 L
.5 .56162 L
s
.5 .53108 m
.50952 .53108 L
.50952 .5 L
.5 .5 L
.5 .53108 L
s
.5 .5 m
.50952 .5 L
.50952 .46892 L
.5 .46892 L
.5 .5 L
s
.5 .46892 m
.50952 .46892 L
.50952 .43838 L
.5 .43838 L
.5 .46892 L
s
.5 .43838 m
.50952 .43838 L
.50952 .40888 L
.5 .40888 L
.5 .43838 L
s
.5 .40888 m
.50952 .40888 L
.50952 .38095 L
.5 .38095 L
.5 .40888 L
s
.5 .38095 m
.50952 .38095 L
.50952 .35506 L
.5 .35506 L
.5 .38095 L
s
.5 .35506 m
.50952 .35506 L
.50952 .33164 L
.5 .33164 L
.5 .35506 L
s
.5 .33164 m
.50952 .33164 L
.50952 .31111 L
.5 .31111 L
.5 .33164 L
s
.5 .31111 m
.50952 .31111 L
.50952 .2938 L
.5 .2938 L
.5 .31111 L
s
.5 .2938 m
.50952 .2938 L
.50952 .28003 L
.5 .28003 L
.5 .2938 L
s
.5 .28003 m
.50952 .28003 L
.50952 .27002 L
.5 .27002 L
.5 .28003 L
s
.5 .27002 m
.50952 .27002 L
.50952 .26394 L
.5 .26394 L
.5 .27002 L
s
.5 .26394 m
.50952 .26394 L
.50952 .2619 L
.5 .2619 L
.5 .26394 L
s
.5 .2619 m
.50952 .2619 L
.50952 .26394 L
.5 .26394 L
.5 .2619 L
s
.5 .26394 m
.50952 .26394 L
.50952 .27002 L
.5 .27002 L
.5 .26394 L
s
.5 .27002 m
.50952 .27002 L
.50952 .28003 L
.5 .28003 L
.5 .27002 L
s
.5 .28003 m
.50952 .28003 L
.50952 .2938 L
.5 .2938 L
.5 .28003 L
s
.5 .2938 m
.50952 .2938 L
.50952 .31111 L
.5 .31111 L
.5 .2938 L
s
.5 .31111 m
.50952 .31111 L
.50952 .33164 L
.5 .33164 L
.5 .31111 L
s
.5 .33164 m
.50952 .33164 L
.50952 .35506 L
.5 .35506 L
.5 .33164 L
s
.5 .35506 m
.50952 .35506 L
.50952 .38095 L
.5 .38095 L
.5 .35506 L
s
.5 .38095 m
.50952 .38095 L
.50952 .40888 L
.5 .40888 L
.5 .38095 L
s
.5 .40888 m
.50952 .40888 L
.50952 .43838 L
.5 .43838 L
.5 .40888 L
s
.5 .43838 m
.50952 .43838 L
.50952 .46892 L
.5 .46892 L
.5 .43838 L
s
.5 .46892 m
.50952 .46892 L
.50952 .5 L
.5 .5 L
.5 .46892 L
s
.5 .5 m
.50952 .5 L
.50952 .53108 L
.5 .53108 L
.5 .5 L
s
.5 .53108 m
.50952 .53108 L
.50952 .56162 L
.5 .56162 L
.5 .53108 L
s
.5 .56162 m
.50952 .56162 L
.50952 .59112 L
.5 .59112 L
.5 .56162 L
s
.5 .59112 m
.50952 .59112 L
.50952 .61905 L
.5 .61905 L
.5 .59112 L
s
.5 .61905 m
.50952 .61905 L
.50952 .64494 L
.5 .64494 L
.5 .61905 L
s
.5 .64494 m
.50952 .64494 L
.50952 .66836 L
.5 .66836 L
.5 .64494 L
s
.5 .66836 m
.50952 .66836 L
.50952 .68889 L
.5 .68889 L
.5 .66836 L
s
.5 .68889 m
.50952 .68889 L
.50952 .7062 L
.5 .7062 L
.5 .68889 L
s
.5 .7062 m
.50952 .7062 L
.50952 .71997 L
.5 .71997 L
.5 .7062 L
s
.5 .71997 m
.50952 .71997 L
.50952 .72998 L
.5 .72998 L
.5 .71997 L
s
.5 .72998 m
.50952 .72998 L
.50952 .73606 L
.5 .73606 L
.5 .72998 L
s
.5 .73606 m
.50952 .73606 L
.50952 .7381 L
.5 .7381 L
.5 .73606 L
s
.50952 .7381 m
.50952 .7381 L
.50952 .73606 L
.50952 .73606 L
.50952 .7381 L
s
.50952 .73606 m
.50952 .73606 L
.50952 .72998 L
.50952 .72998 L
.50952 .73606 L
s
.50952 .72998 m
.50952 .72998 L
.50952 .71997 L
.50952 .71997 L
.50952 .72998 L
s
.50952 .71997 m
.50952 .71997 L
.50952 .7062 L
.50952 .7062 L
.50952 .71997 L
s
.50952 .7062 m
.50952 .7062 L
.50952 .68889 L
.50952 .68889 L
.50952 .7062 L
s
.50952 .68889 m
.50952 .68889 L
.50952 .66836 L
.50952 .66836 L
.50952 .68889 L
s
.50952 .66836 m
.50952 .66836 L
.50952 .64494 L
.50952 .64494 L
.50952 .66836 L
s
.50952 .64494 m
.50952 .64494 L
.50952 .61905 L
.50952 .61905 L
.50952 .64494 L
s
.50952 .61905 m
.50952 .61905 L
.50952 .59112 L
.50952 .59112 L
.50952 .61905 L
s
.50952 .59112 m
.50952 .59112 L
.50952 .56162 L
.50952 .56162 L
.50952 .59112 L
s
.50952 .56162 m
.50952 .56162 L
.50952 .53108 L
.50952 .53108 L
.50952 .56162 L
s
.50952 .53108 m
.50952 .53108 L
.50952 .5 L
.50952 .5 L
.50952 .53108 L
s
.50952 .5 m
.50952 .5 L
.50952 .46892 L
.50952 .46892 L
.50952 .5 L
s
.50952 .46892 m
.50952 .46892 L
.50952 .43838 L
.50952 .43838 L
.50952 .46892 L
s
.50952 .43838 m
.50952 .43838 L
.50952 .40888 L
.50952 .40888 L
.50952 .43838 L
s
.50952 .40888 m
.50952 .40888 L
.50952 .38095 L
.50952 .38095 L
.50952 .40888 L
s
.50952 .38095 m
.50952 .38095 L
.50952 .35506 L
.50952 .35506 L
.50952 .38095 L
s
.50952 .35506 m
.50952 .35506 L
.50952 .33164 L
.50952 .33164 L
.50952 .35506 L
s
.50952 .33164 m
.50952 .33164 L
.50952 .31111 L
.50952 .31111 L
.50952 .33164 L
s
.50952 .31111 m
.50952 .31111 L
.50952 .2938 L
.50952 .2938 L
.50952 .31111 L
s
.50952 .2938 m
.50952 .2938 L
.50952 .28003 L
.50952 .28003 L
.50952 .2938 L
s
.50952 .28003 m
.50952 .28003 L
.50952 .27002 L
.50952 .27002 L
.50952 .28003 L
s
.50952 .27002 m
.50952 .27002 L
.50952 .26394 L
.50952 .26394 L
.50952 .27002 L
s
.50952 .26394 m
.50952 .26394 L
.50952 .2619 L
.50952 .2619 L
.50952 .26394 L
s
.50952 .2619 m
.50952 .2619 L
.50952 .26394 L
.50952 .26394 L
.50952 .2619 L
s
.50952 .26394 m
.50952 .26394 L
.50952 .27002 L
.50952 .27002 L
.50952 .26394 L
s
.50952 .27002 m
.50952 .27002 L
.50952 .28003 L
.50952 .28003 L
.50952 .27002 L
s
.50952 .28003 m
.50952 .28003 L
.50952 .2938 L
.50952 .2938 L
.50952 .28003 L
s
.50952 .2938 m
.50952 .2938 L
.50952 .31111 L
.50952 .31111 L
.50952 .2938 L
s
.50952 .31111 m
.50952 .31111 L
.50952 .33164 L
.50952 .33164 L
.50952 .31111 L
s
.50952 .33164 m
.50952 .33164 L
.50952 .35506 L
.50952 .35506 L
.50952 .33164 L
s
.50952 .35506 m
.50952 .35506 L
.50952 .38095 L
.50952 .38095 L
.50952 .35506 L
s
.50952 .38095 m
.50952 .38095 L
.50952 .40888 L
.50952 .40888 L
.50952 .38095 L
s
.50952 .40888 m
.50952 .40888 L
.50952 .43838 L
.50952 .43838 L
.50952 .40888 L
s
.50952 .43838 m
.50952 .43838 L
.50952 .46892 L
.50952 .46892 L
.50952 .43838 L
s
.50952 .46892 m
.50952 .46892 L
.50952 .5 L
.50952 .5 L
.50952 .46892 L
s
.50952 .5 m
.50952 .5 L
.50952 .53108 L
.50952 .53108 L
.50952 .5 L
s
.50952 .53108 m
.50952 .53108 L
.50952 .56162 L
.50952 .56162 L
.50952 .53108 L
s
.50952 .56162 m
.50952 .56162 L
.50952 .59112 L
.50952 .59112 L
.50952 .56162 L
s
.50952 .59112 m
.50952 .59112 L
.50952 .61905 L
.50952 .61905 L
.50952 .59112 L
s
.50952 .61905 m
.50952 .61905 L
.50952 .64494 L
.50952 .64494 L
.50952 .61905 L
s
.50952 .64494 m
.50952 .64494 L
.50952 .66836 L
.50952 .66836 L
.50952 .64494 L
s
.50952 .66836 m
.50952 .66836 L
.50952 .68889 L
.50952 .68889 L
.50952 .66836 L
s
.50952 .68889 m
.50952 .68889 L
.50952 .7062 L
.50952 .7062 L
.50952 .68889 L
s
.50952 .7062 m
.50952 .7062 L
.50952 .71997 L
.50952 .71997 L
.50952 .7062 L
s
.50952 .71997 m
.50952 .71997 L
.50952 .72998 L
.50952 .72998 L
.50952 .71997 L
s
.50952 .72998 m
.50952 .72998 L
.50952 .73606 L
.50952 .73606 L
.50952 .72998 L
s
.50952 .73606 m
.50952 .73606 L
.50952 .7381 L
.50952 .7381 L
.50952 .73606 L
s
.50952 .7381 m
.54762 .7381 L
.54762 .73606 L
.50952 .73606 L
.50952 .7381 L
s
.50952 .73606 m
.54762 .73606 L
.54762 .72998 L
.50952 .72998 L
.50952 .73606 L
s
.50952 .72998 m
.54762 .72998 L
.54762 .71997 L
.50952 .71997 L
.50952 .72998 L
s
.50952 .71997 m
.54762 .71997 L
.54762 .7062 L
.50952 .7062 L
.50952 .71997 L
s
.50952 .7062 m
.54762 .7062 L
.54762 .68889 L
.50952 .68889 L
.50952 .7062 L
s
.50952 .68889 m
.54762 .68889 L
.54762 .66836 L
.50952 .66836 L
.50952 .68889 L
s
.50952 .66836 m
.54762 .66836 L
.54762 .64494 L
.50952 .64494 L
.50952 .66836 L
s
.50952 .64494 m
.54762 .64494 L
.54762 .61905 L
.50952 .61905 L
.50952 .64494 L
s
.50952 .61905 m
.54762 .61905 L
.54762 .59112 L
.50952 .59112 L
.50952 .61905 L
s
.50952 .59112 m
.54762 .59112 L
.54762 .56162 L
.50952 .56162 L
.50952 .59112 L
s
.50952 .56162 m
.54762 .56162 L
.54762 .53108 L
.50952 .53108 L
.50952 .56162 L
s
.50952 .53108 m
.54762 .53108 L
.54762 .5 L
.50952 .5 L
.50952 .53108 L
s
.50952 .5 m
.54762 .5 L
.54762 .46892 L
.50952 .46892 L
.50952 .5 L
s
.50952 .46892 m
.54762 .46892 L
.54762 .43838 L
.50952 .43838 L
.50952 .46892 L
s
.50952 .43838 m
.54762 .43838 L
.54762 .40888 L
.50952 .40888 L
.50952 .43838 L
s
.50952 .40888 m
.54762 .40888 L
.54762 .38095 L
.50952 .38095 L
.50952 .40888 L
s
.50952 .38095 m
.54762 .38095 L
.54762 .35506 L
.50952 .35506 L
.50952 .38095 L
s
.50952 .35506 m
.54762 .35506 L
.54762 .33164 L
.50952 .33164 L
.50952 .35506 L
s
.50952 .33164 m
.54762 .33164 L
.54762 .31111 L
.50952 .31111 L
.50952 .33164 L
s
.50952 .31111 m
.54762 .31111 L
.54762 .2938 L
.50952 .2938 L
.50952 .31111 L
s
.50952 .2938 m
.54762 .2938 L
.54762 .28003 L
.50952 .28003 L
.50952 .2938 L
s
.50952 .28003 m
.54762 .28003 L
.54762 .27002 L
.50952 .27002 L
.50952 .28003 L
s
.50952 .27002 m
.54762 .27002 L
.54762 .26394 L
.50952 .26394 L
.50952 .27002 L
s
.50952 .26394 m
.54762 .26394 L
.54762 .2619 L
.50952 .2619 L
.50952 .26394 L
s
.50952 .2619 m
.54762 .2619 L
.54762 .26394 L
.50952 .26394 L
.50952 .2619 L
s
.50952 .26394 m
.54762 .26394 L
.54762 .27002 L
.50952 .27002 L
.50952 .26394 L
s
.50952 .27002 m
.54762 .27002 L
.54762 .28003 L
.50952 .28003 L
.50952 .27002 L
s
.50952 .28003 m
.54762 .28003 L
.54762 .2938 L
.50952 .2938 L
.50952 .28003 L
s
.50952 .2938 m
.54762 .2938 L
.54762 .31111 L
.50952 .31111 L
.50952 .2938 L
s
.50952 .31111 m
.54762 .31111 L
.54762 .33164 L
.50952 .33164 L
.50952 .31111 L
s
.50952 .33164 m
.54762 .33164 L
.54762 .35506 L
.50952 .35506 L
.50952 .33164 L
s
.50952 .35506 m
.54762 .35506 L
.54762 .38095 L
.50952 .38095 L
.50952 .35506 L
s
.50952 .38095 m
.54762 .38095 L
.54762 .40888 L
.50952 .40888 L
.50952 .38095 L
s
.50952 .40888 m
.54762 .40888 L
.54762 .43838 L
.50952 .43838 L
.50952 .40888 L
s
.50952 .43838 m
.54762 .43838 L
.54762 .46892 L
.50952 .46892 L
.50952 .43838 L
s
.50952 .46892 m
.54762 .46892 L
.54762 .5 L
.50952 .5 L
.50952 .46892 L
s
.50952 .5 m
.54762 .5 L
.54762 .53108 L
.50952 .53108 L
.50952 .5 L
s
.50952 .53108 m
.54762 .53108 L
.54762 .56162 L
.50952 .56162 L
.50952 .53108 L
s
.50952 .56162 m
.54762 .56162 L
.54762 .59112 L
.50952 .59112 L
.50952 .56162 L
s
.50952 .59112 m
.54762 .59112 L
.54762 .61905 L
.50952 .61905 L
.50952 .59112 L
s
.50952 .61905 m
.54762 .61905 L
.54762 .64494 L
.50952 .64494 L
.50952 .61905 L
s
.50952 .64494 m
.54762 .64494 L
.54762 .66836 L
.50952 .66836 L
.50952 .64494 L
s
.50952 .66836 m
.54762 .66836 L
.54762 .68889 L
.50952 .68889 L
.50952 .66836 L
s
.50952 .68889 m
.54762 .68889 L
.54762 .7062 L
.50952 .7062 L
.50952 .68889 L
s
.50952 .7062 m
.54762 .7062 L
.54762 .71997 L
.50952 .71997 L
.50952 .7062 L
s
.50952 .71997 m
.54762 .71997 L
.54762 .72998 L
.50952 .72998 L
.50952 .71997 L
s
.50952 .72998 m
.54762 .72998 L
.54762 .73606 L
.50952 .73606 L
.50952 .72998 L
s
.50952 .73606 m
.54762 .73606 L
.54762 .7381 L
.50952 .7381 L
.50952 .73606 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.11905 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.50952 .5 L
s
0 0 0 r
2 Mabswid
.50952 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .5 m
.50952 .5 L
s
0 0 0 r
2 Mabswid
.50952 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.50952 .5 m
.54762 .5 L
s
0 0 0 r
2 Mabswid
.54762 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.54762 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(LP)] .50476 .22381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool500000004
0?ooo`0000000000000008D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0PP3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo08@0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo08@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`030?ooo`<00000Q03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`220?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
P`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000P`3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`210?ooo`<000000`3oool4000008@0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`230?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo3`00001j0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl0
00002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo3`00001j0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl00000
2P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo3`00001j0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1o
Ogl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo3`00001j0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo3`00001j0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo3`00001j0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo3`00001j0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0
000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0
000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0
000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo3`00
001j0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@00000
07moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@00000
07moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@00000
07moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@00000
07moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo3`00001j0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007mo
O`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007mo
O`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007mo
O`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo3`00001j0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1o
Ogl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1o
Ogl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1o
Ogl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1o
Ogl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo3`00001j0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl0
00002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl0
00002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl0
00002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00@0000007moO`1oOgl000002P1oOgl00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00@0000007moO`1oOgl0
00002P1oOgl00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo1000000907moO`800000N@3oool2000000L0oooo00060?ooo`030000003o
ool0oooo01T0ooooK`09jPX00`0000002NX:00WZ2P0800WZ2P0300000009jPX02NX:07P02NX:0P00
00070?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`l00000NP3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`l00000NP3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`04
0000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`04
0000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`04
0000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`l0
0000NP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000
001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000
001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000
001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000
001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`l00000NP3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001o
Ogl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001o
Ogl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001o
Ogl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`l00000NP3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0
Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0
Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0
Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`l00000NP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo
000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo
000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`l00000NP3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo0000
00X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo0000
00X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`l00000NP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0
Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0
Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`l00000NP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`040000001oOgl0Ogmo000000X0Ogmo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`l00000NP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`040000001oOgl0Ogmo000000X0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`l00000NP3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo0P00003o0?oooa40oooo00<000000?ooo`3oool01@3oool000H0ooooo`00
000D000000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{\({1, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", \({1.`, 0.`, 0.`}\), ",", 
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 2}\), ",", 
            StyleBox["1.51926803816985422`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "40.1391404022400255`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.695468472160417316`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.718556611709094639`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 3}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "40.1391404022400255`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.695468472160417316`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.718556611709094639`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 4}\), ",", 
            StyleBox["1.52584130859896438`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "40.1391404022400255`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.695468472160417316`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.718556611709094639`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({2, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "40.1391404022400255`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.695468472160417316`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.718556611709094639`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], "}"}]],
   "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{Move[SingleRay[],10],
Move[LinearPolarizer[45,50,5, CenterThickness->0, \
ComponentMedium->{HN38,CrownGlass}, Centered->False],50], \
Boundary[100]},PlotType->TopView];
ReadRays[sys,{{ComponentNumber,SurfaceNumber},RefractiveIndex,RayTilt,\
Intensity,Polarization}]\
\>", "Input",
  CellTags->"LinearPolarizer"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.5 .22381 -9 -4.5 ]
[.5 .22381 9 4.5 ]
[.54762 .22381 -9 -4.5 ]
[.54762 .22381 9 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.5 .2619 m
.5 .2619 L
.5 .30159 L
.5 .30159 L
.5 .2619 L
F
.5 .30159 m
.5 .30159 L
.5 .34127 L
.5 .34127 L
.5 .30159 L
F
.5 .34127 m
.5 .34127 L
.5 .38095 L
.5 .38095 L
.5 .34127 L
F
.5 .38095 m
.5 .38095 L
.5 .42063 L
.5 .42063 L
.5 .38095 L
F
.5 .42063 m
.5 .42063 L
.5 .46032 L
.5 .46032 L
.5 .42063 L
F
.5 .46032 m
.5 .46032 L
.5 .5 L
.5 .5 L
.5 .46032 L
F
.5 .5 m
.5 .5 L
.5 .53968 L
.5 .53968 L
.5 .5 L
F
.5 .53968 m
.5 .53968 L
.5 .57937 L
.5 .57937 L
.5 .53968 L
F
.5 .57937 m
.5 .57937 L
.5 .61905 L
.5 .61905 L
.5 .57937 L
F
.5 .61905 m
.5 .61905 L
.5 .65873 L
.5 .65873 L
.5 .61905 L
F
.5 .65873 m
.5 .65873 L
.5 .69841 L
.5 .69841 L
.5 .65873 L
F
.5 .69841 m
.5 .69841 L
.5 .7381 L
.5 .7381 L
.5 .69841 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.5 .2619 m
.5 .30159 L
.5 .34127 L
.5 .38095 L
.5 .42063 L
.5 .46032 L
.5 .5 L
.5 .53968 L
.5 .57937 L
.5 .61905 L
.5 .65873 L
.5 .69841 L
.5 .7381 L
.5 .7381 L
.5 .69841 L
.5 .65873 L
.5 .61905 L
.5 .57937 L
.5 .53968 L
.5 .5 L
.5 .46032 L
.5 .42063 L
.5 .38095 L
.5 .34127 L
.5 .30159 L
.5 .2619 L
.5 .2619 L
s
.5 g
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
F
0 g
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
s
.5 g
.5 .2619 m
.54762 .2619 L
.54762 .30159 L
.5 .30159 L
.5 .2619 L
F
.5 .30159 m
.54762 .30159 L
.54762 .34127 L
.5 .34127 L
.5 .30159 L
F
.5 .34127 m
.54762 .34127 L
.54762 .38095 L
.5 .38095 L
.5 .34127 L
F
.5 .38095 m
.54762 .38095 L
.54762 .42063 L
.5 .42063 L
.5 .38095 L
F
.5 .42063 m
.54762 .42063 L
.54762 .46032 L
.5 .46032 L
.5 .42063 L
F
.5 .46032 m
.54762 .46032 L
.54762 .5 L
.5 .5 L
.5 .46032 L
F
.5 .5 m
.54762 .5 L
.54762 .53968 L
.5 .53968 L
.5 .5 L
F
.5 .53968 m
.54762 .53968 L
.54762 .57937 L
.5 .57937 L
.5 .53968 L
F
.5 .57937 m
.54762 .57937 L
.54762 .61905 L
.5 .61905 L
.5 .57937 L
F
.5 .61905 m
.54762 .61905 L
.54762 .65873 L
.5 .65873 L
.5 .61905 L
F
.5 .65873 m
.54762 .65873 L
.54762 .69841 L
.5 .69841 L
.5 .65873 L
F
.5 .69841 m
.54762 .69841 L
.54762 .7381 L
.5 .7381 L
.5 .69841 L
F
0 g
.5 .2619 m
.5 .30159 L
.5 .34127 L
.5 .38095 L
.5 .42063 L
.5 .46032 L
.5 .5 L
.5 .53968 L
.5 .57937 L
.5 .61905 L
.5 .65873 L
.5 .69841 L
.5 .7381 L
.54762 .7381 L
.54762 .69841 L
.54762 .65873 L
.54762 .61905 L
.54762 .57937 L
.54762 .53968 L
.54762 .5 L
.54762 .46032 L
.54762 .42063 L
.54762 .38095 L
.54762 .34127 L
.54762 .30159 L
.54762 .2619 L
.5 .2619 L
s
.5 g
.5 .5 m
.54762 .5 L
.54762 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.54762 .5 L
.54762 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.54762 .5 L
.54762 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.54762 .5 L
.54762 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.54762 .5 L
.54762 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.54762 .5 L
.54762 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.54762 .5 L
.54762 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.54762 .5 L
.54762 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.54762 .5 L
.54762 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.54762 .5 L
.54762 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.54762 .5 L
.54762 .5 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.54762 .5 L
.54762 .5 L
.5 .5 L
.5 .5 L
F
0 g
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.54762 .5 L
.5 .5 L
s
.5 .7381 m
.5 .7381 L
.5 .73606 L
.5 .73606 L
.5 .7381 L
s
.5 .73606 m
.5 .73606 L
.5 .72998 L
.5 .72998 L
.5 .73606 L
s
.5 .72998 m
.5 .72998 L
.5 .71997 L
.5 .71997 L
.5 .72998 L
s
.5 .71997 m
.5 .71997 L
.5 .7062 L
.5 .7062 L
.5 .71997 L
s
.5 .7062 m
.5 .7062 L
.5 .68889 L
.5 .68889 L
.5 .7062 L
s
.5 .68889 m
.5 .68889 L
.5 .66836 L
.5 .66836 L
.5 .68889 L
s
.5 .66836 m
.5 .66836 L
.5 .64494 L
.5 .64494 L
.5 .66836 L
s
.5 .64494 m
.5 .64494 L
.5 .61905 L
.5 .61905 L
.5 .64494 L
s
.5 .61905 m
.5 .61905 L
.5 .59112 L
.5 .59112 L
.5 .61905 L
s
.5 .59112 m
.5 .59112 L
.5 .56162 L
.5 .56162 L
.5 .59112 L
s
.5 .56162 m
.5 .56162 L
.5 .53108 L
.5 .53108 L
.5 .56162 L
s
.5 .53108 m
.5 .53108 L
.5 .5 L
.5 .5 L
.5 .53108 L
s
.5 .5 m
.5 .5 L
.5 .46892 L
.5 .46892 L
.5 .5 L
s
.5 .46892 m
.5 .46892 L
.5 .43838 L
.5 .43838 L
.5 .46892 L
s
.5 .43838 m
.5 .43838 L
.5 .40888 L
.5 .40888 L
.5 .43838 L
s
.5 .40888 m
.5 .40888 L
.5 .38095 L
.5 .38095 L
.5 .40888 L
s
.5 .38095 m
.5 .38095 L
.5 .35506 L
.5 .35506 L
.5 .38095 L
s
.5 .35506 m
.5 .35506 L
.5 .33164 L
.5 .33164 L
.5 .35506 L
s
.5 .33164 m
.5 .33164 L
.5 .31111 L
.5 .31111 L
.5 .33164 L
s
.5 .31111 m
.5 .31111 L
.5 .2938 L
.5 .2938 L
.5 .31111 L
s
.5 .2938 m
.5 .2938 L
.5 .28003 L
.5 .28003 L
.5 .2938 L
s
.5 .28003 m
.5 .28003 L
.5 .27002 L
.5 .27002 L
.5 .28003 L
s
.5 .27002 m
.5 .27002 L
.5 .26394 L
.5 .26394 L
.5 .27002 L
s
.5 .26394 m
.5 .26394 L
.5 .2619 L
.5 .2619 L
.5 .26394 L
s
.5 .2619 m
.5 .2619 L
.5 .26394 L
.5 .26394 L
.5 .2619 L
s
.5 .26394 m
.5 .26394 L
.5 .27002 L
.5 .27002 L
.5 .26394 L
s
.5 .27002 m
.5 .27002 L
.5 .28003 L
.5 .28003 L
.5 .27002 L
s
.5 .28003 m
.5 .28003 L
.5 .2938 L
.5 .2938 L
.5 .28003 L
s
.5 .2938 m
.5 .2938 L
.5 .31111 L
.5 .31111 L
.5 .2938 L
s
.5 .31111 m
.5 .31111 L
.5 .33164 L
.5 .33164 L
.5 .31111 L
s
.5 .33164 m
.5 .33164 L
.5 .35506 L
.5 .35506 L
.5 .33164 L
s
.5 .35506 m
.5 .35506 L
.5 .38095 L
.5 .38095 L
.5 .35506 L
s
.5 .38095 m
.5 .38095 L
.5 .40888 L
.5 .40888 L
.5 .38095 L
s
.5 .40888 m
.5 .40888 L
.5 .43838 L
.5 .43838 L
.5 .40888 L
s
.5 .43838 m
.5 .43838 L
.5 .46892 L
.5 .46892 L
.5 .43838 L
s
.5 .46892 m
.5 .46892 L
.5 .5 L
.5 .5 L
.5 .46892 L
s
.5 .5 m
.5 .5 L
.5 .53108 L
.5 .53108 L
.5 .5 L
s
.5 .53108 m
.5 .53108 L
.5 .56162 L
.5 .56162 L
.5 .53108 L
s
.5 .56162 m
.5 .56162 L
.5 .59112 L
.5 .59112 L
.5 .56162 L
s
.5 .59112 m
.5 .59112 L
.5 .61905 L
.5 .61905 L
.5 .59112 L
s
.5 .61905 m
.5 .61905 L
.5 .64494 L
.5 .64494 L
.5 .61905 L
s
.5 .64494 m
.5 .64494 L
.5 .66836 L
.5 .66836 L
.5 .64494 L
s
.5 .66836 m
.5 .66836 L
.5 .68889 L
.5 .68889 L
.5 .66836 L
s
.5 .68889 m
.5 .68889 L
.5 .7062 L
.5 .7062 L
.5 .68889 L
s
.5 .7062 m
.5 .7062 L
.5 .71997 L
.5 .71997 L
.5 .7062 L
s
.5 .71997 m
.5 .71997 L
.5 .72998 L
.5 .72998 L
.5 .71997 L
s
.5 .72998 m
.5 .72998 L
.5 .73606 L
.5 .73606 L
.5 .72998 L
s
.5 .73606 m
.5 .73606 L
.5 .7381 L
.5 .7381 L
.5 .73606 L
s
.5 .7381 m
.54762 .7381 L
.54762 .73606 L
.5 .73606 L
.5 .7381 L
s
.5 .73606 m
.54762 .73606 L
.54762 .72998 L
.5 .72998 L
.5 .73606 L
s
.5 .72998 m
.54762 .72998 L
.54762 .71997 L
.5 .71997 L
.5 .72998 L
s
.5 .71997 m
.54762 .71997 L
.54762 .7062 L
.5 .7062 L
.5 .71997 L
s
.5 .7062 m
.54762 .7062 L
.54762 .68889 L
.5 .68889 L
.5 .7062 L
s
.5 .68889 m
.54762 .68889 L
.54762 .66836 L
.5 .66836 L
.5 .68889 L
s
.5 .66836 m
.54762 .66836 L
.54762 .64494 L
.5 .64494 L
.5 .66836 L
s
.5 .64494 m
.54762 .64494 L
.54762 .61905 L
.5 .61905 L
.5 .64494 L
s
.5 .61905 m
.54762 .61905 L
.54762 .59112 L
.5 .59112 L
.5 .61905 L
s
.5 .59112 m
.54762 .59112 L
.54762 .56162 L
.5 .56162 L
.5 .59112 L
s
.5 .56162 m
.54762 .56162 L
.54762 .53108 L
.5 .53108 L
.5 .56162 L
s
.5 .53108 m
.54762 .53108 L
.54762 .5 L
.5 .5 L
.5 .53108 L
s
.5 .5 m
.54762 .5 L
.54762 .46892 L
.5 .46892 L
.5 .5 L
s
.5 .46892 m
.54762 .46892 L
.54762 .43838 L
.5 .43838 L
.5 .46892 L
s
.5 .43838 m
.54762 .43838 L
.54762 .40888 L
.5 .40888 L
.5 .43838 L
s
.5 .40888 m
.54762 .40888 L
.54762 .38095 L
.5 .38095 L
.5 .40888 L
s
.5 .38095 m
.54762 .38095 L
.54762 .35506 L
.5 .35506 L
.5 .38095 L
s
.5 .35506 m
.54762 .35506 L
.54762 .33164 L
.5 .33164 L
.5 .35506 L
s
.5 .33164 m
.54762 .33164 L
.54762 .31111 L
.5 .31111 L
.5 .33164 L
s
.5 .31111 m
.54762 .31111 L
.54762 .2938 L
.5 .2938 L
.5 .31111 L
s
.5 .2938 m
.54762 .2938 L
.54762 .28003 L
.5 .28003 L
.5 .2938 L
s
.5 .28003 m
.54762 .28003 L
.54762 .27002 L
.5 .27002 L
.5 .28003 L
s
.5 .27002 m
.54762 .27002 L
.54762 .26394 L
.5 .26394 L
.5 .27002 L
s
.5 .26394 m
.54762 .26394 L
.54762 .2619 L
.5 .2619 L
.5 .26394 L
s
.5 .2619 m
.54762 .2619 L
.54762 .26394 L
.5 .26394 L
.5 .2619 L
s
.5 .26394 m
.54762 .26394 L
.54762 .27002 L
.5 .27002 L
.5 .26394 L
s
.5 .27002 m
.54762 .27002 L
.54762 .28003 L
.5 .28003 L
.5 .27002 L
s
.5 .28003 m
.54762 .28003 L
.54762 .2938 L
.5 .2938 L
.5 .28003 L
s
.5 .2938 m
.54762 .2938 L
.54762 .31111 L
.5 .31111 L
.5 .2938 L
s
.5 .31111 m
.54762 .31111 L
.54762 .33164 L
.5 .33164 L
.5 .31111 L
s
.5 .33164 m
.54762 .33164 L
.54762 .35506 L
.5 .35506 L
.5 .33164 L
s
.5 .35506 m
.54762 .35506 L
.54762 .38095 L
.5 .38095 L
.5 .35506 L
s
.5 .38095 m
.54762 .38095 L
.54762 .40888 L
.5 .40888 L
.5 .38095 L
s
.5 .40888 m
.54762 .40888 L
.54762 .43838 L
.5 .43838 L
.5 .40888 L
s
.5 .43838 m
.54762 .43838 L
.54762 .46892 L
.5 .46892 L
.5 .43838 L
s
.5 .46892 m
.54762 .46892 L
.54762 .5 L
.5 .5 L
.5 .46892 L
s
.5 .5 m
.54762 .5 L
.54762 .53108 L
.5 .53108 L
.5 .5 L
s
.5 .53108 m
.54762 .53108 L
.54762 .56162 L
.5 .56162 L
.5 .53108 L
s
.5 .56162 m
.54762 .56162 L
.54762 .59112 L
.5 .59112 L
.5 .56162 L
s
.5 .59112 m
.54762 .59112 L
.54762 .61905 L
.5 .61905 L
.5 .59112 L
s
.5 .61905 m
.54762 .61905 L
.54762 .64494 L
.5 .64494 L
.5 .61905 L
s
.5 .64494 m
.54762 .64494 L
.54762 .66836 L
.5 .66836 L
.5 .64494 L
s
.5 .66836 m
.54762 .66836 L
.54762 .68889 L
.5 .68889 L
.5 .66836 L
s
.5 .68889 m
.54762 .68889 L
.54762 .7062 L
.5 .7062 L
.5 .68889 L
s
.5 .7062 m
.54762 .7062 L
.54762 .71997 L
.5 .71997 L
.5 .7062 L
s
.5 .71997 m
.54762 .71997 L
.54762 .72998 L
.5 .72998 L
.5 .71997 L
s
.5 .72998 m
.54762 .72998 L
.54762 .73606 L
.5 .73606 L
.5 .72998 L
s
.5 .73606 m
.54762 .73606 L
.54762 .7381 L
.5 .7381 L
.5 .73606 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.11905 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.54762 .5 L
s
0 0 0 r
2 Mabswid
.54762 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.54762 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(LP1)] .5 .22381 0 0 Mshowa
[(LP2)] .54762 .22381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0OP3oool500000004
0?ooo`0000000000000000@0oooo1@000000103oool000000000000000030?ooo`@00000M03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1o0?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000M03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0
oooo00<0oooo0`0000040?ooo`030000003oool0oooo00<0oooo0`0000040?ooo`030000003oool0
oooo07<0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0O`3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo00000080oooo0P0000050?ooo`060000003oool0oooo0000003oool000000P3oool00`000000
oooo0?ooo`1b0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo07h0oooo
0`0000030?ooo`@000000`3oool3000000<0oooo100000030?ooo`800000M@3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool?0000
07X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000
Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool?000007X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;
07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool?000007X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000
003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool?000007X0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo
07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000
Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07mo
O`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0QP3oool?000007X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`03
0000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool0
0`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool?000007X0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo
07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;
07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool?000007X0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000
003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0
oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`00
0000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo
07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool?000007X0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07mo
O`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000
003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0
oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`00
0000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool?000007X0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07mo
O`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07mo
O`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000
003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0
oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool?0000
07X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000
Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07mo
O`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07mo
O`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000
003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool?000007X0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo
07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000
Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07mo
O`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0;07mo
O`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000Ogmo07moO`0;07moO`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool2000000/0Ogmo0P00001i0?ooo`800000
1`3oool000H0oooo00<000000?ooo`3oool06@3ooomj00WZ2P0300000009jPX02NX:07P02NX:0P00
00070?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0
Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0
Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`l00000NP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0
Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`l00000NP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`l00000NP3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo
00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`l00000
NP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001o
Ogl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo
00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`l00000NP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`03
0000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001o
Ogl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo
00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`l00000NP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`03
0000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`l00000NP3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0
Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0
Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`l00000NP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`l00000NP3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001o
Ogl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`l00000NP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`l00000NP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo0P00003o0?oooa40oooo00<000000?ooo`3oool01@3oool0
00H0ooooo`00000D000000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{\({1, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", \({1.`, 0.`, 0.`}\), ",", 
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 2}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", \({1.`, 0.`, 0.`}\), ",", 
            "40.1391404022400255`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.695468472160417316`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.718556611709094639`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 3}\), ",", 
            StyleBox["1.52584130859896438`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "40.1391404022400255`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.695468472160417316`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.718556611709094639`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({2, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "40.1391404022400255`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.695468472160417316`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.718556611709094639`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{Move[SingleRay[],10],
Move[LensSurface[50,ComponentMedium->HN38],48],
Move[LinearPolarizer[45,50,ComponentMedium->HN38],50], \
Move[LensSurface[50,ComponentMedium->HN38],52],
Boundary[100]},PlotType->TopView];
ReadRays[sys,{IntersectionNumber,RefractiveIndex,RayTilt,Intensity,\
Polarization}]\
\>", "Input",
  CellTags->"LinearPolarizer"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.48095 .22381 -6 -4.5 ]
[.48095 .22381 6 4.5 ]
[.5 .22381 -6 -4.5 ]
[.5 .22381 6 4.5 ]
[.51905 .22381 -6 -4.5 ]
[.51905 .22381 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.48095 .2619 m
.48095 .30159 L
.48095 .34127 L
.48095 .38095 L
.48095 .42063 L
.48095 .46032 L
.48095 .5 L
.48095 .53968 L
.48095 .57937 L
.48095 .61905 L
.48095 .65873 L
.48095 .69841 L
.48095 .7381 L
.48095 .7381 L
.48095 .69841 L
.48095 .65873 L
.48095 .61905 L
.48095 .57937 L
.48095 .53968 L
.48095 .5 L
.48095 .46032 L
.48095 .42063 L
.48095 .38095 L
.48095 .34127 L
.48095 .30159 L
.48095 .2619 L
.48095 .2619 L
s
.48095 .5 m
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
.48095 .5 L
s
.48095 .7381 m
.48095 .73606 L
.48095 .72998 L
.48095 .71997 L
.48095 .7062 L
.48095 .68889 L
.48095 .66836 L
.48095 .64494 L
.48095 .61905 L
.48095 .59112 L
.48095 .56162 L
.48095 .53108 L
.48095 .5 L
.48095 .46892 L
.48095 .43838 L
.48095 .40888 L
.48095 .38095 L
.48095 .35506 L
.48095 .33164 L
.48095 .31111 L
.48095 .2938 L
.48095 .28003 L
.48095 .27002 L
.48095 .26394 L
.48095 .2619 L
.48095 .26394 L
.48095 .27002 L
.48095 .28003 L
.48095 .2938 L
.48095 .31111 L
.48095 .33164 L
.48095 .35506 L
.48095 .38095 L
.48095 .40888 L
.48095 .43838 L
.48095 .46892 L
.48095 .5 L
.48095 .53108 L
.48095 .56162 L
.48095 .59112 L
.48095 .61905 L
.48095 .64494 L
.48095 .66836 L
.48095 .68889 L
.48095 .7062 L
.48095 .71997 L
.48095 .72998 L
.48095 .73606 L
.48095 .7381 L
s
.5 .2619 m
.5 .30159 L
.5 .34127 L
.5 .38095 L
.5 .42063 L
.5 .46032 L
.5 .5 L
.5 .53968 L
.5 .57937 L
.5 .61905 L
.5 .65873 L
.5 .69841 L
.5 .7381 L
.5 .7381 L
.5 .69841 L
.5 .65873 L
.5 .61905 L
.5 .57937 L
.5 .53968 L
.5 .5 L
.5 .46032 L
.5 .42063 L
.5 .38095 L
.5 .34127 L
.5 .30159 L
.5 .2619 L
.5 .2619 L
s
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
s
.5 .7381 m
.5 .73606 L
.5 .72998 L
.5 .71997 L
.5 .7062 L
.5 .68889 L
.5 .66836 L
.5 .64494 L
.5 .61905 L
.5 .59112 L
.5 .56162 L
.5 .53108 L
.5 .5 L
.5 .46892 L
.5 .43838 L
.5 .40888 L
.5 .38095 L
.5 .35506 L
.5 .33164 L
.5 .31111 L
.5 .2938 L
.5 .28003 L
.5 .27002 L
.5 .26394 L
.5 .2619 L
.5 .26394 L
.5 .27002 L
.5 .28003 L
.5 .2938 L
.5 .31111 L
.5 .33164 L
.5 .35506 L
.5 .38095 L
.5 .40888 L
.5 .43838 L
.5 .46892 L
.5 .5 L
.5 .53108 L
.5 .56162 L
.5 .59112 L
.5 .61905 L
.5 .64494 L
.5 .66836 L
.5 .68889 L
.5 .7062 L
.5 .71997 L
.5 .72998 L
.5 .73606 L
.5 .7381 L
s
.51905 .2619 m
.51905 .30159 L
.51905 .34127 L
.51905 .38095 L
.51905 .42063 L
.51905 .46032 L
.51905 .5 L
.51905 .53968 L
.51905 .57937 L
.51905 .61905 L
.51905 .65873 L
.51905 .69841 L
.51905 .7381 L
.51905 .7381 L
.51905 .69841 L
.51905 .65873 L
.51905 .61905 L
.51905 .57937 L
.51905 .53968 L
.51905 .5 L
.51905 .46032 L
.51905 .42063 L
.51905 .38095 L
.51905 .34127 L
.51905 .30159 L
.51905 .2619 L
.51905 .2619 L
s
.51905 .5 m
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
.51905 .5 L
s
.51905 .7381 m
.51905 .73606 L
.51905 .72998 L
.51905 .71997 L
.51905 .7062 L
.51905 .68889 L
.51905 .66836 L
.51905 .64494 L
.51905 .61905 L
.51905 .59112 L
.51905 .56162 L
.51905 .53108 L
.51905 .5 L
.51905 .46892 L
.51905 .43838 L
.51905 .40888 L
.51905 .38095 L
.51905 .35506 L
.51905 .33164 L
.51905 .31111 L
.51905 .2938 L
.51905 .28003 L
.51905 .27002 L
.51905 .26394 L
.51905 .2619 L
.51905 .26394 L
.51905 .27002 L
.51905 .28003 L
.51905 .2938 L
.51905 .31111 L
.51905 .33164 L
.51905 .35506 L
.51905 .38095 L
.51905 .40888 L
.51905 .43838 L
.51905 .46892 L
.51905 .5 L
.51905 .53108 L
.51905 .56162 L
.51905 .59112 L
.51905 .61905 L
.51905 .64494 L
.51905 .66836 L
.51905 .68889 L
.51905 .7062 L
.51905 .71997 L
.51905 .72998 L
.51905 .73606 L
.51905 .7381 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.11905 .5 m
.48095 .5 L
s
0 0 0 r
2 Mabswid
.48095 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.48095 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.51905 .5 L
s
0 0 0 r
2 Mabswid
.51905 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.51905 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(L1)] .48095 .22381 0 0 Mshowa
[(LP)] .5 .22381 0 0 Mshowa
[(L2)] .51905 .22381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0N`3oool:00000003
0?ooo`000000000000<0000000<0oooo0000000000000P00001o0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo07`0oooo00L000000?ooo`3oool000000?ooo`000000oooo
008000000P3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool0O@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo07l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0O03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000<0oooo0`0000040?ooo`030000003oool0oooo
07h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0O03oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1m0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo07`0
oooo00<000000?ooo`3oool00P3oool3000000<0oooo00H000000?ooo`3oool000000?ooo`000002
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0N`3oool300000080oooo100000020?ooo`@000000`3oool200000800oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0P03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`21
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`21
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0840
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0840
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0800oooo0P0000040?ooo`8000000`3oool200000840oooo0P0000070?ooo`001P3oool00`000000
oooo0?ooo`0I0?ooofL02NX:00<0000000WZ2P09jPX0R`09jPX2000000L0oooo00060?ooo`030000
003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0840
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0840
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`21
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`21
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo0P0000220?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool200000?l0oooo4@3oool00`000000oooo0?ooo`050?ooo`001P3ooooo000001@000001`3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"1", ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", \({1.`, 0.`, 0.`}\), ",", 
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"2", ",", 
            StyleBox["1.51926803816985422`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{"0", ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"3", ",", 
            StyleBox["1.51926803816985422`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "40.1391404022400255`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.695468472160417316`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.718556611709094639`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"4", ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "40.1391404022400255`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.695468472160417316`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.718556611709094639`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModelIntensity[HN38]", "Input",
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    \({{{0.4`, 65.3120291299999955`}, {0.409999999999999964`, 
          69.6600924400000032`}, {0.420000000000000017`, 
          72.2839956400000005`}, {0.429999999999999982`, 
          74.4647640400000021`}, {0.440000000000000035`, 
          76.2140230100000071`}, {0.45`, 
          77.6288576000000052`}, {0.460000000000000053`, 
          78.3416455899999952`}, {0.469999999999999928`, 
          79.2446786600000052`}, {0.479999999999999982`, 
          80.3483113900000134`}, {0.490000000000000035`, 
          81.0920859199999988`}, {0.5`, 
          81.2770935700000052`}, {0.509999999999999964`, 
          80.5356288299999967`}, {0.520000000000000017`, 
          80.5356910499999933`}, {0.530000000000000071`, 
          80.3492338300000064`}, {0.540000000000000035`, 
          79.7997486700000013`}, {0.55`, 
          79.2464507800000017`}, {0.560000000000000053`, 
          78.7019689600000038`}, {0.569999999999999928`, 
          78.523883010000004`}, {0.579999999999999982`, 
          77.2657761300000078`}, {0.589999999999999946`, 
          77.2010347400000007`}, {0.6`, 
          75.9473515200000015`}, {0.609999999999999964`, 
          75.8551260900000023`}, {0.620000000000000017`, 
          75.8551253200000008`}, {0.629999999999999982`, 
          75.3392295899999986`}, {0.640000000000000035`, 
          75.8551279200000028`}, {0.65`, 
          76.3806236500000057`}, {0.660000000000000053`, 
          76.6420233200000033`}, {0.670000000000000017`, 
          77.8074537499999951`}, {0.680000000000000071`, 
          77.9871791500000011`}, {0.689999999999999946`, 
          79.2464522300000062`}, {0.7`, 
          79.9874974599999966`}, {0.709999999999999964`, 
          81.0925376600000014`}, {0.719999999999999928`, 
          82.219217449999995`}, {0.729999999999999982`, 
          83.5583622300000072`}, {0.740000000000000035`, 
          84.7230773499999934`}, {0.75`, 
          84.9234825699999973`}, {0.759999999999999964`, 
          86.3017424599999927`}}, {{0.4`, 
          4.04213440000000012`}, {0.409999999999999964`, 
          3.93338554000000009`}, {0.420000000000000017`, 
          3.32023703999999986`}, {0.429999999999999982`, 
          2.6455465600000001`}, {0.440000000000000035`, 
          1.85005324000000008`}, {0.45`, 
          1.32682616999999991`}, {0.460000000000000053`, 
          0.765876180000000061`}, {0.469999999999999928`, 
          0.530004040000000031`}, {0.479999999999999982`, 
          0.385820180000000014`}, {0.490000000000000035`, 
          0.27129650999999999`}, {0.5`, 
          0.184553839999999986`}, {0.509999999999999964`, 
          0.111751779999999989`}, {0.520000000000000017`, 
          0.0496674199999999999`}, {0.530000000000000071`, 
          0.0248913399999999995`}, {0.540000000000000035`, 
          0.0112782300000000001`}, {0.55`, 
          0.00504753999999999969`}, {0.560000000000000053`, 
          0.00381184999999999973`}, {0.569999999999999928`, 
          0.0025469999999999997`}, {0.579999999999999982`, 
          0.00257552999999999965`}, {0.589999999999999946`, 
          0.00237042999999999981`}, {0.6`, 
          0.00223838999999999987`}, {0.609999999999999964`, 
          0.00218838000000000043`}, {0.620000000000000017`, 
          0.00216202000000000049`}, {0.629999999999999982`, 
          0.00207062999999999997`}, {0.640000000000000035`, 
          0.0020433699999999999`}, {0.65`, 
          0.00200313000000000007`}, {0.660000000000000053`, 
          0.00197019999999999999`}, {0.670000000000000017`, 
          0.00195354000000000027`}, {0.680000000000000071`, 
          0.00189774999999999991`}, {0.689999999999999946`, 
          0.00184234999999999971`}, {0.7`, 
          0.00191280000000000001`}, {0.709999999999999964`, 
          0.00209637000000000028`}, {0.719999999999999928`, 
          0.00276091000000000041`}, {0.729999999999999982`, 
          0.00501445999999999969`}, {0.740000000000000035`, 
          0.0129834800000000004`}, {0.75`, 
          0.0459236900000000058`}, {0.759999999999999964`, 
          0.0961741899999999994`}}}\)], "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModelRefractiveIndex[HN38][WaveLength->.532]", "Input",
  CellTags->"LinearPolarizer"],

Cell[BoxData[
    \(1.51926803816985405`\)], "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["LinearPolarizer with user-defined surface", "Section",
  CellTags->"LinearPolarizer with user-defined surface"],

Cell[CellGroupData[{

Cell["LinearPolarizer[Function[#1^2/100+#2^2/100],90,100]", "Input",
  CellTags->"LinearPolarizer with user-defined surface"],

Cell[BoxData[
    TagBox[\(LinearPolarizer[#1\^2\/100 + #2\^2\/100 &, 90, 100]\),
      HoldForm]], "Output",
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[LinearPolarizer[Function[#1^2/100+#2^2/100],90,100]]\
\>\
", "Input",
  CellTags->"LinearPolarizer with user-defined surface"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.815 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.386592 1.87247 0 1.87247 [
[ 0 0 0 0 ]
[ 1 1.815 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.815 L
0 1.815 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.88062 .85366 m
.90035 .92314 L
s
.85799 .78485 m
.88062 .85366 L
s
.83271 .71748 m
.85799 .78485 L
s
.90035 .92314 m
.91695 .9925 L
s
.80505 .65231 m
.83271 .71748 L
s
.91695 .9925 m
.93019 1.06097 L
s
.77529 .59013 m
.80505 .65231 L
s
.93019 1.06097 m
.93986 1.12773 L
s
.74375 .53171 m
.77529 .59013 L
s
.93986 1.12773 m
.94577 1.19193 L
s
.71075 .47786 m
.74375 .53171 L
s
.94577 1.19193 m
.94775 1.25273 L
s
.94577 1.19193 m
.82629 1.16891 L
s
.94577 1.19193 m
.94577 1.19193 L
s
.67668 .42939 m
.71075 .47786 L
s
.82629 1.16891 m
.71928 1.1413 L
s
.94775 1.25273 m
.94563 1.30922 L
s
.67668 .42939 m
.67668 .42939 L
s
.59931 .52981 m
.67668 .42939 L
s
.64194 .38712 m
.67668 .42939 L
s
.71928 1.1413 m
.62466 1.10884 L
s
.53536 .62629 m
.59931 .52981 L
s
.94563 1.30922 m
.93929 1.36048 L
s
.53536 .62629 m
.48483 .71916 L
s
.62466 1.10884 m
.54241 1.07125 L
s
.60698 .35188 m
.64194 .38712 L
s
.48483 .71916 m
.44784 .80873 L
s
.93929 1.36048 m
.92864 1.40557 L
s
.54241 1.07125 m
.47264 1.02816 L
s
.57229 .32447 m
.60698 .35188 L
s
.44784 .80873 m
.42463 .8953 L
s
.92864 1.40557 m
.91364 1.44354 L
s
.47264 1.02816 m
.41556 .97916 L
s
.42463 .8953 m
.41556 .97916 L
s
.53841 .30568 m
.57229 .32447 L
s
.91364 1.44354 m
.89433 1.47344 L
s
.41556 .97916 m
.42116 1.06057 L
s
.41556 .97916 m
.37154 .92373 L
s
.50593 .29624 m
.53841 .30568 L
s
.42116 1.06057 m
.4421 1.13979 L
s
.89433 1.47344 m
.87079 1.49437 L
s
.37154 .92373 m
.34106 .86127 L
s
.47546 .29679 m
.50593 .29624 L
s
.4421 1.13979 m
.47924 1.21709 L
s
.87079 1.49437 m
.84321 1.50549 L
s
.34106 .86127 m
.32478 .79109 L
s
.44766 .30786 m
.47546 .29679 L
s
.47924 1.21709 m
.53368 1.29273 L
s
.84321 1.50549 m
.81188 1.50609 L
s
.42317 .32978 m
.44766 .30786 L
s
.32478 .79109 m
.32355 .71232 L
s
.81188 1.50609 m
.77722 1.49558 L
s
.53368 1.29273 m
.60675 1.36697 L
s
.40265 .3627 m
.42317 .32978 L
s
.32355 .71232 m
.33845 .62397 L
s
.77722 1.49558 m
.73973 1.47362 L
s
.38673 .40652 m
.40265 .3627 L
s
.60675 1.36697 m
.70008 1.44009 L
s
.73973 1.47362 m
.70008 1.44009 L
s
.37597 .4608 m
.38673 .40652 L
s
.33845 .62397 m
.37084 .52483 L
s
.70008 1.44009 m
.70008 1.44009 L
s
.70008 1.44009 m
.65902 1.3952 L
s
.37084 .52483 m
.37597 .4608 L
s
.65902 1.3952 m
.61744 1.3395 L
s
.37084 .52483 m
.37084 .52483 L
s
.37167 .59751 m
.37084 .52483 L
s
.61744 1.3395 m
.57628 1.27387 L
s
.37866 .67744 m
.37167 .59751 L
s
.57628 1.27387 m
.53654 1.1996 L
s
.3918 .76289 m
.37866 .67744 L
s
.53654 1.1996 m
.49922 1.11828 L
s
.41091 .85188 m
.3918 .76289 L
s
.49922 1.11828 m
.46528 1.0318 L
s
.4356 .94226 m
.41091 .85188 L
s
.46528 1.0318 m
.4356 .94226 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{158.625, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002N000182000`400?l00000o`00003oWP3oool0
09h0oooo002N0?ooo`00WP3oool009h0oooo002N0?ooo`00WP3oool009h0oooo002N0?ooo`00WP3o
ool009h0oooo002N0?ooo`00WP3oool009h0oooo002N0?ooo`00WP3oool009h0oooo002N0?ooo`00
WP3oool009h0oooo002N0?ooo`00WP3oool009h0oooo002N0?ooo`00WP3oool009h0oooo002N0?oo
o`00WP3oool009h0oooo002N0?ooo`00WP3oool009h0oooo002N0?ooo`00WP3oool009h0oooo002N
0?ooo`00WP3oool009h0oooo002N0?ooo`00WP3oool009h0oooo002N0?ooo`00WP3oool009h0oooo
002N0?ooo`00WP3oool009h0oooo002N0?ooo`00B03oool;000004/0oooo00160?ooo`8000002`3o
ool3000004P0oooo00150?ooo`030000003oool0oooo00h0oooo0P0000160?ooo`00A03oool00`00
0000oooo0?ooo`0A0?ooo`800000A03oool004<0oooo00<000000?ooo`3oool0503oool200000480
oooo00120?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0?`3oool00480oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0n0?ooo`00@@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo03d0oooo00100?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0?03oool00400oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0k0?ooo`00
?`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03X0oooo000o0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0>@3oool003h0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0h0?ooo`00?P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
03L0oooo000m0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0=P3oool003d0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0f0?ooo`00?@3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo03D0oooo000l0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0=03oool003`0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0c0?oo
o`00?03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo03<0oooo000l0?ooo`030000
003oool0oooo02X0oooo0P00000c0?ooo`00?03oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo0340oooo000k0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0<@3oool0
03/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0000000b0?ooo`00>`3oool00`000000
oooo0?ooo`0Z0?ooo`050000003oool0oooo0?ooo`000000<@3oool003/0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02h0oooo000k0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0]0?ooo`00>`3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;03o
ool003/0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo02/0oooo000k0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0[0?ooo`00>`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0:P3oool003/0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo02X0oooo000j0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0Y0?ooo`00>P3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0:03oool003X0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02P0oooo000j0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0W0?ooo`00
>P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
9`3oool003X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo02H0oooo000i0?ooo`8000008P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo02H0oooo000i0?ooo`8000008@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
02D0oooo000i0?ooo`8000008@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02D0
oooo000h0?ooo`030000003oool000000200oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0T0?ooo`00>03oool00`000000oooo0000000P0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool08`3oool003P0oooo00<000000?ooo`0000007`3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo02<0oooo000g0?ooo`040000003oool0oooo000001h0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0R0?ooo`00=`3oool010000000oooo0?ooo`00000N
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool08P3oool003L0oooo00@000000?oo
o`3oool000007@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0240oooo000f0?oo
o`050000003oool0oooo0?ooo`000000703oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo0240oooo000f0?ooo`050000003oool0oooo0?ooo`000000703oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo0200oooo000f0?ooo`050000003oool0oooo0?ooo`0000006`3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0200oooo000e0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
0200oooo000e0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo01l0oooo000e0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01l0oooo
000e0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01h0oooo000d0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo01h0oooo000d0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01d0oooo000d0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo01d0oooo000d0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01`0oooo000d0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo01`0oooo000d0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo01/0oooo000d0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01/0
oooo000c0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo01X0oooo000c0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01X0oooo000c
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo01T0oooo000c0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01T0oooo000c0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo01P0oooo000c0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01P0oooo000c0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo01L0oooo000c0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01L0oooo000c0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
01L0oooo000c0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo01H0oooo000c0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01H0oooo
000c0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo01H0oooo000c0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01D0oooo000c0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo01D0oooo000c0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo000c0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo01@0oooo000c0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01@0oooo000c0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo01@0oooo000c0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo01<0oooo000c0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01<0
oooo000d0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo01<0oooo000d0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0180oooo000d
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo0180oooo000d0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0180oooo000d0?ooo`03
0000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo000000140?ooo`030000003oool0oooo
0180oooo000e0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000150?oo
o`030000003oool0oooo0140oooo000e0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3o
ool0oooo000000150?ooo`030000003oool0oooo0140oooo000e0?ooo`030000003oool0oooo00P0
oooo00D000000?ooo`3oool0oooo000000150?ooo`030000003oool0oooo0140oooo000e0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`000000AP3oool00`000000oooo0?ooo`0A0?ooo`00
=P3oool00`000000oooo0?ooo`080?ooo`030000003oool0000004L0oooo00<000000?ooo`3oool0
403oool003H0oooo00<000000?ooo`3oool0203oool00`000000oooo000000170?ooo`030000003o
ool0oooo0100oooo000g0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0@0?ooo`00=`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool03`3oool003P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000h0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00>@3oool00`000000oooo0?oo
o`060?ooo`800000B@3oool00`000000oooo0?ooo`0>0?ooo`00>@3oool00`000000oooo0?ooo`06
0?ooo`800000B@3oool00`000000oooo0?ooo`0>0?ooo`00>P3oool00`000000oooo0?ooo`050?oo
o`800000B@3oool00`000000oooo0?ooo`0>0?ooo`00>P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0000004P0oooo00<000000?ooo`3oool03P3oool003/0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000190?ooo`030000003oool0oooo00d0oooo000l0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000B@3oool00`000000oooo0?ooo`0=0?ooo`00
?@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0=0?ooo`00?P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool0303oool003l0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo00`0oooo00100?ooo`800000103oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo00`0oooo00110?ooo`8000000`3oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo00`0oooo00110?ooo`030000003oool000000080oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`0;0?ooo`00@@3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool02`3oool00440oooo00L000000?ooo`3o
ool0oooo0000003oool0000004P0oooo00<000000?ooo`3oool02`3oool00440oooo00<000000?oo
o`3oool00P3oool2000004P0oooo00<000000?ooo`3oool02`3oool00440oooo00<000000?ooo`3o
ool00`3oool2000004L0oooo00<000000?ooo`3oool02`3oool00440oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00X0oooo00120?ooo`030000003o
ool0oooo00<0oooo0P0000170?ooo`030000003oool0oooo00X0oooo00120?ooo`030000003oool0
oooo00@0oooo0`0000150?ooo`030000003oool0oooo00X0oooo00120?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool00000A03oool00`000000oooo0?ooo`0:0?ooo`00@P3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`800000@P3oool00`000000oooo0?ooo`0:
0?ooo`00@P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0P0000110?oo
o`030000003oool0oooo00T0oooo00120?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00T0oooo00120?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool2000003h0oooo00<000000?ooo`3oool0
2@3oool00480oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool02@3oool00480oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`070?ooo`800000>`3oool00`000000oooo0?ooo`090?ooo`00@`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo0P00000i0?ooo`030000003oool0oooo
00T0oooo00130?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool2000003P0
oooo00<000000?ooo`3oool0203oool004<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0<0?ooo`<00000=@3oool00`000000oooo0?ooo`080?ooo`00@`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00h0oooo0P00000c0?ooo`030000003oool0oooo00P0oooo0014
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool200000340oooo00<00000
0?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?oo
o`<00000;P3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01@0oooo0`00000/0?ooo`030000003oool0oooo00L0oooo00140?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool05`3oool3000002T0oooo00<000000?ooo`3oool0
1`3oool004@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0I0?ooo`<000009P3o
ool00`000000oooo0?ooo`070?ooo`00A@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01`0oooo0`00000S0?ooo`030000003oool0oooo00L0oooo00150?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool07P3oool300000200oooo00<000000?ooo`3oool01`3oool004D0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Q0?ooo`@00000703oool00`000000
oooo0?ooo`070?ooo`00AP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02@0oooo
1@00000G0?ooo`030000003oool0oooo00L0oooo00160?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0:@3oool4000001<0oooo00<000000?ooo`3oool01`3oool004L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0]0?ooo`@00000403oool00`000000oooo0?ooo`06
0?ooo`00A`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0300oooo1@00000;0?oo
o`030000003oool0oooo00H0oooo00180?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0=@3oool5000000H0oooo00<000000?ooo`3oool01P3oool004P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0i0?ooo`D0000000<0oooo0000003oool01`3oool004T0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0n0?ooo`800000203oool004T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00H0oooo001:0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`060?oo
o`00BP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool01P3oool004/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo00H0oooo001;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`060?ooo`00C03oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool01P3oool004d0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00H0oooo001>0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`060?ooo`00CP3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool01P3oool004l0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00H0oooo001@
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`06
0?ooo`00D@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool01P3oool00540oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`060?ooo`00D`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool01P3oool005@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`060?ooo`00EP3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool01P3oool005L0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00H0oooo
001H0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`060?ooo`00F@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool01P3oool005X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo00H0oooo001K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`070?ooo`00G03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool01`3oool005d0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00L0oooo001N0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`070?ooo`00G`3oool20000
0080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`070?ooo`00H@3oool010000000
oooo0?ooo`00000_0?ooo`030000003oool0oooo00L0oooo001R0?ooo`040000003oool0oooo0000
02d0oooo00<000000?ooo`3oool0203oool006<0oooo00<000000?ooo`000000;@3oool00`000000
oooo0?ooo`080?ooo`00I03oool3000002`0oooo00<000000?ooo`3oool0203oool006H0oooo0P00
000[0?ooo`030000003oool0oooo00P0oooo001W0?ooo`800000:@3oool00`000000oooo0?ooo`09
0?ooo`00J03oool2000002P0oooo00<000000?ooo`3oool02@3oool006T0oooo0P00000W0?ooo`03
0000003oool0oooo00T0oooo001[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
2P3oool006`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0:0?ooo`00K@3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00X0oooo001^0?ooo`800000803oool00`00
0000oooo0?ooo`0;0?ooo`00L03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00/0
oooo001a0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0303oool00780oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0=0?ooo`00L`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00h0oooo001d0?ooo`8000005P3oool00`000000oooo0?ooo`0?0?oo
o`00MP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00l0oooo001g0?ooo`800000
4P3oool00`000000oooo0?ooo`0@0?ooo`00N@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0140oooo001j0?ooo`@000002@3oool3000001@0oooo001n0?ooo`T000005`3oool009h0
oooo002N0?ooo`00WP3oool009h0oooo002N0?ooo`00WP3oool009h0oooo002N0?ooo`00WP3oool0
09h0oooo002N0?ooo`00WP3oool009h0oooo002N0?ooo`00WP3oool009h0oooo002N0?ooo`00WP3o
ool009h0oooo002N0?ooo`00WP3oool009h0oooo002N0?ooo`00WP3oool009h0oooo002N0?ooo`00
WP3oool009h0oooo002N0?ooo`00WP3oool009h0oooo002N0?ooo`00WP3oool009h0oooo002N0?oo
o`00WP3oool009h0oooo002N0?ooo`00WP3oool009h0oooo002N0?ooo`00WP3oool009h0oooo002N
0?ooo`00WP3oool009h0oooo002N0?ooo`00WP3oool009h0oooo0000\
\>"],
  ImageRangeCache->{{{0, 157.625}, {287, 0}} -> {0.206458, -0.00154752, \
0.00338816, 0.00338816}},
  CellTags->"LinearPolarizer with user-defined surface"],

Cell[BoxData[
    TagBox[\(DrawSystem[{LinearPolarizer[#1\^2\/100 + #2\^2\/100 &, 90, 
            100]}]\),
      HoldForm]], "Print",
  CellTags->"LinearPolarizer with user-defined surface"],

Cell[BoxData[
    \("-rendered unpropagated system-"\)], "Output",
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[LinearPolarizer[Function[#1^2/100+#2^2/100], 90, 100, \
5]];\
\>", "Input",
  CellTags->"LinearPolarizer with user-defined surface"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.72577 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.344566 1.7853 2.22045e-16 1.7853 [
[ 0 0 0 0 ]
[ 1 1.72577 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.72577 L
0 1.72577 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.85447 .88769 m
.83598 .82244 L
s
.83598 .82244 m
.8596 .81494 L
s
.83598 .82244 m
.81473 .75784 L
s
.81473 .75784 m
.8383 .75017 L
s
.81473 .75784 m
.79094 .6946 L
s
.86997 .95284 m
.85447 .88769 L
s
.85447 .88769 m
.87817 .88033 L
s
.87817 .88033 m
.8596 .81494 L
s
.8596 .81494 m
.88332 .80739 L
s
.8596 .81494 m
.8383 .75017 L
s
.79094 .6946 m
.81451 .68677 L
s
.79094 .6946 m
.76487 .63345 L
s
.8383 .75017 m
.86198 .74247 L
s
.81451 .68677 m
.8383 .75017 L
s
.89379 .94561 m
.87817 .88033 L
s
.87817 .88033 m
.90197 .87293 L
s
.88332 .80739 m
.90197 .87293 L
s
.86198 .74247 m
.88332 .80739 L
s
.81451 .68677 m
.83819 .67889 L
s
.81451 .68677 m
.78847 .62543 L
s
.88227 1.01716 m
.86997 .95284 L
s
.86997 .95284 m
.89379 .94561 L
s
.83819 .67889 m
.86198 .74247 L
s
.90197 .87293 m
.91772 .93835 L
s
.76487 .63345 m
.78847 .62543 L
s
.76487 .63345 m
.73678 .57512 L
s
.81219 .61737 m
.83819 .67889 L
s
.90625 1.01005 m
.89379 .94561 L
s
.89379 .94561 m
.91772 .93835 L
s
.78847 .62543 m
.81219 .61737 L
s
.78847 .62543 m
.76046 .56691 L
s
.91772 .93835 m
.93034 1.00291 L
s
.89117 1.07989 m
.88227 1.01716 L
s
.88227 1.01716 m
.90625 1.01005 L
s
.78427 .55865 m
.81219 .61737 L
s
.91535 1.07288 m
.90625 1.01005 L
s
.90625 1.01005 m
.93034 1.00291 L
s
.73678 .57512 m
.76046 .56691 L
s
.73678 .57512 m
.70697 .52034 L
s
.93034 1.00291 m
.93965 1.06584 L
s
.76046 .56691 m
.78427 .55865 L
s
.76046 .56691 m
.73077 .51193 L
s
.89117 1.07989 m
.91535 1.07288 L
s
.7547 .50347 m
.78427 .55865 L
s
.91535 1.07288 m
.93965 1.06584 L
s
.70697 .52034 m
.73077 .51193 L
s
.70697 .52034 m
.67576 .46987 L
s
.73077 .51193 m
.7547 .50347 L
s
.73077 .51193 m
.69972 .46125 L
s
.7238 .45258 m
.7547 .50347 L
s
.78414 1.11867 m .92092 1.13331 L .8965 1.14023 L .656 .751 .92 r
F
0 g
.8965 1.14023 m
.89809 1.19739 L
s
.89117 1.07989 m
.89565 1.13061 L
s
.80846 1.11164 m .94545 1.12635 L .92092 1.13331 L .656 .751 .92 r
F
0 g
.91535 1.07288 m
.92002 1.12362 L
s
.78414 1.11867 m .80846 1.11164 L .92092 1.13331 L .656 .751 .92 r
F
0 g
.8965 1.14023 m
.92092 1.13331 L
s
.92092 1.13331 m
.92277 1.19053 L
s
.67576 .46987 m
.69972 .46125 L
s
.80846 1.11164 m .8329 1.10458 L .94545 1.12635 L .656 .751 .92 r
F
0 g
.94545 1.12635 m
.94758 1.18364 L
s
.92092 1.13331 m
.94545 1.12635 L
s
.93965 1.06584 m
.94545 1.12635 L
s
.69972 .46125 m
.7238 .45258 L
s
.68346 1.09281 m .80846 1.11164 L .78414 1.11867 L .656 .751 .92 r
F
0 g
.78414 1.11867 m
.8965 1.14023 L
s
.70775 1.08565 m .8329 1.10458 L .80846 1.11164 L .656 .751 .92 r
F
.68346 1.09281 m .70775 1.08565 L .80846 1.11164 L F
0 g
.80846 1.11164 m
.92092 1.13331 L
s
.89579 1.2505 m
.89809 1.19739 L
s
.89809 1.19739 m
.92277 1.19053 L
s
.70775 1.08565 m .73217 1.07845 L .8329 1.10458 L .656 .751 .92 r
F
0 g
.8329 1.10458 m
.94545 1.12635 L
s
.92078 1.2437 m
.92277 1.19053 L
s
.92277 1.19053 m
.94758 1.18364 L
s
.6435 .42447 m .59483 .51014 L .57073 .51879 L .544 .324 .532 r
F
.6435 .42447 m .66765 .41563 L .59483 .51014 L F
0 g
.65182 .43618 m
.67576 .46987 L
s
.94758 1.18364 m
.94589 1.23686 L
s
.59437 1.06242 m .70775 1.08565 L .68346 1.09281 L .656 .751 .92 r
F
0 g
.68346 1.09281 m
.78414 1.11867 L
s
.66765 .41563 m .61905 .50145 L .59483 .51014 L .544 .324 .532 r
F
.66765 .41563 m .69193 .40674 L .61905 .50145 L F
0 g
.6435 .42447 m
.66765 .41563 L
s
.61057 .3849 m
.6435 .42447 L
s
.67598 .42747 m
.69972 .46125 L
s
.63495 .37585 m
.66765 .41563 L
s
.66765 .41563 m
.69193 .40674 L
s
.69193 .40674 m
.7238 .45258 L
s
.61869 1.05511 m .73217 1.07845 L .70775 1.08565 L .656 .751 .92 r
F
.59437 1.06242 m .61869 1.05511 L .70775 1.08565 L F
0 g
.70775 1.08565 m
.80846 1.11164 L
s
.65946 .36674 m
.69193 .40674 L
s
.57073 .51879 m .53464 .60094 L .51054 .60942 L .544 .324 .532 r
F
.57073 .51879 m .59483 .51014 L .53464 .60094 L F
0 g
.57073 .51879 m
.6435 .42447 L
s
.61869 1.05511 m .64314 1.04775 L .73217 1.07845 L .656 .751 .92 r
F
0 g
.73217 1.07845 m
.8329 1.10458 L
s
.88949 1.29872 m
.89579 1.2505 L
s
.89579 1.2505 m
.92078 1.2437 L
s
.59483 .51014 m .55887 .59243 L .53464 .60094 L .544 .324 .532 r
F
.59483 .51014 m .61905 .50145 L .55887 .59243 L F
0 g
.59483 .51014 m
.66765 .41563 L
s
.61905 .50145 m
.69193 .40674 L
s
.91481 1.29194 m
.92078 1.2437 L
s
.92078 1.2437 m
.94589 1.23686 L
s
.51054 .60942 m .48709 .68835 L .46291 .69667 L .544 .324 .532 r
F
.51054 .60942 m .53464 .60094 L .48709 .68835 L F
0 g
.51054 .60942 m
.57073 .51879 L
s
.51685 1.02722 m .61869 1.05511 L .59437 1.06242 L .656 .751 .92 r
F
0 g
.59437 1.06242 m
.68346 1.09281 L
s
.94589 1.23686 m
.94025 1.28514 L
s
.61057 .3849 m
.63495 .37585 L
s
.61057 .3849 m
.5774 .35195 L
s
.53464 .60094 m .51139 .67999 L .48709 .68835 L .544 .324 .532 r
F
.53464 .60094 m .55887 .59243 L .51139 .67999 L F
0 g
.53464 .60094 m
.59483 .51014 L
s
.55887 .59243 m
.61905 .50145 L
s
.54128 1.01973 m .64314 1.04775 L .61869 1.05511 L .656 .751 .92 r
F
.51685 1.02722 m .54128 1.01973 L .61869 1.05511 L F
0 g
.61869 1.05511 m
.70775 1.08565 L
s
.63495 .37585 m
.65946 .36674 L
s
.63495 .37585 m
.60205 .34267 L
s
.54128 1.01973 m .56583 1.01219 L .64314 1.04775 L .656 .751 .92 r
F
0 g
.64314 1.04775 m
.73217 1.07845 L
s
.62683 .33336 m
.65946 .36674 L
s
.46291 .69667 m .45228 .77265 L .42795 .78083 L .544 .324 .532 r
F
.46291 .69667 m .48709 .68835 L .45228 .77265 L F
0 g
.46291 .69667 m
.51054 .60942 L
s
.87912 1.34115 m
.88949 1.29872 L
s
.88949 1.29872 m
.91481 1.29194 L
s
.48709 .68835 m .47673 .76443 L .45228 .77265 L .544 .324 .532 r
F
.48709 .68835 m .51139 .67999 L .47673 .76443 L F
0 g
.48709 .68835 m
.53464 .60094 L
s
.51139 .67999 m
.55887 .59243 L
s
.90479 1.33438 m
.91481 1.29194 L
s
.91481 1.29194 m
.94025 1.28514 L
s
.45102 .98688 m .54128 1.01973 L .51685 1.02722 L .656 .751 .92 r
F
0 g
.51685 1.02722 m
.59437 1.06242 L
s
.94025 1.28514 m
.93059 1.32758 L
s
.47561 .97918 m .56583 1.01219 L .54128 1.01973 L .656 .751 .92 r
F
.45102 .98688 m .47561 .97918 L .54128 1.01973 L F
0 g
.54128 1.01973 m
.61869 1.05511 L
s
.5774 .35195 m
.60205 .34267 L
s
.5774 .35195 m
.54446 .32636 L
s
.47561 .97918 m .50033 .97143 L .56583 1.01219 L .656 .751 .92 r
F
0 g
.56583 1.01219 m
.64314 1.04775 L
s
.60205 .34267 m
.62683 .33336 L
s
.60205 .34267 m
.5694 .31688 L
s
.42795 .78083 m .43043 .85413 L .40589 .86219 L .544 .324 .532 r
F
.42795 .78083 m .45228 .77265 L .43043 .85413 L F
0 g
.42795 .78083 m
.46291 .69667 L
s
.59448 .30735 m
.62683 .33336 L
s
.45228 .77265 m .4551 .84603 L .43043 .85413 L .544 .324 .532 r
F
.45228 .77265 m .47673 .76443 L .4551 .84603 L F
0 g
.45228 .77265 m
.48709 .68835 L
s
.47673 .76443 m
.51139 .67999 L
s
.86463 1.37689 m
.87912 1.34115 L
s
.87912 1.34115 m
.90479 1.33438 L
s
.39706 .941 m .47561 .97918 L .45102 .98688 L .656 .751 .92 r
F
0 g
.45102 .98688 m
.51685 1.02722 L
s
.89067 1.37011 m
.90479 1.33438 L
s
.90479 1.33438 m
.93059 1.32758 L
s
.4219 .93305 m .50033 .97143 L .47561 .97918 L .656 .751 .92 r
F
.39706 .941 m .4219 .93305 L .47561 .97918 L F
0 g
.47561 .97918 m
.54128 1.01973 L
s
.40589 .86219 m .4219 .93305 L .39706 .941 L .544 .324 .532 r
F
.40589 .86219 m .43043 .85413 L .4219 .93305 L F
0 g
.40589 .86219 m
.42795 .78083 L
s
.93059 1.32758 m
.91686 1.3633 L
s
.54446 .32636 m
.5694 .31688 L
s
.54446 .32636 m
.51225 .30888 L
s
.4219 .93305 m .44686 .92506 L .50033 .97143 L .656 .751 .92 r
F
0 g
.50033 .97143 m
.56583 1.01219 L
s
.43043 .85413 m .44686 .92506 L .4219 .93305 L .544 .324 .532 r
F
.43043 .85413 m .4551 .84603 L .44686 .92506 L F
0 g
.43043 .85413 m
.45228 .77265 L
s
.4551 .84603 m
.47673 .76443 L
s
.5694 .31688 m
.59448 .30735 L
s
.5694 .31688 m
.53752 .2992 L
s
.56292 .28946 m
.59448 .30735 L
s
.84606 1.40507 m
.86463 1.37689 L
s
.86463 1.37689 m
.89067 1.37011 L
s
.39706 .941 m .42716 1.00967 L .40195 1.01753 L .544 .324 .532 r
F
.39706 .941 m .4219 .93305 L .42716 1.00967 L F
0 g
.42402 .96393 m
.45102 .98688 L
s
.35531 .88911 m .4219 .93305 L .39706 .941 L .656 .751 .92 r
F
0 g
.3996 .91834 m
.40589 .86219 L
s
.8725 1.39825 m
.89067 1.37011 L
s
.89067 1.37011 m
.91686 1.3633 L
s
.4219 .93305 m .45251 1.00177 L .42716 1.00967 L .544 .324 .532 r
F
.4219 .93305 m .44686 .92506 L .45251 1.00177 L F
0 g
.44918 .95648 m
.47561 .97918 L
s
.38046 .88088 m .44686 .92506 L .4219 .93305 L .656 .751 .92 r
F
0 g
.42438 .9101 m
.43043 .85413 L
s
.35531 .88911 m .38046 .88088 L .4219 .93305 L .656 .751 .92 r
F
0 g
.91686 1.3633 m
.89907 1.3914 L
s
.51225 .30888 m
.53752 .2992 L
s
.51225 .30888 m
.48134 .30019 L
s
.38046 .88088 m .40575 .87261 L .44686 .92506 L .656 .751 .92 r
F
0 g
.44686 .92506 m
.50033 .97143 L
s
.44686 .92506 m
.4551 .84603 L
s
.53752 .2992 m
.56292 .28946 L
s
.53752 .2992 m
.50695 .29031 L
s
.5327 .28039 m
.56292 .28946 L
s
.40195 1.01753 m .44687 1.08423 L .42119 1.09202 L .544 .324 .532 r
F
.40195 1.01753 m .42716 1.00967 L .44687 1.08423 L F
0 g
.39706 .941 m
.40195 1.01753 L
s
.8725 1.39825 m
.84606 1.40507 L
s
.82351 1.42483 m
.84606 1.40507 L
s
.42716 1.00967 m .47269 1.07641 L .44687 1.08423 L .544 .324 .532 r
F
.42716 1.00967 m .45251 1.00177 L .47269 1.07641 L F
0 g
.4219 .93305 m
.42716 1.00967 L
s
.44686 .92506 m
.45251 1.00177 L
s
.32621 .83065 m .38046 .88088 L .35531 .88911 L .656 .751 .92 r
F
0 g
.35531 .88911 m
.39706 .941 L
s
.89907 1.3914 m
.8725 1.39825 L
s
.85034 1.41795 m
.8725 1.39825 L
s
.35177 .8221 m .40575 .87261 L .38046 .88088 L .656 .751 .92 r
F
.32621 .83065 m .35177 .8221 L .38046 .88088 L F
0 g
.38046 .88088 m
.4219 .93305 L
s
.89907 1.3914 m
.87731 1.41103 L
s
.48134 .30019 m
.50695 .29031 L
s
.48134 .30019 m
.4523 .30087 L
s
.35177 .8221 m .37748 .8135 L .40575 .87261 L .656 .751 .92 r
F
0 g
.40575 .87261 m
.44686 .92506 L
s
.50695 .29031 m
.5327 .28039 L
s
.50695 .29031 m
.47827 .29083 L
s
.50439 .28073 m
.5327 .28039 L
s
.42119 1.09202 m .48183 1.15699 L .45559 1.16471 L .544 .324 .532 r
F
.42119 1.09202 m .44687 1.08423 L .48183 1.15699 L F
0 g
.40195 1.01753 m
.42119 1.09202 L
s
.79716 1.43539 m
.82351 1.42483 L
s
.82351 1.42483 m
.85034 1.41795 L
s
.44687 1.08423 m .50822 1.14922 L .48183 1.15699 L .544 .324 .532 r
F
.44687 1.08423 m .47269 1.07641 L .50822 1.14922 L F
0 g
.42716 1.00967 m
.44687 1.08423 L
s
.45251 1.00177 m
.47269 1.07641 L
s
.82438 1.42842 m
.85034 1.41795 L
s
.85034 1.41795 m
.87731 1.41103 L
s
.31039 .76496 m .35177 .8221 L .32621 .83065 L .656 .751 .92 r
F
0 g
.32621 .83065 m
.35531 .88911 L
s
.87731 1.41103 m
.85176 1.42141 L
s
.4523 .30087 m
.47827 .29083 L
s
.4523 .30087 m
.42574 .31143 L
s
.31039 .76496 m .33645 .75604 L .35177 .8221 L .656 .751 .92 r
F
.33645 .75604 m .37748 .8135 L .35177 .8221 L F
0 g
.35177 .8221 m
.38046 .88088 L
s
.47827 .29083 m
.50439 .28073 L
s
.47827 .29083 m
.4521 .30124 L
s
.33645 .75604 m .36266 .74707 L .37748 .8135 L .656 .751 .92 r
F
0 g
.37748 .8135 m
.40575 .87261 L
s
.47861 .29099 m
.50439 .28073 L
s
.45559 1.16471 m .53307 1.22818 L .50615 1.23585 L .544 .324 .532 r
F
.45559 1.16471 m .48183 1.15699 L .53307 1.22818 L F
0 g
.42119 1.09202 m
.45559 1.16471 L
s
.76729 1.43607 m
.79716 1.43539 L
s
.79716 1.43539 m
.82438 1.42842 L
s
.48183 1.15699 m .56014 1.22046 L .53307 1.22818 L .544 .324 .532 r
F
.48183 1.15699 m .50822 1.14922 L .56014 1.22046 L F
0 g
.44687 1.08423 m
.48183 1.15699 L
s
.47269 1.07641 m
.50822 1.14922 L
s
.7949 1.42898 m
.82438 1.42842 L
s
.82438 1.42842 m
.85176 1.42141 L
s
.85176 1.42141 m
.82267 1.42185 L
s
.42574 .31143 m
.4521 .30124 L
s
.42574 .31143 m
.40231 .33218 L
s
.30863 .69125 m .33645 .75604 L .31039 .76496 L .656 .751 .92 r
F
0 g
.31039 .76496 m
.32621 .83065 L
s
.4521 .30124 m
.47861 .29099 L
s
.4521 .30124 m
.42905 .32187 L
s
.3353 .68191 m .36266 .74707 L .33645 .75604 L .656 .751 .92 r
F
.30863 .69125 m .3353 .68191 L .33645 .75604 L F
0 g
.33645 .75604 m
.35177 .8221 L
s
.45595 .31151 m
.47861 .29099 L
s
.3353 .68191 m .36212 .67252 L .36266 .74707 L .656 .751 .92 r
F
0 g
.36266 .74707 m
.37748 .8135 L
s
.73429 1.42633 m
.76729 1.43607 L
s
.76729 1.43607 m
.7949 1.42898 L
s
.50615 1.23585 m .60183 1.29805 L .57411 1.30569 L .544 .324 .532 r
F
.50615 1.23585 m .53307 1.22818 L .60183 1.29805 L F
0 g
.45559 1.16471 m
.50615 1.23585 L
s
.76227 1.41909 m
.7949 1.42898 L
s
.7949 1.42898 m
.82267 1.42185 L
s
.53307 1.22818 m .62971 1.29036 L .60183 1.29805 L .544 .324 .532 r
F
.53307 1.22818 m .56014 1.22046 L .62971 1.29036 L F
0 g
.48183 1.15699 m
.53307 1.22818 L
s
.50822 1.14922 m
.56014 1.22046 L
s
.82267 1.42185 m
.79042 1.41181 L
s
.40231 .33218 m
.42905 .32187 L
s
.38261 .36325 m
.40231 .33218 L
s
.42905 .32187 m
.45595 .31151 L
s
.40974 .35286 m
.42905 .32187 L
s
.43704 .34241 m
.45595 .31151 L
s
.32193 .60859 m .3353 .68191 L .30863 .69125 L .656 .751 .92 r
F
0 g
.30863 .69125 m
.31039 .76496 L
s
.32193 .60859 m .34932 .59876 L .3353 .68191 L .656 .751 .92 r
F
.34932 .59876 m .36212 .67252 L .3353 .68191 L F
0 g
.3353 .68191 m
.33645 .75604 L
s
.69866 1.40584 m
.73429 1.42633 L
s
.73429 1.42633 m
.76227 1.41909 L
s
.34932 .59876 m .37688 .58888 L .36212 .67252 L .656 .751 .92 r
F
0 g
.36212 .67252 m
.36266 .74707 L
s
.72699 1.39842 m
.76227 1.41909 L
s
.76227 1.41909 m
.79042 1.41181 L
s
.79042 1.41181 m
.7555 1.39096 L
s
.38261 .36325 m
.40974 .35286 L
s
.38261 .36325 m
.36724 .40453 L
s
.57411 1.30569 m .68967 1.36687 L .66102 1.37449 L .544 .324 .532 r
F
.57411 1.30569 m .60183 1.29805 L .68967 1.36687 L F
0 g
.50615 1.23585 m
.57411 1.30569 L
s
.40974 .35286 m
.43704 .34241 L
s
.40974 .35286 m
.39476 .3941 L
s
.60183 1.29805 m .7185 1.3592 L .68967 1.36687 L .544 .324 .532 r
F
.60183 1.29805 m .62971 1.29036 L .7185 1.3592 L F
0 g
.57411 1.30569 m
.66102 1.37449 L
s
.53307 1.22818 m
.60183 1.29805 L
s
.60183 1.29805 m
.68967 1.36687 L
s
.56014 1.22046 m
.62971 1.29036 L
s
.42245 .3836 m
.43704 .34241 L
s
.62971 1.29036 m
.7185 1.3592 L
s
.66102 1.37449 m
.69866 1.40584 L
s
.69866 1.40584 m
.72699 1.39842 L
s
.68967 1.36687 m
.72699 1.39842 L
s
.72699 1.39842 m
.7555 1.39096 L
s
.7185 1.3592 m
.7555 1.39096 L
s
.36724 .40453 m
.39476 .3941 L
s
.36724 .40453 m
.35674 .45562 L
s
.35155 .51584 m .34932 .59876 L .32193 .60859 L .656 .751 .92 r
F
0 g
.30863 .69125 m
.32193 .60859 L
s
.39476 .3941 m
.42245 .3836 L
s
.39476 .3941 m
.38464 .44519 L
s
.35155 .51584 m .3798 .50545 L .34932 .59876 L .656 .751 .92 r
F
.3798 .50545 m .37688 .58888 L .34932 .59876 L F
0 g
.32193 .60859 m
.35155 .51584 L
s
.3353 .68191 m
.34932 .59876 L
s
.4127 .4347 m
.42245 .3836 L
s
.3798 .50545 m .40823 .495 L .37688 .58888 L .656 .751 .92 r
F
0 g
.36212 .67252 m
.37688 .58888 L
s
.34932 .59876 m
.3798 .50545 L
s
.37688 .58888 m
.40823 .495 L
s
.66102 1.37449 m
.68967 1.36687 L
s
.6221 1.33248 m
.66102 1.37449 L
s
.68967 1.36687 m
.7185 1.3592 L
s
.65103 1.32462 m
.68967 1.36687 L
s
.35674 .45562 m
.38464 .44519 L
s
.35155 .51584 m
.35674 .45562 L
s
.68014 1.31672 m
.7185 1.3592 L
s
.38464 .44519 m
.4127 .4347 L
s
.3798 .50545 m
.38464 .44519 L
s
.40823 .495 m
.4127 .4347 L
s
.58274 1.2803 m
.6221 1.33248 L
s
.6221 1.33248 m
.65103 1.32462 L
s
.6119 1.27219 m
.65103 1.32462 L
s
.65103 1.32462 m
.68014 1.31672 L
s
.35155 .51584 m
.3798 .50545 L
s
.35155 .51584 m
.35201 .58415 L
s
.68014 1.31672 m
.64124 1.26403 L
s
.3798 .50545 m
.40823 .495 L
s
.3798 .50545 m
.38059 .57386 L
s
.40823 .495 m
.40934 .5635 L
s
.54382 1.21882 m
.58274 1.2803 L
s
.58274 1.2803 m
.6119 1.27219 L
s
.57316 1.21043 m
.6119 1.27219 L
s
.6119 1.27219 m
.64124 1.26403 L
s
.35201 .58415 m
.38059 .57386 L
s
.35201 .58415 m
.3583 .65924 L
s
.64124 1.26403 m
.60268 1.20199 L
s
.38059 .57386 m
.40934 .5635 L
s
.38059 .57386 m
.38716 .64908 L
s
.5063 1.1492 m
.54382 1.21882 L
s
.54382 1.21882 m
.57316 1.21043 L
s
.4162 .63886 m
.40934 .5635 L
s
.53576 1.14053 m
.57316 1.21043 L
s
.57316 1.21043 m
.60268 1.20199 L
s
.3583 .65924 m
.38716 .64908 L
s
.3583 .65924 m
.37043 .73948 L
s
.60268 1.20199 m
.5654 1.1318 L
s
.38716 .64908 m
.4162 .63886 L
s
.38716 .64908 m
.39953 .7295 L
s
.47112 1.07295 m
.5063 1.1492 L
s
.5063 1.1492 m
.53576 1.14053 L
s
.42882 .71946 m
.4162 .63886 L
s
.37043 .73948 m
.38823 .82302 L
s
.39953 .7295 m
.37043 .73948 L
s
.50063 1.06399 m
.53576 1.14053 L
s
.53576 1.14053 m
.5654 1.1318 L
s
.39953 .7295 m
.42882 .71946 L
s
.39953 .7295 m
.41752 .81326 L
s
.43919 .99184 m
.47112 1.07295 L
s
.47112 1.07295 m
.50063 1.06399 L
s
.5654 1.1318 m
.53033 1.05498 L
s
.38823 .82302 m
.41752 .81326 L
s
.38823 .82302 m
.41133 .90784 L
s
.41133 .90784 m
.43919 .99184 L
s
.43919 .99184 m
.46869 .9826 L
s
.447 .80344 m
.42882 .71946 L
s
.46869 .9826 m
.50063 1.06399 L
s
.50063 1.06399 m
.53033 1.05498 L
s
.41133 .90784 m
.44075 .89833 L
s
.41752 .81326 m
.447 .80344 L
s
.41752 .81326 m
.44075 .89833 L
s
.44075 .89833 m
.46869 .9826 L
s
.46869 .9826 m
.49838 .9733 L
s
.53033 1.05498 m
.49838 .9733 L
s
.44075 .89833 m
.47037 .88876 L
s
.47037 .88876 m
.447 .80344 L
s
.49838 .9733 m
.47037 .88876 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{166.875, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002V000182000`400?l00000o`00003oYP3oool0
0:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3o
ool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00
YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?oo
o`00YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V
0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0oooo
002V0?ooo`00YP3oool00:H0oooo001B0?ooo`P00000C03oool00500oooo0P0000030?ooo`800000
0`3oool3000004T0oooo001>0?ooo`X000000`3oool4000004L0oooo001;0?ooo`@0000000@0oooo
00000000000000001@3oool3000000@0oooo0P0000150?ooo`00B@3oool:00000080oooo0`000003
0?ooo`800000103oool00`000000oooo0?ooo`120?ooo`00A`3oool300000080oooo00<000000?oo
o`3oool0103oool3000000L0oooo00<000000?ooo`3oool0100000120?ooo`00A@3oool200000003
0?ooo`0000000000008000002P3oool2000000D0oooo0`0000040?ooo`030000003oool0oooo03l0
oooo00140?ooo`030000003oool00000008000000P3oool00`000000oooo0?ooo`0:0?ooo`800000
00<0oooo0000000000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03h0oooo
00130?ooo`<0000000D0oooo0000003oool0oooo0000000?0?ooo`800000103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo03d0oooo00120?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool2000003h0oooo00120?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`020?ooo`040000003oool0000000000080oooo00<000000?ooo`3o
ool0>`3oool00440oooo00D000000?ooo`3oool000000?ooo`03000001D0oooo00<000000?ooo`3o
ool0100000040?ooo`030000003oool0oooo03X0oooo00100?ooo`030000003oool0000000<00000
0P3oool00`000000oooo0?ooo`0D0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo03T0oooo00100?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0h0?ooo`00?`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=`3o
ool003l0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`00000h0?ooo`00?P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`<000000P3o
ool00`000000oooo0?ooo`0f0?ooo`00?P3oool01@000000oooo0?ooo`3oool000000080oooo0P00
000M0?ooo`060000003oool000000000003oool00000103oool00`000000oooo0?ooo`0e0?ooo`00
?@3oool010000000oooo0?ooo`3oool4000000030?ooo`000000oooo01d0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo000m0?ooo`030000
003oool0oooo00800000103oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0c0?ooo`00?@3oool3000000030?ooo`00
0000oooo0080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0<P3oool003`0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool000000240oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`800000<`3oool003`0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool00P3oool01P000000oooo000000000000Re:8000003<0
oooo000l0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00<000000P2;DXP00`000000oooo0000000b0?ooo`00?03oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool08P3oool200000080Re:800<0000008]BR000
00000`3oool00`000000oooo0?ooo`0_0?ooo`00?03oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool08`3oool01@000000Re:808]BR0000000Re:800800000103oool00`00
0000oooo0?ooo`0^0?ooo`00>`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
0000903oool010000000Re:808]BR000000208]BR0800000103oool00`000000oooo0?ooo`0^0?oo
o`00>`3oool010000000oooo0?ooo`3oool4000000030?ooo`000000oooo0280oooo00@0000008]B
R02;DXP000000P2;DXP010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02d0oooo000k
0?ooo`030000003oool0000000800000103oool00`000000oooo0?ooo`0P0?ooo`040000002;DXP0
Re:800000080Re:800<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02`0oooo000k0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0200oooo00P0000008]BR02;DXP0000008]BR0000000oooo000000@0oooo00<000000?ooo`3o
ool00`00000]0?ooo`00>`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool07`3oool010000000Re:808]BR000000208]BR0030000003oool0000000@0oooo0`0000020?oo
o`030000003oool0oooo02/0oooo000k0?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`0N0?ooo`040000002;DXP0Re:800000080Re:800H000000?ooo`3oool0oooo0000
003oool2000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0:P3oool003/0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo01h0oooo00@0000008]BR02;DXP0
00000P2;DXP00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0Y0?ooo`00>`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool07P3oool00`000000Re:80000000208]BR0030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02T0
oooo000k0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0M0?ooo`04
0000002;DXP0Re:800000080Re:800<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0:03oool003X0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000001h0oooo00@0000008]BR02;DXP000000P2;DXP0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
000Z0?ooo`00>P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo008000007@3oool0
10000000Re:808]BR000000208]BR0030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02L0oooo000j0?ooo`030000003oool0
oooo0080oooo0`0000000`2W`>/000000?ooo`0L0?ooo`030000002;DXP000000080Re:800<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`800000:03o
ool003X0oooo00<000000?ooo`3oool00`0000030:O0j`030000003oool0oooo01X0oooo00<00000
08]BR00000000`2;DXP00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00H00000
0?ooo`00000000000?ooo`00000X0?ooo`00>P3oool300000080Yl3[00<000000:O0j`2W`>/00P00
000K0?ooo`040000002;DXP0Re:800000080Re:800<000000?ooo`3oool0303oool00`000000oooo
0?ooo`03000000@0oooo00<000000?ooo`3oool09@3oool003X0oooo00@000000:O0j`2W`>/0Yl3[
0P0000020:O0j`8000006P3oool010000000Re:808]BR000000208]BR0030000003oool0oooo00h0
oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09@3oool003X0oooo
00@000000:O0j`2W`>/0Yl3[0P0000020:O0j`8000006P3oool00`000000Re:80000000308]BR003
0000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo02@0oooo000i0?ooo`8000000`2W`>/2000000040:O0j`000000oooo000001T0
oooo00@0000008]BR02;DXP000000P2;DXP00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`0T0?ooo`00>@3oool200000080Yl3[00L000000:O0
j`000000Yl3[0000003oool0000001P0oooo00@0000008]BR02;DXP000000P2;DXP00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0S0?ooo`00>@3oool200000080Yl3[00L000000:O0j`000000Yl3[0000003oool0000001P0
oooo00@0000008]BR02;DXP000000P2;DXP00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo0000000U0?ooo`00>03oool01@000000Yl3[0000002W`>/0
00000080Yl3[0P0000020?ooo`030000003oool0oooo01D0oooo00@0000008]BR02;DXP000000P2;
DXP00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`0R0?ooo`00>03oool01@000000Yl3[0000002W`>/000000080Yl3[0P0000020?ooo`030000
003oool0oooo01@0oooo00@0000008]BR02;DXP000000P2;DXP00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000T0?ooo`00>03oool01@000000
Yl3[0000002W`>/000000080Yl3[0P0000000`3oool000000000000F0?ooo`040000002;DXP0Re:8
00000080Re:800<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool000000080oooo0`00
000S0?ooo`00=`3oool00`000000Yl3[0:O0j`02000000<0Yl3[0`0000000`3oool000000?ooo`0D
0?ooo`040000002;DXP0Re:800000080Re:800<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0400000080oooo00<000000?ooo`3oool08@3oool003L0oooo00<000000:O0j`2W`>/00P000002
0:O0j`8000000`3oool00`000000oooo0?ooo`0B0?ooo`040000002;DXP0Re:800000080Re:800<0
00000?ooo`3oool06@3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0P0?ooo`00=`3oool00`000000Yl3[0:O0j`04000000030:O0j`000000oooo0080oooo00<00000
0?ooo`3oool04P3oool010000000Re:808]BR000000208]BR0030000003oool0oooo01T0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000280oooo000f0?ooo`050000002W
`>/0Yl3[0:O0j`0000000`2W`>/2000000@0oooo00<000000?ooo`3oool0403oool010000000Re:8
08]BR000000208]BR0030000003oool0oooo01/0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo01l0oooo000f0?ooo`050000002W`>/0Yl3[0:O0j`0000000`2W`>/20000
00@0oooo00<000000?ooo`3oool03`3oool01`000000Re:808]BR02;DXP0000008]BR00000007P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool07`3oool003H0oooo00<0
00000:O0j`2W`>/00P0000030:O0j`800000103oool00`000000oooo0?ooo`0?0?ooo`040000002;
DXP0Re:800000080Re:800<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000008@3oool003D0oooo00@000000:O0j`2W`>/0Yl3[0P0000030:O0j`80
0000103oool00`000000oooo0?ooo`0>0?ooo`040000002;DXP0Re:800000080Re:800<000000?oo
o`3oool07P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool07P3oool0
03D0oooo00@000000:O0j`2W`>/0Yl3[0P0000030:O0j`800000103oool00`000000oooo0?ooo`0=
0?ooo`050000002;DXP0Re:808]BR00000000P2;DXP00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo0000000P0?ooo`00=@3oool010000000Yl3[0:O0
j`2W`>/200000080Yl3[00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0=0?ooo`04
0000002;DXP0Re:800000080Re:800<000000?ooo`3oool0803oool01@000000oooo0?ooo`3oool0
000000<0oooo0P00000O0?ooo`00=@3oool01P000000Yl3[0:O0j`000000Yl3[00000080Yl3[00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`0<0?ooo`050000002;DXP0Re:808]BR000
00000P2;DXP00`000000oooo0?ooo`0P0?ooo`060000003oool0oooo0?ooo`000000oooo0P000000
0`3oool000000?ooo`0N0?ooo`00=@3oool010000000Yl3[0:O0j`0000020:O0j`030000002W`>/0
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`040000002;DXP0
Re:800000080Re:800<000000?ooo`3oool08@3oool00`000000oooo0?ooo`03000000@0oooo00<0
00000?ooo`3oool0703oool003@0oooo00D000000:O0j`2W`>/0Yl3[000000020:O0j`030000002W
`>/000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`040000002;
DXP0Re:8000000<0Re:800<000000?ooo`3oool08P3oool200000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0L0?ooo`00=03oool01@000000Yl3[0:O0j`2W`>/000000080Yl3[
00<000000:O0j`0000000P3oool010000000oooo0?ooo`3oool2000000/0oooo00D0000008]BR02;
DXP0Re:80000000208]BR0030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo000d0?ooo`050000002W`>/0Yl3[0:O0
j`0000000P2W`>/00`000000Yl3[000000020?ooo`@0000000<0oooo0000003oool02P3oool01000
0000Re:808]BR000000208]BR0030000003oool0oooo02D0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo01/0oooo000d0?ooo`050000002W`>/0Yl3[0:O0j`0000000P2W
`>/00`000000Yl3[00000003000000@0oooo00<000000?ooo`3oool0203oool01@000000Re:808]B
R02;DXP000000080Re:800<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool06P3oool003@0oooo00D000000:O0j`2W`>/0Yl3[
000000020:O0j`<000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
00@0000008]BR02;DXP000000P2;DXP00`000000oooo0?ooo`0W0?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`0J0?ooo`00=03oool010000000Yl3[0:O0j`0000030:O0
j`8000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00D0000008]B
R02;DXP0Re:80000000208]BR0030000003oool0oooo02L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo000d0?ooo`040000002W`>/0Yl3[
000000<0Yl3[0P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool0
10000000Re:808]BR000000208]BR0030000003oool0oooo02T0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo01T0oooo000c0?ooo`050000002W`>/0Yl3[0:O0j`000000
0`2W`>/2000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`040000
002;DXP0Re:8000000<0Re:800<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo0?ooo`8000006P3oool003<0oooo00D000000:O0j`2W`>/0Yl3[000000040:O0
j`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`050000002;DXP0Re:808]BR00000000P2;DXP00`000000oooo0?ooo`0[0?ooo`060000003oool0
oooo0?ooo`000000oooo0P0000000`3oool000000?ooo`0I0?ooo`00<`3oool01@000000Yl3[0:O0
j`2W`>/0000000@0Yl3[00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00@0000008]BR02;DXP000000`2;DXP00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo00<000000`3oool00`000000oooo0?ooo`0H0?ooo`00<`3oool01@000000Yl3[
0:O0j`2W`>/0000000@0Yl3[00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00D0000008]BR02;DXP0Re:80000000208]BR0030000003oool0oooo
02d0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool003<0
oooo00D000000:O0j`2W`>/0Yl3[000000040:O0j`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000002;DXP0Re:8000000<0Re:800<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000006@3o
ool003<0oooo00D000000:O0j`2W`>/0Yl3[000000040:O0j`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0Re:800D0000008]BR02;DXP0
Re:80000000`0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0G0?oo
o`00<`3oool01@000000Yl3[0:O0j`2W`>/0000000@0Yl3[00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`2;DXP010000000Re:808]BR000
000a0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0F0?ooo`00<`3o
ool01@000000Yl3[0:O0j`2W`>/0000000@0Yl3[00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`3oool200000080oooo00D0000008]BR02;DXP0Re:80000000308]BR0030000003oool0oooo
02l0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000001P0oooo000c0?oo
o`050000002W`>/0Yl3[0:O0j`000000102W`>/2000000@0oooo100000001@3oool000000?ooo`3o
ool0000000<0Re:800D0000008]BR02;DXP0Re:80000000b0?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`0F0?ooo`00<`3oool01@000000Yl3[0:O0j`2W`>/0000000@0
Yl3[0P0000030?ooo`800000103oool010000000oooo0?ooo`00000308]BR0040000002;DXP0Re:8
000003<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000H0?ooo`00<`3oool0
1@000000Yl3[0:O0j`2W`>/0000000@0Yl3[1@0000000`3oool000000?ooo`040?ooo`8000000`2;
DXP01@000000Re:808]BR02;DXP0000003<0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000001L0oooo000c0?ooo`050000002W`>/0Yl3[0:O0j`000000102W`>/2000000@0
oooo00<000000?ooo`3oool00`3oool2000000<0Re:800D0000008]BR02;DXP0Re:80000000d0?oo
o`050000003oool0oooo0?ooo`0000000P3oool2000001L0oooo000c0?ooo`050000002W`>/0Yl3[
0:O0j`000000102W`>/2000000D0oooo00<000000?ooo`3oool00P3oool00`000000Re:808]BR002
08]BR0040000002;DXP0Re:8000003D0oooo00@000000?ooo`3oool0oooo0`0000000`3oool00000
0?ooo`0F0?ooo`00<`3oool01@000000Yl3[0:O0j`2W`>/0000000@0Yl3[0P0000050?ooo`030000
003oool0oooo0080oooo00D0000008]BR02;DXP0Re:80000000308]BR0030000003oool0oooo03<0
oooo00H000000?ooo`00000000000?ooo`0000030?ooo`030000003oool0oooo01@0oooo000c0?oo
o`050000002W`>/0Yl3[0:O0j`000000102W`>/00`000000oooo000000040?ooo`040000003oool0
oooo0?ooo`8000000`2;DXP01@000000Re:808]BR02;DXP0000003H0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo01@0oooo000c0?ooo`050000002W`>/0Yl3[0:O0j`00
0000102W`>/00`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000Re:800000002
08]BR0040000002;DXP0Re:8000003L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00000F0?ooo`00<`3oool00`000000Yl3[0:O0j`020:O0j`030000002W`>/0Yl3[0080Yl3[0P00
00040?ooo`090000003oool0oooo0?ooo`000000Re:80000002;DXP0000000<0Re:800<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000005@3oool0
03<0oooo00<000000:O0j`2W`>/00P2W`>/00`000000Yl3[0:O0j`020:O0j`8000001@3oool00`00
0000oooo0000000208]BR0030000002;DXP0000000<0Re:800<000000?ooo`3oool0=P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool04`3oool003@0oooo00D000000:O0
j`2W`>/0Yl3[000000040:O0j`030000003oool0000000@0oooo00<000000?ooo`0000000P2;DXP0
0`000000Re:80000000208]BR0030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`00000E0?ooo`00=03oool00`000000Yl3[0:O0j`020:O0j`070000002W`>/0
Yl3[0:O0j`000000oooo000000040?ooo`030000003oool000000080Re:80P00000308]BR0030000
003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000001@0
oooo000d0?ooo`030000002W`>/0Yl3[0080Yl3[00L000000:O0j`2W`>/0Yl3[0000003oool00000
00@0oooo0P00000408]BR0050000002;DXP0Re:808]BR0000000>P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool04P3oool003D0oooo00D000000:O0j`2W`>/0Yl3[0000
00040:O0j`800000103oool2000000<0Re:80P00000208]BR0030000003oool0oooo03T0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0180oooo000e0?ooo`050000002W
`>/0Yl3[0:O0j`000000102W`>/2000000D0oooo1P00000208]BR0030000003oool0oooo03T0oooo
00<000000?ooo`3oool00P3oool00`000000oooo00000002000001<0oooo000e0?ooo`030000002W
`>/0Yl3[0080Yl3[00L000000:O0j`2W`>/0Yl3[0000003oool000000080oooo0`00000308]BR080
00000P2;DXP00`000000oooo0?ooo`0j0?ooo`030000003oool0000000<000000P3oool00`000000
oooo0?ooo`0A0?ooo`00=@3oool00`000000Yl3[0:O0j`020:O0j`060000002W`>/0Yl3[0:O0j`00
0000oooo0`0000020?ooo`060000002;DXP0Re:808]BR0000000Re:80P00000m0?ooo`8000000P3o
ool01@000000oooo0?ooo`3oool0000001<0oooo000f0?ooo`050000002W`>/0Yl3[0:O0j`000000
102W`>/2000000<0oooo0P00000308]BR0040000002;DXP00000000003d0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo0100oooo000f0?ooo`030000002W`>/0Yl3[0080
Yl3[00@000000:O0j`2W`>/0Yl3[0P0000030?ooo`050000002;DXP0000008]BR00000000P2;DXP2
000003d0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000180oooo000f
0?ooo`030000002W`>/0Yl3[0080Yl3[00<000000:O0j`2W`>/00P2W`>/200000080oooo00D00000
08]BR0000000Re:80000000208]BR0800000?P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool0403oool003L0oooo00<000000:O0j`2W`>/00P2W`>/010000000Yl3[0:O0
j`2W`>/200000080oooo00D0000008]BR0000000Re:80000000208]BR0800000?P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool03`3oool003L0oooo00<000000:O0j`2W
`>/00P2W`>/00`000000Yl3[0:O0j`020:O0j`040000003oool0oooo00000080Re:800@0000008]B
R02;DXP0Re:80P00000n0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
000A0?ooo`00>03oool00`000000Yl3[0:O0j`020:O0j`040000002W`>/0Yl3[0:O0j`<000000`2;
DXP010000000Re:808]BR02;DXP2000003l0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo00l0oooo000h0?ooo`030000002W`>/0Yl3[0080Yl3[00<000000:O0j`2W`>/0
0P2W`>/2000000<0Re:800L0000008]BR02;DXP0Re:80000003oool0000003h0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo00l0oooo000h0?ooo`030000002W`>/0Yl3[
00<0Yl3[00@000000:O0j`2W`>/0Yl3[0P00000308]BR0070000002;DXP0Re:808]BR0000000oooo
0000000n0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0>0?ooo`00
>@3oool00`000000Yl3[0:O0j`020:O0j`040000002W`>/0Yl3[0:O0j`8000000`2;DXP200000080
Re:800<000000?ooo`000000?P3oool00`000000oooo0?ooo`020?ooo`030000003oool000000080
0000403oool003T0oooo00<000000:O0j`2W`>/00`2W`>/01@000000Yl3[0:O0j`2W`>/0000000<0
Re:80P00000208]BR0040000003oool0oooo000003h0oooo00<000000?ooo`0000000`0000020?oo
o`030000003oool0oooo00h0oooo000j0?ooo`030000002W`>/0Yl3[0080Yl3[00@000000:O0j`2W
`>/0Yl3[0P0000001P2;DXP0000008]BR0000000Re:800000080oooo0P00000n0?ooo`8000000P3o
ool01@000000oooo0?ooo`3oool000000100oooo000j0?ooo`030000002W`>/0Yl3[00<0Yl3[00D0
00000:O0j`2W`>/000000:O0j`0200000080Re:8100000000`3oool000000?ooo`0m0?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0=0?ooo`00>`3oool00`000000Yl3[
0:O0j`030:O0j`050000002W`>/0Yl3[0000002W`>/01@0000030?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000l0oooo000l0?ooo`03
0000002W`>/0Yl3[0080Yl3[00<000000:O0j`2W`>/0100000000`2;DXP00000000000040?ooo`03
0000003oool0oooo03`0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00d0oooo000m0?ooo`030000002W`>/0Yl3[0080Yl3[00H000000:O0j`000000Yl3[0000002W`>/3
000000@0oooo00<000000?ooo`3oool0?03oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0303oool003h0oooo00<000000:O0j`2W`>/00P2W`>/2000000@0Yl3[0P000004
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000h0oooo000n0?ooo`030000002W`>/0Yl3[0080Yl3[00<000000:O0j`000000102W`>/0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo03`0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo00`0oooo000o0?ooo`030000002W`>/0Yl3[0080Yl3[0P000003
0:O0j`0308]BR0000000000000@0oooo00<000000?ooo`3oool0?03oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool0303oool00400oooo00<000000:O0j`2W`>/00P2W`>/0
0`000000Re:808]BR00208]BR0<000000`3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`0;0?ooo`00@@3oool010000000Yl3[08]BR02;
DXP2000000<0Re:80P0000001@2W`>/000000?ooo`3oool0000003h0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo00000002000000d0oooo00110?ooo`040000002;DXP0Re:808]BR0800000
0`2;DXP200000080Yl3[00@000000?ooo`3oool00000?P3oool00`000000oooo0000000300000080
oooo00<000000?ooo`3oool02`3oool00440oooo00@0000008]BR02;DXP0Re:80P00000308]BR080
00000`2W`>/00`000000oooo0000000n0?ooo`8000000P3oool01@000000oooo0?ooo`3oool00000
00d0oooo00110?ooo`040000002;DXP0Re:808]BR08000000`2;DXP3000000<0Yl3[0P00000n0?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0:0?ooo`00@@3oool01`00
0000Re:808]BR02;DXP0000008]BR00000000`2;DXP2000000@0Yl3[0P00000m0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo0000000<0?ooo`00@@3oool01`000000Re:808]B
R02;DXP0000008]BR00000000`2;DXP3000000<0Yl3[0`00000l0?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo0000000<0?ooo`00@@3oool00`000000Re:808]BR00208]BR080
00000`2;DXP00`000000Yl3[00000003000000040:O0j`000000Yl3[000003`0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo00X0oooo00120?ooo`070000002;DXP0Re:8
08]BR0000000Re:80000000208]BR0<000000P2W`>/01@000000Yl3[0:O0j`000000Yl3[00800000
>P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool02P3oool00480oooo
00H0000008]BR02;DXP0Re:80000002;DXP4000000030:O0j`000000Yl3[0080Yl3[0`0000030:O0
j`800000>03oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool02@3oool0
0480oooo00L0000008]BR02;DXP0Re:80000002;DXP000000080Re:8100000040:O0j`800000102W
`>/00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
0000000;0?ooo`00@P3oool01@000000Re:808]BR02;DXP000000080Re:800<0000008]BR0000000
0P3oool2000000@0Yl3[0P0000040:O0j`800000=@3oool00`000000oooo0?ooo`020?ooo`030000
003oool00000008000002`3oool00480oooo00D0000008]BR02;DXP0Re:80000000208]BR0030000
002;DXP0000000<0oooo0P0000030:O0j`040000002W`>/00000000000@0Yl3[00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0300000080oooo00<000000?ooo`3oool02@3oool00480oooo
00D0000008]BR02;DXP0Re:80000000308]BR08000000`3oool01P000000oooo000000000000Yl3[
000000<0Yl3[00<000000:O0j`2W`>/00P2W`>/2000003<0oooo0`0000000`3oool000000?ooo`02
0?ooo`030000003oool0oooo00T0oooo00120?ooo`050000002;DXP0Re:808]BR00000000`2;DXP0
0`000000Re:8000000030?ooo`030000003oool0oooo00<000000`2W`>/2000000@0Yl3[0P00000a
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`00@P3oool0
0`000000Re:808]BR00208]BR0060000002;DXP0Re:80000002;DXP000000`3oool00`000000oooo
0?ooo`020?ooo`800000102W`>/2000000@0Yl3[0P00000_0?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`090?ooo`00@P3oool00`000000Re:808]BR00208]BR0040000
002;DXP0Re:808]BR08000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool000000000
00@0Yl3[0P0000040:O0j`<00000;03oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool02@3oool004<0oooo00D0000008]BR02;DXP0Re:80000000308]BR0800000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00800000102W`>/3000000@0Yl3[0P00000Z
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`080?ooo`00@`3oool0
0`000000Re:808]BR00208]BR0040000002;DXP0Re:808]BR08000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo0`0000040:O0j`800000102W`>/2000002P0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000X0oooo00130?ooo`030000002;
DXP0Re:80080Re:800@0000008]BR02;DXP0Re:80P0000040?ooo`050000003oool0oooo0?ooo`00
00001`3oool2000000@0Yl3[0P0000040:O0j`<000009@3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000002P3oool004<0oooo00<0000008]BR02;DXP00P2;DXP00`000000
Re:808]BR00208]BR0030000003oool0oooo0080oooo00<000000?ooo`3oool00`0000080?ooo`80
0000102W`>/3000000@0Yl3[0`00000S0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`080?ooo`00A03oool00`000000Re:808]BR00208]BR0050000002;DXP0Re:808]B
R0000000103oool300000080oooo00<000000?ooo`3oool0203oool3000000@0Yl3[0`0000040:O0
j`<00000803oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0203oool0
04@0oooo00<0000008]BR02;DXP00P2;DXP010000000Re:808]BR02;DXP5000000030?ooo`000000
oooo00<0oooo00<000000?ooo`3oool02P3oool3000000@0Yl3[0`0000040:O0j`<000007@3oool0
1P000000oooo0?ooo`3oool000000?ooo`<000002P3oool004@0oooo00<0000008]BR02;DXP00P2;
DXP00`000000Re:808]BR00208]BR0030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo
0000000?0?ooo`<00000102W`>/3000000@0Yl3[0`00000J0?ooo`030000003oool0000000<00000
0P3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000Re:808]BR00308]BR0050000002;
DXP0Re:808]BR00000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo
0`0000040:O0j`<00000102W`>/3000001L0oooo0P0000020?ooo`050000003oool0oooo0?ooo`00
00002P3oool004D0oooo00<0000008]BR02;DXP00P2;DXP00`000000Re:808]BR00208]BR0030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`<00000
102W`>/3000000@0Yl3[1000000C0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`080?ooo`00A@3oool00`000000Re:808]BR00208]BR0030000002;DXP0Re:80080Re:8
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo
0`0000040:O0j`@00000102W`>/5000000h0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo00P0oooo00150?ooo`030000002;DXP0Re:800<0Re:800@0000008]BR02;DXP0
Re:80P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool4000000@0
Yl3[1@0000040:O0j`@000002P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool0203oool004H0oooo00<0000008]BR02;DXP00P2;DXP00`000000Re:808]BR00208]BR003
0000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`D00000102W`>/40000
00@0Yl3[100000060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000009
0?ooo`00AP3oool00`000000Re:808]BR00208]BR0030000002;DXP0Re:80080Re:80P0000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool07`3oool4000000@0Yl3[100000040:O0
j`D000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01`3oool0
04L0oooo00<0000008]BR02;DXP00P2;DXP00`000000Re:808]BR00208]BR0030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0S0?ooo`@00000102W`>/50000
00@0Yl3[100000020?ooo`050000003oool0oooo0?ooo`0000002@3oool004L0oooo00<0000008]B
R02;DXP00P2;DXP00`000000Re:808]BR00208]BR0800000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo02H0oooo1@0000040:O0j`@00000102W`>/5000000030?ooo`000000oooo
00P0oooo00180?ooo`030000002;DXP0Re:80080Re:800<0000008]BR02;DXP00P2;DXP00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:`3oool4000000@0
Yl3[1@0000030:O0j`<000002@3oool004P0oooo00<0000008]BR02;DXP00P2;DXP00`000000Re:8
08]BR00208]BR08000000`3oool010000000oooo0?ooo`3oool300000300oooo1@0000030:O0j`@0
00000P3oool00`000000oooo0?ooo`070?ooo`00B@3oool00`000000Re:808]BR00208]BR0040000
002;DXP0Re:808]BR08000000P3oool500000080oooo00<000000?ooo`3oool0<`3oool300000080
oooo00D000000?ooo`3oool0oooo000000090?ooo`00B@3oool00`000000Re:808]BR00208]BR003
0000002;DXP0Re:80080Re:80`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0<`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01`3oool004X0
oooo00D0000008]BR02;DXP0Re:80000000408]BR0800000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo03<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo00L0oooo001:0?ooo`030000002;DXP0Re:80080Re:800<0000008]BR02;DXP00P2;DXP20000
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0b0?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`060?ooo`00B`3oool01@000000Re:808]BR02;DXP0
000000@0Re:800<0000008]BR00000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000P0oooo001;
0?ooo`030000002;DXP0Re:80080Re:800<0000008]BR02;DXP00P2;DXP2000000@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000080?ooo`00C03oool00`000000Re:808]BR00208]BR0030000002;DXP0
Re:80080Re:80P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000203oool004d0oooo00<00000
08]BR02;DXP00P2;DXP01`000000Re:808]BR02;DXP0000008]BR00000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool00P3oool00`000000oooo
00000002000000P0oooo001=0?ooo`030000002;DXP0Re:80080Re:800<0000008]BR02;DXP00P2;
DXP2000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo00@000000P3oool00`000000oooo0?ooo`060?ooo`00CP3oool00`000000Re:808]BR002
08]BR0070000002;DXP0Re:808]BR0000000Re:8000000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0;`3oool300000080oooo00D000000?ooo`3oool0oooo000000080?ooo`00
C`3oool00`000000Re:808]BR00208]BR0070000002;DXP0Re:808]BR0000000Re:8000000030?oo
o`040000003oool0oooo0?ooo`800000<03oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000203oool004l0oooo00<0000008]BR02;DXP00`2;DXP010000000Re:808]BR02;
DXP2000000<0oooo00H000000?ooo`00000000000?ooo`00000`0?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000080?ooo`00D03oool00`000000Re:808]BR00208]BR008
0000002;DXP0Re:808]BR0000000Re:80000003oool3000000@0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000T0oooo001A0?ooo`030000002;
DXP0Re:80080Re:800@0000008]BR02;DXP0Re:80`0000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0;03oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool01`3oool00540oooo00<0000008]BR02;DXP00`2;DXP010000000Re:808]BR000000208]BR004
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0;03oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool01`3oool00580oooo00<0000008]BR02;DXP00`2;DXP01000
0000Re:808]BR000000208]BR0040000003oool0oooo000000@0oooo00<000000?ooo`3oool0:`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01`3oool005<0oooo0P00
000408]BR0040000002;DXP0Re:800000080Re:800<000000?ooo`0000001@3oool00`000000oooo
0?ooo`0Z0?ooo`060000003oool0oooo0?ooo`000000oooo0`0000090?ooo`00E@3oool00`000000
Re:808]BR00208]BR0030000002;DXP0000000<0Re:800<000000?ooo`000000103oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0000000<000000P3oool00`000000oooo0?ooo`070?ooo`00
EP3oool00`000000Re:808]BR00208]BR0030000002;DXP0000000<0Re:80P0000050?ooo`030000
003oool0oooo02T0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000002@3oool005L0oooo
00<0000008]BR02;DXP00P2;DXP2000000@0Re:80P0000040?ooo`030000003oool0oooo02T0oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000
002;DXP0Re:80080Re:80P00000408]BR0800000103oool00`000000oooo0?ooo`0X0?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`070?ooo`00F@3oool00`000000Re:8
08]BR00208]BR0800000102;DXP010000000oooo0?ooo`3oool3000002T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00P0oooo001J0?ooo`030000002;DXP0Re:80080
Re:800@0000008]BR02;DXP0Re:81@0000020?ooo`030000003oool0oooo02L0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`080?ooo`00F`3oool00`000000Re:808]BR00208]B
R0<000000P2;DXP2000000@0oooo00<000000?ooo`3oool09@3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool0203oool005`0oooo00@0000008]BR02;DXP0Re:80P000004
08]BR0800000103oool00`000000oooo0?ooo`0T0?ooo`060000003oool0oooo0?ooo`000000oooo
0`00000:0?ooo`00G@3oool010000000Re:808]BR02;DXP2000000@0Re:80`0000030?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`0000000`0000020?ooo`030000003oool0oooo00P0oooo
001N0?ooo`040000002;DXP0Re:808]BR0<000000P2;DXP010000000Re:808]BR00000020?ooo`03
0000003oool0oooo02<0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000002P3oool005l0
oooo0P00000208]BR0030000002;DXP000000080Re:800@0000008]BR02;DXP000000P3oool00`00
0000oooo0?ooo`0R0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`08
0?ooo`00H@3oool01P000000Re:808]BR0000000Re:800000080Re:800<0000008]BR02;DXP00P00
00000`3oool000000?ooo`0R0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`090?ooo`00HP3oool00`000000Re:80000000208]BR0030000002;DXP0000000@0Re:80`00
000Q0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`00H`3o
ool00`000000Re:80000000208]BR0<0000000<0Re:80000000000001000000P0?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`00I03oool00`000000Re:80000
000208]BR0<000001@2;DXP2000001l0oooo00H000000?ooo`3oool0oooo0000003oool3000000/0
oooo001U0?ooo`040000002;DXP0000000000080Re:80P00000508]BR08000007@3oool00`000000
oooo0?ooo`0400000080oooo00<000000?ooo`3oool02@3oool006H0oooo0P00000408]BR0800000
1@2;DXP2000001`0oooo0`0000020?ooo`040000003oool0oooo000000`0oooo001X0?ooo`030000
002;DXP0Re:80080Re:80P00000608]BR0030000003oool0oooo01T0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo00X0oooo001Y0?ooo`030000002;DXP0Re:800<0Re:8
00<0000008]BR02;DXP0102;DXP00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo0000000<0?ooo`00JP3oool00`000000Re:808]BR00308]BR0030000
002;DXP0Re:800<0Re:80P00000H0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`0;0?ooo`00J`3oool00`000000Re:808]BR00308]BR0030000002;DXP0000000800000
0P3oool00`000000oooo0?ooo`0E0?ooo`060000003oool0oooo0?ooo`000000oooo0`00000=0?oo
o`00K03oool010000000Re:808]BR02;DXP4000000D0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0000000400000080oooo00<000000?ooo`3oool02`3oool006d0oooo0`0000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool04P3oool200000080oooo00D000000?ooo`3o
ool0oooo0000000>0?ooo`00K`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00d0oooo001`0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0?0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool03@3oool00740
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool4000000h0oooo00H000000?oo
o`3oool0oooo0000003oool300000100oooo001b0?ooo`040000003oool0oooo0?ooo`D00000103o
ool2000000`0oooo1`00000B0?ooo`00L`3oool3000000@0oooo0P0000050?ooo`800000203oool3
000000050?ooo`000000oooo0?ooo`0000004`3oool007D0oooo0P0000050?ooo`8000000`3oool4
000000D0oooo00@000000?ooo`3oool0oooo1000000D0?ooo`00M`3oool2000000<0oooo1@000004
0?ooo`<0000000<0oooo0000003oool01@00000F0?ooo`00N@3oool3000000@0oooo0`0000030?oo
o`P00000603oool007`0oooo0`0000020?ooo`X000006`3oool007l0oooo1`00000P0?ooo`00YP3o
ool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00
YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?oo
o`00YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V
0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0oooo
002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0
oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 165.875}, {287, 0}} -> {0.192999, -0.00125073, \
0.00337685, 0.00337685}},
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[LinearPolarizer[{Function[#1^2/100+#2^2/100],Function[#1^\
2/100+#2^2/100]}, 90, 100, 10, CenterThickness->2, \
ComponentMedium->{BK7,CrownGlass}]];\
\>", "Input",
  CellTags->"LinearPolarizer with user-defined surface"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.64656 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.307489 1.70804 0 1.70804 [
[ 0 0 0 0 ]
[ 1 1.64656 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.64656 L
0 1.64656 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.81364 .85625 m
.79625 .79476 L
s
.79625 .79476 m
.83181 .78346 L
s
.79625 .79476 m
.77622 .7339 L
s
.77622 .7339 m
.81171 .72235 L
s
.77622 .7339 m
.75375 .67433 L
s
.82816 .91766 m
.81364 .85625 L
s
.81364 .85625 m
.84932 .84516 L
s
.75375 .67433 m
.78924 .66253 L
s
.75375 .67433 m
.72909 .61675 L
s
.84932 .84516 m
.83181 .78346 L
s
.83181 .78346 m
.84075 .78062 L
s
.83181 .78346 m
.81171 .72235 L
s
.81171 .72235 m
.82063 .71945 L
s
.78924 .66253 m
.81171 .72235 L
s
.85829 .84238 m
.84075 .78062 L
s
.84075 .78062 m
.8497 .77777 L
s
.84075 .78062 m
.82063 .71945 L
s
.83962 .9783 m
.82816 .91766 L
s
.82816 .91766 m
.86403 .90677 L
s
.82063 .71945 m
.82957 .71655 L
s
.82063 .71945 m
.79816 .65956 L
s
.86403 .90677 m
.84932 .84516 L
s
.84932 .84516 m
.85829 .84238 L
s
.86727 .83959 m
.8497 .77777 L
s
.8497 .77777 m
.88567 .76634 L
s
.8497 .77777 m
.82957 .71655 L
s
.82957 .71655 m
.86548 .70487 L
s
.82957 .71655 m
.80709 .65659 L
s
.87304 .90404 m
.85829 .84238 L
s
.85829 .84238 m
.86727 .83959 L
s
.78924 .66253 m
.79816 .65956 L
s
.78924 .66253 m
.76464 .60467 L
s
.72909 .61675 m
.76464 .60467 L
s
.72909 .61675 m
.70249 .56184 L
s
.88207 .9013 m
.86727 .83959 L
s
.86727 .83959 m
.90337 .82837 L
s
.79816 .65956 m
.80709 .65659 L
s
.79816 .65956 m
.77357 .60163 L
s
.80709 .65659 m
.843 .64465 L
s
.80709 .65659 m
.78252 .59859 L
s
.87574 .96759 m
.86403 .90677 L
s
.86403 .90677 m
.87304 .90404 L
s
.88567 .76634 m
.90337 .82837 L
s
.86548 .70487 m
.88567 .76634 L
s
.88481 .9649 m
.87304 .90404 L
s
.87304 .90404 m
.88207 .9013 L
s
.843 .64465 m
.86548 .70487 L
s
.84785 1.03745 m
.83962 .9783 L
s
.83962 .9783 m
.87574 .96759 L
s
.76464 .60467 m
.77357 .60163 L
s
.76464 .60467 m
.73816 .54947 L
s
.8939 .96221 m
.88207 .9013 L
s
.88207 .9013 m
.91836 .89029 L
s
.90337 .82837 m
.91836 .89029 L
s
.77357 .60163 m
.78252 .59859 L
s
.77357 .60163 m
.74712 .54636 L
s
.81849 .58637 m
.843 .64465 L
s
.78252 .59859 m
.81849 .58637 L
s
.78252 .59859 m
.7561 .54324 L
s
.70249 .56184 m
.73816 .54947 L
s
.70249 .56184 m
.67423 .51029 L
s
.88426 1.02689 m
.87574 .96759 L
s
.87574 .96759 m
.88481 .9649 L
s
.91836 .89029 m
.93044 .95137 L
s
.89341 1.02424 m
.88481 .9649 L
s
.88481 .9649 m
.8939 .96221 L
s
.90257 1.02158 m
.8939 .96221 L
s
.8939 .96221 m
.93044 .95137 L
s
.79219 .53073 m
.81849 .58637 L
s
.73816 .54947 m
.74712 .54636 L
s
.73816 .54947 m
.71007 .49761 L
s
.84785 1.03745 m
.88426 1.02689 L
s
.74712 .54636 m
.7561 .54324 L
s
.74712 .54636 m
.71908 .49443 L
s
.7561 .54324 m
.79219 .53073 L
s
.7561 .54324 m
.7281 .49124 L
s
.93044 .95137 m
.93942 1.0109 L
s
.67423 .51029 m
.71007 .49761 L
s
.67423 .51029 m
.6446 .46281 L
s
.88426 1.02689 m
.89341 1.02424 L
s
.89341 1.02424 m
.90257 1.02158 L
s
.76438 .47841 m
.79219 .53073 L
s
.90257 1.02158 m
.93942 1.0109 L
s
.71007 .49761 m
.71908 .49443 L
s
.71007 .49761 m
.68068 .44983 L
s
.71908 .49443 m
.7281 .49124 L
s
.71908 .49443 m
.68975 .44656 L
s
.74662 1.0741 m .88943 1.08394 L .85266 1.09436 L .656 .751 .92 r
F
0 g
.85266 1.09436 m
.85391 1.14828 L
s
.84785 1.03745 m
.85156 1.08133 L
s
.7281 .49124 m
.76438 .47841 L
s
.7281 .49124 m
.69883 .44329 L
s
.6446 .46281 m
.68068 .44983 L
s
.78325 1.06351 m .89866 1.08132 L .88943 1.08394 L .656 .751 .92 r
F
0 g
.88426 1.02689 m
.88905 1.07984 L
s
.74662 1.0741 m .78325 1.06351 L .88943 1.08394 L .656 .751 .92 r
F
0 g
.85266 1.09436 m
.88943 1.08394 L
s
.88943 1.08394 m
.89108 1.13796 L
s
.73535 .43015 m
.76438 .47841 L
s
.79245 1.06085 m .90792 1.07869 L .89866 1.08132 L .656 .751 .92 r
F
0 g
.89341 1.02424 m
.89828 1.07721 L
s
.78325 1.06351 m .79245 1.06085 L .89866 1.08132 L .656 .751 .92 r
F
0 g
.88943 1.08394 m
.89866 1.08132 L
s
.89866 1.08132 m
.90042 1.13536 L
s
.80167 1.05819 m .94513 1.06814 L .90792 1.07869 L .656 .751 .92 r
F
0 g
.90257 1.02158 m
.90668 1.06548 L
s
.79245 1.06085 m .80167 1.05819 L .90792 1.07869 L .656 .751 .92 r
F
0 g
.89866 1.08132 m
.90792 1.07869 L
s
.90792 1.07869 m
.90978 1.13276 L
s
.65156 1.0498 m .78325 1.06351 L .74662 1.0741 L .656 .751 .92 r
F
0 g
.74662 1.0741 m
.85266 1.09436 L
s
.68068 .44983 m
.68975 .44656 L
s
.68975 .44656 m
.69883 .44329 L
s
.69883 .44329 m
.73535 .43015 L
s
.80167 1.05819 m .83874 1.04747 L .94513 1.06814 L .656 .751 .92 r
F
0 g
.94513 1.06814 m
.9474 1.12232 L
s
.90792 1.07869 m
.94513 1.06814 L
s
.93942 1.0109 m
.94513 1.06814 L
s
.85145 1.1984 m
.85391 1.14828 L
s
.85391 1.14828 m
.89108 1.13796 L
s
.68814 1.03901 m .79245 1.06085 L .78325 1.06351 L .656 .751 .92 r
F
.65156 1.0498 m .68814 1.03901 L .78325 1.06351 L F
0 g
.78325 1.06351 m
.88943 1.08394 L
s
.69733 1.0363 m .80167 1.05819 L .79245 1.06085 L .656 .751 .92 r
F
.68814 1.03901 m .69733 1.0363 L .79245 1.06085 L F
0 g
.79245 1.06085 m
.89866 1.08132 L
s
.70654 1.03359 m .83874 1.04747 L .80167 1.05819 L .656 .751 .92 r
F
.69733 1.0363 m .70654 1.03359 L .80167 1.05819 L F
0 g
.80167 1.05819 m
.90792 1.07869 L
s
.88908 1.18815 m
.89108 1.13796 L
s
.89108 1.13796 m
.90042 1.13536 L
s
.61395 .42013 m .58156 .49602 L .54528 .50903 L .544 .324 .532 r
F
.61395 .42013 m .65032 .40682 L .58156 .49602 L F
0 g
.62654 .43767 m
.6446 .46281 L
s
.89853 1.18558 m
.90042 1.13536 L
s
.90042 1.13536 m
.90978 1.13276 L
s
.908 1.183 m
.90978 1.13276 L
s
.90978 1.13276 m
.9474 1.12232 L
s
.56738 1.02124 m .68814 1.03901 L .65156 1.0498 L .656 .751 .92 r
F
0 g
.65156 1.0498 m
.74662 1.0741 L
s
.70654 1.03359 m .74357 1.02267 L .83874 1.04747 L .656 .751 .92 r
F
0 g
.83874 1.04747 m
.94513 1.06814 L
s
.65032 .40682 m .59068 .49274 L .58156 .49602 L .544 .324 .532 r
F
.65032 .40682 m .65946 .40348 L .59068 .49274 L F
0 g
.61395 .42013 m
.65032 .40682 L
s
.65346 .41127 m
.68068 .44983 L
s
.65946 .40348 m .59982 .48947 L .59068 .49274 L .544 .324 .532 r
F
.65946 .40348 m .66862 .40013 L .59982 .48947 L F
0 g
.65032 .40682 m
.65946 .40348 L
s
.6626 .40794 m
.68975 .44656 L
s
.54528 .50903 m .52471 .58171 L .48842 .59447 L .544 .324 .532 r
F
.54528 .50903 m .58156 .49602 L .52471 .58171 L F
0 g
.54528 .50903 m
.61395 .42013 L
s
.9474 1.12232 m
.94609 1.17263 L
s
.60401 1.01022 m .69733 1.0363 L .68814 1.03901 L .656 .751 .92 r
F
.56738 1.02124 m .60401 1.01022 L .68814 1.03901 L F
0 g
.68814 1.03901 m
.78325 1.06351 L
s
.66862 .40013 m .63655 .47629 L .59982 .48947 L .544 .324 .532 r
F
0 g
.58263 .38297 m
.61395 .42013 L
s
.66862 .40013 m .70543 .38665 L .63655 .47629 L .544 .324 .532 r
F
0 g
.61935 .36933 m
.65032 .40682 L
s
.62858 .3659 m
.65946 .40348 L
s
.65946 .40348 m
.66862 .40013 L
s
.68123 .41815 m
.69883 .44329 L
s
.63782 .36247 m
.66862 .40013 L
s
.66862 .40013 m
.70543 .38665 L
s
.70543 .38665 m
.73535 .43015 L
s
.61322 1.00746 m .70654 1.03359 L .69733 1.0363 L .656 .751 .92 r
F
.60401 1.01022 m .61322 1.00746 L .69733 1.0363 L F
0 g
.69733 1.0363 m
.79245 1.06085 L
s
.62244 1.00468 m .74357 1.02267 L .70654 1.03359 L .656 .751 .92 r
F
.61322 1.00746 m .62244 1.00468 L .70654 1.03359 L F
0 g
.70654 1.03359 m
.80167 1.05819 L
s
.8452 1.24391 m
.85145 1.1984 L
s
.85145 1.1984 m
.88908 1.18815 L
s
.58156 .49602 m .53383 .5785 L .52471 .58171 L .544 .324 .532 r
F
.58156 .49602 m .59068 .49274 L .53383 .5785 L F
0 g
.58156 .49602 m
.65032 .40682 L
s
.67499 .34867 m
.70543 .38665 L
s
.59068 .49274 m .54297 .57529 L .53383 .5785 L .544 .324 .532 r
F
.59068 .49274 m .59982 .48947 L .54297 .57529 L F
0 g
.59068 .49274 m
.65946 .40348 L
s
.59982 .48947 m .57972 .56238 L .54297 .57529 L .544 .324 .532 r
F
.59982 .48947 m .63655 .47629 L .57972 .56238 L F
0 g
.59982 .48947 m
.66862 .40013 L
s
.63655 .47629 m
.70543 .38665 L
s
.62244 1.00468 m .65952 .99353 L .74357 1.02267 L .656 .751 .92 r
F
0 g
.74357 1.02267 m
.83874 1.04747 L
s
.88332 1.23371 m
.88908 1.18815 L
s
.88908 1.18815 m
.89853 1.18558 L
s
.48842 .59447 m .47977 .6642 L .44336 .67673 L .544 .324 .532 r
F
.48842 .59447 m .52471 .58171 L .47977 .6642 L F
0 g
.48842 .59447 m
.54528 .50903 L
s
.49408 .98817 m .60401 1.01022 L .56738 1.02124 L .656 .751 .92 r
F
0 g
.56738 1.02124 m
.65156 1.0498 L
s
.89289 1.23115 m
.89853 1.18558 L
s
.89853 1.18558 m
.908 1.183 L
s
.58263 .38297 m
.61935 .36933 L
s
.58263 .38297 m
.55106 .35204 L
s
.90249 1.22858 m
.908 1.183 L
s
.908 1.183 m
.94609 1.17263 L
s
.52471 .58171 m .48892 .66106 L .47977 .6642 L .544 .324 .532 r
F
.52471 .58171 m .53383 .5785 L .48892 .66106 L F
0 g
.52471 .58171 m
.58156 .49602 L
s
.53086 .97688 m .61322 1.00746 L .60401 1.01022 L .656 .751 .92 r
F
.49408 .98817 m .53086 .97688 L .60401 1.01022 L F
0 g
.60401 1.01022 m
.68814 1.03901 L
s
.61935 .36933 m
.62858 .3659 L
s
.61935 .36933 m
.58817 .33808 L
s
.53383 .5785 m .49809 .6579 L .48892 .66106 L .544 .324 .532 r
F
.53383 .5785 m .54297 .57529 L .49809 .6579 L F
0 g
.53383 .5785 m
.59068 .49274 L
s
.5401 .97404 m .62244 1.00468 L .61322 1.00746 L .656 .751 .92 r
F
.53086 .97688 m .5401 .97404 L .61322 1.00746 L F
0 g
.61322 1.00746 m
.69733 1.0363 L
s
.94609 1.17263 m
.94109 1.21825 L
s
.62858 .3659 m
.63782 .36247 L
s
.62858 .3659 m
.5975 .33457 L
s
.54297 .57529 m .53495 .64523 L .49809 .6579 L .544 .324 .532 r
F
.54297 .57529 m .57972 .56238 L .53495 .64523 L F
0 g
.54297 .57529 m
.59982 .48947 L
s
.57972 .56238 m
.63655 .47629 L
s
.54936 .9712 m .65952 .99353 L .62244 1.00468 L .656 .751 .92 r
F
.5401 .97404 m .54936 .9712 L .62244 1.00468 L F
0 g
.62244 1.00468 m
.70654 1.03359 L
s
.63782 .36247 m
.67499 .34867 L
s
.63782 .36247 m
.60684 .33106 L
s
.44336 .67673 m .44684 .74378 L .41021 .75609 L .544 .324 .532 r
F
.44336 .67673 m .47977 .6642 L .44684 .74378 L F
0 g
.44336 .67673 m
.48842 .59447 L
s
.83507 1.28397 m
.8452 1.24391 L
s
.8452 1.24391 m
.88332 1.23371 L
s
.54936 .9712 m .5866 .95977 L .65952 .99353 L .656 .751 .92 r
F
0 g
.65952 .99353 m
.74357 1.02267 L
s
.64442 .31692 m
.67499 .34867 L
s
.47977 .6642 m .45604 .74068 L .44684 .74378 L .544 .324 .532 r
F
.47977 .6642 m .48892 .66106 L .45604 .74068 L F
0 g
.47977 .6642 m
.52471 .58171 L
s
.43174 .95026 m .53086 .97688 L .49408 .98817 L .656 .751 .92 r
F
0 g
.49408 .98817 m
.56738 1.02124 L
s
.48892 .66106 m .46526 .73758 L .45604 .74068 L .544 .324 .532 r
F
.48892 .66106 m .49809 .6579 L .46526 .73758 L F
0 g
.48892 .66106 m
.53383 .5785 L
s
.87372 1.27379 m
.88332 1.23371 L
s
.88332 1.23371 m
.89289 1.23115 L
s
.49809 .6579 m .50235 .72511 L .46526 .73758 L .544 .324 .532 r
F
.49809 .6579 m .53495 .64523 L .50235 .72511 L F
0 g
.49809 .6579 m
.54297 .57529 L
s
.53495 .64523 m
.57972 .56238 L
s
.88343 1.27123 m
.89289 1.23115 L
s
.89289 1.23115 m
.90249 1.22858 L
s
.55106 .35204 m
.58817 .33808 L
s
.55106 .35204 m
.51967 .32807 L
s
.89316 1.26866 m
.90249 1.22858 L
s
.90249 1.22858 m
.94109 1.21825 L
s
.46877 .93866 m .5401 .97404 L .53086 .97688 L .656 .751 .92 r
F
.43174 .95026 m .46877 .93866 L .53086 .97688 L F
0 g
.53086 .97688 m
.60401 1.01022 L
s
.47808 .93574 m .54936 .9712 L .5401 .97404 L .656 .751 .92 r
F
.46877 .93866 m .47808 .93574 L .5401 .97404 L F
0 g
.5401 .97404 m
.61322 1.00746 L
s
.41021 .75609 m .42612 .82069 L .38917 .83282 L .544 .324 .532 r
F
.41021 .75609 m .44684 .74378 L .42612 .82069 L F
0 g
.41021 .75609 m
.44336 .67673 L
s
.48741 .93282 m .5866 .95977 L .54936 .9712 L .656 .751 .92 r
F
.47808 .93574 m .48741 .93282 L .54936 .9712 L F
0 g
.54936 .9712 m
.62244 1.00468 L
s
.58817 .33808 m
.5975 .33457 L
s
.58817 .33808 m
.55723 .3138 L
s
.94109 1.21825 m
.9323 1.25835 L
s
.5975 .33457 m
.60684 .33106 L
s
.5975 .33457 m
.56666 .31021 L
s
.60684 .33106 m
.64442 .31692 L
s
.60684 .33106 m
.57612 .30661 L
s
.44684 .74378 m .43541 .81764 L .42612 .82069 L .544 .324 .532 r
F
.44684 .74378 m .45604 .74068 L .43541 .81764 L F
0 g
.44684 .74378 m
.47977 .6642 L
s
.48741 .93282 m .5249 .92106 L .5866 .95977 L .656 .751 .92 r
F
0 g
.5866 .95977 m
.65952 .99353 L
s
.45604 .74068 m .44471 .81458 L .43541 .81764 L .544 .324 .532 r
F
.45604 .74068 m .46526 .73758 L .44471 .81458 L F
0 g
.45604 .74068 m
.48892 .66106 L
s
.46526 .73758 m .48213 .8023 L .44471 .81458 L .544 .324 .532 r
F
.46526 .73758 m .50235 .72511 L .48213 .8023 L F
0 g
.46526 .73758 m
.49809 .6579 L
s
.50235 .72511 m
.53495 .64523 L
s
.82104 1.31774 m
.83507 1.28397 L
s
.83507 1.28397 m
.87372 1.27379 L
s
.61415 .29216 m
.64442 .31692 L
s
.38056 .90716 m .46877 .93866 L .43174 .95026 L .656 .751 .92 r
F
0 g
.43174 .95026 m
.49408 .98817 L
s
.86025 1.30754 m
.87372 1.27379 L
s
.87372 1.27379 m
.88343 1.27123 L
s
.38917 .83282 m .41795 .89519 L .38056 .90716 L .544 .324 .532 r
F
.38917 .83282 m .42612 .82069 L .41795 .89519 L F
0 g
.38917 .83282 m
.41021 .75609 L
s
.8701 1.30497 m
.88343 1.27123 L
s
.88343 1.27123 m
.89316 1.26866 L
s
.51967 .32807 m
.55723 .3138 L
s
.51967 .32807 m
.48895 .31175 L
s
.41795 .89519 m .47808 .93574 L .46877 .93866 L .656 .751 .92 r
F
.38056 .90716 m .41795 .89519 L .46877 .93866 L F
0 g
.46877 .93866 m
.53086 .97688 L
s
.87998 1.3024 m
.89316 1.26866 L
s
.89316 1.26866 m
.9323 1.25835 L
s
.42735 .89218 m .48741 .93282 L .47808 .93574 L .656 .751 .92 r
F
.41795 .89519 m .42735 .89218 L .47808 .93574 L F
0 g
.47808 .93574 m
.5401 .97404 L
s
.43676 .88916 m .5249 .92106 L .48741 .93282 L .656 .751 .92 r
F
.42735 .89218 m .43676 .88916 L .48741 .93282 L F
0 g
.48741 .93282 m
.54936 .9712 L
s
.42612 .82069 m .42735 .89218 L .41795 .89519 L .544 .324 .532 r
F
.42612 .82069 m .43541 .81764 L .42735 .89218 L F
0 g
.42612 .82069 m
.44684 .74378 L
s
.43541 .81764 m .43676 .88916 L .42735 .89218 L .544 .324 .532 r
F
.43541 .81764 m .44471 .81458 L .43676 .88916 L F
0 g
.43541 .81764 m
.45604 .74068 L
s
.55723 .3138 m
.56666 .31021 L
s
.55723 .3138 m
.52699 .29717 L
s
.9323 1.25835 m
.91969 1.29207 L
s
.44471 .81458 m .47464 .87704 L .43676 .88916 L .544 .324 .532 r
F
.44471 .81458 m .48213 .8023 L .47464 .87704 L F
0 g
.44471 .81458 m
.46526 .73758 L
s
.48213 .8023 m
.50235 .72511 L
s
.56666 .31021 m
.57612 .30661 L
s
.56666 .31021 m
.53655 .29351 L
s
.57612 .30661 m
.61415 .29216 L
s
.57612 .30661 m
.54613 .28984 L
s
.43676 .88916 m .47464 .87704 L .5249 .92106 L .656 .751 .92 r
F
0 g
.5249 .92106 m
.5866 .95977 L
s
.80314 1.34439 m
.82104 1.31774 L
s
.82104 1.31774 m
.86025 1.30754 L
s
.58466 .27507 m
.61415 .29216 L
s
.38056 .90716 m .42278 .96752 L .38482 .97935 L .544 .324 .532 r
F
.38056 .90716 m .41795 .89519 L .42278 .96752 L F
0 g
.42102 .94123 m
.43174 .95026 L
s
.34082 .85841 m .41795 .89519 L .38056 .90716 L .656 .751 .92 r
F
0 g
.38383 .87892 m
.38917 .83282 L
s
.84293 1.33413 m
.86025 1.30754 L
s
.86025 1.30754 m
.8701 1.30497 L
s
.85293 1.33155 m
.8701 1.30497 L
s
.8701 1.30497 m
.87998 1.3024 L
s
.41795 .89519 m .43232 .96454 L .42278 .96752 L .544 .324 .532 r
F
.41795 .89519 m .42735 .89218 L .43232 .96454 L F
0 g
.42815 .90391 m
.46877 .93866 L
s
.37869 .84602 m .42735 .89218 L .41795 .89519 L .656 .751 .92 r
F
0 g
.41913 .88439 m
.42612 .82069 L
s
.34082 .85841 m .37869 .84602 L .41795 .89519 L .656 .751 .92 r
F
0 g
.48895 .31175 m
.52699 .29717 L
s
.48895 .31175 m
.45943 .30372 L
s
.86295 1.32897 m
.87998 1.3024 L
s
.87998 1.3024 m
.91969 1.29207 L
s
.42735 .89218 m .44188 .96156 L .43232 .96454 L .544 .324 .532 r
F
.42735 .89218 m .43676 .88916 L .44188 .96156 L F
0 g
.4376 .90098 m
.47808 .93574 L
s
.38821 .8429 m .43676 .88916 L .42735 .89218 L .656 .751 .92 r
F
0 g
.42852 .88131 m
.43541 .81764 L
s
.37869 .84602 m .38821 .8429 L .42735 .89218 L .656 .751 .92 r
F
.43676 .88916 m .48033 .94957 L .44188 .96156 L .544 .324 .532 r
F
.43676 .88916 m .47464 .87704 L .48033 .94957 L F
0 g
.47841 .92506 m
.48741 .93282 L
s
.39775 .83978 m .47464 .87704 L .43676 .88916 L .656 .751 .92 r
F
0 g
.43985 .86018 m
.44471 .81458 L
s
.38821 .8429 m .39775 .83978 L .43676 .88916 L .656 .751 .92 r
F
0 g
.52699 .29717 m
.53655 .29351 L
s
.52699 .29717 m
.49799 .28885 L
s
.91969 1.29207 m
.90327 1.31857 L
s
.53655 .29351 m
.54613 .28984 L
s
.53655 .29351 m
.50768 .28512 L
s
.39775 .83978 m .43612 .82723 L .47464 .87704 L .656 .751 .92 r
F
0 g
.47464 .87704 m
.5249 .92106 L
s
.47464 .87704 m
.48213 .8023 L
s
.54613 .28984 m
.58466 .27507 L
s
.54613 .28984 m
.51739 .28137 L
s
.38482 .97935 m .44122 1.03791 L .40256 1.04963 L .544 .324 .532 r
F
.38482 .97935 m .42278 .96752 L .44122 1.03791 L F
0 g
.38056 .90716 m
.38482 .97935 L
s
.84293 1.33413 m
.80314 1.34439 L
s
.78147 1.36312 m
.80314 1.34439 L
s
.55645 .26632 m
.58466 .27507 L
s
.31297 .8035 m .37869 .84602 L .34082 .85841 L .656 .751 .92 r
F
0 g
.34082 .85841 m
.38056 .90716 L
s
.42278 .96752 m .45093 1.03497 L .44122 1.03791 L .544 .324 .532 r
F
.42278 .96752 m .43232 .96454 L .45093 1.03497 L F
0 g
.41795 .89519 m
.42278 .96752 L
s
.85293 1.33155 m
.84293 1.33413 L
s
.82185 1.35276 m
.84293 1.33413 L
s
.43232 .96454 m .46067 1.03201 L .45093 1.03497 L .544 .324 .532 r
F
.43232 .96454 m .44188 .96156 L .46067 1.03201 L F
0 g
.42735 .89218 m
.43232 .96454 L
s
.86295 1.32897 m
.85293 1.33155 L
s
.832 1.35016 m
.85293 1.33155 L
s
.44188 .96156 m .49984 1.02014 L .46067 1.03201 L .544 .324 .532 r
F
.44188 .96156 m .48033 .94957 L .49984 1.02014 L F
0 g
.43676 .88916 m
.44188 .96156 L
s
.47464 .87704 m
.48033 .94957 L
s
.35145 .79062 m .38821 .8429 L .37869 .84602 L .656 .751 .92 r
F
.31297 .8035 m .35145 .79062 L .37869 .84602 L F
0 g
.37869 .84602 m
.41795 .89519 L
s
.90327 1.31857 m
.86295 1.32897 L
s
.84218 1.34755 m
.86295 1.32897 L
s
.45943 .30372 m
.49799 .28885 L
s
.45943 .30372 m
.43166 .30453 L
s
.36112 .78739 m .39775 .83978 L .38821 .8429 L .656 .751 .92 r
F
.35145 .79062 m .36112 .78739 L .38821 .8429 L F
0 g
.38821 .8429 m
.42735 .89218 L
s
.37081 .78414 m .43612 .82723 L .39775 .83978 L .656 .751 .92 r
F
.36112 .78739 m .37081 .78414 L .39775 .83978 L F
0 g
.39775 .83978 m
.43676 .88916 L
s
.90327 1.31857 m
.8831 1.33705 L
s
.49799 .28885 m
.50768 .28512 L
s
.49799 .28885 m
.47076 .28941 L
s
.50768 .28512 m
.51739 .28137 L
s
.50768 .28512 m
.48059 .28561 L
s
.37081 .78414 m .40981 .7711 L .43612 .82723 L .656 .751 .92 r
F
0 g
.43612 .82723 m
.47464 .87704 L
s
.51739 .28137 m
.55645 .26632 L
s
.51739 .28137 m
.49045 .2818 L
s
.40256 1.04963 m .47402 1.1066 L .43452 1.11823 L .544 .324 .532 r
F
.40256 1.04963 m .44122 1.03791 L .47402 1.1066 L F
0 g
.38482 .97935 m
.40256 1.04963 L
s
.75621 1.37318 m
.78147 1.36312 L
s
.78147 1.36312 m
.82185 1.35276 L
s
.53007 .26648 m
.55645 .26632 L
s
.44122 1.03791 m .48395 1.10368 L .47402 1.1066 L .544 .324 .532 r
F
.44122 1.03791 m .45093 1.03497 L .48395 1.10368 L F
0 g
.42278 .96752 m
.44122 1.03791 L
s
.45093 1.03497 m .49391 1.10075 L .48395 1.10368 L .544 .324 .532 r
F
.45093 1.03497 m .46067 1.03201 L .49391 1.10075 L F
0 g
.43232 .96454 m
.45093 1.03497 L
s
.29756 .7418 m .35145 .79062 L .31297 .8035 L .656 .751 .92 r
F
0 g
.31297 .8035 m
.34082 .85841 L
s
.79719 1.36268 m
.82185 1.35276 L
s
.82185 1.35276 m
.832 1.35016 L
s
.46067 1.03201 m .53395 1.08897 L .49391 1.10075 L .544 .324 .532 r
F
.46067 1.03201 m .49984 1.02014 L .53395 1.08897 L F
0 g
.44188 .96156 m
.46067 1.03201 L
s
.48033 .94957 m
.49984 1.02014 L
s
.80749 1.36005 m
.832 1.35016 L
s
.832 1.35016 m
.84218 1.34755 L
s
.81782 1.3574 m
.84218 1.34755 L
s
.84218 1.34755 m
.8831 1.33705 L
s
.43166 .30453 m
.47076 .28941 L
s
.43166 .30453 m
.40623 .31463 L
s
.29756 .7418 m .33678 .72837 L .35145 .79062 L .656 .751 .92 r
F
.33678 .72837 m .36112 .78739 L .35145 .79062 L F
0 g
.35145 .79062 m
.37869 .84602 L
s
.33678 .72837 m .34665 .725 L .36112 .78739 L .656 .751 .92 r
F
.34665 .725 m .37081 .78414 L .36112 .78739 L F
0 g
.36112 .78739 m
.38821 .8429 L
s
.34665 .725 m .35653 .72161 L .37081 .78414 L .656 .751 .92 r
F
.35653 .72161 m .40981 .7711 L .37081 .78414 L F
0 g
.37081 .78414 m
.39775 .83978 L
s
.8831 1.33705 m
.85935 1.34677 L
s
.47076 .28941 m
.48059 .28561 L
s
.47076 .28941 m
.4459 .2993 L
s
.48059 .28561 m
.49045 .2818 L
s
.48059 .28561 m
.45587 .29544 L
s
.49045 .2818 m
.53007 .26648 L
s
.49045 .2818 m
.46587 .29158 L
s
.35653 .72161 m .39629 .708 L .40981 .7711 L .656 .751 .92 r
F
0 g
.40981 .7711 m
.43612 .82723 L
s
.43452 1.11823 m .52216 1.17382 L .48164 1.18537 L .544 .324 .532 r
F
.43452 1.11823 m .47402 1.1066 L .52216 1.17382 L F
0 g
.40256 1.04963 m
.43452 1.11823 L
s
.72763 1.37393 m
.75621 1.37318 L
s
.75621 1.37318 m
.79719 1.36268 L
s
.50609 .27603 m
.53007 .26648 L
s
.47402 1.1066 m .53234 1.17092 L .52216 1.17382 L .544 .324 .532 r
F
.47402 1.1066 m .48395 1.10368 L .53234 1.17092 L F
0 g
.44122 1.03791 m
.47402 1.1066 L
s
.7692 1.36326 m
.79719 1.36268 L
s
.79719 1.36268 m
.80749 1.36005 L
s
.48395 1.10368 m .54255 1.16801 L .53234 1.17092 L .544 .324 .532 r
F
.48395 1.10368 m .49391 1.10075 L .54255 1.16801 L F
0 g
.45093 1.03497 m
.48395 1.10368 L
s
.77964 1.36057 m
.80749 1.36005 L
s
.80749 1.36005 m
.81782 1.3574 L
s
.49391 1.10075 m .58363 1.15629 L .54255 1.16801 L .544 .324 .532 r
F
.49391 1.10075 m .53395 1.08897 L .58363 1.15629 L F
0 g
.46067 1.03201 m
.49391 1.10075 L
s
.49984 1.02014 m
.53395 1.08897 L
s
.40623 .31463 m
.4459 .2993 L
s
.40623 .31463 m
.38373 .33434 L
s
.79012 1.35789 m
.81782 1.3574 L
s
.81782 1.3574 m
.85935 1.34677 L
s
.29533 .67257 m .33678 .72837 L .29756 .7418 L .656 .751 .92 r
F
0 g
.29756 .7418 m
.31297 .8035 L
s
.4459 .2993 m
.45587 .29544 L
s
.4459 .2993 m
.42398 .31883 L
s
.85935 1.34677 m
.83225 1.34707 L
s
.33546 .65852 m .34665 .725 L .33678 .72837 L .656 .751 .92 r
F
.29533 .67257 m .33546 .65852 L .33678 .72837 L F
0 g
.33678 .72837 m
.35145 .79062 L
s
.45587 .29544 m
.46587 .29158 L
s
.45587 .29544 m
.43411 .31493 L
s
.34556 .65498 m .35653 .72161 L .34665 .725 L .656 .751 .92 r
F
.33546 .65852 m .34556 .65498 L .34665 .725 L F
0 g
.34665 .725 m
.36112 .78739 L
s
.46587 .29158 m
.50609 .27603 L
s
.46587 .29158 m
.44425 .31102 L
s
.35567 .65144 m .39629 .708 L .35653 .72161 L .656 .751 .92 r
F
.34556 .65498 m .35567 .65144 L .35653 .72161 L F
0 g
.35653 .72161 m
.37081 .78414 L
s
.69611 1.36487 m
.72763 1.37393 L
s
.72763 1.37393 m
.7692 1.36326 L
s
.48507 .29529 m
.50609 .27603 L
s
.48164 1.18537 m .5868 1.2398 L .54509 1.25131 L .544 .324 .532 r
F
.48164 1.18537 m .52216 1.17382 L .5868 1.2398 L F
0 g
.43452 1.11823 m
.48164 1.18537 L
s
.35567 .65144 m .39637 .63718 L .39629 .708 L .656 .751 .92 r
F
0 g
.39629 .708 m
.40981 .7711 L
s
.73824 1.35398 m
.7692 1.36326 L
s
.7692 1.36326 m
.77964 1.36057 L
s
.74883 1.35124 m
.77964 1.36057 L
s
.77964 1.36057 m
.79012 1.35789 L
s
.52216 1.17382 m .59729 1.23691 L .5868 1.2398 L .544 .324 .532 r
F
.52216 1.17382 m .53234 1.17092 L .59729 1.23691 L F
0 g
.47402 1.1066 m
.52216 1.17382 L
s
.38373 .33434 m
.42398 .31883 L
s
.36476 .36376 m
.38373 .33434 L
s
.75944 1.34849 m
.79012 1.35789 L
s
.79012 1.35789 m
.83225 1.34707 L
s
.53234 1.17092 m .60781 1.23401 L .59729 1.23691 L .544 .324 .532 r
F
.53234 1.17092 m .54255 1.16801 L .60781 1.23401 L F
0 g
.48395 1.10368 m
.53234 1.17092 L
s
.54255 1.16801 m .65011 1.22235 L .60781 1.23401 L .544 .324 .532 r
F
.54255 1.16801 m .58363 1.15629 L .65011 1.22235 L F
0 g
.49391 1.10075 m
.54255 1.16801 L
s
.53395 1.08897 m
.58363 1.15629 L
s
.42398 .31883 m
.43411 .31493 L
s
.4056 .34813 m
.42398 .31883 L
s
.83225 1.34707 m
.80216 1.33744 L
s
.43411 .31493 m
.44425 .31102 L
s
.41587 .3442 m
.43411 .31493 L
s
.44425 .31102 m
.48507 .29529 L
s
.42616 .34026 m
.44425 .31102 L
s
.30722 .59495 m .33546 .65852 L .29533 .67257 L .656 .751 .92 r
F
0 g
.29533 .67257 m
.29756 .7418 L
s
.66214 1.34568 m
.69611 1.36487 L
s
.69611 1.36487 m
.73824 1.35398 L
s
.46758 .3244 m
.48507 .29529 L
s
.30722 .59495 m .34844 .58016 L .33546 .65852 L .656 .751 .92 r
F
.34844 .58016 m .34556 .65498 L .33546 .65852 L F
0 g
.33546 .65852 m
.33678 .72837 L
s
.34844 .58016 m .3588 .57644 L .34556 .65498 L .656 .751 .92 r
F
.3588 .57644 m .35567 .65144 L .34556 .65498 L F
0 g
.34556 .65498 m
.34665 .725 L
s
.3588 .57644 m .36919 .57272 L .35567 .65144 L .656 .751 .92 r
F
.36919 .57272 m .39637 .63718 L .35567 .65144 L F
0 g
.35567 .65144 m
.35653 .72161 L
s
.70478 1.33452 m
.73824 1.35398 L
s
.73824 1.35398 m
.74883 1.35124 L
s
.71551 1.33171 m
.74883 1.35124 L
s
.74883 1.35124 m
.75944 1.34849 L
s
.36476 .36376 m
.4056 .34813 L
s
.36476 .36376 m
.34988 .40279 L
s
.72626 1.3289 m
.75944 1.34849 L
s
.75944 1.34849 m
.80216 1.33744 L
s
.54509 1.25131 m .66941 1.3048 L .62629 1.31627 L .544 .324 .532 r
F
.54509 1.25131 m .5868 1.2398 L .66941 1.3048 L F
0 g
.48164 1.18537 m
.54509 1.25131 L
s
.36919 .57272 m .411 .55772 L .39637 .63718 L .656 .751 .92 r
F
0 g
.39629 .708 m
.39637 .63718 L
s
.4056 .34813 m
.41587 .3442 L
s
.4056 .34813 m
.3913 .38709 L
s
.80216 1.33744 m
.76951 1.31758 L
s
.5868 1.2398 m .68026 1.30191 L .66941 1.3048 L .544 .324 .532 r
F
.5868 1.2398 m .59729 1.23691 L .68026 1.30191 L F
0 g
.52216 1.17382 m
.5868 1.2398 L
s
.41587 .3442 m
.42616 .34026 L
s
.41587 .3442 m
.40172 .38314 L
s
.59729 1.23691 m .69113 1.29902 L .68026 1.30191 L .544 .324 .532 r
F
.59729 1.23691 m .60781 1.23401 L .69113 1.29902 L F
0 g
.53234 1.17092 m
.59729 1.23691 L
s
.42616 .34026 m
.46758 .3244 L
s
.42616 .34026 m
.41216 .37918 L
s
.60781 1.23401 m .73487 1.28738 L .69113 1.29902 L .544 .324 .532 r
F
.60781 1.23401 m .65011 1.22235 L .73487 1.28738 L F
0 g
.54509 1.25131 m
.62629 1.31627 L
s
.5868 1.2398 m
.66941 1.3048 L
s
.59729 1.23691 m
.68026 1.30191 L
s
.54255 1.16801 m
.60781 1.23401 L
s
.60781 1.23401 m
.69113 1.29902 L
s
.58363 1.15629 m
.65011 1.22235 L
s
.62629 1.31627 m
.66214 1.34568 L
s
.66214 1.34568 m
.70478 1.33452 L
s
.45418 .36326 m
.46758 .3244 L
s
.65011 1.22235 m
.73487 1.28738 L
s
.66941 1.3048 m
.70478 1.33452 L
s
.70478 1.33452 m
.71551 1.33171 L
s
.68026 1.30191 m
.71551 1.33171 L
s
.71551 1.33171 m
.72626 1.3289 L
s
.34988 .40279 m
.3913 .38709 L
s
.34988 .40279 m
.33962 .45104 L
s
.33439 .50787 m .34844 .58016 L .30722 .59495 L .656 .751 .92 r
F
0 g
.29533 .67257 m
.30722 .59495 L
s
.69113 1.29902 m
.72626 1.3289 L
s
.72626 1.3289 m
.76951 1.31758 L
s
.3913 .38709 m
.40172 .38314 L
s
.3913 .38709 m
.3816 .43535 L
s
.33439 .50787 m .3769 .49224 L .34844 .58016 L .656 .751 .92 r
F
0 g
.30722 .59495 m
.33439 .50787 L
s
.3769 .49224 m .3588 .57644 L .34844 .58016 L .656 .751 .92 r
F
0 g
.33546 .65852 m
.34844 .58016 L
s
.73487 1.28738 m
.76951 1.31758 L
s
.40172 .38314 m
.41216 .37918 L
s
.40172 .38314 m
.39215 .4314 L
s
.3769 .49224 m .38759 .48831 L .3588 .57644 L .656 .751 .92 r
F
.38759 .48831 m .36919 .57272 L .3588 .57644 L F
0 g
.34556 .65498 m
.3588 .57644 L
s
.41216 .37918 m
.45418 .36326 L
s
.41216 .37918 m
.40274 .42744 L
s
.38759 .48831 m .39831 .48437 L .36919 .57272 L .656 .751 .92 r
F
.39831 .48437 m .411 .55772 L .36919 .57272 L F
0 g
.3588 .57644 m
.38759 .48831 L
s
.34844 .58016 m
.3769 .49224 L
s
.35567 .65144 m
.36919 .57272 L
s
.62629 1.31627 m
.66941 1.3048 L
s
.58928 1.2768 m
.62629 1.31627 L
s
.44533 .41152 m
.45418 .36326 L
s
.39831 .48437 m .44144 .46852 L .411 .55772 L .656 .751 .92 r
F
0 g
.39637 .63718 m
.411 .55772 L
s
.36919 .57272 m
.39831 .48437 L
s
.411 .55772 m
.44144 .46852 L
s
.66941 1.3048 m
.68026 1.30191 L
s
.63281 1.26498 m
.66941 1.3048 L
s
.33962 .45104 m
.3816 .43535 L
s
.33439 .50787 m
.33962 .45104 L
s
.68026 1.30191 m
.69113 1.29902 L
s
.64376 1.26201 m
.68026 1.30191 L
s
.69113 1.29902 m
.73487 1.28738 L
s
.65474 1.25903 m
.69113 1.29902 L
s
.3816 .43535 m
.39215 .4314 L
s
.3769 .49224 m
.3816 .43535 L
s
.39215 .4314 m
.40274 .42744 L
s
.38759 .48831 m
.39215 .4314 L
s
.69892 1.24703 m
.73487 1.28738 L
s
.40274 .42744 m
.44533 .41152 L
s
.39831 .48437 m
.40274 .42744 L
s
.55188 1.22777 m
.58928 1.2768 L
s
.58928 1.2768 m
.63281 1.26498 L
s
.44144 .46852 m
.44533 .41152 L
s
.33439 .50787 m
.3769 .49224 L
s
.33439 .50787 m
.33452 .57231 L
s
.59576 1.21556 m
.63281 1.26498 L
s
.63281 1.26498 m
.64376 1.26201 L
s
.6068 1.21249 m
.64376 1.26201 L
s
.64376 1.26201 m
.65474 1.25903 L
s
.61787 1.20941 m
.65474 1.25903 L
s
.65474 1.25903 m
.69892 1.24703 L
s
.3769 .49224 m
.38759 .48831 L
s
.3769 .49224 m
.37752 .55682 L
s
.38759 .48831 m
.39831 .48437 L
s
.38759 .48831 m
.38833 .55292 L
s
.51496 1.16995 m
.55188 1.22777 L
s
.55188 1.22777 m
.59576 1.21556 L
s
.39831 .48437 m
.44144 .46852 L
s
.39831 .48437 m
.39917 .54902 L
s
.69892 1.24703 m
.6624 1.19702 L
s
.33452 .57231 m
.37752 .55682 L
s
.33452 .57231 m
.34019 .6431 L
s
.55911 1.15733 m
.59576 1.21556 L
s
.59576 1.21556 m
.6068 1.21249 L
s
.44144 .46852 m
.44281 .5333 L
s
.57021 1.15416 m
.6068 1.21249 L
s
.6068 1.21249 m
.61787 1.20941 L
s
.58135 1.15097 m
.61787 1.20941 L
s
.61787 1.20941 m
.6624 1.19702 L
s
.37752 .55682 m
.38833 .55292 L
s
.37752 .55682 m
.38362 .62782 L
s
.47942 1.10446 m
.51496 1.16995 L
s
.51496 1.16995 m
.55911 1.15733 L
s
.38833 .55292 m
.39917 .54902 L
s
.38833 .55292 m
.39454 .62397 L
s
.39917 .54902 m
.44281 .5333 L
s
.39917 .54902 m
.40549 .62012 L
s
.6624 1.19702 m
.62615 1.13817 L
s
.34019 .6431 m
.38362 .62782 L
s
.34019 .6431 m
.35142 .71871 L
s
.52374 1.09142 m
.55911 1.15733 L
s
.55911 1.15733 m
.57021 1.15416 L
s
.53489 1.08814 m
.57021 1.15416 L
s
.57021 1.15416 m
.58135 1.15097 L
s
.44957 .60461 m
.44281 .5333 L
s
.54606 1.08485 m
.58135 1.15097 L
s
.58135 1.15097 m
.62615 1.13817 L
s
.44614 1.03272 m
.47942 1.10446 L
s
.47942 1.10446 m
.52374 1.09142 L
s
.38362 .62782 m
.39454 .62397 L
s
.38362 .62782 m
.39521 .7037 L
s
.39454 .62397 m
.40549 .62012 L
s
.39454 .62397 m
.40622 .69993 L
s
.35142 .71871 m
.39521 .7037 L
s
.35142 .71871 m
.36805 .79741 L
s
.40549 .62012 m
.44957 .60461 L
s
.40549 .62012 m
.41727 .69614 L
s
.62615 1.13817 m
.59105 1.0716 L
s
.49054 1.01924 m
.52374 1.09142 L
s
.52374 1.09142 m
.53489 1.08814 L
s
.41599 .95638 m
.44614 1.03272 L
s
.44614 1.03272 m
.49054 1.01924 L
s
.50171 1.01585 m
.53489 1.08814 L
s
.53489 1.08814 m
.54606 1.08485 L
s
.36805 .79741 m
.41212 .78273 L
s
.36805 .79741 m
.38974 .87729 L
s
.39521 .7037 m
.41212 .78273 L
s
.40622 .69993 m
.39521 .7037 L
s
.51291 1.01245 m
.54606 1.08485 L
s
.54606 1.08485 m
.59105 1.0716 L
s
.46172 .68091 m
.44957 .60461 L
s
.38974 .87729 m
.41599 .95638 L
s
.41599 .95638 m
.46038 .94247 L
s
.40622 .69993 m
.42321 .77903 L
s
.41727 .69614 m
.40622 .69993 L
s
.38974 .87729 m
.43402 .86298 L
s
.41727 .69614 m
.46172 .68091 L
s
.41727 .69614 m
.43433 .77533 L
s
.46038 .94247 m
.49054 1.01924 L
s
.49054 1.01924 m
.50171 1.01585 L
s
.47154 .93898 m
.50171 1.01585 L
s
.50171 1.01585 m
.51291 1.01245 L
s
.41212 .78273 m
.42321 .77903 L
s
.41212 .78273 m
.43402 .86298 L
s
.59105 1.0716 m
.55799 .99877 L
s
.48274 .93547 m
.51291 1.01245 L
s
.51291 1.01245 m
.55799 .99877 L
s
.42321 .77903 m
.43433 .77533 L
s
.42321 .77903 m
.44516 .85938 L
s
.43402 .86298 m
.46038 .94247 L
s
.46038 .94247 m
.47154 .93898 L
s
.43402 .86298 m
.44516 .85938 L
s
.43433 .77533 m
.47907 .76043 L
s
.43433 .77533 m
.45632 .85577 L
s
.44516 .85938 m
.47154 .93898 L
s
.47154 .93898 m
.48274 .93547 L
s
.47907 .76043 m
.46172 .68091 L
s
.44516 .85938 m
.45632 .85577 L
s
.45632 .85577 m
.48274 .93547 L
s
.48274 .93547 m
.5278 .92135 L
s
.45632 .85577 m
.50127 .84124 L
s
.55799 .99877 m
.5278 .92135 L
s
.50127 .84124 m
.47907 .76043 L
s
.5278 .92135 m
.50127 .84124 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{174.875, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002^000182000`400?l00000o`00003o[P3oool0
0:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3o
ool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00
[P3oool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?oo
o`00[P3oool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^
0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3oool00:h0oooo
002^0?ooo`00[P3oool00:h0oooo001K0?ooo`L00000C03oool005P0oooo0`000000103oool00000
0000000000030?ooo`<00000B@3oool005H0oooo0P0000020?ooo`8000001`3oool4000004L0oooo
001D0?ooo`T000000`3oool3000000@0oooo0P0000150?ooo`00D03oool800000080oooo1P000009
0?ooo`030000003oool0oooo0480oooo001>0?ooo`L000000`3oool3000000050?ooo`0000000000
0000003oool00P0000070?ooo`<00000@P3oool004`0oooo1`0000000`3oool000000?ooo`040?oo
o`<000000P3oool2000000030?ooo`00000000000080oooo0`0000030?ooo`030000003oool0oooo
03l0oooo00190?ooo`/000000`3oool3000000<0oooo0`0000000`3oool000000?ooo`03000000L0
oooo0P00000o0?ooo`00A`3oool4000000030?ooo`000000000000@0oooo1@0000080?ooo`D00000
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03`0oooo00150?ooo`80000000<0
oooo0000000000000P0000000`3oool000000?ooo`030?ooo`030000003oool0oooo0080oooo0P00
00040?ooo`8000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00@0oooo0`00
000m0?ooo`00A03oool4000000030?ooo`000000oooo008000000`3oool2000000L0oooo00@00000
0?ooo`00000000001P3oool00`000000oooo000000020?ooo`030000003oool0oooo00<000000`3o
ool00`000000oooo0?ooo`0j0?ooo`00@`3oool2000000<0oooo00D000000?ooo`00000000000?oo
o`03000000030?ooo`000000oooo00L0oooo0P0000080?ooo`040000003oool000000?ooo`<00000
1`3oool00`000000oooo0?ooo`0i0?ooo`00@P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool000000?ooo`8000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`0000000P0000090?ooo`030000003oool0oooo03P0oooo00120?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`00000000001@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00@0oooo0`0000020?ooo`8000002@3oool00`000000oooo0?ooo`0g0?ooo`00@@3o
ool010000000oooo0?ooo`3oool4000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`03000000<0oooo00<000000?ooo`3oool00P0000080?ooo`800000
>03oool00400oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`02000000D0oooo00<0
00000?ooo`3oool03@3oool2000000L0oooo00<000000?ooo`3oool00P0000040?ooo`<0000000<0
oooo0000003oool0=`3oool00400oooo0P0000040?ooo`80000000<0oooo0000003oool0103oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P000000
0`3oool00000000000050?ooo`030000003oool0oooo03D0oooo000o0?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`0000000000103oool2000001<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo00000002000000P0oooo00<000000?ooo`3oool0=03oool003l0oooo00<000000?oo
o`3oool00`3oool2000000030?ooo`000000oooo00<0000000<0oooo0000003oool04`3oool00`00
0000oooo0?ooo`040?ooo`80000000@0oooo0000003oool00000203oool00`000000oooo0?ooo`0c
0?ooo`00?P3oool00`000000oooo0?ooo`040?ooo`80000000<0oooo000000000000103oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0000000L0oooo0000003oool0oooo0000003o
ool0000000L0oooo00<000000?ooo`3oool0<`3oool003h0oooo00<000000?ooo`3oool00`3oool4
000000H0oooo00<000000?ooo`3oool0503oool2000000D0oooo00H000000?ooo`3oool000000?oo
o`0000070?ooo`030000003oool0oooo0380oooo000m0?ooo`030000003oool0oooo00<0oooo0`00
00000`3oool000000?ooo`050?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3o
ool01P000000oooo0?ooo`000000oooo000000H0oooo0P00000c0?ooo`00?@3oool00`000000oooo
0?ooo`03000000050?ooo`00000000000?ooo`0000001@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0300000003
08]BR0000000oooo0380oooo000m0?ooo`<00000103oool2000000030?ooo`000000oooo00@0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`040000003oool000000?ooo`<0
00000`2;DXP00`000000oooo0000000b0?ooo`00?03oool00`000000oooo0?ooo`040?ooo`050000
003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0
oooo00D000000?ooo`000000Re:80000000308]BR0050000003oool0oooo0?ooo`000000<@3oool0
03`0oooo00<000000?ooo`3oool0103oool2000000030?ooo`000000oooo00@0oooo0P00000J0?oo
o`030000003oool0oooo00@0oooo1@00000308]BR0030000003oool0oooo0080oooo00<000000?oo
o`3oool0;`3oool003`0oooo00<000000?ooo`3oool0103oool2000000040?ooo`000000oooo0?oo
o`<0000000<0oooo0000003oool06P3oool00`000000oooo0?ooo`0300000080Re:80P00000408]B
R0030000003oool0oooo00<0oooo00<000000?ooo`3oool0;P3oool003`0oooo00<000000?ooo`3o
ool0103oool2000000040?ooo`0000000000000000@0oooo00<000000?ooo`3oool06P3oool20000
00@0Re:80P00000408]BR0030000003oool0oooo00@0oooo00<000000?ooo`3oool0;P3oool003`0
oooo00<000000?ooo`3oool0103oool4000000H0oooo00<000000?ooo`3oool06P3oool00`000000
Re:808]BR00208]BR0030000002;DXP0000000<0Re:80P0000070?ooo`030000003oool0oooo02d0
oooo000k0?ooo`030000003oool0oooo00@0oooo0`0000000`3oool000000?ooo`050?ooo`030000
003oool0oooo01T0oooo00<0000008]BR02;DXP00P2;DXP3000000<0Re:80P0000000`3oool00000
0?ooo`050?ooo`800000;P3oool003/0oooo00<000000?ooo`3oool00P3oool3000000040?ooo`00
0000oooo000000H0oooo00<000000?ooo`3oool0603oool010000000Re:808]BR02;DXP4000000@0
Re:800D000000?ooo`000000oooo000000020?ooo`<0000000<0oooo0000003oool0;@3oool003/0
oooo00<000000?ooo`0000000P0000020?ooo`050000003oool000000?ooo`0000001@3oool00`00
0000oooo0?ooo`0H0?ooo`030000002;DXP0Re:800<0Re:80P00000408]BR0040000003oool00000
0?ooo`@000001@3oool00`000000oooo0?ooo`0[0?ooo`00>`3oool2000000D0oooo00D000000?oo
o`000000oooo000000050?ooo`030000003oool0oooo01L0oooo00<0000008]BR02;DXP00`2;DXP0
0`000000Re:80000000308]BR0030000003oool0oooo00<0000000<0oooo0000003oool01P3oool0
0`000000oooo0?ooo`0Z0?ooo`00>`3oool00`000000oooo0?ooo`040?ooo`050000003oool00000
0?ooo`0000001@3oool00`000000oooo0?ooo`0G0?ooo`030000002;DXP0Re:80080Re:80`000003
08]BR0@0000000H0oooo0000003oool000000?ooo`0000060?ooo`030000003oool0oooo02X0oooo
000k0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`00000000001P3oool00`000000oooo
0?ooo`0F0?ooo`030000002;DXP0Re:80080Re:80`00000408]BR0030000003oool0oooo00<0oooo
00D000000?ooo`000000oooo000000060?ooo`030000003oool0oooo02T0oooo000k0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`000000oooo000000050?ooo`8000005`3oool00`000000
Re:808]BR00208]BR0<00000102;DXP00`000000oooo0?ooo`050?ooo`80000000<0oooo0000003o
ool01@3oool00`000000oooo0?ooo`0Y0?ooo`00>`3oool00`000000oooo0?ooo`030?ooo`050000
003oool000000?ooo`0000000P3oool3000000030:O0j`000000oooo01D0oooo00<0000008]BR02;
DXP00`2;DXP00`000000Re:80000000308]BR0030000003oool0000000H0oooo00D000000?ooo`00
0000oooo000000060?ooo`030000003oool0oooo02P0oooo000k0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`000000oooo0`0000040:O0j`030000003oool0oooo01<0oooo00<0000008]B
R02;DXP00`2;DXP3000000<0Re:800@000000?ooo`3oool000001`3oool010000000oooo00000000
00060?ooo`800000:@3oool003X0oooo00<000000?ooo`3oool0103oool00`000000oooo00000002
000000D0Yl3[0P00000E0?ooo`030000002;DXP0Re:80080Re:80`00000408]BR0050000003oool0
oooo0?ooo`0000001P3oool01@000000oooo0000003oool000000080oooo0`0000000`3oool00000
0?ooo`0X0?ooo`00>P3oool00`000000oooo0?ooo`030?ooo`@0000000<0Yl3[0000002W`>/0102W
`>/2000001@0oooo00<0000008]BR02;DXP00P2;DXP3000000@0Re:800<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`040000003oool000000?ooo`8000001@3oool00`000000oooo
0?ooo`0V0?ooo`00>P3oool00`000000oooo0?ooo`03000000030:O0j`000000Yl3[00<000001@2W
`>/2000001<0oooo00<0000008]BR02;DXP00P2;DXP20000000308]BR0000000Re:80080Re:800<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`D000001P3oool00`000000oooo0?oo
o`0V0?ooo`00>P3oool3000000@0Yl3[1@0000040:O0j`030000003oool000000180oooo00<00000
08]BR02;DXP00`2;DXP3000000@0Re:800<000000?ooo`3oool01@3oool010000000oooo0?ooo`3o
ool2000000060?ooo`000000oooo0000003oool000001P3oool00`000000oooo0?ooo`0U0?ooo`00
>P3oool00`000000Yl3[0:O0j`030:O0j`H00000102W`>/00`000000oooo0000000A0?ooo`030000
002;DXP0Re:800<0Re:80`00000408]BR0030000003oool0oooo00H0oooo00@000000?ooo`000000
0000103oool010000000oooo0000000000070?ooo`030000003oool0oooo02@0oooo000j0?ooo`03
0000002W`>/0Yl3[00<0Yl3[100000000`2W`>/000000:O0j`030:O0j`030000003oool000000140
oooo00<0000008]BR02;DXP00P2;DXP20000000308]BR0000000Re:80080Re:800<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000001P3oool00`00
0000oooo0?ooo`0T0?ooo`00>@3oool2000000D0Yl3[0P000000102W`>/000000:O0j`0000030:O0
j`040000003oool0oooo00000100oooo00<0000008]BR02;DXP00`2;DXP00`000000Re:800000004
08]BR0030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool01@000000oooo0000003o
ool0000000H0oooo00<000000?ooo`3oool08`3oool003T0oooo0P0000040:O0j`070000002W`>/0
00000:O0j`000000Yl3[000000030:O0j`040000003oool0oooo000000l0oooo00<0000008]BR02;
DXP00`2;DXP3000000@0Re:800<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`80
000000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0S0?ooo`00>@3oool2000000@0Yl3[
00<000000:O0j`0000000P0000000`2W`>/000000:O0j`020:O0j`040000003oool0oooo000000l0
oooo00<0000008]BR02;DXP00P2;DXP20000000308]BR0000000Re:80080Re:800<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`050?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`80
0000903oool003P0oooo00<000000:O0j`000000102W`>/5000000060:O0j`000000Yl3[0:O0j`00
0000oooo0`00000>0?ooo`030000002;DXP0Re:800<0Re:800<0000008]BR0000000102;DXP00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo0P000000103oool000000?ooo`3oool3
000000030?ooo`000000oooo02<0oooo000h0?ooo`030000002W`>/0000000<0Yl3[00<000000:O0
j`0000000`0000000`2W`>/000000:O0j`0300000080oooo00<000000?ooo`3oool02`3oool00`00
0000Re:808]BR00308]BR0<00000102;DXP00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00@0oooo0P000000103oool000000000000000050?ooo`030000003oool0oooo0240oooo000h0?oo
o`030000002W`>/0000000<0Yl3[00D000000:O0j`00000000000:O0j`04000000030:O0j`000000
oooo0080oooo00<000000?ooo`3oool02`3oool00`000000Re:808]BR00208]BR080000000<0Re:8
0000002;DXP00P2;DXP00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo0`000000
0`3oool000000?ooo`050?ooo`030000003oool0oooo0240oooo000g0?ooo`040000002W`>/0Yl3[
000000<0Yl3[0P000000202W`>/00000000000000000Yl3[0000002W`>/00000103oool00`000000
oooo0?ooo`0:0?ooo`030000002;DXP0Re:800<0Re:800<0000008]BR0000000102;DXP00`000000
oooo0?ooo`0@0?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000000000000P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0200oooo000g0?ooo`040000002W`>/0Yl3[0000
0080Yl3[00<000000:O0j`0000000P0000001P2W`>/000000:O0j`000000Yl3[000000D0oooo00<0
00000?ooo`3oool0203oool00`000000Re:808]BR00308]BR0030000002;DXP0000000@0Re:800<0
00000?ooo`3oool04@3oool010000000oooo0000000000040?ooo`80000000<0oooo0000003oool0
1@3oool00`000000oooo0?ooo`0P0?ooo`00=`3oool01@000000Yl3[0:O0j`000000Yl3[00H00000
00H0Yl3[0000002W`>/000000:O0j`0000050?ooo`030000003oool0oooo00P0oooo00<0000008]B
R02;DXP00P2;DXP20000000308]BR0000000Re:80080Re:800<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`040?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01l0oooo000f0?ooo`040000002W`>/0Yl3[0:O0j`80000000@0Yl3[000000000000Yl3[0P000000
1P2W`>/000000:O0j`000000Yl3[000000D0oooo00<000000?ooo`3oool01`3oool00`000000Re:8
08]BR00308]BR0030000002;DXP0000000@0Re:800<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`040?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`0O0?ooo`00
=P3oool02P000000Yl3[0:O0j`2W`>/000000:O0j`000000Yl3[0000002W`>/2000000030:O0j`00
0000Yl3[008000001P3oool00`000000oooo0?ooo`060?ooo`030000002;DXP0Re:800<0Re:800<0
000008]BR0000000102;DXP00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`000000oooo000000060?ooo`030000003oool0oooo01h0oooo000f0?ooo`0:0000002W
`>/0Yl3[0:O0j`000000Yl3[0000002W`>/000000:O0j`80000000<0Yl3[0000002W`>/00P000006
0?ooo`030000003oool0oooo00H0oooo00<0000008]BR02;DXP00P2;DXP20000000308]BR0000000
Re:800<0Re:800<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`050000003oool0
00000?ooo`0000001P3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000Yl3[0:O0j`02
0:O0j`040000002W`>/000000:O0j`80000000@0Yl3[0000002W`>/000000P2W`>/00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0000008]BR02;DXP00`2;DXP00`000000Re:8
0000000408]BR0030000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool01@000000oooo
0000003oool0000000D0oooo0P00000O0?ooo`00=@3oool00`000000Yl3[0:O0j`020:O0j`040000
002W`>/000000:O0j`80000000L0Yl3[0000002W`>/0Yl3[0000002W`>/0000000L0oooo00<00000
0?ooo`3oool00`3oool00`000000Re:808]BR00308]BR080000000<0Re:80000002;DXP00`2;DXP0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo0000
00020?ooo`<0000000<0oooo0000003oool07P3oool003D0oooo00<000000:O0j`2W`>/00P2W`>/0
1P000000Yl3[000000000000Yl3[00000080Yl3[00D000000:O0j`000000Yl3[000000070?ooo`03
0000003oool0oooo00<0oooo00<0000008]BR02;DXP00`2;DXP00`000000Re:80000000408]BR003
0000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`000000oooo00000004000000D0
oooo00<000000?ooo`3oool0703oool003D0oooo00<000000:O0j`2W`>/00P2W`>/2000000040:O0
j`000000Yl3[00000080Yl3[00<000000:O0j`0000000P0000060?ooo`800000103oool00`000000
Re:808]BR00308]BR0<000001@2;DXP00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0
oooo0P000000103oool000000?ooo`0000060?ooo`030000003oool0oooo01`0oooo000e0?ooo`03
0000002W`>/0Yl3[00<0Yl3[00D000000:O0j`000000Yl3[000000020:O0j`030000002W`>/00000
008000000`3oool3000000030?ooo`000000oooo00<0oooo00<0000008]BR02;DXP00P2;DXP20000
000308]BR0000000Re:800<0Re:800<000000?ooo`3oool06P3oool00`000000oooo0?ooo`030000
00070?ooo`000000oooo0?ooo`000000oooo000000050?ooo`030000003oool0oooo01`0oooo000d
0?ooo`030000002W`>/0Yl3[00@0Yl3[00@000000:O0j`00000000000`2W`>/00`000000Yl3[0000
0005000000@0oooo00D000000?ooo`3oool0oooo0000000508]BR0<000001@2;DXP00`000000oooo
0?ooo`0K0?ooo`8000001@3oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`3o
ool06`3oool003@0oooo00<000000:O0j`2W`>/0102W`>/010000000Yl3[0000000000030:O0j`D0
00001`3oool01@000000oooo0?ooo`3oool0000000@0Re:80P0000000`2;DXP0000008]BR00308]B
R0030000003oool0oooo01`0oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool0
000000H0oooo00<000000?ooo`3oool06`3oool003@0oooo00<000000:O0j`2W`>/0102W`>/01000
0000Yl3[0000000000020:O0j`80000000@0Yl3[0000000000000000203oool00`000000oooo0000
000508]BR0<000001@2;DXP00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`000000oooo000000060?ooo`030000003oool0oooo01X0oooo000d0?ooo`030000002W
`>/0Yl3[00@0Yl3[00<000000:O0j`0000000`0000001P2W`>/000000:O0j`000000oooo000000P0
oooo00<000000?ooo`000000102;DXP010000000Re:800000000000408]BR0030000003oool0oooo
01h0oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool0000000H0oooo00<00000
0?ooo`3oool06P3oool003@0oooo00<000000:O0j`2W`>/0102W`>/4000000<0Yl3[00D000000:O0
j`000000oooo000000080?ooo`8000001@2;DXP3000000D0Re:800<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`040?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01X0oooo000d0?ooo`030000002W`>/0Yl3[00<0Yl3[100000040:O0j`060000002W`>/00000
0000003oool000001`3oool2000000@0Re:800<0000008]BR00000001@2;DXP00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000050?ooo`800000
6`3oool003@0oooo00<000000:O0j`2W`>/00`2W`>/4000000D0Yl3[0`0000000`3oool000000?oo
o`060?ooo`8000000`2;DXP010000000Re:800000000000508]BR0030000003oool0oooo0240oooo
00<000000?ooo`3oool0103oool2000000040?ooo`000000oooo0?ooo`<0000000<0oooo0000003o
ool06P3oool003<0oooo00<000000:O0j`2W`>/0102W`>/4000000D0Yl3[0`0000000`3oool00000
0?ooo`060?ooo`030000002;DXP0Re:80080Re:800<0000008]BR00000001@2;DXP00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00@0oooo0P000000103oool000000000000000050?ooo`03
0000003oool0oooo01P0oooo000c0?ooo`030000002W`>/0Yl3[00@0Yl3[100000050:O0j`<00000
00<0oooo0000003oool01P3oool01P000000Re:808]BR02;DXP0000008]BR08000001@2;DXP00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00<0oooo0`0000000`3oool000000?ooo`050?oo
o`030000003oool0oooo01P0oooo000c0?ooo`030000002W`>/0Yl3[00@0Yl3[00@000000:O0j`00
000000001@2W`>/3000000030?ooo`000000oooo00D0oooo00<0000008]BR00000000P2;DXP00`00
0000Re:80000000508]BR0030000003oool0oooo02@0oooo00<000000?ooo`3oool00`0000000`3o
ool00000000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0603oool003<0
oooo00<000000:O0j`2W`>/0102W`>/010000000Yl3[0000000000050:O0j`<0000000<0oooo0000
003oool01@3oool01P000000Re:80000002;DXP0000008]BR08000001@2;DXP00`000000oooo0?oo
o`0U0?ooo`8000001@3oool2000000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool05`3o
ool003<0oooo00<000000:O0j`2W`>/0102W`>/010000000Yl3[0000000000050:O0j`<0000000<0
oooo0000003oool0103oool020000000Re:8000000000000Re:80000002;DXP000001P2;DXP00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00@0oooo0P0000000`3oool000000?ooo`050?oo
o`030000003oool0oooo01L0oooo000c0?ooo`030000002W`>/0Yl3[00@0Yl3[00@000000:O0j`00
000000001@2W`>/2000000040?ooo`000000oooo000000<0oooo0`000000102;DXP000000000002;
DXP2000000D0Re:800<000000?ooo`3oool09P3oool00`000000oooo0?ooo`040?ooo`8000000P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo000c0?ooo`030000002W`>/0
Yl3[00@0Yl3[00@000000:O0j`00000000001P2W`>/010000000oooo0000003oool5000000<0Re:8
0P0000000`2;DXP000000000000508]BR0030000003oool0oooo02L0oooo00<000000?ooo`3oool0
103oool2000000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool05P3oool003<0oooo00<0
00000:O0j`2W`>/0102W`>/010000000Yl3[0000000000060:O0j`030000003oool0000000800000
0`3oool00`000000Re:808]BR00208]BR0030000002;DXP0000000D0Re:800<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`040?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01H0oooo000c0?ooo`030000002W`>/0Yl3[00@0Yl3[00@000000:O0j`0000000000
1@2W`>/4000000050?ooo`000000oooo0?ooo`000000102;DXP4000000D0Re:800<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`050?ooo`80000000<0oooo0000003oool0103oool2000001L0
oooo000c0?ooo`030000002W`>/0Yl3[00@0Yl3[00@000000:O0j`00000000000P2W`>/300000006
0:O0j`000000oooo0000003oool000000P3oool00`000000Re:808]BR00208]BR0<000001@2;DXP0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00@0oooo0P000000103oool000000?ooo`3o
ool3000000030?ooo`000000oooo01H0oooo000c0?ooo`030000002W`>/0Yl3[00@0Yl3[00<00000
0:O0j`0000000`0000040:O0j`030000003oool000000080oooo0P00000408]BR0040000002;DXP0
0000000000D0Re:800<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`040?ooo`80000000@0
oooo0000000000000000103oool00`000000oooo0?ooo`0E0?ooo`00<`3oool00`000000Yl3[0:O0
j`040:O0j`040000002W`>/00000000000H0Yl3[0P0000000`3oool000000?ooo`02000000@0Re:8
00<0000008]BR00000001P2;DXP00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00<0oooo
100000000`3oool000000?ooo`050?ooo`030000003oool0oooo01@0oooo000c0?ooo`030000002W
`>/0Yl3[00@0Yl3[00@000000:O0j`00000000001`2W`>/010000000oooo0000003oool2000000<0
Re:800<0000008]BR00000000P00000408]BR0030000003oool0oooo02`0oooo00<000000?ooo`00
00000P0000020?ooo`80000000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0D0?ooo`00
<`3oool00`000000Yl3[0:O0j`040:O0j`040000002W`>/00000000000L0Yl3[00D000000?ooo`00
0000oooo0000000408]BR0030000002;DXP0000000800000102;DXP00`000000oooo0?ooo`0/0?oo
o`8000001@3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool0503oool0
03<0oooo00<000000:O0j`2W`>/0102W`>/00`000000Yl3[00000002000000H0Yl3[00D000000?oo
o`000000oooo0000000408]BR0050000002;DXP0000008]BR0000000102;DXP00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo00D0oooo0P0000000`3oool000000?ooo`050?ooo`030000003o
ool0oooo01<0oooo000c0?ooo`030000002W`>/0Yl3[00D0Yl3[0P0000000`2W`>/000000:O0j`05
0:O0j`80000000@0oooo0000002;DXP000000P2;DXP01P000000Re:8000000000000Re:8000000<0
Re:800<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`040?ooo`80000000<0oooo0000003o
ool01@3oool00`000000oooo0?ooo`0C0?ooo`00<`3oool00`000000Yl3[0:O0j`050:O0j`040000
002W`>/00000000000L0Yl3[00D000000?ooo`000000Re:80000000208]BR0060000002;DXP00000
0000002;DXP000000`2;DXP00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`000000oooo000000050?ooo`030000003oool0oooo01<0oooo000c0?ooo`030000002W
`>/0Yl3[00D0Yl3[00<000000:O0j`0000000P0000060:O0j`<0000000L0Re:80000002;DXP0Re:8
0000002;DXP0000000<0Re:800@0000008]BR02;DXP00000<03oool00`000000oooo0?ooo`050?oo
o`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0C0?ooo`00=03oool00`000000
Yl3[0:O0j`050:O0j`@000001P2W`>/30000000508]BR0000000Re:80000002;DXP00P00000208]B
R080000000<0Re:80000003oool0<@3oool00`000000oooo0?ooo`040?ooo`80000000<0oooo0000
003oool01@3oool00`000000oooo0?ooo`0B0?ooo`00=03oool00`000000Yl3[0:O0j`050:O0j`@0
00001P2W`>/30000000508]BR0000000Re:80000002;DXP010000000102;DXP0000008]BR000000b
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`00000000001@3oool2000001@0oooo000d
0?ooo`030000002W`>/0Yl3[00D0Yl3[100000060:O0j`80000000<0Re:80000002;DXP01@000003
08]BR0030000002;DXP000000380oooo00<000000?ooo`3oool0103oool01P000000oooo0000003o
ool000000?ooo`<0000000<0oooo0000003oool04`3oool003D0oooo00<000000:O0j`2W`>/0102W
`>/01@000000Yl3[0000002W`>/0000000H0Yl3[2000000508]BR0030000003oool0oooo0380oooo
00<000000?ooo`3oool0103oool2000000030?ooo`000000000000D0oooo00<000000?ooo`3oool0
4@3oool003D0oooo00<000000:O0j`2W`>/01@2W`>/4000000@0Yl3[1@0000000`2;DXP000000000
0002000000D0Re:800<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`030?ooo`D000001P3o
ool00`000000oooo0?ooo`0A0?ooo`00=@3oool00`000000Yl3[0:O0j`050:O0j`P000000P2W`>/3
0000000308]BR0000000Re:8008000001@2;DXP00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo00<0000000<0oooo0000003oool00P0000060?ooo`030000003oool0oooo0140oooo000e0?oo
o`030000002W`>/0Yl3[00D0Yl3[1@0000050:O0j`80000000H0Re:8000000000000000008]BR000
000408]BR0030000003oool0000003@0oooo0P0000040?ooo`050000003oool000000?ooo`000000
1P3oool00`000000oooo0?ooo`0@0?ooo`00=P3oool00`000000Yl3[0:O0j`050:O0j`80000000<0
Yl3[0000002W`>/01@2W`>/50000000308]BR0000000Re:800<0Re:800<000000?ooo`000000=03o
ool00`000000oooo0?ooo`040?ooo`040000003oool00000000000H0oooo00<000000?ooo`3oool0
403oool003H0oooo00<000000:O0j`2W`>/01@2W`>/200000080Yl3[00<000000:O0j`2W`>/00`2W
`>/6000000D0Re:800<000000?ooo`000000=03oool00`000000oooo0?ooo`040?ooo`040000003o
ool00000000000H0oooo00<000000?ooo`3oool0403oool003H0oooo00<000000:O0j`2W`>/01@2W
`>/01@000000Yl3[0000002W`>/0000000D0Yl3[00H000000:O0j`000000000008]BR000000508]B
R0030000003oool0000003D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0
000000H0oooo00<000000?ooo`3oool03`3oool003L0oooo00<000000:O0j`2W`>/01@2W`>/30000
00030:O0j`000000Yl3[00@0Yl3[0`0000000`2;DXP0000008]BR00408]BR0040000003oool0oooo
000003@0oooo00<000000?ooo`3oool0103oool010000000oooo0000000000060?ooo`030000003o
ool0oooo00l0oooo000g0?ooo`030000002W`>/0Yl3[00D0Yl3[0`0000000`2W`>/000000:O0j`04
0:O0j`<0000000<0Re:80000002;DXP0102;DXP010000000oooo0?ooo`00000d0?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`0?0?ooo`00>03o
ool00`000000Yl3[0:O0j`050:O0j`<0000000<0Yl3[0000002W`>/00`2W`>/01@000000Yl3[0000
002;DXP0000000D0Re:800@000000?ooo`3oool00000=@3oool00`000000oooo0?ooo`030?ooo`04
0000003oool00000000000D0oooo0`00000@0?ooo`00>@3oool00`000000Yl3[0:O0j`040:O0j`<0
000000<0Yl3[0000002W`>/00`2W`>/00`000000Yl3[00000003000000@0Re:800D000000?ooo`3o
ool0oooo0000000d0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P000000103o
ool000000000000000020?ooo`030000003oool0oooo00h0oooo000i0?ooo`030000002W`>/0Yl3[
00@0Yl3[0P000000102W`>/000000:O0j`0000040:O0j`050000002W`>/0000008]BR00000000`2;
DXP010000000oooo0?ooo`3oool2000003@0oooo00<000000?ooo`3oool0103oool5000000D0oooo
00<000000?ooo`3oool03P3oool003X0oooo00<000000:O0j`2W`>/0102W`>/01@000000Yl3[0000
002W`>/0000000@0Yl3[00<000000:O0j`0000000P00000308]BR0@0000000<0oooo0000003oool0
<`3oool00`000000oooo0?ooo`030?ooo`80000000<0oooo0000000000001P3oool00`000000oooo
0?ooo`0>0?ooo`00>P3oool00`000000Yl3[0:O0j`040:O0j`80000000@0Yl3[0000002W`>/00000
0`2W`>/00`000000Yl3[0:O0j`06000000@0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
00000002000000030?ooo`000000oooo008000001`3oool00`000000oooo0?ooo`0=0?ooo`00>`3o
ool00`000000Yl3[0:O0j`040:O0j`060000002W`>/0Yl3[0000002W`>/000000`2W`>/500000080
Re:800<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0b0?ooo`800000103oool01@000000
oooo0000003oool0000000H0oooo00<000000?ooo`3oool03@3oool003/0oooo00<000000:O0j`2W
`>/0102W`>/200000080Yl3[00<000000:O0j`0000000`0000000`2W`>/000000:O0j`0200000003
08]BR0000000oooo00@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`040?ooo`04
0000003oool00000000000H0oooo00<000000?ooo`3oool03@3oool003`0oooo00<000000:O0j`2W
`>/0102W`>/600000080Yl3[00H000000:O0j`000000Yl3[0000002W`>/2000000D0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`040?ooo`040000003oool00000000000H0oooo00<0
00000?ooo`3oool03@3oool003d0oooo00<000000:O0j`2W`>/00`2W`>/3000000040:O0j`000000
Yl3[00000080Yl3[00H000000:O0j`000000Yl3[0000002W`>/2000000D0oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000001@3oool00`00
0000oooo0?ooo`0=0?ooo`00?P3oool010000000Yl3[0:O0j`2W`>/20000000A0:O0j`000000Yl3[
0:O0j`000000Yl3[0000002W`>/000000:O0j`000000Yl3[0000002;DXP000000:O0j`000000103o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00@0oooo0P0000000`3oool000000?oo
o`050?ooo`030000003oool0oooo00`0oooo000o0?ooo`030000002W`>/0Yl3[0080Yl3[00@00000
0:O0j`000000Yl3[0P0000002@2W`>/000000000002;DXP0000008]BR0000000Re:8000000020:O0
j`050000003oool0oooo0?ooo`000000=03oool00`000000oooo0?ooo`040?ooo`80000000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0<0?ooo`00?`3oool00`000000Yl3[0:O0j`020:O0
j`040000002W`>/0Yl3[00000080Yl3[0P0000001@2;DXP0000008]BR0000000Re:8008000000`2W
`>/010000000oooo0?ooo`00000d0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`000000
00001@3oool2000000h0oooo00100?ooo`050000002W`>/0Yl3[0:O0j`0000000`2W`>/02@000000
Re:8000000000000Re:80000002;DXP0000008]BR002000000@0Yl3[00@000000?ooo`3oool00000
<`3oool00`000000oooo0?ooo`040?ooo`060000003oool000000?ooo`000000oooo0`0000000`3o
ool000000?ooo`0=0?ooo`00@@3oool02@000000Yl3[0:O0j`2W`>/000000:O0j`2;DXP0000008]B
R0020000000508]BR0000000Re:80000002;DXP00P0000050:O0j`030000003oool0000003@0oooo
00<000000?ooo`3oool0103oool5000000@0oooo00<000000?ooo`3oool0303oool00480oooo00@0
00000:O0j`2;DXP000000P2;DXP010000000Re:800000000000208]BR080000000<0Re:800000000
00001P2W`>/2000003@0oooo00@000000?ooo`3oool0oooo1@0000000`3oool000000?ooo`050?oo
o`030000003oool0oooo00/0oooo00120?ooo`040000002;DXP0Re:800000080Re:800@0000008]B
R000000000000P2;DXP010000000Re:80000002;DXP2000000H0Yl3[0P00000c0?ooo`@000000`3o
ool2000000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool02`3oool00480oooo00P00000
08]BR02;DXP0Re:80000002;DXP0000008]BR08000000P2;DXP010000000Re:80000002;DXP20000
00H0Yl3[0`00000b0?ooo`030000003oool0oooo00@0oooo0P0000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02`3oool00480oooo00/0000008]BR02;DXP0Re:80000002;DXP0
000008]BR0000000Re:80000000208]BR080000000<0Re:80000000000000`2W`>/3000000040:O0
j`000000Yl3[00000340oooo00<000000?ooo`3oool01@3oool2000000030?ooo`000000oooo00@0
oooo00<000000?ooo`3oool02`3oool00480oooo00L0000008]BR02;DXP0Re:80000002;DXP00000
0080Re:80P00000208]BR0040000002;DXP0000008]BR0@000001@2W`>/010000000Yl3[00000000
000_0?ooo`030000003oool0oooo00D0oooo0P0000000`3oool000000?ooo`040?ooo`030000003o
ool0oooo00/0oooo00120?ooo`030000002;DXP0Re:80080Re:800@0000008]BR0000000Re:80P00
000208]BR0030000002;DXP0000000<0000000<0Yl3[0000002W`>/0102W`>/01@000000Yl3[0:O0
j`2W`>/0000002l0oooo00<000000?ooo`3oool0103oool2000000030?ooo`000000oooo00D0oooo
00<000000?ooo`3oool02P3oool00480oooo00<0000008]BR02;DXP00P2;DXP010000000Re:80000
002;DXP20000000308]BR000000000000080000000<0Re:80000002W`>/0100000040:O0j`050000
002W`>/0Yl3[0:O0j`000000;P3oool00`000000oooo0?ooo`040?ooo`80000000<0oooo0000003o
ool01@3oool00`000000oooo0?ooo`0:0?ooo`00@P3oool00`000000Re:808]BR00208]BR0030000
002;DXP0000000@000000P2;DXP00`000000Re:800000003000000030:O0j`000000Yl3[00800000
0P2W`>/00`000000Yl3[0:O0j`020:O0j`800000;03oool00`000000oooo0?ooo`040?ooo`800000
0P3oool00`000000oooo0?ooo`020?ooo`800000303oool00480oooo00<0000008]BR02;DXP00`2;
DXP20000000308]BR0000000000000@0Re:8100000000`2W`>/0000000000002000000040:O0j`00
0000Yl3[000000H0Yl3[00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`050?ooo`800000
00<0oooo0000003oool00`0000000`3oool000000?ooo`0;0?ooo`00@P3oool00`000000Re:808]B
R00308]BR080000000<0Re:8000000000000102;DXP01@000000Re:80000002W`>/000000080Yl3[
00<000000:O0j`000000100000060:O0j`800000:@3oool00`000000oooo0?ooo`050?ooo`D00000
103oool00`000000oooo0?ooo`0:0?ooo`00@P3oool00`000000Re:808]BR00408]BR0040000002;
DXP00000000000@0Re:800<0000008]BR00000000P0000030:O0j`80000000@0Yl3[0000002W`>/0
0000202W`>/2000002P0oooo00<000000?ooo`3oool00P3oool4000000030?ooo`000000oooo00@0
oooo00<000000?ooo`3oool02P3oool00480oooo00<0000008]BR02;DXP0102;DXP01@000000Re:8
0000002;DXP0000000@0Re:800D0000008]BR0000000Yl3[000000040:O0j`030000002W`>/00000
00<00000202W`>/2000002H0oooo00<000000?ooo`0000000P0000020?ooo`80000000<0oooo0000
003oool01@3oool00`000000oooo0?ooo`090?ooo`00@P3oool00`000000Re:808]BR00408]BR005
0000002;DXP0000008]BR0000000102;DXP01@000000Re:80000002W`>/0000000D0Yl3[0P000000
0`2W`>/0000000000002000000P0Yl3[0`00000S0?ooo`8000001@3oool2000000030?ooo`000000
oooo00D0oooo00<000000?ooo`3oool02@3oool00480oooo00<0000008]BR02;DXP01@2;DXP01000
0000Re:800000000000508]BR080000000<0Yl3[0000002W`>/01P2W`>/7000000T0Yl3[0P00000Q
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?oo
o`090?ooo`00@P3oool00`000000Re:808]BR00508]BR0050000002;DXP0000008]BR0000000102;
DXP00`000000Re:800000002000000P0Yl3[0P0000000`2W`>/0000000000003000000P0Yl3[0P00
000O0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`00000000001P3oool00`000000oooo
0?ooo`090?ooo`00@`3oool00`000000Re:808]BR00408]BR0<0000000<0Re:80000002;DXP00`2;
DXP010000000Re:80000003oool3000000H0Yl3[00<000000:O0j`0000000P0000000`2W`>/00000
00000002000000P0Yl3[0`00000M0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000
oooo000000050?ooo`030000003oool0oooo00T0oooo00130?ooo`030000002;DXP0Re:800@0Re:8
0`0000000`2;DXP0000008]BR00408]BR0<0000000<0oooo0000003oool00`0000020:O0j`<00000
0`2W`>/2000000030:O0j`0000000000008000002@2W`>/3000001X0oooo00<000000?ooo`3oool0
103oool2000000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool0203oool004<0oooo00<0
000008]BR02;DXP01@2;DXP01@000000Re:80000002;DXP0000000@0Re:80`000000103oool00000
0?ooo`3oool400000080Yl3[00<000000:O0j`2W`>/00`2W`>/2000000030:O0j`00000000000080
00002P2W`>/3000001L0oooo00<000000?ooo`3oool0103oool2000000030?ooo`000000oooo00D0
oooo00<000000?ooo`3oool0203oool004<0oooo00<0000008]BR02;DXP01@2;DXP30000000308]B
R0000000Re:800<0Re:800<0000008]BR0000000100000040?ooo`@000001P2W`>/200000080Yl3[
1000000:0:O0j`<00000503oool00`000000oooo0?ooo`040?ooo`040000003oool00000000000<0
oooo1000000:0?ooo`00A03oool00`000000Re:808]BR00408]BR0<0000000<0Re:80000002;DXP0
0P2;DXP5000000030?ooo`000000oooo00L0oooo0`0000060:O0j`<000000P2W`>/4000000X0Yl3[
0`00000A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000100000030?ooo`030000
003oool0oooo00P0oooo00140?ooo`030000002;DXP0Re:800@0Re:80`0000000`2;DXP000000000
000200000080Re:80P000000103oool000000?ooo`0000070?ooo`030000003oool0oooo00<00000
1P2W`>/300000080Yl3[1000000:0:O0j`<000003`3oool00`000000oooo0?ooo`020?ooo`D00000
1P3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000Re:808]BR00508]BR0<0000000<0
Re:80000002;DXP0102;DXP3000000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool00P3o
ool3000000H0Yl3[0`0000020:O0j`@000002P2W`>/4000000/0oooo00<000000?ooo`0000000P00
00000`3oool000000?ooo`02000000H0oooo00<000000?ooo`3oool0203oool004@0oooo00<00000
08]BR02;DXP01@2;DXP30000000308]BR0000000Re:800@0Re:80P0000000`3oool0000000000008
0?ooo`030000003oool0oooo00D0oooo0`0000060:O0j`<000000P2W`>/4000000/0Yl3[10000007
0?ooo`800000103oool010000000oooo0000000000060?ooo`030000003oool0oooo00P0oooo0015
0?ooo`030000002;DXP0Re:800@0Re:800<0000008]BR00000000P2;DXP00`000000Re:808]BR003
08]BR0<0000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`070?ooo`<000001P2W`>/3
00000080Yl3[1@00000;0:O0j`@000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0
0000000000H0oooo00<000000?ooo`3oool0203oool004D0oooo00<0000008]BR02;DXP01@2;DXP3
0000000308]BR0000000Re:800@0Re:80P0000000`3oool00000000000080?ooo`030000003oool0
oooo00X0oooo0`0000060:O0j`@000000P2W`>/6000000X0Yl3[100000050?ooo`050000003oool0
00000?ooo`0000001P3oool00`000000oooo0?ooo`070?ooo`00A@3oool00`000000Re:808]BR005
08]BR0050000002;DXP0000008]BR00000001P2;DXP3000000030?ooo`000000oooo00L0oooo00<0
00000?ooo`3oool0303oool3000000L0Yl3[1@0000000`2W`>/0000000000004000000X0Yl3[1P00
00020?ooo`8000001P3oool00`000000oooo0?ooo`070?ooo`00AP3oool00`000000Re:808]BR005
08]BR0<0000000<0Re:80000002;DXP0102;DXP3000000030?ooo`000000oooo00L0oooo00<00000
0?ooo`3oool03`3oool3000000T0Yl3[100000000`2W`>/0000000000005000000X0Yl3[1@000006
0?ooo`030000003oool0oooo00L0oooo00160?ooo`030000002;DXP0Re:800D0Re:800D0000008]B
R0000000Re:80000000508]BR0060000002;DXP000000000003oool000001`3oool00`000000oooo
0?ooo`0B0?ooo`<000002P2W`>/>000000T0Yl3[1@0000000`3oool000000?ooo`080?ooo`00A`3o
ool00`000000Re:808]BR00508]BR0<0000000<0Re:80000002;DXP0102;DXP3000000030?ooo`00
0000oooo00D0oooo0`00000F0?ooo`<00000302W`>/?000000H0Yl3[100000090?ooo`00A`3oool0
0`000000Re:808]BR00508]BR0<0000000<0Re:80000002;DXP0102;DXP00`000000Re:800000002
00000080oooo100000020?ooo`030000003oool0oooo01L0oooo1@00000=0:O0j`l000000`3oool0
0`000000oooo0?ooo`070?ooo`00B03oool00`000000Re:808]BR00508]BR0<0000000<0Re:80000
002;DXP0102;DXP3000000030?ooo`000000000000L0oooo00<000000?ooo`3oool06`3oool70000
00`0Yl3[1P0000060?ooo`030000003oool0oooo00L0oooo00180?ooo`030000002;DXP0Re:800D0
Re:80`0000000`2;DXP0000008]BR00408]BR0030000002;DXP0000000800000203oool00`000000
oooo0?ooo`0R0?ooo`H00000102W`>/3000000030?ooo`000000oooo008000001P3oool00`000000
oooo0?ooo`070?ooo`00B@3oool00`000000Re:808]BR00508]BR0@00000102;DXP5000000030?oo
o`000000oooo00L0oooo00<000000?ooo`3oool09`3oool4000000@0oooo00@000000?ooo`000000
00001P3oool00`000000oooo0?ooo`070?ooo`00B@3oool00`000000Re:808]BR00508]BR0<00000
00<0Re:80000000000000P00000208]BR0030000002;DXP0000000800000203oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`00000000001P3oool00`000000
oooo0?ooo`070?ooo`00BP3oool00`000000Re:808]BR00508]BR0@000001P2;DXP01@000000Re:8
0000003oool0000000P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`030?ooo`04
0000003oool00000000000H0oooo00<000000?ooo`3oool01`3oool004X0oooo00<0000008]BR02;
DXP01@2;DXP30000000308]BR0000000Re:800@0Re:800H0000008]BR02;DXP000000?ooo`000007
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003o
ool0000000D0oooo00<000000?ooo`3oool01`3oool004/0oooo00<0000008]BR02;DXP01@2;DXP3
0000000308]BR0000000Re:800@0Re:800D0000008]BR0000000oooo000000080?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000000D0oooo
00<000000?ooo`3oool01`3oool004/0oooo00<0000008]BR02;DXP01P2;DXP01@000000Re:80000
002;DXP0000000@0Re:800H0000008]BR02;DXP000000?ooo`0000070?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000000@0oooo0P000009
0?ooo`00C03oool00`000000Re:808]BR00508]BR080000000<0Re:80000000000001@2;DXP00`00
0000Re:800000002000000P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`030?oo
o`060000003oool000000?ooo`000000oooo0`0000000`3oool000000?ooo`080?ooo`00C@3oool0
0`000000Re:808]BR00508]BR0050000002;DXP0000008]BR00000001@2;DXP00`000000Re:80000
0002000000L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`030?ooo`H00000103o
ool00`000000oooo0?ooo`070?ooo`00C@3oool00`000000Re:808]BR00608]BR0050000002;DXP0
000008]BR0000000102;DXP01P000000Re:8000000000000oooo000000D0oooo0`00000W0?ooo`03
0000003oool0oooo0080oooo0P000000103oool000000?ooo`0000050?ooo`030000003oool0oooo
00L0oooo001>0?ooo`030000002;DXP0Re:800D0Re:80P000000102;DXP0000008]BR000000408]B
R0030000002;DXP00000008000000P3oool300000080oooo00<000000?ooo`3oool09@3oool00`00
0000oooo00000002000000060?ooo`000000oooo0000003oool000001@3oool00`000000oooo0?oo
o`070?ooo`00C`3oool00`000000Re:808]BR00508]BR0050000002;DXP0000008]BR0000000102;
DXP010000000Re:80000002;DXP3000000H0oooo00<000000?ooo`3oool0903oool2000000@0oooo
00D000000?ooo`000000oooo000000050?ooo`030000003oool0oooo00L0oooo001?0?ooo`030000
002;DXP0Re:800H0Re:800D0000008]BR0000000Re:80000000208]BR0D0000000<0Re:800000000
00001`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`00
0000oooo000000050?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000002;DXP0Re:800D0
Re:800<0000008]BR02;DXP01000000208]BR0030000002;DXP000000080Re:80P0000060?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool010000000oooo0000000000060?oo
o`030000003oool0oooo00L0oooo001A0?ooo`030000002;DXP0Re:800D0Re:80P000000102;DXP0
000008]BR000000308]BR0030000002;DXP000000080Re:80P0000060?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool00`3oool010000000oooo0000000000060?ooo`030000003oool0
oooo00L0oooo001A0?ooo`030000002;DXP0Re:800D0Re:81000000208]BR00;0000002;DXP0Re:8
08]BR0000000Re:80000002;DXP0000008]BR00000001P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`0000000000103oool3000000T0oooo001B0?ooo`03
0000002;DXP0Re:800D0Re:800@0000008]BR000000000000P2;DXP01P000000Re:808]BR0000000
Re:800000080Re:800<0000008]BR00000001P3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo00<0oooo00D000000?ooo`00000000000?ooo`0300000080oooo00<000000?ooo`3oool0
1`3oool005<0oooo00<0000008]BR02;DXP01@2;DXP010000000Re:800000000000208]BR0080000
002;DXP0Re:80000002;DXP0000008]BR000000208]BR0030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`020?ooo`H000001@3oool00`000000oooo0?ooo`07
0?ooo`00E03oool00`000000Re:808]BR00408]BR0030000002;DXP0Re:8008000000P2;DXP01@00
0000Re:80000002;DXP000000080Re:800@0000008]BR02;DXP000001@3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool000000080000000<0oooo0000003oool00P0000060?ooo`030000003o
ool0oooo00L0oooo001E0?ooo`030000002;DXP0Re:800@0Re:800<0000008]BR02;DXP00P000002
08]BR0050000002;DXP0000008]BR00000000P2;DXP010000000Re:808]BR00000030?ooo`<00000
803oool2000000@0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`070?ooo`00
EP3oool00`000000Re:808]BR00308]BR0040000002;DXP0Re:808]BR08000000P2;DXP01`000000
Re:80000002;DXP0000008]BR00000000P2;DXP400000080oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`030?ooo`040000003oool00000000000D0oooo00<000000?ooo`3oool0203o
ool005L0oooo00<0000008]BR02;DXP00`2;DXP010000000Re:808]BR02;DXP200000080Re:80P00
00000`2;DXP0000008]BR00300000080Re:800<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001P3oool00`000000oooo0?oo
o`080?ooo`00F03oool00`000000Re:808]BR00308]BR0040000002;DXP0Re:808]BR080000000<0
Re:80000000000000`0000000`2;DXP0000008]BR00308]BR0030000003oool0oooo0080oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`040000003oool00000000000H0oooo
00<000000?ooo`3oool0203oool005T0oooo00<0000008]BR02;DXP00P2;DXP00`000000Re:808]B
R00400000080Re:800<0000008]BR00000000P2;DXP00`000000Re:808]BR00208]BR08000000P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`0000000000
0`3oool4000000X0oooo001J0?ooo`030000002;DXP0Re:80080Re:80P00000308]BR08000000P2;
DXP00`000000Re:80000000208]BR0030000002;DXP0Re:800<0Re:800@000000?ooo`3oool00000
703oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@000000`3oool00`000000oooo
0?ooo`080?ooo`00F`3oool01@000000Re:808]BR02;DXP0000000D0Re:80P00000208]BR0<00000
00<0Re:80000002;DXP01@2;DXP010000000oooo0?ooo`00000K0?ooo`040000003oool0oooo0?oo
o`H000001P3oool00`000000oooo0?ooo`080?ooo`00G03oool01@000000Re:808]BR02;DXP00000
00D0Re:80`0000001P2;DXP00000000000000000Re:8000000H0Re:800<000000?ooo`0000006P3o
ool00`000000oooo0000000200000080oooo00@000000?ooo`00000000001P3oool00`000000oooo
0?ooo`080?ooo`00G@3oool01@000000Re:808]BR02;DXP0000000H0Re:80P0000000`2;DXP00000
0000000208]BR0030000002;DXP0Re:800@0Re:800<000000?ooo`0000006@3oool2000000D0oooo
00@000000?ooo`00000000001@3oool00`000000oooo0?ooo`090?ooo`00GP3oool200000080Re:8
00<0000008]BR02;DXP0102;DXP30000000408]BR0000000Re:8000000L0Re:80`00000H0?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`090?oo
o`00H03oool010000000Re:808]BR000000608]BR0<0000000@0Re:800000000000000000P2;DXP4
0000000308]BR0000000000001P0oooo00<000000?ooo`3oool00`3oool010000000oooo00000000
00060?ooo`030000003oool0oooo00T0oooo001Q0?ooo`030000002;DXP0000000L0Re:800@00000
08]BR0000000Re:81000000708]BR0030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0000000000030?ooo`@000002`3oool00680oooo00<0000008]BR00000001`2;
DXP7000000P0Re:800<000000?ooo`3oool04`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000D000000`3oool00`000000oooo0?ooo`090?ooo`00H`3oool00`000000Re:800000002
08]BR0@0000000@0Re:8000000000000Re:81000000808]BR0030000003oool0oooo0180oooo00<0
00000?ooo`3oool00P3oool4000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool02P3o
ool006@0oooo00@0000008]BR000000000001`2;DXP00`000000Re:800000003000000P0Re:800<0
00000?ooo`3oool04@3oool00`000000oooo00000002000000030?ooo`000000oooo008000001P3o
ool00`000000oooo0?ooo`0:0?ooo`00I@3oool2000000T0Re:800H0000008]BR0000000000008]B
R000000808]BR0030000003oool0oooo0100oooo0P0000030?ooo`050000003oool000000?ooo`00
00001@3oool00`000000oooo0?ooo`0;0?ooo`00I`3oool00`000000Re:808]BR00708]BR0060000
002;DXP0Re:80000002;DXP000001P2;DXP400000100oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0000003oool0000000D0oooo00<000000?ooo`3oool02`3oool006P0oooo00<0000008]B
R02;DXP01`2;DXP01P000000Re:808]BR0000000Re:800000080Re:80`0000040?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool00`3oool010000000oooo0000000000020?ooo`@00000
3P3oool006T0oooo00<0000008]BR02;DXP01`2;DXP00`000000Re:800000004000000P0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@000000`3o
ool00`000000oooo0?ooo`0<0?ooo`00JP3oool00`000000Re:808]BR00508]BR0@000000P3oool0
0`000000oooo000000080?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool0oooo1@00
00000`3oool000000?ooo`030?ooo`030000003oool0oooo00d0oooo001[0?ooo`030000002;DXP0
Re:800@00000103oool01P000000oooo0?ooo`000000oooo000000P0oooo00<000000?ooo`3oool0
203oool400000080oooo00@000000?ooo`00000000001@3oool00`000000oooo0?ooo`0=0?ooo`00
K03oool2000000T0oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`@000001`3oool20000
00@0oooo00@000000?ooo`00000000000`3oool300000100oooo001^0?ooo`030000003oool0oooo
00L0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`<00000103oool2000000D0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0000003oool500000180oooo001_0?ooo`800000203o
ool00`000000oooo00000004000000T0oooo0P0000020?ooo`030000003oool0oooo00<0oooo1@00
00020?ooo`030000003oool0oooo0140oooo001a0?ooo`030000003oool0oooo00@0oooo10000002
0?ooo`040000003oool00000000000L0oooo100000030?ooo`D000000P3oool3000001@0oooo001b
0?ooo`030000003oool0oooo00<00000103oool2000000040?ooo`00000000000?ooo`8000000P3o
ool3000000<0oooo1@0000000`3oool0000000000004000001H0oooo001c0?ooo`8000002@3oool2
000000030?ooo`000000oooo00<00000103oool3000000030?ooo`000000000000H00000603oool0
07D0oooo0P0000070?ooo``0000000<0oooo0000000000001P00000K0?ooo`00M`3oool200000080
oooo0`0000040?ooo`<0000000<0oooo0000000000002000000N0?ooo`00N@3oool2000000P0oooo
2000000S0?ooo`00N`3oool300000080oooo0`0000000`3oool0000000000002000002H0oooo001n
0?ooo`L00000:@3oool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3oool00:h0
oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3oool0
0:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3o
ool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00
[P3oool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?oo
o`00[P3oool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 173.875}, {287, 0}} -> {0.180022, -0.00119071, \
0.0033672, 0.0033672}},
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{Move[SingleRay[],10],
Move[LensSurface[Function[#1+#2], 50], 50], \
Boundary[100]},PlotType->TopView];\
\>", "Input",
  CellTags->"LinearPolarizer with user-defined surface"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.5 .22381 -3 -4.5 ]
[.5 .22381 3 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.2619 .2619 m
.30159 .30159 L
.34127 .34127 L
.38095 .38095 L
.42063 .42063 L
.46032 .46032 L
.5 .5 L
.53968 .53968 L
.57937 .57937 L
.61905 .61905 L
.65873 .65873 L
.69841 .69841 L
.7381 .7381 L
.7381 .7381 L
.69841 .69841 L
.65873 .65873 L
.61905 .61905 L
.57937 .57937 L
.53968 .53968 L
.5 .5 L
.46032 .46032 L
.42063 .42063 L
.38095 .38095 L
.34127 .34127 L
.30159 .30159 L
.2619 .2619 L
.2619 .2619 L
s
.2619 .5 m
.30159 .5 L
.34127 .5 L
.38095 .5 L
.42063 .5 L
.46032 .5 L
.5 .5 L
.53968 .5 L
.57937 .5 L
.61905 .5 L
.65873 .5 L
.69841 .5 L
.7381 .5 L
.7381 .5 L
.69841 .5 L
.65873 .5 L
.61905 .5 L
.57937 .5 L
.53968 .5 L
.5 .5 L
.46032 .5 L
.42063 .5 L
.38095 .5 L
.34127 .5 L
.30159 .5 L
.2619 .5 L
.2619 .5 L
s
.7381 .7381 m
.76714 .73606 L
.79161 .72998 L
.81109 .71997 L
.82524 .7062 L
.83384 .68889 L
.83672 .66836 L
.83384 .64494 L
.82524 .61905 L
.81109 .59112 L
.79161 .56162 L
.76714 .53108 L
.7381 .5 L
.70498 .46892 L
.66836 .43838 L
.62886 .40888 L
.58715 .38095 L
.54395 .35506 L
.5 .33164 L
.45605 .31111 L
.41285 .2938 L
.37114 .28003 L
.33164 .27002 L
.29502 .26394 L
.2619 .2619 L
.23286 .26394 L
.20839 .27002 L
.18891 .28003 L
.17476 .2938 L
.16616 .31111 L
.16328 .33164 L
.16616 .35506 L
.17476 .38095 L
.18891 .40888 L
.20839 .43838 L
.23286 .46892 L
.2619 .5 L
.29502 .53108 L
.33164 .56162 L
.37114 .59112 L
.41285 .61905 L
.45605 .64494 L
.5 .66836 L
.54395 .68889 L
.58715 .7062 L
.62886 .71997 L
.66836 .72998 L
.70498 .73606 L
.7381 .7381 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.11905 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.97619 .36237 L
s
0 0 0 r
2 Mabswid
.97619 .36237 Mdot
[(L)] .5 .22381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P`3oool5000008L0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q03oool010000000oooo
0?ooo`0000270?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08@0oooo
00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`240?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0Q03oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08@0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`230?ooo`<00000R@3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0<X0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=`3ooolH00000<00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool3000000`0oooo00<000000?oo
o`3oool02@3oool500000;/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0<@3oool300000100oooo00<000000?ooo`3oool03@3oool500000;H0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0;`3oool2000001@0oooo00<000000?ooo`3oool0
4@3oool400000;80oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo0`00002_0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0F0?ooo`@00000Z`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool30000
0:P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo0`00002U0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0M0?ooo`<00000XP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3oool200000:00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo0200oooo0`00002M0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0R0?oo
o`800000V`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool08`3oool2000009T0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo02@0oooo0`00002F0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?ooo`800000U03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool09`3oool200000980oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
02P0oooo0P00002@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`<00000S@3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0:`3oool2000008/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo0P00
00290?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0]0?ooo`800000Q`3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool0;P3oool2000008D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02l0oooo0P0000230?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0`0?ooo`<00000P03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0<P3o
ool2000007h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03<0oooo0P00001l0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0d0?ooo`800000NP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`1g0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0e0?ooo`800000M@3oool00`09jPX00000
000000070?ooo`001P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`1_0?ooo`<02NX:00<0oooo0000000000001`3o
ool000H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo03H0oooo0P00001[0?ooo`@02NX:1@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`1U0?ooo`<02NX:2@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0=`3oool200000680
oooo0`09jPX<0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo05/0oooo
1009jPX?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`0h0?ooo`800000F03oool300WZ2Q<0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0D@3oool400WZ2QH0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo03T0oooo0P00001>0?ooo`<02NX:6P3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`170?ooo`@02NX:7@3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
>P3oool2000004@0oooo0`09jPXQ0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo03h0oooo0`09jPXT0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0k0?ooo`800000>P3oool4
00WZ2RL0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=03oool300WZ
2R/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo03`0oooo0P00000`0?ooo`@02NX:;P3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0Z0?ooo`<02NX:<P3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`0U0?ooo`@02NX:=@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0?@3oool200000280oooo0`09jPXi0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo01`0oooo0`09jPXl0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0n0?ooo`80
0000603oool400WZ2Sl0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
4P3oool300WZ2T<0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3o
ool400WZ2TH0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03l0oooo0P00000:0?ooo`<02NX:BP3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`040?ooo`<02NX:C@3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool0@03oool00`000000oooo00WZ2P0300WZ2U00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo03h0oooo0`09jPYD0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0i0?ooo`@02NX:0`3o
ool200000580oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo03D0oooo0`09jPX90?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo0300oooo1009jPX=0?ooo`030000003oool0oooo
04h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo02`0oooo0`09jPXB0?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo02P0oooo0`09jPXF0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo02<0oooo1009jPXJ0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo01l0oooo0`09jPXO0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo01X0oooo1009jPXS0?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo01H0oooo0`09jPXX0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo0140oooo1009jPX/0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo00d0oooo0`09jPXa0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo00T0oooo0`09jPXe0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
00@0oooo1009jPXi0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`<000000`09jPXn0?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
6@3ooom_00WZ2T@00000@`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo03d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0B`3oool200000480oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0500oooo0P0000110?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
05H0oooo0P0000100?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0FP3oool2000003l0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo05`0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0G@3oool2000003h0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo05l0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
H03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1Q0?ooo`800000?@3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`1T0?ooo`800000?03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0IP3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1W0?ooo`800000>`3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0J@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1Z
0?ooo`800000>P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`1]0?ooo`800000>@3oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
K`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1`0?ooo`800000>03o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`1c0?ooo`800000=`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0M@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1f0?ooo`800000=P3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1i
0?ooo`800000=@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0N`3oool2000003@0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo07d0oooo0P00000c0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1o0?ooo`<00000
<@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0PP3oool200000300oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08@0oooo0P00000_0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`800000;P3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0R03oool2000002d0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08X0oooo
0P00000/0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2<0?ooo`<00000:P3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0S`3oool2000002T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0940oooo0P00000X0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`2C0?ooo`8000009`3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
U@3oool3000002D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo09P0oooo0P00000T0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`2J0?ooo`8000008`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0W03oool30000
0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo09l0oooo0`00000O0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`2R0?ooo`<000007@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Y@3oool3000001/0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0:P0oooo0`00000I0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2[0?oo
o`<000005`3oool00`000000oooo0?ooo`0F0?ooo`800000;`3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`2^0?ooo`@00000503oool00`000000oooo0?ooo`0C0?ooo`80
0000<@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2b0?ooo`<00000
4P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0]@3oool5000000h0oooo00<000000?ooo`3oool03@3o
ool3000003@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0^P3oool5
000000X0oooo00<000000?ooo`3oool02@3oool3000003L0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0_`3ooolF000003X0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`800000o`3ooolA0?ooo`030000003oool0oooo00D0oooo00060?ooool0000050000007
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{Move[SingleRay[],10],
Move[LinearPolarizer[Function[#1+#2], 90, 50], 50], \
Boundary[100]},PlotType->TopView];\
\>", "Input",
  CellTags->"LinearPolarizer with user-defined surface"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.5 .22381 -6 -4.5 ]
[.5 .22381 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.2619 .2619 m
.2619 .2619 L
.30159 .30159 L
.30159 .30159 L
.2619 .2619 L
F
.30159 .30159 m
.30159 .30159 L
.34127 .34127 L
.34127 .34127 L
.30159 .30159 L
F
.34127 .34127 m
.34127 .34127 L
.38095 .38095 L
.38095 .38095 L
.34127 .34127 L
F
.38095 .38095 m
.38095 .38095 L
.42063 .42063 L
.42063 .42063 L
.38095 .38095 L
F
.42063 .42063 m
.42063 .42063 L
.46032 .46032 L
.46032 .46032 L
.42063 .42063 L
F
.46032 .46032 m
.46032 .46032 L
.5 .5 L
.5 .5 L
.46032 .46032 L
F
.5 .5 m
.5 .5 L
.53968 .53968 L
.53968 .53968 L
.5 .5 L
F
.53968 .53968 m
.53968 .53968 L
.57937 .57937 L
.57937 .57937 L
.53968 .53968 L
F
.57937 .57937 m
.57937 .57937 L
.61905 .61905 L
.61905 .61905 L
.57937 .57937 L
F
.61905 .61905 m
.61905 .61905 L
.65873 .65873 L
.65873 .65873 L
.61905 .61905 L
F
.65873 .65873 m
.65873 .65873 L
.69841 .69841 L
.69841 .69841 L
.65873 .65873 L
F
.69841 .69841 m
.69841 .69841 L
.7381 .7381 L
.7381 .7381 L
.69841 .69841 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.2619 .2619 m
.30159 .30159 L
.34127 .34127 L
.38095 .38095 L
.42063 .42063 L
.46032 .46032 L
.5 .5 L
.53968 .53968 L
.57937 .57937 L
.61905 .61905 L
.65873 .65873 L
.69841 .69841 L
.7381 .7381 L
.7381 .7381 L
.69841 .69841 L
.65873 .65873 L
.61905 .61905 L
.57937 .57937 L
.53968 .53968 L
.5 .5 L
.46032 .46032 L
.42063 .42063 L
.38095 .38095 L
.34127 .34127 L
.30159 .30159 L
.2619 .2619 L
.2619 .2619 L
s
.5 g
.2619 .5 m
.2619 .5 L
.30159 .5 L
.30159 .5 L
.2619 .5 L
F
.30159 .5 m
.30159 .5 L
.34127 .5 L
.34127 .5 L
.30159 .5 L
F
.34127 .5 m
.34127 .5 L
.38095 .5 L
.38095 .5 L
.34127 .5 L
F
.38095 .5 m
.38095 .5 L
.42063 .5 L
.42063 .5 L
.38095 .5 L
F
.42063 .5 m
.42063 .5 L
.46032 .5 L
.46032 .5 L
.42063 .5 L
F
.46032 .5 m
.46032 .5 L
.5 .5 L
.5 .5 L
.46032 .5 L
F
.5 .5 m
.5 .5 L
.53968 .5 L
.53968 .5 L
.5 .5 L
F
.53968 .5 m
.53968 .5 L
.57937 .5 L
.57937 .5 L
.53968 .5 L
F
.57937 .5 m
.57937 .5 L
.61905 .5 L
.61905 .5 L
.57937 .5 L
F
.61905 .5 m
.61905 .5 L
.65873 .5 L
.65873 .5 L
.61905 .5 L
F
.65873 .5 m
.65873 .5 L
.69841 .5 L
.69841 .5 L
.65873 .5 L
F
.69841 .5 m
.69841 .5 L
.7381 .5 L
.7381 .5 L
.69841 .5 L
F
0 g
.2619 .5 m
.30159 .5 L
.34127 .5 L
.38095 .5 L
.42063 .5 L
.46032 .5 L
.5 .5 L
.53968 .5 L
.57937 .5 L
.61905 .5 L
.65873 .5 L
.69841 .5 L
.7381 .5 L
.7381 .5 L
.69841 .5 L
.65873 .5 L
.61905 .5 L
.57937 .5 L
.53968 .5 L
.5 .5 L
.46032 .5 L
.42063 .5 L
.38095 .5 L
.34127 .5 L
.30159 .5 L
.2619 .5 L
.2619 .5 L
s
.7381 .7381 m
.76714 .73606 L
.79161 .72998 L
.81109 .71997 L
.82524 .7062 L
.83384 .68889 L
.83672 .66836 L
.83384 .64494 L
.82524 .61905 L
.81109 .59112 L
.79161 .56162 L
.76714 .53108 L
.7381 .5 L
.70498 .46892 L
.66836 .43838 L
.62886 .40888 L
.58715 .38095 L
.54395 .35506 L
.5 .33164 L
.45605 .31111 L
.41285 .2938 L
.37114 .28003 L
.33164 .27002 L
.29502 .26394 L
.2619 .2619 L
.23286 .26394 L
.20839 .27002 L
.18891 .28003 L
.17476 .2938 L
.16616 .31111 L
.16328 .33164 L
.16616 .35506 L
.17476 .38095 L
.18891 .40888 L
.20839 .43838 L
.23286 .46892 L
.2619 .5 L
.29502 .53108 L
.33164 .56162 L
.37114 .59112 L
.41285 .61905 L
.45605 .64494 L
.5 .66836 L
.54395 .68889 L
.58715 .7062 L
.62886 .71997 L
.66836 .72998 L
.70498 .73606 L
.7381 .7381 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.11905 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(LP)] .5 .22381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P03oool500000004
0?ooo`0000000000000008H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0P@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`030?ooo`<00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000Q03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`200?ooo`<000000`3oool4000008D0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`3:0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03L0oooo600000300?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo0`00000<0?ooo`030000
003oool0oooo00T0oooo1@00002k0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0340oooo0`00000@0?ooo`030000003oool0oooo00d0oooo1@00002f0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo02l0oooo0P00000D0?ooo`030000003oool0
oooo0140oooo1000002b0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`<00000[`3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool05P3oool400000:/0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo
0`00002X0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`<00000Y@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool07@3oool300000:80oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo0P00002P0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0P0?ooo`<00000W@3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
8P3oool2000009/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo0P00002I0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0T0?ooo`<00000UP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool20000
09@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo02L0oooo0P00002B0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0X0?ooo`800000T03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool3000008d0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo02/0oooo0P00002;0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?oo
o`800000R@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool2000008L0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo02h0oooo0P0000250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0_0?ooo`800000P`3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool0<03oool300000800oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
0380oooo0P00001n0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?ooo`800000O03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0=03oool2000007X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0M`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=@3oool2000007L0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0=P3oool2000007@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0=`3oool200000740oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0>03oool20000
06h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0J`3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0>@3oool2000006/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0J03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3oool2000006P0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0>`3oool2000006D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
HP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool0?03oool200000680oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0m0?ooo`800000GP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0n0?ooo`800000F`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo03l0oooo0P00001G0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`100?ooo`800000DP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo04/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0440oooo0`00
00110?ooo`030000003oool0oooo0480oooo0P0000070?ooo`001P3oool00`000000oooo0?ooo`0I
0?ooooD02NX:0P0000070?ooo`001P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0B`3o
ool200000480oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0500oooo
0P0000110?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo05H0oooo0P0000100?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo05T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0FP3oool20000
03l0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0G@3oool2000003h0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`1Q0?ooo`800000?@3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0H`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1T0?ooo`800000
?03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`1W0?ooo`800000>`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1Z0?ooo`800000>P3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`1]0?ooo`800000>@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`1`0?ooo`800000>03oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1c0?ooo`800000
=`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`1f0?ooo`800000=P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1i0?ooo`800000=@3oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0N`3oool2000003@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo07d0oooo0P00
000c0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`1o0?ooo`<00000<@3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0PP3oool200000300oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08@0oooo0P00000_0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`800000;P3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0R03o
ool2000002d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08X0oooo0P00000/0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`2<0?ooo`<00000:P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0S`3oool2000002T0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0940oooo0P00000X0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`2C0?ooo`8000009`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0U@3oool3000002D0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo09P0oooo0P00000T0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2J0?ooo`80
00008`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0W03oool300000240oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo09l0oooo0`00000O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2R0?ooo`<000007@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0Y@3oool3000001/0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0
oooo0`00000I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2[0?ooo`<000005`3oool00`000000oooo
0?ooo`0F0?ooo`800000;`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`2^0?ooo`@00000503oool00`000000oooo0?ooo`0C0?ooo`800000<@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`2b0?ooo`<000004P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0]@3oool5000000h0oooo00<000000?ooo`3oool03@3oool3000003@0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0^P3oool5000000X0oooo00<000000?ooo`3o
ool02@3oool3000003L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
_`3ooolF000003X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`800000o`3ooolA0?oo
o`030000003oool0oooo00D0oooo00060?ooool00000500000070?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LinearPolarizer[Function[#1+#2], 90, 50]", "Input",
  CellTags->"LinearPolarizer with user-defined surface"],

Cell[BoxData[
    TagBox[\(LinearPolarizer[#1 + #2 &, 90, 50]\),
      HoldForm]], "Output",
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{Move[SingleRay[],10],
Move[LinearPolarizer[Function[#1+#2], 45, 50], 50], \
Boundary[100]},PlotType->TopView];
ReadRays[sys,{{ComponentNumber,SurfaceNumber},RefractiveIndex,RayTilt,\
Intensity,Polarization}]\
\>", "Input",
  CellTags->"LinearPolarizer with user-defined surface"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.5 .22381 -6 -4.5 ]
[.5 .22381 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.2619 .2619 m
.2619 .2619 L
.30159 .30159 L
.30159 .30159 L
.2619 .2619 L
F
.30159 .30159 m
.30159 .30159 L
.34127 .34127 L
.34127 .34127 L
.30159 .30159 L
F
.34127 .34127 m
.34127 .34127 L
.38095 .38095 L
.38095 .38095 L
.34127 .34127 L
F
.38095 .38095 m
.38095 .38095 L
.42063 .42063 L
.42063 .42063 L
.38095 .38095 L
F
.42063 .42063 m
.42063 .42063 L
.46032 .46032 L
.46032 .46032 L
.42063 .42063 L
F
.46032 .46032 m
.46032 .46032 L
.5 .5 L
.5 .5 L
.46032 .46032 L
F
.5 .5 m
.5 .5 L
.53968 .53968 L
.53968 .53968 L
.5 .5 L
F
.53968 .53968 m
.53968 .53968 L
.57937 .57937 L
.57937 .57937 L
.53968 .53968 L
F
.57937 .57937 m
.57937 .57937 L
.61905 .61905 L
.61905 .61905 L
.57937 .57937 L
F
.61905 .61905 m
.61905 .61905 L
.65873 .65873 L
.65873 .65873 L
.61905 .61905 L
F
.65873 .65873 m
.65873 .65873 L
.69841 .69841 L
.69841 .69841 L
.65873 .65873 L
F
.69841 .69841 m
.69841 .69841 L
.7381 .7381 L
.7381 .7381 L
.69841 .69841 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.2619 .2619 m
.30159 .30159 L
.34127 .34127 L
.38095 .38095 L
.42063 .42063 L
.46032 .46032 L
.5 .5 L
.53968 .53968 L
.57937 .57937 L
.61905 .61905 L
.65873 .65873 L
.69841 .69841 L
.7381 .7381 L
.7381 .7381 L
.69841 .69841 L
.65873 .65873 L
.61905 .61905 L
.57937 .57937 L
.53968 .53968 L
.5 .5 L
.46032 .46032 L
.42063 .42063 L
.38095 .38095 L
.34127 .34127 L
.30159 .30159 L
.2619 .2619 L
.2619 .2619 L
s
.5 g
.2619 .5 m
.2619 .5 L
.30159 .5 L
.30159 .5 L
.2619 .5 L
F
.30159 .5 m
.30159 .5 L
.34127 .5 L
.34127 .5 L
.30159 .5 L
F
.34127 .5 m
.34127 .5 L
.38095 .5 L
.38095 .5 L
.34127 .5 L
F
.38095 .5 m
.38095 .5 L
.42063 .5 L
.42063 .5 L
.38095 .5 L
F
.42063 .5 m
.42063 .5 L
.46032 .5 L
.46032 .5 L
.42063 .5 L
F
.46032 .5 m
.46032 .5 L
.5 .5 L
.5 .5 L
.46032 .5 L
F
.5 .5 m
.5 .5 L
.53968 .5 L
.53968 .5 L
.5 .5 L
F
.53968 .5 m
.53968 .5 L
.57937 .5 L
.57937 .5 L
.53968 .5 L
F
.57937 .5 m
.57937 .5 L
.61905 .5 L
.61905 .5 L
.57937 .5 L
F
.61905 .5 m
.61905 .5 L
.65873 .5 L
.65873 .5 L
.61905 .5 L
F
.65873 .5 m
.65873 .5 L
.69841 .5 L
.69841 .5 L
.65873 .5 L
F
.69841 .5 m
.69841 .5 L
.7381 .5 L
.7381 .5 L
.69841 .5 L
F
0 g
.2619 .5 m
.30159 .5 L
.34127 .5 L
.38095 .5 L
.42063 .5 L
.46032 .5 L
.5 .5 L
.53968 .5 L
.57937 .5 L
.61905 .5 L
.65873 .5 L
.69841 .5 L
.7381 .5 L
.7381 .5 L
.69841 .5 L
.65873 .5 L
.61905 .5 L
.57937 .5 L
.53968 .5 L
.5 .5 L
.46032 .5 L
.42063 .5 L
.38095 .5 L
.34127 .5 L
.30159 .5 L
.2619 .5 L
.2619 .5 L
s
.7381 .7381 m
.76714 .73606 L
.79161 .72998 L
.81109 .71997 L
.82524 .7062 L
.83384 .68889 L
.83672 .66836 L
.83384 .64494 L
.82524 .61905 L
.81109 .59112 L
.79161 .56162 L
.76714 .53108 L
.7381 .5 L
.70498 .46892 L
.66836 .43838 L
.62886 .40888 L
.58715 .38095 L
.54395 .35506 L
.5 .33164 L
.45605 .31111 L
.41285 .2938 L
.37114 .28003 L
.33164 .27002 L
.29502 .26394 L
.2619 .2619 L
.23286 .26394 L
.20839 .27002 L
.18891 .28003 L
.17476 .2938 L
.16616 .31111 L
.16328 .33164 L
.16616 .35506 L
.17476 .38095 L
.18891 .40888 L
.20839 .43838 L
.23286 .46892 L
.2619 .5 L
.29502 .53108 L
.33164 .56162 L
.37114 .59112 L
.41285 .61905 L
.45605 .64494 L
.5 .66836 L
.54395 .68889 L
.58715 .7062 L
.62886 .71997 L
.66836 .72998 L
.70498 .73606 L
.7381 .7381 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.11905 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(LP)] .5 .22381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P03oool500000004
0?ooo`0000000000000008H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0P@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`030?ooo`<00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000Q03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`200?ooo`<000000`3oool4000008D0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`3:0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03L0oooo600000300?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo0`00000<0?ooo`030000
003oool0oooo00T0oooo1@00002k0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0340oooo0`00000@0?ooo`030000003oool0oooo00d0oooo1@00002f0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo02l0oooo0P00000D0?ooo`030000003oool0
oooo0140oooo1000002b0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`<00000[`3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool05P3oool400000:/0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo
0`00002X0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`<00000Y@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool07@3oool300000:80oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo0P00002P0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0P0?ooo`<00000W@3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
8P3oool2000009/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo0P00002I0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0T0?ooo`<00000UP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool20000
09@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo02L0oooo0P00002B0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0X0?ooo`800000T03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool3000008d0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo02/0oooo0P00002;0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?oo
o`800000R@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool2000008L0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo02h0oooo0P0000250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0_0?ooo`800000P`3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool0<03oool300000800oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
0380oooo0P00001n0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?ooo`800000O03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0=03oool2000007X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0M`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=@3oool2000007L0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0=P3oool2000007@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0=`3oool200000740oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0>03oool20000
06h0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0J`3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0>@3oool2000006/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0J03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3oool2000006P0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0>`3oool2000006D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
HP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool0?03oool200000680oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0m0?ooo`800000GP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0n0?ooo`800000F`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo03l0oooo0P00001G0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`100?ooo`800000DP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo04/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0440oooo0`00
00110?ooo`030000003oool0oooo0480oooo0P0000070?ooo`001P3oool00`000000oooo0?ooo`0I
0?ooooD02NX:0P0000070?ooo`001P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0B`3o
ool200000480oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0500oooo
0P0000110?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo05H0oooo0P0000100?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo05T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0FP3oool20000
03l0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0G@3oool2000003h0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`1Q0?ooo`800000?@3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0H`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1T0?ooo`800000
?03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`1W0?ooo`800000>`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1Z0?ooo`800000>P3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`1]0?ooo`800000>@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`1`0?ooo`800000>03oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1c0?ooo`800000
=`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`1f0?ooo`800000=P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1i0?ooo`800000=@3oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0N`3oool2000003@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo07d0oooo0P00
000c0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`1o0?ooo`<00000<@3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0PP3oool200000300oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08@0oooo0P00000_0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`800000;P3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0R03o
ool2000002d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08X0oooo0P00000/0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`2<0?ooo`<00000:P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0S`3oool2000002T0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0940oooo0P00000X0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`2C0?ooo`8000009`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0U@3oool3000002D0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo09P0oooo0P00000T0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2J0?ooo`80
00008`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0W03oool300000240oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo09l0oooo0`00000O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2R0?ooo`<000007@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0Y@3oool3000001/0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0
oooo0`00000I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2[0?ooo`<000005`3oool00`000000oooo
0?ooo`0F0?ooo`800000;`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`2^0?ooo`@00000503oool00`000000oooo0?ooo`0C0?ooo`800000<@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`2b0?ooo`<000004P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0]@3oool5000000h0oooo00<000000?ooo`3oool03@3oool3000003@0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0^P3oool5000000X0oooo00<000000?ooo`3o
ool02@3oool3000003L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
_`3ooolF000003X0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`800000o`3ooolA0?oo
o`030000003oool0oooo00D0oooo00060?ooool00000500000070?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"LinearPolarizer with user-defined surface"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{\({1, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", \({1.`, 0.`, 0.`}\), ",", 
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({2, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", \({1.`, 0.`, 0.`}\), ",", 
            "49.9999999999999733`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.707106781186547461`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.70710678118654755`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
LinearPolarizer[Function[#1^2/100+#2^2/100], 90, 100, 30, CenterThickness->2, \
Centered->0], PlotType->TopView];\
\>", "Input",
  CellTags->"LinearPolarizer with user-defined surface"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 3.33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 1.66667 0.031746 [
[ 0 0 0 0 ]
[ 1 3.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.81746 .07937 m
.88095 .07937 L
.63845 .34392 L
.57496 .34392 L
.81746 .07937 L
F
.57496 .34392 m
.63845 .34392 L
.44004 .60847 L
.37654 .60847 L
.57496 .34392 L
F
.37654 .60847 m
.44004 .60847 L
.28571 .87302 L
.22222 .87302 L
.37654 .60847 L
F
.22222 .87302 m
.28571 .87302 L
.17549 1.13757 L
.11199 1.13757 L
.22222 .87302 L
F
.11199 1.13757 m
.17549 1.13757 L
.10935 1.40212 L
.04586 1.40212 L
.11199 1.13757 L
F
.04586 1.40212 m
.10935 1.40212 L
.0873 1.66667 L
.02381 1.66667 L
.04586 1.40212 L
F
.02381 1.66667 m
.0873 1.66667 L
.10935 1.93122 L
.04586 1.93122 L
.02381 1.66667 L
F
.04586 1.93122 m
.10935 1.93122 L
.17549 2.19577 L
.11199 2.19577 L
.04586 1.93122 L
F
.11199 2.19577 m
.17549 2.19577 L
.28571 2.46032 L
.22222 2.46032 L
.11199 2.19577 L
F
.22222 2.46032 m
.28571 2.46032 L
.44004 2.72487 L
.37654 2.72487 L
.22222 2.46032 L
F
.37654 2.72487 m
.44004 2.72487 L
.63845 2.98942 L
.57496 2.98942 L
.37654 2.72487 L
F
.57496 2.98942 m
.63845 2.98942 L
.88095 3.25397 L
.81746 3.25397 L
.57496 2.98942 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.81746 .07937 m
.57496 .34392 L
.37654 .60847 L
.22222 .87302 L
.11199 1.13757 L
.04586 1.40212 L
.02381 1.66667 L
.04586 1.93122 L
.11199 2.19577 L
.22222 2.46032 L
.37654 2.72487 L
.57496 2.98942 L
.81746 3.25397 L
.88095 3.25397 L
.63845 2.98942 L
.44004 2.72487 L
.28571 2.46032 L
.17549 2.19577 L
.10935 1.93122 L
.0873 1.66667 L
.10935 1.40212 L
.17549 1.13757 L
.28571 .87302 L
.44004 .60847 L
.63845 .34392 L
.88095 .07937 L
.81746 .07937 L
s
.5 g
.81746 1.66667 m
.88095 1.66667 L
.63845 1.66667 L
.57496 1.66667 L
.81746 1.66667 L
F
.57496 1.66667 m
.63845 1.66667 L
.44004 1.66667 L
.37654 1.66667 L
.57496 1.66667 L
F
.37654 1.66667 m
.44004 1.66667 L
.28571 1.66667 L
.22222 1.66667 L
.37654 1.66667 L
F
.22222 1.66667 m
.28571 1.66667 L
.17549 1.66667 L
.11199 1.66667 L
.22222 1.66667 L
F
.11199 1.66667 m
.17549 1.66667 L
.10935 1.66667 L
.04586 1.66667 L
.11199 1.66667 L
F
.04586 1.66667 m
.10935 1.66667 L
.0873 1.66667 L
.02381 1.66667 L
.04586 1.66667 L
F
.02381 1.66667 m
.0873 1.66667 L
.10935 1.66667 L
.04586 1.66667 L
.02381 1.66667 L
F
.04586 1.66667 m
.10935 1.66667 L
.17549 1.66667 L
.11199 1.66667 L
.04586 1.66667 L
F
.11199 1.66667 m
.17549 1.66667 L
.28571 1.66667 L
.22222 1.66667 L
.11199 1.66667 L
F
.22222 1.66667 m
.28571 1.66667 L
.44004 1.66667 L
.37654 1.66667 L
.22222 1.66667 L
F
.37654 1.66667 m
.44004 1.66667 L
.63845 1.66667 L
.57496 1.66667 L
.37654 1.66667 L
F
.57496 1.66667 m
.63845 1.66667 L
.88095 1.66667 L
.81746 1.66667 L
.57496 1.66667 L
F
0 g
.81746 1.66667 m
.57496 1.66667 L
.37654 1.66667 L
.22222 1.66667 L
.11199 1.66667 L
.04586 1.66667 L
.02381 1.66667 L
.04586 1.66667 L
.11199 1.66667 L
.22222 1.66667 L
.37654 1.66667 L
.57496 1.66667 L
.81746 1.66667 L
.88095 1.66667 L
.63845 1.66667 L
.44004 1.66667 L
.28571 1.66667 L
.17549 1.66667 L
.10935 1.66667 L
.0873 1.66667 L
.10935 1.66667 L
.17549 1.66667 L
.28571 1.66667 L
.44004 1.66667 L
.63845 1.66667 L
.88095 1.66667 L
.81746 1.66667 L
s
.5 g
.88095 .07937 m
.97619 .07937 L
.97619 .34392 L
.63845 .34392 L
.88095 .07937 L
F
.63845 .34392 m
.97619 .34392 L
.97619 .60847 L
.44004 .60847 L
.63845 .34392 L
F
.44004 .60847 m
.97619 .60847 L
.97619 .87302 L
.28571 .87302 L
.44004 .60847 L
F
.28571 .87302 m
.97619 .87302 L
.97619 1.13757 L
.17549 1.13757 L
.28571 .87302 L
F
.17549 1.13757 m
.97619 1.13757 L
.97619 1.40212 L
.10935 1.40212 L
.17549 1.13757 L
F
.10935 1.40212 m
.97619 1.40212 L
.97619 1.66667 L
.0873 1.66667 L
.10935 1.40212 L
F
.0873 1.66667 m
.97619 1.66667 L
.97619 1.93122 L
.10935 1.93122 L
.0873 1.66667 L
F
.10935 1.93122 m
.97619 1.93122 L
.97619 2.19577 L
.17549 2.19577 L
.10935 1.93122 L
F
.17549 2.19577 m
.97619 2.19577 L
.97619 2.46032 L
.28571 2.46032 L
.17549 2.19577 L
F
.28571 2.46032 m
.97619 2.46032 L
.97619 2.72487 L
.44004 2.72487 L
.28571 2.46032 L
F
.44004 2.72487 m
.97619 2.72487 L
.97619 2.98942 L
.63845 2.98942 L
.44004 2.72487 L
F
.63845 2.98942 m
.97619 2.98942 L
.97619 3.25397 L
.88095 3.25397 L
.63845 2.98942 L
F
0 g
.88095 .07937 m
.63845 .34392 L
.44004 .60847 L
.28571 .87302 L
.17549 1.13757 L
.10935 1.40212 L
.0873 1.66667 L
.10935 1.93122 L
.17549 2.19577 L
.28571 2.46032 L
.44004 2.72487 L
.63845 2.98942 L
.88095 3.25397 L
.97619 3.25397 L
.97619 2.98942 L
.97619 2.72487 L
.97619 2.46032 L
.97619 2.19577 L
.97619 1.93122 L
.97619 1.66667 L
.97619 1.40212 L
.97619 1.13757 L
.97619 .87302 L
.97619 .60847 L
.97619 .34392 L
.97619 .07937 L
.88095 .07937 L
s
.5 g
.88095 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.63845 1.66667 L
.88095 1.66667 L
F
.63845 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.44004 1.66667 L
.63845 1.66667 L
F
.44004 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.28571 1.66667 L
.44004 1.66667 L
F
.28571 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.17549 1.66667 L
.28571 1.66667 L
F
.17549 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.10935 1.66667 L
.17549 1.66667 L
F
.10935 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.0873 1.66667 L
.10935 1.66667 L
F
.0873 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.10935 1.66667 L
.0873 1.66667 L
F
.10935 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.17549 1.66667 L
.10935 1.66667 L
F
.17549 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.28571 1.66667 L
.17549 1.66667 L
F
.28571 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.44004 1.66667 L
.28571 1.66667 L
F
.44004 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.63845 1.66667 L
.44004 1.66667 L
F
.63845 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.88095 1.66667 L
.63845 1.66667 L
F
0 g
.88095 1.66667 m
.63845 1.66667 L
.44004 1.66667 L
.28571 1.66667 L
.17549 1.66667 L
.10935 1.66667 L
.0873 1.66667 L
.10935 1.66667 L
.17549 1.66667 L
.28571 1.66667 L
.44004 1.66667 L
.63845 1.66667 L
.88095 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.88095 1.66667 L
s
.81746 3.25397 m
.81746 3.24039 L
.81746 3.19988 L
.81746 3.13314 L
.81746 3.04131 L
.81746 2.92596 L
.81746 2.78906 L
.81746 2.63295 L
.81746 2.46032 L
.81746 2.2741 L
.81746 2.07749 L
.81746 1.87385 L
.81746 1.66667 L
.81746 1.45948 L
.81746 1.25584 L
.81746 1.05923 L
.81746 .87302 L
.81746 .70038 L
.81746 .54427 L
.81746 .40738 L
.81746 .29202 L
.81746 .20019 L
.81746 .13345 L
.81746 .09294 L
.81746 .07937 L
.81746 .09294 L
.81746 .13345 L
.81746 .20019 L
.81746 .29202 L
.81746 .40738 L
.81746 .54427 L
.81746 .70038 L
.81746 .87302 L
.81746 1.05923 L
.81746 1.25584 L
.81746 1.45948 L
.81746 1.66667 L
.81746 1.87385 L
.81746 2.07749 L
.81746 2.2741 L
.81746 2.46032 L
.81746 2.63295 L
.81746 2.78906 L
.81746 2.92596 L
.81746 3.04131 L
.81746 3.13314 L
.81746 3.19988 L
.81746 3.24039 L
.81746 3.25397 L
s
.88095 3.25397 m
.88095 3.24039 L
.88095 3.19988 L
.88095 3.13314 L
.88095 3.04131 L
.88095 2.92596 L
.88095 2.78906 L
.88095 2.63295 L
.88095 2.46032 L
.88095 2.2741 L
.88095 2.07749 L
.88095 1.87385 L
.88095 1.66667 L
.88095 1.45948 L
.88095 1.25584 L
.88095 1.05923 L
.88095 .87302 L
.88095 .70038 L
.88095 .54427 L
.88095 .40738 L
.88095 .29202 L
.88095 .20019 L
.88095 .13345 L
.88095 .09294 L
.88095 .07937 L
.88095 .09294 L
.88095 .13345 L
.88095 .20019 L
.88095 .29202 L
.88095 .40738 L
.88095 .54427 L
.88095 .70038 L
.88095 .87302 L
.88095 1.05923 L
.88095 1.25584 L
.88095 1.45948 L
.88095 1.66667 L
.88095 1.87385 L
.88095 2.07749 L
.88095 2.2741 L
.88095 2.46032 L
.88095 2.63295 L
.88095 2.78906 L
.88095 2.92596 L
.88095 3.04131 L
.88095 3.13314 L
.88095 3.19988 L
.88095 3.24039 L
.88095 3.25397 L
s
.97619 3.25397 m
.97619 3.24039 L
.97619 3.19988 L
.97619 3.13314 L
.97619 3.04131 L
.97619 2.92596 L
.97619 2.78906 L
.97619 2.63295 L
.97619 2.46032 L
.97619 2.2741 L
.97619 2.07749 L
.97619 1.87385 L
.97619 1.66667 L
.97619 1.45948 L
.97619 1.25584 L
.97619 1.05923 L
.97619 .87302 L
.97619 .70038 L
.97619 .54427 L
.97619 .40738 L
.97619 .29202 L
.97619 .20019 L
.97619 .13345 L
.97619 .09294 L
.97619 .07937 L
.97619 .09294 L
.97619 .13345 L
.97619 .20019 L
.97619 .29202 L
.97619 .40738 L
.97619 .54427 L
.97619 .70038 L
.97619 .87302 L
.97619 1.05923 L
.97619 1.25584 L
.97619 1.45948 L
.97619 1.66667 L
.97619 1.87385 L
.97619 2.07749 L
.97619 2.2741 L
.97619 2.46032 L
.97619 2.63295 L
.97619 2.78906 L
.97619 2.92596 L
.97619 3.04131 L
.97619 3.13314 L
.97619 3.19988 L
.97619 3.24039 L
.97619 3.25397 L
s
.81746 3.25397 m
.88095 3.25397 L
.88095 3.24039 L
.81746 3.24039 L
.81746 3.25397 L
s
.81746 3.24039 m
.88095 3.24039 L
.88095 3.19988 L
.81746 3.19988 L
.81746 3.24039 L
s
.81746 3.19988 m
.88095 3.19988 L
.88095 3.13314 L
.81746 3.13314 L
.81746 3.19988 L
s
.81746 3.13314 m
.88095 3.13314 L
.88095 3.04131 L
.81746 3.04131 L
.81746 3.13314 L
s
.81746 3.04131 m
.88095 3.04131 L
.88095 2.92596 L
.81746 2.92596 L
.81746 3.04131 L
s
.81746 2.92596 m
.88095 2.92596 L
.88095 2.78906 L
.81746 2.78906 L
.81746 2.92596 L
s
.81746 2.78906 m
.88095 2.78906 L
.88095 2.63295 L
.81746 2.63295 L
.81746 2.78906 L
s
.81746 2.63295 m
.88095 2.63295 L
.88095 2.46032 L
.81746 2.46032 L
.81746 2.63295 L
s
.81746 2.46032 m
.88095 2.46032 L
.88095 2.2741 L
.81746 2.2741 L
.81746 2.46032 L
s
.81746 2.2741 m
.88095 2.2741 L
.88095 2.07749 L
.81746 2.07749 L
.81746 2.2741 L
s
.81746 2.07749 m
.88095 2.07749 L
.88095 1.87385 L
.81746 1.87385 L
.81746 2.07749 L
s
.81746 1.87385 m
.88095 1.87385 L
.88095 1.66667 L
.81746 1.66667 L
.81746 1.87385 L
s
.81746 1.66667 m
.88095 1.66667 L
.88095 1.45948 L
.81746 1.45948 L
.81746 1.66667 L
s
.81746 1.45948 m
.88095 1.45948 L
.88095 1.25584 L
.81746 1.25584 L
.81746 1.45948 L
s
.81746 1.25584 m
.88095 1.25584 L
.88095 1.05923 L
.81746 1.05923 L
.81746 1.25584 L
s
.81746 1.05923 m
.88095 1.05923 L
.88095 .87302 L
.81746 .87302 L
.81746 1.05923 L
s
.81746 .87302 m
.88095 .87302 L
.88095 .70038 L
.81746 .70038 L
.81746 .87302 L
s
.81746 .70038 m
.88095 .70038 L
.88095 .54427 L
.81746 .54427 L
.81746 .70038 L
s
.81746 .54427 m
.88095 .54427 L
.88095 .40738 L
.81746 .40738 L
.81746 .54427 L
s
.81746 .40738 m
.88095 .40738 L
.88095 .29202 L
.81746 .29202 L
.81746 .40738 L
s
.81746 .29202 m
.88095 .29202 L
.88095 .20019 L
.81746 .20019 L
.81746 .29202 L
s
.81746 .20019 m
.88095 .20019 L
.88095 .13345 L
.81746 .13345 L
.81746 .20019 L
s
.81746 .13345 m
.88095 .13345 L
.88095 .09294 L
.81746 .09294 L
.81746 .13345 L
s
.81746 .09294 m
.88095 .09294 L
.88095 .07937 L
.81746 .07937 L
.81746 .09294 L
s
.81746 .07937 m
.88095 .07937 L
.88095 .09294 L
.81746 .09294 L
.81746 .07937 L
s
.81746 .09294 m
.88095 .09294 L
.88095 .13345 L
.81746 .13345 L
.81746 .09294 L
s
.81746 .13345 m
.88095 .13345 L
.88095 .20019 L
.81746 .20019 L
.81746 .13345 L
s
.81746 .20019 m
.88095 .20019 L
.88095 .29202 L
.81746 .29202 L
.81746 .20019 L
s
.81746 .29202 m
.88095 .29202 L
.88095 .40738 L
.81746 .40738 L
.81746 .29202 L
s
.81746 .40738 m
.88095 .40738 L
.88095 .54427 L
.81746 .54427 L
.81746 .40738 L
s
.81746 .54427 m
.88095 .54427 L
.88095 .70038 L
.81746 .70038 L
.81746 .54427 L
s
.81746 .70038 m
.88095 .70038 L
.88095 .87302 L
.81746 .87302 L
.81746 .70038 L
s
.81746 .87302 m
.88095 .87302 L
.88095 1.05923 L
.81746 1.05923 L
.81746 .87302 L
s
.81746 1.05923 m
.88095 1.05923 L
.88095 1.25584 L
.81746 1.25584 L
.81746 1.05923 L
s
.81746 1.25584 m
.88095 1.25584 L
.88095 1.45948 L
.81746 1.45948 L
.81746 1.25584 L
s
.81746 1.45948 m
.88095 1.45948 L
.88095 1.66667 L
.81746 1.66667 L
.81746 1.45948 L
s
.81746 1.66667 m
.88095 1.66667 L
.88095 1.87385 L
.81746 1.87385 L
.81746 1.66667 L
s
.81746 1.87385 m
.88095 1.87385 L
.88095 2.07749 L
.81746 2.07749 L
.81746 1.87385 L
s
.81746 2.07749 m
.88095 2.07749 L
.88095 2.2741 L
.81746 2.2741 L
.81746 2.07749 L
s
.81746 2.2741 m
.88095 2.2741 L
.88095 2.46032 L
.81746 2.46032 L
.81746 2.2741 L
s
.81746 2.46032 m
.88095 2.46032 L
.88095 2.63295 L
.81746 2.63295 L
.81746 2.46032 L
s
.81746 2.63295 m
.88095 2.63295 L
.88095 2.78906 L
.81746 2.78906 L
.81746 2.63295 L
s
.81746 2.78906 m
.88095 2.78906 L
.88095 2.92596 L
.81746 2.92596 L
.81746 2.78906 L
s
.81746 2.92596 m
.88095 2.92596 L
.88095 3.04131 L
.81746 3.04131 L
.81746 2.92596 L
s
.81746 3.04131 m
.88095 3.04131 L
.88095 3.13314 L
.81746 3.13314 L
.81746 3.04131 L
s
.81746 3.13314 m
.88095 3.13314 L
.88095 3.19988 L
.81746 3.19988 L
.81746 3.13314 L
s
.81746 3.19988 m
.88095 3.19988 L
.88095 3.24039 L
.81746 3.24039 L
.81746 3.19988 L
s
.81746 3.24039 m
.88095 3.24039 L
.88095 3.25397 L
.81746 3.25397 L
.81746 3.24039 L
s
.88095 3.25397 m
.97619 3.25397 L
.97619 3.24039 L
.88095 3.24039 L
.88095 3.25397 L
s
.88095 3.24039 m
.97619 3.24039 L
.97619 3.19988 L
.88095 3.19988 L
.88095 3.24039 L
s
.88095 3.19988 m
.97619 3.19988 L
.97619 3.13314 L
.88095 3.13314 L
.88095 3.19988 L
s
.88095 3.13314 m
.97619 3.13314 L
.97619 3.04131 L
.88095 3.04131 L
.88095 3.13314 L
s
.88095 3.04131 m
.97619 3.04131 L
.97619 2.92596 L
.88095 2.92596 L
.88095 3.04131 L
s
.88095 2.92596 m
.97619 2.92596 L
.97619 2.78906 L
.88095 2.78906 L
.88095 2.92596 L
s
.88095 2.78906 m
.97619 2.78906 L
.97619 2.63295 L
.88095 2.63295 L
.88095 2.78906 L
s
.88095 2.63295 m
.97619 2.63295 L
.97619 2.46032 L
.88095 2.46032 L
.88095 2.63295 L
s
.88095 2.46032 m
.97619 2.46032 L
.97619 2.2741 L
.88095 2.2741 L
.88095 2.46032 L
s
.88095 2.2741 m
.97619 2.2741 L
.97619 2.07749 L
.88095 2.07749 L
.88095 2.2741 L
s
.88095 2.07749 m
.97619 2.07749 L
.97619 1.87385 L
.88095 1.87385 L
.88095 2.07749 L
s
.88095 1.87385 m
.97619 1.87385 L
.97619 1.66667 L
.88095 1.66667 L
.88095 1.87385 L
s
.88095 1.66667 m
.97619 1.66667 L
.97619 1.45948 L
.88095 1.45948 L
.88095 1.66667 L
s
.88095 1.45948 m
.97619 1.45948 L
.97619 1.25584 L
.88095 1.25584 L
.88095 1.45948 L
s
.88095 1.25584 m
.97619 1.25584 L
.97619 1.05923 L
.88095 1.05923 L
.88095 1.25584 L
s
.88095 1.05923 m
.97619 1.05923 L
.97619 .87302 L
.88095 .87302 L
.88095 1.05923 L
s
.88095 .87302 m
.97619 .87302 L
.97619 .70038 L
.88095 .70038 L
.88095 .87302 L
s
.88095 .70038 m
.97619 .70038 L
.97619 .54427 L
.88095 .54427 L
.88095 .70038 L
s
.88095 .54427 m
.97619 .54427 L
.97619 .40738 L
.88095 .40738 L
.88095 .54427 L
s
.88095 .40738 m
.97619 .40738 L
.97619 .29202 L
.88095 .29202 L
.88095 .40738 L
s
.88095 .29202 m
.97619 .29202 L
.97619 .20019 L
.88095 .20019 L
.88095 .29202 L
s
.88095 .20019 m
.97619 .20019 L
.97619 .13345 L
.88095 .13345 L
.88095 .20019 L
s
.88095 .13345 m
.97619 .13345 L
.97619 .09294 L
.88095 .09294 L
.88095 .13345 L
s
.88095 .09294 m
.97619 .09294 L
.97619 .07937 L
.88095 .07937 L
.88095 .09294 L
s
.88095 .07937 m
.97619 .07937 L
.97619 .09294 L
.88095 .09294 L
.88095 .07937 L
s
.88095 .09294 m
.97619 .09294 L
.97619 .13345 L
.88095 .13345 L
.88095 .09294 L
s
.88095 .13345 m
.97619 .13345 L
.97619 .20019 L
.88095 .20019 L
.88095 .13345 L
s
.88095 .20019 m
.97619 .20019 L
.97619 .29202 L
.88095 .29202 L
.88095 .20019 L
s
.88095 .29202 m
.97619 .29202 L
.97619 .40738 L
.88095 .40738 L
.88095 .29202 L
s
.88095 .40738 m
.97619 .40738 L
.97619 .54427 L
.88095 .54427 L
.88095 .40738 L
s
.88095 .54427 m
.97619 .54427 L
.97619 .70038 L
.88095 .70038 L
.88095 .54427 L
s
.88095 .70038 m
.97619 .70038 L
.97619 .87302 L
.88095 .87302 L
.88095 .70038 L
s
.88095 .87302 m
.97619 .87302 L
.97619 1.05923 L
.88095 1.05923 L
.88095 .87302 L
s
.88095 1.05923 m
.97619 1.05923 L
.97619 1.25584 L
.88095 1.25584 L
.88095 1.05923 L
s
.88095 1.25584 m
.97619 1.25584 L
.97619 1.45948 L
.88095 1.45948 L
.88095 1.25584 L
s
.88095 1.45948 m
.97619 1.45948 L
.97619 1.66667 L
.88095 1.66667 L
.88095 1.45948 L
s
.88095 1.66667 m
.97619 1.66667 L
.97619 1.87385 L
.88095 1.87385 L
.88095 1.66667 L
s
.88095 1.87385 m
.97619 1.87385 L
.97619 2.07749 L
.88095 2.07749 L
.88095 1.87385 L
s
.88095 2.07749 m
.97619 2.07749 L
.97619 2.2741 L
.88095 2.2741 L
.88095 2.07749 L
s
.88095 2.2741 m
.97619 2.2741 L
.97619 2.46032 L
.88095 2.46032 L
.88095 2.2741 L
s
.88095 2.46032 m
.97619 2.46032 L
.97619 2.63295 L
.88095 2.63295 L
.88095 2.46032 L
s
.88095 2.63295 m
.97619 2.63295 L
.97619 2.78906 L
.88095 2.78906 L
.88095 2.63295 L
s
.88095 2.78906 m
.97619 2.78906 L
.97619 2.92596 L
.88095 2.92596 L
.88095 2.78906 L
s
.88095 2.92596 m
.97619 2.92596 L
.97619 3.04131 L
.88095 3.04131 L
.88095 2.92596 L
s
.88095 3.04131 m
.97619 3.04131 L
.97619 3.13314 L
.88095 3.13314 L
.88095 3.04131 L
s
.88095 3.13314 m
.97619 3.13314 L
.97619 3.19988 L
.88095 3.19988 L
.88095 3.13314 L
s
.88095 3.19988 m
.97619 3.19988 L
.97619 3.24039 L
.88095 3.24039 L
.88095 3.19988 L
s
.88095 3.24039 m
.97619 3.24039 L
.97619 3.25397 L
.88095 3.25397 L
.88095 3.24039 L
s
0 0 m
1 0 L
1 3.33333 L
0 3.33333 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{78.8125, 262.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001>00011R000`400?l00000o`00003oCP3oool0
04h0oooo001>0?ooo`00CP3oool004h0oooo001>0?ooo`00CP3oool003l0oooo3@0000020?ooo`00
?`3oool=00000080oooo000n0?ooo`8000000`1oOgl2000000H0Ogmo0@0000010?ooo`40oooo000m
0?ooo`030000001oOgl000000080Ogmo00<0000007moO`0000001P1oOgl100000040oooo0@3oool0
03`0oooo00<0000007moO`1oOgl03@0000020?ooo`00>`3oool010000000Ogmo07moO`1oOgl20000
00<0Ogmo00<0000007moO`1oOgl0101oOgl100000040oooo0@3oool003X0oooo00<0000007moO`1o
Ogl00P1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40
oooo000i0?ooo`030000001oOgl0Ogmo0080Ogmo0P00000407moO`030000001oOgl0Ogmo00@0Ogmo
0@0000010?ooo`40oooo000h0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`000000101o
Ogl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00=`3oool00`000000Ogmo07moO`02
07moO`040000001oOgl0Ogmo000000@0Ogmo00<0000007moO`1oOgl0101oOgl100000040oooo0@3o
ool003H0oooo00<0000007moO`1oOgl00P1oOgl010000000Ogmo07moO`1oOgl=00000080oooo000e
0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`02
07moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000e0?ooo`030000001oOgl0Ogmo
0080Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo
00@0Ogmo0@0000010?ooo`40oooo000d0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40
oooo000c0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000b0?ooo`030000001o
Ogl0Ogmo0080Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0207moO`030000001o
Ogl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000a0?ooo`030000001oOgl0Ogmo0080Ogmo00<00000
07moO`1oOgl01P1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@000001
0?ooo`40oooo000`0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl01`1oOgl=0000
0080oooo000_0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0201oOgl00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000^0?ooo`030000
001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0207moO`030000
001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000]0?ooo`030000001oOgl0Ogmo0080Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@00
00010?ooo`40oooo000/0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl02`1oOgl0
0`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000/0?oo
o`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000[0?ooo`030000001oOgl0Ogmo0080
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0
Ogmo0@0000010?ooo`40oooo000Z0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0
3@1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo
000Y0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl03P1oOgl00`000000Ogmo07mo
O`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000Y0?ooo`030000001oOgl0
Ogmo0080Ogmo00<0000007moO`1oOgl03P1oOgl=00000080oooo000X0?ooo`030000001oOgl0Ogmo
0080Ogmo00<0000007moO`1oOgl03`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo
00@0Ogmo0@0000010?ooo`40oooo000W0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1o
Ogl0401oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40
oooo000V0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl04@1oOgl00`000000Ogmo
07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000V0?ooo`030000001o
Ogl0Ogmo0080Ogmo00<0000007moO`1oOgl04@1oOgl00`000000Ogmo07moO`0207moO`030000001o
Ogl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000U0?ooo`030000001oOgl0Ogmo0080Ogmo00<00000
07moO`1oOgl04P1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@000001
0?ooo`40oooo000T0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl04`1oOgl00`00
0000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000S0?ooo`03
0000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0501oOgl00`000000Ogmo07moO`0207moO`03
0000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000S0?ooo`030000001oOgl0Ogmo0080Ogmo
00<0000007moO`1oOgl0501oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo
0@0000010?ooo`40oooo000R0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl05@1o
Ogl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000Q
0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl05P1oOgl=00000080oooo000P0?oo
o`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl05`1oOgl00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000P0?ooo`030000001oOgl0Ogmo0080
Ogmo00<0000007moO`1oOgl05`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0
Ogmo0@0000010?ooo`40oooo000O0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0
601oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo
000N0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl06@1oOgl00`000000Ogmo07mo
O`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000M0?ooo`030000001oOgl0
Ogmo0080Ogmo00<0000007moO`1oOgl06P1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0
Ogmo00@0Ogmo0@0000010?ooo`40oooo000M0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007mo
O`1oOgl06P1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?oo
o`40oooo000L0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl06`1oOgl00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000L0?ooo`030000
001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl06`1oOgl00`000000Ogmo07moO`0207moO`030000
001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000K0?ooo`030000001oOgl0Ogmo0080Ogmo00<0
000007moO`1oOgl0701oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@00
00010?ooo`40oooo000J0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl07@1oOgl0
0`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000J0?oo
o`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl07@1oOgl00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000I0?ooo`030000001oOgl0Ogmo0080
Ogmo00<0000007moO`1oOgl07P1oOgl=00000080oooo000I0?ooo`030000001oOgl0Ogmo0080Ogmo
00<0000007moO`1oOgl07P1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo
0@0000010?ooo`40oooo000H0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl07`1o
Ogl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000H
0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl07`1oOgl00`000000Ogmo07moO`02
07moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000G0?ooo`030000001oOgl0Ogmo
0080Ogmo00<0000007moO`1oOgl0801oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo
00@0Ogmo0@0000010?ooo`40oooo000F0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1o
Ogl08@1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40
oooo000F0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl08@1oOgl00`000000Ogmo
07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000E0?ooo`030000001o
Ogl0Ogmo0080Ogmo00<0000007moO`1oOgl08P1oOgl00`000000Ogmo07moO`0207moO`030000001o
Ogl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000E0?ooo`030000001oOgl0Ogmo0080Ogmo00<00000
07moO`1oOgl08P1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@000001
0?ooo`40oooo000D0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl08`1oOgl00`00
0000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000D0?ooo`03
0000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl08`1oOgl00`000000Ogmo07moO`0207moO`03
0000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000C0?ooo`030000001oOgl0Ogmo0080Ogmo
00<0000007moO`1oOgl0901oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo
0@0000010?ooo`40oooo000B0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl09@1o
Ogl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000B
0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl09@1oOgl00`000000Ogmo07moO`02
07moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000A0?ooo`030000001oOgl0Ogmo
0080Ogmo00<0000007moO`1oOgl09P1oOgl=00000080oooo000A0?ooo`030000001oOgl0Ogmo0080
Ogmo00<0000007moO`1oOgl09P1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0
Ogmo0@0000010?ooo`40oooo000@0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0
9`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo
000@0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl09`1oOgl00`000000Ogmo07mo
O`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000?0?ooo`030000001oOgl0
Ogmo0080Ogmo00<0000007moO`1oOgl0:01oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0
Ogmo00@0Ogmo0@0000010?ooo`40oooo000?0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007mo
O`1oOgl0:01oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?oo
o`40oooo000?0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0:01oOgl00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000>0?ooo`030000
001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0:@1oOgl00`000000Ogmo07moO`0207moO`030000
001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000>0?ooo`030000001oOgl0Ogmo0080Ogmo00<0
000007moO`1oOgl0:@1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@00
00010?ooo`40oooo000=0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0:P1oOgl0
0`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000=0?oo
o`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0:P1oOgl00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000<0?ooo`030000001oOgl0Ogmo0080
Ogmo00<0000007moO`1oOgl0:`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0
Ogmo0@0000010?ooo`40oooo000<0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0
:`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo
000;0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0;01oOgl00`000000Ogmo07mo
O`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo000;0?ooo`030000001oOgl0
Ogmo0080Ogmo00<0000007moO`1oOgl0;01oOgl=00000080oooo000:0?ooo`030000001oOgl0Ogmo
0080Ogmo00<0000007moO`1oOgl0;@1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo
00@0Ogmo0@0000010?ooo`40oooo000:0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1o
Ogl0;@1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40
oooo000:0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0;@1oOgl00`000000Ogmo
07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00090?ooo`030000001o
Ogl0Ogmo0080Ogmo00<0000007moO`1oOgl0;P1oOgl00`000000Ogmo07moO`0207moO`030000001o
Ogl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00090?ooo`030000001oOgl0Ogmo0080Ogmo00<00000
07moO`1oOgl0;P1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@000001
0?ooo`40oooo00080?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0;`1oOgl00`00
0000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00080?ooo`03
0000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0;`1oOgl00`000000Ogmo07moO`0207moO`03
0000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00080?ooo`030000001oOgl0Ogmo0080Ogmo
00<0000007moO`1oOgl0;`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo
0@0000010?ooo`40oooo00070?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0<01o
Ogl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo0007
0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0<01oOgl00`000000Ogmo07moO`02
07moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00070?ooo`030000001oOgl0Ogmo
0080Ogmo00<0000007moO`1oOgl0<01oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo
00@0Ogmo0@0000010?ooo`40oooo00070?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1o
Ogl0<01oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40
oooo00060?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0<@1oOgl00`000000Ogmo
07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00060?ooo`030000001o
Ogl0Ogmo0080Ogmo00<0000007moO`1oOgl0<@1oOgl00`000000Ogmo07moO`0207moO`030000001o
Ogl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00060?ooo`030000001oOgl0Ogmo0080Ogmo00<00000
07moO`1oOgl0<@1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@000001
0?ooo`40oooo00060?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0<@1oOgl=0000
0080oooo00050?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0<P1oOgl00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00050?ooo`030000
001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0<P1oOgl00`000000Ogmo07moO`0207moO`030000
001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00050?ooo`030000001oOgl0Ogmo0080Ogmo00<0
000007moO`1oOgl0<P1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@00
00010?ooo`40oooo00050?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0<P1oOgl0
0`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00050?oo
o`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0<P1oOgl00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00040?ooo`030000001oOgl0Ogmo0080
Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0
Ogmo0@0000010?ooo`40oooo00040?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0
<`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo
00040?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000Ogmo07mo
O`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00040?ooo`030000001oOgl0
Ogmo0080Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0
Ogmo00@0Ogmo0@0000010?ooo`40oooo00030?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007mo
O`1oOgl0=01oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?oo
o`40oooo00030?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0=01oOgl00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00030?ooo`030000
001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0=01oOgl00`000000Ogmo07moO`0207moO`030000
001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00030?ooo`030000001oOgl0Ogmo0080Ogmo00<0
000007moO`1oOgl0=01oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@00
00010?ooo`40oooo00030?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0=01oOgl0
0`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00030?oo
o`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0=01oOgl00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00030?ooo`030000001oOgl0Ogmo0080
Ogmo00<0000007moO`1oOgl0=01oOgl=00000080oooo00020?ooo`030000001oOgl0Ogmo0080Ogmo
00<0000007moO`1oOgl0=@1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo
0@0000010?ooo`40oooo00020?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0=@1o
Ogl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo0002
0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0=@1oOgl00`000000Ogmo07moO`02
07moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00020?ooo`030000001oOgl0Ogmo
0080Ogmo00<0000007moO`1oOgl0=@1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo
00@0Ogmo0@0000010?ooo`40oooo00020?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1o
Ogl0=@1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40
oooo00020?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0=@1oOgl00`000000Ogmo
07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00020?ooo`030000001o
Ogl0Ogmo0080Ogmo00<0000007moO`1oOgl0=@1oOgl00`000000Ogmo07moO`0207moO`030000001o
Ogl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00020?ooo`030000001oOgl0Ogmo0080Ogmo00<00000
07moO`1oOgl0=@1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@000001
0?ooo`40oooo00020?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0=@1oOgl00`00
0000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00020?ooo`03
0000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0=@1oOgl00`000000Ogmo07moO`0207moO`03
0000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00020?ooo`030000001oOgl0Ogmo0080Ogmo
00<0000007moO`1oOgl0=@1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo
0@0000010?ooo`40oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo03H0Ogmo00<0
000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`0000<0oooo
0000001oOgl00`1oOgl00`000000Ogmo07moO`0f07moO`030000001oOgl0Ogmo0080Ogmo00<00000
07moO`1oOgl0101oOgl100000040oooo0@3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007mo
O`1oOgl0=P1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?oo
o`40oooo00000`3oool0000007moO`0307moO`030000001oOgl0Ogmo03H0Ogmo00<0000007moO`1o
Ogl00P1oOgl00`000000Ogmo07moO`0407moO`8000000@3oool000030?ooo`000000000004T00000
0P3oool000030?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0=P1oOgl00`000000Ogmo07mo
O`0207moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00000`3oool0000007moO`03
07moO`030000001oOgl0Ogmo03H0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`04
07moO`4000000@3oool10?ooo`0000<0oooo0000001oOgl00`1oOgl00`000000Ogmo07moO`0f07mo
O`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0101oOgl100000040oooo0@3oool00003
0?ooo`000000Ogmo00<0Ogmo00<0000007moO`1oOgl0=P1oOgl00`000000Ogmo07moO`0207moO`03
0000001oOgl0Ogmo00@0Ogmo0@0000010?ooo`40oooo00000`3oool0000007moO`0307moO`030000
001oOgl0Ogmo03H0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`400000
0@3oool10?ooo`000P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo03D0Ogmo00<0
000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`000P3oool0
0`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo03D0Ogmo00<0000007moO`1oOgl00P1oOgl0
0`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`000P3oool00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo03D0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407mo
O`4000000@3oool10?ooo`000P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo03D0
Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00
0P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo03D0Ogmo00<0000007moO`1oOgl0
0P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`000P3oool00`000000Ogmo07mo
O`0207moO`030000001oOgl0Ogmo03D0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07mo
O`0407moO`4000000@3oool10?ooo`000P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0
Ogmo03D0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool1
0?ooo`000P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo03D0Ogmo00<0000007mo
O`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`000P3oool00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo03D0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000
Ogmo07moO`0407moO`4000000@3oool10?ooo`000P3oool00`000000Ogmo07moO`0207moO`030000
001oOgl0Ogmo03D0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`400000
0@3oool10?ooo`000`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo03@0Ogmo3@00
00020?ooo`000`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo03@0Ogmo00<00000
07moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`000`3oool00`00
0000Ogmo07moO`0207moO`030000001oOgl0Ogmo03@0Ogmo00<0000007moO`1oOgl00P1oOgl00`00
0000Ogmo07moO`0407moO`4000000@3oool10?ooo`000`3oool00`000000Ogmo07moO`0207moO`03
0000001oOgl0Ogmo03@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`40
00000@3oool10?ooo`000`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo03@0Ogmo
00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`000`3o
ool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo03@0Ogmo00<0000007moO`1oOgl00P1o
Ogl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`000`3oool00`000000Ogmo07moO`02
07moO`030000001oOgl0Ogmo03@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`04
07moO`4000000@3oool10?ooo`00103oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo
03<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?oo
o`00103oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo03<0Ogmo00<0000007moO`1o
Ogl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00103oool00`000000Ogmo
07moO`0207moO`030000001oOgl0Ogmo03<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo
07moO`0407moO`4000000@3oool10?ooo`00103oool00`000000Ogmo07moO`0207moO`030000001o
Ogl0Ogmo03<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3o
ool10?ooo`001@3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0380Ogmo00<00000
07moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`001@3oool00`00
0000Ogmo07moO`0207moO`030000001oOgl0Ogmo0380Ogmo00<0000007moO`1oOgl00P1oOgl00`00
0000Ogmo07moO`0407moO`4000000@3oool10?ooo`001@3oool00`000000Ogmo07moO`0207moO`03
0000001oOgl0Ogmo0380Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`40
00000@3oool10?ooo`001@3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0380Ogmo
00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`001P3o
ool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0340Ogmo00<0000007moO`1oOgl00P1o
Ogl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`001P3oool00`000000Ogmo07moO`02
07moO`030000001oOgl0Ogmo0340Ogmo3@0000020?ooo`001P3oool00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo0340Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407mo
O`4000000@3oool10?ooo`001P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0340
Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00
1P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0340Ogmo00<0000007moO`1oOgl0
0P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`001`3oool00`000000Ogmo07mo
O`0207moO`030000001oOgl0Ogmo0300Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07mo
O`0407moO`4000000@3oool10?ooo`001`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0
Ogmo0300Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool1
0?ooo`001`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0300Ogmo00<0000007mo
O`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`001`3oool00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo0300Ogmo00<0000007moO`1oOgl00P1oOgl00`000000
Ogmo07moO`0407moO`4000000@3oool10?ooo`00203oool00`000000Ogmo07moO`0207moO`030000
001oOgl0Ogmo02l0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`400000
0@3oool10?ooo`00203oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo02l0Ogmo00<0
000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00203oool0
0`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo02l0Ogmo00<0000007moO`1oOgl00P1oOgl0
0`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`002@3oool00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo02h0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407mo
O`4000000@3oool10?ooo`002@3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo02h0
Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00
2P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo02d0Ogmo00<0000007moO`1oOgl0
0P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`002P3oool00`000000Ogmo07mo
O`0207moO`030000001oOgl0Ogmo02d0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07mo
O`0407moO`4000000@3oool10?ooo`002P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0
Ogmo02d0Ogmo3@0000020?ooo`002`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo
02`0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?oo
o`002`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo02`0Ogmo00<0000007moO`1o
Ogl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00303oool00`000000Ogmo
07moO`0207moO`030000001oOgl0Ogmo02/0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo
07moO`0407moO`4000000@3oool10?ooo`00303oool00`000000Ogmo07moO`0207moO`030000001o
Ogl0Ogmo02/0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3o
ool10?ooo`003@3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo02X0Ogmo00<00000
07moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`003@3oool00`00
0000Ogmo07moO`0207moO`030000001oOgl0Ogmo02X0Ogmo00<0000007moO`1oOgl00P1oOgl00`00
0000Ogmo07moO`0407moO`4000000@3oool10?ooo`003P3oool00`000000Ogmo07moO`0207moO`03
0000001oOgl0Ogmo02T0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`40
00000@3oool10?ooo`003P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo02T0Ogmo
00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`003`3o
ool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo02P0Ogmo00<0000007moO`1oOgl00P1o
Ogl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`003`3oool00`000000Ogmo07moO`02
07moO`030000001oOgl0Ogmo02P0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`04
07moO`4000000@3oool10?ooo`003`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo
02P0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?oo
o`00403oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo02L0Ogmo00<0000007moO`1o
Ogl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00403oool00`000000Ogmo
07moO`0207moO`030000001oOgl0Ogmo02L0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo
07moO`0407moO`4000000@3oool10?ooo`004@3oool00`000000Ogmo07moO`0207moO`030000001o
Ogl0Ogmo02H0Ogmo3@0000020?ooo`004@3oool00`000000Ogmo07moO`0207moO`030000001oOgl0
Ogmo02H0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool1
0?ooo`004P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo02D0Ogmo00<0000007mo
O`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`004P3oool00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo02D0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000
Ogmo07moO`0407moO`4000000@3oool10?ooo`004`3oool00`000000Ogmo07moO`0207moO`030000
001oOgl0Ogmo02@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`400000
0@3oool10?ooo`00503oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo02<0Ogmo00<0
000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00503oool0
0`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo02<0Ogmo00<0000007moO`1oOgl00P1oOgl0
0`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`005@3oool00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo0280Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407mo
O`4000000@3oool10?ooo`005@3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0280
Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00
5P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0240Ogmo00<0000007moO`1oOgl0
0P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`005P3oool00`000000Ogmo07mo
O`0207moO`030000001oOgl0Ogmo0240Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07mo
O`0407moO`4000000@3oool10?ooo`005`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0
Ogmo0200Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool1
0?ooo`00603oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo01l0Ogmo00<0000007mo
O`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00603oool00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo01l0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000
Ogmo07moO`0407moO`4000000@3oool10?ooo`006@3oool00`000000Ogmo07moO`0207moO`030000
001oOgl0Ogmo01h0Ogmo3@0000020?ooo`006@3oool00`000000Ogmo07moO`0207moO`030000001o
Ogl0Ogmo01h0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3o
ool10?ooo`006P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo01d0Ogmo00<00000
07moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`006P3oool00`00
0000Ogmo07moO`0207moO`030000001oOgl0Ogmo01d0Ogmo00<0000007moO`1oOgl00P1oOgl00`00
0000Ogmo07moO`0407moO`4000000@3oool10?ooo`006`3oool00`000000Ogmo07moO`0207moO`03
0000001oOgl0Ogmo01`0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`40
00000@3oool10?ooo`00703oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo01/0Ogmo
00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00703o
ool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo01/0Ogmo00<0000007moO`1oOgl00P1o
Ogl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`007@3oool00`000000Ogmo07moO`02
07moO`030000001oOgl0Ogmo01X0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`04
07moO`4000000@3oool10?ooo`007@3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo
01X0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?oo
o`007P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo01T0Ogmo00<0000007moO`1o
Ogl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`007`3oool00`000000Ogmo
07moO`0207moO`030000001oOgl0Ogmo01P0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo
07moO`0407moO`4000000@3oool10?ooo`00803oool00`000000Ogmo07moO`0207moO`030000001o
Ogl0Ogmo01L0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3o
ool10?ooo`00803oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo01L0Ogmo3@000002
0?ooo`008@3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo01H0Ogmo00<0000007mo
O`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`008P3oool00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo01D0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000
Ogmo07moO`0407moO`4000000@3oool10?ooo`008P3oool00`000000Ogmo07moO`0207moO`030000
001oOgl0Ogmo01D0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`400000
0@3oool10?ooo`008`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo01@0Ogmo00<0
000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00903oool0
0`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo01<0Ogmo00<0000007moO`1oOgl00P1oOgl0
0`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`009@3oool00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo0180Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407mo
O`4000000@3oool10?ooo`009@3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0180
Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00
9P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0140Ogmo00<0000007moO`1oOgl0
0P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`009`3oool00`000000Ogmo07mo
O`0207moO`030000001oOgl0Ogmo0100Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07mo
O`0407moO`4000000@3oool10?ooo`009`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0
Ogmo0100Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool1
0?ooo`00:03oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00l0Ogmo3@0000020?oo
o`00:@3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00h0Ogmo00<0000007moO`1o
Ogl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00:P3oool00`000000Ogmo
07moO`0207moO`030000001oOgl0Ogmo00d0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo
07moO`0407moO`4000000@3oool10?ooo`00:P3oool00`000000Ogmo07moO`0207moO`030000001o
Ogl0Ogmo00d0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3o
ool10?ooo`00:`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00;03oool00`00
0000Ogmo07moO`0207moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl00P1oOgl00`00
0000Ogmo07moO`0407moO`4000000@3oool10?ooo`00;03oool00`000000Ogmo07moO`0207moO`03
0000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`40
00000@3oool10?ooo`00;@3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00;P3o
ool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl00P1o
Ogl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00;`3oool00`000000Ogmo07moO`02
07moO`030000001oOgl0Ogmo00P0Ogmo3@0000020?ooo`00<03oool00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407mo
O`4000000@3oool10?ooo`00<@3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00H0
Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00
<P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0
0P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00<`3oool00`000000Ogmo07mo
O`0207moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07mo
O`0407moO`4000000@3oool10?ooo`00=03oool00`000000Ogmo07moO`0207moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool1
0?ooo`00=@3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0080Ogmo00<0000007mo
O`1oOgl00P1oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00=P3oool00`000000
Ogmo07moO`0207moO`040000001oOgl0Ogmo07moO`d000000P3oool003L0oooo00<0000007moO`1o
Ogl00P1oOgl010000000Ogmo07moO`00000407moO`030000001oOgl0Ogmo00@0Ogmo0@0000010?oo
o`40oooo000h0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`000000101oOgl00`000000
Ogmo07moO`0407moO`4000000@3oool10?ooo`00>@3oool00`000000Ogmo07moO`0207moO`800000
101oOgl00`000000Ogmo07moO`0407moO`4000000@3oool10?ooo`00>P3oool00`000000Ogmo07mo
O`0207moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0101oOgl100000040oooo0@3o
ool003/0oooo00@0000007moO`1oOgl0Ogmo3@0000020?ooo`00?03oool01P000000Ogmo07moO`00
0000Ogmo00000080Ogmo00<0000007moO`1oOgl0101oOgl100000040oooo0@3oool003d0oooo00<0
000007moO`0000000P1oOgl00`000000Ogmo0000000607moO`4000000@3oool10?ooo`00?P3oool>
00000080oooo000o0?ooo`d000000P3oool004h0oooo001>0?ooo`00CP3oool004h0oooo001>0?oo
o`00CP3oool004h0oooo0000\
\>"],
  ImageRangeCache->{{{0, 77.8125}, {261.688, 0}} -> {-0.750157, -52.9688, \
0.404824, 0.404824}},
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
LinearPolarizer[Function[#1^2/100+#2^2/100], 90, 100, 30, CenterThickness->2, \
Centered->1], PlotType->TopView];\
\>", "Input",
  CellTags->"LinearPolarizer with user-defined surface"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 3.33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 1.66667 0.031746 [
[ 0 0 0 0 ]
[ 1 3.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.81746 .07937 m
.9127 .07937 L
.9127 .34392 L
.57496 .34392 L
.81746 .07937 L
F
.57496 .34392 m
.9127 .34392 L
.9127 .60847 L
.37654 .60847 L
.57496 .34392 L
F
.37654 .60847 m
.9127 .60847 L
.9127 .87302 L
.22222 .87302 L
.37654 .60847 L
F
.22222 .87302 m
.9127 .87302 L
.9127 1.13757 L
.11199 1.13757 L
.22222 .87302 L
F
.11199 1.13757 m
.9127 1.13757 L
.9127 1.40212 L
.04586 1.40212 L
.11199 1.13757 L
F
.04586 1.40212 m
.9127 1.40212 L
.9127 1.66667 L
.02381 1.66667 L
.04586 1.40212 L
F
.02381 1.66667 m
.9127 1.66667 L
.9127 1.93122 L
.04586 1.93122 L
.02381 1.66667 L
F
.04586 1.93122 m
.9127 1.93122 L
.9127 2.19577 L
.11199 2.19577 L
.04586 1.93122 L
F
.11199 2.19577 m
.9127 2.19577 L
.9127 2.46032 L
.22222 2.46032 L
.11199 2.19577 L
F
.22222 2.46032 m
.9127 2.46032 L
.9127 2.72487 L
.37654 2.72487 L
.22222 2.46032 L
F
.37654 2.72487 m
.9127 2.72487 L
.9127 2.98942 L
.57496 2.98942 L
.37654 2.72487 L
F
.57496 2.98942 m
.9127 2.98942 L
.9127 3.25397 L
.81746 3.25397 L
.57496 2.98942 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.81746 .07937 m
.57496 .34392 L
.37654 .60847 L
.22222 .87302 L
.11199 1.13757 L
.04586 1.40212 L
.02381 1.66667 L
.04586 1.93122 L
.11199 2.19577 L
.22222 2.46032 L
.37654 2.72487 L
.57496 2.98942 L
.81746 3.25397 L
.9127 3.25397 L
.9127 2.98942 L
.9127 2.72487 L
.9127 2.46032 L
.9127 2.19577 L
.9127 1.93122 L
.9127 1.66667 L
.9127 1.40212 L
.9127 1.13757 L
.9127 .87302 L
.9127 .60847 L
.9127 .34392 L
.9127 .07937 L
.81746 .07937 L
s
.5 g
.81746 1.66667 m
.9127 1.66667 L
.9127 1.66667 L
.57496 1.66667 L
.81746 1.66667 L
F
.57496 1.66667 m
.9127 1.66667 L
.9127 1.66667 L
.37654 1.66667 L
.57496 1.66667 L
F
.37654 1.66667 m
.9127 1.66667 L
.9127 1.66667 L
.22222 1.66667 L
.37654 1.66667 L
F
.22222 1.66667 m
.9127 1.66667 L
.9127 1.66667 L
.11199 1.66667 L
.22222 1.66667 L
F
.11199 1.66667 m
.9127 1.66667 L
.9127 1.66667 L
.04586 1.66667 L
.11199 1.66667 L
F
.04586 1.66667 m
.9127 1.66667 L
.9127 1.66667 L
.02381 1.66667 L
.04586 1.66667 L
F
.02381 1.66667 m
.9127 1.66667 L
.9127 1.66667 L
.04586 1.66667 L
.02381 1.66667 L
F
.04586 1.66667 m
.9127 1.66667 L
.9127 1.66667 L
.11199 1.66667 L
.04586 1.66667 L
F
.11199 1.66667 m
.9127 1.66667 L
.9127 1.66667 L
.22222 1.66667 L
.11199 1.66667 L
F
.22222 1.66667 m
.9127 1.66667 L
.9127 1.66667 L
.37654 1.66667 L
.22222 1.66667 L
F
.37654 1.66667 m
.9127 1.66667 L
.9127 1.66667 L
.57496 1.66667 L
.37654 1.66667 L
F
.57496 1.66667 m
.9127 1.66667 L
.9127 1.66667 L
.81746 1.66667 L
.57496 1.66667 L
F
0 g
.81746 1.66667 m
.57496 1.66667 L
.37654 1.66667 L
.22222 1.66667 L
.11199 1.66667 L
.04586 1.66667 L
.02381 1.66667 L
.04586 1.66667 L
.11199 1.66667 L
.22222 1.66667 L
.37654 1.66667 L
.57496 1.66667 L
.81746 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.81746 1.66667 L
s
.5 g
.9127 .07937 m
.97619 .07937 L
.97619 .34392 L
.9127 .34392 L
.9127 .07937 L
F
.9127 .34392 m
.97619 .34392 L
.97619 .60847 L
.9127 .60847 L
.9127 .34392 L
F
.9127 .60847 m
.97619 .60847 L
.97619 .87302 L
.9127 .87302 L
.9127 .60847 L
F
.9127 .87302 m
.97619 .87302 L
.97619 1.13757 L
.9127 1.13757 L
.9127 .87302 L
F
.9127 1.13757 m
.97619 1.13757 L
.97619 1.40212 L
.9127 1.40212 L
.9127 1.13757 L
F
.9127 1.40212 m
.97619 1.40212 L
.97619 1.66667 L
.9127 1.66667 L
.9127 1.40212 L
F
.9127 1.66667 m
.97619 1.66667 L
.97619 1.93122 L
.9127 1.93122 L
.9127 1.66667 L
F
.9127 1.93122 m
.97619 1.93122 L
.97619 2.19577 L
.9127 2.19577 L
.9127 1.93122 L
F
.9127 2.19577 m
.97619 2.19577 L
.97619 2.46032 L
.9127 2.46032 L
.9127 2.19577 L
F
.9127 2.46032 m
.97619 2.46032 L
.97619 2.72487 L
.9127 2.72487 L
.9127 2.46032 L
F
.9127 2.72487 m
.97619 2.72487 L
.97619 2.98942 L
.9127 2.98942 L
.9127 2.72487 L
F
.9127 2.98942 m
.97619 2.98942 L
.97619 3.25397 L
.9127 3.25397 L
.9127 2.98942 L
F
0 g
.9127 .07937 m
.9127 .34392 L
.9127 .60847 L
.9127 .87302 L
.9127 1.13757 L
.9127 1.40212 L
.9127 1.66667 L
.9127 1.93122 L
.9127 2.19577 L
.9127 2.46032 L
.9127 2.72487 L
.9127 2.98942 L
.9127 3.25397 L
.97619 3.25397 L
.97619 2.98942 L
.97619 2.72487 L
.97619 2.46032 L
.97619 2.19577 L
.97619 1.93122 L
.97619 1.66667 L
.97619 1.40212 L
.97619 1.13757 L
.97619 .87302 L
.97619 .60847 L
.97619 .34392 L
.97619 .07937 L
.9127 .07937 L
s
.5 g
.9127 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
F
.9127 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
F
.9127 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
F
.9127 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
F
.9127 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
F
.9127 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
F
.9127 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
F
.9127 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
F
.9127 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
F
.9127 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
F
.9127 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
F
.9127 1.66667 m
.97619 1.66667 L
.97619 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
F
0 g
.9127 1.66667 m
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.9127 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.97619 1.66667 L
.9127 1.66667 L
s
.81746 3.25397 m
.81746 3.24039 L
.81746 3.19988 L
.81746 3.13314 L
.81746 3.04131 L
.81746 2.92596 L
.81746 2.78906 L
.81746 2.63295 L
.81746 2.46032 L
.81746 2.2741 L
.81746 2.07749 L
.81746 1.87385 L
.81746 1.66667 L
.81746 1.45948 L
.81746 1.25584 L
.81746 1.05923 L
.81746 .87302 L
.81746 .70038 L
.81746 .54427 L
.81746 .40738 L
.81746 .29202 L
.81746 .20019 L
.81746 .13345 L
.81746 .09294 L
.81746 .07937 L
.81746 .09294 L
.81746 .13345 L
.81746 .20019 L
.81746 .29202 L
.81746 .40738 L
.81746 .54427 L
.81746 .70038 L
.81746 .87302 L
.81746 1.05923 L
.81746 1.25584 L
.81746 1.45948 L
.81746 1.66667 L
.81746 1.87385 L
.81746 2.07749 L
.81746 2.2741 L
.81746 2.46032 L
.81746 2.63295 L
.81746 2.78906 L
.81746 2.92596 L
.81746 3.04131 L
.81746 3.13314 L
.81746 3.19988 L
.81746 3.24039 L
.81746 3.25397 L
s
.9127 3.25397 m
.9127 3.24039 L
.9127 3.19988 L
.9127 3.13314 L
.9127 3.04131 L
.9127 2.92596 L
.9127 2.78906 L
.9127 2.63295 L
.9127 2.46032 L
.9127 2.2741 L
.9127 2.07749 L
.9127 1.87385 L
.9127 1.66667 L
.9127 1.45948 L
.9127 1.25584 L
.9127 1.05923 L
.9127 .87302 L
.9127 .70038 L
.9127 .54427 L
.9127 .40738 L
.9127 .29202 L
.9127 .20019 L
.9127 .13345 L
.9127 .09294 L
.9127 .07937 L
.9127 .09294 L
.9127 .13345 L
.9127 .20019 L
.9127 .29202 L
.9127 .40738 L
.9127 .54427 L
.9127 .70038 L
.9127 .87302 L
.9127 1.05923 L
.9127 1.25584 L
.9127 1.45948 L
.9127 1.66667 L
.9127 1.87385 L
.9127 2.07749 L
.9127 2.2741 L
.9127 2.46032 L
.9127 2.63295 L
.9127 2.78906 L
.9127 2.92596 L
.9127 3.04131 L
.9127 3.13314 L
.9127 3.19988 L
.9127 3.24039 L
.9127 3.25397 L
s
.97619 3.25397 m
.97619 3.24039 L
.97619 3.19988 L
.97619 3.13314 L
.97619 3.04131 L
.97619 2.92596 L
.97619 2.78906 L
.97619 2.63295 L
.97619 2.46032 L
.97619 2.2741 L
.97619 2.07749 L
.97619 1.87385 L
.97619 1.66667 L
.97619 1.45948 L
.97619 1.25584 L
.97619 1.05923 L
.97619 .87302 L
.97619 .70038 L
.97619 .54427 L
.97619 .40738 L
.97619 .29202 L
.97619 .20019 L
.97619 .13345 L
.97619 .09294 L
.97619 .07937 L
.97619 .09294 L
.97619 .13345 L
.97619 .20019 L
.97619 .29202 L
.97619 .40738 L
.97619 .54427 L
.97619 .70038 L
.97619 .87302 L
.97619 1.05923 L
.97619 1.25584 L
.97619 1.45948 L
.97619 1.66667 L
.97619 1.87385 L
.97619 2.07749 L
.97619 2.2741 L
.97619 2.46032 L
.97619 2.63295 L
.97619 2.78906 L
.97619 2.92596 L
.97619 3.04131 L
.97619 3.13314 L
.97619 3.19988 L
.97619 3.24039 L
.97619 3.25397 L
s
.81746 3.25397 m
.9127 3.25397 L
.9127 3.24039 L
.81746 3.24039 L
.81746 3.25397 L
s
.81746 3.24039 m
.9127 3.24039 L
.9127 3.19988 L
.81746 3.19988 L
.81746 3.24039 L
s
.81746 3.19988 m
.9127 3.19988 L
.9127 3.13314 L
.81746 3.13314 L
.81746 3.19988 L
s
.81746 3.13314 m
.9127 3.13314 L
.9127 3.04131 L
.81746 3.04131 L
.81746 3.13314 L
s
.81746 3.04131 m
.9127 3.04131 L
.9127 2.92596 L
.81746 2.92596 L
.81746 3.04131 L
s
.81746 2.92596 m
.9127 2.92596 L
.9127 2.78906 L
.81746 2.78906 L
.81746 2.92596 L
s
.81746 2.78906 m
.9127 2.78906 L
.9127 2.63295 L
.81746 2.63295 L
.81746 2.78906 L
s
.81746 2.63295 m
.9127 2.63295 L
.9127 2.46032 L
.81746 2.46032 L
.81746 2.63295 L
s
.81746 2.46032 m
.9127 2.46032 L
.9127 2.2741 L
.81746 2.2741 L
.81746 2.46032 L
s
.81746 2.2741 m
.9127 2.2741 L
.9127 2.07749 L
.81746 2.07749 L
.81746 2.2741 L
s
.81746 2.07749 m
.9127 2.07749 L
.9127 1.87385 L
.81746 1.87385 L
.81746 2.07749 L
s
.81746 1.87385 m
.9127 1.87385 L
.9127 1.66667 L
.81746 1.66667 L
.81746 1.87385 L
s
.81746 1.66667 m
.9127 1.66667 L
.9127 1.45948 L
.81746 1.45948 L
.81746 1.66667 L
s
.81746 1.45948 m
.9127 1.45948 L
.9127 1.25584 L
.81746 1.25584 L
.81746 1.45948 L
s
.81746 1.25584 m
.9127 1.25584 L
.9127 1.05923 L
.81746 1.05923 L
.81746 1.25584 L
s
.81746 1.05923 m
.9127 1.05923 L
.9127 .87302 L
.81746 .87302 L
.81746 1.05923 L
s
.81746 .87302 m
.9127 .87302 L
.9127 .70038 L
.81746 .70038 L
.81746 .87302 L
s
.81746 .70038 m
.9127 .70038 L
.9127 .54427 L
.81746 .54427 L
.81746 .70038 L
s
.81746 .54427 m
.9127 .54427 L
.9127 .40738 L
.81746 .40738 L
.81746 .54427 L
s
.81746 .40738 m
.9127 .40738 L
.9127 .29202 L
.81746 .29202 L
.81746 .40738 L
s
.81746 .29202 m
.9127 .29202 L
.9127 .20019 L
.81746 .20019 L
.81746 .29202 L
s
.81746 .20019 m
.9127 .20019 L
.9127 .13345 L
.81746 .13345 L
.81746 .20019 L
s
.81746 .13345 m
.9127 .13345 L
.9127 .09294 L
.81746 .09294 L
.81746 .13345 L
s
.81746 .09294 m
.9127 .09294 L
.9127 .07937 L
.81746 .07937 L
.81746 .09294 L
s
.81746 .07937 m
.9127 .07937 L
.9127 .09294 L
.81746 .09294 L
.81746 .07937 L
s
.81746 .09294 m
.9127 .09294 L
.9127 .13345 L
.81746 .13345 L
.81746 .09294 L
s
.81746 .13345 m
.9127 .13345 L
.9127 .20019 L
.81746 .20019 L
.81746 .13345 L
s
.81746 .20019 m
.9127 .20019 L
.9127 .29202 L
.81746 .29202 L
.81746 .20019 L
s
.81746 .29202 m
.9127 .29202 L
.9127 .40738 L
.81746 .40738 L
.81746 .29202 L
s
.81746 .40738 m
.9127 .40738 L
.9127 .54427 L
.81746 .54427 L
.81746 .40738 L
s
.81746 .54427 m
.9127 .54427 L
.9127 .70038 L
.81746 .70038 L
.81746 .54427 L
s
.81746 .70038 m
.9127 .70038 L
.9127 .87302 L
.81746 .87302 L
.81746 .70038 L
s
.81746 .87302 m
.9127 .87302 L
.9127 1.05923 L
.81746 1.05923 L
.81746 .87302 L
s
.81746 1.05923 m
.9127 1.05923 L
.9127 1.25584 L
.81746 1.25584 L
.81746 1.05923 L
s
.81746 1.25584 m
.9127 1.25584 L
.9127 1.45948 L
.81746 1.45948 L
.81746 1.25584 L
s
.81746 1.45948 m
.9127 1.45948 L
.9127 1.66667 L
.81746 1.66667 L
.81746 1.45948 L
s
.81746 1.66667 m
.9127 1.66667 L
.9127 1.87385 L
.81746 1.87385 L
.81746 1.66667 L
s
.81746 1.87385 m
.9127 1.87385 L
.9127 2.07749 L
.81746 2.07749 L
.81746 1.87385 L
s
.81746 2.07749 m
.9127 2.07749 L
.9127 2.2741 L
.81746 2.2741 L
.81746 2.07749 L
s
.81746 2.2741 m
.9127 2.2741 L
.9127 2.46032 L
.81746 2.46032 L
.81746 2.2741 L
s
.81746 2.46032 m
.9127 2.46032 L
.9127 2.63295 L
.81746 2.63295 L
.81746 2.46032 L
s
.81746 2.63295 m
.9127 2.63295 L
.9127 2.78906 L
.81746 2.78906 L
.81746 2.63295 L
s
.81746 2.78906 m
.9127 2.78906 L
.9127 2.92596 L
.81746 2.92596 L
.81746 2.78906 L
s
.81746 2.92596 m
.9127 2.92596 L
.9127 3.04131 L
.81746 3.04131 L
.81746 2.92596 L
s
.81746 3.04131 m
.9127 3.04131 L
.9127 3.13314 L
.81746 3.13314 L
.81746 3.04131 L
s
.81746 3.13314 m
.9127 3.13314 L
.9127 3.19988 L
.81746 3.19988 L
.81746 3.13314 L
s
.81746 3.19988 m
.9127 3.19988 L
.9127 3.24039 L
.81746 3.24039 L
.81746 3.19988 L
s
.81746 3.24039 m
.9127 3.24039 L
.9127 3.25397 L
.81746 3.25397 L
.81746 3.24039 L
s
.9127 3.25397 m
.97619 3.25397 L
.97619 3.24039 L
.9127 3.24039 L
.9127 3.25397 L
s
.9127 3.24039 m
.97619 3.24039 L
.97619 3.19988 L
.9127 3.19988 L
.9127 3.24039 L
s
.9127 3.19988 m
.97619 3.19988 L
.97619 3.13314 L
.9127 3.13314 L
.9127 3.19988 L
s
.9127 3.13314 m
.97619 3.13314 L
.97619 3.04131 L
.9127 3.04131 L
.9127 3.13314 L
s
.9127 3.04131 m
.97619 3.04131 L
.97619 2.92596 L
.9127 2.92596 L
.9127 3.04131 L
s
.9127 2.92596 m
.97619 2.92596 L
.97619 2.78906 L
.9127 2.78906 L
.9127 2.92596 L
s
.9127 2.78906 m
.97619 2.78906 L
.97619 2.63295 L
.9127 2.63295 L
.9127 2.78906 L
s
.9127 2.63295 m
.97619 2.63295 L
.97619 2.46032 L
.9127 2.46032 L
.9127 2.63295 L
s
.9127 2.46032 m
.97619 2.46032 L
.97619 2.2741 L
.9127 2.2741 L
.9127 2.46032 L
s
.9127 2.2741 m
.97619 2.2741 L
.97619 2.07749 L
.9127 2.07749 L
.9127 2.2741 L
s
.9127 2.07749 m
.97619 2.07749 L
.97619 1.87385 L
.9127 1.87385 L
.9127 2.07749 L
s
.9127 1.87385 m
.97619 1.87385 L
.97619 1.66667 L
.9127 1.66667 L
.9127 1.87385 L
s
.9127 1.66667 m
.97619 1.66667 L
.97619 1.45948 L
.9127 1.45948 L
.9127 1.66667 L
s
.9127 1.45948 m
.97619 1.45948 L
.97619 1.25584 L
.9127 1.25584 L
.9127 1.45948 L
s
.9127 1.25584 m
.97619 1.25584 L
.97619 1.05923 L
.9127 1.05923 L
.9127 1.25584 L
s
.9127 1.05923 m
.97619 1.05923 L
.97619 .87302 L
.9127 .87302 L
.9127 1.05923 L
s
.9127 .87302 m
.97619 .87302 L
.97619 .70038 L
.9127 .70038 L
.9127 .87302 L
s
.9127 .70038 m
.97619 .70038 L
.97619 .54427 L
.9127 .54427 L
.9127 .70038 L
s
.9127 .54427 m
.97619 .54427 L
.97619 .40738 L
.9127 .40738 L
.9127 .54427 L
s
.9127 .40738 m
.97619 .40738 L
.97619 .29202 L
.9127 .29202 L
.9127 .40738 L
s
.9127 .29202 m
.97619 .29202 L
.97619 .20019 L
.9127 .20019 L
.9127 .29202 L
s
.9127 .20019 m
.97619 .20019 L
.97619 .13345 L
.9127 .13345 L
.9127 .20019 L
s
.9127 .13345 m
.97619 .13345 L
.97619 .09294 L
.9127 .09294 L
.9127 .13345 L
s
.9127 .09294 m
.97619 .09294 L
.97619 .07937 L
.9127 .07937 L
.9127 .09294 L
s
.9127 .07937 m
.97619 .07937 L
.97619 .09294 L
.9127 .09294 L
.9127 .07937 L
s
.9127 .09294 m
.97619 .09294 L
.97619 .13345 L
.9127 .13345 L
.9127 .09294 L
s
.9127 .13345 m
.97619 .13345 L
.97619 .20019 L
.9127 .20019 L
.9127 .13345 L
s
.9127 .20019 m
.97619 .20019 L
.97619 .29202 L
.9127 .29202 L
.9127 .20019 L
s
.9127 .29202 m
.97619 .29202 L
.97619 .40738 L
.9127 .40738 L
.9127 .29202 L
s
.9127 .40738 m
.97619 .40738 L
.97619 .54427 L
.9127 .54427 L
.9127 .40738 L
s
.9127 .54427 m
.97619 .54427 L
.97619 .70038 L
.9127 .70038 L
.9127 .54427 L
s
.9127 .70038 m
.97619 .70038 L
.97619 .87302 L
.9127 .87302 L
.9127 .70038 L
s
.9127 .87302 m
.97619 .87302 L
.97619 1.05923 L
.9127 1.05923 L
.9127 .87302 L
s
.9127 1.05923 m
.97619 1.05923 L
.97619 1.25584 L
.9127 1.25584 L
.9127 1.05923 L
s
.9127 1.25584 m
.97619 1.25584 L
.97619 1.45948 L
.9127 1.45948 L
.9127 1.25584 L
s
.9127 1.45948 m
.97619 1.45948 L
.97619 1.66667 L
.9127 1.66667 L
.9127 1.45948 L
s
.9127 1.66667 m
.97619 1.66667 L
.97619 1.87385 L
.9127 1.87385 L
.9127 1.66667 L
s
.9127 1.87385 m
.97619 1.87385 L
.97619 2.07749 L
.9127 2.07749 L
.9127 1.87385 L
s
.9127 2.07749 m
.97619 2.07749 L
.97619 2.2741 L
.9127 2.2741 L
.9127 2.07749 L
s
.9127 2.2741 m
.97619 2.2741 L
.97619 2.46032 L
.9127 2.46032 L
.9127 2.2741 L
s
.9127 2.46032 m
.97619 2.46032 L
.97619 2.63295 L
.9127 2.63295 L
.9127 2.46032 L
s
.9127 2.63295 m
.97619 2.63295 L
.97619 2.78906 L
.9127 2.78906 L
.9127 2.63295 L
s
.9127 2.78906 m
.97619 2.78906 L
.97619 2.92596 L
.9127 2.92596 L
.9127 2.78906 L
s
.9127 2.92596 m
.97619 2.92596 L
.97619 3.04131 L
.9127 3.04131 L
.9127 2.92596 L
s
.9127 3.04131 m
.97619 3.04131 L
.97619 3.13314 L
.9127 3.13314 L
.9127 3.04131 L
s
.9127 3.13314 m
.97619 3.13314 L
.97619 3.19988 L
.9127 3.19988 L
.9127 3.13314 L
s
.9127 3.19988 m
.97619 3.19988 L
.97619 3.24039 L
.9127 3.24039 L
.9127 3.19988 L
s
.9127 3.24039 m
.97619 3.24039 L
.97619 3.25397 L
.9127 3.25397 L
.9127 3.24039 L
s
0 0 m
1 0 L
1 3.33333 L
0 3.33333 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{78.8125, 262.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001>00011R000`400?l00000o`00003oCP3oool0
04h0oooo001>0?ooo`00CP3oool004h0oooo001>0?ooo`00CP3oool003l0oooo3@0000020?ooo`00
?`3oool=00000080oooo000n0?ooo`8000001`1oOgl01@000000Ogmo07moO`1oOgl000000080oooo
000m0?ooo`030000001oOgl0000000L0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00?03o
ool00`000000Ogmo07moO`0=00000080oooo000k0?ooo`050000001oOgl0Ogmo07moO`0000001`1o
Ogl01@000000Ogmo07moO`1oOgl000000080oooo000j0?ooo`030000001oOgl0Ogmo0080Ogmo00<0
000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000i0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo
000h0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07mo
O`1oOgl000000080oooo000g0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl01@1o
Ogl01@000000Ogmo07moO`1oOgl000000080oooo000f0?ooo`030000001oOgl0Ogmo00H0Ogmo3@00
00020?ooo`00=@3oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00D0Ogmo00D00000
07moO`1oOgl0Ogmo000000020?ooo`00=@3oool00`000000Ogmo07moO`0707moO`030000001oOgl0
Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00=03oool00`000000Ogmo07moO`08
07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00<`3oool0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo0000
00020?ooo`00<P3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00D0Ogmo00D00000
07moO`1oOgl0Ogmo000000020?ooo`00<@3oool00`000000Ogmo07moO`0;07moO`030000001oOgl0
Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00<03oool00`000000Ogmo07moO`0<
07moO`d000000P3oool002l0oooo00<0000007moO`1oOgl03@1oOgl00`000000Ogmo07moO`0507mo
O`050000001oOgl0Ogmo07moO`0000000P3oool002h0oooo00<0000007moO`1oOgl03P1oOgl00`00
0000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool002d0oooo00<0000007mo
O`1oOgl03`1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool0
02`0oooo00<0000007moO`1oOgl0401oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo
07moO`0000000P3oool002`0oooo00<0000007moO`1oOgl0401oOgl00`000000Ogmo07moO`0507mo
O`050000001oOgl0Ogmo07moO`0000000P3oool002/0oooo00<0000007moO`1oOgl04@1oOgl00`00
0000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool002X0oooo00<0000007mo
O`1oOgl04P1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool0
02T0oooo00<0000007moO`1oOgl04`1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo
07moO`0000000P3oool002T0oooo00<0000007moO`1oOgl04`1oOgl=00000080oooo000X0?ooo`03
0000001oOgl0Ogmo01@0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl00000
0080oooo000W0?ooo`030000001oOgl0Ogmo01D0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000
Ogmo07moO`1oOgl000000080oooo000V0?ooo`030000001oOgl0Ogmo01H0Ogmo00<0000007moO`1o
Ogl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000V0?ooo`030000001oOgl0Ogmo01H0
Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000U0?ooo`03
0000001oOgl0Ogmo01L0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl00000
0080oooo000T0?ooo`030000001oOgl0Ogmo01P0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000
Ogmo07moO`1oOgl000000080oooo000S0?ooo`030000001oOgl0Ogmo01T0Ogmo00<0000007moO`1o
Ogl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000S0?ooo`030000001oOgl0Ogmo01T0
Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000R0?ooo`03
0000001oOgl0Ogmo01X0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl00000
0080oooo000Q0?ooo`030000001oOgl0Ogmo01/0Ogmo3@0000020?ooo`00803oool00`000000Ogmo
07moO`0L07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00
803oool00`000000Ogmo07moO`0L07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0
Ogmo000000020?ooo`007`3oool00`000000Ogmo07moO`0M07moO`030000001oOgl0Ogmo00D0Ogmo
00D0000007moO`1oOgl0Ogmo000000020?ooo`007P3oool00`000000Ogmo07moO`0N07moO`030000
001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`007@3oool00`000000Ogmo
07moO`0O07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00
7@3oool00`000000Ogmo07moO`0O07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0
Ogmo000000020?ooo`00703oool00`000000Ogmo07moO`0P07moO`030000001oOgl0Ogmo00D0Ogmo
00D0000007moO`1oOgl0Ogmo000000020?ooo`00703oool00`000000Ogmo07moO`0P07moO`030000
001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`006`3oool00`000000Ogmo
07moO`0Q07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00
6P3oool00`000000Ogmo07moO`0R07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0
Ogmo000000020?ooo`006P3oool00`000000Ogmo07moO`0R07moO`030000001oOgl0Ogmo00D0Ogmo
00D0000007moO`1oOgl0Ogmo000000020?ooo`006@3oool00`000000Ogmo07moO`0S07moO`d00000
0P3oool001T0oooo00<0000007moO`1oOgl08`1oOgl00`000000Ogmo07moO`0507moO`050000001o
Ogl0Ogmo07moO`0000000P3oool001P0oooo00<0000007moO`1oOgl0901oOgl00`000000Ogmo07mo
O`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool001P0oooo00<0000007moO`1oOgl0901o
Ogl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool001L0oooo00<0
000007moO`1oOgl09@1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`000000
0P3oool001H0oooo00<0000007moO`1oOgl09P1oOgl00`000000Ogmo07moO`0507moO`050000001o
Ogl0Ogmo07moO`0000000P3oool001H0oooo00<0000007moO`1oOgl09P1oOgl00`000000Ogmo07mo
O`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool001D0oooo00<0000007moO`1oOgl09`1o
Ogl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool001D0oooo00<0
000007moO`1oOgl09`1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`000000
0P3oool001@0oooo00<0000007moO`1oOgl0:01oOgl00`000000Ogmo07moO`0507moO`050000001o
Ogl0Ogmo07moO`0000000P3oool001@0oooo00<0000007moO`1oOgl0:01oOgl00`000000Ogmo07mo
O`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool001<0oooo00<0000007moO`1oOgl0:@1o
Ogl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool00180oooo00<0
000007moO`1oOgl0:P1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`000000
0P3oool00180oooo00<0000007moO`1oOgl0:P1oOgl00`000000Ogmo07moO`0507moO`050000001o
Ogl0Ogmo07moO`0000000P3oool00140oooo00<0000007moO`1oOgl0:`1oOgl=00000080oooo000A
0?ooo`030000001oOgl0Ogmo02/0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1o
Ogl000000080oooo000@0?ooo`030000001oOgl0Ogmo02`0Ogmo00<0000007moO`1oOgl01@1oOgl0
1@000000Ogmo07moO`1oOgl000000080oooo000@0?ooo`030000001oOgl0Ogmo02`0Ogmo00<00000
07moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000?0?ooo`030000001oOgl0
Ogmo02d0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000?
0?ooo`030000001oOgl0Ogmo02d0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1o
Ogl000000080oooo000?0?ooo`030000001oOgl0Ogmo02d0Ogmo00<0000007moO`1oOgl01@1oOgl0
1@000000Ogmo07moO`1oOgl000000080oooo000>0?ooo`030000001oOgl0Ogmo02h0Ogmo00<00000
07moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000>0?ooo`030000001oOgl0
Ogmo02h0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000=
0?ooo`030000001oOgl0Ogmo02l0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1o
Ogl000000080oooo000=0?ooo`030000001oOgl0Ogmo02l0Ogmo00<0000007moO`1oOgl01@1oOgl0
1@000000Ogmo07moO`1oOgl000000080oooo000<0?ooo`030000001oOgl0Ogmo0300Ogmo00<00000
07moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000<0?ooo`030000001oOgl0
Ogmo0300Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000;
0?ooo`030000001oOgl0Ogmo0340Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1o
Ogl000000080oooo000;0?ooo`030000001oOgl0Ogmo0340Ogmo3@0000020?ooo`002P3oool00`00
0000Ogmo07moO`0b07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo00000002
0?ooo`002P3oool00`000000Ogmo07moO`0b07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007mo
O`1oOgl0Ogmo000000020?ooo`002P3oool00`000000Ogmo07moO`0b07moO`030000001oOgl0Ogmo
00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`002@3oool00`000000Ogmo07moO`0c07mo
O`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`002@3oool00`00
0000Ogmo07moO`0c07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo00000002
0?ooo`00203oool00`000000Ogmo07moO`0d07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007mo
O`1oOgl0Ogmo000000020?ooo`00203oool00`000000Ogmo07moO`0d07moO`030000001oOgl0Ogmo
00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00203oool00`000000Ogmo07moO`0d07mo
O`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`001`3oool00`00
0000Ogmo07moO`0e07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo00000002
0?ooo`001`3oool00`000000Ogmo07moO`0e07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007mo
O`1oOgl0Ogmo000000020?ooo`001`3oool00`000000Ogmo07moO`0e07moO`030000001oOgl0Ogmo
00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`001`3oool00`000000Ogmo07moO`0e07mo
O`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`001P3oool00`00
0000Ogmo07moO`0f07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo00000002
0?ooo`001P3oool00`000000Ogmo07moO`0f07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007mo
O`1oOgl0Ogmo000000020?ooo`001P3oool00`000000Ogmo07moO`0f07moO`030000001oOgl0Ogmo
00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`001P3oool00`000000Ogmo07moO`0f07mo
O`d000000P3oool000D0oooo00<0000007moO`1oOgl0=`1oOgl00`000000Ogmo07moO`0507moO`05
0000001oOgl0Ogmo07moO`0000000P3oool000D0oooo00<0000007moO`1oOgl0=`1oOgl00`000000
Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool000D0oooo00<0000007moO`1o
Ogl0=`1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool000D0
oooo00<0000007moO`1oOgl0=`1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07mo
O`0000000P3oool000D0oooo00<0000007moO`1oOgl0=`1oOgl00`000000Ogmo07moO`0507moO`05
0000001oOgl0Ogmo07moO`0000000P3oool000@0oooo00<0000007moO`1oOgl0>01oOgl00`000000
Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool000@0oooo00<0000007moO`1o
Ogl0>01oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool000@0
oooo00<0000007moO`1oOgl0>01oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07mo
O`0000000P3oool000@0oooo00<0000007moO`1oOgl0>01oOgl00`000000Ogmo07moO`0507moO`05
0000001oOgl0Ogmo07moO`0000000P3oool000<0oooo00<0000007moO`1oOgl0>@1oOgl00`000000
Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool000<0oooo00<0000007moO`1o
Ogl0>@1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool000<0
oooo00<0000007moO`1oOgl0>@1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07mo
O`0000000P3oool000<0oooo00<0000007moO`1oOgl0>@1oOgl00`000000Ogmo07moO`0507moO`05
0000001oOgl0Ogmo07moO`0000000P3oool000<0oooo00<0000007moO`1oOgl0>@1oOgl00`000000
Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool000<0oooo00<0000007moO`1o
Ogl0>@1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool000<0
oooo00<0000007moO`1oOgl0>@1oOgl=00000080oooo00020?ooo`030000001oOgl0Ogmo03X0Ogmo
00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo00020?ooo`030000
001oOgl0Ogmo03X0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080
oooo00020?ooo`030000001oOgl0Ogmo03X0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo
07moO`1oOgl000000080oooo00020?ooo`030000001oOgl0Ogmo03X0Ogmo00<0000007moO`1oOgl0
1@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo00020?ooo`030000001oOgl0Ogmo03X0Ogmo
00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo00020?ooo`030000
001oOgl0Ogmo03X0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080
oooo00020?ooo`030000001oOgl0Ogmo03X0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo
07moO`1oOgl000000080oooo00020?ooo`030000001oOgl0Ogmo03X0Ogmo00<0000007moO`1oOgl0
1@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo00020?ooo`030000001oOgl0Ogmo03X0Ogmo
00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo00020?ooo`030000
001oOgl0Ogmo03X0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080
oooo00020?ooo`030000001oOgl0Ogmo03X0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo
07moO`1oOgl000000080oooo00000`3oool0000007moO`0l07moO`030000001oOgl0Ogmo00D0Ogmo
00D0000007moO`1oOgl0Ogmo000000020?ooo`0000<0oooo0000001oOgl0?01oOgl00`000000Ogmo
07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool000030?ooo`000000Ogmo03`0Ogmo
00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo00000`3oool00000
07moO`0l07moO`030000001oOgl0Ogmo00D0Ogmo00@0000007moO`1oOgl0Ogmo0P0000010?ooo`00
00<0oooo000000000000B@0000020?ooo`0000<0oooo0000001oOgl0?01oOgl00`000000Ogmo07mo
O`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool000030?ooo`000000Ogmo03`0Ogmo00<0
000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo00000`3oool0000007mo
O`0l07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`0000<0
oooo0000001oOgl0?01oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`000000
0P3oool000030?ooo`000000Ogmo03`0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07mo
O`1oOgl000000080oooo00020?ooo`030000001oOgl0Ogmo03X0Ogmo00<0000007moO`1oOgl01@1o
Ogl01@000000Ogmo07moO`1oOgl000000080oooo00020?ooo`030000001oOgl0Ogmo03X0Ogmo00<0
000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo00020?ooo`030000001o
Ogl0Ogmo03X0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo
00020?ooo`030000001oOgl0Ogmo03X0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07mo
O`1oOgl000000080oooo00020?ooo`030000001oOgl0Ogmo03X0Ogmo00<0000007moO`1oOgl01@1o
Ogl01@000000Ogmo07moO`1oOgl000000080oooo00020?ooo`030000001oOgl0Ogmo03X0Ogmo00<0
000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo00020?ooo`030000001o
Ogl0Ogmo03X0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo
00020?ooo`030000001oOgl0Ogmo03X0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07mo
O`1oOgl000000080oooo00020?ooo`030000001oOgl0Ogmo03X0Ogmo00<0000007moO`1oOgl01@1o
Ogl01@000000Ogmo07moO`1oOgl000000080oooo00020?ooo`030000001oOgl0Ogmo03X0Ogmo00<0
000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo00030?ooo`030000001o
Ogl0Ogmo03T0Ogmo3@0000020?ooo`000`3oool00`000000Ogmo07moO`0i07moO`030000001oOgl0
Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`000`3oool00`000000Ogmo07moO`0i
07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`000`3oool0
0`000000Ogmo07moO`0i07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo0000
00020?ooo`000`3oool00`000000Ogmo07moO`0i07moO`030000001oOgl0Ogmo00D0Ogmo00D00000
07moO`1oOgl0Ogmo000000020?ooo`000`3oool00`000000Ogmo07moO`0i07moO`030000001oOgl0
Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`000`3oool00`000000Ogmo07moO`0i
07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00103oool0
0`000000Ogmo07moO`0h07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo0000
00020?ooo`00103oool00`000000Ogmo07moO`0h07moO`030000001oOgl0Ogmo00D0Ogmo00D00000
07moO`1oOgl0Ogmo000000020?ooo`00103oool00`000000Ogmo07moO`0h07moO`030000001oOgl0
Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00103oool00`000000Ogmo07moO`0h
07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`001@3oool0
0`000000Ogmo07moO`0g07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo0000
00020?ooo`001@3oool00`000000Ogmo07moO`0g07moO`030000001oOgl0Ogmo00D0Ogmo00D00000
07moO`1oOgl0Ogmo000000020?ooo`001@3oool00`000000Ogmo07moO`0g07moO`030000001oOgl0
Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`001@3oool00`000000Ogmo07moO`0g
07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`001P3oool0
0`000000Ogmo07moO`0f07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo0000
00020?ooo`001P3oool00`000000Ogmo07moO`0f07moO`d000000P3oool000H0oooo00<0000007mo
O`1oOgl0=P1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool0
00H0oooo00<0000007moO`1oOgl0=P1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo
07moO`0000000P3oool000H0oooo00<0000007moO`1oOgl0=P1oOgl00`000000Ogmo07moO`0507mo
O`050000001oOgl0Ogmo07moO`0000000P3oool000L0oooo00<0000007moO`1oOgl0=@1oOgl00`00
0000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool000L0oooo00<0000007mo
O`1oOgl0=@1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool0
00L0oooo00<0000007moO`1oOgl0=@1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo
07moO`0000000P3oool000L0oooo00<0000007moO`1oOgl0=@1oOgl00`000000Ogmo07moO`0507mo
O`050000001oOgl0Ogmo07moO`0000000P3oool000P0oooo00<0000007moO`1oOgl0=01oOgl00`00
0000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool000P0oooo00<0000007mo
O`1oOgl0=01oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool0
00P0oooo00<0000007moO`1oOgl0=01oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo
07moO`0000000P3oool000T0oooo00<0000007moO`1oOgl0<`1oOgl00`000000Ogmo07moO`0507mo
O`050000001oOgl0Ogmo07moO`0000000P3oool000T0oooo00<0000007moO`1oOgl0<`1oOgl00`00
0000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool000X0oooo00<0000007mo
O`1oOgl0<P1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool0
00X0oooo00<0000007moO`1oOgl0<P1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo
07moO`0000000P3oool000X0oooo00<0000007moO`1oOgl0<P1oOgl=00000080oooo000;0?ooo`03
0000001oOgl0Ogmo0340Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl00000
0080oooo000;0?ooo`030000001oOgl0Ogmo0340Ogmo00<0000007moO`1oOgl01@1oOgl01@000000
Ogmo07moO`1oOgl000000080oooo000<0?ooo`030000001oOgl0Ogmo0300Ogmo00<0000007moO`1o
Ogl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000<0?ooo`030000001oOgl0Ogmo0300
Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000=0?ooo`03
0000001oOgl0Ogmo02l0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl00000
0080oooo000=0?ooo`030000001oOgl0Ogmo02l0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000
Ogmo07moO`1oOgl000000080oooo000>0?ooo`030000001oOgl0Ogmo02h0Ogmo00<0000007moO`1o
Ogl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000>0?ooo`030000001oOgl0Ogmo02h0
Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000?0?ooo`03
0000001oOgl0Ogmo02d0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl00000
0080oooo000?0?ooo`030000001oOgl0Ogmo02d0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000
Ogmo07moO`1oOgl000000080oooo000?0?ooo`030000001oOgl0Ogmo02d0Ogmo00<0000007moO`1o
Ogl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000@0?ooo`030000001oOgl0Ogmo02`0
Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000@0?ooo`03
0000001oOgl0Ogmo02`0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl00000
0080oooo000A0?ooo`030000001oOgl0Ogmo02/0Ogmo3@0000020?ooo`004@3oool00`000000Ogmo
07moO`0[07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00
4P3oool00`000000Ogmo07moO`0Z07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0
Ogmo000000020?ooo`004P3oool00`000000Ogmo07moO`0Z07moO`030000001oOgl0Ogmo00D0Ogmo
00D0000007moO`1oOgl0Ogmo000000020?ooo`004`3oool00`000000Ogmo07moO`0Y07moO`030000
001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00503oool00`000000Ogmo
07moO`0X07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00
503oool00`000000Ogmo07moO`0X07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0
Ogmo000000020?ooo`005@3oool00`000000Ogmo07moO`0W07moO`030000001oOgl0Ogmo00D0Ogmo
00D0000007moO`1oOgl0Ogmo000000020?ooo`005@3oool00`000000Ogmo07moO`0W07moO`030000
001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`005P3oool00`000000Ogmo
07moO`0V07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00
5P3oool00`000000Ogmo07moO`0V07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0
Ogmo000000020?ooo`005`3oool00`000000Ogmo07moO`0U07moO`030000001oOgl0Ogmo00D0Ogmo
00D0000007moO`1oOgl0Ogmo000000020?ooo`00603oool00`000000Ogmo07moO`0T07moO`030000
001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00603oool00`000000Ogmo
07moO`0T07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00
6@3oool00`000000Ogmo07moO`0S07moO`d000000P3oool001T0oooo00<0000007moO`1oOgl08`1o
Ogl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool001X0oooo00<0
000007moO`1oOgl08P1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`000000
0P3oool001X0oooo00<0000007moO`1oOgl08P1oOgl00`000000Ogmo07moO`0507moO`050000001o
Ogl0Ogmo07moO`0000000P3oool001/0oooo00<0000007moO`1oOgl08@1oOgl00`000000Ogmo07mo
O`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool001`0oooo00<0000007moO`1oOgl0801o
Ogl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool001`0oooo00<0
000007moO`1oOgl0801oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`000000
0P3oool001d0oooo00<0000007moO`1oOgl07`1oOgl00`000000Ogmo07moO`0507moO`050000001o
Ogl0Ogmo07moO`0000000P3oool001d0oooo00<0000007moO`1oOgl07`1oOgl00`000000Ogmo07mo
O`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool001h0oooo00<0000007moO`1oOgl07P1o
Ogl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool001l0oooo00<0
000007moO`1oOgl07@1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`000000
0P3oool00200oooo00<0000007moO`1oOgl0701oOgl00`000000Ogmo07moO`0507moO`050000001o
Ogl0Ogmo07moO`0000000P3oool00200oooo00<0000007moO`1oOgl0701oOgl=00000080oooo000Q
0?ooo`030000001oOgl0Ogmo01/0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1o
Ogl000000080oooo000R0?ooo`030000001oOgl0Ogmo01X0Ogmo00<0000007moO`1oOgl01@1oOgl0
1@000000Ogmo07moO`1oOgl000000080oooo000R0?ooo`030000001oOgl0Ogmo01X0Ogmo00<00000
07moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000S0?ooo`030000001oOgl0
Ogmo01T0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000T
0?ooo`030000001oOgl0Ogmo01P0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1o
Ogl000000080oooo000U0?ooo`030000001oOgl0Ogmo01L0Ogmo00<0000007moO`1oOgl01@1oOgl0
1@000000Ogmo07moO`1oOgl000000080oooo000U0?ooo`030000001oOgl0Ogmo01L0Ogmo00<00000
07moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000V0?ooo`030000001oOgl0
Ogmo01H0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000W
0?ooo`030000001oOgl0Ogmo01D0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1o
Ogl000000080oooo000W0?ooo`030000001oOgl0Ogmo01D0Ogmo00<0000007moO`1oOgl01@1oOgl0
1@000000Ogmo07moO`1oOgl000000080oooo000X0?ooo`030000001oOgl0Ogmo01@0Ogmo3@000002
0?ooo`00:@3oool00`000000Ogmo07moO`0C07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007mo
O`1oOgl0Ogmo000000020?ooo`00:P3oool00`000000Ogmo07moO`0B07moO`030000001oOgl0Ogmo
00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00:P3oool00`000000Ogmo07moO`0B07mo
O`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00:`3oool00`00
0000Ogmo07moO`0A07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo00000002
0?ooo`00;03oool00`000000Ogmo07moO`0@07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007mo
O`1oOgl0Ogmo000000020?ooo`00;03oool00`000000Ogmo07moO`0@07moO`030000001oOgl0Ogmo
00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00;@3oool00`000000Ogmo07moO`0?07mo
O`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo000000020?ooo`00;P3oool00`00
0000Ogmo07moO`0>07moO`030000001oOgl0Ogmo00D0Ogmo00D0000007moO`1oOgl0Ogmo00000002
0?ooo`00;`3oool00`000000Ogmo07moO`0=07moO`d000000P3oool00300oooo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool00340
oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07mo
O`0000000P3oool00380oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0507moO`05
0000001oOgl0Ogmo07moO`0000000P3oool003<0oooo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool003@0oooo00<0000007moO`1o
Ogl0201oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P3oool003D0
oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0507moO`050000001oOgl0Ogmo07mo
O`0000000P3oool003H0oooo00<0000007moO`1oOgl01P1oOgl=00000080oooo000g0?ooo`030000
001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080
oooo000h0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000Ogmo
07moO`1oOgl000000080oooo000i0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
1@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000j0?ooo`030000001oOgl0Ogmo0080Ogmo
00<0000007moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl000000080oooo000k0?ooo`040000
001oOgl0Ogmo07moO`d000000P3oool003`0oooo00@0000007moO`1oOgl000001`1oOgl01@000000
Ogmo07moO`1oOgl000000080oooo000m0?ooo`030000001oOgl0000000L0Ogmo00D0000007moO`1o
Ogl0Ogmo000000020?ooo`00?P3oool>00000080oooo000o0?ooo`d000000P3oool004h0oooo001>
0?ooo`00CP3oool004h0oooo001>0?ooo`00CP3oool004h0oooo0000\
\>"],
  ImageRangeCache->{{{0, 77.8125}, {261.688, 0}} -> {-0.750157, -52.9688, \
0.404824, 0.404824}},
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{Move[SingleRay[],10],
Move[LinearPolarizer[{Function[#1^2/100+#2^2/100],Function[#1^2/100+#2^2/100]}\
, 45, 100, 10, CenterThickness->2, ComponentMedium->{BK7,CrownGlass}],50], \
Boundary[100]},PlotType->TopView];
ReadRays[sys,{{ComponentNumber,SurfaceNumber},RefractiveIndex,RayTilt,\
Intensity,Polarization}]\
\>", "Input",
  CellTags->"LinearPolarizer with user-defined surface"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.04 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.539048 0.00952381 [
[.54762 .02476 -6 -4.5 ]
[.54762 .02476 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1.04 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.7381 .06286 m
.77619 .06286 L
.70344 .14222 L
.66534 .14222 L
.7381 .06286 L
F
.66534 .14222 m
.70344 .14222 L
.64392 .22159 L
.60582 .22159 L
.66534 .14222 L
F
.60582 .22159 m
.64392 .22159 L
.59762 .30095 L
.55952 .30095 L
.60582 .22159 L
F
.55952 .30095 m
.59762 .30095 L
.56455 .38032 L
.52646 .38032 L
.55952 .30095 L
F
.52646 .38032 m
.56455 .38032 L
.54471 .45968 L
.50661 .45968 L
.52646 .38032 L
F
.50661 .45968 m
.54471 .45968 L
.5381 .53905 L
.5 .53905 L
.50661 .45968 L
F
.5 .53905 m
.5381 .53905 L
.54471 .61841 L
.50661 .61841 L
.5 .53905 L
F
.50661 .61841 m
.54471 .61841 L
.56455 .69778 L
.52646 .69778 L
.50661 .61841 L
F
.52646 .69778 m
.56455 .69778 L
.59762 .77714 L
.55952 .77714 L
.52646 .69778 L
F
.55952 .77714 m
.59762 .77714 L
.64392 .85651 L
.60582 .85651 L
.55952 .77714 L
F
.60582 .85651 m
.64392 .85651 L
.70344 .93587 L
.66534 .93587 L
.60582 .85651 L
F
.66534 .93587 m
.70344 .93587 L
.77619 1.01524 L
.7381 1.01524 L
.66534 .93587 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .06286 m
.66534 .14222 L
.60582 .22159 L
.55952 .30095 L
.52646 .38032 L
.50661 .45968 L
.5 .53905 L
.50661 .61841 L
.52646 .69778 L
.55952 .77714 L
.60582 .85651 L
.66534 .93587 L
.7381 1.01524 L
.77619 1.01524 L
.70344 .93587 L
.64392 .85651 L
.59762 .77714 L
.56455 .69778 L
.54471 .61841 L
.5381 .53905 L
.54471 .45968 L
.56455 .38032 L
.59762 .30095 L
.64392 .22159 L
.70344 .14222 L
.77619 .06286 L
.7381 .06286 L
s
.5 g
.7381 .53905 m
.77619 .53905 L
.70344 .53905 L
.66534 .53905 L
.7381 .53905 L
F
.66534 .53905 m
.70344 .53905 L
.64392 .53905 L
.60582 .53905 L
.66534 .53905 L
F
.60582 .53905 m
.64392 .53905 L
.59762 .53905 L
.55952 .53905 L
.60582 .53905 L
F
.55952 .53905 m
.59762 .53905 L
.56455 .53905 L
.52646 .53905 L
.55952 .53905 L
F
.52646 .53905 m
.56455 .53905 L
.54471 .53905 L
.50661 .53905 L
.52646 .53905 L
F
.50661 .53905 m
.54471 .53905 L
.5381 .53905 L
.5 .53905 L
.50661 .53905 L
F
.5 .53905 m
.5381 .53905 L
.54471 .53905 L
.50661 .53905 L
.5 .53905 L
F
.50661 .53905 m
.54471 .53905 L
.56455 .53905 L
.52646 .53905 L
.50661 .53905 L
F
.52646 .53905 m
.56455 .53905 L
.59762 .53905 L
.55952 .53905 L
.52646 .53905 L
F
.55952 .53905 m
.59762 .53905 L
.64392 .53905 L
.60582 .53905 L
.55952 .53905 L
F
.60582 .53905 m
.64392 .53905 L
.70344 .53905 L
.66534 .53905 L
.60582 .53905 L
F
.66534 .53905 m
.70344 .53905 L
.77619 .53905 L
.7381 .53905 L
.66534 .53905 L
F
0 g
.7381 .53905 m
.66534 .53905 L
.60582 .53905 L
.55952 .53905 L
.52646 .53905 L
.50661 .53905 L
.5 .53905 L
.50661 .53905 L
.52646 .53905 L
.55952 .53905 L
.60582 .53905 L
.66534 .53905 L
.7381 .53905 L
.77619 .53905 L
.70344 .53905 L
.64392 .53905 L
.59762 .53905 L
.56455 .53905 L
.54471 .53905 L
.5381 .53905 L
.54471 .53905 L
.56455 .53905 L
.59762 .53905 L
.64392 .53905 L
.70344 .53905 L
.77619 .53905 L
.7381 .53905 L
s
.5 g
.77619 .06286 m
.78571 .06286 L
.71296 .14222 L
.70344 .14222 L
.77619 .06286 L
F
.70344 .14222 m
.71296 .14222 L
.65344 .22159 L
.64392 .22159 L
.70344 .14222 L
F
.64392 .22159 m
.65344 .22159 L
.60714 .30095 L
.59762 .30095 L
.64392 .22159 L
F
.59762 .30095 m
.60714 .30095 L
.57407 .38032 L
.56455 .38032 L
.59762 .30095 L
F
.56455 .38032 m
.57407 .38032 L
.55423 .45968 L
.54471 .45968 L
.56455 .38032 L
F
.54471 .45968 m
.55423 .45968 L
.54762 .53905 L
.5381 .53905 L
.54471 .45968 L
F
.5381 .53905 m
.54762 .53905 L
.55423 .61841 L
.54471 .61841 L
.5381 .53905 L
F
.54471 .61841 m
.55423 .61841 L
.57407 .69778 L
.56455 .69778 L
.54471 .61841 L
F
.56455 .69778 m
.57407 .69778 L
.60714 .77714 L
.59762 .77714 L
.56455 .69778 L
F
.59762 .77714 m
.60714 .77714 L
.65344 .85651 L
.64392 .85651 L
.59762 .77714 L
F
.64392 .85651 m
.65344 .85651 L
.71296 .93587 L
.70344 .93587 L
.64392 .85651 L
F
.70344 .93587 m
.71296 .93587 L
.78571 1.01524 L
.77619 1.01524 L
.70344 .93587 L
F
0 g
.77619 .06286 m
.70344 .14222 L
.64392 .22159 L
.59762 .30095 L
.56455 .38032 L
.54471 .45968 L
.5381 .53905 L
.54471 .61841 L
.56455 .69778 L
.59762 .77714 L
.64392 .85651 L
.70344 .93587 L
.77619 1.01524 L
.78571 1.01524 L
.71296 .93587 L
.65344 .85651 L
.60714 .77714 L
.57407 .69778 L
.55423 .61841 L
.54762 .53905 L
.55423 .45968 L
.57407 .38032 L
.60714 .30095 L
.65344 .22159 L
.71296 .14222 L
.78571 .06286 L
.77619 .06286 L
s
.5 g
.77619 .53905 m
.78571 .53905 L
.71296 .53905 L
.70344 .53905 L
.77619 .53905 L
F
.70344 .53905 m
.71296 .53905 L
.65344 .53905 L
.64392 .53905 L
.70344 .53905 L
F
.64392 .53905 m
.65344 .53905 L
.60714 .53905 L
.59762 .53905 L
.64392 .53905 L
F
.59762 .53905 m
.60714 .53905 L
.57407 .53905 L
.56455 .53905 L
.59762 .53905 L
F
.56455 .53905 m
.57407 .53905 L
.55423 .53905 L
.54471 .53905 L
.56455 .53905 L
F
.54471 .53905 m
.55423 .53905 L
.54762 .53905 L
.5381 .53905 L
.54471 .53905 L
F
.5381 .53905 m
.54762 .53905 L
.55423 .53905 L
.54471 .53905 L
.5381 .53905 L
F
.54471 .53905 m
.55423 .53905 L
.57407 .53905 L
.56455 .53905 L
.54471 .53905 L
F
.56455 .53905 m
.57407 .53905 L
.60714 .53905 L
.59762 .53905 L
.56455 .53905 L
F
.59762 .53905 m
.60714 .53905 L
.65344 .53905 L
.64392 .53905 L
.59762 .53905 L
F
.64392 .53905 m
.65344 .53905 L
.71296 .53905 L
.70344 .53905 L
.64392 .53905 L
F
.70344 .53905 m
.71296 .53905 L
.78571 .53905 L
.77619 .53905 L
.70344 .53905 L
F
0 g
.77619 .53905 m
.70344 .53905 L
.64392 .53905 L
.59762 .53905 L
.56455 .53905 L
.54471 .53905 L
.5381 .53905 L
.54471 .53905 L
.56455 .53905 L
.59762 .53905 L
.64392 .53905 L
.70344 .53905 L
.77619 .53905 L
.78571 .53905 L
.71296 .53905 L
.65344 .53905 L
.60714 .53905 L
.57407 .53905 L
.55423 .53905 L
.54762 .53905 L
.55423 .53905 L
.57407 .53905 L
.60714 .53905 L
.65344 .53905 L
.71296 .53905 L
.78571 .53905 L
.77619 .53905 L
s
.5 g
.78571 .06286 m
.79524 .06286 L
.72249 .14222 L
.71296 .14222 L
.78571 .06286 L
F
.71296 .14222 m
.72249 .14222 L
.66296 .22159 L
.65344 .22159 L
.71296 .14222 L
F
.65344 .22159 m
.66296 .22159 L
.61667 .30095 L
.60714 .30095 L
.65344 .22159 L
F
.60714 .30095 m
.61667 .30095 L
.5836 .38032 L
.57407 .38032 L
.60714 .30095 L
F
.57407 .38032 m
.5836 .38032 L
.56376 .45968 L
.55423 .45968 L
.57407 .38032 L
F
.55423 .45968 m
.56376 .45968 L
.55714 .53905 L
.54762 .53905 L
.55423 .45968 L
F
.54762 .53905 m
.55714 .53905 L
.56376 .61841 L
.55423 .61841 L
.54762 .53905 L
F
.55423 .61841 m
.56376 .61841 L
.5836 .69778 L
.57407 .69778 L
.55423 .61841 L
F
.57407 .69778 m
.5836 .69778 L
.61667 .77714 L
.60714 .77714 L
.57407 .69778 L
F
.60714 .77714 m
.61667 .77714 L
.66296 .85651 L
.65344 .85651 L
.60714 .77714 L
F
.65344 .85651 m
.66296 .85651 L
.72249 .93587 L
.71296 .93587 L
.65344 .85651 L
F
.71296 .93587 m
.72249 .93587 L
.79524 1.01524 L
.78571 1.01524 L
.71296 .93587 L
F
0 g
.78571 .06286 m
.71296 .14222 L
.65344 .22159 L
.60714 .30095 L
.57407 .38032 L
.55423 .45968 L
.54762 .53905 L
.55423 .61841 L
.57407 .69778 L
.60714 .77714 L
.65344 .85651 L
.71296 .93587 L
.78571 1.01524 L
.79524 1.01524 L
.72249 .93587 L
.66296 .85651 L
.61667 .77714 L
.5836 .69778 L
.56376 .61841 L
.55714 .53905 L
.56376 .45968 L
.5836 .38032 L
.61667 .30095 L
.66296 .22159 L
.72249 .14222 L
.79524 .06286 L
.78571 .06286 L
s
.5 g
.78571 .53905 m
.79524 .53905 L
.72249 .53905 L
.71296 .53905 L
.78571 .53905 L
F
.71296 .53905 m
.72249 .53905 L
.66296 .53905 L
.65344 .53905 L
.71296 .53905 L
F
.65344 .53905 m
.66296 .53905 L
.61667 .53905 L
.60714 .53905 L
.65344 .53905 L
F
.60714 .53905 m
.61667 .53905 L
.5836 .53905 L
.57407 .53905 L
.60714 .53905 L
F
.57407 .53905 m
.5836 .53905 L
.56376 .53905 L
.55423 .53905 L
.57407 .53905 L
F
.55423 .53905 m
.56376 .53905 L
.55714 .53905 L
.54762 .53905 L
.55423 .53905 L
F
.54762 .53905 m
.55714 .53905 L
.56376 .53905 L
.55423 .53905 L
.54762 .53905 L
F
.55423 .53905 m
.56376 .53905 L
.5836 .53905 L
.57407 .53905 L
.55423 .53905 L
F
.57407 .53905 m
.5836 .53905 L
.61667 .53905 L
.60714 .53905 L
.57407 .53905 L
F
.60714 .53905 m
.61667 .53905 L
.66296 .53905 L
.65344 .53905 L
.60714 .53905 L
F
.65344 .53905 m
.66296 .53905 L
.72249 .53905 L
.71296 .53905 L
.65344 .53905 L
F
.71296 .53905 m
.72249 .53905 L
.79524 .53905 L
.78571 .53905 L
.71296 .53905 L
F
0 g
.78571 .53905 m
.71296 .53905 L
.65344 .53905 L
.60714 .53905 L
.57407 .53905 L
.55423 .53905 L
.54762 .53905 L
.55423 .53905 L
.57407 .53905 L
.60714 .53905 L
.65344 .53905 L
.71296 .53905 L
.78571 .53905 L
.79524 .53905 L
.72249 .53905 L
.66296 .53905 L
.61667 .53905 L
.5836 .53905 L
.56376 .53905 L
.55714 .53905 L
.56376 .53905 L
.5836 .53905 L
.61667 .53905 L
.66296 .53905 L
.72249 .53905 L
.79524 .53905 L
.78571 .53905 L
s
.5 g
.79524 .06286 m
.83333 .06286 L
.76058 .14222 L
.72249 .14222 L
.79524 .06286 L
F
.72249 .14222 m
.76058 .14222 L
.70106 .22159 L
.66296 .22159 L
.72249 .14222 L
F
.66296 .22159 m
.70106 .22159 L
.65476 .30095 L
.61667 .30095 L
.66296 .22159 L
F
.61667 .30095 m
.65476 .30095 L
.62169 .38032 L
.5836 .38032 L
.61667 .30095 L
F
.5836 .38032 m
.62169 .38032 L
.60185 .45968 L
.56376 .45968 L
.5836 .38032 L
F
.56376 .45968 m
.60185 .45968 L
.59524 .53905 L
.55714 .53905 L
.56376 .45968 L
F
.55714 .53905 m
.59524 .53905 L
.60185 .61841 L
.56376 .61841 L
.55714 .53905 L
F
.56376 .61841 m
.60185 .61841 L
.62169 .69778 L
.5836 .69778 L
.56376 .61841 L
F
.5836 .69778 m
.62169 .69778 L
.65476 .77714 L
.61667 .77714 L
.5836 .69778 L
F
.61667 .77714 m
.65476 .77714 L
.70106 .85651 L
.66296 .85651 L
.61667 .77714 L
F
.66296 .85651 m
.70106 .85651 L
.76058 .93587 L
.72249 .93587 L
.66296 .85651 L
F
.72249 .93587 m
.76058 .93587 L
.83333 1.01524 L
.79524 1.01524 L
.72249 .93587 L
F
0 g
.79524 .06286 m
.72249 .14222 L
.66296 .22159 L
.61667 .30095 L
.5836 .38032 L
.56376 .45968 L
.55714 .53905 L
.56376 .61841 L
.5836 .69778 L
.61667 .77714 L
.66296 .85651 L
.72249 .93587 L
.79524 1.01524 L
.83333 1.01524 L
.76058 .93587 L
.70106 .85651 L
.65476 .77714 L
.62169 .69778 L
.60185 .61841 L
.59524 .53905 L
.60185 .45968 L
.62169 .38032 L
.65476 .30095 L
.70106 .22159 L
.76058 .14222 L
.83333 .06286 L
.79524 .06286 L
s
.5 g
.79524 .53905 m
.83333 .53905 L
.76058 .53905 L
.72249 .53905 L
.79524 .53905 L
F
.72249 .53905 m
.76058 .53905 L
.70106 .53905 L
.66296 .53905 L
.72249 .53905 L
F
.66296 .53905 m
.70106 .53905 L
.65476 .53905 L
.61667 .53905 L
.66296 .53905 L
F
.61667 .53905 m
.65476 .53905 L
.62169 .53905 L
.5836 .53905 L
.61667 .53905 L
F
.5836 .53905 m
.62169 .53905 L
.60185 .53905 L
.56376 .53905 L
.5836 .53905 L
F
.56376 .53905 m
.60185 .53905 L
.59524 .53905 L
.55714 .53905 L
.56376 .53905 L
F
.55714 .53905 m
.59524 .53905 L
.60185 .53905 L
.56376 .53905 L
.55714 .53905 L
F
.56376 .53905 m
.60185 .53905 L
.62169 .53905 L
.5836 .53905 L
.56376 .53905 L
F
.5836 .53905 m
.62169 .53905 L
.65476 .53905 L
.61667 .53905 L
.5836 .53905 L
F
.61667 .53905 m
.65476 .53905 L
.70106 .53905 L
.66296 .53905 L
.61667 .53905 L
F
.66296 .53905 m
.70106 .53905 L
.76058 .53905 L
.72249 .53905 L
.66296 .53905 L
F
.72249 .53905 m
.76058 .53905 L
.83333 .53905 L
.79524 .53905 L
.72249 .53905 L
F
0 g
.79524 .53905 m
.72249 .53905 L
.66296 .53905 L
.61667 .53905 L
.5836 .53905 L
.56376 .53905 L
.55714 .53905 L
.56376 .53905 L
.5836 .53905 L
.61667 .53905 L
.66296 .53905 L
.72249 .53905 L
.79524 .53905 L
.83333 .53905 L
.76058 .53905 L
.70106 .53905 L
.65476 .53905 L
.62169 .53905 L
.60185 .53905 L
.59524 .53905 L
.60185 .53905 L
.62169 .53905 L
.65476 .53905 L
.70106 .53905 L
.76058 .53905 L
.83333 .53905 L
.79524 .53905 L
s
.7381 1.01524 m
.7381 1.01116 L
.7381 .99901 L
.7381 .97899 L
.7381 .95144 L
.7381 .91683 L
.7381 .87577 L
.7381 .82893 L
.7381 .77714 L
.7381 .72128 L
.7381 .66229 L
.7381 .6012 L
.7381 .53905 L
.7381 .47689 L
.7381 .4158 L
.7381 .35682 L
.7381 .30095 L
.7381 .24916 L
.7381 .20233 L
.7381 .16126 L
.7381 .12665 L
.7381 .0991 L
.7381 .07908 L
.7381 .06693 L
.7381 .06286 L
.7381 .06693 L
.7381 .07908 L
.7381 .0991 L
.7381 .12665 L
.7381 .16126 L
.7381 .20233 L
.7381 .24916 L
.7381 .30095 L
.7381 .35682 L
.7381 .4158 L
.7381 .47689 L
.7381 .53905 L
.7381 .6012 L
.7381 .66229 L
.7381 .72128 L
.7381 .77714 L
.7381 .82893 L
.7381 .87577 L
.7381 .91683 L
.7381 .95144 L
.7381 .97899 L
.7381 .99901 L
.7381 1.01116 L
.7381 1.01524 L
s
.77619 1.01524 m
.77619 1.01116 L
.77619 .99901 L
.77619 .97899 L
.77619 .95144 L
.77619 .91683 L
.77619 .87577 L
.77619 .82893 L
.77619 .77714 L
.77619 .72128 L
.77619 .66229 L
.77619 .6012 L
.77619 .53905 L
.77619 .47689 L
.77619 .4158 L
.77619 .35682 L
.77619 .30095 L
.77619 .24916 L
.77619 .20233 L
.77619 .16126 L
.77619 .12665 L
.77619 .0991 L
.77619 .07908 L
.77619 .06693 L
.77619 .06286 L
.77619 .06693 L
.77619 .07908 L
.77619 .0991 L
.77619 .12665 L
.77619 .16126 L
.77619 .20233 L
.77619 .24916 L
.77619 .30095 L
.77619 .35682 L
.77619 .4158 L
.77619 .47689 L
.77619 .53905 L
.77619 .6012 L
.77619 .66229 L
.77619 .72128 L
.77619 .77714 L
.77619 .82893 L
.77619 .87577 L
.77619 .91683 L
.77619 .95144 L
.77619 .97899 L
.77619 .99901 L
.77619 1.01116 L
.77619 1.01524 L
s
.78571 1.01524 m
.78571 1.01116 L
.78571 .99901 L
.78571 .97899 L
.78571 .95144 L
.78571 .91683 L
.78571 .87577 L
.78571 .82893 L
.78571 .77714 L
.78571 .72128 L
.78571 .66229 L
.78571 .6012 L
.78571 .53905 L
.78571 .47689 L
.78571 .4158 L
.78571 .35682 L
.78571 .30095 L
.78571 .24916 L
.78571 .20233 L
.78571 .16126 L
.78571 .12665 L
.78571 .0991 L
.78571 .07908 L
.78571 .06693 L
.78571 .06286 L
.78571 .06693 L
.78571 .07908 L
.78571 .0991 L
.78571 .12665 L
.78571 .16126 L
.78571 .20233 L
.78571 .24916 L
.78571 .30095 L
.78571 .35682 L
.78571 .4158 L
.78571 .47689 L
.78571 .53905 L
.78571 .6012 L
.78571 .66229 L
.78571 .72128 L
.78571 .77714 L
.78571 .82893 L
.78571 .87577 L
.78571 .91683 L
.78571 .95144 L
.78571 .97899 L
.78571 .99901 L
.78571 1.01116 L
.78571 1.01524 L
s
.79524 1.01524 m
.79524 1.01116 L
.79524 .99901 L
.79524 .97899 L
.79524 .95144 L
.79524 .91683 L
.79524 .87577 L
.79524 .82893 L
.79524 .77714 L
.79524 .72128 L
.79524 .66229 L
.79524 .6012 L
.79524 .53905 L
.79524 .47689 L
.79524 .4158 L
.79524 .35682 L
.79524 .30095 L
.79524 .24916 L
.79524 .20233 L
.79524 .16126 L
.79524 .12665 L
.79524 .0991 L
.79524 .07908 L
.79524 .06693 L
.79524 .06286 L
.79524 .06693 L
.79524 .07908 L
.79524 .0991 L
.79524 .12665 L
.79524 .16126 L
.79524 .20233 L
.79524 .24916 L
.79524 .30095 L
.79524 .35682 L
.79524 .4158 L
.79524 .47689 L
.79524 .53905 L
.79524 .6012 L
.79524 .66229 L
.79524 .72128 L
.79524 .77714 L
.79524 .82893 L
.79524 .87577 L
.79524 .91683 L
.79524 .95144 L
.79524 .97899 L
.79524 .99901 L
.79524 1.01116 L
.79524 1.01524 L
s
.83333 1.01524 m
.83333 1.01116 L
.83333 .99901 L
.83333 .97899 L
.83333 .95144 L
.83333 .91683 L
.83333 .87577 L
.83333 .82893 L
.83333 .77714 L
.83333 .72128 L
.83333 .66229 L
.83333 .6012 L
.83333 .53905 L
.83333 .47689 L
.83333 .4158 L
.83333 .35682 L
.83333 .30095 L
.83333 .24916 L
.83333 .20233 L
.83333 .16126 L
.83333 .12665 L
.83333 .0991 L
.83333 .07908 L
.83333 .06693 L
.83333 .06286 L
.83333 .06693 L
.83333 .07908 L
.83333 .0991 L
.83333 .12665 L
.83333 .16126 L
.83333 .20233 L
.83333 .24916 L
.83333 .30095 L
.83333 .35682 L
.83333 .4158 L
.83333 .47689 L
.83333 .53905 L
.83333 .6012 L
.83333 .66229 L
.83333 .72128 L
.83333 .77714 L
.83333 .82893 L
.83333 .87577 L
.83333 .91683 L
.83333 .95144 L
.83333 .97899 L
.83333 .99901 L
.83333 1.01116 L
.83333 1.01524 L
s
.7381 1.01524 m
.77619 1.01524 L
.77619 1.01116 L
.7381 1.01116 L
.7381 1.01524 L
s
.7381 1.01116 m
.77619 1.01116 L
.77619 .99901 L
.7381 .99901 L
.7381 1.01116 L
s
.7381 .99901 m
.77619 .99901 L
.77619 .97899 L
.7381 .97899 L
.7381 .99901 L
s
.7381 .97899 m
.77619 .97899 L
.77619 .95144 L
.7381 .95144 L
.7381 .97899 L
s
.7381 .95144 m
.77619 .95144 L
.77619 .91683 L
.7381 .91683 L
.7381 .95144 L
s
.7381 .91683 m
.77619 .91683 L
.77619 .87577 L
.7381 .87577 L
.7381 .91683 L
s
.7381 .87577 m
.77619 .87577 L
.77619 .82893 L
.7381 .82893 L
.7381 .87577 L
s
.7381 .82893 m
.77619 .82893 L
.77619 .77714 L
.7381 .77714 L
.7381 .82893 L
s
.7381 .77714 m
.77619 .77714 L
.77619 .72128 L
.7381 .72128 L
.7381 .77714 L
s
.7381 .72128 m
.77619 .72128 L
.77619 .66229 L
.7381 .66229 L
.7381 .72128 L
s
.7381 .66229 m
.77619 .66229 L
.77619 .6012 L
.7381 .6012 L
.7381 .66229 L
s
.7381 .6012 m
.77619 .6012 L
.77619 .53905 L
.7381 .53905 L
.7381 .6012 L
s
.7381 .53905 m
.77619 .53905 L
.77619 .47689 L
.7381 .47689 L
.7381 .53905 L
s
.7381 .47689 m
.77619 .47689 L
.77619 .4158 L
.7381 .4158 L
.7381 .47689 L
s
.7381 .4158 m
.77619 .4158 L
.77619 .35682 L
.7381 .35682 L
.7381 .4158 L
s
.7381 .35682 m
.77619 .35682 L
.77619 .30095 L
.7381 .30095 L
.7381 .35682 L
s
.7381 .30095 m
.77619 .30095 L
.77619 .24916 L
.7381 .24916 L
.7381 .30095 L
s
.7381 .24916 m
.77619 .24916 L
.77619 .20233 L
.7381 .20233 L
.7381 .24916 L
s
.7381 .20233 m
.77619 .20233 L
.77619 .16126 L
.7381 .16126 L
.7381 .20233 L
s
.7381 .16126 m
.77619 .16126 L
.77619 .12665 L
.7381 .12665 L
.7381 .16126 L
s
.7381 .12665 m
.77619 .12665 L
.77619 .0991 L
.7381 .0991 L
.7381 .12665 L
s
.7381 .0991 m
.77619 .0991 L
.77619 .07908 L
.7381 .07908 L
.7381 .0991 L
s
.7381 .07908 m
.77619 .07908 L
.77619 .06693 L
.7381 .06693 L
.7381 .07908 L
s
.7381 .06693 m
.77619 .06693 L
.77619 .06286 L
.7381 .06286 L
.7381 .06693 L
s
.7381 .06286 m
.77619 .06286 L
.77619 .06693 L
.7381 .06693 L
.7381 .06286 L
s
.7381 .06693 m
.77619 .06693 L
.77619 .07908 L
.7381 .07908 L
.7381 .06693 L
s
.7381 .07908 m
.77619 .07908 L
.77619 .0991 L
.7381 .0991 L
.7381 .07908 L
s
.7381 .0991 m
.77619 .0991 L
.77619 .12665 L
.7381 .12665 L
.7381 .0991 L
s
.7381 .12665 m
.77619 .12665 L
.77619 .16126 L
.7381 .16126 L
.7381 .12665 L
s
.7381 .16126 m
.77619 .16126 L
.77619 .20233 L
.7381 .20233 L
.7381 .16126 L
s
.7381 .20233 m
.77619 .20233 L
.77619 .24916 L
.7381 .24916 L
.7381 .20233 L
s
.7381 .24916 m
.77619 .24916 L
.77619 .30095 L
.7381 .30095 L
.7381 .24916 L
s
.7381 .30095 m
.77619 .30095 L
.77619 .35682 L
.7381 .35682 L
.7381 .30095 L
s
.7381 .35682 m
.77619 .35682 L
.77619 .4158 L
.7381 .4158 L
.7381 .35682 L
s
.7381 .4158 m
.77619 .4158 L
.77619 .47689 L
.7381 .47689 L
.7381 .4158 L
s
.7381 .47689 m
.77619 .47689 L
.77619 .53905 L
.7381 .53905 L
.7381 .47689 L
s
.7381 .53905 m
.77619 .53905 L
.77619 .6012 L
.7381 .6012 L
.7381 .53905 L
s
.7381 .6012 m
.77619 .6012 L
.77619 .66229 L
.7381 .66229 L
.7381 .6012 L
s
.7381 .66229 m
.77619 .66229 L
.77619 .72128 L
.7381 .72128 L
.7381 .66229 L
s
.7381 .72128 m
.77619 .72128 L
.77619 .77714 L
.7381 .77714 L
.7381 .72128 L
s
.7381 .77714 m
.77619 .77714 L
.77619 .82893 L
.7381 .82893 L
.7381 .77714 L
s
.7381 .82893 m
.77619 .82893 L
.77619 .87577 L
.7381 .87577 L
.7381 .82893 L
s
.7381 .87577 m
.77619 .87577 L
.77619 .91683 L
.7381 .91683 L
.7381 .87577 L
s
.7381 .91683 m
.77619 .91683 L
.77619 .95144 L
.7381 .95144 L
.7381 .91683 L
s
.7381 .95144 m
.77619 .95144 L
.77619 .97899 L
.7381 .97899 L
.7381 .95144 L
s
.7381 .97899 m
.77619 .97899 L
.77619 .99901 L
.7381 .99901 L
.7381 .97899 L
s
.7381 .99901 m
.77619 .99901 L
.77619 1.01116 L
.7381 1.01116 L
.7381 .99901 L
s
.7381 1.01116 m
.77619 1.01116 L
.77619 1.01524 L
.7381 1.01524 L
.7381 1.01116 L
s
.77619 1.01524 m
.78571 1.01524 L
.78571 1.01116 L
.77619 1.01116 L
.77619 1.01524 L
s
.77619 1.01116 m
.78571 1.01116 L
.78571 .99901 L
.77619 .99901 L
.77619 1.01116 L
s
.77619 .99901 m
.78571 .99901 L
.78571 .97899 L
.77619 .97899 L
.77619 .99901 L
s
.77619 .97899 m
.78571 .97899 L
.78571 .95144 L
.77619 .95144 L
.77619 .97899 L
s
.77619 .95144 m
.78571 .95144 L
.78571 .91683 L
.77619 .91683 L
.77619 .95144 L
s
.77619 .91683 m
.78571 .91683 L
.78571 .87577 L
.77619 .87577 L
.77619 .91683 L
s
.77619 .87577 m
.78571 .87577 L
.78571 .82893 L
.77619 .82893 L
.77619 .87577 L
s
.77619 .82893 m
.78571 .82893 L
.78571 .77714 L
.77619 .77714 L
.77619 .82893 L
s
.77619 .77714 m
.78571 .77714 L
.78571 .72128 L
.77619 .72128 L
.77619 .77714 L
s
.77619 .72128 m
.78571 .72128 L
.78571 .66229 L
.77619 .66229 L
.77619 .72128 L
s
.77619 .66229 m
.78571 .66229 L
.78571 .6012 L
.77619 .6012 L
.77619 .66229 L
s
.77619 .6012 m
.78571 .6012 L
.78571 .53905 L
.77619 .53905 L
.77619 .6012 L
s
.77619 .53905 m
.78571 .53905 L
.78571 .47689 L
.77619 .47689 L
.77619 .53905 L
s
.77619 .47689 m
.78571 .47689 L
.78571 .4158 L
.77619 .4158 L
.77619 .47689 L
s
.77619 .4158 m
.78571 .4158 L
.78571 .35682 L
.77619 .35682 L
.77619 .4158 L
s
.77619 .35682 m
.78571 .35682 L
.78571 .30095 L
.77619 .30095 L
.77619 .35682 L
s
.77619 .30095 m
.78571 .30095 L
.78571 .24916 L
.77619 .24916 L
.77619 .30095 L
s
.77619 .24916 m
.78571 .24916 L
.78571 .20233 L
.77619 .20233 L
.77619 .24916 L
s
.77619 .20233 m
.78571 .20233 L
.78571 .16126 L
.77619 .16126 L
.77619 .20233 L
s
.77619 .16126 m
.78571 .16126 L
.78571 .12665 L
.77619 .12665 L
.77619 .16126 L
s
.77619 .12665 m
.78571 .12665 L
.78571 .0991 L
.77619 .0991 L
.77619 .12665 L
s
.77619 .0991 m
.78571 .0991 L
.78571 .07908 L
.77619 .07908 L
.77619 .0991 L
s
.77619 .07908 m
.78571 .07908 L
.78571 .06693 L
.77619 .06693 L
.77619 .07908 L
s
.77619 .06693 m
.78571 .06693 L
.78571 .06286 L
.77619 .06286 L
.77619 .06693 L
s
.77619 .06286 m
.78571 .06286 L
.78571 .06693 L
.77619 .06693 L
.77619 .06286 L
s
.77619 .06693 m
.78571 .06693 L
.78571 .07908 L
.77619 .07908 L
.77619 .06693 L
s
.77619 .07908 m
.78571 .07908 L
.78571 .0991 L
.77619 .0991 L
.77619 .07908 L
s
.77619 .0991 m
.78571 .0991 L
.78571 .12665 L
.77619 .12665 L
.77619 .0991 L
s
.77619 .12665 m
.78571 .12665 L
.78571 .16126 L
.77619 .16126 L
.77619 .12665 L
s
.77619 .16126 m
.78571 .16126 L
.78571 .20233 L
.77619 .20233 L
.77619 .16126 L
s
.77619 .20233 m
.78571 .20233 L
.78571 .24916 L
.77619 .24916 L
.77619 .20233 L
s
.77619 .24916 m
.78571 .24916 L
.78571 .30095 L
.77619 .30095 L
.77619 .24916 L
s
.77619 .30095 m
.78571 .30095 L
.78571 .35682 L
.77619 .35682 L
.77619 .30095 L
s
.77619 .35682 m
.78571 .35682 L
.78571 .4158 L
.77619 .4158 L
.77619 .35682 L
s
.77619 .4158 m
.78571 .4158 L
.78571 .47689 L
.77619 .47689 L
.77619 .4158 L
s
.77619 .47689 m
.78571 .47689 L
.78571 .53905 L
.77619 .53905 L
.77619 .47689 L
s
.77619 .53905 m
.78571 .53905 L
.78571 .6012 L
.77619 .6012 L
.77619 .53905 L
s
.77619 .6012 m
.78571 .6012 L
.78571 .66229 L
.77619 .66229 L
.77619 .6012 L
s
.77619 .66229 m
.78571 .66229 L
.78571 .72128 L
.77619 .72128 L
.77619 .66229 L
s
.77619 .72128 m
.78571 .72128 L
.78571 .77714 L
.77619 .77714 L
.77619 .72128 L
s
.77619 .77714 m
.78571 .77714 L
.78571 .82893 L
.77619 .82893 L
.77619 .77714 L
s
.77619 .82893 m
.78571 .82893 L
.78571 .87577 L
.77619 .87577 L
.77619 .82893 L
s
.77619 .87577 m
.78571 .87577 L
.78571 .91683 L
.77619 .91683 L
.77619 .87577 L
s
.77619 .91683 m
.78571 .91683 L
.78571 .95144 L
.77619 .95144 L
.77619 .91683 L
s
.77619 .95144 m
.78571 .95144 L
.78571 .97899 L
.77619 .97899 L
.77619 .95144 L
s
.77619 .97899 m
.78571 .97899 L
.78571 .99901 L
.77619 .99901 L
.77619 .97899 L
s
.77619 .99901 m
.78571 .99901 L
.78571 1.01116 L
.77619 1.01116 L
.77619 .99901 L
s
.77619 1.01116 m
.78571 1.01116 L
.78571 1.01524 L
.77619 1.01524 L
.77619 1.01116 L
s
.78571 1.01524 m
.79524 1.01524 L
.79524 1.01116 L
.78571 1.01116 L
.78571 1.01524 L
s
.78571 1.01116 m
.79524 1.01116 L
.79524 .99901 L
.78571 .99901 L
.78571 1.01116 L
s
.78571 .99901 m
.79524 .99901 L
.79524 .97899 L
.78571 .97899 L
.78571 .99901 L
s
.78571 .97899 m
.79524 .97899 L
.79524 .95144 L
.78571 .95144 L
.78571 .97899 L
s
.78571 .95144 m
.79524 .95144 L
.79524 .91683 L
.78571 .91683 L
.78571 .95144 L
s
.78571 .91683 m
.79524 .91683 L
.79524 .87577 L
.78571 .87577 L
.78571 .91683 L
s
.78571 .87577 m
.79524 .87577 L
.79524 .82893 L
.78571 .82893 L
.78571 .87577 L
s
.78571 .82893 m
.79524 .82893 L
.79524 .77714 L
.78571 .77714 L
.78571 .82893 L
s
.78571 .77714 m
.79524 .77714 L
.79524 .72128 L
.78571 .72128 L
.78571 .77714 L
s
.78571 .72128 m
.79524 .72128 L
.79524 .66229 L
.78571 .66229 L
.78571 .72128 L
s
.78571 .66229 m
.79524 .66229 L
.79524 .6012 L
.78571 .6012 L
.78571 .66229 L
s
.78571 .6012 m
.79524 .6012 L
.79524 .53905 L
.78571 .53905 L
.78571 .6012 L
s
.78571 .53905 m
.79524 .53905 L
.79524 .47689 L
.78571 .47689 L
.78571 .53905 L
s
.78571 .47689 m
.79524 .47689 L
.79524 .4158 L
.78571 .4158 L
.78571 .47689 L
s
.78571 .4158 m
.79524 .4158 L
.79524 .35682 L
.78571 .35682 L
.78571 .4158 L
s
.78571 .35682 m
.79524 .35682 L
.79524 .30095 L
.78571 .30095 L
.78571 .35682 L
s
.78571 .30095 m
.79524 .30095 L
.79524 .24916 L
.78571 .24916 L
.78571 .30095 L
s
.78571 .24916 m
.79524 .24916 L
.79524 .20233 L
.78571 .20233 L
.78571 .24916 L
s
.78571 .20233 m
.79524 .20233 L
.79524 .16126 L
.78571 .16126 L
.78571 .20233 L
s
.78571 .16126 m
.79524 .16126 L
.79524 .12665 L
.78571 .12665 L
.78571 .16126 L
s
.78571 .12665 m
.79524 .12665 L
.79524 .0991 L
.78571 .0991 L
.78571 .12665 L
s
.78571 .0991 m
.79524 .0991 L
.79524 .07908 L
.78571 .07908 L
.78571 .0991 L
s
.78571 .07908 m
.79524 .07908 L
.79524 .06693 L
.78571 .06693 L
.78571 .07908 L
s
.78571 .06693 m
.79524 .06693 L
.79524 .06286 L
.78571 .06286 L
.78571 .06693 L
s
.78571 .06286 m
.79524 .06286 L
.79524 .06693 L
.78571 .06693 L
.78571 .06286 L
s
.78571 .06693 m
.79524 .06693 L
.79524 .07908 L
.78571 .07908 L
.78571 .06693 L
s
.78571 .07908 m
.79524 .07908 L
.79524 .0991 L
.78571 .0991 L
.78571 .07908 L
s
.78571 .0991 m
.79524 .0991 L
.79524 .12665 L
.78571 .12665 L
.78571 .0991 L
s
.78571 .12665 m
.79524 .12665 L
.79524 .16126 L
.78571 .16126 L
.78571 .12665 L
s
.78571 .16126 m
.79524 .16126 L
.79524 .20233 L
.78571 .20233 L
.78571 .16126 L
s
.78571 .20233 m
.79524 .20233 L
.79524 .24916 L
.78571 .24916 L
.78571 .20233 L
s
.78571 .24916 m
.79524 .24916 L
.79524 .30095 L
.78571 .30095 L
.78571 .24916 L
s
.78571 .30095 m
.79524 .30095 L
.79524 .35682 L
.78571 .35682 L
.78571 .30095 L
s
.78571 .35682 m
.79524 .35682 L
.79524 .4158 L
.78571 .4158 L
.78571 .35682 L
s
.78571 .4158 m
.79524 .4158 L
.79524 .47689 L
.78571 .47689 L
.78571 .4158 L
s
.78571 .47689 m
.79524 .47689 L
.79524 .53905 L
.78571 .53905 L
.78571 .47689 L
s
.78571 .53905 m
.79524 .53905 L
.79524 .6012 L
.78571 .6012 L
.78571 .53905 L
s
.78571 .6012 m
.79524 .6012 L
.79524 .66229 L
.78571 .66229 L
.78571 .6012 L
s
.78571 .66229 m
.79524 .66229 L
.79524 .72128 L
.78571 .72128 L
.78571 .66229 L
s
.78571 .72128 m
.79524 .72128 L
.79524 .77714 L
.78571 .77714 L
.78571 .72128 L
s
.78571 .77714 m
.79524 .77714 L
.79524 .82893 L
.78571 .82893 L
.78571 .77714 L
s
.78571 .82893 m
.79524 .82893 L
.79524 .87577 L
.78571 .87577 L
.78571 .82893 L
s
.78571 .87577 m
.79524 .87577 L
.79524 .91683 L
.78571 .91683 L
.78571 .87577 L
s
.78571 .91683 m
.79524 .91683 L
.79524 .95144 L
.78571 .95144 L
.78571 .91683 L
s
.78571 .95144 m
.79524 .95144 L
.79524 .97899 L
.78571 .97899 L
.78571 .95144 L
s
.78571 .97899 m
.79524 .97899 L
.79524 .99901 L
.78571 .99901 L
.78571 .97899 L
s
.78571 .99901 m
.79524 .99901 L
.79524 1.01116 L
.78571 1.01116 L
.78571 .99901 L
s
.78571 1.01116 m
.79524 1.01116 L
.79524 1.01524 L
.78571 1.01524 L
.78571 1.01116 L
s
.79524 1.01524 m
.83333 1.01524 L
.83333 1.01116 L
.79524 1.01116 L
.79524 1.01524 L
s
.79524 1.01116 m
.83333 1.01116 L
.83333 .99901 L
.79524 .99901 L
.79524 1.01116 L
s
.79524 .99901 m
.83333 .99901 L
.83333 .97899 L
.79524 .97899 L
.79524 .99901 L
s
.79524 .97899 m
.83333 .97899 L
.83333 .95144 L
.79524 .95144 L
.79524 .97899 L
s
.79524 .95144 m
.83333 .95144 L
.83333 .91683 L
.79524 .91683 L
.79524 .95144 L
s
.79524 .91683 m
.83333 .91683 L
.83333 .87577 L
.79524 .87577 L
.79524 .91683 L
s
.79524 .87577 m
.83333 .87577 L
.83333 .82893 L
.79524 .82893 L
.79524 .87577 L
s
.79524 .82893 m
.83333 .82893 L
.83333 .77714 L
.79524 .77714 L
.79524 .82893 L
s
.79524 .77714 m
.83333 .77714 L
.83333 .72128 L
.79524 .72128 L
.79524 .77714 L
s
.79524 .72128 m
.83333 .72128 L
.83333 .66229 L
.79524 .66229 L
.79524 .72128 L
s
.79524 .66229 m
.83333 .66229 L
.83333 .6012 L
.79524 .6012 L
.79524 .66229 L
s
.79524 .6012 m
.83333 .6012 L
.83333 .53905 L
.79524 .53905 L
.79524 .6012 L
s
.79524 .53905 m
.83333 .53905 L
.83333 .47689 L
.79524 .47689 L
.79524 .53905 L
s
.79524 .47689 m
.83333 .47689 L
.83333 .4158 L
.79524 .4158 L
.79524 .47689 L
s
.79524 .4158 m
.83333 .4158 L
.83333 .35682 L
.79524 .35682 L
.79524 .4158 L
s
.79524 .35682 m
.83333 .35682 L
.83333 .30095 L
.79524 .30095 L
.79524 .35682 L
s
.79524 .30095 m
.83333 .30095 L
.83333 .24916 L
.79524 .24916 L
.79524 .30095 L
s
.79524 .24916 m
.83333 .24916 L
.83333 .20233 L
.79524 .20233 L
.79524 .24916 L
s
.79524 .20233 m
.83333 .20233 L
.83333 .16126 L
.79524 .16126 L
.79524 .20233 L
s
.79524 .16126 m
.83333 .16126 L
.83333 .12665 L
.79524 .12665 L
.79524 .16126 L
s
.79524 .12665 m
.83333 .12665 L
.83333 .0991 L
.79524 .0991 L
.79524 .12665 L
s
.79524 .0991 m
.83333 .0991 L
.83333 .07908 L
.79524 .07908 L
.79524 .0991 L
s
.79524 .07908 m
.83333 .07908 L
.83333 .06693 L
.79524 .06693 L
.79524 .07908 L
s
.79524 .06693 m
.83333 .06693 L
.83333 .06286 L
.79524 .06286 L
.79524 .06693 L
s
.79524 .06286 m
.83333 .06286 L
.83333 .06693 L
.79524 .06693 L
.79524 .06286 L
s
.79524 .06693 m
.83333 .06693 L
.83333 .07908 L
.79524 .07908 L
.79524 .06693 L
s
.79524 .07908 m
.83333 .07908 L
.83333 .0991 L
.79524 .0991 L
.79524 .07908 L
s
.79524 .0991 m
.83333 .0991 L
.83333 .12665 L
.79524 .12665 L
.79524 .0991 L
s
.79524 .12665 m
.83333 .12665 L
.83333 .16126 L
.79524 .16126 L
.79524 .12665 L
s
.79524 .16126 m
.83333 .16126 L
.83333 .20233 L
.79524 .20233 L
.79524 .16126 L
s
.79524 .20233 m
.83333 .20233 L
.83333 .24916 L
.79524 .24916 L
.79524 .20233 L
s
.79524 .24916 m
.83333 .24916 L
.83333 .30095 L
.79524 .30095 L
.79524 .24916 L
s
.79524 .30095 m
.83333 .30095 L
.83333 .35682 L
.79524 .35682 L
.79524 .30095 L
s
.79524 .35682 m
.83333 .35682 L
.83333 .4158 L
.79524 .4158 L
.79524 .35682 L
s
.79524 .4158 m
.83333 .4158 L
.83333 .47689 L
.79524 .47689 L
.79524 .4158 L
s
.79524 .47689 m
.83333 .47689 L
.83333 .53905 L
.79524 .53905 L
.79524 .47689 L
s
.79524 .53905 m
.83333 .53905 L
.83333 .6012 L
.79524 .6012 L
.79524 .53905 L
s
.79524 .6012 m
.83333 .6012 L
.83333 .66229 L
.79524 .66229 L
.79524 .6012 L
s
.79524 .66229 m
.83333 .66229 L
.83333 .72128 L
.79524 .72128 L
.79524 .66229 L
s
.79524 .72128 m
.83333 .72128 L
.83333 .77714 L
.79524 .77714 L
.79524 .72128 L
s
.79524 .77714 m
.83333 .77714 L
.83333 .82893 L
.79524 .82893 L
.79524 .77714 L
s
.79524 .82893 m
.83333 .82893 L
.83333 .87577 L
.79524 .87577 L
.79524 .82893 L
s
.79524 .87577 m
.83333 .87577 L
.83333 .91683 L
.79524 .91683 L
.79524 .87577 L
s
.79524 .91683 m
.83333 .91683 L
.83333 .95144 L
.79524 .95144 L
.79524 .91683 L
s
.79524 .95144 m
.83333 .95144 L
.83333 .97899 L
.79524 .97899 L
.79524 .95144 L
s
.79524 .97899 m
.83333 .97899 L
.83333 .99901 L
.79524 .99901 L
.79524 .97899 L
s
.79524 .99901 m
.83333 .99901 L
.83333 1.01116 L
.79524 1.01116 L
.79524 .99901 L
s
.79524 1.01116 m
.83333 1.01116 L
.83333 1.01524 L
.79524 1.01524 L
.79524 1.01116 L
s
.97619 1.01524 m
.97619 .06286 L
.97619 .06286 L
.97619 1.01524 L
.97619 1.01524 L
s
.97619 .06286 m
.02381 .06286 L
.02381 .06286 L
.97619 .06286 L
.97619 .06286 L
s
.02381 .06286 m
.02381 1.01524 L
.02381 1.01524 L
.02381 .06286 L
.02381 .06286 L
s
.02381 1.01524 m
.97619 1.01524 L
.97619 1.01524 L
.02381 1.01524 L
.02381 1.01524 L
s
.97619 .06286 m
.97619 1.01524 L
.02381 1.01524 L
.02381 .06286 L
.97619 .06286 L
s
.97619 1.01524 m
.97619 .06286 L
.02381 .06286 L
.02381 1.01524 L
.97619 1.01524 L
s
.039 .916 .04 r
.11905 .53905 m
.5 .53905 L
s
0 0 0 r
2 Mabswid
.5 .53905 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .53905 m
.5381 .53905 L
s
0 0 0 r
2 Mabswid
.5381 .53905 Mdot
.039 .916 .04 r
.5 Mabswid
.5381 .53905 m
.54762 .53905 L
s
0 0 0 r
2 Mabswid
.54762 .53905 Mdot
.039 .916 .04 r
.5 Mabswid
.54762 .53905 m
.55714 .53905 L
s
0 0 0 r
2 Mabswid
.55714 .53905 Mdot
.039 .916 .04 r
.5 Mabswid
.55714 .53905 m
.59524 .53905 L
s
0 0 0 r
2 Mabswid
.59524 .53905 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .53905 m
.97619 .53905 L
s
0 0 0 r
2 Mabswid
.97619 .53905 Mdot
[(LP)] .54762 .02476 0 0 Mshowa
0 0 m
1 0 L
1 1.04 L
0 1.04 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.375, 293.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J00019B000`400?l00000o`00003oo`3ooolK
0?ooo`00o`3ooolK0?ooo`00o`3ooolK0?ooo`00o`3ooolK0?ooo`00U03oool5000000040?ooo`00
00000000000007d0oooo002E0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
O03oool009D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1l0?ooo`00U@3oool0
0`000000oooo0?ooo`030?ooo`<00000O03oool009D0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`00001k0?ooo`00U@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
000007/0oooo002D0?ooo`<000000`3oool4000007`0oooo003o0?oooa/0oooo003o0?oooa/0oooo
003o0?oooa/0oooo003o0?oooa/0oooo003o0?oooa/0oooo003o0?oooa/0oooo00060?ooo`030000
003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`050?ooo`001P3ooooo000000h000001`3o
ool000H0oooo00<000000?ooo`3oool0aP3ooolL000002L0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0a@3oool2000000T0Ogmo0P0000000`1oOgl00000000000020000
00T0Ogmo0P00000W0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0<@0
oooo00<0000007moO`000000201oOgl020000000Ogmo000000000000Ogmo0000001oOgl00000201o
Ogl00`000000oooo0000000W0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0<<0oooo00<0000007moO`1oOgl07000000W0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0<80oooo00D0000007moO`1oOgl0Ogmo0000000607moO`030000001oOgl0
Ogmo00<0000000@0Ogmo0000001oOgl000001P1oOgl01@000000oooo0?ooo`3oool0000002L0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0`@3oool00`000000Ogmo07mo
O`0207moO`030000001oOgl0Ogmo00<0Ogmo00H0000007moO`1oOgl0000007moO`00000207moO`03
0000001oOgl0000000D0Ogmo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0<00oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0207moO`050000001oOgl0Ogmo0000001oOgl00P00000207moO`03
0000001oOgl0000000@0Ogmo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0;l0oooo00<0000007moO`1oOgl0
101oOgl01@000000Ogmo07moO`1oOgl000000080Ogmo00D0000007moO`000000Ogmo0000000207mo
O`030000001oOgl0000000<0Ogmo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0;h0oooo00<0000007moO`1o
Ogl01@1oOgl010000000Ogmo07moO`00000207moO`030000001oOgl000000080Ogmo00H0000007mo
O`1oOgl0000007moO`00000207moO`030000003oool0oooo00D0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2m0?ooo`030000001oOgl0
Ogmo00H0Ogmo7000000W0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0;`0oooo00<0000007moO`1oOgl01`1oOgl200000080Ogmo00<0000007moO`000000101oOgl01@00
0000Ogmo07moO`000000Ogmo008000002@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0;`0oooo00<0000007moO`1oOgl01`1oOgl01000
0000Ogmo07moO`00000207moO`030000001oOgl0Ogmo0080Ogmo00D0000007moO`1oOgl0000007mo
O`02000000T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`2k0?ooo`030000001oOgl0Ogmo00L0Ogmo0P0000001@1oOgl0000007moO`1o
Ogl0000000D0Ogmo00H0000007moO`1oOgl0000007moO`00000:0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0^P3oool00`000000Ogmo
07moO`0707moO`040000001oOgl0000000000080Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`03000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`2i0?ooo`030000001oOgl0Ogmo00L0Ogmo00@0000007moO`1oOgl0
00000P1oOgl00`000000Ogmo07moO`0507moO`060000001oOgl0Ogmo0000003oool000002P3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0;P0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`020000000307moO`000000Ogmo
00L0Ogmo00H0000007moO`00000000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0]`3oool00`000000Ogmo07moO`07
07moO`050000001oOgl0Ogmo0000001oOgl00P00000907moO`80000000@0oooo0000003oool00000
2P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0;H0oooo00<0000007moO`1oOgl01`1oOgl010000000Ogmo07moO`00000207moOa`00000
9`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2e0?ooo`030000001o
Ogl0Ogmo00L0Ogmo00@0000007moO`1oOgl000000P1oOgl2000000T0Ogmo0P0000020?ooo`030000
003oool0000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`2d0?ooo`030000001oOgl0Ogmo00L0Ogmo00@0000007moO`1oOgl00000
0P1oOgl00`000000Ogmo0000000807moO`030000003oool000000080oooo00<000000?ooo`000000
2P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0;<0oooo00<0000007moO`1oOgl01`1oOgl010000000Ogmo07moO`00000207moO`040000
001oOgl0Ogmo000000L0Ogmo00@000000?ooo`3oool000000P3oool00`000000oooo0000000:0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0/P3oool00`000000Ogmo07moO`0707moO`040000001oOgl0Ogmo00000080Ogmo00D0000007mo
O`1oOgl0Ogmo0000000607moO`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0000
000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0/P3oool00`000000Ogmo07moO`0707moO`040000001oOgl0Ogmo00000080Ogmo00D0
000007moO`1oOgl0Ogmo0000000607moO`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0000000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0/@3oool00`000000Ogmo07moO`0707moO`040000001oOgl0Ogmo00000080
Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0080
oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0/03oool00`000000Ogmo07moO`0707mo
O`040000001oOgl0Ogmo00000080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`02
07moO`030000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0[`3o
ool00`000000Ogmo07moO`0707moO`040000001oOgl0Ogmo00000080Ogmo00<0000007moO`1oOgl0
101oOgl01@000000Ogmo07moO`1oOgl0000000H0oooo00H000000?ooo`3oool000000?ooo`00000:
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0[`3oool00`000000Ogmo07moO`0707moO`040000001oOgl0Ogmo00000080Ogmo00<00000
07moO`1oOgl0101oOglL000002L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0[P3oool00`000000Ogmo07moO`0707moO`040000001oOgl0Ogmo00000080Ogmo00<00000
07moO`1oOgl01@1oOgl010000000Ogmo07moO`0000070?ooo`060000003oool0oooo0000003oool0
00002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0:d0oooo00<0000007moO`1oOgl01`1oOgl010000000Ogmo07moO`00000207moO`03
0000001oOgl0Ogmo00H0Ogmo00<0000007moO`000000203oool01P000000oooo0?ooo`000000oooo
000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`2/0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`00
0000Ogmo07moO`0707moO`8000002@3oool01P000000oooo0?ooo`000000oooo000000X0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2[
0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`08
07moO`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z`3o
ool00`000000Ogmo07moO`0707moO`040000001oOgl0Ogmo00000080Ogmo00<0000007moO`1oOgl0
201oOgl00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:X0
oooo00<0000007moO`1oOgl01`1oOgl010000000Ogmo07moO`00000207moO`030000001oOgl0Ogmo
00P0Ogmo0P00000:0?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:T0oooo00<00000
07moO`1oOgl0201oOgl00`000000Ogmo0000000207moO`030000001oOgl0Ogmo00P0Ogmo00<00000
0?ooo`0000002P3oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`030000001o
Ogl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`040000003o
ool0oooo000000X0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`000000
Ogmo07moO`0707moO`040000001oOgl0Ogmo00000080Ogmo00<0000007moO`1oOgl0201oOgl01000
0000oooo0?ooo`00000:0?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:L0oooo00<0
000007moO`1oOgl01`1oOgl010000000Ogmo07moO`00000207moO`030000001oOgl0Ogmo00P0Ogmo
00D000000?ooo`3oool0oooo0000000:0?ooo`060000003oool0oooo0000003oool000002P3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0:H0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000000207moO`030000001oOgl0Ogmo
00P0Ogmo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo
0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0:D0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo00000002
07moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool00`3ooolL000002L0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Y03oool00`000000Ogmo07moO`0807mo
O`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Y03oool0
0`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?oo
o`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0X`3oool00`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0
000007moO`1oOgl0201oOgl00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00H0
00000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0XP3oool00`000000Ogmo07moO`0807moO`030000
001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0X@3oool00`000000
Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0X@3oool00`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0000007mo
O`1oOgl0201oOgl00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00H000000?oo
o`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0X03oool00`000000Ogmo07moO`0807moO`030000001oOgl0
00000080Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0X03oool00`000000Ogmo07mo
O`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
W`3oool00`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0
201oOgl00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool0
00000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0WP3oool00`000000Ogmo07moO`0807moO`030000001oOgl000000080
Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0
oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0WP3oool00`000000Ogmo07moO`0807mo
O`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0W@3oool0
0`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?oo
o`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0W@3oool00`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0
000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0;0?oooa`000009`3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`2L0?ooo`030000001oOgl0Ogmo00P0Ogmo00<00000
07moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2L0?ooo`030000001o
Ogl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`2K0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo
07moO`0807moO`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool01P000000oooo
0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`2J0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`00
00000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2J0?ooo`030000001oOgl0Ogmo
00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2I
0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`08
07moO`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`00
0000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`2I0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1o
Ogl00`000000Ogmo07moO`0807moO`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203o
ool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2H0?ooo`030000001oOgl0Ogmo00P0Ogmo
00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo0100oooo
00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2H0?ooo`03
0000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo
000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`2G0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`00
0000Ogmo07moO`0807moO`030000003oool0oooo0140oooo00<000000?ooo`3oool0203oool01P00
0000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`2G0?ooo`030000001oOgl0Ogmo00P0Ogmo00<00000
07moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2F0?ooo`030000001o
Ogl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`2E0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo
07moO`0807moO`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool01P000000oooo
0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`2E0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`00
00000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2D0?ooo`030000001oOgl0Ogmo
00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo
01@0oooo7000000W0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo09@0
oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000000207moO`030000001oOgl0Ogmo00P0
Ogmo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000
003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo09<0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000000207mo
O`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`080?oo
o`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo09<0oooo00<0000007moO`1oOgl0201oOgl0
0`000000Ogmo0000000207moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo09<0oooo00<0
000007moO`1oOgl01`1oOgl010000000Ogmo07moO`00000207moO`030000001oOgl0Ogmo00L0Ogmo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003o
ool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0980oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000000207moO`03
0000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`06
0000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0980oooo00<0000007moO`1oOgl01`1oOgl01000
0000Ogmo07moO`00000207moO`030000001oOgl0Ogmo00L0Ogmo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0940oooo00<0
000007moO`1oOgl0201oOgl00`000000Ogmo0000000207moO`030000001oOgl0Ogmo00P0Ogmo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool0
00002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0940oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000000207moO`030000
001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`060000
003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0940oooo00<0000007moO`1oOgl01`1oOgl010000000
Ogmo07moO`00000207moO`030000001oOgl0Ogmo00L0Ogmo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0900oooo00<00000
07moO`1oOgl0201oOgl00`000000Ogmo0000000207moO`030000001oOgl0Ogmo00P0Ogmo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool00000
2P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0900oooo00<0000007moO`1oOgl01`1oOgl010000000Ogmo07moO`00000207moO`030000
001oOgl0Ogmo00L0Ogmo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`080?ooo`060000
003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08l0oooo00<0000007moO`1oOgl0201oOgl00`000000
Ogmo0000000207moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08l0oooo00<0000007mo
O`1oOgl01`1oOgl010000000Ogmo07moO`00000207moO`030000001oOgl0Ogmo00L0Ogmo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool00000
2P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08h0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000000207moO`030000001o
Ogl0Ogmo00P0Ogmo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`080?ooo`060000003o
ool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08h0oooo00<0000007moO`1oOgl01`1oOgl010000000Ogmo
07moO`00000207moO`030000001oOgl0Ogmo00L0Ogmo00<000000?ooo`3oool06`3ooolL000002L0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0SP3oool00`000000Ogmo
07moO`0707moO`040000001oOgl0Ogmo00000080Ogmo00<0000007moO`1oOgl01`1oOgl00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0S@3oool00`000000Ogmo07moO`0707moO`040000001oOgl0Ogmo00000080Ogmo00<00000
07moO`1oOgl01`1oOgl00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00P0oooo00H00000
0?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0S@3oool00`000000Ogmo07moO`0707moO`040000001o
Ogl0Ogmo00000080Ogmo00<0000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0S03oool00`000000
Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0S03oool00`000000Ogmo07moO`0707moO`040000001oOgl0Ogmo00000080Ogmo00<00000
07moO`1oOgl01`1oOgl00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00P0oooo00H00000
0?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0S03oool00`000000Ogmo07moO`0707moO`040000001o
Ogl0Ogmo00000080Ogmo00<0000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0R`3oool00`000000
Ogmo07moO`0707moO`040000001oOgl0Ogmo00000080Ogmo00<0000007moO`1oOgl01`1oOgl00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00
000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0R`3oool00`000000Ogmo07moO`0707moO`040000001oOgl0Ogmo00000080Ogmo00<0
000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00P0oooo00H0
00000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0R`3oool00`000000Ogmo07moO`0707moO`040000
001oOgl0Ogmo00000080Ogmo00<0000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0RP3oool00`00
0000Ogmo07moO`0707moO`040000001oOgl0Ogmo00000080Ogmo00<0000007moO`1oOgl01`1oOgl0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?oo
o`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0RP3oool00`000000Ogmo07moO`0707moO`040000001oOgl0Ogmo00000080Ogmo
00<0000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00P0oooo
00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0RP3oool00`000000Ogmo07moO`0707moO`04
0000001oOgl0Ogmo00000080Ogmo00<0000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0R@3oool0
0`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?oo
o`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0R@3oool00`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0
000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00P0oooo00H0
00000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0R@3oool00`000000Ogmo07moO`0707moO`040000
001oOgl0Ogmo00000080Ogmo00<0000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0R@3oool00`00
0000Ogmo07moO`0707moO`040000001oOgl0Ogmo00000080Ogmo00<0000007moO`1oOgl01`1oOgl0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?oo
o`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0R03oool00`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0
000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0P0?oooa`000009`3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`280?ooo`030000001oOgl0Ogmo00P0Ogmo00<00000
07moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`280?ooo`030000001o
Ogl0Ogmo00L0Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000Ogmo07moO`0707moO`030000
003oool0oooo0240oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo0000
00X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`280?ooo`030000001oOgl0Ogmo00L0Ogmo00@0000007moO`1oOgl000000P1oOgl00`00
0000Ogmo07moO`0707moO`030000003oool0oooo0240oooo00<000000?ooo`3oool0203oool01P00
0000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`030000001oOgl0Ogmo00P0Ogmo00<00000
07moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`030000001o
Ogl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`270?ooo`030000001oOgl0Ogmo00L0Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000
Ogmo07moO`0707moO`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool01P000000
oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007mo
O`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo0280oooo00<000000?oo
o`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0
Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0
oooo0280oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07mo
O`0807moO`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool01P000000oooo0?oo
o`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`000000
0P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo0280oooo00<000000?ooo`3oool0
203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`250?ooo`030000001oOgl0Ogmo00P0
Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`250?oo
o`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807mo
O`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000
oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`250?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl0
0`000000Ogmo07moO`0807moO`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool0
1P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`250?ooo`030000001oOgl0Ogmo00P0Ogmo00<0
000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`250?ooo`030000
001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo0000
00X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`250?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000
Ogmo07moO`0807moO`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool01P000000
oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`250?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007mo
O`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo02<0oooo7000000W0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08D0oooo00<0000007moO`1o
Ogl0201oOgl00`000000Ogmo0000000207moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08@0oooo00<0000007moO`1oOgl0201oOgl01P000000Ogmo07moO`000000Ogmo000000X0Ogmo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool0
00002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08@0oooo00<0000007moO`1oOgl0201oOgl01P000000Ogmo07moO`000000Ogmo0000
00X0Ogmo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo
0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08@0oooo00<0000007moO`1oOgl0201oOgl01P000000Ogmo07moO`00
0000Ogmo000000X0Ogmo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`060000
003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08@0oooo00<0000007moO`1oOgl0201oOgl01P000000
Ogmo07moO`000000Ogmo000000X0Ogmo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`08
0?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08@0oooo00<0000007moO`1oOgl0201o
Ogl01P000000Ogmo07moO`000000Ogmo000000X0Ogmo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08@0oooo00<0000007mo
O`1oOgl0201oOgl00`000000Ogmo0000000207moO`030000001oOgl0Ogmo00P0Ogmo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08@0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000000207moO`030000001oOgl0
Ogmo00P0Ogmo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`060000003oool0
oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08@0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000
000207moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`080?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08@0oooo00<0000007moO`1oOgl0
201oOgl00`000000Ogmo0000000207moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08@0
oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000000207moO`030000001oOgl0Ogmo00P0
Ogmo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000
003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08@0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000000207mo
O`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?oo
o`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08<0oooo00<0000007moO`1oOgl0201oOgl0
1P000000Ogmo07moO`000000Ogmo000000X0Ogmo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08<0oooo00<0000007moO`1o
Ogl0201oOgl01P000000Ogmo07moO`000000Ogmo000000X0Ogmo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08<0oooo00<0
000007moO`1oOgl0201oOgl01P000000Ogmo07moO`000000Ogmo000000X0Ogmo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08<0oooo00<0000007moO`1oOgl0201oOgl01P000000Ogmo07moO`000000Ogmo000000X0Ogmo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool0
00002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08<0oooo0P00000807moO`80000000@0Ogmo000000000000Ogmo0P00000807moO`80
00009`3oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool0
0`000000oooo0?ooo`0U0?ooo`8000001P3oool000H0oooo00<000000?ooo`3oool0603ooome00WZ
2P0400000009jPX02NX:000000`02NX:00<0000000WZ2P09jPX0J@09jPX2000000H0oooo00060?oo
o`030000003oool0oooo08<0oooo00<0000007moO`1oOgl0201oOgl01P000000Ogmo07moO`000000
Ogmo000000X0Ogmo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`060000003o
ool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08<0oooo00<0000007moO`1oOgl0201oOgl01P000000Ogmo
07moO`000000Ogmo000000X0Ogmo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?oo
o`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08<0oooo00<0000007moO`1oOgl0201oOgl0
1P000000Ogmo07moO`000000Ogmo000000X0Ogmo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08<0oooo00<0000007moO`1o
Ogl0201oOgl01P000000Ogmo07moO`000000Ogmo000000X0Ogmo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08<0oooo00<0
000007moO`1oOgl0201oOgl01P000000Ogmo07moO`000000Ogmo000000X0Ogmo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08@0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000000207moO`030000001oOgl0Ogmo
00P0Ogmo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo
0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08@0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo00000002
07moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`08
0?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08@0oooo00<0000007moO`1oOgl0201o
Ogl00`000000Ogmo0000000207moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08@0oooo
00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000000207moO`030000001oOgl0Ogmo00P0Ogmo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003o
ool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08@0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000000207moO`03
0000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`06
0000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08@0oooo00<0000007moO`1oOgl0201oOgl00`00
0000Ogmo0000000207moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08@0oooo00<00000
07moO`1oOgl0201oOgl01P000000Ogmo07moO`000000Ogmo000000X0Ogmo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08@0
oooo00<0000007moO`1oOgl0201oOgl01P000000Ogmo07moO`000000Ogmo000000X0Ogmo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool00000
2P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08@0oooo00<0000007moO`1oOgl0201oOgl01P000000Ogmo07moO`000000Ogmo000000X0
Ogmo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000
003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08@0oooo00<0000007moO`1oOgl0201oOgl01P000000Ogmo07moO`000000
Ogmo000000X0Ogmo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`060000003o
ool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08@0oooo00<0000007moO`1oOgl0201oOgl01P000000Ogmo
07moO`000000Ogmo000000X0Ogmo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?oo
o`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08D0oooo00<0000007moO`1oOgl0201oOgl0
0`000000Ogmo0000000207moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool08`3ooolL
000002L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q@3oool00`00
0000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00
000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<00000
07moO`1oOgl0201oOgl00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo00H00000
0?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0Q@3oool00`000000Ogmo07moO`0807moO`030000001o
Ogl000000080Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q@3oool00`000000Ogmo
07moO`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0Q@3oool00`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1o
Ogl0201oOgl00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3o
ool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0Q@3oool00`000000Ogmo07moO`0807moO`030000001oOgl00000
0080Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q@3oool00`000000Ogmo07moO`08
07moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201o
Ogl00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool00000
0?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo
00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo
00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000Ogmo07moO`0807moO`03
0000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`00
0000Ogmo07moO`0707moO`040000001oOgl0Ogmo00000080Ogmo00<0000007moO`1oOgl01`1oOgl0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?oo
o`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0Q`3oool00`000000Ogmo07moO`0707moO`040000001oOgl0Ogmo00000080Ogmo
00<0000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo
00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`000000Ogmo07moO`0807moO`03
0000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`00
0000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00
000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0R03oool00`000000Ogmo07moO`0707moO`040000001oOgl0Ogmo00000080Ogmo00<0
000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00P0oooo00H0
00000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0R03oool00`000000Ogmo07moO`0707moO`040000
001oOgl0Ogmo00000080Ogmo00<0000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0R03oool00`00
0000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl00`00
0000oooo0?ooo`0P0?oooa`000009`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`280?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000
Ogmo07moO`0807moO`030000003oool0oooo0200oooo00<000000?ooo`3oool0203oool01P000000
oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`290?ooo`030000001oOgl0Ogmo00L0Ogmo00@0000007mo
O`1oOgl000000P1oOgl00`000000Ogmo07moO`0707moO`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`290?ooo`030000001o
Ogl0Ogmo00L0Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000Ogmo07moO`0707moO`030000
003oool0oooo0200oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo0000
00X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`290?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000
Ogmo07moO`0807moO`030000003oool0oooo01l0oooo00<000000?ooo`3oool0203oool01P000000
oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`2:0?ooo`030000001oOgl0Ogmo00L0Ogmo00@0000007mo
O`1oOgl000000P1oOgl00`000000Ogmo07moO`0707moO`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2:0?ooo`030000001o
Ogl0Ogmo00L0Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000Ogmo07moO`0707moO`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo0000
00X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`2:0?ooo`030000001oOgl0Ogmo00L0Ogmo00@0000007moO`1oOgl000000P1oOgl00`00
0000Ogmo07moO`0707moO`030000003oool0oooo01l0oooo00<000000?ooo`3oool0203oool01P00
0000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`2:0?ooo`030000001oOgl0Ogmo00L0Ogmo00@00000
07moO`1oOgl000000P1oOgl00`000000Ogmo07moO`0707moO`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2;0?ooo`030000
001oOgl0Ogmo00L0Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000Ogmo07moO`0707moO`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo
000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`2;0?ooo`030000001oOgl0Ogmo00L0Ogmo00@0000007moO`1oOgl000000P1oOgl0
0`000000Ogmo07moO`0707moO`030000003oool0oooo01h0oooo00<000000?ooo`3oool0203oool0
1P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2;0?ooo`030000001oOgl0Ogmo00L0Ogmo00@0
000007moO`1oOgl000000P1oOgl00`000000Ogmo07moO`0707moO`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2<0?ooo`03
0000001oOgl0Ogmo00L0Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000Ogmo07moO`0707mo
O`030000003oool0oooo01d0oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000
oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`2<0?ooo`030000001oOgl0Ogmo00L0Ogmo00@0000007moO`1oOgl000000P1o
Ogl00`000000Ogmo07moO`0707moO`030000003oool0oooo01d0oooo00<000000?ooo`3oool0203o
ool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2<0?ooo`030000001oOgl0Ogmo00P0Ogmo
00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2=0?ooo`03
0000001oOgl0Ogmo00L0Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000Ogmo07moO`0707mo
O`030000003oool0oooo01`0oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000
oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`2=0?ooo`030000001oOgl0Ogmo00L0Ogmo00@0000007moO`1oOgl000000P1o
Ogl00`000000Ogmo07moO`0707moO`030000003oool0oooo01`0oooo00<000000?ooo`3oool0203o
ool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2>0?ooo`030000001oOgl0Ogmo00L0Ogmo
00@0000007moO`1oOgl000000P1oOgl00`000000Ogmo07moO`0707moO`030000003oool0oooo01/0
oooo7000000W0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08h0oooo
00<0000007moO`1oOgl01`1oOgl010000000Ogmo07moO`00000207moO`030000001oOgl0Ogmo00L0
Ogmo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000
003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08h0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000000207mo
O`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`080?oo
o`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08l0oooo00<0000007moO`1oOgl01`1oOgl0
10000000Ogmo07moO`00000207moO`030000001oOgl0Ogmo00L0Ogmo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08l0oooo
00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000000207moO`030000001oOgl0Ogmo00P0Ogmo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003o
ool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0900oooo00<0000007moO`1oOgl01`1oOgl010000000Ogmo07moO`00000207mo
O`030000001oOgl0Ogmo00L0Ogmo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`080?oo
o`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0900oooo00<0000007moO`1oOgl01`1oOgl0
10000000Ogmo07moO`00000207moO`030000001oOgl0Ogmo00L0Ogmo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0900oooo
00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000000207moO`030000001oOgl0Ogmo00P0Ogmo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003o
ool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0940oooo00<0000007moO`1oOgl01`1oOgl010000000Ogmo07moO`00000207mo
O`030000001oOgl0Ogmo00L0Ogmo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`080?oo
o`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0940oooo00<0000007moO`1oOgl0201oOgl0
0`000000Ogmo0000000207moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0940oooo00<0
000007moO`1oOgl0201oOgl00`000000Ogmo0000000207moO`030000001oOgl0Ogmo00P0Ogmo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool0
00002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0980oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000000207moO`030000
001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`060000
003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0980oooo00<0000007moO`1oOgl0201oOgl00`000000
Ogmo0000000207moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo09<0oooo00<0000007mo
O`1oOgl01`1oOgl010000000Ogmo07moO`00000207moO`030000001oOgl0Ogmo00L0Ogmo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool00000
2P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo09<0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000000207moO`030000001o
Ogl0Ogmo00P0Ogmo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`080?ooo`060000003o
ool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo09<0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo
0000000207moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`080?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo09@0oooo00<0000007moO`1o
Ogl0201oOgl00`000000Ogmo0000000207moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3o
ool0503ooolL000002L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
U03oool00`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0
201oOgl00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool0
00000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0U@3oool00`000000Ogmo07moO`0807moO`030000001oOgl000000080
Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0
oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0U@3oool00`000000Ogmo07moO`0807mo
O`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0UP3oool0
0`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?oo
o`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0U`3oool00`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0
000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo00H0
00000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0U`3oool00`000000Ogmo07moO`0807moO`030000
001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0V03oool00`000000
Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0V03oool00`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0000007mo
O`1oOgl0201oOgl00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo00H000000?oo
o`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0V@3oool00`000000Ogmo07moO`0807moO`030000001oOgl0
00000080Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0VP3oool00`000000Ogmo07mo
O`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
VP3oool00`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0
201oOgl00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool0
00000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0V`3oool00`000000Ogmo07moO`0807moO`030000001oOgl000000080
Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0
oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0V`3oool00`000000Ogmo07moO`0807mo
O`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0W03oool0
0`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl0
0`000000oooo0?ooo`0<0?oooa`000009`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`2M0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`00
0000Ogmo07moO`0807moO`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool01P00
0000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`2M0?ooo`030000001oOgl0Ogmo00P0Ogmo00<00000
07moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2N0?ooo`030000001o
Ogl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`2N0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo
07moO`0807moO`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool01P000000oooo
0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`2O0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`00
00000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2P0?ooo`030000001oOgl0Ogmo
00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2P
0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`08
07moO`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`00
0000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`2Q0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1o
Ogl00`000000Ogmo07moO`0807moO`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2Q0?ooo`030000001oOgl0Ogmo00P0Ogmo
00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2R0?ooo`03
0000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo
000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`2S0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`00
0000Ogmo07moO`0807moO`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool01P00
0000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`2T0?ooo`030000001oOgl0Ogmo00P0Ogmo00<00000
07moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2T0?ooo`030000001o
Ogl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003o
ool0oooo00@0oooo7000000W0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0:D0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000000207moO`030000001oOgl0
Ogmo00P0Ogmo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`060000003oool0
oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0:H0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo0000
000207moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`080?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:L0oooo00<0000007moO`1oOgl0
1`1oOgl010000000Ogmo07moO`00000207moO`030000001oOgl0Ogmo00P0Ogmo00D000000?ooo`3o
ool0oooo0000000:0?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<00000
07moO`1oOgl01`1oOgl010000000Ogmo07moO`00000207moO`030000001oOgl0Ogmo00P0Ogmo00@0
00000?ooo`3oool000002P3oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`03
0000001oOgl0Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`04
0000003oool0oooo000000X0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z@3oool0
0`000000Ogmo07moO`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl0201oOgl0
0`000000oooo0000000:0?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:X0oooo00<0
000007moO`1oOgl01`1oOgl010000000Ogmo07moO`00000207moO`030000001oOgl0Ogmo00P0Ogmo
0P00000:0?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:/0oooo00<0000007moO`1o
Ogl01`1oOgl010000000Ogmo07moO`00000207moO`030000001oOgl0Ogmo00P0Ogmo00<000000?oo
o`3oool0203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2[0?ooo`030000001oOgl0
Ogmo00P0Ogmo00<0000007moO`0000000P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0
oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0[03oool00`000000Ogmo07mo
O`0807moO`030000001oOgl000000080Ogmo00<0000007moO`1oOgl01`1oOgl2000000T0oooo00H0
00000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0[@3oool00`000000Ogmo07moO`0707moO`040000
001oOgl0Ogmo00000080Ogmo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo000000080?ooo`06
0000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0:h0oooo00<0000007moO`1oOgl01`1oOgl01000
0000Ogmo07moO`00000207moO`030000001oOgl0Ogmo00D0Ogmo7000000W0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0:l0oooo00<0000007moO`1oOgl01`1oOgl01000
0000Ogmo07moO`00000207moO`030000001oOgl0Ogmo00@0Ogmo00D0000007moO`1oOgl0Ogmo0000
00060?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:l0oooo00<0000007moO`1oOgl0
1`1oOgl010000000Ogmo07moO`00000207moO`030000001oOgl0Ogmo00@0Ogmo00D0000007moO`1o
Ogl0Ogmo000000060?ooo`060000003oool0oooo0000003oool000002P3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0;00oooo00<00000
07moO`1oOgl01`1oOgl010000000Ogmo07moO`00000207moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool0
00002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0;40oooo00<0000007moO`1oOgl01`1oOgl010000000Ogmo07moO`00000207moO`03
0000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`020?ooo`06
0000003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0;80oooo00<0000007moO`1oOgl01`1oOgl01000
0000Ogmo07moO`00000207moO`050000001oOgl0Ogmo07moO`0000001P1oOgl01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0;80oooo00<0000007moO`1oOgl01`1o
Ogl010000000Ogmo07moO`00000207moO`050000001oOgl0Ogmo07moO`0000001P1oOgl01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0;<0oooo00<0000007moO`1o
Ogl01`1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo000000L0Ogmo00@00000
0?ooo`3oool000000P3oool00`000000oooo0000000:0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0]03oool00`000000Ogmo07moO`07
07moO`040000001oOgl0Ogmo00000080Ogmo00<0000007moO`000000201oOgl00`000000oooo0000
00020?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`2e0?ooo`030000001oOgl0Ogmo00L0Ogmo00@00000
07moO`1oOgl000000P1oOgl2000000T0Ogmo0P0000020?ooo`030000003oool0000000X0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2f
0?ooo`030000001oOgl0Ogmo00L0Ogmo00@0000007moO`1oOgl000000P1oOglL000002L0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0]`3oool00`000000Ogmo07moO`07
07moO`050000001oOgl0Ogmo0000001oOgl00P00000907moO`80000000@0oooo0000003oool00000
2P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0;P0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`020000000307moO`00
0000Ogmo00L0Ogmo00H0000007moO`00000000000?ooo`00000:0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0^@3oool00`000000Ogmo
07moO`0707moO`040000001oOgl0Ogmo00000080Ogmo00<0000007moO`1oOgl01@1oOgl01P000000
Ogmo07moO`000000oooo000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`2i0?ooo`030000001oOgl0Ogmo00P0Ogmo00H0000007mo
O`000000000007moO`00000707moO`060000001oOgl0Ogmo0000003oool000002P3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0;X0oooo
00<0000007moO`1oOgl0201oOgl20000000407moO`000000Ogmo000000H0Ogmo00<0000007moO`1o
Ogl00`00000:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0^`3oool00`000000Ogmo07moO`0807moO`060000001oOgl0Ogmo0000001o
Ogl000001@1oOgl01P000000Ogmo07moO`000000Ogmo000000X0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2l0?ooo`030000001oOgl0
Ogmo00L0Ogmo7000000W0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0;d0oooo00<0000007moO`1oOgl01P1oOgl200000080Ogmo00@0000007moO`1oOgl000000`1oOgl0
20000000Ogmo07moO`000000Ogmo0000001oOgl00000203oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0;h0oooo00<0000007moO`1oOgl0
1@1oOgl00`000000Ogmo0000000207moO`040000001oOgl0Ogmo00000080Ogmo00H0000007moO`1o
Ogl0000007moO`00000207moO`030000003oool0oooo00D0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2o0?ooo`030000001oOgl0Ogmo
00@0Ogmo00@0000007moO`1oOgl000000P1oOgl01P000000Ogmo07moO`000000Ogmo00000080Ogmo
00<0000007moO`0000000`1oOgl00`000000oooo0?ooo`040?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0_`3oool00`000000Ogmo07mo
O`0407moO`050000001oOgl0Ogmo07moO`0000000P1oOgl01@000000Ogmo0000001oOgl000000080
Ogmo00<0000007moO`0000000`1oOgl00`000000oooo0?ooo`040?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0`03oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00D0000007moO`1oOgl0000007moO`0200000080
Ogmo00<0000007moO`000000101oOgl00`000000oooo0?ooo`030?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0`@3oool00`000000Ogmo
07moO`0207moOa`000009`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`320?ooo`050000001oOgl0Ogmo07moO`0000001P1oOgl00`000000Ogmo07moO`030000000407mo
O`000000Ogmo000000H0Ogmo00D000000?ooo`3oool0oooo0000000W0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0<<0oooo00@0000007moO`1oOgl000001`1oOgl01@00
0000Ogmo07moO`000000Ogmo0080000000<0Ogmo0000001oOgl01P1oOgl010000000oooo0?ooo`00
000W0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0<@0oooo00<00000
07moO`0000006`00000W0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0<D0oooo0P00000907moO`80000000<0Ogmo0000000000000P00000907moO`8000009`3oool00`00
0000oooo0?ooo`050?ooo`001P3ooooo000000h000001`3oool00?l0oooo6`3oool00?l0oooo6`3o
ool00?l0oooo6`3oool00?l0oooo6`3oool00?l0oooo6`3oool00?l0oooo6`3oool00001\
\>"],
  ImageRangeCache->{{{0, 281.375}, {292.625, 0}} -> {-2.50089, -56.6, \
0.373174, 0.373174}},
  CellTags->"LinearPolarizer with user-defined surface"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{\({1, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", \({1.`, 0.`, 0.`}\), ",", 
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 2}\), ",", 
            StyleBox["1.52584130859896438`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "100.`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 3}\), ",", 
            StyleBox["1.51947243256730679`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "100.`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 4}\), ",", 
            StyleBox["1.51947243256730679`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "50.0000000000000177`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.707106781186547461`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.70710678118654755`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 5}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "50.0000000000000177`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.707106781186547461`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.70710678118654755`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({2, 1}\), ",", 
            StyleBox["1.52584130859896438`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "50.0000000000000177`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.707106781186547461`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.70710678118654755`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["LinearPolarizer in beamsplitting mode: SplitRays->Reflection", "Section",
  CellTags->"LinearPolarizer in beamsplitting mode SplitRays->Reflection"],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{Move[SingleRay[Polarization->{1,1,0}],10],
Move[LinearPolarizer[0,50,CenterThickness->1, \
Transmittance->{100,100},SplitRays->Reflection],{50,0,45}], \
Boundary[100]},PlotType->TopView];
ReadRays[sys,{{ComponentNumber,SurfaceNumber},RefractiveIndex,RayTilt,\
Intensity,Polarization}]\
\>", "Input",
  CellTags->"LinearPolarizer in beamsplitting mode SplitRays->Reflection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.69866 .30807 -6 -4.5 ]
[.69866 .30807 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.66836 .33164 m
.67173 .33501 L
.64367 .36307 L
.6403 .3597 L
.66836 .33164 L
F
.6403 .3597 m
.64367 .36307 L
.61561 .39113 L
.61224 .38776 L
.6403 .3597 L
F
.61224 .38776 m
.61561 .39113 L
.58755 .41919 L
.58418 .41582 L
.61224 .38776 L
F
.58418 .41582 m
.58755 .41919 L
.55949 .44725 L
.55612 .44388 L
.58418 .41582 L
F
.55612 .44388 m
.55949 .44725 L
.53143 .47531 L
.52806 .47194 L
.55612 .44388 L
F
.52806 .47194 m
.53143 .47531 L
.50337 .50337 L
.5 .5 L
.52806 .47194 L
F
.5 .5 m
.50337 .50337 L
.47531 .53143 L
.47194 .52806 L
.5 .5 L
F
.47194 .52806 m
.47531 .53143 L
.44725 .55949 L
.44388 .55612 L
.47194 .52806 L
F
.44388 .55612 m
.44725 .55949 L
.41919 .58755 L
.41582 .58418 L
.44388 .55612 L
F
.41582 .58418 m
.41919 .58755 L
.39113 .61561 L
.38776 .61224 L
.41582 .58418 L
F
.38776 .61224 m
.39113 .61561 L
.36307 .64367 L
.3597 .6403 L
.38776 .61224 L
F
.3597 .6403 m
.36307 .64367 L
.33501 .67173 L
.33164 .66836 L
.3597 .6403 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.66836 .33164 m
.6403 .3597 L
.61224 .38776 L
.58418 .41582 L
.55612 .44388 L
.52806 .47194 L
.5 .5 L
.47194 .52806 L
.44388 .55612 L
.41582 .58418 L
.38776 .61224 L
.3597 .6403 L
.33164 .66836 L
.33501 .67173 L
.36307 .64367 L
.39113 .61561 L
.41919 .58755 L
.44725 .55949 L
.47531 .53143 L
.50337 .50337 L
.53143 .47531 L
.55949 .44725 L
.58755 .41919 L
.61561 .39113 L
.64367 .36307 L
.67173 .33501 L
.66836 .33164 L
s
.5 g
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
0 g
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.5 .5 L
s
.5 g
.67173 .33501 m
.67509 .33838 L
.64703 .36644 L
.64367 .36307 L
.67173 .33501 L
F
.64367 .36307 m
.64703 .36644 L
.61897 .3945 L
.61561 .39113 L
.64367 .36307 L
F
.61561 .39113 m
.61897 .3945 L
.59091 .42255 L
.58755 .41919 L
.61561 .39113 L
F
.58755 .41919 m
.59091 .42255 L
.56285 .45061 L
.55949 .44725 L
.58755 .41919 L
F
.55949 .44725 m
.56285 .45061 L
.53479 .47867 L
.53143 .47531 L
.55949 .44725 L
F
.53143 .47531 m
.53479 .47867 L
.50673 .50673 L
.50337 .50337 L
.53143 .47531 L
F
.50337 .50337 m
.50673 .50673 L
.47867 .53479 L
.47531 .53143 L
.50337 .50337 L
F
.47531 .53143 m
.47867 .53479 L
.45061 .56285 L
.44725 .55949 L
.47531 .53143 L
F
.44725 .55949 m
.45061 .56285 L
.42255 .59091 L
.41919 .58755 L
.44725 .55949 L
F
.41919 .58755 m
.42255 .59091 L
.3945 .61897 L
.39113 .61561 L
.41919 .58755 L
F
.39113 .61561 m
.3945 .61897 L
.36644 .64703 L
.36307 .64367 L
.39113 .61561 L
F
.36307 .64367 m
.36644 .64703 L
.33838 .67509 L
.33501 .67173 L
.36307 .64367 L
F
0 g
.67173 .33501 m
.64367 .36307 L
.61561 .39113 L
.58755 .41919 L
.55949 .44725 L
.53143 .47531 L
.50337 .50337 L
.47531 .53143 L
.44725 .55949 L
.41919 .58755 L
.39113 .61561 L
.36307 .64367 L
.33501 .67173 L
.33838 .67509 L
.36644 .64703 L
.3945 .61897 L
.42255 .59091 L
.45061 .56285 L
.47867 .53479 L
.50673 .50673 L
.53479 .47867 L
.56285 .45061 L
.59091 .42255 L
.61897 .3945 L
.64703 .36644 L
.67509 .33838 L
.67173 .33501 L
s
.5 g
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
0 g
.50337 .50337 m
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
s
.33164 .66836 m
.33308 .66692 L
.33738 .66262 L
.34446 .65554 L
.3542 .6458 L
.36643 .63357 L
.38095 .61905 L
.39751 .60249 L
.41582 .58418 L
.43557 .56443 L
.45643 .54357 L
.47802 .52198 L
.5 .5 L
.52198 .47802 L
.54357 .45643 L
.56443 .43557 L
.58418 .41582 L
.60249 .39751 L
.61905 .38095 L
.63357 .36643 L
.6458 .3542 L
.65554 .34446 L
.66262 .33738 L
.66692 .33308 L
.66836 .33164 L
.66692 .33308 L
.66262 .33738 L
.65554 .34446 L
.6458 .3542 L
.63357 .36643 L
.61905 .38095 L
.60249 .39751 L
.58418 .41582 L
.56443 .43557 L
.54357 .45643 L
.52198 .47802 L
.5 .5 L
.47802 .52198 L
.45643 .54357 L
.43557 .56443 L
.41582 .58418 L
.39751 .60249 L
.38095 .61905 L
.36643 .63357 L
.3542 .6458 L
.34446 .65554 L
.33738 .66262 L
.33308 .66692 L
.33164 .66836 L
s
.33501 .67173 m
.33645 .67029 L
.34075 .66599 L
.34782 .65891 L
.35756 .64917 L
.3698 .63694 L
.38432 .62241 L
.40088 .60586 L
.41919 .58755 L
.43894 .5678 L
.45979 .54694 L
.48139 .52534 L
.50337 .50337 L
.52534 .48139 L
.54694 .45979 L
.5678 .43894 L
.58755 .41919 L
.60586 .40088 L
.62241 .38432 L
.63694 .3698 L
.64917 .35756 L
.65891 .34782 L
.66599 .34075 L
.67029 .33645 L
.67173 .33501 L
.67029 .33645 L
.66599 .34075 L
.65891 .34782 L
.64917 .35756 L
.63694 .3698 L
.62241 .38432 L
.60586 .40088 L
.58755 .41919 L
.5678 .43894 L
.54694 .45979 L
.52534 .48139 L
.50337 .50337 L
.48139 .52534 L
.45979 .54694 L
.43894 .5678 L
.41919 .58755 L
.40088 .60586 L
.38432 .62241 L
.3698 .63694 L
.35756 .64917 L
.34782 .65891 L
.34075 .66599 L
.33645 .67029 L
.33501 .67173 L
s
.33838 .67509 m
.33982 .67365 L
.34411 .66936 L
.35119 .66228 L
.36093 .65254 L
.37317 .6403 L
.38769 .62578 L
.40424 .60922 L
.42255 .59091 L
.44231 .57116 L
.46316 .55031 L
.48476 .52871 L
.50673 .50673 L
.52871 .48476 L
.55031 .46316 L
.57116 .44231 L
.59091 .42255 L
.60922 .40424 L
.62578 .38769 L
.6403 .37317 L
.65254 .36093 L
.66228 .35119 L
.66936 .34411 L
.67365 .33982 L
.67509 .33838 L
.67365 .33982 L
.66936 .34411 L
.66228 .35119 L
.65254 .36093 L
.6403 .37317 L
.62578 .38769 L
.60922 .40424 L
.59091 .42255 L
.57116 .44231 L
.55031 .46316 L
.52871 .48476 L
.50673 .50673 L
.48476 .52871 L
.46316 .55031 L
.44231 .57116 L
.42255 .59091 L
.40424 .60922 L
.38769 .62578 L
.37317 .6403 L
.36093 .65254 L
.35119 .66228 L
.34411 .66936 L
.33982 .67365 L
.33838 .67509 L
s
.33164 .66836 m
.33501 .67173 L
.33645 .67029 L
.33308 .66692 L
.33164 .66836 L
s
.33308 .66692 m
.33645 .67029 L
.34075 .66599 L
.33738 .66262 L
.33308 .66692 L
s
.33738 .66262 m
.34075 .66599 L
.34782 .65891 L
.34446 .65554 L
.33738 .66262 L
s
.34446 .65554 m
.34782 .65891 L
.35756 .64917 L
.3542 .6458 L
.34446 .65554 L
s
.3542 .6458 m
.35756 .64917 L
.3698 .63694 L
.36643 .63357 L
.3542 .6458 L
s
.36643 .63357 m
.3698 .63694 L
.38432 .62241 L
.38095 .61905 L
.36643 .63357 L
s
.38095 .61905 m
.38432 .62241 L
.40088 .60586 L
.39751 .60249 L
.38095 .61905 L
s
.39751 .60249 m
.40088 .60586 L
.41919 .58755 L
.41582 .58418 L
.39751 .60249 L
s
.41582 .58418 m
.41919 .58755 L
.43894 .5678 L
.43557 .56443 L
.41582 .58418 L
s
.43557 .56443 m
.43894 .5678 L
.45979 .54694 L
.45643 .54357 L
.43557 .56443 L
s
.45643 .54357 m
.45979 .54694 L
.48139 .52534 L
.47802 .52198 L
.45643 .54357 L
s
.47802 .52198 m
.48139 .52534 L
.50337 .50337 L
.5 .5 L
.47802 .52198 L
s
.5 .5 m
.50337 .50337 L
.52534 .48139 L
.52198 .47802 L
.5 .5 L
s
.52198 .47802 m
.52534 .48139 L
.54694 .45979 L
.54357 .45643 L
.52198 .47802 L
s
.54357 .45643 m
.54694 .45979 L
.5678 .43894 L
.56443 .43557 L
.54357 .45643 L
s
.56443 .43557 m
.5678 .43894 L
.58755 .41919 L
.58418 .41582 L
.56443 .43557 L
s
.58418 .41582 m
.58755 .41919 L
.60586 .40088 L
.60249 .39751 L
.58418 .41582 L
s
.60249 .39751 m
.60586 .40088 L
.62241 .38432 L
.61905 .38095 L
.60249 .39751 L
s
.61905 .38095 m
.62241 .38432 L
.63694 .3698 L
.63357 .36643 L
.61905 .38095 L
s
.63357 .36643 m
.63694 .3698 L
.64917 .35756 L
.6458 .3542 L
.63357 .36643 L
s
.6458 .3542 m
.64917 .35756 L
.65891 .34782 L
.65554 .34446 L
.6458 .3542 L
s
.65554 .34446 m
.65891 .34782 L
.66599 .34075 L
.66262 .33738 L
.65554 .34446 L
s
.66262 .33738 m
.66599 .34075 L
.67029 .33645 L
.66692 .33308 L
.66262 .33738 L
s
.66692 .33308 m
.67029 .33645 L
.67173 .33501 L
.66836 .33164 L
.66692 .33308 L
s
.66836 .33164 m
.67173 .33501 L
.67029 .33645 L
.66692 .33308 L
.66836 .33164 L
s
.66692 .33308 m
.67029 .33645 L
.66599 .34075 L
.66262 .33738 L
.66692 .33308 L
s
.66262 .33738 m
.66599 .34075 L
.65891 .34782 L
.65554 .34446 L
.66262 .33738 L
s
.65554 .34446 m
.65891 .34782 L
.64917 .35756 L
.6458 .3542 L
.65554 .34446 L
s
.6458 .3542 m
.64917 .35756 L
.63694 .3698 L
.63357 .36643 L
.6458 .3542 L
s
.63357 .36643 m
.63694 .3698 L
.62241 .38432 L
.61905 .38095 L
.63357 .36643 L
s
.61905 .38095 m
.62241 .38432 L
.60586 .40088 L
.60249 .39751 L
.61905 .38095 L
s
.60249 .39751 m
.60586 .40088 L
.58755 .41919 L
.58418 .41582 L
.60249 .39751 L
s
.58418 .41582 m
.58755 .41919 L
.5678 .43894 L
.56443 .43557 L
.58418 .41582 L
s
.56443 .43557 m
.5678 .43894 L
.54694 .45979 L
.54357 .45643 L
.56443 .43557 L
s
.54357 .45643 m
.54694 .45979 L
.52534 .48139 L
.52198 .47802 L
.54357 .45643 L
s
.52198 .47802 m
.52534 .48139 L
.50337 .50337 L
.5 .5 L
.52198 .47802 L
s
.5 .5 m
.50337 .50337 L
.48139 .52534 L
.47802 .52198 L
.5 .5 L
s
.47802 .52198 m
.48139 .52534 L
.45979 .54694 L
.45643 .54357 L
.47802 .52198 L
s
.45643 .54357 m
.45979 .54694 L
.43894 .5678 L
.43557 .56443 L
.45643 .54357 L
s
.43557 .56443 m
.43894 .5678 L
.41919 .58755 L
.41582 .58418 L
.43557 .56443 L
s
.41582 .58418 m
.41919 .58755 L
.40088 .60586 L
.39751 .60249 L
.41582 .58418 L
s
.39751 .60249 m
.40088 .60586 L
.38432 .62241 L
.38095 .61905 L
.39751 .60249 L
s
.38095 .61905 m
.38432 .62241 L
.3698 .63694 L
.36643 .63357 L
.38095 .61905 L
s
.36643 .63357 m
.3698 .63694 L
.35756 .64917 L
.3542 .6458 L
.36643 .63357 L
s
.3542 .6458 m
.35756 .64917 L
.34782 .65891 L
.34446 .65554 L
.3542 .6458 L
s
.34446 .65554 m
.34782 .65891 L
.34075 .66599 L
.33738 .66262 L
.34446 .65554 L
s
.33738 .66262 m
.34075 .66599 L
.33645 .67029 L
.33308 .66692 L
.33738 .66262 L
s
.33308 .66692 m
.33645 .67029 L
.33501 .67173 L
.33164 .66836 L
.33308 .66692 L
s
.33501 .67173 m
.33838 .67509 L
.33982 .67365 L
.33645 .67029 L
.33501 .67173 L
s
.33645 .67029 m
.33982 .67365 L
.34411 .66936 L
.34075 .66599 L
.33645 .67029 L
s
.34075 .66599 m
.34411 .66936 L
.35119 .66228 L
.34782 .65891 L
.34075 .66599 L
s
.34782 .65891 m
.35119 .66228 L
.36093 .65254 L
.35756 .64917 L
.34782 .65891 L
s
.35756 .64917 m
.36093 .65254 L
.37317 .6403 L
.3698 .63694 L
.35756 .64917 L
s
.3698 .63694 m
.37317 .6403 L
.38769 .62578 L
.38432 .62241 L
.3698 .63694 L
s
.38432 .62241 m
.38769 .62578 L
.40424 .60922 L
.40088 .60586 L
.38432 .62241 L
s
.40088 .60586 m
.40424 .60922 L
.42255 .59091 L
.41919 .58755 L
.40088 .60586 L
s
.41919 .58755 m
.42255 .59091 L
.44231 .57116 L
.43894 .5678 L
.41919 .58755 L
s
.43894 .5678 m
.44231 .57116 L
.46316 .55031 L
.45979 .54694 L
.43894 .5678 L
s
.45979 .54694 m
.46316 .55031 L
.48476 .52871 L
.48139 .52534 L
.45979 .54694 L
s
.48139 .52534 m
.48476 .52871 L
.50673 .50673 L
.50337 .50337 L
.48139 .52534 L
s
.50337 .50337 m
.50673 .50673 L
.52871 .48476 L
.52534 .48139 L
.50337 .50337 L
s
.52534 .48139 m
.52871 .48476 L
.55031 .46316 L
.54694 .45979 L
.52534 .48139 L
s
.54694 .45979 m
.55031 .46316 L
.57116 .44231 L
.5678 .43894 L
.54694 .45979 L
s
.5678 .43894 m
.57116 .44231 L
.59091 .42255 L
.58755 .41919 L
.5678 .43894 L
s
.58755 .41919 m
.59091 .42255 L
.60922 .40424 L
.60586 .40088 L
.58755 .41919 L
s
.60586 .40088 m
.60922 .40424 L
.62578 .38769 L
.62241 .38432 L
.60586 .40088 L
s
.62241 .38432 m
.62578 .38769 L
.6403 .37317 L
.63694 .3698 L
.62241 .38432 L
s
.63694 .3698 m
.6403 .37317 L
.65254 .36093 L
.64917 .35756 L
.63694 .3698 L
s
.64917 .35756 m
.65254 .36093 L
.66228 .35119 L
.65891 .34782 L
.64917 .35756 L
s
.65891 .34782 m
.66228 .35119 L
.66936 .34411 L
.66599 .34075 L
.65891 .34782 L
s
.66599 .34075 m
.66936 .34411 L
.67365 .33982 L
.67029 .33645 L
.66599 .34075 L
s
.67029 .33645 m
.67365 .33982 L
.67509 .33838 L
.67173 .33501 L
.67029 .33645 L
s
.67173 .33501 m
.67509 .33838 L
.67365 .33982 L
.67029 .33645 L
.67173 .33501 L
s
.67029 .33645 m
.67365 .33982 L
.66936 .34411 L
.66599 .34075 L
.67029 .33645 L
s
.66599 .34075 m
.66936 .34411 L
.66228 .35119 L
.65891 .34782 L
.66599 .34075 L
s
.65891 .34782 m
.66228 .35119 L
.65254 .36093 L
.64917 .35756 L
.65891 .34782 L
s
.64917 .35756 m
.65254 .36093 L
.6403 .37317 L
.63694 .3698 L
.64917 .35756 L
s
.63694 .3698 m
.6403 .37317 L
.62578 .38769 L
.62241 .38432 L
.63694 .3698 L
s
.62241 .38432 m
.62578 .38769 L
.60922 .40424 L
.60586 .40088 L
.62241 .38432 L
s
.60586 .40088 m
.60922 .40424 L
.59091 .42255 L
.58755 .41919 L
.60586 .40088 L
s
.58755 .41919 m
.59091 .42255 L
.57116 .44231 L
.5678 .43894 L
.58755 .41919 L
s
.5678 .43894 m
.57116 .44231 L
.55031 .46316 L
.54694 .45979 L
.5678 .43894 L
s
.54694 .45979 m
.55031 .46316 L
.52871 .48476 L
.52534 .48139 L
.54694 .45979 L
s
.52534 .48139 m
.52871 .48476 L
.50673 .50673 L
.50337 .50337 L
.52534 .48139 L
s
.50337 .50337 m
.50673 .50673 L
.48476 .52871 L
.48139 .52534 L
.50337 .50337 L
s
.48139 .52534 m
.48476 .52871 L
.46316 .55031 L
.45979 .54694 L
.48139 .52534 L
s
.45979 .54694 m
.46316 .55031 L
.44231 .57116 L
.43894 .5678 L
.45979 .54694 L
s
.43894 .5678 m
.44231 .57116 L
.42255 .59091 L
.41919 .58755 L
.43894 .5678 L
s
.41919 .58755 m
.42255 .59091 L
.40424 .60922 L
.40088 .60586 L
.41919 .58755 L
s
.40088 .60586 m
.40424 .60922 L
.38769 .62578 L
.38432 .62241 L
.40088 .60586 L
s
.38432 .62241 m
.38769 .62578 L
.37317 .6403 L
.3698 .63694 L
.38432 .62241 L
s
.3698 .63694 m
.37317 .6403 L
.36093 .65254 L
.35756 .64917 L
.3698 .63694 L
s
.35756 .64917 m
.36093 .65254 L
.35119 .66228 L
.34782 .65891 L
.35756 .64917 L
s
.34782 .65891 m
.35119 .66228 L
.34411 .66936 L
.34075 .66599 L
.34782 .65891 L
s
.34075 .66599 m
.34411 .66936 L
.33982 .67365 L
.33645 .67029 L
.34075 .66599 L
s
.33645 .67029 m
.33982 .67365 L
.33838 .67509 L
.33501 .67173 L
.33645 .67029 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.11905 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.50513 .50161 L
s
0 0 0 r
2 Mabswid
.50513 .50161 Mdot
.039 .916 .04 r
.5 Mabswid
.50513 .50161 m
.51026 .50321 L
s
0 0 0 r
2 Mabswid
.51026 .50321 Mdot
.039 .916 .04 r
.5 Mabswid
.50513 .50161 m
.50352 .49648 L
s
0 0 0 r
2 Mabswid
.50352 .49648 Mdot
.039 .916 .04 r
.5 Mabswid
.51026 .50321 m
.97619 .50321 L
s
0 0 0 r
2 Mabswid
.97619 .50321 Mdot
.039 .916 .04 r
.5 Mabswid
.50352 .49648 m
.50352 .02381 L
s
0 0 0 r
2 Mabswid
.50352 .02381 Mdot
[(LP)] .69866 .30807 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
Q`3oool2000008H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3o
ool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`25
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?oo
o`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`03
00WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?oo
o`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?oo
o`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo
0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<0
2NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`27
0?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo
08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0
oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo
00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0
oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09
jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0
oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0
Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3o
ool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool0
0`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3o
ool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ
2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3o
ool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`25
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?oo
o`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`03
00WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?oo
o`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?oo
o`0300WZ2P3oool0oooo02l0oooo1@000000103oool0000000000000001=0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0<03oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`0`0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`270?ooo`0300WZ2P3oool0oooo0300oooo00<000000?ooo`3oool00`3oool3000004`0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo
0?ooo`0`0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000B`3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo0300oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00001;0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0;`3oool3000000<0oooo
1000001<0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<0
2NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`27
0?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0;03oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0
:`3oool00`000000Ogmo0000001G0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08L0oooo00<02NX:0?ooo`3oool0:P3oool01@000000Ogmo0000001oOgl0000005H0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?oo
o`0Y0?ooo`050000001oOgl0000007moO`000000E`3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo02P0oooo00D0000007moO`000000Ogmo
0000001H0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<0
2NX:0?ooo`3oool09`3oool01@000000Ogmo0000001oOgl0000005T0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`0V0?ooo`050000001o
Ogl0000007moO`000000FP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`270?ooo`0300WZ2P3oool0oooo02D0oooo00D0000007moO`000000Ogmo0000001K0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0903o
ool01@000000Ogmo0000001oOgl0000005`0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`0S0?ooo`050000001oOgl0000007moO`000000
G@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3o
ool0oooo0280oooo00D0000007moO`000000Ogmo0000001N0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool08@3oool01@000000Ogmo0000
001oOgl0000005l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3o
ool00`09jPX0oooo0?ooo`0P0?ooo`050000001oOgl0000007moO`000000H03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo01l0oooo00D0
000007moO`000000Ogmo0000001Q0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08L0oooo00<02NX:0?ooo`3oool07P3oool01@000000Ogmo0000001oOgl000000680oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?oo
o`0M0?ooo`050000001oOgl0000007moO`000000H`3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo01`0oooo00D0000007moO`000000Ogmo
0000001T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<0
2NX:0?ooo`3oool06`3oool01@000000Ogmo0000001oOgl0000006D0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`0J0?ooo`050000001o
Ogl0000007moO`000000IP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`270?ooo`0300WZ2P3oool0oooo01T0oooo00D0000007moO`000000Ogmo0000001W0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0603o
ool01@000000Ogmo0000001oOgl0000006P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`0G0?ooo`050000001oOgl0000007moO`000000
J@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3o
ool0oooo01H0oooo00D0000007moO`000000Ogmo0000001Z0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool05@3oool01@000000Ogmo0000
001oOgl0000006/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3o
ool00`09jPX0oooo0?ooo`0D0?ooo`050000001oOgl0000007moO`000000K03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo01<0oooo0`00
00000`1oOgl000000?ooo`1/0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08L0oooo00<02NX:0?ooo`3oool04P3oool5000006h0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`0A0?ooo`D00000K`3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo0100
oooo1@00001`0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo
00<02NX:0?ooo`3oool03`3oool500000740oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`0>0?ooo`D00000LP3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo00d0oooo1@00001c
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?oo
o`3oool0303oool5000007@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0Q`3oool00`09jPX0oooo0?ooo`0;0?ooo`D00000M@3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo00X0oooo1@00001f0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool02@3o
ool5000007L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool0
0`09jPX0oooo0?ooo`080?ooo`D00000N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo00L0oooo00<0000007moO`0000000P00001i0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3o
ool01P3oool01@000000Ogmo0000001oOgl0000007X0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`050?ooo`050000001oOgl0000007mo
O`000000N`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`03
00WZ2P3oool0oooo00@0oooo00D0000007moO`000000Ogmo0000001l0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool00`3oool01@000000
Ogmo0000001oOgl0000007d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0Q`3oool00`09jPX0oooo0?ooo`020?ooo`050000001oOgl0000007moO`000000OP3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0900WZ2P3oool0oooo0?oo
o`000000Ogmo0000001oOgl0000007l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0Q`3oool02009jPX0oooo0?ooo`000000Ogmo0000001oOgl00000P03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0700WZ2P3oool0000007moO`00
0000Ogmo000000210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0
oooo00H02NX:0000001oOgl0000007moO`0000220?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00H0000000WZ2P000000000007moO`0000230?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo01T0ooooK`09jPX3000008<0oooo0P000007
0?ooo`001P3oool00`000000oooo0?ooo`250?ooo`040000001oOgl00000000008D02NX:0P000007
0?ooo`001P3oool00`000000oooo0?ooo`240?ooo`050000001oOgl0000007moO`000000QP3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`230?ooo`050000001oOgl00000
07moO`000000Q`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`220?oo
o`050000001oOgl0000007moO`000000R03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`210?ooo`050000001oOgl0000007moO`000000R@3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`200?ooo`050000001oOgl0000007moO`000000RP3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1o0?ooo`<0000000<0Ogmo0000
003oool0RP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1n0?ooo`D0
0000S03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1m0?ooo`D00000
S@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1l0?ooo`D00000SP3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1k0?ooo`D00000S`3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1j0?ooo`D00000T03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1i0?ooo`D00000T@3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1h0?ooo`D00000TP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1g0?ooo`D00000T`3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`1f0?ooo`D00000U03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`1e0?ooo`D00000U@3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`1d0?ooo`D00000UP3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`1c0?ooo`D00000U`3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`1b0?ooo`030000001oOgl0000000800000V03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`1a0?ooo`050000001oOgl0000007moO`000000V@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1`0?ooo`050000001oOgl0
000007moO`000000VP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1_
0?ooo`050000001oOgl0000007moO`000000V`3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`1^0?ooo`050000001oOgl0000007moO`000000W03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`1]0?ooo`050000001oOgl0000007moO`000000W@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1/0?ooo`050000001oOgl0
000007moO`000000WP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1[
0?ooo`050000001oOgl0000007moO`000000W`3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`1Z0?ooo`050000001oOgl0000007moO`000000X03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`1Y0?ooo`050000001oOgl0000007moO`000000X@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1X0?ooo`050000001oOgl0
000007moO`000000XP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1W
0?ooo`050000001oOgl0000007moO`000000X`3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`1V0?ooo`050000001oOgl0000007moO`000000Y03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`1U0?ooo`050000001oOgl0000007moO`000000Y@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1T0?ooo`050000001oOgl0
000007moO`000000YP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1S
0?ooo`050000001oOgl0000007moO`000000Y`3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`1R0?ooo`050000001oOgl0000007moO`000000Z03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`1Q0?ooo`050000001oOgl0000007moO`000000Z@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1P0?ooo`050000001oOgl0
000007moO`000000ZP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1O
0?ooo`050000001oOgl0000007moO`000000Z`3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`1N0?ooo`050000001oOgl0000007moO`000000[03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`1M0?ooo`050000001oOgl0000007moO`000000[@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1L0?ooo`050000001oOgl0
000007moO`000000[P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1K
0?ooo`050000001oOgl0000007moO`000000[`3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`1J0?ooo`050000001oOgl0000007moO`000000/03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`1I0?ooo`050000001oOgl0000007moO`000000/@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1H0?ooo`050000001oOgl0
000007moO`000000/P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`1G
0?ooo`050000001oOgl0000007moO`000000/`3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`1F0?ooo`050000001oOgl0000007moO`000000]03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`1G0?ooo`030000001oOgl000000;D0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`2d0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool200000?l0oooo4@3oool00`000000oooo0?ooo`050?ooo`001P3ooooo000001@00000
1`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"LinearPolarizer in beamsplitting mode SplitRays->Reflection"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{\({1, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", \({1.`, 0.`, 0.`}\), ",", 
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 2}\), ",", 
            StyleBox["1.52584130859896438`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.954282461381086122`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.298906312915027392`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0"}], "}"}], ",", "100.`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 3}\), ",", 
            StyleBox["1.52584130859896438`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.954282461381086122`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.298906312915027392`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0"}], "}"}], ",", 
            "49.9999999999999822`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`", ",", "0.`"}], "}"}]}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 1}\), ",", 
            StyleBox["1.52584130859896438`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"-", 
                  StyleBox["0.298906312915027427`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], ",", 
                RowBox[{"-", 
                  StyleBox["0.954282461381085767`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], ",", "0"}], "}"}], ",", 
            "49.9999999999999822`", ",", 
            RowBox[{"{", 
              RowBox[{"0.`", ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({2, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.00000000000000044`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "49.9999999999999822`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`", ",", "0.`"}], "}"}]}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({2, 2}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{"0", ",", 
                RowBox[{"-", 
                  StyleBox["0.999999999999999822`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], ",", "0"}], "}"}], ",", 
            "49.9999999999999822`", ",", 
            RowBox[{"{", 
              RowBox[{"0.`", ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"LinearPolarizer in beamsplitting mode SplitRays->Reflection"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{Move[SingleRay[],10],
Move[LinearPolarizer[0,50,CenterThickness->1, \
Transmittance->{100,100},SplitRays->Reflection],{50,0,45}], \
Boundary[100]},PlotType->TopView];
ReadRays[sys,{{ComponentNumber,SurfaceNumber},RefractiveIndex,RayTilt,\
Intensity,Polarization}]\
\>", "Input",
  CellTags->"LinearPolarizer in beamsplitting mode SplitRays->Reflection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.69866 .30807 -6 -4.5 ]
[.69866 .30807 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.66836 .33164 m
.67173 .33501 L
.64367 .36307 L
.6403 .3597 L
.66836 .33164 L
F
.6403 .3597 m
.64367 .36307 L
.61561 .39113 L
.61224 .38776 L
.6403 .3597 L
F
.61224 .38776 m
.61561 .39113 L
.58755 .41919 L
.58418 .41582 L
.61224 .38776 L
F
.58418 .41582 m
.58755 .41919 L
.55949 .44725 L
.55612 .44388 L
.58418 .41582 L
F
.55612 .44388 m
.55949 .44725 L
.53143 .47531 L
.52806 .47194 L
.55612 .44388 L
F
.52806 .47194 m
.53143 .47531 L
.50337 .50337 L
.5 .5 L
.52806 .47194 L
F
.5 .5 m
.50337 .50337 L
.47531 .53143 L
.47194 .52806 L
.5 .5 L
F
.47194 .52806 m
.47531 .53143 L
.44725 .55949 L
.44388 .55612 L
.47194 .52806 L
F
.44388 .55612 m
.44725 .55949 L
.41919 .58755 L
.41582 .58418 L
.44388 .55612 L
F
.41582 .58418 m
.41919 .58755 L
.39113 .61561 L
.38776 .61224 L
.41582 .58418 L
F
.38776 .61224 m
.39113 .61561 L
.36307 .64367 L
.3597 .6403 L
.38776 .61224 L
F
.3597 .6403 m
.36307 .64367 L
.33501 .67173 L
.33164 .66836 L
.3597 .6403 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.66836 .33164 m
.6403 .3597 L
.61224 .38776 L
.58418 .41582 L
.55612 .44388 L
.52806 .47194 L
.5 .5 L
.47194 .52806 L
.44388 .55612 L
.41582 .58418 L
.38776 .61224 L
.3597 .6403 L
.33164 .66836 L
.33501 .67173 L
.36307 .64367 L
.39113 .61561 L
.41919 .58755 L
.44725 .55949 L
.47531 .53143 L
.50337 .50337 L
.53143 .47531 L
.55949 .44725 L
.58755 .41919 L
.61561 .39113 L
.64367 .36307 L
.67173 .33501 L
.66836 .33164 L
s
.5 g
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
.5 .5 m
.50337 .50337 L
.50337 .50337 L
.5 .5 L
.5 .5 L
F
0 g
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.5 .5 L
s
.5 g
.67173 .33501 m
.67509 .33838 L
.64703 .36644 L
.64367 .36307 L
.67173 .33501 L
F
.64367 .36307 m
.64703 .36644 L
.61897 .3945 L
.61561 .39113 L
.64367 .36307 L
F
.61561 .39113 m
.61897 .3945 L
.59091 .42255 L
.58755 .41919 L
.61561 .39113 L
F
.58755 .41919 m
.59091 .42255 L
.56285 .45061 L
.55949 .44725 L
.58755 .41919 L
F
.55949 .44725 m
.56285 .45061 L
.53479 .47867 L
.53143 .47531 L
.55949 .44725 L
F
.53143 .47531 m
.53479 .47867 L
.50673 .50673 L
.50337 .50337 L
.53143 .47531 L
F
.50337 .50337 m
.50673 .50673 L
.47867 .53479 L
.47531 .53143 L
.50337 .50337 L
F
.47531 .53143 m
.47867 .53479 L
.45061 .56285 L
.44725 .55949 L
.47531 .53143 L
F
.44725 .55949 m
.45061 .56285 L
.42255 .59091 L
.41919 .58755 L
.44725 .55949 L
F
.41919 .58755 m
.42255 .59091 L
.3945 .61897 L
.39113 .61561 L
.41919 .58755 L
F
.39113 .61561 m
.3945 .61897 L
.36644 .64703 L
.36307 .64367 L
.39113 .61561 L
F
.36307 .64367 m
.36644 .64703 L
.33838 .67509 L
.33501 .67173 L
.36307 .64367 L
F
0 g
.67173 .33501 m
.64367 .36307 L
.61561 .39113 L
.58755 .41919 L
.55949 .44725 L
.53143 .47531 L
.50337 .50337 L
.47531 .53143 L
.44725 .55949 L
.41919 .58755 L
.39113 .61561 L
.36307 .64367 L
.33501 .67173 L
.33838 .67509 L
.36644 .64703 L
.3945 .61897 L
.42255 .59091 L
.45061 .56285 L
.47867 .53479 L
.50673 .50673 L
.53479 .47867 L
.56285 .45061 L
.59091 .42255 L
.61897 .3945 L
.64703 .36644 L
.67509 .33838 L
.67173 .33501 L
s
.5 g
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
.50337 .50337 m
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
.50337 .50337 L
F
0 g
.50337 .50337 m
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50337 .50337 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50673 .50673 L
.50337 .50337 L
s
.33164 .66836 m
.33308 .66692 L
.33738 .66262 L
.34446 .65554 L
.3542 .6458 L
.36643 .63357 L
.38095 .61905 L
.39751 .60249 L
.41582 .58418 L
.43557 .56443 L
.45643 .54357 L
.47802 .52198 L
.5 .5 L
.52198 .47802 L
.54357 .45643 L
.56443 .43557 L
.58418 .41582 L
.60249 .39751 L
.61905 .38095 L
.63357 .36643 L
.6458 .3542 L
.65554 .34446 L
.66262 .33738 L
.66692 .33308 L
.66836 .33164 L
.66692 .33308 L
.66262 .33738 L
.65554 .34446 L
.6458 .3542 L
.63357 .36643 L
.61905 .38095 L
.60249 .39751 L
.58418 .41582 L
.56443 .43557 L
.54357 .45643 L
.52198 .47802 L
.5 .5 L
.47802 .52198 L
.45643 .54357 L
.43557 .56443 L
.41582 .58418 L
.39751 .60249 L
.38095 .61905 L
.36643 .63357 L
.3542 .6458 L
.34446 .65554 L
.33738 .66262 L
.33308 .66692 L
.33164 .66836 L
s
.33501 .67173 m
.33645 .67029 L
.34075 .66599 L
.34782 .65891 L
.35756 .64917 L
.3698 .63694 L
.38432 .62241 L
.40088 .60586 L
.41919 .58755 L
.43894 .5678 L
.45979 .54694 L
.48139 .52534 L
.50337 .50337 L
.52534 .48139 L
.54694 .45979 L
.5678 .43894 L
.58755 .41919 L
.60586 .40088 L
.62241 .38432 L
.63694 .3698 L
.64917 .35756 L
.65891 .34782 L
.66599 .34075 L
.67029 .33645 L
.67173 .33501 L
.67029 .33645 L
.66599 .34075 L
.65891 .34782 L
.64917 .35756 L
.63694 .3698 L
.62241 .38432 L
.60586 .40088 L
.58755 .41919 L
.5678 .43894 L
.54694 .45979 L
.52534 .48139 L
.50337 .50337 L
.48139 .52534 L
.45979 .54694 L
.43894 .5678 L
.41919 .58755 L
.40088 .60586 L
.38432 .62241 L
.3698 .63694 L
.35756 .64917 L
.34782 .65891 L
.34075 .66599 L
.33645 .67029 L
.33501 .67173 L
s
.33838 .67509 m
.33982 .67365 L
.34411 .66936 L
.35119 .66228 L
.36093 .65254 L
.37317 .6403 L
.38769 .62578 L
.40424 .60922 L
.42255 .59091 L
.44231 .57116 L
.46316 .55031 L
.48476 .52871 L
.50673 .50673 L
.52871 .48476 L
.55031 .46316 L
.57116 .44231 L
.59091 .42255 L
.60922 .40424 L
.62578 .38769 L
.6403 .37317 L
.65254 .36093 L
.66228 .35119 L
.66936 .34411 L
.67365 .33982 L
.67509 .33838 L
.67365 .33982 L
.66936 .34411 L
.66228 .35119 L
.65254 .36093 L
.6403 .37317 L
.62578 .38769 L
.60922 .40424 L
.59091 .42255 L
.57116 .44231 L
.55031 .46316 L
.52871 .48476 L
.50673 .50673 L
.48476 .52871 L
.46316 .55031 L
.44231 .57116 L
.42255 .59091 L
.40424 .60922 L
.38769 .62578 L
.37317 .6403 L
.36093 .65254 L
.35119 .66228 L
.34411 .66936 L
.33982 .67365 L
.33838 .67509 L
s
.33164 .66836 m
.33501 .67173 L
.33645 .67029 L
.33308 .66692 L
.33164 .66836 L
s
.33308 .66692 m
.33645 .67029 L
.34075 .66599 L
.33738 .66262 L
.33308 .66692 L
s
.33738 .66262 m
.34075 .66599 L
.34782 .65891 L
.34446 .65554 L
.33738 .66262 L
s
.34446 .65554 m
.34782 .65891 L
.35756 .64917 L
.3542 .6458 L
.34446 .65554 L
s
.3542 .6458 m
.35756 .64917 L
.3698 .63694 L
.36643 .63357 L
.3542 .6458 L
s
.36643 .63357 m
.3698 .63694 L
.38432 .62241 L
.38095 .61905 L
.36643 .63357 L
s
.38095 .61905 m
.38432 .62241 L
.40088 .60586 L
.39751 .60249 L
.38095 .61905 L
s
.39751 .60249 m
.40088 .60586 L
.41919 .58755 L
.41582 .58418 L
.39751 .60249 L
s
.41582 .58418 m
.41919 .58755 L
.43894 .5678 L
.43557 .56443 L
.41582 .58418 L
s
.43557 .56443 m
.43894 .5678 L
.45979 .54694 L
.45643 .54357 L
.43557 .56443 L
s
.45643 .54357 m
.45979 .54694 L
.48139 .52534 L
.47802 .52198 L
.45643 .54357 L
s
.47802 .52198 m
.48139 .52534 L
.50337 .50337 L
.5 .5 L
.47802 .52198 L
s
.5 .5 m
.50337 .50337 L
.52534 .48139 L
.52198 .47802 L
.5 .5 L
s
.52198 .47802 m
.52534 .48139 L
.54694 .45979 L
.54357 .45643 L
.52198 .47802 L
s
.54357 .45643 m
.54694 .45979 L
.5678 .43894 L
.56443 .43557 L
.54357 .45643 L
s
.56443 .43557 m
.5678 .43894 L
.58755 .41919 L
.58418 .41582 L
.56443 .43557 L
s
.58418 .41582 m
.58755 .41919 L
.60586 .40088 L
.60249 .39751 L
.58418 .41582 L
s
.60249 .39751 m
.60586 .40088 L
.62241 .38432 L
.61905 .38095 L
.60249 .39751 L
s
.61905 .38095 m
.62241 .38432 L
.63694 .3698 L
.63357 .36643 L
.61905 .38095 L
s
.63357 .36643 m
.63694 .3698 L
.64917 .35756 L
.6458 .3542 L
.63357 .36643 L
s
.6458 .3542 m
.64917 .35756 L
.65891 .34782 L
.65554 .34446 L
.6458 .3542 L
s
.65554 .34446 m
.65891 .34782 L
.66599 .34075 L
.66262 .33738 L
.65554 .34446 L
s
.66262 .33738 m
.66599 .34075 L
.67029 .33645 L
.66692 .33308 L
.66262 .33738 L
s
.66692 .33308 m
.67029 .33645 L
.67173 .33501 L
.66836 .33164 L
.66692 .33308 L
s
.66836 .33164 m
.67173 .33501 L
.67029 .33645 L
.66692 .33308 L
.66836 .33164 L
s
.66692 .33308 m
.67029 .33645 L
.66599 .34075 L
.66262 .33738 L
.66692 .33308 L
s
.66262 .33738 m
.66599 .34075 L
.65891 .34782 L
.65554 .34446 L
.66262 .33738 L
s
.65554 .34446 m
.65891 .34782 L
.64917 .35756 L
.6458 .3542 L
.65554 .34446 L
s
.6458 .3542 m
.64917 .35756 L
.63694 .3698 L
.63357 .36643 L
.6458 .3542 L
s
.63357 .36643 m
.63694 .3698 L
.62241 .38432 L
.61905 .38095 L
.63357 .36643 L
s
.61905 .38095 m
.62241 .38432 L
.60586 .40088 L
.60249 .39751 L
.61905 .38095 L
s
.60249 .39751 m
.60586 .40088 L
.58755 .41919 L
.58418 .41582 L
.60249 .39751 L
s
.58418 .41582 m
.58755 .41919 L
.5678 .43894 L
.56443 .43557 L
.58418 .41582 L
s
.56443 .43557 m
.5678 .43894 L
.54694 .45979 L
.54357 .45643 L
.56443 .43557 L
s
.54357 .45643 m
.54694 .45979 L
.52534 .48139 L
.52198 .47802 L
.54357 .45643 L
s
.52198 .47802 m
.52534 .48139 L
.50337 .50337 L
.5 .5 L
.52198 .47802 L
s
.5 .5 m
.50337 .50337 L
.48139 .52534 L
.47802 .52198 L
.5 .5 L
s
.47802 .52198 m
.48139 .52534 L
.45979 .54694 L
.45643 .54357 L
.47802 .52198 L
s
.45643 .54357 m
.45979 .54694 L
.43894 .5678 L
.43557 .56443 L
.45643 .54357 L
s
.43557 .56443 m
.43894 .5678 L
.41919 .58755 L
.41582 .58418 L
.43557 .56443 L
s
.41582 .58418 m
.41919 .58755 L
.40088 .60586 L
.39751 .60249 L
.41582 .58418 L
s
.39751 .60249 m
.40088 .60586 L
.38432 .62241 L
.38095 .61905 L
.39751 .60249 L
s
.38095 .61905 m
.38432 .62241 L
.3698 .63694 L
.36643 .63357 L
.38095 .61905 L
s
.36643 .63357 m
.3698 .63694 L
.35756 .64917 L
.3542 .6458 L
.36643 .63357 L
s
.3542 .6458 m
.35756 .64917 L
.34782 .65891 L
.34446 .65554 L
.3542 .6458 L
s
.34446 .65554 m
.34782 .65891 L
.34075 .66599 L
.33738 .66262 L
.34446 .65554 L
s
.33738 .66262 m
.34075 .66599 L
.33645 .67029 L
.33308 .66692 L
.33738 .66262 L
s
.33308 .66692 m
.33645 .67029 L
.33501 .67173 L
.33164 .66836 L
.33308 .66692 L
s
.33501 .67173 m
.33838 .67509 L
.33982 .67365 L
.33645 .67029 L
.33501 .67173 L
s
.33645 .67029 m
.33982 .67365 L
.34411 .66936 L
.34075 .66599 L
.33645 .67029 L
s
.34075 .66599 m
.34411 .66936 L
.35119 .66228 L
.34782 .65891 L
.34075 .66599 L
s
.34782 .65891 m
.35119 .66228 L
.36093 .65254 L
.35756 .64917 L
.34782 .65891 L
s
.35756 .64917 m
.36093 .65254 L
.37317 .6403 L
.3698 .63694 L
.35756 .64917 L
s
.3698 .63694 m
.37317 .6403 L
.38769 .62578 L
.38432 .62241 L
.3698 .63694 L
s
.38432 .62241 m
.38769 .62578 L
.40424 .60922 L
.40088 .60586 L
.38432 .62241 L
s
.40088 .60586 m
.40424 .60922 L
.42255 .59091 L
.41919 .58755 L
.40088 .60586 L
s
.41919 .58755 m
.42255 .59091 L
.44231 .57116 L
.43894 .5678 L
.41919 .58755 L
s
.43894 .5678 m
.44231 .57116 L
.46316 .55031 L
.45979 .54694 L
.43894 .5678 L
s
.45979 .54694 m
.46316 .55031 L
.48476 .52871 L
.48139 .52534 L
.45979 .54694 L
s
.48139 .52534 m
.48476 .52871 L
.50673 .50673 L
.50337 .50337 L
.48139 .52534 L
s
.50337 .50337 m
.50673 .50673 L
.52871 .48476 L
.52534 .48139 L
.50337 .50337 L
s
.52534 .48139 m
.52871 .48476 L
.55031 .46316 L
.54694 .45979 L
.52534 .48139 L
s
.54694 .45979 m
.55031 .46316 L
.57116 .44231 L
.5678 .43894 L
.54694 .45979 L
s
.5678 .43894 m
.57116 .44231 L
.59091 .42255 L
.58755 .41919 L
.5678 .43894 L
s
.58755 .41919 m
.59091 .42255 L
.60922 .40424 L
.60586 .40088 L
.58755 .41919 L
s
.60586 .40088 m
.60922 .40424 L
.62578 .38769 L
.62241 .38432 L
.60586 .40088 L
s
.62241 .38432 m
.62578 .38769 L
.6403 .37317 L
.63694 .3698 L
.62241 .38432 L
s
.63694 .3698 m
.6403 .37317 L
.65254 .36093 L
.64917 .35756 L
.63694 .3698 L
s
.64917 .35756 m
.65254 .36093 L
.66228 .35119 L
.65891 .34782 L
.64917 .35756 L
s
.65891 .34782 m
.66228 .35119 L
.66936 .34411 L
.66599 .34075 L
.65891 .34782 L
s
.66599 .34075 m
.66936 .34411 L
.67365 .33982 L
.67029 .33645 L
.66599 .34075 L
s
.67029 .33645 m
.67365 .33982 L
.67509 .33838 L
.67173 .33501 L
.67029 .33645 L
s
.67173 .33501 m
.67509 .33838 L
.67365 .33982 L
.67029 .33645 L
.67173 .33501 L
s
.67029 .33645 m
.67365 .33982 L
.66936 .34411 L
.66599 .34075 L
.67029 .33645 L
s
.66599 .34075 m
.66936 .34411 L
.66228 .35119 L
.65891 .34782 L
.66599 .34075 L
s
.65891 .34782 m
.66228 .35119 L
.65254 .36093 L
.64917 .35756 L
.65891 .34782 L
s
.64917 .35756 m
.65254 .36093 L
.6403 .37317 L
.63694 .3698 L
.64917 .35756 L
s
.63694 .3698 m
.6403 .37317 L
.62578 .38769 L
.62241 .38432 L
.63694 .3698 L
s
.62241 .38432 m
.62578 .38769 L
.60922 .40424 L
.60586 .40088 L
.62241 .38432 L
s
.60586 .40088 m
.60922 .40424 L
.59091 .42255 L
.58755 .41919 L
.60586 .40088 L
s
.58755 .41919 m
.59091 .42255 L
.57116 .44231 L
.5678 .43894 L
.58755 .41919 L
s
.5678 .43894 m
.57116 .44231 L
.55031 .46316 L
.54694 .45979 L
.5678 .43894 L
s
.54694 .45979 m
.55031 .46316 L
.52871 .48476 L
.52534 .48139 L
.54694 .45979 L
s
.52534 .48139 m
.52871 .48476 L
.50673 .50673 L
.50337 .50337 L
.52534 .48139 L
s
.50337 .50337 m
.50673 .50673 L
.48476 .52871 L
.48139 .52534 L
.50337 .50337 L
s
.48139 .52534 m
.48476 .52871 L
.46316 .55031 L
.45979 .54694 L
.48139 .52534 L
s
.45979 .54694 m
.46316 .55031 L
.44231 .57116 L
.43894 .5678 L
.45979 .54694 L
s
.43894 .5678 m
.44231 .57116 L
.42255 .59091 L
.41919 .58755 L
.43894 .5678 L
s
.41919 .58755 m
.42255 .59091 L
.40424 .60922 L
.40088 .60586 L
.41919 .58755 L
s
.40088 .60586 m
.40424 .60922 L
.38769 .62578 L
.38432 .62241 L
.40088 .60586 L
s
.38432 .62241 m
.38769 .62578 L
.37317 .6403 L
.3698 .63694 L
.38432 .62241 L
s
.3698 .63694 m
.37317 .6403 L
.36093 .65254 L
.35756 .64917 L
.3698 .63694 L
s
.35756 .64917 m
.36093 .65254 L
.35119 .66228 L
.34782 .65891 L
.35756 .64917 L
s
.34782 .65891 m
.35119 .66228 L
.34411 .66936 L
.34075 .66599 L
.34782 .65891 L
s
.34075 .66599 m
.34411 .66936 L
.33982 .67365 L
.33645 .67029 L
.34075 .66599 L
s
.33645 .67029 m
.33982 .67365 L
.33838 .67509 L
.33501 .67173 L
.33645 .67029 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.11905 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.50513 .50161 L
s
0 0 0 r
2 Mabswid
.50513 .50161 Mdot
.039 .916 .04 r
.5 Mabswid
.50513 .50161 m
.50352 .49648 L
s
0 0 0 r
2 Mabswid
.50352 .49648 Mdot
.039 .916 .04 r
.5 Mabswid
.50352 .49648 m
.50352 .02381 L
s
0 0 0 r
2 Mabswid
.50352 .02381 Mdot
[(LP)] .69866 .30807 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
Q`3oool2000008H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3o
ool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`25
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?oo
o`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`03
00WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?oo
o`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?oo
o`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo
0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<0
2NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`27
0?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo
08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0
oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo
00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0
oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09
jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0
oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0
Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3o
ool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool0
0`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3o
ool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ
2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3o
ool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`25
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?oo
o`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`03
00WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0Q@3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo08D0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?oo
o`250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?oo
o`0300WZ2P3oool0oooo02l0oooo1@000000103oool0000000000000001=0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0<03oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`0`0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`270?ooo`0300WZ2P3oool0oooo0300oooo00<000000?ooo`3oool00`3oool3000004`0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo
0?ooo`0`0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000B`3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo0300oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00001;0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0;`3oool3000000<0oooo
1000001<0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<0
2NX:0?ooo`3oool0Q@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`27
0?ooo`0300WZ2P3oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0Q`3oool00`09jPX0oooo0?ooo`250?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0;03oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0
:`3oool00`000000Ogmo0000001G0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08L0oooo00<02NX:0?ooo`3oool0:P3oool01@000000Ogmo0000001oOgl0000005H0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?oo
o`0Y0?ooo`050000001oOgl0000007moO`000000E`3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo02P0oooo00D0000007moO`000000Ogmo
0000001H0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<0
2NX:0?ooo`3oool09`3oool01@000000Ogmo0000001oOgl0000005T0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`0V0?ooo`050000001o
Ogl0000007moO`000000FP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`270?ooo`0300WZ2P3oool0oooo02D0oooo00D0000007moO`000000Ogmo0000001K0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0903o
ool01@000000Ogmo0000001oOgl0000005`0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`0S0?ooo`050000001oOgl0000007moO`000000
G@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3o
ool0oooo0280oooo00D0000007moO`000000Ogmo0000001N0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool08@3oool01@000000Ogmo0000
001oOgl0000005l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3o
ool00`09jPX0oooo0?ooo`0P0?ooo`050000001oOgl0000007moO`000000H03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo01l0oooo00D0
000007moO`000000Ogmo0000001Q0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08L0oooo00<02NX:0?ooo`3oool07P3oool01@000000Ogmo0000001oOgl000000680oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?oo
o`0M0?ooo`050000001oOgl0000007moO`000000H`3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo01`0oooo00D0000007moO`000000Ogmo
0000001T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<0
2NX:0?ooo`3oool06`3oool01@000000Ogmo0000001oOgl0000006D0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`0J0?ooo`050000001o
Ogl0000007moO`000000IP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`270?ooo`0300WZ2P3oool0oooo01T0oooo00D0000007moO`000000Ogmo0000001W0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool0603o
ool01@000000Ogmo0000001oOgl0000006P0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`0G0?ooo`050000001oOgl0000007moO`000000
J@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3o
ool0oooo01H0oooo00D0000007moO`000000Ogmo0000001Z0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool05@3oool01@000000Ogmo0000
001oOgl0000006/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3o
ool00`09jPX0oooo0?ooo`0D0?ooo`050000001oOgl0000007moO`000000K03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo01<0oooo0`00
00000`1oOgl000000?ooo`1/0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08L0oooo00<02NX:0?ooo`3oool04P3oool5000006h0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`0A0?ooo`D00000K`3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo0100
oooo1@00001`0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo
00<02NX:0?ooo`3oool03`3oool500000740oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`0>0?ooo`D00000LP3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo00d0oooo1@00001c
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?oo
o`3oool0303oool5000007@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0Q`3oool00`09jPX0oooo0?ooo`0;0?ooo`D00000M@3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo00X0oooo1@00001f0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool02@3o
ool5000007L0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Q`3oool0
0`09jPX0oooo0?ooo`080?ooo`D00000N03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`270?ooo`0300WZ2P3oool0oooo00L0oooo00<0000007moO`0000000P00001i0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3o
ool01P3oool01@000000Ogmo0000001oOgl0000007X0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0Q`3oool00`09jPX0oooo0?ooo`050?ooo`050000001oOgl0000007mo
O`000000N`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`03
00WZ2P3oool0oooo00@0oooo00D0000007moO`000000Ogmo0000001l0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08L0oooo00<02NX:0?ooo`3oool00`3oool01@000000
Ogmo0000001oOgl0000007d0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0Q`3oool00`09jPX0oooo0?ooo`020?ooo`050000001oOgl0000007moO`000000OP3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0900WZ2P3oool0oooo0?oo
o`000000Ogmo0000001oOgl0000007l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0Q`3oool02009jPX0oooo0?ooo`000000Ogmo0000001oOgl00000P03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`270?ooo`0700WZ2P3oool0000007moO`00
0000Ogmo000000210?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08L0
oooo00H02NX:0000001oOgl0000007moO`0000220?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00H0000000WZ2P000000000007moO`0000230?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo01T0ooooK`09jPX00`000000Ogmo00000024
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08D0oooo00<0000007mo
O`0000000P0000250?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08@0
oooo00D0000007moO`000000Ogmo000000260?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08<0oooo00D0000007moO`000000Ogmo000000270?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0880oooo00D0000007moO`000000Ogmo000000280?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0840oooo00D0000007moO`00
0000Ogmo000000290?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0800
oooo00D0000007moO`000000Ogmo0000002:0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo07l0oooo0`0000000`1oOgl000000?ooo`2:0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo07h0oooo1@00002<0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo07d0oooo1@00002=0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo07`0oooo1@00002>0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo07/0oooo1@00002?0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo07X0oooo1@00002@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo07T0oooo1@00002A0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo07P0oooo1@00002B0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo07L0oooo1@00002C0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
07H0oooo1@00002D0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo07D0
oooo1@00002E0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo07@0oooo
1@00002F0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo07<0oooo1@00
002G0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0780oooo00<00000
07moO`0000000P00002H0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0740oooo00D0000007moO`000000Ogmo0000002I0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0700oooo00D0000007moO`000000Ogmo0000002J0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo06l0oooo00D0000007moO`000000Ogmo0000002K
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo06h0oooo00D0000007mo
O`000000Ogmo0000002L0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
06d0oooo00D0000007moO`000000Ogmo0000002M0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo06`0oooo00D0000007moO`000000Ogmo0000002N0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo06/0oooo00D0000007moO`000000Ogmo0000002O
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo06X0oooo00D0000007mo
O`000000Ogmo0000002P0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
06T0oooo00D0000007moO`000000Ogmo0000002Q0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo06P0oooo00D0000007moO`000000Ogmo0000002R0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo06L0oooo00D0000007moO`000000Ogmo0000002S
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo06H0oooo00D0000007mo
O`000000Ogmo0000002T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
06D0oooo00D0000007moO`000000Ogmo0000002U0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo06@0oooo00D0000007moO`000000Ogmo0000002V0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo06<0oooo00D0000007moO`000000Ogmo0000002W
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0680oooo00D0000007mo
O`000000Ogmo0000002X0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0640oooo00D0000007moO`000000Ogmo0000002Y0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0600oooo00D0000007moO`000000Ogmo0000002Z0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo05l0oooo00D0000007moO`000000Ogmo0000002[
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo05h0oooo00D0000007mo
O`000000Ogmo0000002/0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
05d0oooo00D0000007moO`000000Ogmo0000002]0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo05`0oooo00D0000007moO`000000Ogmo0000002^0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo05/0oooo00D0000007moO`000000Ogmo0000002_
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo05X0oooo00D0000007mo
O`000000Ogmo0000002`0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
05T0oooo00D0000007moO`000000Ogmo0000002a0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo05P0oooo00D0000007moO`000000Ogmo0000002b0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo05L0oooo00D0000007moO`000000Ogmo0000002c
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo05H0oooo00D0000007mo
O`000000Ogmo0000002d0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
05L0oooo00<0000007moO`000000]@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`800000o`3ooolA0?ooo`030000
003oool0oooo00D0oooo00060?ooool00000500000070?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"LinearPolarizer in beamsplitting mode SplitRays->Reflection"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{\({1, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", \({1.`, 0.`, 0.`}\), ",", 
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 2}\), ",", 
            StyleBox["1.52584130859896438`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.954282461381086122`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.298906312915027392`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0"}], "}"}], ",", "100.`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 1}\), ",", 
            StyleBox["1.52584130859896438`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"-", 
                  StyleBox["0.298906312915027427`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], ",", 
                RowBox[{"-", 
                  StyleBox["0.954282461381085767`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], ",", "0"}], "}"}], ",", "100.`", 
            ",", 
            RowBox[{"{", 
              RowBox[{"0.`", ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({2, 2}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{"0", ",", 
                RowBox[{"-", 
                  StyleBox["0.999999999999999822`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], ",", "0"}], "}"}], ",", "100.`", 
            ",", 
            RowBox[{"{", 
              RowBox[{"0.`", ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"LinearPolarizer in beamsplitting mode SplitRays->Reflection"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["PolarizingBeamSplitterCube", "Section",
  CellTags->"PolarizingBeamSplitterCube"],

Cell[CellGroupData[{

Cell["DrawSystem[PolarizingBeamSplitterCube[50]]", "Input",
  CellTags->"PolarizingBeamSplitterCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.66497 .02988 m .42216 .58164 L .40598 1.06315 L 0 0 .346 r
F
0 g
.5 Mabswid
[ ] 0 setdash
.536 .54442 m
.91022 .42206 L
s
.97657 .93008 m
.91022 .42206 L
s
.66497 .02988 m .40598 1.06315 L .6952 .58531 L 0 0 .346 r
F
0 g
.40598 1.06315 m
.6952 .58531 L
s
.66497 .02988 m
.91022 .42206 L
s
.10855 .26104 m
.42216 .58164 L
s
.40598 1.06315 m
.42216 .58164 L
s
.42216 .58164 m
.66497 .02988 L
s
.02877 .79167 m
.40598 1.06315 L
s
.40598 1.06315 m
.97657 .93008 L
s
.10855 .26104 m
.66497 .02988 L
s
.02877 .79167 m
.10855 .26104 L
s
.6952 .58531 m
.97657 .93008 L
s
.66497 .02988 m
.6952 .58531 L
s
.02877 .79167 m
.6952 .58531 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{249.062, 270.312},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003i00013R000`400?l00000o`00003on@3oool0
0?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo002S0?ooo`800000
E03oool00:00oooo0`0000000`3oool000000?ooo`1C0?ooo`00WP3oool2000000<0oooo0`00001C
0?ooo`00W03oool2000000D0oooo0P0000000`3oool000000?ooo`1A0?ooo`00V@3oool3000000H0
oooo00D000000000F0000000oooo0000001B0?ooo`00U`3oool2000000T0oooo00<000000000F000
00000P3oool00`000000oooo0?ooo`1?0?ooo`00U03oool3000000/0oooo00<000000000F0000000
0P3oool00`000000oooo0?ooo`1?0?ooo`00TP3oool2000000d0oooo00@000000000F00005P00000
0`3oool00`000000oooo0?ooo`1>0?ooo`00S`3oool3000000l0oooo00@000000000F00005P00000
103oool00`000000oooo0?ooo`1=0?ooo`00S@3oool200000140oooo00D000000000F00005P0001H
000000040?ooo`030000003oool0oooo04d0oooo002;0?ooo`8000004`3oool00`000000001H0000
F0020000F0030000003oool0oooo0080oooo00<000000?ooo`3oool0C03oool008P0oooo0`00000D
0?ooo`030000000005P0001H00<0001H00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00QP3oool2000001L0oooo00<000000000F00005P00`0005P00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo00230?ooo`<00000603oool00`000000001H0000F0040000F003
0000003oool0oooo00@0oooo00<000000?ooo`3oool0BP3oool00840oooo0P00000K0?ooo`030000
000005P0001H00@0001H00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`00OP3o
ool3000001d0oooo00<000000000F00005P0100005P00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo04T0oooo001l0?ooo`8000007`3oool00`000000001H0000F0050000F0030000003oool0
oooo00H0oooo00<000000?ooo`3oool0B03oool007X0oooo0P00000Q0?ooo`030000000005P0001H
00D0001H00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`180?ooo`00M`3oool300000280
oooo00<000000000F00005P01P0005P00`000000oooo0?ooo`070?ooo`030000003oool0oooo04L0
oooo001e0?ooo`8000009@3oool00`000000001H0000F0060000F0030000003oool0oooo00P0oooo
00<000000?ooo`3oool0AP3oool00780oooo0`00000V0?ooo`030000000005P0001H00L0001H00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`160?ooo`00L03oool2000002T0oooo00<00000
0000F00005P01`0005P00`000000oooo0?ooo`090?ooo`030000003oool0oooo04D0oooo001^0?oo
o`800000:`3oool00`000000001H0000F0070000F0030000003oool0oooo00X0oooo00<000000?oo
o`3oool0A03oool006/0oooo0`00000/0?ooo`030000000005P0001H00P0001H00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`140?ooo`00J@3oool2000002l0oooo00<000000000F00005P0
200005P00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04<0oooo001V0?ooo`<00000<03o
ool00`000000001H0000F0090000F0030000003oool0oooo00/0oooo00<000000?ooo`3oool0@`3o
ool006@0oooo0P00000c0?ooo`030000000005P0001H00T0001H00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`120?ooo`00H@3oool3000003@0oooo00<000000000F00005P02`0005P00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0440oooo001O0?ooo`800000=`3oool00`000000
001H0000F00;0000F0030000003oool0oooo00`0oooo00<000000?ooo`3oool0@@3oool005d0oooo
0P00000h0?ooo`030000000005P0001H00`0001H00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`100?ooo`00FP3oool3000003X0oooo00<000000000F00005P0300005P00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo03l0oooo001H0?ooo`800000?@3oool00`000000001H0000F00<
0000F0030000003oool0oooo00h0oooo00<000000?ooo`3oool0?`3oool005D0oooo0`00000n0?oo
o`030000000005P0001H00d0001H00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0n0?oo
o`00D`3oool200000440oooo00<000000000F00005P03@0005P00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo03h0oooo001@0?ooo`<00000@P3oool00`000000001H0000F00>0000F0030000
003oool0oooo0100oooo00<000000?ooo`3oool0?@3oool004h0oooo0P0000150?ooo`0300000000
05P0001H00h0001H00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0l0?ooo`00C03oool2
000004H0oooo00<000000000F00005P03`0005P00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo03`0oooo00190?ooo`<00000B03oool00`000000001H0000F00?0000F0030000003oool0oooo
0180oooo00<000000?ooo`3oool0>`3oool004L0oooo0P00001:0?ooo`030000000005P0001H0100
001H00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0j0?ooo`00A03oool3000004`0oooo
00<000000000F00005P0400005P00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03X0oooo
00120?ooo`800000C`3oool00`000000001H0000F00@0000F0030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0>@3oool00400oooo0P00001@0?ooo`030000000005P0001H0140001H00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0i0?ooo`00?@3oool300000580oooo00<000000000
F00005P04@0005P00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03P0oooo000k0?ooo`80
0000E03oool00`000000001H0000F00B0000F0030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0=`3oool003P0oooo0`00001F0?ooo`030000000005P0001H01<0001H00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0g0?ooo`00=P3oool2000005P0oooo00<000000000F00005P05000
05P00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03H0oooo000c0?ooo`<00000FP3oool0
0`000000001H0000F00D0000F0030000003oool0oooo01L0oooo00<000000?ooo`3oool0=@3oool0
0340oooo0P00001L0?ooo`030000000005P0001H01D0001H00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0e0?ooo`00;`3oool2000005h0oooo00<000000000F00005P05@0005P00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo03@0oooo000/0?ooo`<00000H03oool00`000000001H
0000F00E0000F0030000003oool0oooo01T0oooo00<000000?ooo`3oool0<`3oool002X0oooo0P00
001R0?ooo`030000000005P0001H01H0001H00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0c0?ooo`009`3oool3000006@0oooo00<000000000F00005P05P0005P00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo0380oooo000U0?ooo`800000IP3oool00`000000001H0000F00G0000
F0030000003oool0oooo01X0oooo00<000000?ooo`3oool0<P3oool00280oooo0`00001X0?ooo`03
0000000005P0001H01L0001H00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0a0?ooo`00
803oool2000006X0oooo00<000000000F00005P0600005P00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo0300oooo000N0?ooo`800000K03oool00`000000001H0000F00H0000F0030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0<03oool001/0oooo0`00001^0?ooo`030000000005P0
001H01P0001H00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0_0?ooo`006P3oool00`00
0000oooo0?ooo`1^0?ooo`030000000005P0001H01T0001H00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0^0?ooo`006P3oool00`000000oooo0?ooo`1^0?ooo`030000000005P0001H01T0
001H00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0^0?ooo`006P3oool2000006h0oooo
00<000000000F00005P06P0005P00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02d0oooo
000J0?ooo`030000003oool0000006d0oooo00<000000000F00005P06P0005P00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo02d0oooo000I0?ooo`050000003oool0oooo0?ooo`000000J`3o
ool00`000000001H0000F00L0000F0030000003oool0oooo01l0oooo00<000000?ooo`3oool0;03o
ool001T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1X0?ooo`030000000005P0
001H01`0001H00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0[0?ooo`006@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo06H0oooo00<000000000F00005P07@0005P00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo02/0oooo000I0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0I@3oool00`000000001H0000F00M0000F0030000003oool0oooo0240
oooo00<000000?ooo`3oool0:P3oool001T0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1T0?ooo`030000000005P0001H01d0001H00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0Y0?ooo`006@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0680oooo00<0
00000000F00005P07P0005P00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02T0oooo000I
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0H@3oool00`000000001H0000F00N
0000F0030000003oool0oooo02<0oooo00<000000?ooo`3oool0:03oool001P0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`1O0?ooo`030000000005P0001H01l0001H00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0X0?ooo`00603oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo05h0oooo00<000000000F00005P07`0005P00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo02L0oooo000H0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
G03oool00`000000001H0000F00P0000F0030000003oool0oooo02D0oooo00<000000?ooo`3oool0
9P3oool001P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1K0?ooo`0300000000
05P0001H0200001H00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0V0?ooo`00603oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo05T0oooo00<000000000F00005P08@0005P0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02D0oooo000H0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0F03oool00`000000001H0000F00Q0000F0030000003oool0oooo
02L0oooo00<000000?ooo`3oool0903oool001P0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`1G0?ooo`030000000005P0001H0240001H00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`0T0?ooo`005`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05D0oooo
00<000000000F00005P08P0005P00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02<0oooo
000G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0E03oool00`000000001H0000
F00R0000F0030000003oool0oooo02P0oooo00<000000?ooo`3oool08`3oool001L0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`1B0?ooo`030000000005P0001H02<0001H00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0R0?ooo`005`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo0540oooo00<000000000F00005P0900005P00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0240oooo000G0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0C`3oool00`000000001H0000F00U0000F0030000003oool0oooo02T0oooo00<000000?ooo`3o
ool08@3oool001L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1>0?ooo`030000
000005P0001H02D0001H00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0P0?ooo`005`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04`0oooo00<000000000F00005P09P00
05P00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01l0oooo000F0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0B`3oool00`000000001H0000F00V0000F0030000003oool0
oooo02/0oooo00<000000?ooo`3oool07`3oool001H0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`1:0?ooo`030000000005P0001H02H0001H00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0N0?ooo`005P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo04P0
oooo00<000000000F00005P09`0005P00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01d0
oooo000F0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0A`3oool00`000000001H
0000F00W0000F0030000003oool0oooo02d0oooo00<000000?ooo`3oool07@3oool001H0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`150?ooo`030000000005P0001H02P0001H00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0L0?ooo`005P3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo04@0oooo00<000000000F00005P0:00005P00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo01`0oooo000F0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0@P3oool00`000000001H0000F00Y0000F0030000003oool0oooo02l0oooo00<000000?oo
o`3oool06`3oool001D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`110?ooo`03
0000000005P0001H02T0001H00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0J0?ooo`00
5@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0400oooo00<000000000F00005P0
:@0005P00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01X0oooo000E0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0?P3oool00`000000001H0000F00Z0000F0030000003o
ool0oooo0340oooo00<000000?ooo`3oool06@3oool001D0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0m0?ooo`030000000005P0001H02X0001H00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
03/0oooo00<000000000F00005P0:`0005P00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
01P0oooo000E0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0>P3oool00`000000
001H0000F00[0000F0030000003oool0oooo03<0oooo00<000000?ooo`3oool05`3oool001D0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0h0?ooo`030000000005P0001H02d0001H
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0G0?ooo`00503oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo03L0oooo00<000000000F00005P0;@0005P00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0=@3oool00`000000001H0000F00^0000F0030000003oool0oooo0380oooo0`00000G
0?ooo`00503oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo03@0oooo00<000000000
F00005P0;P0005P00`000000oooo0?ooo`0_0?ooo`<000000P3oool00`000000oooo0?ooo`0E0?oo
o`00503oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo03<0oooo00<000000000F000
05P0;P0005P00`000000oooo0?ooo`0/0?ooo`<000001@3oool00`000000oooo0?ooo`0E0?ooo`00
503oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0340oooo00<000000000F00005P0
;`0005P00`000000oooo0?ooo`0Y0?ooo`<00000203oool00`000000oooo0?ooo`0E0?ooo`00503o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0300oooo00<000000000F00005P0;`00
05P00`000000oooo0?ooo`0V0?ooo`<000002`3oool00`000000oooo0?ooo`0E0?ooo`00503oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02h0oooo00<000000000F00005P0<00005P0
0`000000oooo0?ooo`0S0?ooo`<000003`3oool00`000000oooo0?ooo`0D0?ooo`004`3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo02d0oooo00<000000000F00005P0<00005P00`00
0000oooo0?ooo`0P0?ooo`<000004P3oool00`000000oooo0?ooo`0D0?ooo`004`3oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo02/0oooo00<000000000F00005P0<@0005P00`000000
oooo0?ooo`0M0?ooo`<000005@3oool00`000000oooo0?ooo`0D0?ooo`004`3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo02X0oooo00<000000000F00005P0<@0005P00`000000oooo
0?ooo`0J0?ooo`<00000603oool00`000000oooo0?ooo`0D0?ooo`004`3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo02P0oooo00<000000000F00005P0<P0005P00`000000oooo0?oo
o`0G0?ooo`<000006`3oool00`000000oooo0?ooo`0D0?ooo`004`3oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo02L0oooo00<000000000F00005P0<P0005P00`000000oooo0?ooo`0C
0?ooo`@000007P3oool00`000000oooo0?ooo`0D0?ooo`004`3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo02H0oooo00<000000000F00005P0<P0005P00`000000oooo0?ooo`0@0?oo
o`<000008P3oool00`000000oooo0?ooo`0D0?ooo`004`3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo02@0oooo00<000000000F00005P0<`0005P00`000000oooo0?ooo`0=0?ooo`<0
00009P3oool00`000000oooo0?ooo`0C0?ooo`004P3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo02<0oooo00<000000000F00005P0<`0005P00`000000oooo0?ooo`0:0?ooo`<00000
:@3oool00`000000oooo0?ooo`0C0?ooo`004P3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo0240oooo00<000000000F00005P0=00005P00`000000oooo0?ooo`070?ooo`<00000;03o
ool00`000000oooo0?ooo`0C0?ooo`004P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo0200oooo00<000000000F00005P0=@0005P00`000000oooo0?ooo`030?ooo`<00000;`3oool0
0`000000oooo0?ooo`0C0?ooo`004P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
01h0oooo00<000000000F00005P0=P0005P00`000000oooo0?ooo`0300000380oooo00<000000?oo
o`3oool04`3oool00180oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0M0?ooo`03
0000000005P0001H03H0001H0`00000e0?ooo`030000003oool0oooo01<0oooo000B0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool06`3oool00`000000001H0000F00g0000F0030000
003oool0oooo03D0oooo00<000000?ooo`3oool04`3oool00180oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0J0?ooo`030000000005P0001H03L0001H00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo01T0oooo00<000000000F00005P0=`0005P00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo0180oooo000A0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool05`3oool00`00
0000001H0000F00h0000F0030000003oool0oooo03H0oooo00<000000?ooo`3oool04P3oool00140
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0F0?ooo`030000000005P0001H03P0
001H00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0B0?ooo`004@3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo01@0oooo00<000000000F00005P0>@0005P00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo0180oooo000A0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool04`3oool00`000000001H0000F00i0000F0030000003oool0oooo03H0oooo00<0
00000?ooo`3oool04P3oool00140oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0A
0?ooo`030000000005P0001H03X0001H00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0B
0?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0100oooo00<000000000
F00005P0>P0005P00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0180oooo000@0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool00`000000001H0000F00j0000F003
0000003oool0oooo03L0oooo00<000000?ooo`3oool04@3oool00100oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`0=0?ooo`030000000005P0001H03/0001H00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0A0?ooo`00403oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo00`0oooo00<000000000F00005P0>`0005P00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo0140oooo000@0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool02P3oool0
0`000000001H0000F00E0000F0030000000005P0001H02@0001H00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0A0?ooo`00403oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
00T0oooo00<000000000F00005P0?00005P00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0140oooo000@0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01`3oool00`000000
001H0000F00n0000F0030000003oool0oooo03H0oooo00<000000?ooo`3oool04@3oool00100oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`060?ooo`030000000005P0001H03h0001H
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?oo
o`1A0?ooo`030000003oool0oooo00@0oooo00<000000000F00005P0?`0005P00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo0100oooo000?0?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool00`3oool00`000000001H0000F00o0000F0030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0403oool000l0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`020?oo
o`030000000005P0001H03l0001H00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0@0?oo
o`003`3oool00`000000oooo0?ooo`1D0?ooo`040000003oool0oooo00000480001H00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool000000480001H00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0@0?ooo`00
3`3oool00`000000oooo0?ooo`1F0?ooo`030000000005P0001H0440001H00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`1F0?ooo`0300000000
05P0001H03l0001H0`00000i0?ooo`030000003oool0oooo0100oooo000>0?ooo`030000003oool0
oooo05L0oooo00<000000000F00005P0?00005P300000080001H00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?ooo`1G0?ooo`030000000005P0001H
03T0001H0`0000040000F0030000003oool0000003T0oooo00<000000?ooo`3oool03`3oool000h0
oooo00<000000?ooo`3oool0E`3oool00`000000001H0000F00f0000F0<000001P0005P01@000000
oooo0?ooo`3oool0000003P0oooo00<000000?ooo`3oool03`3oool000h0oooo00<000000?ooo`3o
ool0E`3oool00`000000001H0000F00c0000F0<000002@0005P00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool03`3oool000h0oooo00<000000?ooo`3oool0
E`3oool00`000000001H0000F00`0000F0<000002`0005P00`000000oooo0?ooo`040?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool03`3oool000h0oooo00<000000?ooo`3oool0E`3o
ool00`000000001H0000F00/0000F0@000003P0005P00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool03`3oool000h0oooo00<000000?ooo`3oool0E`3oool0
0`000000001H0000F00Y0000F0<000004@0005P00`000000oooo0?ooo`060?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0F03oool00`00
0000001H0000F00V0000F0<000004`0005P00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0F03oool00`000000
001H0000F00S0000F0<000005P0005P00`000000oooo0?ooo`090?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool03P3oool000d0oooo00<000000?ooo`3oool0F03oool00`000000001H
0000F00P0000F0<00000600005P00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool03P3oool000d0oooo00<000000?ooo`3oool0F03oool00`000000001H0000
F00M0000F0<000006`0005P00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool03P3oool000d0oooo00<000000?ooo`3oool0F03oool00`000000001H0000F00I
0000F0@000007@0005P00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool03P3oool000d0oooo00<000000?ooo`3oool0F03oool00`000000001H0000F00F0000
F0<00000800005P00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool03P3oool000d0oooo00<000000?ooo`3oool0F03oool00`000000001H0000F00C0000F0<0
00008`0005P00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool03P3oool000`0oooo00<000000?ooo`3oool0F03oool00`000000001H0000F00A0000F0<00000
9@0005P00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
3P3oool000`0oooo00<000000?ooo`3oool0F03oool00`000000001H0000F00>0000F0<00000:000
05P00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool03P3o
ool000`0oooo00<000000?ooo`3oool0F03oool00`000000001H0000F00:0000F0@00000:P0005P0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool03@3oool0
00`0oooo00<000000?ooo`3oool0F03oool00`000000001H0000F0070000F0<00000;@0005P00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool03@3oool000`0
oooo00<000000?ooo`3oool0F03oool00`000000001H0000F0040000F0<00000<00005P00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool03@3oool000`0oooo
00<000000?ooo`3oool0F03oool010000000001H0000F00005P300000380001H00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00d0oooo000<0?ooo`030000
003oool0oooo05P0oooo1000000e0000F0030000003oool0oooo01X0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0=0?ooo`002`3oool00`000000oooo0?ooo`1G0?ooo`<00000=`00
05P00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03@3o
ool000/0oooo00<000000?ooo`3oool0D`3oool400000080oooo00<000000000F00005P0=00005P0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03@3oool0
00/0oooo00<000000?ooo`3oool0D03oool3000000H0oooo00<000000000F00005P0=00005P00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0303oool000/0
oooo00<000000?ooo`3oool0C@3oool3000000T0oooo00<000000000F00005P0<`0005P00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0303oool000/0oooo
00<000000?ooo`3oool0BP3oool3000000`0oooo00<000000000F00005P0<`0005P00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0303oool000/0oooo00<0
00000?ooo`3oool0A`3oool3000000l0oooo00<000000000F00005P0<P0005P00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool000/0oooo00<00000
0?ooo`3oool0A03oool300000180oooo00<000000000F00005P0<@0005P00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool000X0oooo00<000000?oo
o`3oool0@@3oool4000001D0oooo00<000000000F00005P0<@0005P00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0303oool000X0oooo00<000000?ooo`3o
ool0?P3oool3000001T0oooo00<000000000F00005P0<00005P00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0303oool000X0oooo00<000000?ooo`3oool0
>`3oool3000001`0oooo00<000000000F00005P0<00005P00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool02`3oool000X0oooo00<000000?ooo`3oool0>03o
ool3000001l0oooo00<000000000F00005P0;`0005P00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool02`3oool000X0oooo00<000000?ooo`3oool0=@3oool3
00000280oooo00<000000000F00005P0;P0005P00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool02`3oool000X0oooo00<000000?ooo`3oool0<P3oool30000
02D0oooo00<000000000F00005P0;P0005P00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool02`3oool000X0oooo00<000000?ooo`3oool0;P3oool4000002P0
oooo00<000000000F00005P0;@0005P00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool02`3oool000T0oooo00<000000?ooo`3oool0;03oool3000002`0oooo
00<000000000F00005P0;@0005P00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool02`3oool000T0oooo00<000000?ooo`3oool0:@3oool3000002l0oooo00<0
00000000F00005P0;00005P00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool02`3oool000T0oooo00<000000?ooo`3oool09P3oool300000380oooo00<00000
0000F00005P0:`0005P00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool02`3oool000T0oooo00<000000?ooo`3oool08`3oool3000003D0oooo00<000000000
F00005P0:`0005P00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool02P3oool000T0oooo00<000000?ooo`3oool07`3oool4000003P0oooo00<000000000F000
05P0:P0005P00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool02P3oool000T0oooo00<000000?ooo`3oool0703oool3000003`0oooo00<000000000F00005P0
:@0005P00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
2P3oool000T0oooo00<000000?ooo`3oool06@3oool3000003l0oooo00<000000000F00005P0:@00
05P00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02P3o
ool000P0oooo00<000000?ooo`3oool05`3oool300000480oooo00<000000000F00005P0:00005P0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool02P3oool0
00P0oooo00<000000?ooo`3oool0503oool3000004D0oooo00<000000000F00005P0:00005P00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool02P3oool000P0
oooo00<000000?ooo`3oool04@3oool3000004L0oooo00<000000000F00005P0:00005P00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02P3oool000P0oooo
00<000000?ooo`3oool03@3oool4000004X0oooo00<000000000F00005P09`0005P00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool000P0oooo00<0
00000?ooo`3oool02P3oool3000004h0oooo00<000000000F00005P09`0005P00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02@3oool000P0oooo00<00000
0?ooo`3oool01`3oool300000540oooo00<000000000F00005P09P0005P00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02@3oool000P0oooo00<000000?oo
o`3oool0103oool3000005@0oooo00<000000000F00005P09P0005P00`000000oooo0?ooo`110?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool02@3oool000L0oooo00<000000?ooo`3o
ool00P3oool3000005L0oooo00<000000000F00005P09@0005P00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool000L0oooo00<000000?ooo`000000
0P00001J0?ooo`030000000005P0001H02@0001H00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00T0oooo00070?ooo`800000G@3oool00`000000001H0000
F00T0000F0030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`090?ooo`002@3oool00`000000oooo0?ooo`1J0?ooo`030000000005P0001H02<0001H00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000:0?oo
o`030000003oool0oooo05T0oooo00<000000000F00005P08`0005P00`000000oooo0?ooo`190?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool000/0oooo0P00001I0?ooo`03
0000000005P0001H0280001H00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00P0oooo000=0?ooo`030000003oool0oooo05H0oooo00<000000000F00005P0
8@0005P00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
203oool000h0oooo0P00001F0?ooo`030000000005P0001H0240001H00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo000@0?ooo`030000003oool0
oooo05<0oooo00<000000000F00005P0800005P00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0203oool00140oooo00<000000?ooo`3oool0DP3oool00`00
0000001H0000F00P0000F0030000003oool0oooo0500oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`080?ooo`004P3oool200000580oooo00<000000000F00005P07`0005P00`000000
oooo0?ooo`1A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool001@0oooo
00<000000?ooo`3oool0C`3oool00`000000001H0000F00N0000F0030000003oool0oooo05<0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`005@3oool2000004l0oooo00<0
00000000F00005P07P0005P00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool01`3oool001L0oooo00<000000?ooo`3oool0C03oool00`000000001H0000F00M
0000F0030000003oool0oooo05H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`07
0?ooo`00603oool00`000000oooo0?ooo`1;0?ooo`030000000005P0001H01d0001H00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo000I0?ooo`80
0000B`3oool00`000000001H0000F00L0000F0030000003oool0oooo05T0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`070?ooo`006`3oool00`000000oooo0?ooo`180?ooo`030000
000005P0001H01/0001H00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00L0oooo000L0?ooo`800000B03oool00`000000001H0000F00K0000F0030000003o
ool0oooo05/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`007P3oool0
0`000000oooo0?ooo`150?ooo`030000000005P0001H01X0001H00<000000?ooo`3oool0G@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo000O0?ooo`030000003oool0oooo
04@0oooo00<000000000F00005P06P0005P00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01P3oool00200oooo0P0000140?ooo`030000000005P0001H01T0
001H00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0
oooo000R0?ooo`030000003oool0oooo0440oooo00<000000000F00005P0600005P00`000000oooo
0?ooo`1Q0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool002<0oooo00<0
00000?ooo`3oool0@03oool00`000000001H0000F00H0000F0030000003oool0oooo0680oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`00903oool200000400oooo00<00000
0000F00005P05`0005P00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool002H0oooo00<000000?ooo`3oool0?@3oool00`000000001H0000F00G0000
F0030000003oool0oooo06D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`009`3oool2000003`0oooo00<000000000F00005P05`0005P00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool002T0oooo00<000000?ooo`3oool0
>@3oool00`000000001H0000F00F0000F0030000003oool0oooo06P0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`00:P3oool00`000000oooo0?ooo`0h0?ooo`0300000000
05P0001H01H0001H00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo000[0?ooo`800000>03oool00`000000001H0000F00E0000F0030000003oool0
oooo06/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`00;@3oool00`00
0000oooo0?ooo`0e0?ooo`030000000005P0001H01D0001H00<000000?ooo`3oool0K03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000=@3oool00`000000
001H0000F00D0000F0030000003oool0oooo06h0oooo00D000000?ooo`3oool0oooo000000070?oo
o`00<03oool00`000000oooo0?ooo`0b0?ooo`030000000005P0001H01<0001H00<000000?ooo`3o
ool0L03oool010000000oooo0?ooo`0000070?ooo`00<@3oool00`000000oooo0?ooo`0a0?ooo`03
0000000005P0001H01<0001H00<000000?ooo`3oool0L03oool010000000oooo0?ooo`0000070?oo
o`00<P3oool200000340oooo00<000000000F00005P04P0005P00`000000oooo0?ooo`1b0?ooo`04
0000003oool0oooo000000H0oooo000d0?ooo`030000003oool0oooo02h0oooo00<000000000F000
05P04@0005P00`000000oooo0?ooo`1d0?ooo`030000003oool0000000H0oooo000e0?ooo`800000
;P3oool00`000000001H0000F00A0000F0030000003oool0oooo07D0oooo0P0000060?ooo`00=`3o
ool00`000000oooo0?ooo`0[0?ooo`030000000005P0001H0100001H00<000000?ooo`3oool0M@3o
ool3000000H0oooo000h0?ooo`030000003oool0oooo02X0oooo00<000000000F00005P0400005P0
0`000000oooo0?ooo`1a0?ooo`@000002@3oool003T0oooo0P00000Z0?ooo`030000000005P0001H
00l0001H00<000000?ooo`3oool0K@3oool5000000d0oooo000k0?ooo`030000003oool0oooo02L0
oooo00<000000000F00005P03P0005P00`000000oooo0?ooo`1Z0?ooo`@000004P3oool003`0oooo
00<000000?ooo`3oool09P3oool00`000000001H0000F00>0000F0030000003oool0oooo06H0oooo
1000000F0?ooo`00?@3oool2000002H0oooo00<000000000F00005P03@0005P00`000000oooo0?oo
o`1R0?ooo`D000006P3oool003l0oooo00<000000?ooo`3oool08`3oool00`000000001H0000F00=
0000F0030000003oool0oooo05h0oooo1000000O0?ooo`00@03oool2000002<0oooo00<000000000
F00005P0300005P00`000000oooo0?ooo`1K0?ooo`@000008`3oool00480oooo00<000000?ooo`3o
ool0803oool00`000000001H0000F00;0000F0030000003oool0oooo05L0oooo1@00000W0?ooo`00
@`3oool00`000000oooo0?ooo`0O0?ooo`030000000005P0001H00/0001H00<000000?ooo`3oool0
D`3oool4000002`0oooo00140?ooo`8000007`3oool00`000000001H0000F00:0000F0030000003o
ool0oooo0500oooo1000000`0?ooo`00AP3oool00`000000oooo0?ooo`0L0?ooo`030000000005P0
001H00X0001H00<000000?ooo`3oool0C03oool4000003@0oooo00170?ooo`800000703oool00`00
0000001H0000F0090000F0030000003oool0oooo04P0oooo1@00000h0?ooo`00B@3oool00`000000
oooo0?ooo`0I0?ooo`030000000005P0001H00P0001H00<000000?ooo`3oool0A@3oool4000003d0
oooo001:0?ooo`030000003oool0oooo01P0oooo00<000000000F00005P0200005P00`000000oooo
0?ooo`110?ooo`@00000@@3oool004/0oooo0P00000H0?ooo`030000000005P0001H00L0001H00<0
00000?ooo`3oool0?@3oool5000004D0oooo001=0?ooo`030000003oool0oooo01D0oooo00<00000
0000F00005P01`0005P00`000000oooo0?ooo`0i0?ooo`@00000BP3oool004h0oooo00<000000?oo
o`3oool0503oool00`000000001H0000F0060000F0030000003oool0oooo03H0oooo1000001>0?oo
o`00C`3oool2000001@0oooo00<000000000F00005P01@0005P00`000000oooo0?ooo`0b0?ooo`D0
0000DP3oool00540oooo00<000000?ooo`3oool0403oool00`000000001H0000F0060000F0030000
003oool0oooo02h0oooo1000001G0?ooo`00DP3oool200000100oooo00<000000000F00005P01@00
05P00`000000oooo0?ooo`0[0?ooo`@00000F`3oool005@0oooo00<000000?ooo`3oool03@3oool0
0`000000001H0000F0050000F0030000003oool0oooo02H0oooo1@00001O0?ooo`00E@3oool00`00
0000oooo0?ooo`0<0?ooo`030000000005P0001H00@0001H00<000000?ooo`3oool08`3oool40000
06@0oooo001F0?ooo`800000303oool00`000000001H0000F0030000F0030000003oool0oooo0200
oooo1000001X0?ooo`00F03oool00`000000oooo0?ooo`090?ooo`030000000005P0001H00<0001H
00<000000?ooo`3oool0703oool4000006`0oooo001I0?ooo`8000002@3oool00`000000001H0000
F0020000F0030000003oool0oooo01P0oooo1@00001`0?ooo`00F`3oool00`000000oooo0?ooo`06
0?ooo`030000000005P0001H0080001H00<000000?ooo`3oool0503oool4000007D0oooo001L0?oo
o`030000003oool0oooo00D0oooo00D000000000F00005P0001H0000000C0?ooo`@00000N@3oool0
05d0oooo0P0000050?ooo`040000000005P0001H000000l0oooo1@00001m0?ooo`00G`3oool00`00
0000oooo0?ooo`020?ooo`040000000005P0001H000000/0oooo100000220?ooo`00H03oool20000
0080oooo00<000000000F0000000203oool4000008H0oooo001R0?ooo`050000003oool000000000
F00000000`3oool5000008X0oooo001S0?ooo`L00000S`3oool006@0oooo0P00002C0?ooo`00n@3o
ool00?T0oooo003i0?ooo`00n@3oool00?T0oooo0000\
\>"],
  ImageRangeCache->{{{0, 248.062}, {269.312, 0}} -> {0.0486402, -7.49314*^-5, \
0.00345712, 0.00345712}},
  CellTags->"PolarizingBeamSplitterCube"],

Cell[BoxData[
    TagBox[\(DrawSystem[{PolarizingBeamSplitterCube[50]}]\),
      HoldForm]], "Print",
  CellTags->"PolarizingBeamSplitterCube"],

Cell[BoxData[
    \("-rendered unpropagated system-"\)], "Output",
  CellTags->"PolarizingBeamSplitterCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{Move[SingleRay[Polarization->{1,1,0}],10],
Move[PolarizingBeamSplitterCube[25],50], Boundary[100]},PlotType->TopView];
ReadRays[sys,{{ComponentNumber,SurfaceNumber},RefractiveIndex,RayTilt,\
Intensity,Polarization}]\
\>", "Input",
  CellTags->"PolarizingBeamSplitterCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.76503 .35401 -6 -4.5 ]
[.76503 .35401 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .38095 m
.5 .61905 L
.5 .61905 L
.5 .38095 L
.5 .38095 L
s
.7381 .38095 m
.7381 .61905 L
.7381 .61905 L
.7381 .38095 L
.7381 .38095 L
s
.7381 .61905 m
.5 .61905 L
.5 .61905 L
.7381 .61905 L
.7381 .61905 L
s
.5 .38095 m
.7381 .38095 L
.7381 .38095 L
.5 .38095 L
.5 .38095 L
s
.7381 .38095 m
.7381 .61905 L
.5 .61905 L
.5 .38095 L
.7381 .38095 L
s
.7381 .61905 m
.7381 .38095 L
.5 .38095 L
.5 .61905 L
.7381 .61905 L
s
.5 g
.7381 .38095 m
.5 .61905 L
.5 .61905 L
.7381 .38095 L
.7381 .38095 L
F
0 g
.7381 .38095 m
.5 .61905 L
.5 .61905 L
.7381 .38095 L
.7381 .38095 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.11905 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.61905 .5 L
s
0 0 0 r
2 Mabswid
.61905 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.61905 .5 m
.7381 .5 L
s
0 0 0 r
2 Mabswid
.7381 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.61905 .5 m
.61905 .38095 L
s
0 0 0 r
2 Mabswid
.61905 .38095 Mdot
.039 .916 .04 r
.5 Mabswid
.7381 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.61905 .38095 m
.61905 .02381 L
s
0 0 0 r
2 Mabswid
.61905 .02381 Mdot
[(BS)] .76503 .35401 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
Z03oool2000006D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03o
ool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?oo
o`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`03
00WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?oo
o`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:
0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?oo
o`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo
0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<0
2NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X
0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo
06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0
oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo
00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0
oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09
jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0
oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0
I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3o
ool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool0
0`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3o
ool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ
2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03o
ool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?oo
o`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`03
00WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?oo
o`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:
0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?oo
o`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo
0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<0
2NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X
0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool08@3oool4
00000080oooo00@000000?ooo`0000000000>@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo0280oooo00D000000?ooo`3oool000000?oo
o`0200000080oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo0280oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`800000>03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`2X0?ooo`0300WZ2P3oool0oooo0280oooo0`0000030?ooo`<00000>@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo0280oooo00D00000
0?ooo`3oool000000?ooo`0200000080oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo0280oooo00H00000
0?ooo`3oool000000?ooo`0000020?ooo`800000>03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo0240oooo100000030?ooo`80000000<0
oooo0000003oool0=`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X
0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0:P0oooo00<02NX:0000003oool0I03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooob80000000<02NX:0000000000008@0000130?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool07`3o
ool00`09jPX0oooo0?ooo`0N0?ooo`800000A03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool07@3oool0
0`000000oooo000000140?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0L0?ooo`040000003oool0oooo
000004@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo01/0oooo00D000000?ooo`3oool0oooo00000014
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool07`3oool00`09jPX0oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo01l0oooo00<02NX:0?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo01P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0G0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool05P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo
01D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool07`3oool00`09jPX0
oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0oooo
00<02NX:0?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`0O0?ooo`0300WZ2P3oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool0403oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo00l0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0>0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool03@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0
oooo00`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool07`3oool00`09
jPX0oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0
oooo00<02NX:0?ooo`3oool02P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`0O0?ooo`0300WZ2P3oool0oooo00T0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool01`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo00H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`050?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool0
103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3o
ool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool07`3oool0
0`09jPX0oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
01l0oooo00D02NX:0?ooo`3oool0oooo0000000M0?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0O0?oo
o`0400WZ2P3oool0oooo000001h0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0oooo00<02NX:0?oo
o`0000007`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo0P00000P0?ooo`0300WZ2P000000oooo01l0oooo0P0000120?ooo`80
00001`3oool000H0oooo00<000000?ooo`3oool06@3ooooe00WZ2P8000001`3oool000H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00D000000?ooo`3oool0oooo0000000o0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool010000000oooo0?ooo`0000100?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo000000110?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool200000480oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooodH00000@`3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`80
0000o`3ooolA0?ooo`030000003oool0oooo00D0oooo00060?ooool00000500000070?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"PolarizingBeamSplitterCube"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{\({1, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", \({1.`, 0.`, 0.`}\), ",", 
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 7}\), ",", 
            StyleBox["1.51947243256730679`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "100.`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 2}\), ",", 
            StyleBox["1.51947243256730679`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "49.9999999999999822`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`", ",", "0.`"}], "}"}]}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 4}\), ",", 
            StyleBox["1.51947243256730679`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{"0", ",", 
                RowBox[{"-", 
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], ",", "0"}], "}"}], ",", 
            "49.9999999999999822`", ",", 
            RowBox[{"{", 
              RowBox[{"0.`", ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({2, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "49.9999999999999822`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`", ",", "0.`"}], "}"}]}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({2, 2}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{"0", ",", 
                RowBox[{"-", 
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], ",", "0"}], "}"}], ",", 
            "49.9999999999999822`", ",", 
            RowBox[{"{", 
              RowBox[{"0.`", ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"PolarizingBeamSplitterCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{Move[SingleRay[], 10, TwistAngle->45],
Move[PolarizingBeamSplitterCube[25],50], Boundary[100]},PlotType->TopView];
ReadRays[sys,{{ComponentNumber,SurfaceNumber},RefractiveIndex,RayTilt,\
Intensity,Polarization}]\
\>", "Input",
  CellTags->"PolarizingBeamSplitterCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.76503 .35401 -6 -4.5 ]
[.76503 .35401 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .38095 m
.5 .61905 L
.5 .61905 L
.5 .38095 L
.5 .38095 L
s
.7381 .38095 m
.7381 .61905 L
.7381 .61905 L
.7381 .38095 L
.7381 .38095 L
s
.7381 .61905 m
.5 .61905 L
.5 .61905 L
.7381 .61905 L
.7381 .61905 L
s
.5 .38095 m
.7381 .38095 L
.7381 .38095 L
.5 .38095 L
.5 .38095 L
s
.7381 .38095 m
.7381 .61905 L
.5 .61905 L
.5 .38095 L
.7381 .38095 L
s
.7381 .61905 m
.7381 .38095 L
.5 .38095 L
.5 .61905 L
.7381 .61905 L
s
.5 g
.7381 .38095 m
.5 .61905 L
.5 .61905 L
.7381 .38095 L
.7381 .38095 L
F
0 g
.7381 .38095 m
.5 .61905 L
.5 .61905 L
.7381 .38095 L
.7381 .38095 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.11905 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.61905 .5 L
s
0 0 0 r
2 Mabswid
.61905 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.61905 .5 m
.7381 .5 L
s
0 0 0 r
2 Mabswid
.7381 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.61905 .5 m
.61905 .38095 L
s
0 0 0 r
2 Mabswid
.61905 .38095 Mdot
.039 .916 .04 r
.5 Mabswid
.7381 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.61905 .38095 m
.61905 .02381 L
s
0 0 0 r
2 Mabswid
.61905 .02381 Mdot
[(BS)] .76503 .35401 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
Z03oool2000006D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03o
ool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?oo
o`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`03
00WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?oo
o`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:
0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?oo
o`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo
0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<0
2NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X
0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo
06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0
oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo
00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0
oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09
jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0
oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0
I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3o
ool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool0
0`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3o
ool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ
2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03o
ool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?oo
o`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`03
00WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?oo
o`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:
0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?oo
o`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo
0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<0
2NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X
0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool08@3oool4
00000080oooo00@000000?ooo`0000000000>@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo0280oooo00D000000?ooo`3oool000000?oo
o`0200000080oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo0280oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`800000>03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`2X0?ooo`0300WZ2P3oool0oooo0280oooo0`0000030?ooo`<00000>@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo0280oooo00D00000
0?ooo`3oool000000?ooo`0200000080oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo0280oooo00H00000
0?ooo`3oool000000?ooo`0000020?ooo`800000>03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo0240oooo100000030?ooo`80000000<0
oooo0000003oool0=`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X
0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0:P0oooo00<02NX:0000003oool0I03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooob80000000<02NX:0000000000008@0000130?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool07`3o
ool00`09jPX0oooo0?ooo`0N0?ooo`800000A03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool07@3oool0
0`000000oooo000000140?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0L0?ooo`040000003oool0oooo
000004@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo01/0oooo00D000000?ooo`3oool0oooo00000014
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool07`3oool00`09jPX0oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo01l0oooo00<02NX:0?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo01P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0G0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool05P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo
01D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool07`3oool00`09jPX0
oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0oooo
00<02NX:0?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`0O0?ooo`0300WZ2P3oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool0403oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo00l0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0>0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool03@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0
oooo00`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool07`3oool00`09
jPX0oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0
oooo00<02NX:0?ooo`3oool02P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`0O0?ooo`0300WZ2P3oool0oooo00T0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool01`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo00H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`050?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool0
103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3o
ool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool07`3oool0
0`09jPX0oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
01l0oooo00D02NX:0?ooo`3oool0oooo0000000M0?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0O0?oo
o`0400WZ2P3oool0oooo000001h0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0oooo00<02NX:0?oo
o`0000007`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo0P00000P0?ooo`0300WZ2P000000oooo01l0oooo0P0000120?ooo`80
00001`3oool000H0oooo00<000000?ooo`3oool06@3ooooe00WZ2P8000001`3oool000H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00D000000?ooo`3oool0oooo0000000o0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool010000000oooo0?ooo`0000100?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo000000110?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool200000480oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooodH00000@`3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`80
0000o`3ooolA0?ooo`030000003oool0oooo00D0oooo00060?ooool00000500000070?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"PolarizingBeamSplitterCube"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{\({1, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", \({1.`, 0.`, 0.`}\), ",", 
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 7}\), ",", 
            StyleBox["1.51947243256730679`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "100.`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 2}\), ",", 
            StyleBox["1.51947243256730679`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "50.0000000000000177`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.707106781186547461`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.70710678118654755`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                RowBox[{"-", 
                  StyleBox["180.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 4}\), ",", 
            StyleBox["1.51947243256730679`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{"0", ",", 
                RowBox[{"-", 
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], ",", "0"}], "}"}], ",", 
            "49.9999999999999822`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.70710678118654755`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.707106781186547461`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({2, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "50.0000000000000177`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.707106781186547461`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.70710678118654755`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                RowBox[{"-", 
                  StyleBox["180.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({2, 2}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{"0", ",", 
                RowBox[{"-", 
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], ",", "0"}], "}"}], ",", 
            "49.9999999999999822`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.70710678118654755`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.707106781186547461`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"PolarizingBeamSplitterCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{Move[SingleRay[], 10, TwistAngle->30],
Move[PolarizingBeamSplitterCube[25],50], Boundary[100]},PlotType->TopView];
ReadRays[sys,{{ComponentNumber,SurfaceNumber},RefractiveIndex,RayTilt,\
Intensity,Polarization}]\
\>", "Input",
  CellTags->"PolarizingBeamSplitterCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.76503 .35401 -6 -4.5 ]
[.76503 .35401 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .38095 m
.5 .61905 L
.5 .61905 L
.5 .38095 L
.5 .38095 L
s
.7381 .38095 m
.7381 .61905 L
.7381 .61905 L
.7381 .38095 L
.7381 .38095 L
s
.7381 .61905 m
.5 .61905 L
.5 .61905 L
.7381 .61905 L
.7381 .61905 L
s
.5 .38095 m
.7381 .38095 L
.7381 .38095 L
.5 .38095 L
.5 .38095 L
s
.7381 .38095 m
.7381 .61905 L
.5 .61905 L
.5 .38095 L
.7381 .38095 L
s
.7381 .61905 m
.7381 .38095 L
.5 .38095 L
.5 .61905 L
.7381 .61905 L
s
.5 g
.7381 .38095 m
.5 .61905 L
.5 .61905 L
.7381 .38095 L
.7381 .38095 L
F
0 g
.7381 .38095 m
.5 .61905 L
.5 .61905 L
.7381 .38095 L
.7381 .38095 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.11905 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.61905 .5 L
s
0 0 0 r
2 Mabswid
.61905 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.61905 .5 m
.7381 .5 L
s
0 0 0 r
2 Mabswid
.7381 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.61905 .5 m
.61905 .38095 L
s
0 0 0 r
2 Mabswid
.61905 .38095 Mdot
.039 .916 .04 r
.5 Mabswid
.7381 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.61905 .38095 m
.61905 .02381 L
s
0 0 0 r
2 Mabswid
.61905 .02381 Mdot
[(BS)] .76503 .35401 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
Z03oool2000006D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03o
ool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?oo
o`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`03
00WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?oo
o`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:
0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?oo
o`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo
0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<0
2NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X
0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo
06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0
oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo
00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0
oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09
jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0
oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0
I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3o
ool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool0
0`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3o
ool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ
2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03o
ool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?oo
o`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`03
00WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?oo
o`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:
0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?oo
o`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo
0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<0
2NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X
0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0:P0oooo00<02NX:0?ooo`3oool08@3oool4
00000080oooo00@000000?ooo`0000000000>@3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo0280oooo00D000000?ooo`3oool000000?oo
o`0200000080oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo0280oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`800000>03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`2X0?ooo`0300WZ2P3oool0oooo0280oooo0`0000030?ooo`<00000>@3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo0280oooo00D00000
0?ooo`3oool000000?ooo`0200000080oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo0280oooo00H00000
0?ooo`3oool000000?ooo`0000020?ooo`800000>03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`2X0?ooo`0300WZ2P3oool0oooo0240oooo100000030?ooo`80000000<0
oooo0000003oool0=`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`2X
0?ooo`0300WZ2P3oool0oooo06@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0Z03oool00`09jPX0oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0:P0oooo00<02NX:0000003oool0I03oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooob80000000<02NX:0000000000008@0000130?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool07`3o
ool00`09jPX0oooo0?ooo`0N0?ooo`800000A03oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool07@3oool0
0`000000oooo000000140?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0L0?ooo`040000003oool0oooo
000004@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo01/0oooo00D000000?ooo`3oool0oooo00000014
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool07`3oool00`09jPX0oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo01l0oooo00<02NX:0?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo01P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0G0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool05P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo
01D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool07`3oool00`09jPX0
oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0oooo
00<02NX:0?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`0O0?ooo`0300WZ2P3oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool0403oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo00l0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0>0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool03@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0
oooo00`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool07`3oool00`09
jPX0oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0
oooo00<02NX:0?ooo`3oool02P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`0O0?ooo`0300WZ2P3oool0oooo00T0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool01`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo00H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`050?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool0
103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P3o
ool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool07`3oool0
0`09jPX0oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
01l0oooo00D02NX:0?ooo`3oool0oooo0000000M0?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0O0?oo
o`0400WZ2P3oool0oooo000001h0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01l0oooo00<02NX:0?oo
o`0000007`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo0P00000P0?ooo`0300WZ2P000000oooo01l0oooo0P0000120?ooo`80
00001`3oool000H0oooo00<000000?ooo`3oool06@3ooooe00WZ2P8000001`3oool000H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00D000000?ooo`3oool0oooo0000000o0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool010000000oooo0?ooo`0000100?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo000000110?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool200000480oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooodH00000@`3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`80
0000o`3ooolA0?ooo`030000003oool0oooo00D0oooo00060?ooool00000500000070?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"PolarizingBeamSplitterCube"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{\({1, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", \({1.`, 0.`, 0.`}\), ",", 
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 7}\), ",", 
            StyleBox["1.51947243256730679`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "100.`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 2}\), ",", 
            StyleBox["1.51947243256730679`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "24.9999999999999955`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.866025403784438907`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.500000000000000088`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                RowBox[{"-", 
                  StyleBox["180.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 4}\), ",", 
            StyleBox["1.51947243256730679`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{"0", ",", 
                RowBox[{"-", 
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], ",", "0"}], "}"}], ",", 
            "74.9999999999999822`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.866025403784438552`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({2, 1}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0", ",", "0"}], "}"}], ",", 
            "24.9999999999999955`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.866025403784438907`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.500000000000000088`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                RowBox[{"-", 
                  StyleBox["180.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({2, 2}\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{"0", ",", 
                RowBox[{"-", 
                  StyleBox["1.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], ",", "0"}], "}"}], ",", 
            "74.9999999999999822`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.866025403784438552`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"PolarizingBeamSplitterCube"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Using Polarizers from the ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  "'s Database"
}], "Section",
  CellTags->"Using polarizer database"],

Cell[CellGroupData[{

Cell["DataToRayica[FresnelRhomb,FullForm->True]", "Input",
  CellTags->"Using polarizer database"],

Cell[BoxData[
    TagBox[\(FresnelRhomb[
        10, {DefaultAngleSetting \[Rule] 54.7000000000000063`, 
          FullForm \[Rule] True}]\),
      HoldForm]], "Output",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[DataToRayica[FresnelRhomb,FullForm->True]];", "Input",
  CellTags->"Using polarizer database"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .65724 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.00834 -0.141778 1.00834 [
[ 0 0 0 0 ]
[ 1 .65724 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .65724 L
0 .65724 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.61289 .41659 m
.85281 .15322 L
s
.61665 .55179 m
.61289 .41659 L
s
.61289 .41659 m
.15953 .38509 L
s
.52046 .3124 m
.61289 .41659 L
s
.15953 .38509 m
.04177 .27754 L
s
.14743 .52137 m
.15953 .38509 L
s
.8665 .29643 m
.61665 .55179 L
s
.52105 .45104 m
.61665 .55179 L
s
.61665 .55179 m
.14743 .52137 L
s
.14743 .52137 m
.02464 .41725 L
s
.7617 .01913 m
.52046 .3124 L
s
.52105 .45104 m
.52046 .3124 L
s
.52046 .3124 m
.04177 .27754 L
s
.04177 .27754 m
.02464 .41725 L
s
.77243 .16552 m
.52105 .45104 L
s
.02464 .41725 m
.52105 .45104 L
s
.85281 .15322 m
.8665 .29643 L
s
.85281 .15322 m
.7617 .01913 L
s
.8665 .29643 m
.77243 .16552 L
s
.7617 .01913 m
.77243 .16552 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 189.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000_B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00fP3oool00`000000oooo0?ooo`130?ooo`00fP3oool00`000000oooo0?ooo`130?ooo`00
f@3oool3000004@0oooo003H0?ooo`050000003oool000000?ooo`000000@`3oool00=L0oooo00H0
00000?ooo`3oool000000?ooo`0000130?ooo`00eP3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0@03oool00=D0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool000000440oooo003E0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000110?ooo`00e03oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
0000@03oool00=<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo03d0oooo003B0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0l0?ooo`00d@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0?03oool00=40oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo03/0oooo003@0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0j0?ooo`00c`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0>P3oool00<h0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03T0oooo003=
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0h
0?ooo`00c03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0>03oool00<`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo03L0oooo003;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0f0?ooo`00bP3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0=P3oool00<T0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03D0oooo00380?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0d0?ooo`00b03oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0=03oool00<L0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03<0oooo
00360?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0b0?ooo`00a@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0<P3oool00<@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0340oooo00330?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0`0?ooo`00``3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0;`3oool00<80oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02l0oooo00310?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0^0?ooo`00`03oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0;@3oool00;l0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02d0
oooo002n0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0/0?ooo`00_P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0:`3oool00;d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo02/0oooo002l0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0Z0?ooo`00^`3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0:@3oool00;X0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02T0oooo002j0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool04`3oool2000002/0oooo002i0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool04P3oool00`000000oooo0000000[0?ooo`00^03oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool00000:`3oool0
0;L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo
0?ooo`000000:`3oool00;H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0000000@0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool00;D0oooo00<000000?ooo`3o
ool08`3oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0X0?ooo`00]@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02P0
oooo002d0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0:03oool00;<0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0X0?ooo`00/P3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo02P0oooo002a0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0:03oool00;40oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0X0?ooo`00
/03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0
oooo0000000<0?ooo`030000003oool0oooo02P0oooo002_0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool03P3oool00`000000oooo0000000=0?ooo`030000003oool0oooo02P0oooo
002^0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03`3oool2000000l0oooo00<0
00000?ooo`3oool09`3oool00:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0@
0?ooo`8000003`3oool00`000000oooo0?ooo`0W0?ooo`00[03oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo0100oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0W
0?ooo`00[03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02L0oooo002[0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool09`3oool00:X0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0W0?ooo`00Z@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo02L0oooo002X0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool09`3oool0
0:L0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0W0?ooo`00Y`3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo02L0oooo002V0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool09`3oool00:D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0V0?ooo`00Y03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02H0oooo002S0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool09P3oool00:<0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0V0?ooo`00XP3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo02H0oooo002Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool09P3o
ool00:00oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0V0?ooo`00W`3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool06P3oool01@00
0000oooo0?ooo`3oool0000002P0oooo002N0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0K0?ooo`050000003oool0oooo0?ooo`000000:03oool0
00`0oooo2000002:0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0M0?ooo`040000003oool0oooo000002P0oooo000<0?ooo`030000003oool00000
00D0oooo3P00001k0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0O0?ooo`040000003oool0oooo000002L0oooo000<0?ooo`040000003oool0oooo
00000180oooo3@00001]0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0P0?ooo`040000003oool0oooo000002L0oooo000<0?ooo`050000003oool0
oooo0?ooo`0000007P3oool>000005h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0280oooo00<000000?ooo`0000009`3oool000`0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0Y0?ooo`h00000C`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0903oool2000002L0oooo000;0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0=P3oool=00000480oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool09@3oool000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`120?ooo`h0
0000<`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0U0?ooo`002`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo04l0oooo3P00000T0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo000;0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0G03oool=000001H0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3o
ool000/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1X0?ooo`h000001`3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0X0?ooo`002`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
07D0oooo1`00000R0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0Y0?ooo`002`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo07X0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0:P3oool000/0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`1i0?ooo`8000007`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0:`3oool000X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0000001d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo02`0oooo000:0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0M`3oool010000000oooo0?ooo`00000L0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0]0?ooo`002P3oool00`000000oooo0?ooo`0?
0?ooo`800000M`3oool01@000000oooo0?ooo`3oool0000001X0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02h0oooo000:0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo02l0oooo000:0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo0300oooo000:0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0340
oooo000:0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0L@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo0380oooo000:0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0L03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03<0oooo0009
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo03@0oooo00090?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0KP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03D0oooo00090?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo03H0oooo00090?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
K03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03L0oooo00090?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo03P0oooo00090?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0JP3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03T0oooo00090?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
03X0oooo00090?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0J03oool00`000000
oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo03/0oooo00080?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0I`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000140oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0l0?ooo`00203oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo06H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0?@3oool000P0oooo00<000000?ooo`3oool08P3o
ool800000600oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000@0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0?P3oool000P0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`050?ooo`l00000D@3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0
oooo000000h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0o0?ooo`00203oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01@0oooo3P0000130?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0@03oool000P0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0R0?ooo`l00000=03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
0440oooo00080?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0<@3oool>000002H0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`120?ooo`00203oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo03l0oooo3P00000H0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0@`3oool000L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`1=0?ooo`l000002@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04@0oooo0007
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0G@3oool>000000D0oooo00<00000
0?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool0A@3o
ool000L0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo0080oooo3`0000050?ooo`030000003oool0000002H0oooo00<000000?ooo`3oool0AP3oool0
00L0oooo2@00000L0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`090?ooo`L000009P3oool00`000000oooo0?ooo`170?ooo`002@3oool00`000000
oooo0?ooo`040?oooa000000303oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04P0
oooo000:0?ooo`030000003oool0oooo01<0oooo3`00001V0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo04T0oooo
000;0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04000001F0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo04X0oooo000<0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0403oool@
000004H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0B`3oool000d0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0P0?oooa000000=P3oool01@000000oooo0?ooo`3oool0000001D0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`1<0?ooo`003P3oool2000001`0oooo00<000000?oo
o`3oool0<03oool@000002H0oooo00@000000?ooo`3oool000005P3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo04d0oooo000@0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0@03oool?000001L0oooo00<000000?ooo`0000005`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo04h0oooo000A0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0C`3oool@000000L0oooo0P00000H0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0C`3oool00180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1O0?ooo`P00000
6@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0500oooo000C0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0D@3oool001@0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`1X0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`1B0?ooo`005@3oool2000001@0oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0D`3oool001L0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1D0?ooo`00603oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo05D0oooo000I0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0K03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0EP3oool001X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1]
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1G
0?ooo`006`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo06h0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05P0oooo000L0?ooo`80
00003@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`1I0?ooo`007P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0700oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo05X0oooo000O0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0L@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0F`3o
ool00200oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1b0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1L0?ooo`008@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo05d0oooo000R0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0GP3oool002<0oooo0P0000050?ooo`030000003oool0oooo07H0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05l0oooo
000U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0H03oool002H0oooo00D00000
0?ooo`3oool0oooo0000001i0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`1Q0?ooo`009`3oool010000000oooo0?ooo`00001j0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1R0?ooo`00:03oool0
0`000000oooo0000001k0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1S0?ooo`00:@3oool2000007`0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo06@0oooo000Z0?ooo`T00000M@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0I@3oool003<0oooo
4@00001U0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1V0?ooo`00A03ooolA000005D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo06L0oooo001E0?oooa400000A@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0J03oool006H0oooo4000000f0?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`1Y0?ooo`00MP3ooolA0000
02H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1Z0?ooo`00Q`3ooolA0000
01H0oooo00D000000?ooo`000000oooo0000001]0?ooo`00V03ooolA000000H0oooo0`00001^0?oo
o`00Z@3oool8000006l0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {188.25, 0}} -> {-0.00100033, 0.140602, \
0.00346247, 0.00346247}},
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[LinearPolarizer]", "Input",
  CellTags->"Using polarizer database"],

Cell[BoxData[
    \({Labels \[Rule] "LP", LabelPositions \[Rule] Automatic, 
      ComponentMedium \[Rule] Automatic, 
      ComponentDescription \[Rule] Automatic, Transmittance \[Rule] {100, 0}, 
      GraphicDesign \[Rule] Automatic, SplitRays \[Rule] False, 
      Automatic \[Rule] {SurfaceRendering \[Rule] Trace, 
          CrossRendering \[Rule] Trace}, 
      Sketch \[Rule] {SurfaceRendering \[Rule] Trace, 
          CrossRendering \[Rule] Trace}, 
      Wire \[Rule] {SurfaceRendering \[Rule] Mesh, 
          CrossRendering \[Rule] Empty}, 
      Solid \[Rule] {SurfaceRendering \[Rule] {Fill, Trace}, 
          CrossRendering \[Rule] Empty}}\)], "Output",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{

Cell["?LinearPolarizer", "Input",
  CellTags->"Using polarizer database"],

Cell[BoxData[
    \("LinearPolarizer[axisangle, aperture, options] is a flat surface optic \
used to create linearly polarized rays along an axis of alignment given by \
axisangle. \n\nThe axisangle parameter, given in Degrees, determines the \
direction of the first polarization state along the optical surface with \
respect to the horizontal axis of the local surface coordinate system. The \
Transmission->{first, second} option can be also used to weight the outgoing \
intensity of each polarization direction, where first and second can be \
either a number between 0 and 100, a list of {wavelength,transmission} \
values, or a Function-headed expression that depends on ray options such as \
WaveLength. Otherwise, ModelIntensity[componentmedium] = {first,second} can \
be defined to hold two absorption functions or two lists of \
{wavelength,transmission} values. See also: Polarization, LinearPolarization, \
RetardationPlate, and JonesMatrixOptic."\)], "Print",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DataToRayica[LinearPolarizer]", "Input",
  CellTags->"Using polarizer database"],

Cell[BoxData[
    TagBox[\(LinearPolarizer[90, 50, {ComponentMedium \[Rule] HN22}]\),
      HoldForm]], "Output",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{

Cell["?HN22", "Input",
  CellTags->"Using polarizer database"],

Cell[BoxData[
    \("HN22 is an optical material from Polaroid with a transmittance of \
{46.2466, 0.00158929} at the 0.5876 micron wavelength. The transmittance \
model for this Polaroid Type HN22 Polarizing Material is valid from 0.38 to \
0.85 microns of wavelength."\)], "Print",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{SingleRay[], \
Move[DataToRayica[LinearPolarizer],50], Boundary[100]},PlotType->TopView];
ReadRays[sys,{Intensity,Polarization}]\
\>", "Input",
  CellTags->"Using polarizer database"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.5 .22381 -6 -4.5 ]
[.5 .22381 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .2619 m
.5 .30159 L
.5 .34127 L
.5 .38095 L
.5 .42063 L
.5 .46032 L
.5 .5 L
.5 .53968 L
.5 .57937 L
.5 .61905 L
.5 .65873 L
.5 .69841 L
.5 .7381 L
.5 .7381 L
.5 .69841 L
.5 .65873 L
.5 .61905 L
.5 .57937 L
.5 .53968 L
.5 .5 L
.5 .46032 L
.5 .42063 L
.5 .38095 L
.5 .34127 L
.5 .30159 L
.5 .2619 L
.5 .2619 L
s
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
s
.5 .7381 m
.5 .73606 L
.5 .72998 L
.5 .71997 L
.5 .7062 L
.5 .68889 L
.5 .66836 L
.5 .64494 L
.5 .61905 L
.5 .59112 L
.5 .56162 L
.5 .53108 L
.5 .5 L
.5 .46892 L
.5 .43838 L
.5 .40888 L
.5 .38095 L
.5 .35506 L
.5 .33164 L
.5 .31111 L
.5 .2938 L
.5 .28003 L
.5 .27002 L
.5 .26394 L
.5 .2619 L
.5 .26394 L
.5 .27002 L
.5 .28003 L
.5 .2938 L
.5 .31111 L
.5 .33164 L
.5 .35506 L
.5 .38095 L
.5 .40888 L
.5 .43838 L
.5 .46892 L
.5 .5 L
.5 .53108 L
.5 .56162 L
.5 .59112 L
.5 .61905 L
.5 .64494 L
.5 .66836 L
.5 .68889 L
.5 .7062 L
.5 .71997 L
.5 .72998 L
.5 .73606 L
.5 .7381 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(LP)] .5 .22381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P03oool500000004
0?ooo`0000000000000008H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0P@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`030?ooo`<00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000Q03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`200?ooo`<000000`3oool4000008D0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`800000QP3oool2000000L0oooo0006
0?ooool02NX:4P09jPX2000000L0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`800000o`3ooolA0?ooo`030000003oool0oooo
00D0oooo00060?ooool00000500000070?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"Using polarizer database"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"51.8587364436000175`", ",", 
            RowBox[{"{", 
              RowBox[{"0.`", ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReadData[CatalogNumber,LinearPolarizer]", "Input",
  CellTags->"Using polarizer database"],

Cell[BoxData[
    \({"HN22", "HN32", "HN36", "HN42"}\)], "Output",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{SingleRay[], Move[DataToRayica[HN32],50], \
Boundary[100]},PlotType->TopView];
ReadRays[sys,{Intensity,Polarization}]\
\>", "Input",
  CellTags->"Using polarizer database"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.5 .22381 -6 -4.5 ]
[.5 .22381 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .2619 m
.5 .30159 L
.5 .34127 L
.5 .38095 L
.5 .42063 L
.5 .46032 L
.5 .5 L
.5 .53968 L
.5 .57937 L
.5 .61905 L
.5 .65873 L
.5 .69841 L
.5 .7381 L
.5 .7381 L
.5 .69841 L
.5 .65873 L
.5 .61905 L
.5 .57937 L
.5 .53968 L
.5 .5 L
.5 .46032 L
.5 .42063 L
.5 .38095 L
.5 .34127 L
.5 .30159 L
.5 .2619 L
.5 .2619 L
s
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
s
.5 .7381 m
.5 .73606 L
.5 .72998 L
.5 .71997 L
.5 .7062 L
.5 .68889 L
.5 .66836 L
.5 .64494 L
.5 .61905 L
.5 .59112 L
.5 .56162 L
.5 .53108 L
.5 .5 L
.5 .46892 L
.5 .43838 L
.5 .40888 L
.5 .38095 L
.5 .35506 L
.5 .33164 L
.5 .31111 L
.5 .2938 L
.5 .28003 L
.5 .27002 L
.5 .26394 L
.5 .2619 L
.5 .26394 L
.5 .27002 L
.5 .28003 L
.5 .2938 L
.5 .31111 L
.5 .33164 L
.5 .35506 L
.5 .38095 L
.5 .40888 L
.5 .43838 L
.5 .46892 L
.5 .5 L
.5 .53108 L
.5 .56162 L
.5 .59112 L
.5 .61905 L
.5 .64494 L
.5 .66836 L
.5 .68889 L
.5 .7062 L
.5 .71997 L
.5 .72998 L
.5 .73606 L
.5 .7381 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(LP)] .5 .22381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P03oool500000004
0?ooo`0000000000000008H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0P@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`030?ooo`<00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000Q03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`200?ooo`<000000`3oool4000008D0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`800000QP3oool2000000L0oooo0006
0?ooool02NX:4P09jPX2000000L0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`800000o`3ooolA0?ooo`030000003oool0oooo
00D0oooo00060?ooool00000500000070?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"Using polarizer database"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"68.6731390023999921`", ",", 
            RowBox[{"{", 
              RowBox[{"0.`", ",", 
                StyleBox["0.999999999999999822`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{SingleRay[], Move[DataToRayica[HN38],50], \
Boundary[100]}];
ReadRays[sys,{Intensity,Polarization}]\
\>", "Input",
  CellTags->"Using polarizer database"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.42216 .58164 m
.10855 .26104 L
s
.91022 .42206 m
.42216 .58164 L
s
.40598 1.06315 m
.42216 .58164 L
s
.66497 .02988 m
.91022 .42206 L
s
.91022 .42206 m
.97657 .93008 L
s
.40598 1.06315 m
.97657 .93008 L
s
.02877 .79167 m
.40598 1.06315 L
s
.58304 .57122 m
.58829 .59007 L
s
.57688 .55258 m
.58304 .57122 L
s
.5699 .5344 m
.57688 .55258 L
s
.58829 .59007 m
.59255 .60885 L
s
.5622 .51694 m
.5699 .5344 L
s
.59255 .60885 m
.59576 .6273 L
s
.55387 .50045 m
.5622 .51694 L
s
.59576 .6273 m
.59787 .64517 L
s
.54503 .48518 m
.55387 .50045 L
s
.59787 .64517 m
.59883 .66217 L
s
.039 .916 .04 r
.25961 .66843 m
.52632 .58304 L
s
0 g
.5358 .47137 m
.54503 .48518 L
s
.59883 .66217 m
.59862 .67805 L
s
.59883 .66217 m
.58723 .64951 L
s
.59883 .66217 m
.59883 .66217 L
s
.52632 .45924 m
.5358 .47137 L
s
.59862 .67805 m
.5972 .69256 L
s
.51671 .44901 m
.52632 .45924 L
s
.52632 .45924 m
.52632 .45924 L
s
.52632 .45924 m
.52632 .47918 L
s
.58723 .64951 m
.57544 .63664 L
s
.5972 .69256 m
.5946 .70544 L
s
.10855 .26104 m
.66497 .02988 L
s
.02877 .79167 m
.10855 .26104 L
s
.50713 .44086 m
.51671 .44901 L
s
.52632 .49939 m
.52632 .47918 L
s
.57544 .63664 m
.56346 .62357 L
s
.5946 .70544 m
.59081 .71647 L
s
.52632 .49939 m
.52632 .51988 L
s
.49773 .43498 m
.50713 .44086 L
s
.56346 .62357 m
.55128 .61028 L
s
.59081 .71647 m
.58587 .72542 L
s
.52632 .51988 m
.52632 .54064 L
s
.48866 .43151 m
.49773 .43498 L
s
.55128 .61028 m
.5389 .59677 L
s
.58587 .72542 m
.57984 .73209 L
s
.52632 .54064 m
.52632 .5617 L
s
.48009 .43056 m
.48866 .43151 L
s
.5389 .59677 m
.52632 .58304 L
s
.52632 .58304 m
.52632 .5617 L
s
.57984 .73209 m
.57279 .73632 L
s
.47216 .43223 m
.48009 .43056 L
s
.52632 .58304 m
.52632 .60468 L
s
.039 .916 .04 r
.52632 .58304 m
.82351 .48789 L
s
0 0 0 r
2 Mabswid
.52632 .58304 Mdot
0 g
.5 Mabswid
.52632 .58304 m
.51352 .56908 L
s
.57279 .73632 m
.56481 .73796 L
s
.46504 .43654 m
.47216 .43223 L
s
.52632 .60468 m
.52632 .62663 L
s
.51352 .56908 m
.50051 .55488 L
s
.56481 .73796 m
.55603 .73694 L
s
.52632 .62663 m
.52632 .64888 L
s
.45887 .44349 m
.46504 .43654 L
s
.50051 .55488 m
.48727 .54044 L
s
.55603 .73694 m
.54657 .73319 L
s
.52632 .64888 m
.52632 .67145 L
s
.45378 .45301 m
.45887 .44349 L
s
.48727 .54044 m
.47381 .52575 L
s
.54657 .73319 m
.53661 .72671 L
s
.52632 .67145 m
.52632 .69435 L
s
.44991 .465 m
.45378 .45301 L
s
.47381 .52575 m
.46011 .5108 L
s
.52632 .69435 m
.52632 .71758 L
s
.53661 .72671 m
.52632 .71758 L
s
.97657 .93008 m
.6952 .58531 L
s
.44735 .47927 m
.44991 .465 L
s
.52632 .71758 m
.52632 .71758 L
s
.46011 .5108 m
.44618 .4956 L
s
.52632 .71758 m
.51588 .7059 L
s
.44618 .4956 m
.44735 .47927 L
s
.51588 .7059 m
.50551 .69187 L
s
.44644 .51369 m
.44618 .4956 L
s
.44618 .4956 m
.44618 .4956 L
s
.50551 .69187 m
.4954 .67571 L
s
0 0 0 r
2 Mabswid
.82351 .48789 Mdot
0 g
.5 Mabswid
.44816 .53323 m
.44644 .51369 L
s
.4954 .67571 m
.48578 .65772 L
s
.45132 .55382 m
.44816 .53323 L
s
.48578 .65772 m
.47683 .63826 L
s
.45587 .57505 m
.45132 .55382 L
s
.47683 .63826 m
.46875 .61772 L
s
.46172 .5965 m
.45587 .57505 L
s
.46875 .61772 m
.46172 .5965 L
s
.6952 .58531 m
.66497 .02988 L
s
.6952 .58531 m
.02877 .79167 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400049000182000`400?l00000o`00003oo`3oool:
0?ooo`00o`3oool:0?ooo`00o`3oool:0?ooo`00o`3oool:0?ooo`00o`3oool:0?ooo`00o`3oool:
0?ooo`00o`3oool:0?ooo`00o`3oool:0?ooo`00[P3oool2000005T0oooo002[0?ooo`<0000000<0
oooo0000003oool0F03oool00:T0oooo0P0000040?ooo`800000F03oool00:L0oooo0P0000060?oo
o`030000003oool0000005L0oooo002T0?ooo`<00000203oool00`000000oooo0000001G0?ooo`00
XP3oool2000000/0oooo00@000000?ooo`3oool00000EP3oool00:00oooo0P00000=0?ooo`040000
003oool0oooo000005H0oooo002M0?ooo`<000003`3oool01@000000oooo0?ooo`3oool0000005D0
oooo002K0?ooo`8000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0580oooo
002H0?ooo`<00000503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0580oooo002F
0?ooo`800000603oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0540oooo002D0?oo
o`8000006P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0500oooo002A0?ooo`<0
0000703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0500oooo002?0?ooo`800000
7`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04l0oooo002=0?ooo`8000008@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04l0oooo002:0?ooo`<000008`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo04h0oooo00280?ooo`8000009P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo04d0oooo00260?ooo`800000:03oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo04d0oooo00230?ooo`<00000:P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo04`0oooo00210?ooo`800000;@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo04/0oooo001n0?ooo`<00000;`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo04/0oooo001l0?ooo`800000<P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo04X0oooo001j0?ooo`800000=03oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo04X0oooo001g0?ooo`<00000=P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo04T0oooo001e0?ooo`800000>@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo04P0oooo001c0?ooo`800000>`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo04P0oooo001`0?ooo`<00000?@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
04L0oooo001^0?ooo`800000@03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04H0
oooo001[0?ooo`<00000@P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04H0oooo
001Y0?ooo`800000AP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04D0oooo001W
0?ooo`800000B03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04D0oooo001T0?oo
o`<00000BP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04@0oooo001R0?ooo`80
0000C@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04<0oooo001P0?ooo`800000
C`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04<0oooo001M0?ooo`<00000D@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0480oooo001K0?ooo`800000E03oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0440oooo001H0?ooo`<00000EP3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0440oooo001F0?ooo`800000F@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0400oooo001D0?ooo`800000F`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0400oooo001A0?ooo`<00000G@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo03l0oooo001?0?ooo`800000H03oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo03h0oooo001=0?ooo`800000HP3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo03h0oooo001:0?ooo`<00000I03oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo03d0oooo00180?ooo`800000I`3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo03`0oooo00150?ooo`<00000J@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo03`0oooo00130?ooo`800000K03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo03/0oooo00110?ooo`800000KP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
03/0oooo000n0?ooo`<00000L@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03X0
oooo000l0?ooo`800000M03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03T0oooo
000j0?ooo`800000MP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03T0oooo000g
0?ooo`<00000N03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03P0oooo000e0?oo
o`800000N`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03L0oooo000c0?ooo`80
0000O@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03L0oooo000`0?ooo`<00000
O`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03H0oooo000^0?ooo`800000PP3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03H0oooo000[0?ooo`<00000Q03oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03D0oooo000Y0?ooo`800000Q`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo000W0?ooo`800000R@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo000T0?ooo`<00000R`3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo03<0oooo000R0?ooo`800000SP3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0380oooo000P0?ooo`800000T03oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo0380oooo000M0?ooo`<00000TP3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo0340oooo000L0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0a0?ooo`00703oool00`000000oooo0?ooo`2C0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0<03oool001`0oooo0P00002D0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0;`3oool001`0oooo00<000000?ooo`000000U03oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02l0oooo000K0?ooo`050000003oool0oooo
0?ooo`000000T`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02h0oooo000K0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo02d0oooo000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02d0oooo000K0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo02`0oooo000K0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02`0oooo000K0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo02/0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R`3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo02X0oooo000J0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02X0
oooo000J0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0R@3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo02T0oooo000J0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0R03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo000J
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02P0oooo000J0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02L0oooo000J0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02L0oooo000J0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
Q03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02H0oooo000I0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo02D0oooo000I0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0PP3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02D0oooo000I0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
02@0oooo000I0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0P03oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo02<0oooo000I0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02<0oooo
000I0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo0280oooo000H0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0OP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0280oooo000H0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo0240oooo000H0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0200oooo000H0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo0200oooo000H0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0NP3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01l0oooo000H0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo01h0oooo000H0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo01h0oooo000G0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01d0
oooo000G0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0MP3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo01d0oooo000G0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0M@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01`0oooo000G
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo01/0oooo000G0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01/0oooo000G0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo01X0oooo000G0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01T0oooo000F0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo01T0oooo000F0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
01P0oooo000F0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0KP3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo01L0oooo000F0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0f0?ooo`<00000603oool001H0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo03<0oooo0`00
00020?ooo`030000003oool0oooo01H0oooo000E0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0<`3oool4000003@0oooo00<000000?ooo`3oool0<03oool3000000D0oooo00<00000
0?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0`0?oo
o`800000103oool200000380oooo00<000000?ooo`3oool0;@3oool3000000P0oooo00<000000?oo
o`3oool05P3oool001D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo00H0oooo0`00000_0?ooo`030000003oool0oooo02X0oooo0`00000;0?ooo`03
0000003oool0oooo01H0oooo000E0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
9`3oool3000000l0oooo00<000000?ooo`3oool05@3oool001D0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0T0?ooo`<000004P3oool00`000000oooo0?ooo`0E0?ooo`005@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0240oooo0`00000E0?ooo`030000003oool0
oooo01D0oooo000E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool07P3oool30000
01P0oooo00<000000?ooo`3oool05@3oool001@0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0K0?ooo`<000006`3oool00`000000oooo0?ooo`0E0?ooo`00503oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo01P0oooo0`00000N0?ooo`030000003oool0oooo01D0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool05@3oool300000240oooo00<0
00000?ooo`3oool05@3oool001@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo0180oooo0P00000X0?ooo`030000003oool0oooo0180oooo0`00000U
0?ooo`030000003oool0oooo01@0oooo000D0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0000002L0oooo00<000000?oo
o`3oool03`3oool3000002P0oooo00<000000?ooo`3oool0503oool001@0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0180oooo00<000000?ooo`00
00009`3oool00`000000oooo0?ooo`0;0?ooo`@00000:`3oool00`000000oooo0?ooo`0D0?ooo`00
503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
4P3oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo00P0oooo0`00000_0?ooo`03
0000003oool0oooo01@0oooo000C0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000009P3oool00`000000
oooo0?ooo`040?ooo`<00000<P3oool00`000000oooo0?ooo`0D0?ooo`004`3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02<0oooo00@000000?ooo`3oool0oooo0`00000K0?ooo`03
00WZ2P000000000001L0oooo00<000000?ooo`3oool0503oool001<0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0S0?ooo`@000006`3oool300WZ2P030?ooo`000000000001L0oooo
00<000000?ooo`3oool0503oool001<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0J0?ooo`800000503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0200oooo0`00
000K0?ooo`<02NX:7@3oool00`000000oooo0?ooo`0D0?ooo`004`3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01d0oooo0`0000020?ooo`030000003oool0oooo01H0oooo0`09jPXQ
0?ooo`030000003oool0oooo01<0oooo000C0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0603oool2000001@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?oo
o`<000001@3oool00`000000oooo0?ooo`0C0?ooo`<02NX:903oool00`000000oooo0?ooo`0C0?oo
o`004P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01L0oooo00<000000?ooo`00
00004`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo0`0000080?ooo`03
0000003oool0oooo0100oooo0`09jPXW0?ooo`030000003oool0oooo01<0oooo000B0?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0000000B0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool3000000/0oooo00<000000?ooo`3oool0
3@3oool300WZ2RX0oooo00<000000?ooo`3oool04`3oool00180oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0?0?ooo`<000003P3oool00`000000oooo0?ooo`0:0?ooo`<02NX:
;@3oool00`000000oooo0?ooo`0C0?ooo`004P3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo01D0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02`3oool300000140oooo00<000000?ooo`3oool01`3oool300WZ2S00oooo
00<000000?ooo`3oool04`3oool00180oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00P0oooo0`00000D0?ooo`030000003oool0oooo00@0oooo0`09
jPXc0?ooo`030000003oool0oooo01<0oooo000B0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`<000005`3oool010000000oooo0?ooo`3o
ool300WZ2SL0oooo00<000000?ooo`3oool04P3oool00180oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00@000006P3oool0100000002NX:00WZ2P09
jPXj0?ooo`030000003oool0oooo0180oooo000A0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool01`3oool3000001`0oooo0P09jPX00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo0180oooo000A0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool30000
00030?ooo`000000oooo01T0oooo0`09jPX20?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool04P3oool00140oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`3oool30000
00@0oooo00<000000?ooo`3oool05@3oool300WZ2PD0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0B0?ooo`004@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`@00000203oool00`000000
oooo0?ooo`0A0?ooo`<02NX:203oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0180
oooo000A0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00@0oooo0`00000;0?ooo`030000003oool0oooo00h0oooo
0`09jPX;0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool04P3oool00140oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00`0000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3o
ool300WZ2Ph0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0A0?ooo`004@3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool3
000000D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`<02NX:4P3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0140oooo000@0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`<0000000<0oooo0000
003oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo0`09jPXE0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool04@3oool00100oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo0`0000050?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0300WZ2QP0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0A0?ooo`00403oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`0000090?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02`3oool300WZ2Q/0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0A0?ooo`00403oool00`000000oooo0?ooo`1I0?ooo`030000003o
ool0oooo00P0oooo0`00000=0?ooo`050000003oool0oooo0?ooo`0000002P3oool300WZ2P030000
003oool0oooo01/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0A0?ooo`00403o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00@0oooo0`0000000`3oool000000?oo
o`0>0?ooo`040000003oool0oooo000000L0oooo0`09jPX40?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0A0?ooo`00403oool00`000000oooo0?oo
o`1K0?ooo`030000003oool0oooo00<00000103oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0000000@0oooo0`09jPX70?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1M0?ooo`8000001`3oool0
0`000000oooo0?ooo`0?0?ooo`80000000@0oooo00WZ2P09jPX02NX:2P3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0403oool000l0oooo00<00000
0?ooo`3oool0G@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00@02NX:
0000000000002NX:3P3oool00`000000oooo0?ooo`0G0?ooo`<00000?P3oool00`000000oooo0?oo
o`0@0?ooo`003`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool02P3oool300WZ2P80oooo0P00000>0?ooo`030000003oool0oooo01@0oooo0`000002
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0403oool000l0oooo00<000000?oo
o`3oool0G@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0`09jPX50?oo
o`030000003oool0000000d0oooo00<000000?ooo`3oool04@3oool3000000H0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`1M0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool300WZ2PP0oooo00@000000?ooo`3o
ool00000303oool00`000000oooo0?ooo`0>0?ooo`<000002P3oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo0100oooo000?0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3o
ool0203oool00`000000oooo00WZ2P0300WZ2P/0oooo00@000000?ooo`3oool00000303oool00`00
0000oooo0?ooo`0;0?ooo`<000003P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
0100oooo000?0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool01`3oool00`09jPX0
000000WZ2P0?0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`060?oo
o`@000004P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0100oooo000>0?ooo`03
0000003oool0oooo05h0oooo00<000000?ooo`3oool0103oool300WZ2P030?ooo`000000oooo00l0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0
oooo0`00000G0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool03`3oool000h0oooo
00<000000?ooo`3oool0GP3oool010000000oooo0?ooo`3oool300WZ2PD0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00`00000J0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool03`3oool000h0oooo
00<000000?ooo`3oool0GP3oool0100000002NX:00WZ2P09jPX80?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`<000007P3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo00l0oooo000>0?ooo`030000003oool0oooo05/0oooo
1009jPX;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`<0000000<0oooo0000003oool07`3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo00l0oooo000>0?ooo`030000003oool0oooo05P0oooo0`09jPX30?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`D00000103o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool03`3o
ool000h0oooo00<000000?ooo`3oool0E@3oool300WZ2PH0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo100000070?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0?0?ooo`003P3oool00`00
0000oooo0?ooo`1B0?ooo`<02NX:2@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00/0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00l0oooo000=0?oo
o`030000003oool0oooo04l0oooo1009jPX<0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02`3oool4000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3o
ool0C03oool300WZ2Q00oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`<0
0000303oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0>0?ooo`003@3oool00`000000oooo0?ooo`190?ooo`<02NX:
4`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo100000020?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool03P3oool000d0oooo00<000000?ooo`3oool0AP3o
ool300WZ2QD0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`03000000H0oooo00<0
00000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000002D0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0>0?ooo`003@3oool00`000000oooo0?ooo`130?ooo`<02NX:603o
ool00`000000oooo0?ooo`0>0?ooo`<000002@3oool00`000000oooo0?ooo`0=0?ooo`040000003o
ool0oooo000002H0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0>0?ooo`003@3o
ool00`000000oooo0?ooo`0o0?ooo`@02NX:6`3oool00`000000oooo0?ooo`0;0?ooo`@000002`3o
ool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0>0?ooo`00303oool00`000000oooo0?ooo`0m0?ooo`<02NX:7`3o
ool00`000000oooo0?ooo`080?ooo`<00000103oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`0000009`3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo00h0oooo000<0?ooo`030000003oool0oooo03X0oooo0`09jPXR0?ooo`030000003oool0
oooo00@0oooo100000070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool2
000002P0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0>0?ooo`00303oool00`00
0000oooo0?ooo`0g0?ooo`<02NX:9@3oool010000000oooo0?ooo`3oool3000000`0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0=0?ooo`00303oool00`000000oooo0?ooo`0e0?oo
o`802NX::03oool4000000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0=0?oo
o`00303oool00`000000oooo0?ooo`1M0?ooo`<000004P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo00d0oooo000<0?ooo`030000003oool0oooo05X0oooo0`0000020?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0=0?ooo`00303o
ool00`000000oooo0?ooo`1F0?ooo`@000001@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool03@3oool000/0oooo00<000000?ooo`3oool0E03oool3
000000T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00d0oooo000;0?ooo`030000003oool0oooo0540oooo0`00000<0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0=0?ooo`002`3oool00`000000
oooo0?ooo`1>0?ooo`<000003`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool03@3oool000/0oooo00<000000?ooo`3oool0B`3oool300000180oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00`0oooo
000;0?ooo`030000003oool0oooo04L0oooo1000000E0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0<0?ooo`002`3oool00`000000oooo0?ooo`14
0?ooo`<000006@3oool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`0000004@3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0303o
ool000/0oooo00<000000?ooo`3oool0@@3oool3000001`0oooo00<000000?ooo`3oool05`3oool0
10000000oooo0?ooo`00000A0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0<0?ooo`002P3oool00`000000oooo0?ooo`0o0?ooo`<000007`3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool000000140oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo000:0?ooo`030000003oool0oooo
03`0oooo0`00000R0?ooo`030000003oool0oooo01T0oooo0P00000@0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0<0?ooo`002P3oool00`000000
oooo0?ooo`0h0?ooo`@000009@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00`0
oooo000:0?ooo`030000003oool0oooo03D0oooo0`00000Y0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool02`3oool000X0oooo00<000000?ooo`3oool0<P3oool3000002`0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0;0?ooo`002P3oool00`000000oooo0?ooo`0_
0?ooo`<00000;`3oool00`000000oooo0?ooo`0L0?ooo`<000002P3oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool02`3oool000T0oooo00<000000?oo
o`3oool0;@3oool300000380oooo00<000000?ooo`3oool07`3oool2000000H0oooo0P00000m0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool02`3oool000T0oooo00<000000?ooo`3o
ool0:@3oool4000003D0oooo00<000000?ooo`3oool08@3oool3000000030?ooo`00000000000400
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0;0?ooo`002@3oool00`000000oooo
0?ooo`0V0?ooo`<00000>@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0;0?ooo`002@3oool00`000000oooo0?oo
o`0S0?ooo`<00000?03oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool02`3oool000T0oooo00<000000?ooo`3oool0803oool3000003l0oooo00<00000
0?ooo`3oool0J@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00/0oooo00090?oo
o`030000003oool0oooo01d0oooo0`0000120?ooo`030000003oool0oooo06X0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`002@3oool00`000000oooo0?ooo`0I0?ooo`@0
0000A@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool02P3oool000P0oooo00<000000?ooo`3oool05`3oool3000004T0oooo00<000000?ooo`3oool0
K03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00X0oooo00080?ooo`030000003o
ool0oooo01@0oooo0`00001<0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0:0?ooo`00203oool00`000000oooo0?ooo`0A0?ooo`<00000CP3oool0
0`000000oooo0?ooo`1^0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02P3oool0
00P0oooo00<000000?ooo`3oool03P3oool300000540oooo00<000000?ooo`3oool0K`3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00X0oooo00080?ooo`030000003oool0oooo00X0
oooo1000001D0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0:0?ooo`00203oool00`000000oooo0?ooo`070?ooo`<00000F03oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool000P0oooo00<0
00000?ooo`3oool0103oool3000005/0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00T0oooo00070?ooo`030000003oool0oooo0080oooo0`00001N
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`09
0?ooo`001`3oool00`000000oooo0000000200000640oooo00<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00T0oooo00070?ooo`800000I03oool00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool000T0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool000/0oooo0P00001P
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`08
0?ooo`003@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`080?ooo`003P3oool2000005d0oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000@0?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00P0oooo000A0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0NP3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo000B0?ooo`800000F@3oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool0
01@0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0203oool001D0oooo0P00001F0?ooo`030000003oool0oooo07`0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`005`3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`070?ooo`00603oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo07h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`006@3oool200000580oooo00<00000
0?ooo`3oool0O`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo000K0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00L0oooo000L0?ooo`800000C`3oool00`000000oooo0?ooo`200?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool001h0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
1`3oool001l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool01`3oool00200oooo0P00001;0?ooo`030000003oool0
oooo08<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`008P3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`060?ooo`008`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo08@0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`00903oool2000004L0oooo
00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo
000V0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo000W0?ooo`800000A03oool00`000000oooo0?ooo`27
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool002T0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool002X0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool002/0oooo0P00000o0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`00;@3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`00;P3oool2000003`0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo000`0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo000a0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0SP3oool01@000000
oooo0?ooo`3oool0000000L0oooo000b0?ooo`800000>03oool00`000000oooo0?ooo`2>0?ooo`05
0000003oool0oooo0?ooo`0000001`3oool003@0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`2?0?ooo`040000003oool0oooo000000L0oooo000e0?ooo`800000=@3oool00`000000
oooo0?ooo`2@0?ooo`040000003oool0oooo000000H0oooo000g0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool0T@3oool00`000000oooo000000060?ooo`00>03oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo0980oooo0P0000060?ooo`00>@3oool200000340oooo00<0
00000?ooo`3oool0T@3oool3000000H0oooo000k0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0S@3oool4000000T0oooo000l0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0R@3oool4000000d0oooo000m0?ooo`800000;@3oool00`000000oooo0?ooo`240?ooo`D0
00004@3oool003l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`200?ooo`@00000
5P3oool00400oooo0P00000Z0?ooo`030000003oool0oooo07`0oooo1000000J0?ooo`00@P3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo07P0oooo1000000N0?ooo`00@`3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo07@0oooo1000000R0?ooo`00A03oool2000002H0
oooo00<000000?ooo`3oool0K`3oool5000002H0oooo00160?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0J`3oool4000002/0oooo00170?ooo`8000008`3oool00`000000oooo0?oo
o`1W0?ooo`@00000;`3oool004T0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1S
0?ooo`@00000<`3oool004X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1O0?oo
o`@00000=`3oool004/0oooo0P00000O0?ooo`030000003oool0oooo05X0oooo1@00000k0?ooo`00
C@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05H0oooo100000100?ooo`00CP3o
ool2000001`0oooo00<000000?ooo`3oool0DP3oool4000004@0oooo001@0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0CP3oool4000004P0oooo001A0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0BP3oool4000004`0oooo001B0?ooo`800000603oool00`000000
oooo0?ooo`150?ooo`D00000D03oool005@0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`110?ooo`@00000E@3oool005D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0m0?ooo`@00000F@3oool005H0oooo0P00000C0?ooo`030000003oool0oooo03X0oooo1000001M
0?ooo`00F03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03H0oooo1000001Q0?oo
o`00F@3oool200000100oooo00<000000?ooo`3oool0<@3oool5000006D0oooo001K0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0;@3oool4000006X0oooo001L0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0:@3oool4000006h0oooo001M0?ooo`800000303oool0
0`000000oooo0?ooo`0U0?ooo`@00000LP3oool005l0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0Q0?ooo`@00000MP3oool00600oooo0P0000090?ooo`030000003oool0oooo01`0
oooo1@00001j0?ooo`00HP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01P0oooo
1000001o0?ooo`00H`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo1000
00230?ooo`00I03oool2000000D0oooo00<000000?ooo`3oool0403oool4000008L0oooo001V0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool4000008/0oooo001W0?ooo`80
00000P3oool00`000000oooo0?ooo`070?ooo`D00000S`3oool006T0oooo00<000000?ooo`000000
1@3oool4000009@0oooo001Z0?ooo`80000000<0oooo0000000000000P00002H0?ooo`00J`3oool2
000009`0oooo003o0?ooo`X0oooo003o0?ooo`X0oooo003o0?ooo`X0oooo003o0?ooo`X0oooo003o
0?ooo`X0oooo0000\
\>"],
  ImageRangeCache->{{{0, 264.312}, {287, 0}} -> {0.0486402, -0.000148683, \
0.00324458, 0.00324458}},
  CellTags->"Using polarizer database"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"80.2568841464800186`", ",", 
            RowBox[{"{", 
              RowBox[{"0.`", ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{SingleRay[], Move[DataToRayica[HN42],50], \
Boundary[100]},PlotType->TopView];
ReadRays[sys,{Intensity,Polarization}]\
\>", "Input",
  CellTags->"Using polarizer database"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.5 .22381 -6 -4.5 ]
[.5 .22381 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .2619 m
.5 .30159 L
.5 .34127 L
.5 .38095 L
.5 .42063 L
.5 .46032 L
.5 .5 L
.5 .53968 L
.5 .57937 L
.5 .61905 L
.5 .65873 L
.5 .69841 L
.5 .7381 L
.5 .7381 L
.5 .69841 L
.5 .65873 L
.5 .61905 L
.5 .57937 L
.5 .53968 L
.5 .5 L
.5 .46032 L
.5 .42063 L
.5 .38095 L
.5 .34127 L
.5 .30159 L
.5 .2619 L
.5 .2619 L
s
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
s
.5 .7381 m
.5 .73606 L
.5 .72998 L
.5 .71997 L
.5 .7062 L
.5 .68889 L
.5 .66836 L
.5 .64494 L
.5 .61905 L
.5 .59112 L
.5 .56162 L
.5 .53108 L
.5 .5 L
.5 .46892 L
.5 .43838 L
.5 .40888 L
.5 .38095 L
.5 .35506 L
.5 .33164 L
.5 .31111 L
.5 .2938 L
.5 .28003 L
.5 .27002 L
.5 .26394 L
.5 .2619 L
.5 .26394 L
.5 .27002 L
.5 .28003 L
.5 .2938 L
.5 .31111 L
.5 .33164 L
.5 .35506 L
.5 .38095 L
.5 .40888 L
.5 .43838 L
.5 .46892 L
.5 .5 L
.5 .53108 L
.5 .56162 L
.5 .59112 L
.5 .61905 L
.5 .64494 L
.5 .66836 L
.5 .68889 L
.5 .7062 L
.5 .71997 L
.5 .72998 L
.5 .73606 L
.5 .7381 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(LP)] .5 .22381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P03oool500000004
0?ooo`0000000000000008H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0P@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`030?ooo`<00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000Q03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`200?ooo`<000000`3oool4000008D0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`800000QP3oool2000000L0oooo0006
0?ooool02NX:4P09jPX2000000L0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`800000o`3ooolA0?ooo`030000003oool0oooo
00D0oooo00060?ooool00000500000070?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"Using polarizer database"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"81.9825871736800237`", ",", 
            RowBox[{"{", 
              RowBox[{"0.`", ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[{SingleRay[Polarization->{1,1,0}], \
Move[DataToRayica[HN42],50], Boundary[100]},PlotType->TopView];
ReadRays[sys,{Intensity,Polarization}]\
\>", "Input",
  CellTags->"Using polarizer database"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[.5 .22381 -6 -4.5 ]
[.5 .22381 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .2619 m
.5 .30159 L
.5 .34127 L
.5 .38095 L
.5 .42063 L
.5 .46032 L
.5 .5 L
.5 .53968 L
.5 .57937 L
.5 .61905 L
.5 .65873 L
.5 .69841 L
.5 .7381 L
.5 .7381 L
.5 .69841 L
.5 .65873 L
.5 .61905 L
.5 .57937 L
.5 .53968 L
.5 .5 L
.5 .46032 L
.5 .42063 L
.5 .38095 L
.5 .34127 L
.5 .30159 L
.5 .2619 L
.5 .2619 L
s
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
s
.5 .7381 m
.5 .73606 L
.5 .72998 L
.5 .71997 L
.5 .7062 L
.5 .68889 L
.5 .66836 L
.5 .64494 L
.5 .61905 L
.5 .59112 L
.5 .56162 L
.5 .53108 L
.5 .5 L
.5 .46892 L
.5 .43838 L
.5 .40888 L
.5 .38095 L
.5 .35506 L
.5 .33164 L
.5 .31111 L
.5 .2938 L
.5 .28003 L
.5 .27002 L
.5 .26394 L
.5 .2619 L
.5 .26394 L
.5 .27002 L
.5 .28003 L
.5 .2938 L
.5 .31111 L
.5 .33164 L
.5 .35506 L
.5 .38095 L
.5 .40888 L
.5 .43838 L
.5 .46892 L
.5 .5 L
.5 .53108 L
.5 .56162 L
.5 .59112 L
.5 .61905 L
.5 .64494 L
.5 .66836 L
.5 .68889 L
.5 .7062 L
.5 .71997 L
.5 .72998 L
.5 .73606 L
.5 .7381 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .5 m
.5 .5 L
s
0 0 0 r
2 Mabswid
.5 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(LP)] .5 .22381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0P03oool500000004
0?ooo`0000000000000008H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0P@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo08D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`030?ooo`<00000Q@3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
Q03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`210?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000Q03oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`200?ooo`<000000`3oool4000008D0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`800000QP3oool2000000L0oooo0006
0?ooool02NX:4P09jPX2000000L0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`800000o`3ooolA0?ooo`030000003oool0oooo
00D0oooo00060?ooool00000500000070?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->"Using polarizer database"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            StyleBox["100.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->16], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["1.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"41.4498938490000057`", ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.105185393984278041`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", 
                StyleBox["0.994452629788051822`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->16], ",", "0.`"}], "}"}]}], "}"}]}], 
      "}"}]], "Output",
  CellTags->"Using polarizer database"]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1920}, {0, 1174}},
WindowSize->{872, 708},
WindowMargins->{{1, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Tracing through a FresnelRhomb"->{
    Cell[1776, 53, 95, 1, 52, "Section",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[1896, 58, 76, 1, 39, "Input",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[1975, 61, 1284, 18, 244, "Print",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[3296, 84, 84, 1, 39, "Input",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[3383, 87, 1336, 26, 178, "Output",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[4756, 118, 95, 1, 39, "Input",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[4854, 121, 181, 4, 38, "Output",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[5072, 130, 164, 3, 39, "Input",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[5239, 135, 19577, 329, 224, 1362, 99, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[24819, 466, 262, 5, 34, "Print",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[25084, 473, 112, 2, 38, "Output",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[25233, 480, 97, 2, 39, "Input",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[25333, 484, 22018, 360, 207, 1296, 99, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[47388, 849, 317, 8, 114, "Input",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[47708, 859, 24392, 469, 223, 2610, 193, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "Cell marked at {1999, 7, 1, 16, 44, 47}", 
        "Tracing through a FresnelRhomb"}],
    Cell[72103, 1330, 5666, 135, 127, "Output",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[77806, 1470, 339, 8, 114, "Input",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[78148, 1480, 35787, 631, 308, 2964, 221, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[113938, 2113, 7732, 184, 157, "Output",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[121707, 2302, 79, 1, 39, "Input",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[121789, 2305, 181, 4, 38, "Output",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[122007, 2314, 130, 2, 39, "Input",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[122140, 2318, 12781, 224, 232, 1118, 75, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[134924, 2544, 233, 5, 34, "Print",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[135160, 2551, 112, 2, 38, "Output",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[135309, 2558, 301, 8, 114, "Input",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[135613, 2568, 30165, 502, 308, 2032, 150, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[165781, 3072, 4342, 105, 97, "Output",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[170160, 3182, 78, 1, 39, "Input",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[170241, 3185, 1002, 14, 184, "Print",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[171280, 3204, 326, 8, 114, "Input",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[171609, 3214, 30190, 503, 308, 2008, 150, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[201802, 3719, 4340, 105, 97, "Output",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[206179, 3829, 380, 9, 129, "Input",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[206584, 3842, 52898, 2462, 308, 24805, 2110, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[259485, 6306, 18153, 471, 198, 4010, 291, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[277687, 6783, 416, 9, 129, "Input",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[278128, 6796, 64948, 3333, 308, 33287, 2937, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Tracing through a FresnelRhomb"],
    Cell[343079, 10131, 22809, 528, 247, 4009, 291, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Tracing through a FresnelRhomb"]},
  "Cell marked at {1999, 7, 1, 16, 44, 47}"->{
    Cell[47708, 859, 24392, 469, 223, 2610, 193, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "Cell marked at {1999, 7, 1, 16, 44, 47}", 
        "Tracing through a FresnelRhomb"}]},
  "LinearPolarizer"->{
    Cell[365949, 10666, 65, 1, 38, "Section",
      CellTags->"LinearPolarizer"],
    Cell[366039, 10671, 72, 1, 39, "Input",
      CellTags->"LinearPolarizer"],
    Cell[366114, 10674, 1071, 20, 135, "Output",
      CellTags->"LinearPolarizer"],
    Cell[367222, 10699, 85, 1, 39, "Input",
      CellTags->"LinearPolarizer"],
    Cell[367310, 10702, 62641, 1755, 308, 17680, 1195, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer"],
    Cell[429954, 12459, 129, 3, 35, "Print",
      CellTags->"LinearPolarizer"],
    Cell[430086, 12464, 97, 2, 39, "Output",
      CellTags->"LinearPolarizer"],
    Cell[430220, 12471, 83, 1, 39, "Input",
      CellTags->"LinearPolarizer"],
    Cell[430306, 12474, 23344, 521, 308, 3266, 267, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"LinearPolarizer"],
    Cell[453653, 12997, 126, 3, 34, "Print",
      CellTags->"LinearPolarizer"],
    Cell[453782, 13002, 97, 2, 38, "Output",
      CellTags->"LinearPolarizer"],
    Cell[453916, 13009, 152, 5, 54, "Input",
      CellTags->"LinearPolarizer"],
    Cell[454071, 13016, 35124, 1409, 308, 16411, 1172, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"LinearPolarizer"],
    Cell[489232, 14430, 133, 4, 39, "Input",
      CellTags->"LinearPolarizer"],
    Cell[489368, 14436, 58220, 1821, 308, 19160, 1334, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer"],
    Cell[547625, 16262, 150, 4, 39, "Input",
      CellTags->"LinearPolarizer"],
    Cell[547778, 16268, 42400, 1498, 385, 16411, 1172, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer"],
    Cell[590215, 17771, 81, 1, 39, "Input",
      CellTags->"LinearPolarizer"],
    Cell[590299, 17774, 648, 9, 151, "Output",
      CellTags->"LinearPolarizer"],
    Cell[590984, 17788, 79, 1, 39, "Input",
      CellTags->"LinearPolarizer"],
    Cell[591066, 17791, 5267, 88, 336, "Output",
      CellTags->"LinearPolarizer"],
    Cell[596370, 17884, 182, 5, 54, "Input",
      CellTags->"LinearPolarizer"],
    Cell[596555, 17891, 29748, 588, 308, 3387, 257, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer"],
    Cell[626306, 18481, 1832, 39, 83, "Print",
      CellTags->"LinearPolarizer"],
    Cell[628141, 18522, 96, 2, 39, "Output",
      CellTags->"LinearPolarizer"],
    Cell[628274, 18529, 286, 7, 69, "Input",
      CellTags->"LinearPolarizer"],
    Cell[628563, 18538, 41825, 1451, 308, 13180, 1092, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer"],
    Cell[670391, 19991, 3219, 83, 71, "Output",
      CellTags->"LinearPolarizer"],
    Cell[673647, 20079, 297, 7, 84, "Input",
      CellTags->"LinearPolarizer"],
    Cell[673947, 20088, 38547, 1534, 308, 15297, 1242, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer"],
    Cell[712497, 21624, 3217, 83, 68, "Output",
      CellTags->"LinearPolarizer"],
    Cell[715751, 21712, 284, 7, 69, "Input",
      CellTags->"LinearPolarizer"],
    Cell[716038, 21721, 26427, 632, 308, 3651, 346, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer"],
    Cell[742468, 22355, 1424, 37, 53, "Output",
      CellTags->"LinearPolarizer"],
    Cell[743929, 22397, 303, 7, 84, "Input",
      CellTags->"LinearPolarizer"],
    Cell[744235, 22406, 43623, 1473, 390, 13180, 1092, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer"],
    Cell[787861, 23881, 3219, 83, 68, "Output",
      CellTags->"LinearPolarizer"],
    Cell[791117, 23969, 281, 7, 69, "Input",
      CellTags->"LinearPolarizer"],
    Cell[791401, 23978, 36430, 1384, 308, 13180, 1092, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer"],
    Cell[827834, 25364, 3217, 83, 68, "Output",
      CellTags->"LinearPolarizer"],
    Cell[831088, 25452, 262, 6, 69, "Input",
      CellTags->"LinearPolarizer"],
    Cell[831353, 25460, 36430, 1384, 308, 13180, 1092, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer"],
    Cell[867786, 26846, 3217, 83, 68, "Output",
      CellTags->"LinearPolarizer"],
    Cell[871040, 26934, 339, 8, 84, "Input",
      CellTags->"LinearPolarizer"],
    Cell[871382, 26944, 45657, 1919, 308, 19600, 1592, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer"],
    Cell[917042, 28865, 3922, 99, 98, "Output",
      CellTags->"LinearPolarizer"],
    Cell[921001, 28969, 339, 8, 84, "Input",
      CellTags->"LinearPolarizer"],
    Cell[921343, 28979, 37651, 1422, 308, 11582, 1095, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer"],
    Cell[958997, 30403, 2971, 75, 87, "Output",
      CellTags->"LinearPolarizer"],
    Cell[962005, 30483, 367, 9, 114, "Input",
      CellTags->"LinearPolarizer"],
    Cell[962375, 30494, 36282, 815, 308, 5782, 433, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer"],
    Cell[998660, 31311, 3051, 79, 71, "Output",
      CellTags->"LinearPolarizer"],
    Cell[1001748, 31395, 68, 1, 39, "Input",
      CellTags->"LinearPolarizer"],
    Cell[1001819, 31398, 4155, 75, 247, "Output",
      CellTags->"LinearPolarizer"],
    Cell[1006011, 31478, 92, 1, 39, "Input",
      CellTags->"LinearPolarizer"],
    Cell[1006106, 31481, 85, 2, 39, "Output",
      CellTags->"LinearPolarizer"]},
  "LinearPolarizer with user-defined surface"->{
    Cell[1006240, 31489, 117, 1, 38, "Section",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1006382, 31494, 125, 1, 39, "Input",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1006510, 31497, 166, 3, 55, "Output",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1006713, 31505, 147, 4, 39, "Input",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1006863, 31511, 21498, 497, 308, 3237, 267, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1028364, 32010, 192, 4, 51, "Print",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1028559, 32016, 123, 2, 38, "Output",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1028719, 32023, 153, 4, 39, "Input",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1028875, 32029, 52951, 1638, 308, 17449, 1195, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1081863, 33672, 241, 5, 54, "Input",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1082107, 33679, 74892, 2657, 308, 31600, 2118, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1157036, 36341, 202, 5, 54, "Input",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1157241, 36348, 32024, 565, 308, 2794, 199, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1189302, 36918, 210, 5, 54, "Input",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1189515, 36925, 33331, 707, 308, 4454, 346, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1222883, 37637, 114, 1, 39, "Input",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1223000, 37640, 149, 3, 38, "Output",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1223186, 37648, 307, 7, 69, "Input",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1223496, 37657, 33331, 707, 308, 4454, 346, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1256830, 38366, 1449, 37, 53, "Output",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1258316, 38408, 207, 5, 69, "Input",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1258526, 38415, 49461, 1575, 283, 17217, 1172, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1308024, 39995, 207, 5, 69, "Input",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1308234, 40002, 40782, 1473, 283, 16768, 1172, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1349053, 41480, 410, 8, 84, "Input",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1349466, 41490, 99879, 3178, 314, 32518, 2342, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LinearPolarizer with user-defined surface"],
    Cell[1449348, 44670, 4864, 124, 98, "Output",
      CellTags->"LinearPolarizer with user-defined surface"]},
  "LinearPolarizer in beamsplitting mode SplitRays->Reflection"->{
    Cell[1454261, 44800, 154, 1, 38, "Section",
      CellTags->
      "LinearPolarizer in beamsplitting mode SplitRays->Reflection"],
    Cell[1454440, 44805, 402, 8, 84, "Input",
      CellTags->
      "LinearPolarizer in beamsplitting mode SplitRays->Reflection"],
    Cell[1454845, 44815, 42570, 1578, 308, 17044, 1258, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->
      "LinearPolarizer in beamsplitting mode SplitRays->Reflection"],
    Cell[1497418, 46395, 4829, 122, 98, "Output",
      CellTags->
      "LinearPolarizer in beamsplitting mode SplitRays->Reflection"],
    Cell[1502284, 46522, 381, 8, 84, "Input",
      CellTags->
      "LinearPolarizer in beamsplitting mode SplitRays->Reflection"],
    Cell[1502668, 46532, 42414, 1562, 308, 16848, 1242, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->
      "LinearPolarizer in beamsplitting mode SplitRays->Reflection"],
    Cell[1545085, 48096, 3356, 85, 71, "Output",
      CellTags->
      "LinearPolarizer in beamsplitting mode SplitRays->Reflection"]},
  "PolarizingBeamSplitterCube"->{
    Cell[1548490, 48187, 87, 1, 38, "Section",
      CellTags->"PolarizingBeamSplitterCube"],
    Cell[1548602, 48192, 101, 1, 27, "Input",
      CellTags->"PolarizingBeamSplitterCube"],
    Cell[1548706, 48195, 34444, 501, 279, 1215, 86, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"PolarizingBeamSplitterCube"],
    Cell[1583153, 48698, 143, 3, 22, "Print",
      CellTags->"PolarizingBeamSplitterCube"],
    Cell[1583299, 48703, 108, 2, 26, "Output",
      CellTags->"PolarizingBeamSplitterCube"],
    Cell[1583444, 48710, 300, 6, 57, "Input",
      CellTags->"PolarizingBeamSplitterCube"],
    Cell[1583747, 48718, 29916, 522, 296, 2252, 175, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"PolarizingBeamSplitterCube"],
    Cell[1613666, 49242, 4295, 113, 71, "Output",
      CellTags->"PolarizingBeamSplitterCube"],
    Cell[1617998, 49360, 296, 6, 57, "Input",
      CellTags->"PolarizingBeamSplitterCube"],
    Cell[1618297, 49368, 29916, 522, 296, 2252, 175, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"PolarizingBeamSplitterCube"],
    Cell[1648216, 49892, 5147, 131, 86, "Output",
      CellTags->"PolarizingBeamSplitterCube"],
    Cell[1653400, 50028, 296, 6, 57, "Input",
      CellTags->"PolarizingBeamSplitterCube"],
    Cell[1653699, 50036, 29916, 522, 296, 2252, 175, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"PolarizingBeamSplitterCube"],
    Cell[1683618, 50560, 5117, 131, 86, "Output",
      CellTags->"PolarizingBeamSplitterCube"]},
  "Using polarizer database"->{
    Cell[1688784, 50697, 165, 6, 38, "Section",
      CellTags->"Using polarizer database"],
    Cell[1688974, 50707, 98, 1, 39, "Input",
      CellTags->"Using polarizer database"],
    Cell[1689075, 50710, 209, 5, 39, "Output",
      CellTags->"Using polarizer database"],
    Cell[1689321, 50720, 111, 1, 39, "Input",
      CellTags->"Using polarizer database"],
    Cell[1689435, 50723, 22423, 365, 210, 1293, 99, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Using polarizer database"],
    Cell[1711895, 51093, 81, 1, 39, "Input",
      CellTags->"Using polarizer database"],
    Cell[1711979, 51096, 710, 13, 119, "Output",
      CellTags->"Using polarizer database"],
    Cell[1712726, 51114, 73, 1, 39, "Input",
      CellTags->"Using polarizer database"],
    Cell[1712802, 51117, 1014, 14, 195, "Print",
      CellTags->"Using polarizer database"],
    Cell[1713853, 51136, 86, 1, 39, "Input",
      CellTags->"Using polarizer database"],
    Cell[1713942, 51139, 153, 3, 39, "Output",
      CellTags->"Using polarizer database"],
    Cell[1714132, 51147, 62, 1, 39, "Input",
      CellTags->"Using polarizer database"],
    Cell[1714197, 51150, 323, 5, 67, "Print",
      CellTags->"Using polarizer database"],
    Cell[1714557, 51160, 211, 5, 69, "Input",
      CellTags->"Using polarizer database"],
    Cell[1714771, 51167, 25179, 485, 308, 2414, 199, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Using polarizer database"],
    Cell[1739953, 51654, 971, 27, 39, "Output",
      CellTags->"Using polarizer database"],
    Cell[1740961, 51686, 96, 1, 39, "Input",
      CellTags->"Using polarizer database"],
    Cell[1741060, 51689, 106, 2, 39, "Output",
      CellTags->"Using polarizer database"],
    Cell[1741203, 51696, 200, 5, 54, "Input",
      CellTags->"Using polarizer database"],
    Cell[1741406, 51703, 25179, 485, 308, 2414, 199, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Using polarizer database"],
    Cell[1766588, 52190, 989, 27, 39, "Output",
      CellTags->"Using polarizer database"],
    Cell[1767614, 52222, 182, 5, 54, "Input",
      CellTags->"Using polarizer database"],
    Cell[1767799, 52229, 39400, 767, 308, 3779, 322, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Using polarizer database"],
    Cell[1807202, 52998, 971, 27, 39, "Output",
      CellTags->"Using polarizer database"],
    Cell[1808210, 53030, 200, 5, 54, "Input",
      CellTags->"Using polarizer database"],
    Cell[1808413, 53037, 25179, 485, 308, 2414, 199, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Using polarizer database"],
    Cell[1833595, 53524, 971, 27, 39, "Output",
      CellTags->"Using polarizer database"],
    Cell[1834603, 53556, 221, 5, 69, "Input",
      CellTags->"Using polarizer database"],
    Cell[1834827, 53563, 25179, 485, 308, 2414, 199, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Using polarizer database"],
    Cell[1860009, 54050, 1116, 30, 39, "Output",
      CellTags->"Using polarizer database"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Tracing through a FresnelRhomb", 1861798, 54100},
  {"Cell marked at {1999, 7, 1, 16, 44, 47}", 1866196, 54192},
  {"LinearPolarizer", 1866428, 54198},
  {"LinearPolarizer with user-defined surface", 1871959, 54328},
  {"LinearPolarizer in beamsplitting mode SplitRays->Reflection", 1875456, \
54392},
  {"PolarizingBeamSplitterCube", 1876545, 54416},
  {"Using polarizer database", 1878109, 54449}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 95, 1, 52, "Section",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[CellGroupData[{
Cell[1896, 58, 76, 1, 39, "Input",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[1975, 61, 1284, 18, 244, "Print",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3296, 84, 84, 1, 39, "Input",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[3383, 87, 1336, 26, 178, "Output",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4756, 118, 95, 1, 39, "Input",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[4854, 121, 181, 4, 38, "Output",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5072, 130, 164, 3, 39, "Input",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[5239, 135, 19577, 329, 224, 1362, 99, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[24819, 466, 262, 5, 34, "Print",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[25084, 473, 112, 2, 38, "Output",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25233, 480, 97, 2, 39, "Input",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[25333, 484, 22018, 360, 207, 1296, 99, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47388, 849, 317, 8, 114, "Input",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[47708, 859, 24392, 469, 223, 2610, 193, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->{
  "Cell marked at {1999, 7, 1, 16, 44, 47}", 
    "Tracing through a FresnelRhomb"}],
Cell[72103, 1330, 5666, 135, 127, "Output",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{
Cell[77806, 1470, 339, 8, 114, "Input",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[78148, 1480, 35787, 631, 308, 2964, 221, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[113938, 2113, 7732, 184, 157, "Output",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{
Cell[121707, 2302, 79, 1, 39, "Input",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[121789, 2305, 181, 4, 38, "Output",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{
Cell[122007, 2314, 130, 2, 39, "Input",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[122140, 2318, 12781, 224, 232, 1118, 75, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[134924, 2544, 233, 5, 34, "Print",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[135160, 2551, 112, 2, 38, "Output",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{
Cell[135309, 2558, 301, 8, 114, "Input",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[135613, 2568, 30165, 502, 308, 2032, 150, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[165781, 3072, 4342, 105, 97, "Output",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{
Cell[170160, 3182, 78, 1, 39, "Input",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[170241, 3185, 1002, 14, 184, "Print",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{
Cell[171280, 3204, 326, 8, 114, "Input",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[171609, 3214, 30190, 503, 308, 2008, 150, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[201802, 3719, 4340, 105, 97, "Output",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{
Cell[206179, 3829, 380, 9, 129, "Input",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[CellGroupData[{
Cell[206584, 3842, 52898, 2462, 308, 24805, 2110, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[259485, 6306, 18153, 471, 198, 4010, 291, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[277687, 6783, 416, 9, 129, "Input",
  CellTags->"Tracing through a FresnelRhomb"],

Cell[CellGroupData[{
Cell[278128, 6796, 64948, 3333, 308, 33287, 2937, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Tracing through a FresnelRhomb"],
Cell[343079, 10131, 22809, 528, 247, 4009, 291, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Tracing through a FresnelRhomb"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[365949, 10666, 65, 1, 38, "Section",
  CellTags->"LinearPolarizer"],

Cell[CellGroupData[{
Cell[366039, 10671, 72, 1, 39, "Input",
  CellTags->"LinearPolarizer"],
Cell[366114, 10674, 1071, 20, 135, "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[367222, 10699, 85, 1, 39, "Input",
  CellTags->"LinearPolarizer"],
Cell[367310, 10702, 62641, 1755, 308, 17680, 1195, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer"],
Cell[429954, 12459, 129, 3, 35, "Print",
  CellTags->"LinearPolarizer"],
Cell[430086, 12464, 97, 2, 39, "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[430220, 12471, 83, 1, 39, "Input",
  CellTags->"LinearPolarizer"],
Cell[430306, 12474, 23344, 521, 308, 3266, 267, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"LinearPolarizer"],
Cell[453653, 12997, 126, 3, 34, "Print",
  CellTags->"LinearPolarizer"],
Cell[453782, 13002, 97, 2, 38, "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[453916, 13009, 152, 5, 54, "Input",
  CellTags->"LinearPolarizer"],
Cell[454071, 13016, 35124, 1409, 308, 16411, 1172, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[489232, 14430, 133, 4, 39, "Input",
  CellTags->"LinearPolarizer"],
Cell[489368, 14436, 58220, 1821, 308, 19160, 1334, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[547625, 16262, 150, 4, 39, "Input",
  CellTags->"LinearPolarizer"],
Cell[547778, 16268, 42400, 1498, 385, 16411, 1172, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[590215, 17771, 81, 1, 39, "Input",
  CellTags->"LinearPolarizer"],
Cell[590299, 17774, 648, 9, 151, "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[590984, 17788, 79, 1, 39, "Input",
  CellTags->"LinearPolarizer"],
Cell[591066, 17791, 5267, 88, 336, "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[596370, 17884, 182, 5, 54, "Input",
  CellTags->"LinearPolarizer"],
Cell[596555, 17891, 29748, 588, 308, 3387, 257, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"LinearPolarizer"],
Cell[626306, 18481, 1832, 39, 83, "Print",
  CellTags->"LinearPolarizer"],
Cell[628141, 18522, 96, 2, 39, "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[628274, 18529, 286, 7, 69, "Input",
  CellTags->"LinearPolarizer"],
Cell[628563, 18538, 41825, 1451, 308, 13180, 1092, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer"],
Cell[670391, 19991, 3219, 83, 71, "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[673647, 20079, 297, 7, 84, "Input",
  CellTags->"LinearPolarizer"],
Cell[673947, 20088, 38547, 1534, 308, 15297, 1242, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer"],
Cell[712497, 21624, 3217, 83, 68, "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[715751, 21712, 284, 7, 69, "Input",
  CellTags->"LinearPolarizer"],
Cell[716038, 21721, 26427, 632, 308, 3651, 346, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"LinearPolarizer"],
Cell[742468, 22355, 1424, 37, 53, "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[743929, 22397, 303, 7, 84, "Input",
  CellTags->"LinearPolarizer"],
Cell[744235, 22406, 43623, 1473, 390, 13180, 1092, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer"],
Cell[787861, 23881, 3219, 83, 68, "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[791117, 23969, 281, 7, 69, "Input",
  CellTags->"LinearPolarizer"],
Cell[791401, 23978, 36430, 1384, 308, 13180, 1092, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer"],
Cell[827834, 25364, 3217, 83, 68, "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[831088, 25452, 262, 6, 69, "Input",
  CellTags->"LinearPolarizer"],
Cell[831353, 25460, 36430, 1384, 308, 13180, 1092, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer"],
Cell[867786, 26846, 3217, 83, 68, "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[871040, 26934, 339, 8, 84, "Input",
  CellTags->"LinearPolarizer"],
Cell[871382, 26944, 45657, 1919, 308, 19600, 1592, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer"],
Cell[917042, 28865, 3922, 99, 98, "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[921001, 28969, 339, 8, 84, "Input",
  CellTags->"LinearPolarizer"],
Cell[921343, 28979, 37651, 1422, 308, 11582, 1095, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer"],
Cell[958997, 30403, 2971, 75, 87, "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[962005, 30483, 367, 9, 114, "Input",
  CellTags->"LinearPolarizer"],
Cell[962375, 30494, 36282, 815, 308, 5782, 433, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"LinearPolarizer"],
Cell[998660, 31311, 3051, 79, 71, "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1001748, 31395, 68, 1, 39, "Input",
  CellTags->"LinearPolarizer"],
Cell[1001819, 31398, 4155, 75, 247, "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1006011, 31478, 92, 1, 39, "Input",
  CellTags->"LinearPolarizer"],
Cell[1006106, 31481, 85, 2, 39, "Output",
  CellTags->"LinearPolarizer"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1006240, 31489, 117, 1, 38, "Section",
  CellTags->"LinearPolarizer with user-defined surface"],

Cell[CellGroupData[{
Cell[1006382, 31494, 125, 1, 39, "Input",
  CellTags->"LinearPolarizer with user-defined surface"],
Cell[1006510, 31497, 166, 3, 55, "Output",
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1006713, 31505, 147, 4, 39, "Input",
  CellTags->"LinearPolarizer with user-defined surface"],
Cell[1006863, 31511, 21498, 497, 308, 3237, 267, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer with user-defined surface"],
Cell[1028364, 32010, 192, 4, 51, "Print",
  CellTags->"LinearPolarizer with user-defined surface"],
Cell[1028559, 32016, 123, 2, 38, "Output",
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1028719, 32023, 153, 4, 39, "Input",
  CellTags->"LinearPolarizer with user-defined surface"],
Cell[1028875, 32029, 52951, 1638, 308, 17449, 1195, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1081863, 33672, 241, 5, 54, "Input",
  CellTags->"LinearPolarizer with user-defined surface"],
Cell[1082107, 33679, 74892, 2657, 308, 31600, 2118, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1157036, 36341, 202, 5, 54, "Input",
  CellTags->"LinearPolarizer with user-defined surface"],
Cell[1157241, 36348, 32024, 565, 308, 2794, 199, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1189302, 36918, 210, 5, 54, "Input",
  CellTags->"LinearPolarizer with user-defined surface"],
Cell[1189515, 36925, 33331, 707, 308, 4454, 346, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1222883, 37637, 114, 1, 39, "Input",
  CellTags->"LinearPolarizer with user-defined surface"],
Cell[1223000, 37640, 149, 3, 38, "Output",
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1223186, 37648, 307, 7, 69, "Input",
  CellTags->"LinearPolarizer with user-defined surface"],
Cell[1223496, 37657, 33331, 707, 308, 4454, 346, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer with user-defined surface"],
Cell[1256830, 38366, 1449, 37, 53, "Output",
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1258316, 38408, 207, 5, 69, "Input",
  CellTags->"LinearPolarizer with user-defined surface"],
Cell[1258526, 38415, 49461, 1575, 283, 17217, 1172, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1308024, 39995, 207, 5, 69, "Input",
  CellTags->"LinearPolarizer with user-defined surface"],
Cell[1308234, 40002, 40782, 1473, 283, 16768, 1172, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1349053, 41480, 410, 8, 84, "Input",
  CellTags->"LinearPolarizer with user-defined surface"],
Cell[1349466, 41490, 99879, 3178, 314, 32518, 2342, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer with user-defined surface"],
Cell[1449348, 44670, 4864, 124, 98, "Output",
  CellTags->"LinearPolarizer with user-defined surface"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1454261, 44800, 154, 1, 38, "Section",
  CellTags->"LinearPolarizer in beamsplitting mode SplitRays->Reflection"],

Cell[CellGroupData[{
Cell[1454440, 44805, 402, 8, 84, "Input",
  CellTags->"LinearPolarizer in beamsplitting mode SplitRays->Reflection"],
Cell[1454845, 44815, 42570, 1578, 308, 17044, 1258, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer in beamsplitting mode SplitRays->Reflection"],
Cell[1497418, 46395, 4829, 122, 98, "Output",
  CellTags->"LinearPolarizer in beamsplitting mode SplitRays->Reflection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1502284, 46522, 381, 8, 84, "Input",
  CellTags->"LinearPolarizer in beamsplitting mode SplitRays->Reflection"],
Cell[1502668, 46532, 42414, 1562, 308, 16848, 1242, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"LinearPolarizer in beamsplitting mode SplitRays->Reflection"],
Cell[1545085, 48096, 3356, 85, 71, "Output",
  CellTags->"LinearPolarizer in beamsplitting mode SplitRays->Reflection"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1548490, 48187, 87, 1, 38, "Section",
  CellTags->"PolarizingBeamSplitterCube"],

Cell[CellGroupData[{
Cell[1548602, 48192, 101, 1, 27, "Input",
  CellTags->"PolarizingBeamSplitterCube"],
Cell[1548706, 48195, 34444, 501, 279, 1215, 86, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"PolarizingBeamSplitterCube"],
Cell[1583153, 48698, 143, 3, 22, "Print",
  CellTags->"PolarizingBeamSplitterCube"],
Cell[1583299, 48703, 108, 2, 26, "Output",
  CellTags->"PolarizingBeamSplitterCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1583444, 48710, 300, 6, 57, "Input",
  CellTags->"PolarizingBeamSplitterCube"],
Cell[1583747, 48718, 29916, 522, 296, 2252, 175, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"PolarizingBeamSplitterCube"],
Cell[1613666, 49242, 4295, 113, 71, "Output",
  CellTags->"PolarizingBeamSplitterCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1617998, 49360, 296, 6, 57, "Input",
  CellTags->"PolarizingBeamSplitterCube"],
Cell[1618297, 49368, 29916, 522, 296, 2252, 175, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"PolarizingBeamSplitterCube"],
Cell[1648216, 49892, 5147, 131, 86, "Output",
  CellTags->"PolarizingBeamSplitterCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1653400, 50028, 296, 6, 57, "Input",
  CellTags->"PolarizingBeamSplitterCube"],
Cell[1653699, 50036, 29916, 522, 296, 2252, 175, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"PolarizingBeamSplitterCube"],
Cell[1683618, 50560, 5117, 131, 86, "Output",
  CellTags->"PolarizingBeamSplitterCube"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1688784, 50697, 165, 6, 38, "Section",
  CellTags->"Using polarizer database"],

Cell[CellGroupData[{
Cell[1688974, 50707, 98, 1, 39, "Input",
  CellTags->"Using polarizer database"],
Cell[1689075, 50710, 209, 5, 39, "Output",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1689321, 50720, 111, 1, 39, "Input",
  CellTags->"Using polarizer database"],
Cell[1689435, 50723, 22423, 365, 210, 1293, 99, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1711895, 51093, 81, 1, 39, "Input",
  CellTags->"Using polarizer database"],
Cell[1711979, 51096, 710, 13, 119, "Output",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1712726, 51114, 73, 1, 39, "Input",
  CellTags->"Using polarizer database"],
Cell[1712802, 51117, 1014, 14, 195, "Print",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1713853, 51136, 86, 1, 39, "Input",
  CellTags->"Using polarizer database"],
Cell[1713942, 51139, 153, 3, 39, "Output",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1714132, 51147, 62, 1, 39, "Input",
  CellTags->"Using polarizer database"],
Cell[1714197, 51150, 323, 5, 67, "Print",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1714557, 51160, 211, 5, 69, "Input",
  CellTags->"Using polarizer database"],
Cell[1714771, 51167, 25179, 485, 308, 2414, 199, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Using polarizer database"],
Cell[1739953, 51654, 971, 27, 39, "Output",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1740961, 51686, 96, 1, 39, "Input",
  CellTags->"Using polarizer database"],
Cell[1741060, 51689, 106, 2, 39, "Output",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1741203, 51696, 200, 5, 54, "Input",
  CellTags->"Using polarizer database"],
Cell[1741406, 51703, 25179, 485, 308, 2414, 199, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Using polarizer database"],
Cell[1766588, 52190, 989, 27, 39, "Output",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1767614, 52222, 182, 5, 54, "Input",
  CellTags->"Using polarizer database"],
Cell[1767799, 52229, 39400, 767, 308, 3779, 322, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Using polarizer database"],
Cell[1807202, 52998, 971, 27, 39, "Output",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1808210, 53030, 200, 5, 54, "Input",
  CellTags->"Using polarizer database"],
Cell[1808413, 53037, 25179, 485, 308, 2414, 199, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Using polarizer database"],
Cell[1833595, 53524, 971, 27, 39, "Output",
  CellTags->"Using polarizer database"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1834603, 53556, 221, 5, 69, "Input",
  CellTags->"Using polarizer database"],
Cell[1834827, 53563, 25179, 485, 308, 2414, 199, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Using polarizer database"],
Cell[1860009, 54050, 1116, 30, 39, "Output",
  CellTags->"Using polarizer database"]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

