(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1626164,      55059]*)
(*NotebookOutlinePosition[   1626881,      55083]*)
(*  CellTagsIndexPosition[   1626837,      55079]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Advaced Surfaces: a seashell", "Section"],

Cell[TextData[{
  "Surfaces of components in ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  " may take arbitrary shapes. In this file, a mirror is defined with the \
shape of a seashell. The shape definition is taken from Alfred Gray, Modern \
Differential Geometry of Curves and Surfaces with Mathematica, CRC Press, 2nd \
ed. 1998 (pages 195, 196, 198, 309)."
}], "Text"],

Cell[CellGroupData[{

Cell["Definition", "Subsection"],

Cell[CellGroupData[{

Cell["Auxiliary Functions", "Subsubsection"],

Cell["First, we define some auxiliary functions.", "Text"],

Cell["\<\
Clear[cross3by3, surfacetangent, surfacenormal, binormal, helix, \
seashell];\
\>", "Input",
  CellLabel->"In[6]:="],

Cell["\<\
cross3by3[u_List, v_List] :=
\tRotateLeft[u*RotateLeft[v] - \
RotateLeft[u]*v]/;Length[u]==Length[v]==3;\
\>", "Input",
  CellLabel->"In[7]:="],

Cell["\<\
surfacetangent[alpha_][t_] := 
\tD[alpha[tt], tt] / 
\tSimplify[Factor[Dot[ D[alpha[tt], tt], D[alpha[tt], tt] ]]]^(1/2) /. tt->t;\
\
\>", "Input",
  CellLabel->"In[8]:="],

Cell["\<\
binormal[alpha_][t_] :=
\tSimplify[cross3by3[D[alpha[tt], tt], D[alpha[tt], {tt, 2}]]] /
\tSimplify[Factor[Dot[
\t\tcross3by3[ D[alpha[tt], tt], D[alpha[tt], {tt, 2}] ],
\t\tcross3by3[ D[alpha[tt], tt], D[alpha[tt], {tt, 2}] ]
\t]]]^(1/2) /. tt-> t;\
\>", "Input",
  CellLabel->"In[9]:="],

Cell["\<\
surfacenormal[alpha_][t_] := Cross[binormal[alpha][t], \
surfacetangent[alpha][t]];\
\>", "Input",
  CellLabel->"In[10]:="],

Cell["The surface is constructed with a helix.", "Text"],

Cell["helix[a_, b_][t_] := {a*Cos[t], a*Sin[t], b*t};", "Input",
  CellLabel->"In[11]:="],

Cell["\<\
seashell[curve_][r_][t_, theta_] :=
\tcurve[t] +
\tr*t*(-Cos[theta]*surfacenormal[curve][t] + Sin[theta]*binormal[curve][t])\
\
\>", "Input",
  CellLabel->"In[12]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Shape", "Subsubsection"],

Cell["Here is the plot of the surface.", "Text"],

Cell[CellGroupData[{

Cell["\<\
ParametricPlot3D[
\tEvaluate[
\t\tseashell[
\t\t\thelix[1, 0.6]
\t\t][0.1][t, theta]
\t],
\t{t, 1.75*Pi, 4.75*Pi},
\t{theta, 0, 2*Pi},
\tPlotPoints -> {48, 20},
\tBoxed -> False,
\tAxes -> None
];\
\>", "Input",
  CellLabel->"In[13]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.4833 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.230727 1.49617 0 1.49617 [
[ 0 0 0 0 ]
[ 1 1.4833 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.4833 L
0 1.4833 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.52953 .67565 m .57538 .6539 L .55356 .62774 L p .694 .543 .677 r
F P
0 g
s
.55356 .62774 m .50942 .64619 L .52953 .67565 L p .694 .543 .677 r
F P
0 g
s
.59433 .60401 m .55356 .62774 L .57538 .6539 L p .658 .515 .678 r
F P
0 g
s
.50942 .64619 m .55356 .62774 L .53124 .60037 L p .731 .615 .728 r
F P
0 g
s
.55356 .62774 m .59433 .60401 L .56942 .58021 L p .703 .591 .727 r
F P
0 g
s
.56942 .58021 m .53124 .60037 L .55356 .62774 L p .703 .591 .727 r
F P
0 g
s
.48103 .69167 m .52953 .67565 L .50942 .64619 L p .729 .571 .677 r
F P
0 g
s
.50942 .64619 m .46344 .65908 L .48103 .69167 L p .729 .571 .677 r
F P
0 g
s
.46344 .65908 m .50942 .64619 L .49064 .61555 L p .758 .641 .732 r
F P
0 g
s
.53124 .60037 m .49064 .61555 L .50942 .64619 L p .731 .615 .728 r
F P
0 g
s
.49064 .61555 m .53124 .60037 L .51065 .57453 L p .763 .688 .779 r
F P
0 g
s
.53124 .60037 m .56942 .58021 L .54477 .5578 L p .742 .663 .772 r
F P
0 g
s
.54477 .5578 m .51065 .57453 L .53124 .60037 L p .742 .663 .772 r
F P
0 g
s
.60381 .55543 m .56942 .58021 L .59433 .60401 L p .673 .569 .729 r
F P
0 g
s
.56942 .58021 m .60381 .55543 L .57617 .53681 L p .721 .642 .769 r
F P
0 g
s
.57617 .53681 m .54477 .5578 L .56942 .58021 L p .721 .642 .769 r
F P
0 g
s
.50011 .72008 m .54899 .70098 L .52953 .67565 L p .69 .491 .613 r
F P
0 g
s
.52953 .67565 m .48103 .69167 L .50011 .72008 L p .69 .491 .613 r
F P
0 g
s
.57538 .6539 m .52953 .67565 L .54899 .70098 L p .646 .457 .613 r
F P
0 g
s
.49064 .61555 m .4491 .62557 L .46344 .65908 L p .758 .641 .732 r
F P
0 g
s
.4491 .62557 m .49064 .61555 L .4751 .58678 L p .783 .715 .788 r
F P
0 g
s
.51065 .57453 m .4751 .58678 L .49064 .61555 L p .763 .688 .779 r
F P
0 g
s
.57538 .6539 m .617 .6268 L .59433 .60401 L p .658 .515 .678 r
F P
0 g
s
.63029 .57546 m .59433 .60401 L .617 .6268 L p .618 .488 .682 r
F P
0 g
s
.59433 .60401 m .63029 .57546 L .60381 .55543 L p .673 .569 .729 r
F P
0 g
s
.43151 .70178 m .48103 .69167 L .46344 .65908 L p .762 .602 .679 r
F P
0 g
s
.46344 .65908 m .41724 .66631 L .43151 .70178 L p .762 .602 .679 r
F P
0 g
s
.41724 .66631 m .46344 .65908 L .4491 .62557 L p .785 .671 .738 r
F P
0 g
s
.54899 .70098 m .5945 .67622 L .57538 .6539 L p .646 .457 .613 r
F P
0 g
s
.617 .6268 m .57538 .6539 L .5945 .67622 L p .596 .42 .613 r
F P
0 g
s
.44951 .73328 m .50011 .72008 L .48103 .69167 L p .731 .525 .613 r
F P
0 g
s
.48103 .69167 m .43151 .70178 L .44951 .73328 L p .731 .525 .613 r
F P
0 g
s
.63313 .52652 m .60381 .55543 L .63029 .57546 L p .642 .549 .734 r
F P
0 g
s
.60381 .55543 m .63313 .52652 L .60366 .51194 L p .698 .623 .769 r
F P
0 g
s
.60366 .51194 m .57617 .53681 L .60381 .55543 L p .698 .623 .769 r
F P
0 g
s
.51065 .57453 m .54477 .5578 L .52286 .53902 L p .782 .747 .821 r
F P
0 g
s
.54477 .5578 m .57617 .53681 L .55017 .52146 L p .768 .721 .809 r
F P
0 g
s
.55017 .52146 m .52286 .53902 L .54477 .5578 L p .768 .721 .809 r
F P
0 g
s
.4491 .62557 m .40812 .63041 L .41724 .66631 L p .785 .671 .738 r
F P
0 g
s
.40812 .63041 m .4491 .62557 L .43946 .59448 L p .802 .746 .801 r
F P
0 g
s
.4751 .58678 m .43946 .59448 L .4491 .62557 L p .783 .715 .788 r
F P
0 g
s
.4751 .58678 m .51065 .57453 L .49388 .55285 L p .794 .775 .836 r
F P
0 g
s
.52286 .53902 m .49388 .55285 L .51065 .57453 L p .782 .747 .821 r
F P
0 g
s
.5945 .67622 m .63511 .64626 L .617 .6268 L p .596 .42 .613 r
F P
0 g
s
.65296 .59487 m .617 .6268 L .63511 .64626 L p .537 .378 .613 r
F P
0 g
s
.617 .6268 m .65296 .59487 L .63029 .57546 L p .618 .488 .682 r
F P
0 g
s
.57617 .53681 m .60366 .51194 L .57473 .50041 L p .751 .697 .8 r
F P
0 g
s
.57473 .50041 m .55017 .52146 L .57617 .53681 L p .751 .697 .8 r
F P
0 g
s
.66016 .5427 m .63029 .57546 L .65296 .59487 L p .572 .46 .688 r
F P
0 g
s
.63029 .57546 m .66016 .5427 L .63313 .52652 L p .642 .549 .734 r
F P
0 g
s
.38271 .70595 m .43151 .70178 L .41724 .66631 L p .796 .636 .683 r
F P
0 g
s
.41724 .66631 m .37249 .66793 L .38271 .70595 L p .796 .636 .683 r
F P
0 g
s
.37249 .66793 m .41724 .66631 L .40812 .63041 L p .812 .705 .747 r
F P
0 g
s
.3989 .74048 m .44951 .73328 L .43151 .70178 L p .771 .56 .613 r
F P
0 g
s
.43151 .70178 m .38271 .70595 L .3989 .74048 L p .771 .56 .613 r
F P
0 g
s
.51879 .74139 m .56579 .71955 L .54899 .70098 L p .628 .379 .522 r
F P
0 g
s
.54899 .70098 m .50011 .72008 L .51879 .74139 L p .628 .379 .522 r
F P
0 g
s
.5945 .67622 m .54899 .70098 L .56579 .71955 L p .566 .329 .516 r
F P
0 g
s
.43946 .59448 m .4751 .58678 L .4644 .56284 L p .802 .806 .854 r
F P
0 g
s
.49388 .55285 m .4644 .56284 L .4751 .58678 L p .794 .775 .836 r
F P
0 g
s
.46946 .7576 m .51879 .74139 L .50011 .72008 L p .681 .423 .525 r
F P
0 g
s
.50011 .72008 m .44951 .73328 L .46946 .7576 L p .681 .423 .525 r
F P
0 g
s
.6563 .49415 m .63313 .52652 L .66016 .5427 L p .608 .53 .741 r
F P
0 g
s
.63313 .52652 m .6563 .49415 L .62618 .48371 L p .674 .606 .771 r
F P
0 g
s
.62618 .48371 m .60366 .51194 L .63313 .52652 L p .674 .606 .771 r
F P
0 g
s
.56579 .71955 m .60893 .69237 L .5945 .67622 L p .566 .329 .516 r
F P
0 g
s
.63511 .64626 m .5945 .67622 L .60893 .69237 L p .489 .267 .503 r
F P
0 g
s
.60366 .51194 m .62618 .48371 L .59552 .47625 L p .734 .676 .794 r
F P
0 g
s
.59552 .47625 m .57473 .50041 L .60366 .51194 L p .734 .676 .794 r
F P
0 g
s
.40812 .63041 m .36925 .63024 L .37249 .66793 L p .812 .705 .747 r
F P
0 g
s
.36925 .63024 m .40812 .63041 L .40511 .59771 L p .818 .78 .817 r
F P
0 g
s
.43946 .59448 m .40511 .59771 L .40812 .63041 L p .802 .746 .801 r
F P
0 g
s
.41945 .76802 m .46946 .7576 L .44951 .73328 L p .73 .463 .524 r
F P
0 g
s
.44951 .73328 m .3989 .74048 L .41945 .76802 L p .73 .463 .524 r
F P
0 g
s
.49388 .55285 m .52286 .53902 L .50598 .52587 L p .821 .86 .877 r
F P
0 g
s
.52286 .53902 m .55017 .52146 L .52848 .511 L p .819 .823 .852 r
F P
0 g
s
.52848 .511 m .50598 .52587 L .52286 .53902 L p .819 .823 .852 r
F P
0 g
s
.55017 .52146 m .57473 .50041 L .54927 .49314 L p .81 .788 .832 r
F P
0 g
s
.54927 .49314 m .52848 .511 L .55017 .52146 L p .81 .788 .832 r
F P
0 g
s
.63511 .64626 m .66945 .61169 L .65296 .59487 L p .537 .378 .613 r
F P
0 g
s
.682 .55884 m .65296 .59487 L .66945 .61169 L p .463 .328 .612 r
F P
0 g
s
.65296 .59487 m .682 .55884 L .66016 .5427 L p .572 .46 .688 r
F P
0 g
s
.40511 .59771 m .43946 .59448 L .43559 .56903 L p .805 .839 .876 r
F P
0 g
s
.4644 .56284 m .43559 .56903 L .43946 .59448 L p .802 .806 .854 r
F P
0 g
s
.68284 .50652 m .66016 .5427 L .682 .55884 L p .518 .431 .696 r
F P
0 g
s
.66016 .5427 m .68284 .50652 L .6563 .49415 L p .608 .53 .741 r
F P
0 g
s
.57473 .50041 m .59552 .47625 L .56745 .47254 L p .797 .755 .815 r
F P
0 g
s
.56745 .47254 m .54927 .49314 L .57473 .50041 L p .797 .755 .815 r
F P
0 g
s
.4644 .56284 m .49388 .55285 L .48274 .53763 L p .811 .897 .903 r
F P
0 g
s
.50598 .52587 m .48274 .53763 L .49388 .55285 L p .821 .86 .877 r
F P
0 g
s
.60893 .69237 m .64674 .66035 L .63511 .64626 L p .489 .267 .503 r
F P
0 g
s
.66945 .61169 m .63511 .64626 L .64674 .66035 L p .385 .184 .48 r
F P
0 g
s
.6428 .4528 m .62618 .48371 L .6563 .49415 L p .65 .591 .775 r
F P
0 g
s
.62618 .48371 m .6428 .4528 L .61168 .4495 L p .715 .658 .791 r
F P
0 g
s
.61168 .4495 m .59552 .47625 L .62618 .48371 L p .715 .658 .791 r
F P
0 g
s
.35005 .74176 m .3989 .74048 L .38271 .70595 L p .812 .599 .614 r
F P
0 g
s
.38271 .70595 m .33639 .70433 L .35005 .74176 L p .812 .599 .614 r
F P
0 g
s
.33639 .70433 m .38271 .70595 L .37249 .66793 L p .831 .674 .689 r
F P
0 g
s
.37249 .66793 m .33086 .66418 L .33639 .70433 L p .831 .674 .689 r
F P
0 g
s
.33086 .66418 m .37249 .66793 L .36925 .63024 L p .838 .745 .76 r
F P
0 g
s
.67241 .45912 m .6563 .49415 L .68284 .50652 L p .57 .512 .751 r
F P
0 g
s
.6563 .49415 m .67241 .45912 L .6428 .4528 L p .65 .591 .775 r
F P
0 g
s
.59552 .47625 m .61168 .4495 L .58218 .44955 L p .781 .726 .802 r
F P
0 g
s
.58218 .44955 m .56745 .47254 L .59552 .47625 L p .781 .726 .802 r
F P
0 g
s
.48933 .77212 m .53512 .75329 L .51879 .74139 L p .583 .251 .372 r
F P
0 g
s
.51879 .74139 m .46946 .7576 L .48933 .77212 L p .583 .251 .372 r
F P
0 g
s
.56579 .71955 m .51879 .74139 L .53512 .75329 L p .5 .177 .351 r
F P
0 g
s
.53512 .75329 m .57817 .72931 L .56579 .71955 L p .5 .177 .351 r
F P
0 g
s
.60893 .69237 m .56579 .71955 L .57817 .72931 L p .39 .077 .31 r
F P
0 g
s
.43559 .56903 m .4644 .56284 L .45975 .54629 L p .785 .928 .929 r
F P
0 g
s
.48274 .53763 m .45975 .54629 L .4644 .56284 L p .811 .897 .903 r
F P
0 g
s
.37048 .77266 m .41945 .76802 L .3989 .74048 L p .778 .503 .52 r
F P
0 g
s
.3989 .74048 m .35005 .74176 L .37048 .77266 L p .778 .503 .52 r
F P
0 g
s
.40511 .59771 m .37341 .59671 L .36925 .63024 L p .818 .78 .817 r
F P
0 g
s
.37341 .59671 m .40511 .59771 L .40863 .5716 L p .799 .871 .901 r
F P
0 g
s
.43559 .56903 m .40863 .5716 L .40511 .59771 L p .805 .839 .876 r
F P
0 g
s
.44232 .78563 m .48933 .77212 L .46946 .7576 L p .65 .308 .38 r
F P
0 g
s
.46946 .7576 m .41945 .76802 L .44232 .78563 L p .65 .308 .38 r
F P
0 g
s
.66945 .61169 m .69631 .57327 L .682 .55884 L p .463 .328 .612 r
F P
0 g
s
.70304 .51956 m .682 .55884 L .69631 .57327 L p .362 .263 .606 r
F P
0 g
s
.682 .55884 m .70304 .51956 L .68284 .50652 L p .518 .431 .696 r
F P
0 g
s
.36925 .63024 m .33403 .62537 L .33086 .66418 L p .838 .745 .76 r
F P
0 g
s
.33403 .62537 m .36925 .63024 L .37341 .59671 L p .831 .819 .838 r
F P
0 g
s
.57817 .72931 m .61706 .70054 L .60893 .69237 L p .39 .077 .31 r
F P
0 g
s
.64674 .66035 m .60893 .69237 L .61706 .70054 L p .228 0 .236 r
F P
0 g
s
.65285 .42 m .6428 .4528 L .67241 .45912 L p .623 .578 .783 r
F P
0 g
s
.6428 .4528 m .65285 .42 L .62249 .42078 L p .696 .641 .791 r
F P
0 g
s
.62249 .42078 m .61168 .4495 L .6428 .4528 L p .696 .641 .791 r
F P
0 g
s
.61168 .4495 m .62249 .42078 L .59278 .42466 L p .763 .7 .792 r
F P
0 g
s
.59278 .42466 m .58218 .44955 L .61168 .4495 L p .763 .7 .792 r
F P
0 g
s
.52848 .511 m .54927 .49314 L .52997 .49095 L p .875 .914 .851 r
F P
0 g
s
.54927 .49314 m .56745 .47254 L .54486 .47299 L p .872 .86 .826 r
F P
0 g
s
.54486 .47299 m .52997 .49095 L .54927 .49314 L p .872 .86 .826 r
F P
0 g
s
.50598 .52587 m .52848 .511 L .51342 .50661 L p .853 .964 .874 r
F P
0 g
s
.52997 .49095 m .51342 .50661 L .52848 .511 L p .875 .914 .851 r
F P
0 g
s
.64674 .66035 m .67795 .62411 L .66945 .61169 L p .385 .184 .48 r
F P
0 g
s
.69631 .57327 m .66945 .61169 L .67795 .62411 L p .231 .063 .436 r
F P
0 g
s
.69746 .46783 m .68284 .50652 L .70304 .51956 L p .451 .397 .706 r
F P
0 g
s
.68284 .50652 m .69746 .46783 L .67241 .45912 L p .57 .512 .751 r
F P
0 g
s
.56745 .47254 m .58218 .44955 L .55735 .45297 L p .857 .809 .803 r
F P
0 g
s
.55735 .45297 m .54486 .47299 L .56745 .47254 L p .857 .809 .803 r
F P
0 g
s
.48274 .53763 m .50598 .52587 L .496 .51984 L p .786 .993 .88 r
F P
0 g
s
.51342 .50661 m .496 .51984 L .50598 .52587 L p .853 .964 .874 r
F P
0 g
s
.40863 .5716 m .43559 .56903 L .438 .55199 L p .735 .946 .95 r
F P
0 g
s
.45975 .54629 m .438 .55199 L .43559 .56903 L p .785 .928 .929 r
F P
0 g
s
.6808 .42238 m .67241 .45912 L .69746 .46783 L p .526 .496 .765 r
F P
0 g
s
.67241 .45912 m .6808 .42238 L .65285 .42 L p .623 .578 .783 r
F P
0 g
s
.58218 .44955 m .59278 .42466 L .56678 .43122 L p .836 .765 .784 r
F P
0 g
s
.56678 .43122 m .55735 .45297 L .58218 .44955 L p .836 .765 .784 r
F P
0 g
s
.61706 .70054 m .6505 .66745 L .64674 .66035 L p .228 0 .236 r
F P
0 g
s
.67795 .62411 m .64674 .66035 L .6505 .66745 L p 0 0 .1 r
F P
0 g
s
.45975 .54629 m .48274 .53763 L .47852 .53063 L p .651 .97 .849 r
F P
0 g
s
.47852 .53063 m .48274 .53763 L p .49389 .52266 L .786 .993 .88 r
F P
0 g
s
.46179 .53908 m .45975 .54629 L p .47566 .53302 L .651 .97 .849 r
F P
0 g
s
.47852 .53063 m .46179 .53908 L p .47566 .53302 L .651 .97 .849 r
F P
0 g
s
.438 .55199 m .45975 .54629 L .46179 .53908 L p .45 .875 .771 r
F P
0 g
s
.4466 .54538 m .438 .55199 L p .45831 .54097 L .45 .875 .771 r
F P
0 g
s
.46179 .53908 m .4466 .54538 L p .45831 .54097 L .45 .875 .771 r
F P
0 g
s
.41843 .55496 m .438 .55199 L .4466 .54538 L p 0 0 0 r
F P
0 g
s
.4466 .54538 m .46062 .55024 L p .43475 .54985 L .444 0 .07 r
F P
0 g
s
.43364 .54983 m .4466 .54538 L p .43475 .54985 L .444 0 .07 r
F P
0 g
s
.46179 .53908 m .4705 .54225 L p .44772 .54524 L .311 0 .012 r
F P
0 g
s
.4466 .54538 m .46179 .53908 L p .44772 .54524 L .311 0 .012 r
F P
0 g
s
.47852 .53063 m .48186 .53283 L p .46285 .53875 L .119 0 0 r
F P
0 g
s
.46179 .53908 m .47852 .53063 L p .46285 .53875 L .119 0 0 r
F P
0 g
s
.496 .51984 m .47852 .53063 L p .49389 .52266 L .786 .993 .88 r
F P
0 g
s
.39568 .79377 m .44232 .78563 L .41945 .76802 L p .709 .356 .376 r
F P
0 g
s
.41945 .76802 m .37048 .77266 L .39568 .79377 L p .709 .356 .376 r
F P
0 g
s
.30475 .73739 m .35005 .74176 L .33639 .70433 L p .855 .642 .613 r
F P
0 g
s
.33639 .70433 m .29431 .69727 L .30475 .73739 L p .855 .642 .613 r
F P
0 g
s
.29431 .69727 m .33639 .70433 L .33086 .66418 L p .866 .719 .697 r
F P
0 g
s
.62744 .39085 m .62249 .42078 L .65285 .42 L p .676 .627 .793 r
F P
0 g
s
.62249 .42078 m .62744 .39085 L .59871 .39844 L p .744 .676 .785 r
F P
0 g
s
.59871 .39844 m .59278 .42466 L .62249 .42078 L p .744 .676 .785 r
F P
0 g
s
.33086 .66418 m .29402 .65548 L .29431 .69727 L p .866 .719 .697 r
F P
0 g
s
.29402 .65548 m .33086 .66418 L .33403 .62537 L p .863 .79 .777 r
F P
0 g
s
.65588 .38619 m .65285 .42 L .6808 .42238 L p .595 .568 .794 r
F P
0 g
s
.65285 .42 m .65588 .38619 L .62744 .39085 L p .676 .627 .793 r
F P
0 g
s
.59278 .42466 m .59871 .39844 L .57262 .40818 L p .813 .726 .769 r
F P
0 g
s
.57262 .40818 m .56678 .43122 L .59278 .42466 L p .813 .726 .769 r
F P
0 g
s
.32429 .77173 m .37048 .77266 L .35005 .74176 L p .826 .544 .51 r
F P
0 g
s
.35005 .74176 m .30475 .73739 L .32429 .77173 L p .826 .544 .51 r
F P
0 g
s
.37341 .59671 m .34566 .59188 L .33403 .62537 L p .831 .819 .838 r
F P
0 g
s
.34566 .59188 m .37341 .59671 L .38464 .57087 L p .781 .899 .926 r
F P
0 g
s
.40863 .5716 m .38464 .57087 L .37341 .59671 L p .799 .871 .901 r
F P
0 g
s
.50704 .77511 m .54733 .75428 L .53512 .75329 L p .304 0 .007 r
F P
0 g
s
.53512 .75329 m .48933 .77212 L .50704 .77511 L p .304 0 .007 r
F P
0 g
s
.57817 .72931 m .53512 .75329 L .54733 .75428 L p .114 0 0 r
F P
0 g
s
.69631 .57327 m .7147 .53194 L .70304 .51956 L p .362 .263 .606 r
F P
0 g
s
.7153 .47806 m .70304 .51956 L .7147 .53194 L p .212 .169 .59 r
F P
0 g
s
.70304 .51956 m .7153 .47806 L .69746 .46783 L p .451 .397 .706 r
F P
0 g
s
.67795 .62411 m .70145 .58445 L .69631 .57327 L p .231 .063 .436 r
F P
0 g
s
.7147 .53194 m .69631 .57327 L .70145 .58445 L p 0 0 .344 r
F P
0 g
s
.54733 .75428 m .58468 .72901 L .57817 .72931 L p .114 0 0 r
F P
0 g
s
.61706 .70054 m .57817 .72931 L .58468 .72901 L p 0 0 0 r
F P
0 g
s
.38464 .57087 m .40863 .5716 L .41843 .55496 L p .657 .943 .961 r
F P
0 g
s
.438 .55199 m .41843 .55496 L .40863 .5716 L p .735 .946 .95 r
F P
0 g
s
.70342 .42771 m .69746 .46783 L .7153 .47806 L p .361 .355 .718 r
F P
0 g
s
.69746 .46783 m .70342 .42771 L .6808 .42238 L p .526 .496 .765 r
F P
0 g
s
.52997 .49095 m .54486 .47299 L .53022 .47764 L p .92 .977 .747 r
F P
0 g
s
.54486 .47299 m .55735 .45297 L .53981 .45946 L p .944 .917 .757 r
F P
0 g
s
.53981 .45946 m .53022 .47764 L .54486 .47299 L p .944 .917 .757 r
F P
0 g
s
.46516 .79127 m .50704 .77511 L .48933 .77212 L p .436 0 .07 r
F P
0 g
s
.48933 .77212 m .44232 .78563 L .46516 .79127 L p .436 0 .07 r
F P
0 g
s
.51342 .50661 m .52997 .49095 L .51899 .49416 L p .789 .97 .671 r
F P
0 g
s
.53022 .47764 m .51899 .49416 L .52997 .49095 L p .92 .977 .747 r
F P
0 g
s
.33403 .62537 m .30393 .61629 L .29402 .65548 L p .863 .79 .777 r
F P
0 g
s
.30393 .61629 m .33403 .62537 L .34566 .59188 L p .836 .86 .862 r
F P
0 g
s
.55735 .45297 m .56678 .43122 L .54718 .43984 L p .925 .846 .746 r
F P
0 g
s
.54718 .43984 m .53981 .45946 L .55735 .45297 L p .925 .846 .746 r
F P
0 g
s
.62627 .3605 m .62744 .39085 L .65588 .38619 L p .655 .615 .797 r
F P
0 g
s
.62744 .39085 m .62627 .3605 L .59963 .37155 L p .724 .655 .781 r
F P
0 g
s
.59963 .37155 m .59871 .39844 L .62744 .39085 L p .724 .655 .781 r
F P
0 g
s
.59871 .39844 m .59963 .37155 L .57449 .38436 L p .789 .692 .757 r
F P
0 g
s
.57449 .38436 m .57262 .40818 L .59871 .39844 L p .789 .692 .757 r
F P
0 g
s
.68111 .38495 m .6808 .42238 L .70342 .42771 L p .474 .48 .784 r
F P
0 g
s
.6808 .42238 m .68111 .38495 L .65588 .38619 L p .595 .568 .794 r
F P
0 g
s
.496 .51984 m .51342 .50661 L .50675 .50888 L p 0 0 0 r
F P
0 g
s
.51899 .49416 m .50675 .50888 L .51342 .50661 L p .789 .97 .671 r
F P
0 g
s
.6505 .66745 m .67735 .63071 L .67795 .62411 L p 0 0 .1 r
F P
0 g
s
.70145 .58445 m .67795 .62411 L .67735 .63071 L p 0 0 0 r
F P
0 g
s
.58468 .72901 m .61788 .69963 L .61706 .70054 L p 0 0 0 r
F P
0 g
s
.6505 .66745 m .61706 .70054 L .61788 .69963 L p .502 .821 .508 r
F P
0 g
s
.56678 .43122 m .57262 .40818 L .55185 .4191 L p .894 .783 .732 r
F P
0 g
s
.55185 .4191 m .54718 .43984 L .56678 .43122 L p .894 .783 .732 r
F P
0 g
s
.35102 .79668 m .39568 .79377 L .37048 .77266 L p .764 .397 .361 r
F P
0 g
s
.37048 .77266 m .32429 .77173 L .35102 .79668 L p .764 .397 .361 r
F P
0 g
s
.65171 .35235 m .65588 .38619 L .68111 .38495 L p .564 .561 .808 r
F P
0 g
s
.65588 .38619 m .65171 .35235 L .62627 .3605 L p .655 .615 .797 r
F P
0 g
s
.47852 .53063 m .496 .51984 L .49416 .52175 L p 0 0 0 r
F P
0 g
s
.50675 .50888 m .49416 .52175 L .496 .51984 L p 0 0 0 r
F P
0 g
s
.57262 .40818 m .57449 .38436 L .55344 .39764 L p .86 .73 .719 r
F P
0 g
s
.55344 .39764 m .55185 .4191 L .57262 .40818 L p .86 .73 .719 r
F P
0 g
s
.42308 .80271 m .46516 .79127 L .44232 .78563 L p .532 .068 .096 r
F P
0 g
s
.44232 .78563 m .39568 .79377 L .42308 .80271 L p .532 .068 .096 r
F P
0 g
s
.59539 .34472 m .59963 .37155 L .62627 .3605 L p .704 .637 .779 r
F P
0 g
s
.59963 .37155 m .59539 .34472 L .57219 .36035 L p .764 .662 .75 r
F P
0 g
s
.57219 .36035 m .57449 .38436 L .59963 .37155 L p .764 .662 .75 r
F P
0 g
s
.61896 .33062 m .62627 .3605 L .65171 .35235 L p .633 .605 .804 r
F P
0 g
s
.62627 .3605 m .61896 .33062 L .59539 .34472 L p .704 .637 .779 r
F P
0 g
s
.57449 .38436 m .57219 .36035 L .55172 .37592 L p .826 .686 .709 r
F P
0 g
s
.55172 .37592 m .55344 .39764 L .57449 .38436 L p .826 .686 .709 r
F P
0 g
s
.61788 .69963 m .6458 .66663 L .6505 .66745 L p .502 .821 .508 r
F P
0 g
s
.67735 .63071 m .6505 .66745 L .6458 .66663 L p .784 .974 .687 r
F P
0 g
s
.49416 .52175 m .48186 .53283 L .47852 .53063 L p 0 0 0 r
F P
0 g
s
.38464 .57087 m .36468 .56728 L .34566 .59188 L p .781 .899 .926 r
F P
0 g
s
.36468 .56728 m .38464 .57087 L .40192 .55559 L p .554 .914 .958 r
F P
0 g
s
.41843 .55496 m .40192 .55559 L .38464 .57087 L p .657 .943 .961 r
F P
0 g
s
.26479 .72781 m .30475 .73739 L .29431 .69727 L p .901 .692 .611 r
F P
0 g
s
.29431 .69727 m .25822 .68529 L .26479 .72781 L p .901 .692 .611 r
F P
0 g
s
.25822 .68529 m .29431 .69727 L .29402 .65548 L p .903 .773 .708 r
F P
0 g
s
.34566 .59188 m .3231 .58377 L .30393 .61629 L p .836 .86 .862 r
F P
0 g
s
.3231 .58377 m .34566 .59188 L .36468 .56728 L p .746 .92 .95 r
F P
0 g
s
.7147 .53194 m .72393 .48877 L .7153 .47806 L p .212 .169 .59 r
F P
0 g
s
.71828 .4355 m .7153 .47806 L .72393 .48877 L p 0 .024 .54 r
F P
0 g
s
.7153 .47806 m .71828 .4355 L .70342 .42771 L p .361 .355 .718 r
F P
0 g
s
.70145 .58445 m .7164 .54232 L .7147 .53194 L p 0 0 .344 r
F P
0 g
s
.72393 .48877 m .7147 .53194 L .7164 .54232 L p 0 0 .152 r
F P
0 g
s
.58611 .31869 m .59539 .34472 L .61896 .33062 L p .682 .621 .78 r
F P
0 g
s
.59539 .34472 m .58611 .31869 L .56569 .33676 L p .739 .636 .745 r
F P
0 g
s
.56569 .33676 m .57219 .36035 L .59539 .34472 L p .739 .636 .745 r
F P
0 g
s
.57219 .36035 m .56569 .33676 L .54661 .35442 L p .793 .648 .701 r
F P
0 g
s
.54661 .35442 m .55172 .37592 L .57219 .36035 L p .793 .648 .701 r
F P
0 g
s
.70048 .38732 m .70342 .42771 L .71828 .4355 L p .236 .301 .727 r
F P
0 g
s
.70342 .42771 m .70048 .38732 L .68111 .38495 L p .474 .48 .784 r
F P
0 g
s
.29402 .65548 m .26358 .64244 L .25822 .68529 L p .903 .773 .708 r
F P
0 g
s
.26358 .64244 m .29402 .65548 L .30393 .61629 L p .885 .843 .798 r
F P
0 g
s
.53022 .47764 m .53981 .45946 L .53156 .46838 L p .81 .844 .382 r
F P
0 g
s
.53981 .45946 m .54718 .43984 L .53614 .44964 L p .979 .897 .551 r
F P
0 g
s
.53614 .44964 m .53156 .46838 L .53981 .45946 L p .979 .897 .551 r
F P
0 g
s
.54718 .43984 m .55185 .4191 L .53862 .43008 L p .986 .841 .613 r
F P
0 g
s
.53862 .43008 m .53614 .44964 L .54718 .43984 L p .986 .841 .613 r
F P
0 g
s
.28263 .76558 m .32429 .77173 L .30475 .73739 L p .877 .588 .493 r
F P
0 g
s
.30475 .73739 m .26479 .72781 L .28263 .76558 L p .877 .588 .493 r
F P
0 g
s
.67331 .34797 m .68111 .38495 L .70048 .38732 L p .411 .465 .806 r
F P
0 g
s
.68111 .38495 m .67331 .34797 L .65171 .35235 L p .564 .561 .808 r
F P
0 g
s
.67735 .63071 m .69666 .5911 L .70145 .58445 L p 0 0 0 r
F P
0 g
s
.7164 .54232 m .70145 .58445 L .69666 .5911 L p .796 .857 .409 r
F P
0 g
s
.51899 .49416 m .53022 .47764 L .52526 .48608 L p 0 0 0 r
F P
0 g
s
.53156 .46838 m .52526 .48608 L .53022 .47764 L p .81 .844 .382 r
F P
0 g
s
.55185 .4191 m .55344 .39764 L .53867 .41002 L p .946 .77 .631 r
F P
0 g
s
.53867 .41002 m .53862 .43008 L .55185 .4191 L p .946 .77 .631 r
F P
0 g
s
.64049 .3195 m .65171 .35235 L .67331 .34797 L p .531 .556 .826 r
F P
0 g
s
.65171 .35235 m .64049 .3195 L .61896 .33062 L p .633 .605 .804 r
F P
0 g
s
.55519 .31421 m .56569 .33676 L .58611 .31869 L p .713 .612 .743 r
F P
0 g
s
.56569 .33676 m .55519 .31421 L .53821 .33368 L p .76 .614 .697 r
F P
0 g
s
.53821 .33368 m .54661 .35442 L .56569 .33676 L p .76 .614 .697 r
F P
0 g
s
.55344 .39764 m .55172 .37592 L .5361 .38982 L p .899 .707 .635 r
F P
0 g
s
.5361 .38982 m .53867 .41002 L .55344 .39764 L p .899 .707 .635 r
F P
0 g
s
.52064 .76594 m .55398 .74398 L .54733 .75428 L p .45 .871 .745 r
F P
0 g
s
.54733 .75428 m .50704 .77511 L .52064 .76594 L p .45 .871 .745 r
F P
0 g
s
.58468 .72901 m .54733 .75428 L .55398 .74398 L p .659 .972 .837 r
F P
0 g
s
.60579 .30207 m .61896 .33062 L .64049 .3195 L p .61 .598 .814 r
F P
0 g
s
.61896 .33062 m .60579 .30207 L .58611 .31869 L p .682 .621 .78 r
F P
0 g
s
.50675 .50888 m .51899 .49416 L .51771 .50256 L p 0 0 .123 r
F P
0 g
s
.52526 .48608 m .51771 .50256 L .51899 .49416 L p 0 0 0 r
F P
0 g
s
.43364 .54983 m .41843 .55496 L p .44265 .54673 L 0 0 0 r
F P
0 g
s
.4466 .54538 m .43364 .54983 L p .44265 .54673 L 0 0 0 r
F P
0 g
s
.43364 .54983 m .45272 .55709 L p .42457 .55296 L .541 .073 .091 r
F P
0 g
s
.40192 .55559 m .41843 .55496 L .43364 .54983 L p 0 0 0 r
F P
0 g
s
.42352 .55281 m .43364 .54983 L p .42457 .55296 L .541 .073 .091 r
F P
0 g
s
.38223 .80948 m .42308 .80271 L .39568 .79377 L p .606 .128 .092 r
F P
0 g
s
.39568 .79377 m .35102 .79668 L .38223 .80948 L p .606 .128 .092 r
F P
0 g
s
.57214 .29421 m .58611 .31869 L .60579 .30207 L p .66 .606 .784 r
F P
0 g
s
.58611 .31869 m .57214 .29421 L .55519 .31421 L p .713 .612 .743 r
F P
0 g
s
.55398 .74398 m .58446 .71839 L .58468 .72901 L p .659 .972 .837 r
F P
0 g
s
.61788 .69963 m .58468 .72901 L .58446 .71839 L p .795 .994 .874 r
F P
0 g
s
.55172 .37592 m .54661 .35442 L .53082 .36988 L p .853 .655 .634 r
F P
0 g
s
.53082 .36988 m .5361 .38982 L .55172 .37592 L p .853 .655 .634 r
F P
0 g
s
.48186 .53283 m .4705 .54225 L .46179 .53908 L p .119 0 0 r
F P
0 g
s
.5411 .29332 m .55519 .31421 L .57214 .29421 L p .686 .591 .744 r
F P
0 g
s
.55519 .31421 m .5411 .29332 L .52679 .31421 L p .728 .584 .694 r
F P
0 g
s
.52679 .31421 m .53821 .33368 L .55519 .31421 L p .728 .584 .694 r
F P
0 g
s
.50704 .77511 m .46516 .79127 L .48552 .78406 L p 0 0 0 r
F P
0 g
s
.48552 .78406 m .52064 .76594 L .50704 .77511 L p 0 0 0 r
F P
0 g
s
.54661 .35442 m .53821 .33368 L .52292 .35062 L p .81 .611 .633 r
F P
0 g
s
.52292 .35062 m .53082 .36988 L .54661 .35442 L p .81 .611 .633 r
F P
0 g
s
.30393 .61629 m .28034 .60368 L .26358 .64244 L p .885 .843 .798 r
F P
0 g
s
.28034 .60368 m .30393 .61629 L .3231 .58377 L p .83 .902 .89 r
F P
0 g
s
.57214 .29421 m .55406 .27195 L .5411 .29332 L p .686 .591 .744 r
F P
0 g
s
.53821 .33368 m .52679 .31421 L .5126 .33247 L p .769 .572 .631 r
F P
0 g
s
.5126 .33247 m .52292 .35062 L .53821 .33368 L p .769 .572 .631 r
F P
0 g
s
.49416 .52175 m .50675 .50888 L .50941 .51773 L p .226 0 .256 r
F P
0 g
s
.51771 .50256 m .50941 .51773 L .50675 .50888 L p 0 0 .123 r
F P
0 g
s
.6458 .66663 m .6675 .63064 L .67735 .63071 L p .784 .974 .687 r
F P
0 g
s
.69666 .5911 m .67735 .63071 L .6675 .63064 L p .913 .98 .761 r
F P
0 g
s
.60579 .30207 m .58731 .27571 L .57214 .29421 L p .66 .606 .784 r
F P
0 g
s
.55406 .27195 m .57214 .29421 L .58731 .27571 L p .636 .595 .791 r
F P
0 g
s
.30998 .79463 m .35102 .79668 L .32429 .77173 L p .816 .433 .329 r
F P
0 g
s
.32429 .77173 m .28263 .76558 L .30998 .79463 L p .816 .433 .329 r
F P
0 g
s
.58446 .71839 m .61107 .68951 L .61788 .69963 L p .795 .994 .874 r
F P
0 g
s
.6458 .66663 m .61788 .69963 L .61107 .68951 L p .858 .962 .87 r
F P
0 g
s
.64049 .3195 m .62269 .28862 L .60579 .30207 L p .61 .598 .814 r
F P
0 g
s
.58731 .27571 m .60579 .30207 L .62269 .28862 L p .586 .594 .827 r
F P
0 g
s
.4498 .79825 m .48552 .78406 L .46516 .79127 L p 0 0 0 r
F P
0 g
s
.46516 .79127 m .42308 .80271 L .4498 .79825 L p 0 0 0 r
F P
0 g
s
.58731 .27571 m .56434 .2523 L .55406 .27195 L p .636 .595 .791 r
F P
0 g
s
.48186 .53283 m .49416 .52175 L .50088 .5316 L p .391 .088 .327 r
F P
0 g
s
.50941 .51773 m .50088 .5316 L .49416 .52175 L p .226 0 .256 r
F P
0 g
s
.52292 .35062 m .5126 .33247 L .49999 .34622 L p .815 .544 .53 r
F P
0 g
s
.67331 .34797 m .65771 .31255 L .64049 .3195 L p .531 .556 .826 r
F P
0 g
s
.62269 .28862 m .64049 .3195 L .65771 .31255 L p .494 .556 .848 r
F P
0 g
s
.53082 .36988 m .52292 .35062 L .51091 .36327 L p .867 .591 .517 r
F P
0 g
s
.49999 .34622 m .51091 .36327 L .52292 .35062 L p .815 .544 .53 r
F P
0 g
s
.36468 .56728 m .34967 .56141 L .3231 .58377 L p .746 .92 .95 r
F P
0 g
s
.34967 .56141 m .36468 .56728 L .38921 .55434 L p .44 .862 .945 r
F P
0 g
s
.40192 .55559 m .38921 .55434 L .36468 .56728 L p .554 .914 .958 r
F P
0 g
s
.4705 .54225 m .46062 .55024 L .4466 .54538 L p .311 0 .012 r
F P
0 g
s
.70048 .38732 m .68876 .34786 L .67331 .34797 L p .411 .465 .806 r
F P
0 g
s
.65771 .31255 m .67331 .34797 L .68876 .34786 L p .332 .451 .831 r
F P
0 g
s
.5361 .38982 m .53082 .36988 L .52 .38151 L p .922 .642 .492 r
F P
0 g
s
.51091 .36327 m .52 .38151 L .53082 .36988 L p .867 .591 .517 r
F P
0 g
s
.72393 .48877 m .72363 .44494 L .71828 .4355 L p 0 .024 .54 r
F P
0 g
s
.71185 .39309 m .71828 .4355 L .72363 .44494 L p 0 0 .403 r
F P
0 g
s
.71828 .4355 m .71185 .39309 L .70048 .38732 L p .236 .301 .727 r
F P
0 g
s
.68876 .34786 m .70048 .38732 L .71185 .39309 L p .052 .222 .721 r
F P
0 g
s
.7164 .54232 m .72223 .4988 L .72393 .48877 L p 0 0 .152 r
F P
0 g
s
.72363 .44494 m .72393 .48877 L .72223 .4988 L p .818 .682 .14 r
F P
0 g
s
.53867 .41002 m .5361 .38982 L .52702 .4006 L p .973 .696 .442 r
F P
0 g
s
.52 .38151 m .52702 .4006 L .5361 .38982 L p .922 .642 .492 r
F P
0 g
s
.53862 .43008 m .53867 .41002 L .53184 .42019 L p .982 .729 .33 r
F P
0 g
s
.52702 .4006 m .53184 .42019 L .53867 .41002 L p .973 .696 .442 r
F P
0 g
s
.53614 .44964 m .53862 .43008 L .53447 .43996 L p .822 .652 .103 r
F P
0 g
s
.53184 .42019 m .53447 .43996 L .53862 .43008 L p .982 .729 .33 r
F P
0 g
s
.53156 .46838 m .53614 .44964 L .53502 .45959 L p 0 0 .185 r
F P
0 g
s
.53447 .43996 m .53502 .45959 L .53614 .44964 L p .822 .652 .103 r
F P
0 g
s
.69666 .5911 m .70773 .54953 L .7164 .54232 L p .796 .857 .409 r
F P
0 g
s
.72223 .4988 m .7164 .54232 L .70773 .54953 L p .971 .914 .577 r
F P
0 g
s
.62269 .28862 m .59911 .26066 L .58731 .27571 L p .586 .594 .827 r
F P
0 g
s
.56434 .2523 m .58731 .27571 L .59911 .26066 L p .561 .593 .843 r
F P
0 g
s
.61107 .68951 m .63293 .65777 L .6458 .66663 L p .858 .962 .87 r
F P
0 g
s
.6675 .63064 m .6458 .66663 L .63293 .65777 L p .876 .909 .849 r
F P
0 g
s
.43364 .54983 m .42352 .55281 L .40192 .55559 L p 0 0 0 r
F P
0 g
s
.38921 .55434 m .40192 .55559 L .42352 .55281 L p .126 0 0 r
F P
0 g
s
.52526 .48608 m .53156 .46838 L .53368 .47883 L p 0 0 .371 r
F P
0 g
s
.53502 .45959 m .53368 .47883 L .53156 .46838 L p 0 0 .185 r
F P
0 g
s
.3231 .58377 m .30683 .57307 L .28034 .60368 L p .83 .902 .89 r
F P
0 g
s
.30683 .57307 m .3231 .58377 L .34967 .56141 L p .691 .927 .969 r
F P
0 g
s
.4705 .54225 m .48186 .53283 L .49261 .54422 L p .503 .188 .365 r
F P
0 g
s
.50088 .5316 m .49261 .54422 L .48186 .53283 L p .391 .088 .327 r
F P
0 g
s
.51771 .50256 m .52526 .48608 L .53073 .49746 L p .224 .076 .459 r
F P
0 g
s
.53368 .47883 m .53073 .49746 L .52526 .48608 L p 0 0 .371 r
F P
0 g
s
.6675 .63064 m .68221 .59238 L .69666 .5911 L p .913 .98 .761 r
F P
0 g
s
.70773 .54953 m .69666 .5911 L .68221 .59238 L p .937 .919 .77 r
F P
0 g
s
.59911 .26066 m .57084 .23643 L .56434 .2523 L p .561 .593 .843 r
F P
0 g
s
.34407 .8118 m .38223 .80948 L .35102 .79668 L p .663 .166 .058 r
F P
0 g
s
.35102 .79668 m .30998 .79463 L .34407 .8118 L p .663 .166 .058 r
F P
0 g
s
.41467 .80854 m .4498 .79825 L .42308 .80271 L p .158 0 0 r
F P
0 g
s
.42308 .80271 m .38223 .80948 L .41467 .80854 L p .158 0 0 r
F P
0 g
s
.51091 .36327 m .49999 .34622 L .49029 .35397 L p .851 .458 .301 r
F P
0 g
s
.65771 .31255 m .63502 .27978 L .62269 .28862 L p .494 .556 .848 r
F P
0 g
s
.59911 .26066 m .62269 .28862 L .63502 .27978 L p .454 .56 .873 r
F P
0 g
s
.50941 .51773 m .51771 .50256 L .52649 .51533 L p .382 .195 .499 r
F P
0 g
s
.53073 .49746 m .52649 .51533 L .51771 .50256 L p .224 .076 .459 r
F P
0 g
s
.23192 .71365 m .26479 .72781 L .25822 .68529 L p .949 .752 .602 r
F P
0 g
s
.25822 .68529 m .22979 .66913 L .23192 .71365 L p .949 .752 .602 r
F P
0 g
s
.22979 .66913 m .25822 .68529 L .26358 .64244 L p .938 .838 .718 r
F P
0 g
s
.52849 .7453 m .55419 .72321 L .55398 .74398 L p .808 .944 .914 r
F P
0 g
s
.55398 .74398 m .52064 .76594 L .52849 .7453 L p .808 .944 .914 r
F P
0 g
s
.58446 .71839 m .55398 .74398 L .55419 .72321 L p .832 .904 .889 r
F P
0 g
s
.52 .38151 m .51091 .36327 L .50349 .37025 L p .894 .484 .214 r
F P
0 g
s
.49029 .35397 m .50349 .37025 L .51091 .36327 L p .851 .458 .301 r
F P
0 g
s
.26358 .64244 m .24103 .62586 L .22979 .66913 L p .938 .838 .718 r
F P
0 g
s
.24103 .62586 m .26358 .64244 L .28034 .60368 L p .896 .902 .822 r
F P
0 g
s
.46062 .55024 m .45272 .55709 L .43364 .54983 L p .444 0 .07 r
F P
0 g
s
.24723 .75476 m .28263 .76558 L .26479 .72781 L p .931 .636 .461 r
F P
0 g
s
.26479 .72781 m .23192 .71365 L .24723 .75476 L p .931 .636 .461 r
F P
0 g
s
.55419 .72321 m .57735 .69837 L .58446 .71839 L p .832 .904 .889 r
F P
0 g
s
.61107 .68951 m .58446 .71839 L .57735 .69837 L p .836 .86 .862 r
F P
0 g
s
.46062 .55024 m .4705 .54225 L .48506 .55572 L p .588 .262 .385 r
F P
0 g
s
.49261 .54422 m .48506 .55572 L .4705 .54225 L p .503 .188 .365 r
F P
0 g
s
.68876 .34786 m .66875 .31057 L .65771 .31255 L p .332 .451 .831 r
F P
0 g
s
.63502 .27978 m .65771 .31255 L .66875 .31057 L p .231 .435 .855 r
F P
0 g
s
.5011 .76445 m .52849 .7453 L .52064 .76594 L p .754 .968 .93 r
F P
0 g
s
.52064 .76594 m .48552 .78406 L .5011 .76445 L p .754 .968 .93 r
F P
0 g
s
.50088 .5316 m .50941 .51773 L .52133 .53235 L p .488 .278 .52 r
F P
0 g
s
.52649 .51533 m .52133 .53235 L .50941 .51773 L p .382 .195 .499 r
F P
0 g
s
.63293 .65777 m .64927 .62372 L .6675 .63064 L p .876 .909 .849 r
F P
0 g
s
.68221 .59238 m .6675 .63064 L .64927 .62372 L p .869 .853 .824 r
F P
0 g
s
.52702 .4006 m .52 .38151 L .51536 .38803 L p .886 .474 .054 r
F P
0 g
s
.50349 .37025 m .51536 .38803 L .52 .38151 L p .894 .484 .214 r
F P
0 g
s
.63502 .27978 m .60626 .25068 L .59911 .26066 L p .454 .56 .873 r
F P
0 g
s
.57084 .23643 m .59911 .26066 L .60626 .25068 L p .412 .57 .9 r
F P
0 g
s
.53184 .42019 m .52702 .4006 L .52555 .40705 L p .721 .367 0 r
F P
0 g
s
.51536 .38803 m .52555 .40705 L .52702 .4006 L p .886 .474 .054 r
F P
0 g
s
.71185 .39309 m .69629 .35213 L .68876 .34786 L p .052 .222 .721 r
F P
0 g
s
.66875 .31057 m .68876 .34786 L .69629 .35213 L p 0 .108 .662 r
F P
0 g
s
.57735 .69837 m .59723 .67107 L .61107 .68951 L p .836 .86 .862 r
F P
0 g
s
.63293 .65777 m .61107 .68951 L .59723 .67107 L p .829 .818 .839 r
F P
0 g
s
.53447 .43996 m .53184 .42019 L .53382 .42702 L p 0 0 .446 r
F P
0 g
s
.52555 .40705 m .53382 .42702 L .53184 .42019 L p .721 .367 0 r
F P
0 g
s
.28034 .60368 m .26449 .58836 L .24103 .62586 L p .896 .902 .822 r
F P
0 g
s
.26449 .58836 m .28034 .60368 L .30683 .57307 L p .805 .939 .916 r
F P
0 g
s
.72363 .44494 m .71382 .40172 L .71185 .39309 L p 0 0 .403 r
F P
0 g
s
.69629 .35213 m .71185 .39309 L .71382 .40172 L p .752 .422 0 r
F P
0 g
s
.4729 .78058 m .5011 .76445 L .48552 .78406 L p .658 .963 .928 r
F P
0 g
s
.48552 .78406 m .4498 .79825 L .4729 .78058 L p .658 .963 .928 r
F P
0 g
s
.27419 .78809 m .30998 .79463 L .28263 .76558 L p .865 .463 .27 r
F P
0 g
s
.28263 .76558 m .24723 .75476 L .27419 .78809 L p .865 .463 .27 r
F P
0 g
s
.49261 .54422 m .50088 .5316 L .51562 .54848 L p .566 .339 .531 r
F P
0 g
s
.52133 .53235 m .51562 .54848 L .50088 .5316 L p .488 .278 .52 r
F P
0 g
s
.53502 .45959 m .53447 .43996 L .54003 .44764 L p 0 .054 .571 r
F P
0 g
s
.53382 .42702 m .54003 .44764 L .53447 .43996 L p 0 0 .446 r
F P
0 g
s
.72223 .4988 m .7187 .45505 L .72363 .44494 L p .818 .682 .14 r
F P
0 g
s
.71382 .40172 m .72363 .44494 L .7187 .45505 L p .986 .761 .366 r
F P
0 g
s
.38921 .55434 m .38092 .55178 L .34967 .56141 L p .44 .862 .945 r
F P
0 g
s
.42352 .55281 m .41672 .55475 L .38921 .55434 L p .126 0 0 r
F P
0 g
s
.38092 .55178 m .38921 .55434 L .41672 .55475 L p .227 0 0 r
F P
0 g
s
.34967 .56141 m .34038 .55395 L .30683 .57307 L p .691 .927 .969 r
F P
0 g
s
.34038 .55395 m .34967 .56141 L .38092 .55178 L p .333 .799 .931 r
F P
0 g
s
.70773 .54953 m .71014 .50704 L .72223 .4988 L p .971 .914 .577 r
F P
0 g
s
.7187 .45505 m .72223 .4988 L .71014 .50704 L p .983 .856 .636 r
F P
0 g
s
.60626 .25068 m .5728 .22607 L .57084 .23643 L p .412 .57 .9 r
F P
0 g
s
.53368 .47883 m .53502 .45959 L .54414 .46862 L p .213 .19 .615 r
F P
0 g
s
.54003 .44764 m .54414 .46862 L .53502 .45959 L p 0 .054 .571 r
F P
0 g
s
.68221 .59238 m .68941 .5527 L .70773 .54953 L p .937 .919 .77 r
F P
0 g
s
.71014 .50704 m .70773 .54953 L .68941 .5527 L p .919 .849 .758 r
F P
0 g
s
.50349 .37025 m .49029 .35397 L .48459 .35479 L p .611 .079 0 r
F P
0 g
s
.45272 .55709 m .46062 .55024 L .47861 .56631 L p .656 .32 .391 r
F P
0 g
s
.48506 .55572 m .47861 .56631 L .46062 .55024 L p .588 .262 .385 r
F P
0 g
s
.38133 .81507 m .41467 .80854 L .38223 .80948 L p .269 0 0 r
F P
0 g
s
.38223 .80948 m .34407 .8118 L .38133 .81507 L p .269 0 0 r
F P
0 g
s
.53073 .49746 m .53368 .47883 L .54617 .48968 L p .361 .279 .627 r
F P
0 g
s
.54414 .46862 m .54617 .48968 L .53368 .47883 L p .213 .19 .615 r
F P
0 g
s
.59723 .67107 m .61315 .64167 L .63293 .65777 L p .829 .818 .839 r
F P
0 g
s
.64927 .62372 m .63293 .65777 L .61315 .64167 L p .815 .778 .818 r
F P
0 g
s
.66875 .31057 m .64138 .27658 L .63502 .27978 L p .231 .435 .855 r
F P
0 g
s
.60626 .25068 m .63502 .27978 L .64138 .27658 L p .108 .418 .865 r
F P
0 g
s
.41672 .55475 m .42352 .55281 L .44717 .56313 L p .616 .132 .08 r
F P
0 g
s
.45272 .55709 m .44717 .56313 L .42352 .55281 L p .541 .073 .091 r
F P
0 g
s
.52649 .51533 m .53073 .49746 L .54626 .51059 L p .462 .342 .63 r
F P
0 g
s
.54617 .48968 m .54626 .51059 L .53073 .49746 L p .361 .279 .627 r
F P
0 g
s
.48506 .55572 m .49261 .54422 L .50971 .56374 L p .629 .39 .536 r
F P
0 g
s
.51562 .54848 m .50971 .56374 L .49261 .54422 L p .566 .339 .531 r
F P
0 g
s
.64927 .62372 m .65954 .58802 L .68221 .59238 L p .869 .853 .824 r
F P
0 g
s
.68941 .5527 m .68221 .59238 L .65954 .58802 L p .852 .802 .802 r
F P
0 g
s
.51536 .38803 m .50349 .37025 L .50153 .3707 L p 0 .033 .568 r
F P
0 g
s
.50153 .3707 m .50349 .37025 L p .48723 .35695 L .611 .079 0 r
F P
0 g
s
.50153 .3707 m .50535 .36445 L p .515 .38363 L .263 .448 .855 r
F P
0 g
s
.51751 .38864 m .50153 .3707 L p .515 .38363 L .263 .448 .855 r
F P
0 g
s
.48459 .35479 m .50153 .3707 L p .48723 .35695 L .611 .079 0 r
F P
0 g
s
.44482 .79369 m .4729 .78058 L .4498 .79825 L p .522 .917 .9 r
F P
0 g
s
.4498 .79825 m .41467 .80854 L .44482 .79369 L p .522 .917 .9 r
F P
0 g
s
.30683 .57307 m .29776 .56063 L .26449 .58836 L p .805 .939 .916 r
F P
0 g
s
.29776 .56063 m .30683 .57307 L .34038 .55395 L p .617 .916 .979 r
F P
0 g
s
.52133 .53235 m .52649 .51533 L .54458 .53115 L p .537 .391 .63 r
F P
0 g
s
.54626 .51059 m .54458 .53115 L .52649 .51533 L p .462 .342 .63 r
F P
0 g
s
.31003 .81003 m .34407 .8118 L .30998 .79463 L p .702 .183 0 r
F P
0 g
s
.30998 .79463 m .27419 .78809 L .31003 .81003 L p .702 .183 0 r
F P
0 g
s
.69629 .35213 m .67229 .31387 L .66875 .31057 L p 0 .108 .662 r
F P
0 g
s
.64138 .27658 m .66875 .31057 L .67229 .31387 L p 0 0 .504 r
F P
0 g
s
.52555 .40705 m .51536 .38803 L .51751 .38864 L p 0 .16 .701 r
F P
0 g
s
.50153 .3707 m .51751 .38864 L .51536 .38803 L p 0 .033 .568 r
F P
0 g
s
.64138 .27658 m .6079 .24694 L .60626 .25068 L p .108 .418 .865 r
F P
0 g
s
.5728 .22607 m .60626 .25068 L .6079 .24694 L p 0 .396 .843 r
F P
0 g
s
.51562 .54848 m .52133 .53235 L .54135 .55118 L p .596 .431 .628 r
F P
0 g
s
.54458 .53115 m .54135 .55118 L .52133 .53235 L p .537 .391 .63 r
F P
0 g
s
.61315 .64167 m .62457 .61062 L .64927 .62372 L p .815 .778 .818 r
F P
0 g
s
.65954 .58802 m .64927 .62372 L .62457 .61062 L p .797 .743 .802 r
F P
0 g
s
.52958 .71524 m .54776 .69409 L .55419 .72321 L p .835 .823 .837 r
F P
0 g
s
.55419 .72321 m .52849 .7453 L .52958 .71524 L p .835 .823 .837 r
F P
0 g
s
.57735 .69837 m .55419 .72321 L .54776 .69409 L p .82 .782 .817 r
F P
0 g
s
.54776 .69409 m .56401 .67103 L .57735 .69837 L p .82 .782 .817 r
F P
0 g
s
.59723 .67107 m .57735 .69837 L .56401 .67103 L p .802 .746 .8 r
F P
0 g
s
.47861 .56631 m .48506 .55572 L .50395 .5782 L p .684 .434 .538 r
F P
0 g
s
.50971 .56374 m .50395 .5782 L .48506 .55572 L p .629 .39 .536 r
F P
0 g
s
.44717 .56313 m .45272 .55709 L .4736 .57621 L p .717 .368 .386 r
F P
0 g
s
.47861 .56631 m .4736 .57621 L .45272 .55709 L p .656 .32 .391 r
F P
0 g
s
.53382 .42702 m .52555 .40705 L .53201 .4084 L p .086 .26 .746 r
F P
0 g
s
.51751 .38864 m .53201 .4084 L .52555 .40705 L p 0 .16 .701 r
F P
0 g
s
.71382 .40172 m .69493 .3604 L .69629 .35213 L p .752 .422 0 r
F P
0 g
s
.67229 .31387 m .69629 .35213 L .69493 .3604 L p .911 .522 .11 r
F P
0 g
s
.51003 .73437 m .52958 .71524 L .52849 .7453 L p .842 .867 .861 r
F P
0 g
s
.52849 .7453 m .5011 .76445 L .51003 .73437 L p .842 .867 .861 r
F P
0 g
s
.54003 .44764 m .53382 .42702 L .54458 .4297 L p .255 .328 .747 r
F P
0 g
s
.53201 .4084 m .54458 .4297 L .53382 .42702 L p .086 .26 .746 r
F P
0 g
s
.56401 .67103 m .57778 .64627 L .59723 .67107 L p .802 .746 .8 r
F P
0 g
s
.61315 .64167 m .59723 .67107 L .57778 .64627 L p .782 .713 .787 r
F P
0 g
s
.6079 .24694 m .56993 .22245 L .5728 .22607 L p 0 .396 .843 r
F P
0 g
s
.7187 .45505 m .70599 .41232 L .71382 .40172 L p .986 .761 .366 r
F P
0 g
s
.69493 .3604 m .71382 .40172 L .70599 .41232 L p .979 .722 .473 r
F P
0 g
s
.38092 .55178 m .3775 .54852 L .34038 .55395 L p .333 .799 .931 r
F P
0 g
s
.41672 .55475 m .41356 .55617 L .38092 .55178 L p .227 0 0 r
F P
0 g
s
.3775 .54852 m .38092 .55178 L .41356 .55617 L p .279 0 0 r
F P
0 g
s
.50971 .56374 m .51562 .54848 L .53684 .57058 L p .646 .467 .628 r
F P
0 g
s
.54135 .55118 m .53684 .57058 L .51562 .54848 L p .596 .431 .628 r
F P
0 g
s
.71014 .50704 m .70382 .46473 L .7187 .45505 L p .983 .856 .636 r
F P
0 g
s
.70599 .41232 m .7187 .45505 L .70382 .46473 L p .945 .783 .651 r
F P
0 g
s
.54414 .46862 m .54003 .44764 L .5549 .45224 L p .373 .377 .735 r
F P
0 g
s
.54458 .4297 m .5549 .45224 L .54003 .44764 L p .255 .328 .747 r
F P
0 g
s
.68941 .5527 m .68882 .51253 L .71014 .50704 L p .919 .849 .758 r
F P
0 g
s
.70382 .46473 m .71014 .50704 L .68882 .51253 L p .888 .786 .742 r
F P
0 g
s
.50153 .3707 m .48459 .35479 L .48356 .34848 L p .147 .43 .868 r
F P
0 g
s
.54617 .48968 m .54414 .46862 L .5627 .4757 L p .458 .415 .721 r
F P
0 g
s
.5549 .45224 m .5627 .4757 L .54414 .46862 L p .373 .377 .735 r
F P
0 g
s
.41356 .55617 m .41672 .55475 L .44423 .56876 L p .673 .168 .035 r
F P
0 g
s
.44717 .56313 m .44423 .56876 L .41672 .55475 L p .616 .132 .08 r
F P
0 g
s
.65954 .58802 m .66334 .55138 L .68941 .5527 L p .852 .802 .802 r
F P
0 g
s
.68882 .51253 m .68941 .5527 L .66334 .55138 L p .829 .757 .783 r
F P
0 g
s
.48972 .75139 m .51003 .73437 L .5011 .76445 L p .837 .912 .888 r
F P
0 g
s
.5011 .76445 m .4729 .78058 L .48972 .75139 L p .837 .912 .888 r
F P
0 g
s
.41776 .80386 m .44482 .79369 L .41467 .80854 L p .365 .836 .853 r
F P
0 g
s
.41467 .80854 m .38133 .81507 L .41776 .80386 L p .365 .836 .853 r
F P
0 g
s
.57778 .64627 m .58862 .62007 L .61315 .64167 L p .782 .713 .787 r
F P
0 g
s
.62457 .61062 m .61315 .64167 L .58862 .62007 L p .76 .685 .778 r
F P
0 g
s
.54626 .51059 m .54617 .48968 L .56784 .49973 L p .524 .446 .71 r
F P
0 g
s
.5627 .4757 m .56784 .49973 L .54617 .48968 L p .458 .415 .721 r
F P
0 g
s
.34038 .55395 m .33738 .54568 L .29776 .56063 L p .617 .916 .979 r
F P
0 g
s
.33738 .54568 m .34038 .55395 L .3775 .54852 L p .249 .736 .924 r
F P
0 g
s
.20778 .69577 m .23192 .71365 L .22979 .66913 L p .991 .82 .577 r
F P
0 g
s
.22979 .66913 m .21054 .64971 L .20778 .69577 L p .991 .82 .577 r
F P
0 g
s
.21054 .64971 m .22979 .66913 L .24103 .62586 L p .96 .91 .723 r
F P
0 g
s
.67229 .31387 m .64095 .27948 L .64138 .27658 L p 0 0 .504 r
F P
0 g
s
.6079 .24694 m .64138 .27658 L .64095 .27948 L p .67 .143 0 r
F P
0 g
s
.54458 .53115 m .54626 .51059 L .57028 .52401 L p .577 .475 .701 r
F P
0 g
s
.56784 .49973 m .57028 .52401 L .54626 .51059 L p .524 .446 .71 r
F P
0 g
s
.4736 .57621 m .47861 .56631 L .4986 .59198 L p .734 .475 .537 r
F P
0 g
s
.50395 .5782 m .4986 .59198 L .47861 .56631 L p .684 .434 .538 r
F P
0 g
s
.62457 .61062 m .63107 .57842 L .65954 .58802 L p .797 .743 .802 r
F P
0 g
s
.66334 .55138 m .65954 .58802 L .63107 .57842 L p .778 .712 .79 r
F P
0 g
s
.35099 .81811 m .38133 .81507 L .34407 .8118 L p .337 0 0 r
F P
0 g
s
.34407 .8118 m .31003 .81003 L .35099 .81811 L p .337 0 0 r
F P
0 g
s
.24103 .62586 m .22769 .60672 L .21054 .64971 L p .96 .91 .723 r
F P
0 g
s
.22769 .60672 m .24103 .62586 L .26449 .58836 L p .884 .96 .843 r
F P
0 g
s
.50395 .5782 m .50971 .56374 L .53131 .58927 L p .691 .502 .627 r
F P
0 g
s
.53684 .57058 m .53131 .58927 L .50971 .56374 L p .646 .467 .628 r
F P
0 g
s
.21974 .74 m .24723 .75476 L .23192 .71365 L p .976 .683 .397 r
F P
0 g
s
.23192 .71365 m .20778 .69577 L .21974 .74 L p .976 .683 .397 r
F P
0 g
s
.54135 .55118 m .54458 .53115 L .57005 .54824 L p .621 .502 .695 r
F P
0 g
s
.57028 .52401 m .57005 .54824 L .54458 .53115 L p .577 .475 .701 r
F P
0 g
s
.48356 .34848 m .50535 .36445 L .50153 .3707 L p .147 .43 .868 r
F P
0 g
s
.44423 .56876 m .44717 .56313 L .47023 .5857 L p .774 .411 .368 r
F P
0 g
s
.4736 .57621 m .47023 .5857 L .44717 .56313 L p .717 .368 .386 r
F P
0 g
s
.53684 .57058 m .54135 .55118 L .56728 .57212 L p .661 .528 .692 r
F P
0 g
s
.57005 .54824 m .56728 .57212 L .54135 .55118 L p .621 .502 .695 r
F P
0 g
s
.58862 .62007 m .59614 .59273 L .62457 .61062 L p .76 .685 .778 r
F P
0 g
s
.63107 .57842 m .62457 .61062 L .59614 .59273 L p .738 .659 .772 r
F P
0 g
s
.26449 .58836 m .25741 .57136 L .22769 .60672 L p .884 .96 .843 r
F P
0 g
s
.25741 .57136 m .26449 .58836 L .29776 .56063 L p .751 .961 .936 r
F P
0 g
s
.46928 .76631 m .48972 .75139 L .4729 .78058 L p .81 .952 .912 r
F P
0 g
s
.4729 .78058 m .44482 .79369 L .46928 .76631 L p .81 .952 .912 r
F P
0 g
s
.24521 .77767 m .27419 .78809 L .24723 .75476 L p .895 .476 .163 r
F P
0 g
s
.24723 .75476 m .21974 .74 L .24521 .77767 L p .895 .476 .163 r
F P
0 g
s
.53533 .65983 m .54587 .63942 L .56401 .67103 L p .794 .692 .753 r
F P
0 g
s
.56401 .67103 m .54776 .69409 L .53533 .65983 L p .794 .692 .753 r
F P
0 g
s
.57778 .64627 m .56401 .67103 L .54587 .63942 L p .767 .66 .745 r
F P
0 g
s
.4986 .59198 m .50395 .5782 L .52504 .60721 L p .732 .536 .627 r
F P
0 g
s
.53131 .58927 m .52504 .60721 L .50395 .5782 L p .691 .502 .627 r
F P
0 g
s
.69493 .3604 m .66779 .32221 L .67229 .31387 L p .911 .522 .11 r
F P
0 g
s
.64095 .27948 m .67229 .31387 L .66779 .32221 L p .91 .522 .262 r
F P
0 g
s
.53201 .4084 m .51751 .38864 L .52636 .38315 L p .356 .463 .832 r
F P
0 g
s
.50535 .36445 m .52636 .38315 L .51751 .38864 L p .263 .448 .855 r
F P
0 g
s
.53131 .58927 m .53684 .57058 L .56216 .59541 L p .697 .555 .69 r
F P
0 g
s
.56728 .57212 m .56216 .59541 L .53684 .57058 L p .661 .528 .692 r
F P
0 g
s
.54587 .63942 m .55492 .6179 L .57778 .64627 L p .767 .66 .745 r
F P
0 g
s
.58862 .62007 m .57778 .64627 L .55492 .6179 L p .74 .632 .74 r
F P
0 g
s
.64095 .27948 m .60375 .24996 L .6079 .24694 L p .67 .143 0 r
F P
0 g
s
.56993 .22245 m .6079 .24694 L .60375 .24996 L p .72 .189 0 r
F P
0 g
s
.52364 .67906 m .53533 .65983 L .54776 .69409 L p .82 .729 .764 r
F P
0 g
s
.54776 .69409 m .52958 .71524 L .52364 .67906 L p .82 .729 .764 r
F P
0 g
s
.55492 .6179 m .56216 .59541 L .58862 .62007 L p .74 .632 .74 r
F P
0 g
s
.59614 .59273 m .58862 .62007 L .56216 .59541 L p .712 .607 .738 r
F P
0 g
s
.47023 .5857 m .4736 .57621 L .49391 .60523 L p .783 .516 .532 r
F P
0 g
s
.4986 .59198 m .49391 .60523 L .4736 .57621 L p .734 .475 .537 r
F P
0 g
s
.54458 .4297 m .53201 .4084 L .54584 .40438 L p .431 .478 .808 r
F P
0 g
s
.52636 .38315 m .54584 .40438 L .53201 .4084 L p .356 .463 .832 r
F P
0 g
s
.51115 .69705 m .52364 .67906 L .52958 .71524 L p .846 .771 .779 r
F P
0 g
s
.52958 .71524 m .51003 .73437 L .51115 .69705 L p .846 .771 .779 r
F P
0 g
s
.63107 .57842 m .6324 .54567 L .66334 .55138 L p .778 .712 .79 r
F P
0 g
s
.66054 .5146 m .66334 .55138 L .6324 .54567 L p .757 .684 .781 r
F P
0 g
s
.66334 .55138 m .66054 .5146 L .68882 .51253 L p .829 .757 .783 r
F P
0 g
s
.52504 .60721 m .53131 .58927 L .55492 .6179 L p .732 .584 .69 r
F P
0 g
s
.56216 .59541 m .55492 .6179 L .53131 .58927 L p .697 .555 .69 r
F P
0 g
s
.70599 .41232 m .68463 .37183 L .69493 .3604 L p .979 .722 .473 r
F P
0 g
s
.66779 .32221 m .69493 .3604 L .68463 .37183 L p .927 .663 .519 r
F P
0 g
s
.59614 .59273 m .60004 .56463 L .63107 .57842 L p .738 .659 .772 r
F P
0 g
s
.6324 .54567 m .63107 .57842 L .60004 .56463 L p .715 .637 .769 r
F P
0 g
s
.68048 .47286 m .68882 .51253 L .66054 .5146 L p .805 .718 .769 r
F P
0 g
s
.68882 .51253 m .68048 .47286 L .70382 .46473 L p .888 .786 .742 r
F P
0 g
s
.60375 .24996 m .56246 .22609 L .56993 .22245 L p .72 .189 0 r
F P
0 g
s
.56216 .59541 m .56728 .57212 L .59614 .59273 L p .712 .607 .738 r
F P
0 g
s
.56728 .57212 m .57005 .54824 L .60004 .56463 L p .683 .584 .738 r
F P
0 g
s
.60004 .56463 m .59614 .59273 L .56728 .57212 L p .683 .584 .738 r
F P
0 g
s
.57005 .54824 m .57028 .52401 L .60013 .53618 L p .652 .563 .742 r
F P
0 g
s
.60013 .53618 m .60004 .56463 L .57005 .54824 L p .652 .563 .742 r
F P
0 g
s
.68902 .42374 m .70382 .46473 L .68048 .47286 L p .854 .733 .728 r
F P
0 g
s
.70382 .46473 m .68902 .42374 L .70599 .41232 L p .945 .783 .651 r
F P
0 g
s
.5549 .45224 m .54458 .4297 L .56311 .42785 L p .49 .493 .787 r
F P
0 g
s
.54584 .40438 m .56311 .42785 L .54458 .4297 L p .431 .478 .808 r
F P
0 g
s
.68463 .37183 m .70599 .41232 L .68902 .42374 L p .897 .719 .652 r
F P
0 g
s
.29776 .56063 m .29655 .5474 L .25741 .57136 L p .751 .961 .936 r
F P
0 g
s
.29655 .5474 m .29776 .56063 L .33738 .54568 L p .531 .885 .981 r
F P
0 g
s
.41356 .55617 m .41421 .55759 L .3775 .54852 L p .279 0 0 r
F P
0 g
s
.41704 .55825 m .444 .57438 L p .41421 .55759 L .706 .178 0 r
F P
0 g
s
.444 .57438 m .44425 .57498 L p .41421 .55759 L .706 .178 0 r
F P
0 g
s
.44425 .57498 m .44645 .58039 L .4261 .566 L p .706 .178 0 r
F P
0 g
s
.4261 .566 m .41421 .55759 L p .44425 .57498 L .706 .178 0 r
F P
0 g
s
.41864 .55955 m .41421 .55759 L .4261 .566 L p .691 .151 0 r
F P
0 g
s
.4261 .566 m .44645 .58039 L p .41864 .55955 L .691 .151 0 r
F P
0 g
s
.41421 .55759 m .41864 .55955 L .41147 .55695 L p .276 0 0 r
F P
0 g
s
.37918 .54525 m .3775 .54852 L .41421 .55759 L p .276 0 0 r
F P
0 g
s
.41147 .55695 m .37918 .54525 L p .41421 .55759 L .276 0 0 r
F P
0 g
s
.41421 .55759 m .41356 .55617 L .41704 .55825 L p .706 .178 0 r
F P
0 g
s
.38596 .54266 m .38201 .54417 L p .41864 .55955 L 0 .338 .727 r
F P
0 g
s
.38201 .54417 m .37918 .54525 L .39786 .55202 L p 0 .338 .727 r
F P
0 g
s
.39786 .55202 m .41864 .55955 L p .38201 .54417 L 0 .338 .727 r
F P
0 g
s
.44423 .56876 m .444 .57438 L .41356 .55617 L p .673 .168 .035 r
F P
0 g
s
.57028 .52401 m .56784 .49973 L .59635 .50781 L p .619 .544 .748 r
F P
0 g
s
.59635 .50781 m .60013 .53618 L .57028 .52401 L p .619 .544 .748 r
F P
0 g
s
.56784 .49973 m .5627 .4757 L .58877 .47999 L p .582 .526 .757 r
F P
0 g
s
.58877 .47999 m .59635 .50781 L .56784 .49973 L p .582 .526 .757 r
F P
0 g
s
.5627 .4757 m .5549 .45224 L .57757 .45319 L p .54 .509 .77 r
F P
0 g
s
.56311 .42785 m .57757 .45319 L .5549 .45224 L p .49 .493 .787 r
F P
0 g
s
.55492 .6179 m .54587 .63942 L .52504 .60721 L p .732 .584 .69 r
F P
0 g
s
.57757 .45319 m .58877 .47999 L .5627 .4757 L p .54 .509 .77 r
F P
0 g
s
.50535 .36445 m .48356 .34848 L .48742 .33559 L p .456 .541 .855 r
F P
0 g
s
.3775 .54852 m .37918 .54525 L .33738 .54568 L p .249 .736 .924 r
F P
0 g
s
.49391 .60523 m .4986 .59198 L .51828 .62441 L p .773 .572 .627 r
F P
0 g
s
.52504 .60721 m .51828 .62441 L .4986 .59198 L p .732 .536 .627 r
F P
0 g
s
.28152 .80468 m .31003 .81003 L .27419 .78809 L p .706 .168 0 r
F P
0 g
s
.27419 .78809 m .24521 .77767 L .28152 .80468 L p .706 .168 0 r
F P
0 g
s
.39267 .81127 m .41776 .80386 L .38133 .81507 L p .215 .739 .804 r
F P
0 g
s
.38133 .81507 m .35099 .81811 L .39267 .81127 L p .215 .739 .804 r
F P
0 g
s
.51828 .62441 m .52504 .60721 L .54587 .63942 L p .765 .616 .693 r
F P
0 g
s
.54587 .63942 m .53533 .65983 L .51828 .62441 L p .765 .616 .693 r
F P
0 g
s
.60004 .56463 m .60013 .53618 L .6324 .54567 L p .715 .637 .769 r
F P
0 g
s
.49822 .71378 m .51115 .69705 L .51003 .73437 L p .869 .82 .798 r
F P
0 g
s
.51003 .73437 m .48972 .75139 L .49822 .71378 L p .869 .82 .798 r
F P
0 g
s
.49072 1.15314 m .55883 1.13352 L .51959 1.07843 L p .721 .562 .673 r
F P
0 g
s
.51959 1.07843 m .45614 1.09331 L .49072 1.15314 L p .721 .562 .673 r
F P
0 g
s
.5807 1.05701 m .51959 1.07843 L .55883 1.13352 L p .685 .532 .673 r
F P
0 g
s
.45614 1.09331 m .51959 1.07843 L .48169 1.02357 L p .757 .638 .729 r
F P
0 g
s
.51959 1.07843 m .5807 1.05701 L .53625 1.00726 L p .727 .61 .726 r
F P
0 g
s
.53625 1.00726 m .48169 1.02357 L .51959 1.07843 L p .727 .61 .726 r
F P
0 g
s
.444 .57438 m .44423 .56876 L .46862 .59506 L p .83 .449 .331 r
F P
0 g
s
.47023 .5857 m .46862 .59506 L .44423 .56876 L p .774 .411 .368 r
F P
0 g
s
.44933 .77917 m .46928 .76631 L .44482 .79369 L p .748 .974 .924 r
F P
0 g
s
.44482 .79369 m .41776 .80386 L .44933 .77917 L p .748 .974 .924 r
F P
0 g
s
.55883 1.13352 m .62321 1.10708 L .5807 1.05701 L p .685 .532 .673 r
F P
0 g
s
.63747 1.02928 m .5807 1.05701 L .62321 1.10708 L p .646 .504 .675 r
F P
0 g
s
.5807 1.05701 m .63747 1.02928 L .5881 .98515 L p .696 .584 .726 r
F P
0 g
s
.5881 .98515 m .53625 1.00726 L .5807 1.05701 L p .696 .584 .726 r
F P
0 g
s
.66779 .32221 m .63366 .28828 L .64095 .27948 L p .91 .522 .262 r
F P
0 g
s
.60375 .24996 m .64095 .27948 L .63366 .28828 L p .861 .489 .341 r
F P
0 g
s
.51127 .6409 m .51828 .62441 L .53533 .65983 L p .799 .651 .698 r
F P
0 g
s
.53533 .65983 m .52364 .67906 L .51127 .6409 L p .799 .651 .698 r
F P
0 g
s
.62849 .51297 m .6324 .54567 L .60013 .53618 L p .69 .617 .769 r
F P
0 g
s
.6324 .54567 m .62849 .51297 L .66054 .5146 L p .757 .684 .781 r
F P
0 g
s
.60013 .53618 m .59635 .50781 L .62849 .51297 L p .69 .617 .769 r
F P
0 g
s
.48169 1.02357 m .53625 1.00726 L .49397 .96243 L p .766 .69 .779 r
F P
0 g
s
.53625 1.00726 m .5881 .98515 L .53827 .94587 L p .742 .664 .773 r
F P
0 g
s
.53827 .94587 m .49397 .96243 L .53625 1.00726 L p .742 .664 .773 r
F P
0 g
s
.46862 .59506 m .47023 .5857 L .49003 .61812 L p .834 .559 .523 r
F P
0 g
s
.49391 .60523 m .49003 .61812 L .47023 .5857 L p .783 .516 .532 r
F P
0 g
s
.51828 .62441 m .51127 .6409 L .49391 .60523 L p .773 .572 .627 r
F P
0 g
s
.52636 .38315 m .50535 .36445 L .51464 .35207 L p .501 .544 .832 r
F P
0 g
s
.48742 .33559 m .51464 .35207 L .50535 .36445 L p .456 .541 .855 r
F P
0 g
s
.42104 1.16576 m .49072 1.15314 L .45614 1.09331 L p .757 .593 .674 r
F P
0 g
s
.45614 1.09331 m .39244 1.10157 L .42104 1.16576 L p .757 .593 .674 r
F P
0 g
s
.39244 1.10157 m .45614 1.09331 L .42629 1.03397 L p .786 .669 .735 r
F P
0 g
s
.48169 1.02357 m .42629 1.03397 L .45614 1.09331 L p .757 .638 .729 r
F P
0 g
s
.65125 .4785 m .66054 .5146 L .62849 .51297 L p .735 .659 .775 r
F P
0 g
s
.66054 .5146 m .65125 .4785 L .68048 .47286 L p .805 .718 .769 r
F P
0 g
s
.42629 1.03397 m .48169 1.02357 L .44867 .97401 L p .789 .721 .788 r
F P
0 g
s
.49397 .96243 m .44867 .97401 L .48169 1.02357 L p .766 .69 .779 r
F P
0 g
s
.49003 .61812 m .49391 .60523 L .51127 .6409 L p .815 .612 .628 r
F P
0 g
s
.4852 .72928 m .49822 .71378 L .48972 .75139 L p .885 .876 .821 r
F P
0 g
s
.48972 .75139 m .46928 .76631 L .4852 .72928 L p .885 .876 .821 r
F P
0 g
s
.33738 .54568 m .34099 .53745 L .29655 .5474 L p .531 .885 .981 r
F P
0 g
s
.34099 .53745 m .33738 .54568 L .37918 .54525 L p .198 .683 .927 r
F P
0 g
s
.63547 .95755 m .5881 .98515 L .63747 1.02928 L p .664 .561 .728 r
F P
0 g
s
.5881 .98515 m .63547 .95755 L .57998 .92448 L p .718 .64 .77 r
F P
0 g
s
.57998 .92448 m .53827 .94587 L .5881 .98515 L p .718 .64 .77 r
F P
0 g
s
.50423 .65673 m .51127 .6409 L .52364 .67906 L p .834 .691 .705 r
F P
0 g
s
.52364 .67906 m .51115 .69705 L .50423 .65673 L p .834 .691 .705 r
F P
0 g
s
.59635 .50781 m .58877 .47999 L .61945 .48097 L p .665 .599 .772 r
F P
0 g
s
.61945 .48097 m .62849 .51297 L .59635 .50781 L p .665 .599 .772 r
F P
0 g
s
.52685 1.20791 m .5958 1.18372 L .55883 1.13352 L p .679 .48 .61 r
F P
0 g
s
.55883 1.13352 m .49072 1.15314 L .52685 1.20791 L p .679 .48 .61 r
F P
0 g
s
.62321 1.10708 m .55883 1.13352 L .5958 1.18372 L p .633 .445 .61 r
F P
0 g
s
.66473 .43468 m .68048 .47286 L .65125 .4785 L p .78 .685 .759 r
F P
0 g
s
.68048 .47286 m .66473 .43468 L .68902 .42374 L p .854 .733 .728 r
F P
0 g
s
.68463 .37183 m .65558 .33474 L .66779 .32221 L p .927 .663 .519 r
F P
0 g
s
.63366 .28828 m .66779 .32221 L .65558 .33474 L p .871 .609 .54 r
F P
0 g
s
.32481 .81804 m .35099 .81811 L .31003 .81003 L p .36 0 0 r
F P
0 g
s
.31003 .81003 m .28152 .80468 L .32481 .81804 L p .36 0 0 r
F P
0 g
s
.54584 .40438 m .52636 .38315 L .54106 .37207 L p .541 .55 .813 r
F P
0 g
s
.51464 .35207 m .54106 .37207 L .52636 .38315 L p .501 .544 .832 r
F P
0 g
s
.45512 1.22513 m .52685 1.20791 L .49072 1.15314 L p .721 .514 .61 r
F P
0 g
s
.49072 1.15314 m .42104 1.16576 L .45512 1.22513 L p .721 .514 .61 r
F P
0 g
s
.63366 .28828 m .59415 .25955 L .60375 .24996 L p .861 .489 .341 r
F P
0 g
s
.56246 .22609 m .60375 .24996 L .59415 .25955 L p .803 .447 .383 r
F P
0 g
s
.62849 .51297 m .61945 .48097 L .65125 .4785 L p .735 .659 .775 r
F P
0 g
s
.58877 .47999 m .57757 .45319 L .6056 .45031 L p .638 .584 .777 r
F P
0 g
s
.6056 .45031 m .61945 .48097 L .58877 .47999 L p .638 .584 .777 r
F P
0 g
s
.62321 1.10708 m .6818 1.07417 L .63747 1.02928 L p .646 .504 .675 r
F P
0 g
s
.68801 .99567 m .63747 1.02928 L .6818 1.07417 L p .603 .475 .679 r
F P
0 g
s
.63747 1.02928 m .68801 .99567 L .63547 .95755 L p .664 .561 .728 r
F P
0 g
s
.51127 .6409 m .50423 .65673 L .49003 .61812 L p .815 .612 .628 r
F P
0 g
s
.6664 .38518 m .68902 .42374 L .66473 .43468 L p .82 .688 .718 r
F P
0 g
s
.68902 .42374 m .6664 .38518 L .68463 .37183 L p .897 .719 .652 r
F P
0 g
s
.65558 .33474 m .68463 .37183 L .6664 .38518 L p .852 .665 .649 r
F P
0 g
s
.57757 .45319 m .56311 .42785 L .58744 .42159 L p .608 .57 .786 r
F P
0 g
s
.58744 .42159 m .6056 .45031 L .57757 .45319 L p .608 .57 .786 r
F P
0 g
s
.49731 .67198 m .50423 .65673 L .51115 .69705 L p .87 .738 .715 r
F P
0 g
s
.51115 .69705 m .49822 .71378 L .49731 .67198 L p .87 .738 .715 r
F P
0 g
s
.56311 .42785 m .54584 .40438 L .56565 .39535 L p .576 .559 .797 r
F P
0 g
s
.54106 .37207 m .56565 .39535 L .54584 .40438 L p .541 .55 .813 r
F P
0 g
s
.59415 .25955 m .55114 .23671 L .56246 .22609 L p .803 .447 .383 r
F P
0 g
s
.44645 .58039 m .444 .57438 L .46876 .60459 L p .88 .479 .263 r
F P
0 g
s
.46862 .59506 m .46876 .60459 L .444 .57438 L p .83 .449 .331 r
F P
0 g
s
.56565 .39535 m .58744 .42159 L .56311 .42785 L p .576 .559 .797 r
F P
0 g
s
.4305 .7901 m .44933 .77917 L .41776 .80386 L p .641 .962 .915 r
F P
0 g
s
.41776 .80386 m .39267 .81127 L .4305 .7901 L p .641 .962 .915 r
F P
0 g
s
.51464 .35207 m .48742 .33559 L .49581 .31744 L p .575 .562 .802 r
F P
0 g
s
.49003 .61812 m .48704 .63082 L .46862 .59506 L p .834 .559 .523 r
F P
0 g
s
.48704 .63082 m .49003 .61812 L .50423 .65673 L p .859 .657 .629 r
F P
0 g
s
.46876 .60459 m .46862 .59506 L .48704 .63082 L p .887 .606 .505 r
F P
0 g
s
.42629 1.03397 m .37194 1.03848 L .39244 1.10157 L p .786 .669 .735 r
F P
0 g
s
.37194 1.03848 m .42629 1.03397 L .40399 .98063 L p .81 .756 .802 r
F P
0 g
s
.44867 .97401 m .40399 .98063 L .42629 1.03397 L p .789 .721 .788 r
F P
0 g
s
.5958 1.18372 m .65979 1.15281 L .62321 1.10708 L p .633 .445 .61 r
F P
0 g
s
.6818 1.07417 m .62321 1.10708 L .65979 1.15281 L p .581 .406 .61 r
F P
0 g
s
.47243 .7436 m .4852 .72928 L .46928 .76631 L p .886 .935 .844 r
F P
0 g
s
.46928 .76631 m .44933 .77917 L .47243 .7436 L p .886 .935 .844 r
F P
0 g
s
.6767 .92492 m .63547 .95755 L .68801 .99567 L p .629 .539 .733 r
F P
0 g
s
.63547 .95755 m .6767 .92492 L .61758 .89855 L p .692 .619 .77 r
F P
0 g
s
.61758 .89855 m .57998 .92448 L .63547 .95755 L p .692 .619 .77 r
F P
0 g
s
.63581 .4439 m .65125 .4785 L .61945 .48097 L p .712 .637 .773 r
F P
0 g
s
.65125 .4785 m .63581 .4439 L .66473 .43468 L p .78 .685 .759 r
F P
0 g
s
.61945 .48097 m .6056 .45031 L .63581 .4439 L p .712 .637 .773 r
F P
0 g
s
.35201 1.1714 m .42104 1.16576 L .39244 1.10157 L p .792 .628 .678 r
F P
0 g
s
.39244 1.10157 m .33059 1.10329 L .35201 1.1714 L p .792 .628 .678 r
F P
0 g
s
.33059 1.10329 m .39244 1.10157 L .37194 1.03848 L p .815 .705 .744 r
F P
0 g
s
.50423 .65673 m .49731 .67198 L .48704 .63082 L p .859 .657 .629 r
F P
0 g
s
.37918 .54525 m .38596 .54266 L .34099 .53745 L p .198 .683 .927 r
F P
0 g
s
.49397 .96243 m .53827 .94587 L .49265 .91518 L p .79 .757 .822 r
F P
0 g
s
.53827 .94587 m .57998 .92448 L .52669 .89958 L p .773 .727 .81 r
F P
0 g
s
.52669 .89958 m .49265 .91518 L .53827 .94587 L p .773 .727 .81 r
F P
0 g
s
.38283 1.23529 m .45512 1.22513 L .42104 1.16576 L p .762 .55 .61 r
F P
0 g
s
.42104 1.16576 m .35201 1.1714 L .38283 1.23529 L p .762 .55 .61 r
F P
0 g
s
.49066 .68673 m .49731 .67198 L .49822 .71378 L p .906 .795 .727 r
F P
0 g
s
.49822 .71378 m .4852 .72928 L .49066 .68673 L p .906 .795 .727 r
F P
0 g
s
.65558 .33474 m .62019 .3021 L .63366 .28828 L p .871 .609 .54 r
F P
0 g
s
.59415 .25955 m .63366 .28828 L .62019 .3021 L p .818 .561 .551 r
F P
0 g
s
.20179 .62818 m .21054 .64971 L .22769 .60672 L p .932 .969 .698 r
F P
0 g
s
.22769 .60672 m .22461 .5862 L .20179 .62818 L p .932 .969 .698 r
F P
0 g
s
.22461 .5862 m .22769 .60672 L .25741 .57136 L p .823 .997 .845 r
F P
0 g
s
.19384 .67522 m .20778 .69577 L .21054 .64971 L p .982 .871 .503 r
F P
0 g
s
.21054 .64971 m .20179 .62818 L .19384 .67522 L p .982 .871 .503 r
F P
0 g
s
.44867 .97401 m .49397 .96243 L .45788 .92684 L p .806 .79 .838 r
F P
0 g
s
.49265 .91518 m .45788 .92684 L .49397 .96243 L p .79 .757 .822 r
F P
0 g
s
.37043 .8162 m .39267 .81127 L .35099 .81811 L p .094 .651 .773 r
F P
0 g
s
.35099 .81811 m .32481 .81804 L .37043 .8162 L p .094 .651 .773 r
F P
0 g
s
.57998 .92448 m .61758 .89855 L .55871 .88015 L p .753 .7 .801 r
F P
0 g
s
.55871 .88015 m .52669 .89958 L .57998 .92448 L p .753 .7 .801 r
F P
0 g
s
.54106 .37207 m .51464 .35207 L .52845 .33484 L p .607 .573 .79 r
F P
0 g
s
.49581 .31744 m .52845 .33484 L .51464 .35207 L p .575 .562 .802 r
F P
0 g
s
.64223 .39896 m .66473 .43468 L .63581 .4439 L p .754 .655 .752 r
F P
0 g
s
.66473 .43468 m .64223 .39896 L .6664 .38518 L p .82 .688 .718 r
F P
0 g
s
.25741 .57136 m .25981 .5538 L .22461 .5862 L p .823 .997 .845 r
F P
0 g
s
.25981 .5538 m .25741 .57136 L .29655 .5474 L p .66 .957 .942 r
F P
0 g
s
.6056 .45031 m .58744 .42159 L .61486 .41158 L p .688 .618 .773 r
F P
0 g
s
.61486 .41158 m .63581 .4439 L .6056 .45031 L p .688 .618 .773 r
F P
0 g
s
.20166 .72226 m .21974 .74 L .20778 .69577 L p .962 .697 .26 r
F P
0 g
s
.20778 .69577 m .19384 .67522 L .20166 .72226 L p .962 .697 .26 r
F P
0 g
s
.48704 .63082 m .48496 .64351 L .46876 .60459 L p .887 .606 .505 r
F P
0 g
s
.48496 .64351 m .48704 .63082 L .49731 .67198 L p .906 .71 .627 r
F P
0 g
s
.6664 .38518 m .63695 .35011 L .65558 .33474 L p .852 .665 .649 r
F P
0 g
s
.62019 .3021 m .65558 .33474 L .63695 .35011 L p .809 .62 .647 r
F P
0 g
s
.63695 .35011 m .6664 .38518 L .64223 .39896 L p .787 .65 .71 r
F P
0 g
s
.49731 .67198 m .49066 .68673 L .48496 .64351 L p .906 .71 .627 r
F P
0 g
s
.63581 .4439 m .61486 .41158 L .64223 .39896 L p .754 .655 .752 r
F P
0 g
s
.6818 1.07417 m .73262 1.03532 L .68801 .99567 L p .603 .475 .679 r
F P
0 g
s
.73053 .9568 m .68801 .99567 L .73262 1.03532 L p .552 .444 .685 r
F P
0 g
s
.68801 .99567 m .73053 .9568 L .6767 .92492 L p .629 .539 .733 r
F P
0 g
s
.58744 .42159 m .56565 .39535 L .58924 .38227 L p .662 .601 .776 r
F P
0 g
s
.58924 .38227 m .61486 .41158 L .58744 .42159 L p .662 .601 .776 r
F P
0 g
s
.45604 .59398 m .44645 .58039 L p .46917 .60683 L .88 .479 .263 r
F P
0 g
s
.46917 .60683 m .47056 .61457 L .45604 .59398 L p .88 .479 .263 r
F P
0 g
s
.4514 .58718 m .44645 .58039 L .44909 .58413 L p .902 .487 .137 r
F P
0 g
s
.44909 .58413 m .47056 .61457 L p .4514 .58718 L .902 .487 .137 r
F P
0 g
s
.47056 .61457 m .47115 .61654 L p .4514 .58718 L .902 .487 .137 r
F P
0 g
s
.47115 .61654 m .47377 .62522 L .46004 .60187 L p .902 .487 .137 r
F P
0 g
s
.46004 .60187 m .4514 .58718 L p .47115 .61654 L .902 .487 .137 r
F P
0 g
s
.44645 .58039 m .45047 .5859 L p .44409 .57862 L .691 .151 0 r
F P
0 g
s
.45047 .5859 m .4514 .58718 L p .44409 .57862 L .691 .151 0 r
F P
0 g
s
.4514 .58718 m .41864 .55955 L p .44409 .57862 L .691 .151 0 r
F P
0 g
s
.46876 .60459 m .46917 .60683 L p .44645 .58039 L .88 .479 .263 r
F P
0 g
s
.43777 .5671 m .43189 .5647 L p .45852 .59508 L 0 .067 .617 r
F P
0 g
s
.45852 .59508 m .4514 .58718 L .47377 .62522 L p .817 .425 0 r
F P
0 g
s
.45356 .59003 m .45235 .58879 L p .4514 .58718 L .577 .067 0 r
F P
0 g
s
.42663 .56256 m .42224 .56091 L p .4514 .58718 L .577 .067 0 r
F P
0 g
s
.43466 .57306 m .4514 .58718 L p .42224 .56091 L .577 .067 0 r
F P
0 g
s
.45235 .58879 m .42663 .56256 L p .4514 .58718 L .577 .067 0 r
F P
0 g
s
.43189 .5647 m .42663 .56256 L .44261 .57886 L p 0 .067 .617 r
F P
0 g
s
.4514 .58718 m .45852 .59508 L .45356 .59003 L p .577 .067 0 r
F P
0 g
s
.44261 .57886 m .45852 .59508 L p .43189 .5647 L 0 .067 .617 r
F P
0 g
s
.42224 .56091 m .41864 .55955 L .43466 .57306 L p .577 .067 0 r
F P
0 g
s
.47056 .61457 m .46876 .60459 L .48496 .64351 L p .943 .658 .47 r
F P
0 g
s
.56565 .39535 m .54106 .37207 L .56003 .35654 L p .636 .586 .781 r
F P
0 g
s
.52845 .33484 m .56003 .35654 L .54106 .37207 L p .607 .573 .79 r
F P
0 g
s
.29655 .5474 m .30358 .53443 L .25981 .5538 L p .66 .957 .942 r
F P
0 g
s
.30358 .53443 m .29655 .5474 L .34099 .53745 L p .444 .841 .978 r
F P
0 g
s
.62019 .3021 m .5801 .27473 L .59415 .25955 L p .818 .561 .551 r
F P
0 g
s
.55114 .23671 m .59415 .25955 L .5801 .27473 L p .768 .517 .556 r
F P
0 g
s
.5801 .27473 m .53719 .25321 L .55114 .23671 L p .768 .517 .556 r
F P
0 g
s
.22447 .76418 m .24521 .77767 L .21974 .74 L p .852 .438 0 r
F P
0 g
s
.21974 .74 m .20166 .72226 L .22447 .76418 L p .852 .438 0 r
F P
0 g
s
.56003 .35654 m .58924 .38227 L .56565 .39535 L p .636 .586 .781 r
F P
0 g
s
.46023 .75682 m .47243 .7436 L .44933 .77917 L p .853 .985 .856 r
F P
0 g
s
.44933 .77917 m .4305 .7901 L .46023 .75682 L p .853 .985 .856 r
F P
0 g
s
.48436 .70106 m .49066 .68673 L .4852 .72928 L p .938 .862 .739 r
F P
0 g
s
.4852 .72928 m .47243 .7436 L .48436 .70106 L p .938 .862 .739 r
F P
0 g
s
.52845 .33484 m .49581 .31744 L .50785 .29602 L p .641 .564 .753 r
F P
0 g
s
.40399 .98063 m .44867 .97401 L .42374 .93458 L p .816 .827 .858 r
F P
0 g
s
.45788 .92684 m .42374 .93458 L .44867 .97401 L p .806 .79 .838 r
F P
0 g
s
.41864 .55955 m .42663 .56256 L .38596 .54266 L p 0 .338 .727 r
F P
0 g
s
.64968 .86854 m .61758 .89855 L .6767 .92492 L p .665 .6 .772 r
F P
0 g
s
.61758 .89855 m .64968 .86854 L .58746 .85714 L p .733 .676 .795 r
F P
0 g
s
.58746 .85714 m .55871 .88015 L .61758 .89855 L p .733 .676 .795 r
F P
0 g
s
.65979 1.15281 m .71678 1.11559 L .6818 1.07417 L p .581 .406 .61 r
F P
0 g
s
.73262 1.03532 m .6818 1.07417 L .71678 1.11559 L p .519 .362 .609 r
F P
0 g
s
.71025 .88791 m .6767 .92492 L .73053 .9568 L p .59 .518 .741 r
F P
0 g
s
.6767 .92492 m .71025 .88791 L .64968 .86854 L p .665 .6 .772 r
F P
0 g
s
.49155 1.27397 m .56114 1.25234 L .52685 1.20791 L p .67 .417 .529 r
F P
0 g
s
.52685 1.20791 m .45512 1.22513 L .49155 1.27397 L p .67 .417 .529 r
F P
0 g
s
.5958 1.18372 m .52685 1.20791 L .56114 1.25234 L p .618 .374 .525 r
F P
0 g
s
.34099 .53745 m .35122 .53016 L .30358 .53443 L p .444 .841 .978 r
F P
0 g
s
.35122 .53016 m .34099 .53745 L .38596 .54266 L p .183 .644 .939 r
F P
0 g
s
.37194 1.03848 m .32059 1.03733 L .33059 1.10329 L p .815 .705 .744 r
F P
0 g
s
.32059 1.03733 m .37194 1.03848 L .3616 .98246 L p .83 .795 .819 r
F P
0 g
s
.40399 .98063 m .3616 .98246 L .37194 1.03848 L p .81 .756 .802 r
F P
0 g
s
.41336 .79927 m .4305 .7901 L .39267 .81127 L p .492 .904 .876 r
F P
0 g
s
.39267 .81127 m .37043 .8162 L .41336 .79927 L p .492 .904 .876 r
F P
0 g
s
.61396 .36659 m .64223 .39896 L .61486 .41158 L p .727 .629 .748 r
F P
0 g
s
.64223 .39896 m .61396 .36659 L .63695 .35011 L p .787 .65 .71 r
F P
0 g
s
.61486 .41158 m .58924 .38227 L .61396 .36659 L p .727 .629 .748 r
F P
0 g
s
.25982 .7964 m .28152 .80468 L .24521 .77767 L p .636 .104 0 r
F P
0 g
s
.24521 .77767 m .22447 .76418 L .25982 .7964 L p .636 .104 0 r
F P
0 g
s
.48496 .64351 m .48371 .65636 L .47056 .61457 L p .943 .658 .47 r
F P
0 g
s
.48371 .65636 m .48496 .64351 L .49066 .68673 L p .955 .774 .62 r
F P
0 g
s
.63695 .35011 m .60201 .31942 L .62019 .3021 L p .809 .62 .647 r
F P
0 g
s
.5801 .27473 m .62019 .3021 L .60201 .31942 L p .768 .581 .645 r
F P
0 g
s
.49066 .68673 m .48436 .70106 L .48371 .65636 L p .955 .774 .62 r
F P
0 g
s
.56114 1.25234 m .62689 1.22413 L .5958 1.18372 L p .618 .374 .525 r
F P
0 g
s
.65979 1.15281 m .5958 1.18372 L .62689 1.22413 L p .556 .324 .518 r
F P
0 g
s
.56003 .35654 m .52845 .33484 L .54526 .31466 L p .671 .584 .748 r
F P
0 g
s
.50785 .29602 m .54526 .31466 L .52845 .33484 L p .641 .564 .753 r
F P
0 g
s
.60201 .31942 m .63695 .35011 L .61396 .36659 L p .754 .616 .705 r
F P
0 g
s
.42026 1.28886 m .49155 1.27397 L .45512 1.22513 L p .718 .456 .529 r
F P
0 g
s
.45512 1.22513 m .38283 1.23529 L .42026 1.28886 L p .718 .456 .529 r
F P
0 g
s
.56316 .29382 m .52219 .27376 L .53719 .25321 L p .728 .545 .644 r
F P
0 g
s
.53719 .25321 m .5801 .27473 L .56316 .29382 L p .728 .545 .644 r
F P
0 g
s
.58924 .38227 m .56003 .35654 L .58115 .33829 L p .7 .605 .747 r
F P
0 g
s
.58115 .33829 m .61396 .36659 L .58924 .38227 L p .7 .605 .747 r
F P
0 g
s
.47176 .61839 m .48371 .65636 L p .47377 .62522 L .985 .707 .396 r
F P
0 g
s
.48371 .65636 m .48348 .66183 L p .47377 .62522 L .985 .707 .396 r
F P
0 g
s
.48348 .66183 m .48317 .6695 L .47801 .64519 L p .985 .707 .396 r
F P
0 g
s
.47801 .64519 m .47377 .62522 L p .48348 .66183 L .985 .707 .396 r
F P
0 g
s
.4781 .63675 m .47377 .62522 L .48317 .6695 L p .942 .705 .234 r
F P
0 g
s
.47377 .62522 m .4781 .63675 L .4756 .63144 L p .817 .425 0 r
F P
0 g
s
.4756 .63144 m .45852 .59508 L p .47377 .62522 L .817 .425 0 r
F P
0 g
s
.47377 .62522 m .47056 .61457 L .47176 .61839 L p .985 .707 .396 r
F P
0 g
s
.46736 .60438 m .46311 .59991 L p .4781 .63675 L 0 0 .365 r
F P
0 g
s
.46311 .59991 m .45852 .59508 L .46853 .61638 L p 0 0 .365 r
F P
0 g
s
.46853 .61638 m .4781 .63675 L p .46311 .59991 L 0 0 .365 r
F P
0 g
s
.54526 .31466 m .50785 .29602 L .52219 .27376 L p .687 .558 .703 r
F P
0 g
s
.47848 .71507 m .48436 .70106 L .47243 .7436 L p .951 .934 .742 r
F P
0 g
s
.47243 .7436 m .46023 .75682 L .47848 .71507 L p .951 .934 .742 r
F P
0 g
s
.54526 .31466 m .58115 .33829 L .56003 .35654 L p .671 .584 .748 r
F P
0 g
s
.60201 .31942 m .56316 .29382 L .5801 .27473 L p .768 .581 .645 r
F P
0 g
s
.38596 .54266 m .39761 .54144 L .35122 .53016 L p .183 .644 .939 r
F P
0 g
s
.39761 .54144 m .38596 .54266 L .42663 .56256 L p 0 .374 .814 r
F P
0 g
s
.61396 .36659 m .58115 .33829 L .60201 .31942 L p .754 .616 .705 r
F P
0 g
s
.30388 .81538 m .32481 .81804 L .28152 .80468 L p .329 0 0 r
F P
0 g
s
.28152 .80468 m .25982 .7964 L .30388 .81538 L p .329 0 0 r
F P
0 g
s
.52219 .27376 m .56316 .29382 L .54526 .31466 L p .687 .558 .703 r
F P
0 g
s
.67504 .83506 m .64968 .86854 L .71025 .88791 L p .637 .584 .778 r
F P
0 g
s
.64968 .86854 m .67504 .83506 L .61182 .83094 L p .711 .655 .793 r
F P
0 g
s
.61182 .83094 m .58746 .85714 L .64968 .86854 L p .711 .655 .793 r
F P
0 g
s
.44888 .76904 m .46023 .75682 L .4305 .7901 L p .753 .995 .834 r
F P
0 g
s
.4305 .7901 m .41336 .79927 L .44888 .76904 L p .753 .995 .834 r
F P
0 g
s
.56316 .29382 m .60201 .31942 L .58115 .33829 L p .721 .586 .703 r
F P
0 g
s
.3616 .98246 m .40399 .98063 L .39158 .93857 L p .82 .867 .881 r
F P
0 g
s
.42374 .93458 m .39158 .93857 L .40399 .98063 L p .816 .827 .858 r
F P
0 g
s
.49265 .91518 m .52669 .89958 L .48075 .8854 L p .833 .837 .85 r
F P
0 g
s
.52669 .89958 m .55871 .88015 L .50568 .87159 L p .82 .796 .829 r
F P
0 g
s
.50568 .87159 m .48075 .8854 L .52669 .89958 L p .82 .796 .829 r
F P
0 g
s
.48317 .6695 m .48371 .65636 L .48436 .70106 L p .992 .845 .593 r
F P
0 g
s
.58115 .33829 m .54526 .31466 L .56316 .29382 L p .721 .586 .703 r
F P
0 g
s
.48436 .70106 m .47848 .71507 L .48317 .6695 L p .992 .845 .593 r
F P
0 g
s
.55871 .88015 m .58746 .85714 L .52948 .85485 L p .803 .759 .812 r
F P
0 g
s
.52948 .85485 m .50568 .87159 L .55871 .88015 L p .803 .759 .812 r
F P
0 g
s
.62689 1.22413 m .68673 1.18964 L .65979 1.15281 L p .556 .324 .518 r
F P
0 g
s
.71678 1.11559 m .65979 1.15281 L .68673 1.18964 L p .478 .261 .505 r
F P
0 g
s
.42663 .56256 m .43777 .5671 L .39761 .54144 L p 0 .374 .814 r
F P
0 g
s
.45788 .92684 m .49265 .91518 L .45573 .89626 L p .838 .882 .874 r
F P
0 g
s
.48075 .8854 m .45573 .89626 L .49265 .91518 L p .833 .837 .85 r
F P
0 g
s
.35185 .81901 m .37043 .8162 L .32481 .81804 L p .013 .584 .768 r
F P
0 g
s
.32481 .81804 m .30388 .81538 L .35185 .81901 L p .013 .584 .768 r
F P
0 g
s
.73262 1.03532 m .77386 .99126 L .73053 .9568 L p .552 .444 .685 r
F P
0 g
s
.76344 .91349 m .73053 .9568 L .77386 .99126 L p .491 .41 .692 r
F P
0 g
s
.73053 .9568 m .76344 .91349 L .71025 .88791 L p .59 .518 .741 r
F P
0 g
s
.58746 .85714 m .61182 .83094 L .55113 .83535 L p .783 .726 .799 r
F P
0 g
s
.55113 .83535 m .52948 .85485 L .58746 .85714 L p .783 .726 .799 r
F P
0 g
s
.47304 .72881 m .47848 .71507 L .47683 .71883 L p .901 .981 .707 r
F P
0 g
s
.47683 .71883 m .46103 .75498 L p .47304 .72881 L .901 .981 .707 r
F P
0 g
s
.46128 .75451 m .47304 .72881 L .46103 .75498 L .901 .981 .707 r
F
.46103 .75498 m .46023 .75682 L p .46128 .75451 L F P
0 g
s
.46023 .75682 m .44888 .76904 L .47304 .72881 L p .901 .981 .707 r
F P
0 g
s
.46804 .74237 m .47304 .72881 L .44888 .76904 L p .708 .92 .579 r
F P
0 g
s
.47304 .72881 m .46804 .74237 L .46931 .7386 L p .742 .789 .299 r
F P
0 g
s
.48314 .68303 m .48317 .6695 L .48288 .67231 L p .965 .889 .509 r
F P
0 g
s
.48288 .67231 m .47848 .71507 L p .48314 .68303 L .965 .889 .509 r
F P
0 g
s
.48314 .68303 m .48341 .69702 L .48339 .69305 L p 0 0 .049 r
F P
0 g
s
.48317 .6695 m .48314 .68303 L .4781 .63675 L p .942 .705 .234 r
F P
0 g
s
.48339 .69305 m .48316 .6493 L p .48314 .68303 L 0 0 .049 r
F P
0 g
s
.47848 .71507 m .47304 .72881 L .48314 .68303 L p .965 .889 .509 r
F P
0 g
s
.48341 .69702 m .48314 .68303 L .47304 .72881 L p .742 .789 .299 r
F P
0 g
s
.46931 .7386 m .48341 .69702 L p .47304 .72881 L .742 .789 .299 r
F P
0 g
s
.43867 .78038 m .44888 .76904 L .44806 .76974 L p .562 .923 .752 r
F P
0 g
s
.44806 .76974 m .41336 .79927 L p .43867 .78038 L .562 .923 .752 r
F P
0 g
s
.39848 .80691 m .41336 .79927 L .37043 .8162 L p .323 .81 .818 r
F P
0 g
s
.41336 .79927 m .39848 .80691 L .43867 .78038 L p .562 .923 .752 r
F P
0 g
s
.43867 .78038 m .39848 .80691 L p .4289 .79146 L 0 0 0 r
F P
0 g
s
.42983 .79099 m .43867 .78038 L p .4289 .79146 L 0 0 0 r
F P
0 g
s
.44888 .76904 m .43867 .78038 L .46727 .74336 L p .708 .92 .579 r
F P
0 g
s
.46727 .74336 m .46804 .74237 L p .46711 .74366 L .708 .92 .579 r
F P
0 g
s
.44888 .76904 m .46727 .74336 L .46711 .74366 L .708 .92 .579 r
F
.73483 .84735 m .71025 .88791 L .76344 .91349 L p .546 .497 .753 r
F P
0 g
s
.71025 .88791 m .73483 .84735 L .67504 .83506 L p .637 .584 .778 r
F P
0 g
s
.71678 1.11559 m .76481 1.0727 L .73262 1.03532 L p .519 .362 .609 r
F P
0 g
s
.77386 .99126 m .73262 1.03532 L .76481 1.0727 L p .437 .308 .606 r
F P
0 g
s
.45852 .59508 m .46736 .60438 L .43777 .5671 L p 0 .067 .617 r
F P
0 g
s
.37043 .8162 m .35185 .81901 L .39848 .80691 L p .323 .81 .818 r
F P
0 g
s
.42374 .93458 m .45788 .92684 L .4317 .90424 L p .828 .926 .899 r
F P
0 g
s
.45573 .89626 m .4317 .90424 L .45788 .92684 L p .838 .882 .874 r
F P
0 g
s
.3616 .98246 m .32314 .97982 L .32059 1.03733 L p .83 .795 .819 r
F P
0 g
s
.63078 .80205 m .61182 .83094 L .67504 .83506 L p .689 .637 .793 r
F P
0 g
s
.61182 .83094 m .63078 .80205 L .56973 .81337 L p .762 .697 .79 r
F P
0 g
s
.56973 .81337 m .55113 .83535 L .61182 .83094 L p .762 .697 .79 r
F P
0 g
s
.27208 .53694 m .25981 .5538 L .30358 .53443 L p .535 .918 .927 r
F P
0 g
s
.30358 .53443 m .31887 .52281 L .27208 .53694 L p .535 .918 .927 r
F P
0 g
s
.31887 .52281 m .30358 .53443 L .35122 .53016 L p .37 .791 .974 r
F P
0 g
s
.35122 .53016 m .3678 .52467 L .31887 .52281 L p .37 .791 .974 r
F P
0 g
s
.3678 .52467 m .35122 .53016 L .39761 .54144 L p .202 .615 .949 r
F P
0 g
s
.4781 .63675 m .48316 .6493 L .46736 .60438 L p 0 0 .365 r
F P
0 g
s
.48316 .6493 m .4781 .63675 L .48314 .68303 L p 0 0 .049 r
F P
0 g
s
.69262 .79888 m .67504 .83506 L .73483 .84735 L p .605 .569 .787 r
F P
0 g
s
.67504 .83506 m .69262 .79888 L .63078 .80205 L p .689 .637 .793 r
F P
0 g
s
.23251 .56563 m .22461 .5862 L .25981 .5538 L p .678 .973 .8 r
F P
0 g
s
.25981 .5538 m .27208 .53694 L .23251 .56563 L p .678 .973 .8 r
F P
0 g
s
.39761 .54144 m .41363 .54223 L .3678 .52467 L p .202 .615 .949 r
F P
0 g
s
.41363 .54223 m .39761 .54144 L .43777 .5671 L p .052 .409 .86 r
F P
0 g
s
.20453 .60585 m .20179 .62818 L .22461 .5862 L p .775 .94 .592 r
F P
0 g
s
.22461 .5862 m .23251 .56563 L .20453 .60585 L p .775 .94 .592 r
F P
0 g
s
.43777 .5671 m .45148 .57355 L .41363 .54223 L p .052 .409 .86 r
F P
0 g
s
.45148 .57355 m .43777 .5671 L .46736 .60438 L p 0 .197 .723 r
F P
0 g
s
.32314 .97982 m .3616 .98246 L .36271 .93912 L p .812 .906 .906 r
F P
0 g
s
.39158 .93857 m .36271 .93912 L .3616 .98246 L p .82 .867 .881 r
F P
0 g
s
.19128 .65325 m .19384 .67522 L .20179 .62818 L p .804 .805 .316 r
F P
0 g
s
.20179 .62818 m .20453 .60585 L .19128 .65325 L p .804 .805 .316 r
F P
0 g
s
.46736 .60438 m .47735 .61526 L .45148 .57355 L p 0 .197 .723 r
F P
0 g
s
.47735 .61526 m .46736 .60438 L .48316 .6493 L p 0 0 .545 r
F P
0 g
s
.68673 1.18964 m .73867 1.14936 L .71678 1.11559 L p .478 .261 .505 r
F P
0 g
s
.76481 1.0727 m .71678 1.11559 L .73867 1.14936 L p .372 .177 .482 r
F P
0 g
s
.19429 .70265 m .20166 .72226 L .19384 .67522 L p .753 .579 .005 r
F P
0 g
s
.19384 .67522 m .19128 .65325 L .19429 .70265 L p .753 .579 .005 r
F P
0 g
s
.39158 .93857 m .42374 .93458 L .40969 .90953 L p .793 .961 .918 r
F P
0 g
s
.4317 .90424 m .40969 .90953 L .42374 .93458 L p .828 .926 .899 r
F P
0 g
s
.48316 .6493 m .4885 .66293 L .47735 .61526 L p 0 0 .545 r
F P
0 g
s
.4885 .66293 m .48316 .6493 L .48341 .69702 L p 0 0 .308 r
F P
0 g
s
.64356 .77112 m .63078 .80205 L .69262 .79888 L p .665 .621 .796 r
F P
0 g
s
.63078 .80205 m .64356 .77112 L .58445 .78927 L p .74 .672 .784 r
F P
0 g
s
.58445 .78927 m .56973 .81337 L .63078 .80205 L p .74 .672 .784 r
F P
0 g
s
.52684 1.30718 m .59016 1.28169 L .56114 1.25234 L p .582 .267 .401 r
F P
0 g
s
.56114 1.25234 m .49155 1.27397 L .52684 1.30718 L p .582 .267 .401 r
F P
0 g
s
.62689 1.22413 m .56114 1.25234 L .59016 1.28169 L p .506 .199 .381 r
F P
0 g
s
.50568 .87159 m .52948 .85485 L .48139 .86206 L p .883 .864 .816 r
F P
0 g
s
.52948 .85485 m .55113 .83535 L .49881 .84799 L p .863 .809 .795 r
F P
0 g
s
.49881 .84799 m .48139 .86206 L .52948 .85485 L p .863 .809 .795 r
F P
0 g
s
.46084 1.32658 m .52684 1.30718 L .49155 1.27397 L p .645 .321 .409 r
F P
0 g
s
.49155 1.27397 m .42026 1.28886 L .46084 1.32658 L p .645 .321 .409 r
F P
0 g
s
.55113 .83535 m .56973 .81337 L .51524 .8318 L p .839 .762 .778 r
F P
0 g
s
.51524 .8318 m .49881 .84799 L .55113 .83535 L p .839 .762 .778 r
F P
0 g
s
.21326 .74859 m .22447 .76418 L .20166 .72226 L p 0 0 .297 r
F P
0 g
s
.20166 .72226 m .19429 .70265 L .21326 .74859 L p 0 0 .297 r
F P
0 g
s
.48341 .69702 m .48372 .7115 L .4885 .66293 L p 0 0 .308 r
F P
0 g
s
.48372 .7115 m .48341 .69702 L .46804 .74237 L p 0 0 0 r
F P
0 g
s
.48075 .8854 m .50568 .87159 L .46383 .87395 L p .89 .923 .838 r
F P
0 g
s
.48139 .86206 m .46383 .87395 L .50568 .87159 L p .883 .864 .816 r
F P
0 g
s
.56973 .81337 m .58445 .78927 L .52993 .81363 L p .812 .721 .764 r
F P
0 g
s
.52993 .81363 m .51524 .8318 L .56973 .81337 L p .812 .721 .764 r
F P
0 g
s
.2461 .78599 m .25982 .7964 L .22447 .76418 L p 0 .016 .547 r
F P
0 g
s
.22447 .76418 m .21326 .74859 L .2461 .78599 L p 0 .016 .547 r
F P
0 g
s
.46705 .58222 m .45148 .57355 L .47735 .61526 L p .159 .29 .75 r
F P
0 g
s
.47735 .61526 m .48789 .62784 L .46705 .58222 L p .159 .29 .75 r
F P
0 g
s
.48789 .62784 m .47735 .61526 L .4885 .66293 L p .147 .157 .613 r
F P
0 g
s
.46804 .74237 m .46347 .75578 L .48372 .7115 L p 0 0 0 r
F P
0 g
s
.46347 .75578 m .46804 .74237 L .43867 .78038 L p 0 0 0 r
F P
0 g
s
.43331 .54557 m .41363 .54223 L .45148 .57355 L p .189 .436 .866 r
F P
0 g
s
.45148 .57355 m .46705 .58222 L .43331 .54557 L p .189 .436 .866 r
F P
0 g
s
.77386 .99126 m .80393 .94294 L .76344 .91349 L p .491 .41 .692 r
F P
0 g
s
.7854 .86675 m .76344 .91349 L .80393 .94294 L p .411 .369 .702 r
F P
0 g
s
.76344 .91349 m .7854 .86675 L .73483 .84735 L p .546 .497 .753 r
F P
0 g
s
.74937 .80424 m .73483 .84735 L .7854 .86675 L p .493 .477 .768 r
F P
0 g
s
.73483 .84735 m .74937 .80424 L .69262 .79888 L p .605 .569 .787 r
F P
0 g
s
.59016 1.28169 m .64881 1.25033 L .62689 1.22413 L p .506 .199 .381 r
F P
0 g
s
.68673 1.18964 m .62689 1.22413 L .64881 1.25033 L p .404 .108 .345 r
F P
0 g
s
.4885 .66293 m .49369 .67764 L .48789 .62784 L p .147 .157 .613 r
F P
0 g
s
.49369 .67764 m .4885 .66293 L .48372 .7115 L p .114 .005 .44 r
F P
0 g
s
.28917 .81073 m .30388 .81538 L .25982 .7964 L p 0 .304 .717 r
F P
0 g
s
.25982 .7964 m .2461 .78599 L .28917 .81073 L p 0 .304 .717 r
F P
0 g
s
.43867 .78038 m .42983 .79099 L .46347 .75578 L p 0 0 0 r
F P
0 g
s
.39014 .52182 m .3678 .52467 L .41363 .54223 L p .244 .593 .949 r
F P
0 g
s
.41363 .54223 m .43331 .54557 L .39014 .52182 L p .244 .593 .949 r
F P
0 g
s
.70166 .76091 m .69262 .79888 L .74937 .80424 L p .571 .557 .8 r
F P
0 g
s
.69262 .79888 m .70166 .76091 L .64356 .77112 L p .665 .621 .796 r
F P
0 g
s
.3377 .82015 m .35185 .81901 L .30388 .81538 L p 0 .542 .793 r
F P
0 g
s
.30388 .81538 m .28917 .81073 L .3377 .82015 L p 0 .542 .793 r
F P
0 g
s
.39848 .80691 m .38635 .81329 L .42983 .79099 L p 0 0 0 r
F P
0 g
s
.38635 .81329 m .39848 .80691 L .35185 .81901 L p .167 .705 .762 r
F P
0 g
s
.45573 .89626 m .48075 .8854 L .44695 .88371 L p .867 .977 .851 r
F P
0 g
s
.46383 .87395 m .44695 .88371 L .48075 .8854 L p .89 .923 .838 r
F P
0 g
s
.35185 .81901 m .3377 .82015 L .38635 .81329 L p .167 .705 .762 r
F P
0 g
s
.76481 1.0727 m .80213 1.02497 L .77386 .99126 L p .437 .308 .606 r
F P
0 g
s
.80393 .94294 m .77386 .99126 L .80213 1.02497 L p .324 .234 .597 r
F P
0 g
s
.59466 .76356 m .58445 .78927 L .64356 .77112 L p .717 .649 .781 r
F P
0 g
s
.58445 .78927 m .59466 .76356 L .54218 .79373 L p .785 .685 .754 r
F P
0 g
s
.54218 .79373 m .52993 .81363 L .58445 .78927 L p .785 .685 .754 r
F P
0 g
s
.48372 .7115 m .48384 .72643 L .49369 .67764 L p .114 .005 .44 r
F P
0 g
s
.48384 .72643 m .48372 .7115 L .46347 .75578 L p .044 0 .193 r
F P
0 g
s
.64956 .73891 m .64356 .77112 L .70166 .76091 L p .639 .608 .802 r
F P
0 g
s
.64356 .77112 m .64956 .73891 L .59466 .76356 L p .717 .649 .781 r
F P
0 g
s
.34203 .51364 m .31887 .52281 L .3678 .52467 L p .318 .743 .973 r
F P
0 g
s
.3678 .52467 m .39014 .52182 L .34203 .51364 L p .318 .743 .973 r
F P
0 g
s
.48366 .59328 m .46705 .58222 L .48789 .62784 L p .31 .353 .745 r
F P
0 g
s
.48789 .62784 m .49831 .64212 L .48366 .59328 L p .31 .353 .745 r
F P
0 g
s
.49831 .64212 m .48789 .62784 L .49369 .67764 L p .323 .262 .633 r
F P
0 g
s
.49369 .67764 m .49826 .69336 L .49831 .64212 L p .323 .262 .633 r
F P
0 g
s
.49826 .69336 m .49369 .67764 L .48384 .72643 L p .316 .156 .499 r
F P
0 g
s
.36271 .93912 m .39158 .93857 L .3907 .91245 L p .72 .975 .924 r
F P
0 g
s
.40969 .90953 m .3907 .91245 L .39158 .93857 L p .793 .961 .918 r
F P
0 g
s
.46347 .75578 m .4593 .76907 L .48384 .72643 L p .044 0 .193 r
F P
0 g
s
.4593 .76907 m .46347 .75578 L .42983 .79099 L p 0 0 0 r
F P
0 g
s
.45574 .55189 m .43331 .54557 L .46705 .58222 L p .301 .457 .849 r
F P
0 g
s
.46705 .58222 m .48366 .59328 L .45574 .55189 L p .301 .457 .849 r
F P
0 g
s
.59986 .73679 m .59466 .76356 L .64956 .73891 L p .693 .629 .781 r
F P
0 g
s
.59466 .76356 m .59986 .73679 L .5514 .77243 L p .758 .654 .747 r
F P
0 g
s
.5514 .77243 m .54218 .79373 L .59466 .76356 L p .758 .654 .747 r
F P
0 g
s
.48384 .72643 m .48353 .74175 L .49826 .69336 L p .316 .156 .499 r
F P
0 g
s
.48353 .74175 m .48384 .72643 L .4593 .76907 L p .276 .002 .305 r
F P
0 g
s
.36271 .93912 m .33838 .93667 L .32314 .97982 L p .812 .906 .906 r
F P
0 g
s
.4317 .90424 m .43747 .90233 L p .43159 .89149 L .784 .998 .835 r
F P
0 g
s
.44055 .89326 m .43159 .89149 L p .43747 .90233 L .784 .998 .835 r
F P
0 g
s
.44695 .88371 m .43159 .89149 L .45573 .89626 L p .867 .977 .851 r
F P
0 g
s
.43159 .89149 m .41853 .89753 L .4317 .90424 L p .784 .998 .835 r
F P
0 g
s
.43159 .89149 m .4453 .88455 L p .43413 .89208 L 0 0 0 r
F P
0 g
s
.43294 .89288 m .43249 .89242 L .43413 .89208 L 0 0 0 r
F
.43249 .89242 m .43159 .89149 L .43413 .89208 L F
.43439 .90246 m .43123 .91112 L .4367 .89154 L p F P
0 g
s
.44499 .885 m .43294 .89288 L p .4453 .88455 L 0 0 0 r
F P
0 g
s
.43294 .89288 m .42933 .89524 L p .43011 .89396 L 0 0 0 r
F P
0 g
s
.43011 .89396 m .43159 .89149 L .43294 .89288 L 0 0 0 r
F
.43784 .88744 m .42933 .89524 L .4429 .88636 L p .771 .957 .641 r
F P
0 g
s
.4367 .89154 m .43784 .88744 L p .43691 .89149 L 0 0 0 r
F P
0 g
s
.43439 .90246 m .4367 .89154 L .43691 .89149 L 0 0 0 r
F
.4453 .88455 m .44695 .88371 L .44499 .885 L p F P
0 g
s
.4429 .88636 m .44695 .88371 L p .4433 .88521 L .771 .957 .641 r
F P
0 g
s
.43784 .88744 m .4429 .88636 L .4433 .88521 L .771 .957 .641 r
F
.44695 .88371 m .46359 .87409 L p .44559 .88342 L F P
0 g
s
.46341 .87417 m .44559 .88342 L p .46359 .87409 L .771 .957 .641 r
F P
0 g
s
.44531 .88439 m .44695 .88371 L .44559 .88342 L .771 .957 .641 r
F
.44559 .88342 m .43973 .88646 L p .44531 .88439 L F P
0 g
s
.43973 .88646 m .43784 .88744 L p .43871 .88708 L .771 .957 .641 r
F P
0 g
s
.43871 .88708 m .44531 .88439 L .43973 .88646 L .771 .957 .641 r
F
.44834 .87837 m .43784 .88744 L .46383 .87395 L p .919 .978 .734 r
F P
0 g
s
.43784 .88744 m .44834 .87837 L .43911 .89432 L p 0 0 0 r
F P
0 g
s
.43911 .89432 m .43784 .8965 L p .43784 .8881 L 0 0 0 r
F P
0 g
s
.43784 .8881 m .43784 .88744 L .43911 .89432 L 0 0 0 r
F
.43747 .90233 m .45573 .89626 L .44055 .89326 L p .784 .998 .835 r
F P
0 g
s
.44081 .91058 m .44041 .92139 L .43985 .89798 L p 0 0 .111 r
F P
0 g
s
.43494 .90008 m .43784 .88744 L .43784 .8965 L 0 0 0 r
F
.43974 .89312 m .43439 .90246 L .44213 .88909 L p .645 .804 .365 r
F P
0 g
s
.43985 .89798 m .43974 .89312 L p .44012 .89928 L 0 0 .111 r
F P
0 g
s
.44081 .91058 m .43985 .89798 L .44012 .89928 L 0 0 .111 r
F
.44213 .88909 m .44577 .88281 L p .44184 .88951 L .645 .804 .365 r
F P
0 g
s
.44184 .88951 m .44577 .88281 L .44579 .88274 L .645 .804 .365 r
F
.44184 .88951 m .44579 .88274 L .44302 .88906 L F
.44577 .88281 m .44834 .87837 L p .44579 .88274 L F P
0 g
s
.44579 .88274 m .44834 .87837 L .44633 .88241 L .645 .804 .365 r
F
.44579 .88274 m .44633 .88241 L .44302 .88906 L F
.43784 .8965 m .43439 .90246 L p .43494 .90008 L 0 0 0 r
F P
0 g
s
.46383 .87395 m .48139 .86206 L .45875 .87323 L p .919 .978 .734 r
F P
0 g
s
.48139 .86206 m .48228 .86135 L p .4602 .86784 L .947 .919 .752 r
F P
0 g
s
.48228 .86135 m .49881 .84799 L .47288 .86132 L p .947 .919 .752 r
F P
0 g
s
.47288 .86132 m .4602 .86784 L p .48228 .86135 L .947 .919 .752 r
F P
0 g
s
.47273 .8557 m .4602 .86784 L .49881 .84799 L p .927 .847 .743 r
F P
0 g
s
.4602 .86784 m .44834 .87837 L .48139 .86206 L p .947 .919 .752 r
F P
0 g
s
.4602 .86784 m .47273 .8557 L .45952 .86953 L p .938 .931 .574 r
F P
0 g
s
.45875 .87323 m .45057 .87727 L p .4634 .87408 L .919 .978 .734 r
F P
0 g
s
.44977 .87796 m .4634 .87408 L .45057 .87727 L .919 .978 .734 r
F
.45057 .87727 m .44834 .87837 L p .44977 .87796 L F P
0 g
s
.44834 .87837 m .44866 .87809 L p .44302 .88906 L .645 .804 .365 r
F P
0 g
s
.44678 .88442 m .44302 .88906 L p .44866 .87809 L .645 .804 .365 r
F P
0 g
s
.44866 .87809 m .4602 .86784 L .44678 .88442 L p .645 .804 .365 r
F P
0 g
s
.43974 .89312 m .44213 .88909 L .44184 .88951 L .645 .804 .365 r
F
.44302 .88906 m .43974 .89312 L p .44184 .88951 L F P
0 g
s
.44679 .88286 m .43974 .89312 L .45044 .87989 L p .938 .931 .574 r
F P
0 g
s
.43974 .89312 m .44679 .88286 L .44081 .91058 L p 0 0 .111 r
F P
0 g
s
.4429 .89944 m .44081 .91058 L .44415 .8951 L p .814 .722 .191 r
F P
0 g
s
.4429 .89944 m .44415 .8951 L .44406 .89469 L .814 .722 .191 r
F
.4429 .89944 m .44561 .88835 L .4451 .89007 L F
.44415 .8951 m .44561 .88835 L p .44406 .89469 L F P
0 g
s
.44561 .88835 m .44679 .88286 L p .4451 .89007 L .814 .722 .191 r
F P
0 g
s
.4488 .88062 m .45044 .87989 L .4562 .87277 L .938 .931 .574 r
F
.4562 .87277 m .4602 .86784 L p .45585 .87271 L F P
0 g
s
.4488 .88062 m .4562 .87277 L .45585 .87271 L .938 .931 .574 r
F
.44679 .88286 m .45044 .87989 L .4488 .88062 L F
.44837 .88121 m .45585 .87271 L .4577 .87111 L F
.45952 .86953 m .45588 .87335 L p .4577 .87111 L F P
0 g
s
.45588 .87335 m .44837 .88121 L p .4577 .87111 L .938 .931 .574 r
F P
0 g
s
.45236 .87768 m .4429 .89944 L p .44679 .88286 L .814 .722 .191 r
F P
0 g
s
.44632 .88779 m .4429 .89944 L .45236 .87768 L p .992 .787 .407 r
F P
0 g
s
.44815 .88134 m .45585 .87271 L .44837 .88121 L .938 .931 .574 r
F
.44837 .88121 m .44679 .88286 L p .44815 .88134 L F P
0 g
s
.45585 .87271 m .4602 .86784 L .45952 .86953 L .938 .931 .574 r
F
.45504 .87153 m .44679 .88286 L .46738 .8613 L p .985 .878 .641 r
F P
0 g
s
.44679 .88286 m .45504 .87153 L .45236 .87768 L p .814 .722 .191 r
F P
0 g
s
.45236 .87768 m .45504 .87153 L p .45053 .87993 L .992 .787 .407 r
F P
0 g
s
.44632 .88779 m .45236 .87768 L .45053 .87993 L .992 .787 .407 r
F
.45504 .87153 m .46738 .8613 L .46647 .8613 L .985 .878 .641 r
F
.47273 .8557 m .47387 .85445 L p .45504 .87153 L F P
0 g
s
.47387 .85445 m .48525 .84194 L .46582 .86097 L p .985 .878 .641 r
F P
0 g
s
.46582 .86097 m .45504 .87153 L p .47387 .85445 L .985 .878 .641 r
F P
0 g
s
.46392 .85903 m .45504 .87153 L .48525 .84194 L p .951 .796 .653 r
F P
0 g
s
.45504 .87153 m .46392 .85903 L .45147 .87938 L p .992 .787 .407 r
F P
0 g
s
.45147 .87938 m .44632 .88779 L p .45053 .87993 L .992 .787 .407 r
F P
0 g
s
.45053 .87993 m .45504 .87153 L .45147 .87938 L .992 .787 .407 r
F
.45073 .87552 m .44632 .88779 L .45969 .86593 L p .977 .731 .496 r
F P
0 g
s
.45969 .86593 m .46392 .85903 L p .456 .86892 L .977 .731 .496 r
F P
0 g
s
.45073 .87552 m .45969 .86593 L .456 .86892 L .977 .731 .496 r
F
.4429 .89944 m .44632 .88779 L .44672 .90649 L p 0 0 .243 r
F P
0 g
s
.44672 .90649 m .44678 .90972 L p .44643 .90878 L 0 0 .243 r
F P
0 g
s
.44643 .90878 m .4429 .89944 L .44672 .90649 L 0 0 .243 r
F
.44392 .89706 m .44678 .90972 L .44632 .88779 L p .881 .511 .033 r
F P
0 g
s
.44632 .88779 m .45073 .87552 L .44392 .89706 L p .881 .511 .033 r
F P
0 g
s
.44221 .88452 m .44392 .89706 L .45044 .87644 L p .926 .539 .22 r
F P
0 g
s
.45044 .87644 m .45073 .87552 L p .45052 .87573 L .926 .539 .22 r
F P
0 g
s
.44221 .88452 m .45044 .87644 L .45052 .87573 L .926 .539 .22 r
F
.44392 .89706 m .44297 .89008 L p .44282 .8936 L 0 0 .491 r
F P
0 g
s
.44297 .89008 m .44221 .88452 L .44243 .88778 L p 0 0 .491 r
F P
0 g
s
.44243 .88778 m .44282 .8936 L p .44297 .89008 L 0 0 .491 r
F P
0 g
s
.46738 .8613 m .47273 .8557 L p .46647 .8613 L .985 .878 .641 r
F P
0 g
s
.4634 .87408 m .46383 .87395 L .45875 .87323 L .919 .978 .734 r
F
.46359 .87409 m .46383 .87395 L .46341 .87417 L p .771 .957 .641 r
F P
0 g
s
.29413 .52208 m .27208 .53694 L .31887 .52281 L p .393 .848 .898 r
F P
0 g
s
.31887 .52281 m .34203 .51364 L .29413 .52208 L p .393 .848 .898 r
F P
0 g
s
.5004 .6068 m .48366 .59328 L .49831 .64212 L p .416 .398 .732 r
F P
0 g
s
.49831 .64212 m .50796 .65802 L .5004 .6068 L p .416 .398 .732 r
F P
0 g
s
.50796 .65802 m .49831 .64212 L .49826 .69336 L p .439 .333 .638 r
F P
0 g
s
.49826 .69336 m .50182 .70995 L .50796 .65802 L p .439 .333 .638 r
F P
0 g
s
.50182 .70995 m .49826 .69336 L .48353 .74175 L p .445 .254 .527 r
F P
0 g
s
.64881 1.25033 m .70088 1.21347 L .68673 1.18964 L p .404 .108 .345 r
F P
0 g
s
.73867 1.14936 m .68673 1.18964 L .70088 1.21347 L p .257 0 .281 r
F P
0 g
s
.73867 1.14936 m .7809 1.104 L .76481 1.0727 L p .372 .177 .482 r
F P
0 g
s
.80213 1.02497 m .76481 1.0727 L .7809 1.104 L p .215 .054 .436 r
F P
0 g
s
.42983 .79099 m .42256 .80102 L .4593 .76907 L p 0 0 0 r
F P
0 g
s
.42256 .80102 m .42983 .79099 L .38635 .81329 L p 0 0 0 r
F P
0 g
s
.51524 .8318 m .52993 .81363 L .48525 .84194 L p .894 .782 .73 r
F P
0 g
s
.52993 .81363 m .54218 .79373 L .4971 .82659 L p .858 .728 .718 r
F P
0 g
s
.4971 .82659 m .48525 .84194 L .52993 .81363 L p .858 .728 .718 r
F P
0 g
s
.54218 .79373 m .5514 .77243 L .50767 .80979 L p .823 .682 .708 r
F P
0 g
s
.50767 .80979 m .4971 .82659 L .54218 .79373 L p .823 .682 .708 r
F P
0 g
s
.41731 .52235 m .39014 .52182 L .43331 .54557 L p .299 .578 .938 r
F P
0 g
s
.43331 .54557 m .45574 .55189 L .41731 .52235 L p .299 .578 .938 r
F P
0 g
s
.5164 .62269 m .5004 .6068 L .50796 .65802 L p .493 .434 .72 r
F P
0 g
s
.50796 .65802 m .51624 .67535 L .5164 .62269 L p .493 .434 .72 r
F P
0 g
s
.51624 .67535 m .50796 .65802 L .50182 .70995 L p .521 .386 .638 r
F P
0 g
s
.55717 .75013 m .5514 .77243 L .59986 .73679 L p .73 .627 .744 r
F P
0 g
s
.5514 .77243 m .55717 .75013 L .51642 .79174 L p .788 .643 .701 r
F P
0 g
s
.51642 .79174 m .50767 .80979 L .5514 .77243 L p .788 .643 .701 r
F P
0 g
s
.49881 .84799 m .51524 .8318 L .47273 .8557 L p .927 .847 .743 r
F P
0 g
s
.48525 .84194 m .47273 .8557 L .51524 .8318 L p .894 .782 .73 r
F P
0 g
s
.50182 .70995 m .50401 .72721 L .51624 .67535 L p .521 .386 .638 r
F P
0 g
s
.50401 .72721 m .50182 .70995 L .48259 .75736 L p .535 .325 .541 r
F P
0 g
s
.48353 .74175 m .48259 .75736 L .50182 .70995 L p .445 .254 .527 r
F P
0 g
s
.64956 .73891 m .64848 .70624 L .59986 .73679 L p .693 .629 .781 r
F P
0 g
s
.59981 .7096 m .59986 .73679 L .64848 .70624 L p .667 .612 .783 r
F P
0 g
s
.59986 .73679 m .59981 .7096 L .55717 .75013 L p .73 .627 .744 r
F P
0 g
s
.47982 .56149 m .45574 .55189 L .48366 .59328 L p .39 .474 .826 r
F P
0 g
s
.48366 .59328 m .5004 .6068 L .47982 .56149 L p .39 .474 .826 r
F P
0 g
s
.25165 .54643 m .23251 .56563 L .27208 .53694 L p .443 .856 .692 r
F P
0 g
s
.27208 .53694 m .29413 .52208 L .25165 .54643 L p .443 .856 .692 r
F P
0 g
s
.48259 .75736 m .48353 .74175 L .45553 .78227 L p .424 .133 .364 r
F P
0 g
s
.4593 .76907 m .45553 .78227 L .48353 .74175 L p .276 .002 .305 r
F P
0 g
s
.70166 .76091 m .70169 .72217 L .64956 .73891 L p .639 .608 .802 r
F P
0 g
s
.64848 .70624 m .64956 .73891 L .70169 .72217 L p .612 .597 .811 r
F P
0 g
s
.45553 .78227 m .4593 .76907 L .42256 .80102 L p .215 0 .019 r
F P
0 g
s
.5592 .7273 m .55717 .75013 L .59981 .7096 L p .701 .602 .743 r
F P
0 g
s
.55717 .75013 m .5592 .7273 L .52294 .77271 L p .754 .608 .697 r
F P
0 g
s
.52294 .77271 m .51642 .79174 L .55717 .75013 L p .754 .608 .697 r
F P
0 g
s
.53079 .64075 m .5164 .62269 L .51624 .67535 L p .553 .465 .71 r
F P
0 g
s
.51624 .67535 m .52262 .69386 L .53079 .64075 L p .553 .465 .71 r
F P
0 g
s
.52262 .69386 m .51624 .67535 L .50401 .72721 L p .585 .43 .637 r
F P
0 g
s
.74937 .80424 m .75317 .75974 L .70166 .76091 L p .571 .557 .8 r
F P
0 g
s
.70169 .72217 m .70166 .76091 L .75317 .75974 L p .532 .547 .816 r
F P
0 g
s
.38635 .81329 m .3774 .81873 L .42256 .80102 L p 0 0 0 r
F P
0 g
s
.3774 .81873 m .38635 .81329 L .3377 .82015 L p .043 .612 .727 r
F P
0 g
s
.50401 .72721 m .50457 .7449 L .52262 .69386 L p .585 .43 .637 r
F P
0 g
s
.50457 .7449 m .50401 .72721 L .4809 .77312 L p .605 .38 .549 r
F P
0 g
s
.48259 .75736 m .4809 .77312 L .50401 .72721 L p .535 .325 .541 r
F P
0 g
s
.54281 .66068 m .53079 .64075 L .52262 .69386 L p .603 .494 .702 r
F P
0 g
s
.52262 .69386 m .52669 .71322 L .54281 .66068 L p .603 .494 .702 r
F P
0 g
s
.52669 .71322 m .52262 .69386 L .50457 .7449 L p .638 .468 .636 r
F P
0 g
s
.59981 .7096 m .59446 .68268 L .5592 .7273 L p .701 .602 .743 r
F P
0 g
s
.55739 .70444 m .5592 .7273 L .59446 .68268 L p .671 .58 .745 r
F P
0 g
s
.5592 .7273 m .55739 .70444 L .52691 .75304 L p .719 .577 .695 r
F P
0 g
s
.52691 .75304 m .52294 .77271 L .5592 .7273 L p .719 .577 .695 r
F P
0 g
s
.55183 .68206 m .54281 .66068 L .52669 .71322 L p .645 .521 .697 r
F P
0 g
s
.52669 .71322 m .52816 .73308 L .55183 .68206 L p .645 .521 .697 r
F P
0 g
s
.52816 .73308 m .52669 .71322 L .50334 .76277 L p .684 .504 .636 r
F P
0 g
s
.50457 .7449 m .50334 .76277 L .52669 .71322 L p .638 .468 .636 r
F P
0 g
s
.41457 .90836 m .4317 .90424 L .42334 .89998 L p .609 .943 .76 r
F P
0 g
s
.42933 .89524 m .42339 .90206 L .42975 .89386 L p 0 0 0 r
F P
0 g
s
.42975 .89386 m .43159 .89149 L p .43072 .89294 L 0 0 0 r
F P
0 g
s
.42933 .89524 m .42975 .89386 L .43072 .89294 L 0 0 0 r
F
.40969 .90953 m .41457 .90836 L p .41853 .89753 L .609 .943 .76 r
F P
0 g
s
.42334 .89998 m .41853 .89753 L p .41457 .90836 L .609 .943 .76 r
F P
0 g
s
.50438 .57446 m .47982 .56149 L .5004 .6068 L p .459 .49 .803 r
F P
0 g
s
.5004 .6068 m .5164 .62269 L .50438 .57446 L p .459 .49 .803 r
F P
0 g
s
.7854 .86675 m .79539 .81778 L .74937 .80424 L p .493 .477 .768 r
F P
0 g
s
.75317 .75974 m .74937 .80424 L .79539 .81778 L p .427 .455 .787 r
F P
0 g
s
.55739 .70444 m .55183 .68206 L .52816 .73308 L p .684 .549 .695 r
F P
0 g
s
.52816 .73308 m .52691 .75304 L .55739 .70444 L p .684 .549 .695 r
F P
0 g
s
.52691 .75304 m .52816 .73308 L .50029 .78052 L p .727 .54 .637 r
F P
0 g
s
.50334 .76277 m .50029 .78052 L .52816 .73308 L p .684 .504 .636 r
F P
0 g
s
.21936 .5842 m .20453 .60585 L .23251 .56563 L p 0 0 0 r
F P
0 g
s
.23251 .56563 m .25165 .54643 L .21936 .5842 L p 0 0 0 r
F P
0 g
s
.52294 .77271 m .52691 .75304 L .49547 .79789 L p .769 .577 .639 r
F P
0 g
s
.50029 .78052 m .49547 .79789 L .52691 .75304 L p .727 .54 .637 r
F P
0 g
s
.59446 .68268 m .58405 .6567 L .55739 .70444 L p .671 .58 .745 r
F P
0 g
s
.55183 .68206 m .55739 .70444 L .58405 .6567 L p .638 .56 .75 r
F P
0 g
s
.64848 .70624 m .64031 .674 L .59981 .7096 L p .667 .612 .783 r
F P
0 g
s
.59446 .68268 m .59981 .7096 L .64031 .674 L p .641 .596 .789 r
F P
0 g
s
.4809 .77312 m .48259 .75736 L .45212 .79539 L p .527 .224 .397 r
F P
0 g
s
.45553 .78227 m .45212 .79539 L .48259 .75736 L p .424 .133 .364 r
F P
0 g
s
.50334 .76277 m .50457 .7449 L .47836 .78889 L p .663 .427 .553 r
F P
0 g
s
.4809 .77312 m .47836 .78889 L .50457 .7449 L p .605 .38 .549 r
F P
0 g
s
.51642 .79174 m .52294 .77271 L .48909 .81462 L p .811 .619 .642 r
F P
0 g
s
.49547 .79789 m .48909 .81462 L .52294 .77271 L p .769 .577 .639 r
F P
0 g
s
.3723 .50795 m .34203 .51364 L .39014 .52182 L p .293 .701 .974 r
F P
0 g
s
.39014 .52182 m .41731 .52235 L .3723 .50795 L p .293 .701 .974 r
F P
0 g
s
.80393 .94294 m .8215 .89154 L .7854 .86675 L p .411 .369 .702 r
F P
0 g
s
.79539 .81778 m .7854 .86675 L .8215 .89154 L p .301 .317 .71 r
F P
0 g
s
.5282 .59077 m .50438 .57446 L .5164 .62269 L p .516 .506 .784 r
F P
0 g
s
.5164 .62269 m .53079 .64075 L .5282 .59077 L p .516 .506 .784 r
F P
0 g
s
.50767 .80979 m .51642 .79174 L .48143 .83049 L p .855 .667 .647 r
F P
0 g
s
.48909 .81462 m .48143 .83049 L .51642 .79174 L p .811 .619 .642 r
F P
0 g
s
.58405 .6567 m .56903 .63234 L .55183 .68206 L p .638 .56 .75 r
F P
0 g
s
.54281 .66068 m .55183 .68206 L .56903 .63234 L p .603 .541 .758 r
F P
0 g
s
.32861 .82013 m .3377 .82015 L .28917 .81073 L p 0 .523 .836 r
F P
0 g
s
.3377 .82015 m .32861 .82013 L .3774 .81873 L p .043 .612 .727 r
F P
0 g
s
.33838 .93667 m .36271 .93912 L .37563 .91339 L p .599 .949 .902 r
F P
0 g
s
.3907 .91245 m .37563 .91339 L .36271 .93912 L p .72 .975 .924 r
F P
0 g
s
.44814 .52682 m .41731 .52235 L .45574 .55189 L p .357 .567 .917 r
F P
0 g
s
.45574 .55189 m .47982 .56149 L .44814 .52682 L p .357 .567 .917 r
F P
0 g
s
.56903 .63234 m .55011 .61019 L .54281 .66068 L p .603 .541 .758 r
F P
0 g
s
.53079 .64075 m .54281 .66068 L .55011 .61019 L p .562 .523 .769 r
F P
0 g
s
.55011 .61019 m .5282 .59077 L .53079 .64075 L p .562 .523 .769 r
F P
0 g
s
.50029 .78052 m .50334 .76277 L .47499 .8045 L p .714 .471 .555 r
F P
0 g
s
.47836 .78889 m .47499 .8045 L .50334 .76277 L p .663 .427 .553 r
F P
0 g
s
.42256 .80102 m .41703 .81062 L .45553 .78227 L p .215 0 .019 r
F P
0 g
s
.41703 .81062 m .42256 .80102 L .3774 .81873 L p .134 0 0 r
F P
0 g
s
.45212 .79539 m .45553 .78227 L .41703 .81062 L p .378 0 .107 r
F P
0 g
s
.4971 .82659 m .50767 .80979 L .47289 .84533 L p .903 .724 .651 r
F P
0 g
s
.48143 .83049 m .47289 .84533 L .50767 .80979 L p .855 .667 .647 r
F P
0 g
s
.20095 .63129 m .19128 .65325 L .20453 .60585 L p 0 0 0 r
F P
0 g
s
.20453 .60585 m .21936 .5842 L .20095 .63129 L p 0 0 0 r
F P
0 g
s
.70169 .72217 m .6926 .68377 L .64848 .70624 L p .612 .597 .811 r
F P
0 g
s
.64031 .674 m .64848 .70624 L .6926 .68377 L p .583 .588 .823 r
F P
0 g
s
.47836 .78889 m .4809 .77312 L .4491 .80841 L p .605 .293 .414 r
F P
0 g
s
.45212 .79539 m .4491 .80841 L .4809 .77312 L p .527 .224 .397 r
F P
0 g
s
.80213 1.02497 m .8272 .97344 L .80393 .94294 L p .324 .234 .597 r
F P
0 g
s
.8215 .89154 m .80393 .94294 L .8272 .97344 L p .153 .126 .572 r
F P
0 g
s
.64031 .674 m .62535 .6431 L .59446 .68268 L p .641 .596 .789 r
F P
0 g
s
.58405 .6567 m .59446 .68268 L .62535 .6431 L p .612 .583 .798 r
F P
0 g
s
.37196 .8236 m .3774 .81873 L .32861 .82013 L p 0 .544 .724 r
F P
0 g
s
.28917 .81073 m .28361 .80646 L p .32861 .82013 L 0 .523 .836 r
F P
0 g
s
.29772 .81011 m .32861 .82013 L p .28361 .80646 L 0 .523 .836 r
F P
0 g
s
.28361 .80646 m .2815 .80484 L .29772 .81011 L p 0 .523 .836 r
F P
0 g
s
.32506 .81952 m .32861 .82013 L .2815 .80484 L p .037 .521 .882 r
F P
0 g
s
.32861 .82013 m .32506 .81952 L .37196 .8236 L p 0 .544 .724 r
F P
0 g
s
.37028 .82827 m .37196 .8236 L .33883 .82072 L p 0 .504 .753 r
F P
0 g
s
.33883 .82072 m .32506 .81952 L p .36152 .82658 L 0 .504 .753 r
F P
0 g
s
.36152 .82658 m .37028 .82827 L .33883 .82072 L 0 .504 .753 r
F
.2815 .80484 m .28917 .81073 L .2461 .78599 L p 0 .358 .813 r
F P
0 g
s
.70088 1.21347 m .74463 1.17166 L .73867 1.14936 L p .257 0 .281 r
F P
0 g
s
.7809 1.104 m .73867 1.14936 L .74463 1.17166 L p .027 0 .163 r
F P
0 g
s
.49547 .79789 m .50029 .78052 L .47085 .8198 L p .764 .513 .555 r
F P
0 g
s
.47499 .8045 m .47085 .8198 L .50029 .78052 L p .714 .471 .555 r
F P
0 g
s
.48525 .84194 m .4971 .82659 L .46392 .85903 L p .951 .796 .653 r
F P
0 g
s
.47289 .84533 m .46392 .85903 L .4971 .82659 L p .903 .724 .651 r
F P
0 g
s
.19858 .68249 m .19429 .70265 L .19128 .65325 L p 0 0 .271 r
F P
0 g
s
.19128 .65325 m .20095 .63129 L .19858 .68249 L p 0 0 .271 r
F P
0 g
s
.2461 .78599 m .2413 .77439 L .2815 .80484 L p 0 .358 .813 r
F P
0 g
s
.2413 .77439 m .2461 .78599 L .21326 .74859 L p 0 .157 .698 r
F P
0 g
s
.50056 1.34402 m .55735 1.32069 L .52684 1.30718 L p .483 .071 .182 r
F P
0 g
s
.52684 1.30718 m .46084 1.32658 L .50056 1.34402 L p .483 .071 .182 r
F P
0 g
s
.59016 1.28169 m .52684 1.30718 L .55735 1.32069 L p .374 0 .132 r
F P
0 g
s
.21256 .73204 m .21326 .74859 L .19429 .70265 L p 0 0 .515 r
F P
0 g
s
.19429 .70265 m .19858 .68249 L .21256 .73204 L p 0 0 .515 r
F P
0 g
s
.48119 .53564 m .44814 .52682 L .47982 .56149 L p .412 .56 .892 r
F P
0 g
s
.47982 .56149 m .50438 .57446 L .48119 .53564 L p .412 .56 .892 r
F P
0 g
s
.48909 .81462 m .49547 .79789 L .4661 .83465 L p .813 .558 .552 r
F P
0 g
s
.47085 .8198 m .4661 .83465 L .49547 .79789 L p .764 .513 .555 r
F P
0 g
s
.32542 .51053 m .29413 .52208 L .34203 .51364 L p .26 .765 .869 r
F P
0 g
s
.34203 .51364 m .3723 .50795 L .32542 .51053 L p .26 .765 .869 r
F P
0 g
s
.21326 .74859 m .21256 .73204 L .2413 .77439 L p 0 .157 .698 r
F P
0 g
s
.3907 .91245 m .40969 .90953 L .40847 .90216 L p .357 .793 .62 r
F P
0 g
s
.41853 .89753 m .40847 .90216 L .40969 .90953 L p .609 .943 .76 r
F P
0 g
s
.55735 1.32069 m .61067 1.29223 L .59016 1.28169 L p .374 0 .132 r
F P
0 g
s
.64881 1.25033 m .59016 1.28169 L .61067 1.29223 L p .219 0 .043 r
F P
0 g
s
.62535 .6431 m .60425 .61442 L .58405 .6567 L p .612 .583 .798 r
F P
0 g
s
.56903 .63234 m .58405 .6567 L .60425 .61442 L p .58 .573 .81 r
F P
0 g
s
.47499 .8045 m .47836 .78889 L .44649 .82134 L p .67 .348 .42 r
F P
0 g
s
.4491 .80841 m .44649 .82134 L .47836 .78889 L p .605 .293 .414 r
F P
0 g
s
.4491 .80841 m .45212 .79539 L .41338 .81999 L p .493 .064 .153 r
F P
0 g
s
.41703 .81062 m .41338 .81999 L .45212 .79539 L p .378 0 .107 r
F P
0 g
s
.75317 .75974 m .74591 .71514 L .70169 .72217 L p .532 .547 .816 r
F P
0 g
s
.6926 .68377 m .70169 .72217 L .74591 .71514 L p .488 .54 .836 r
F P
0 g
s
.3774 .81873 m .37196 .8236 L .41703 .81062 L p .134 0 0 r
F P
0 g
s
.7809 1.104 m .81181 1.05445 L .80213 1.02497 L p .215 .054 .436 r
F P
0 g
s
.8272 .97344 m .80213 1.02497 L .81181 1.05445 L p 0 0 .341 r
F P
0 g
s
.48143 .83049 m .48909 .81462 L .46097 .84894 L p .866 .607 .545 r
F P
0 g
s
.4661 .83465 m .46097 .84894 L .48909 .81462 L p .813 .558 .552 r
F P
0 g
s
.40847 .50666 m .3723 .50795 L .41731 .52235 L p .295 .666 .973 r
F P
0 g
s
.41731 .52235 m .44814 .52682 L .40847 .50666 L p .295 .666 .973 r
F P
0 g
s
.51492 .54898 m .48119 .53564 L .50438 .57446 L p .462 .558 .867 r
F P
0 g
s
.50438 .57446 m .5282 .59077 L .51492 .54898 L p .462 .558 .867 r
F P
0 g
s
.60425 .61442 m .57796 .58876 L .56903 .63234 L p .58 .573 .81 r
F P
0 g
s
.55011 .61019 m .56903 .63234 L .57796 .58876 L p .545 .565 .825 r
F P
0 g
s
.6926 .68377 m .67471 .64685 L .64031 .674 L p .583 .588 .823 r
F P
0 g
s
.62535 .6431 m .64031 .674 L .67471 .64685 L p .552 .583 .839 r
F P
0 g
s
.41338 .81999 m .41703 .81062 L .37196 .8236 L p .275 0 0 r
F P
0 g
s
.5477 .56678 m .51492 .54898 L .5282 .59077 L p .506 .56 .845 r
F P
0 g
s
.5282 .59077 m .55011 .61019 L .5477 .56678 L p .506 .56 .845 r
F P
0 g
s
.57796 .58876 m .5477 .56678 L .55011 .61019 L p .545 .565 .825 r
F P
0 g
s
.47085 .8198 m .47499 .8045 L .44433 .83416 L p .728 .395 .416 r
F P
0 g
s
.44649 .82134 m .44433 .83416 L .47499 .8045 L p .67 .348 .42 r
F P
0 g
s
.61067 1.29223 m .65879 1.2589 L .64881 1.25033 L p .219 0 .043 r
F P
0 g
s
.70088 1.21347 m .64881 1.25033 L .65879 1.2589 L p 0 0 0 r
F P
0 g
s
.79539 .81778 m .79279 .76799 L .75317 .75974 L p .427 .455 .787 r
F P
0 g
s
.74591 .71514 m .75317 .75974 L .79279 .76799 L p .343 .432 .809 r
F P
0 g
s
.47289 .84533 m .48143 .83049 L .45573 .86257 L p .922 .665 .53 r
F P
0 g
s
.46097 .84894 m .45573 .86257 L .48143 .83049 L p .866 .607 .545 r
F P
0 g
s
.28179 .53011 m .25165 .54643 L .29413 .52208 L p 0 0 0 r
F P
0 g
s
.29413 .52208 m .32542 .51053 L .28179 .53011 L p 0 0 0 r
F P
0 g
s
.37563 .91339 m .36525 .91288 L .33838 .93667 L p .599 .949 .902 r
F P
0 g
s
.44649 .82134 m .4491 .80841 L .4117 .82928 L p .579 .14 .17 r
F P
0 g
s
.41338 .81999 m .4117 .82928 L .4491 .80841 L p .493 .064 .153 r
F P
0 g
s
.4661 .83465 m .47085 .8198 L .44272 .84687 L p .783 .438 .402 r
F P
0 g
s
.44433 .83416 m .44272 .84687 L .47085 .8198 L p .728 .395 .416 r
F P
0 g
s
.37563 .91339 m .3907 .91245 L .40201 .90578 L p 0 0 0 r
F P
0 g
s
.40847 .90216 m .40201 .90578 L .3907 .91245 L p .357 .793 .62 r
F P
0 g
s
.67471 .64685 m .64874 .61256 L .62535 .6431 L p .552 .583 .839 r
F P
0 g
s
.60425 .61442 m .62535 .6431 L .64874 .61256 L p .517 .58 .858 r
F P
0 g
s
.46392 .85903 m .47289 .84533 L .45073 .87552 L p .977 .731 .496 r
F P
0 g
s
.45573 .86257 m .45073 .87552 L .47289 .84533 L p .922 .665 .53 r
F P
0 g
s
.8215 .89154 m .82566 .83843 L .79539 .81778 L p .301 .317 .71 r
F P
0 g
s
.79279 .76799 m .79539 .81778 L .82566 .83843 L p .141 .243 .709 r
F P
0 g
s
.44899 .51048 m .40847 .50666 L .44814 .52682 L p .318 .638 .965 r
F P
0 g
s
.44814 .52682 m .48119 .53564 L .44899 .51048 L p .318 .638 .965 r
F P
0 g
s
.41853 .89753 m .43159 .89149 L .42339 .90206 L p 0 0 0 r
F P
0 g
s
.74463 1.17166 m .77845 1.12564 L .7809 1.104 L p .027 0 .163 r
F P
0 g
s
.81181 1.05445 m .7809 1.104 L .77845 1.12564 L p 0 0 0 r
F P
0 g
s
.74591 .71514 m .72776 .67182 L .6926 .68377 L p .488 .54 .836 r
F P
0 g
s
.67471 .64685 m .6926 .68377 L .72776 .67182 L p .436 .536 .86 r
F P
0 g
s
.4117 .82928 m .41338 .81999 L .37028 .82827 L p .372 0 0 r
F P
0 g
s
.37196 .8236 m .37028 .82827 L .41338 .81999 L p .275 0 0 r
F P
0 g
s
.36488 .5035 m .32542 .51053 L .3723 .50795 L p .156 .688 .854 r
F P
0 g
s
.3723 .50795 m .40847 .50666 L .36488 .5035 L p .156 .688 .854 r
F P
0 g
s
.24633 .5648 m .21936 .5842 L .25165 .54643 L p 0 0 0 r
F P
0 g
s
.25165 .54643 m .28179 .53011 L .24633 .5648 L p 0 0 0 r
F P
0 g
s
.65879 1.2589 m .70012 1.22112 L .70088 1.21347 L p 0 0 0 r
F P
0 g
s
.74463 1.17166 m .70088 1.21347 L .70012 1.22112 L p 0 0 0 r
F P
0 g
s
.44433 .83416 m .44649 .82134 L .41205 .83869 L p .648 .195 .162 r
F P
0 g
s
.4117 .82928 m .41205 .83869 L .44649 .82134 L p .579 .14 .17 r
F P
0 g
s
.46097 .84894 m .4661 .83465 L .44174 .85948 L p .838 .479 .374 r
F P
0 g
s
.44272 .84687 m .44174 .85948 L .4661 .83465 L p .783 .438 .402 r
F P
0 g
s
.8272 .97344 m .83885 .91939 L .8215 .89154 L p .153 .126 .572 r
F P
0 g
s
.82566 .83843 m .8215 .89154 L .83885 .91939 L p 0 0 .501 r
F P
0 g
s
.2815 .80484 m .28145 .79853 L .32506 .81952 L p .037 .521 .882 r
F P
0 g
s
.28145 .79853 m .2815 .80484 L .2413 .77439 L p .072 .406 .859 r
F P
0 g
s
.64874 .61256 m .61583 .58194 L .60425 .61442 L p .517 .58 .858 r
F P
0 g
s
.57796 .58876 m .60425 .61442 L .61583 .58194 L p .479 .582 .88 r
F P
0 g
s
.49203 .51988 m .44899 .51048 L .48119 .53564 L p .354 .616 .949 r
F P
0 g
s
.48119 .53564 m .51492 .54898 L .49203 .51988 L p .354 .616 .949 r
F P
0 g
s
.22318 .61089 m .20095 .63129 L .21936 .5842 L p 0 0 .186 r
F P
0 g
s
.21936 .5842 m .24633 .5648 L .22318 .61089 L p 0 0 .186 r
F P
0 g
s
.61583 .58194 m .5775 .55587 L .57796 .58876 L p .479 .582 .88 r
F P
0 g
s
.5477 .56678 m .57796 .58876 L .5775 .55587 L p .439 .588 .904 r
F P
0 g
s
.45573 .86257 m .46097 .84894 L .44153 .87202 L p .891 .516 .321 r
F P
0 g
s
.44174 .85948 m .44153 .87202 L .46097 .84894 L p .838 .479 .374 r
F P
0 g
s
.53556 .53505 m .49203 .51988 L .51492 .54898 L p .396 .599 .928 r
F P
0 g
s
.51492 .54898 m .5477 .56678 L .53556 .53505 L p .396 .599 .928 r
F P
0 g
s
.40847 .90216 m .41853 .89753 L .42047 .90825 L p .152 0 0 r
F P
0 g
s
.42339 .90206 m .42047 .90825 L .41853 .89753 L p 0 0 0 r
F P
0 g
s
.2413 .77439 m .24607 .76267 L .28145 .79853 L p .072 .406 .859 r
F P
0 g
s
.24607 .76267 m .2413 .77439 L .21256 .73204 L p .079 .267 .754 r
F P
0 g
s
.79279 .76799 m .77751 .71887 L .74591 .71514 L p .343 .432 .809 r
F P
0 g
s
.72776 .67182 m .74591 .71514 L .77751 .71887 L p .231 .403 .828 r
F P
0 g
s
.5775 .55587 m .53556 .53505 L .5477 .56678 L p .439 .588 .904 r
F P
0 g
s
.81181 1.05445 m .83007 1.00182 L .8272 .97344 L p 0 0 .341 r
F P
0 g
s
.83885 .91939 m .8272 .97344 L .83007 1.00182 L p 0 0 .144 r
F P
0 g
s
.44272 .84687 m .44433 .83416 L .41442 .8484 L p .705 .233 .127 r
F P
0 g
s
.41205 .83869 m .41442 .8484 L .44433 .83416 L p .648 .195 .162 r
F P
0 g
s
.40201 .90578 m .39957 .90887 L .37563 .91339 L p 0 0 0 r
F P
0 g
s
.36525 .91288 m .37563 .91339 L .39957 .90887 L p .113 0 0 r
F P
0 g
s
.72776 .67182 m .69939 .63115 L .67471 .64685 L p .436 .536 .86 r
F P
0 g
s
.64874 .61256 m .67471 .64685 L .69939 .63115 L p .376 .535 .886 r
F P
0 g
s
.41205 .83869 m .4117 .82928 L .37248 .83315 L p .431 0 0 r
F P
0 g
s
.37028 .82827 m .37248 .83315 L .4117 .82928 L p .372 0 0 r
F P
0 g
s
.21509 .66322 m .19858 .68249 L .20095 .63129 L p .039 0 .428 r
F P
0 g
s
.20095 .63129 m .22318 .61089 L .21509 .66322 L p .039 0 .428 r
F P
0 g
s
.21256 .73204 m .22304 .71582 L .24607 .76267 L p .079 .267 .754 r
F P
0 g
s
.22304 .71582 m .21256 .73204 L .19858 .68249 L p .067 .121 .61 r
F P
0 g
s
.32209 .51812 m .28179 .53011 L .32542 .51053 L p .048 0 0 r
F P
0 g
s
.32542 .51053 m .36488 .5035 L .32209 .51812 L p .048 0 0 r
F P
0 g
s
.42933 .89524 m .43784 .88744 L .43123 .91112 L p .239 0 .099 r
F P
0 g
s
.41096 .50205 m .36488 .5035 L .40847 .50666 L p .093 .628 .861 r
F P
0 g
s
.40847 .50666 m .44899 .51048 L .41096 .50205 L p .093 .628 .861 r
F P
0 g
s
.19858 .68249 m .21509 .66322 L .22304 .71582 L p .067 .121 .61 r
F P
0 g
s
.32506 .81952 m .32736 .81897 L .36401 .82691 L p 0 .504 .753 r
F P
0 g
s
.32506 .81952 m .36401 .82691 L .36614 .82747 L 0 .504 .753 r
F
.36401 .82691 m .37028 .82827 L p .36614 .82747 L F P
0 g
s
.37248 .83315 m .37028 .82827 L .32736 .81897 L p 0 .49 .805 r
F P
0 g
s
.32736 .81897 m .33563 .81911 L .36695 .83104 L p 0 .49 .805 r
F P
0 g
s
.36695 .83104 m .37248 .83315 L p .36823 .83182 L 0 .49 .805 r
F P
0 g
s
.32736 .81897 m .36695 .83104 L .36823 .83182 L 0 .49 .805 r
F
.37858 .83865 m .37248 .83315 L .33869 .82028 L p 0 .493 .86 r
F P
0 g
s
.33752 .81997 m .37858 .83865 L .33869 .82028 L 0 .493 .86 r
F
.33869 .82028 m .33563 .81911 L p .33752 .81997 L F P
0 g
s
.33563 .81911 m .34975 .82063 L .37858 .83865 L p 0 .493 .86 r
F P
0 g
s
.38843 .84517 m .37858 .83865 L .35227 .8222 L p .082 .503 .9 r
F P
0 g
s
.35227 .8222 m .34975 .82063 L p .35155 .82177 L .082 .503 .9 r
F P
0 g
s
.35155 .82177 m .38843 .84517 L .35227 .8222 L .082 .503 .9 r
F
.32736 .81897 m .32506 .81952 L .28145 .79853 L p .117 .525 .913 r
F P
0 g
s
.45073 .87552 m .45573 .86257 L .44221 .88452 L p .926 .539 .22 r
F P
0 g
s
.44153 .87202 m .44221 .88452 L .45573 .86257 L p .891 .516 .321 r
F P
0 g
s
.70012 1.22112 m .7332 1.17949 L .74463 1.17166 L p 0 0 0 r
F P
0 g
s
.77845 1.12564 m .74463 1.17166 L .7332 1.17949 L p .681 .907 .567 r
F P
0 g
s
.53515 1.33835 m .57955 1.31206 L .55735 1.32069 L p .009 0 0 r
F P
0 g
s
.55735 1.32069 m .50056 1.34402 L .53515 1.33835 L p .009 0 0 r
F P
0 g
s
.61067 1.29223 m .55735 1.32069 L .57955 1.31206 L p 0 0 0 r
F P
0 g
s
.44174 .85948 m .44272 .84687 L .41879 .85857 L p .747 .252 .056 r
F P
0 g
s
.41442 .8484 m .41879 .85857 L .44272 .84687 L p .705 .233 .127 r
F P
0 g
s
.82566 .83843 m .81598 .78517 L .79279 .76799 L p .141 .243 .709 r
F P
0 g
s
.77751 .71887 m .79279 .76799 L .81598 .78517 L p 0 .131 .672 r
F P
0 g
s
.77845 1.12564 m .80101 1.07634 L .81181 1.05445 L p 0 0 0 r
F P
0 g
s
.83007 1.00182 m .81181 1.05445 L .80101 1.07634 L p .741 .808 .333 r
F P
0 g
s
.57955 1.31206 m .61998 1.28181 L .61067 1.29223 L p 0 0 0 r
F P
0 g
s
.65879 1.2589 m .61067 1.29223 L .61998 1.28181 L p .503 .883 .69 r
F P
0 g
s
.40201 .90578 m .40847 .90216 L .42092 .9142 L p .332 0 .052 r
F P
0 g
s
.42047 .90825 m .42092 .9142 L .40847 .90216 L p .152 0 0 r
F P
0 g
s
.69939 .63115 m .662 .59447 L .64874 .61256 L p .376 .535 .886 r
F P
0 g
s
.61583 .58194 m .64874 .61256 L .662 .59447 L p .307 .537 .91 r
F P
0 g
s
.41442 .8484 m .41205 .83869 L .37858 .83865 L p .45 0 0 r
F P
0 g
s
.37248 .83315 m .37858 .83865 L .41205 .83869 L p .431 0 0 r
F P
0 g
s
.42339 .90206 m .42933 .89524 L .43063 .91939 L p .523 .075 .128 r
F P
0 g
s
.43123 .91112 m .43063 .91939 L .42933 .89524 L p .239 0 .099 r
F P
0 g
s
.46166 .50697 m .41096 .50205 L .44899 .51048 L p .076 .589 .884 r
F P
0 g
s
.44899 .51048 m .49203 .51988 L .46166 .50697 L p .076 .589 .884 r
F P
0 g
s
.28492 .54927 m .24633 .5648 L .28179 .53011 L p .186 0 .016 r
F P
0 g
s
.28179 .53011 m .32209 .51812 L .28492 .54927 L p .186 0 .016 r
F P
0 g
s
.77751 .71887 m .75 .67203 L .72776 .67182 L p .231 .403 .828 r
F P
0 g
s
.69939 .63115 m .72776 .67182 L .75 .67203 L p .083 .365 .832 r
F P
0 g
s
.39957 .90887 m .40144 .91194 L .36525 .91288 L p .113 0 0 r
F P
0 g
s
.83885 .91939 m .83634 .86431 L .82566 .83843 L p 0 0 .501 r
F P
0 g
s
.81598 .78517 m .82566 .83843 L .83634 .86431 L p 0 0 .322 r
F P
0 g
s
.28145 .79853 m .28939 .79267 L .32736 .81897 L p .117 .525 .913 r
F P
0 g
s
.28939 .79267 m .28145 .79853 L .24607 .76267 L p .214 .44 .863 r
F P
0 g
s
.44153 .87202 m .44174 .85948 L .42507 .8694 L p .758 .242 0 r
F P
0 g
s
.41879 .85857 m .42507 .8694 L .44174 .85948 L p .747 .252 .056 r
F P
0 g
s
.43439 .90246 m .43974 .89312 L .44041 .92139 L p .101 0 .296 r
F P
0 g
s
.61998 1.28181 m .6551 1.24793 L .65879 1.2589 L p .503 .883 .69 r
F P
0 g
s
.70012 1.22112 m .65879 1.2589 L .6551 1.24793 L p .719 .986 .809 r
F P
0 g
s
.662 .59447 m .61729 .56294 L .61583 .58194 L p .307 .537 .91 r
F P
0 g
s
.5775 .55587 m .61583 .58194 L .61729 .56294 L p .232 .543 .927 r
F P
0 g
s
.51463 .51874 m .46166 .50697 L .49203 .51988 L p .101 .565 .911 r
F P
0 g
s
.49203 .51988 m .53556 .53505 L .51463 .51874 L p .101 .565 .911 r
F P
0 g
s
.37112 .5118 m .32209 .51812 L .36488 .5035 L p .217 0 0 r
F P
0 g
s
.36488 .5035 m .41096 .50205 L .37112 .5118 L p .217 0 0 r
F P
0 g
s
.61729 .56294 m .56736 .53749 L .5775 .55587 L p .232 .543 .927 r
F P
0 g
s
.53556 .53505 m .5775 .55587 L .56736 .53749 L p .158 .552 .928 r
F P
0 g
s
.7332 1.17949 m .75679 1.13474 L .77845 1.12564 L p .681 .907 .567 r
F P
0 g
s
.80101 1.07634 m .77845 1.12564 L .75679 1.13474 L p .887 .984 .712 r
F P
0 g
s
.39957 .90887 m .40201 .90578 L .4249 .92035 L p .458 .013 .103 r
F P
0 g
s
.42092 .9142 m .4249 .92035 L .40201 .90578 L p .332 0 .052 r
F P
0 g
s
.83007 1.00182 m .83474 .94744 L .83885 .91939 L p 0 0 .144 r
F P
0 g
s
.83634 .86431 m .83885 .91939 L .83474 .94744 L p .836 .687 .149 r
F P
0 g
s
.33563 .81911 m .32736 .81897 L .28939 .79267 L p .208 .53 .922 r
F P
0 g
s
.56736 .53749 m .51463 .51874 L .53556 .53505 L p .158 .552 .928 r
F P
0 g
s
.42047 .90825 m .42339 .90206 L .43288 .92759 L p .709 .196 0 r
F P
0 g
s
.43063 .91939 m .43288 .92759 L .42339 .90206 L p .523 .075 .128 r
F P
0 g
s
.41879 .85857 m .41442 .8484 L .38843 .84517 L p .413 0 0 r
F P
0 g
s
.37858 .83865 m .38843 .84517 L .41442 .8484 L p .45 0 0 r
F P
0 g
s
.25775 .59369 m .22318 .61089 L .24633 .5648 L p .247 0 .306 r
F P
0 g
s
.24633 .5648 m .28492 .54927 L .25775 .59369 L p .247 0 .306 r
F P
0 g
s
.44221 .88452 m .44153 .87202 L .43314 .88102 L p .695 .183 0 r
F P
0 g
s
.42507 .8694 m .43314 .88102 L .44153 .87202 L p .758 .242 0 r
F P
0 g
s
.24607 .76267 m .26075 .75196 L .28939 .79267 L p .214 .44 .863 r
F P
0 g
s
.26075 .75196 m .24607 .76267 L .22304 .71582 L p .257 .342 .76 r
F P
0 g
s
.43123 .91112 m .43439 .90246 L .44196 .93206 L p .381 .101 .358 r
F P
0 g
s
.44041 .92139 m .44196 .93206 L .43439 .90246 L p .101 0 .296 r
F P
0 g
s
.6551 1.24793 m .68371 1.21086 L .70012 1.22112 L p .719 .986 .809 r
F P
0 g
s
.7332 1.17949 m .70012 1.22112 L .68371 1.21086 L p .838 .992 .854 r
F P
0 g
s
.81598 .78517 m .79261 .73342 L .77751 .71887 L p 0 .131 .672 r
F P
0 g
s
.75 .67203 m .77751 .71887 L .79261 .73342 L p 0 0 .547 r
F P
0 g
s
.75 .67203 m .71137 .62901 L .69939 .63115 L p .083 .365 .832 r
F P
0 g
s
.662 .59447 m .69939 .63115 L .71137 .62901 L p 0 .312 .796 r
F P
0 g
s
.44081 .91058 m .4429 .89944 L .4509 .92261 L p 0 0 .465 r
F P
0 g
s
.44678 .90972 m .4509 .92261 L .4429 .89944 L p 0 0 .243 r
F P
0 g
s
.24385 .6464 m .21509 .66322 L .22318 .61089 L p .27 .128 .497 r
F P
0 g
s
.22318 .61089 m .25775 .59369 L .24385 .6464 L p .27 .128 .497 r
F P
0 g
s
.22304 .71582 m .24491 .70128 L .26075 .75196 L p .257 .342 .76 r
F P
0 g
s
.24491 .70128 m .22304 .71582 L .21509 .66322 L p .272 .241 .64 r
F P
0 g
s
.80101 1.07634 m .81128 1.02487 L .83007 1.00182 L p .741 .808 .333 r
F P
0 g
s
.83474 .94744 m .83007 1.00182 L .81128 1.02487 L p .961 .906 .538 r
F P
0 g
s
.21509 .66322 m .24385 .6464 L .24491 .70128 L p .272 .241 .64 r
F P
0 g
s
.43314 .88102 m .44282 .8936 L .44221 .88452 L p .695 .183 0 r
F P
0 g
s
.42687 .51225 m .37112 .5118 L .41096 .50205 L p .332 0 0 r
F P
0 g
s
.41096 .50205 m .46166 .50697 L .42687 .51225 L p .332 0 0 r
F P
0 g
s
.42507 .8694 m .41879 .85857 L .40177 .85307 L p 0 .233 .665 r
F P
0 g
s
.38843 .84517 m .40177 .85307 L .41879 .85857 L p .413 0 0 r
F P
0 g
s
.40144 .91194 m .39957 .90887 L .42283 .92182 L p .55 .091 .117 r
F P
0 g
s
.43001 .92331 m .43811 .93611 L p .42769 .92283 L .162 .115 .553 r
F P
0 g
s
.42769 .92283 m .42092 .9142 L .43001 .92331 L .162 .115 .553 r
F
.43288 .92759 m .43473 .9306 L p .42047 .90825 L .709 .196 0 r
F P
0 g
s
.43473 .9306 m .43731 .9348 L p .43449 .93038 L .709 .196 0 r
F P
0 g
s
.43721 .93468 m .43449 .93038 L p .43731 .9348 L .709 .196 0 r
F P
0 g
s
.43449 .93038 m .42047 .90825 L p .43473 .9306 L .709 .196 0 r
F P
0 g
s
.42822 .92315 m .42092 .9142 L p .42818 .92345 L .162 .115 .553 r
F P
0 g
s
.43566 .93299 m .42822 .92315 L .42818 .92345 L .162 .115 .553 r
F
.43594 .93326 m .42822 .92315 L .43566 .93299 L F
.43288 .92759 m .43063 .91939 L .45163 .95401 L p .739 .232 0 r
F P
0 g
s
.43811 .93611 m .43731 .9348 L p .45983 .96585 L .242 .231 .646 r
F P
0 g
s
.43731 .9348 m .43473 .9306 L p .4435 .94268 L .242 .231 .646 r
F P
0 g
s
.43485 .93039 m .4435 .94268 L p .43473 .9306 L .242 .231 .646 r
F P
0 g
s
.43867 .93594 m .42822 .92315 L p .43594 .93326 L .162 .115 .553 r
F P
0 g
s
.43311 .92913 m .43456 .9309 L p .43003 .92632 L .443 .244 .513 r
F P
0 g
s
.4435 .94268 m .45983 .96585 L p .43731 .9348 L .242 .231 .646 r
F P
0 g
s
.45163 .95401 m .45983 .96585 L .4435 .94268 L p .739 .232 0 r
F P
0 g
s
.4435 .94268 m .43288 .92759 L p .44411 .94343 L .739 .232 0 r
F P
0 g
s
.45163 .95401 m .4435 .94268 L .44411 .94343 L .739 .232 0 r
F
.42822 .92315 m .43311 .92913 L p .4281 .92407 L .443 .244 .513 r
F P
0 g
s
.4281 .92407 m .4249 .92035 L .42822 .92315 L .443 .244 .513 r
F
.44567 .94284 m .45163 .95401 L .43063 .91939 L p .599 .233 .32 r
F P
0 g
s
.44555 .94269 m .42657 .92194 L .44472 .94188 L .565 .315 .496 r
F
.42657 .92194 m .42616 .92149 L .42658 .92195 L F
.42657 .92194 m .42658 .92195 L .44472 .94188 L F
.43811 .93611 m .44632 .94531 L .43867 .93594 L p .162 .115 .553 r
F P
0 g
s
.43731 .9348 m .43811 .93611 L .43721 .93468 L p .709 .196 0 r
F P
0 g
s
.43811 .93611 m .43867 .93594 L .43594 .93326 L .162 .115 .553 r
F
.43456 .9309 m .44632 .94531 L p .43432 .93133 L .443 .244 .513 r
F P
0 g
s
.43432 .93133 m .43003 .92632 L .43456 .9309 L .443 .244 .513 r
F
.43473 .9306 m .43288 .92759 L .43485 .93039 L p .242 .231 .646 r
F P
0 g
s
.42828 .92402 m .43207 .92814 L p .42616 .92149 L .565 .315 .496 r
F P
0 g
s
.43207 .92814 m .44472 .94188 L p .43117 .927 L .565 .315 .496 r
F P
0 g
s
.43117 .927 m .42616 .92149 L .43207 .92814 L .565 .315 .496 r
F
.43063 .91939 m .43123 .91112 L .44567 .94284 L p .599 .233 .32 r
F P
0 g
s
.44196 .93206 m .44567 .94284 L .43123 .91112 L p .381 .101 .358 r
F P
0 g
s
.44567 .94284 m .44196 .93206 L .47118 .96404 L p .421 .298 .607 r
F P
0 g
s
.45163 .95401 m .44567 .94284 L .48044 .97927 L p .512 .359 .61 r
F P
0 g
s
.47118 .96404 m .48044 .97927 L .44567 .94284 L p .421 .298 .607 r
F P
0 g
s
.44472 .94188 m .45732 .95558 L p .44555 .94269 L .565 .315 .496 r
F P
0 g
s
.43243 .92716 m .42616 .92149 L p .44555 .94269 L .565 .315 .496 r
F P
0 g
s
.45732 .95558 m .44906 .94615 L .44555 .94269 L .565 .315 .496 r
F
.44906 .94615 m .43243 .92716 L .44555 .94269 L F
.43811 .93611 m .43594 .93326 L .43566 .93299 L .162 .115 .553 r
F
.42616 .92149 m .4249 .92035 L .42828 .92402 L p .565 .315 .496 r
F P
0 g
s
.43003 .92632 m .4281 .92407 L .43311 .92913 L .443 .244 .513 r
F
.4249 .92035 m .42092 .9142 L .42822 .92315 L p F P
0 g
s
.42283 .92182 m .42801 .9247 L p .42061 .92136 L .55 .091 .117 r
F P
0 g
s
.44632 .94531 m .45732 .95558 L .4249 .92035 L p .443 .244 .513 r
F P
0 g
s
.42801 .9247 m .43243 .92716 L p .42797 .92497 L .55 .091 .117 r
F P
0 g
s
.42797 .92497 m .42061 .92136 L .42801 .9247 L .55 .091 .117 r
F
.42061 .92136 m .40144 .91194 L .42283 .92182 L F
.42092 .9142 m .42047 .90825 L .43001 .92331 L p .162 .115 .553 r
F P
0 g
s
.4249 .92035 m .43243 .92716 L .39957 .90887 L p .458 .013 .103 r
F P
0 g
s
.33392 .53913 m .28492 .54927 L .32209 .51812 L p .365 0 .11 r
F P
0 g
s
.32209 .51812 m .37112 .5118 L .33392 .53913 L p .365 0 .11 r
F P
0 g
s
.83634 .86431 m .8195 .80983 L .81598 .78517 L p 0 0 .322 r
F P
0 g
s
.79261 .73342 m .81598 .78517 L .8195 .80983 L p .832 .484 0 r
F P
0 g
s
.44041 .92139 m .44081 .91058 L .45634 .93586 L p .087 .089 .563 r
F P
0 g
s
.4509 .92261 m .45634 .93586 L .44081 .91058 L p 0 0 .465 r
F P
0 g
s
.28939 .79267 m .30533 .78819 L .33563 .81911 L p .208 .53 .922 r
F P
0 g
s
.30533 .78819 m .28939 .79267 L .26075 .75196 L p .327 .466 .847 r
F P
0 g
s
.71137 .62901 m .66329 .59128 L .662 .59447 L p 0 .312 .796 r
F P
0 g
s
.61729 .56294 m .662 .59447 L .66329 .59128 L p 0 .25 .699 r
F P
0 g
s
.68371 1.21086 m .70478 1.1712 L .7332 1.17949 L p .838 .992 .854 r
F P
0 g
s
.75679 1.13474 m .7332 1.17949 L .70478 1.1712 L p .879 .946 .853 r
F P
0 g
s
.34975 .82063 m .33563 .81911 L .30533 .78819 L p .295 .534 .911 r
F P
0 g
s
.75679 1.13474 m .76993 1.08779 L .80101 1.07634 L p .887 .984 .712 r
F P
0 g
s
.81128 1.02487 m .80101 1.07634 L .76993 1.08779 L p .944 .942 .755 r
F P
0 g
s
.44678 .90972 m .44392 .89706 L .45388 .90727 L p 0 .102 .657 r
F P
0 g
s
.44282 .8936 m .45388 .90727 L .44392 .89706 L p 0 0 .491 r
F P
0 g
s
.57955 1.31206 m .53515 1.33835 L .56049 1.30909 L p .686 .978 .895 r
F P
0 g
s
.56049 1.30909 m .5905 1.2811 L .57955 1.31206 L p .686 .978 .895 r
F P
0 g
s
.61998 1.28181 m .57955 1.31206 L .5905 1.2811 L p .781 .977 .911 r
F P
0 g
s
.48685 .52025 m .42687 .51225 L .46166 .50697 L p .403 0 0 r
F P
0 g
s
.46166 .50697 m .51463 .51874 L .48685 .52025 L p .403 0 0 r
F P
0 g
s
.40177 .85307 m .4182 .8627 L .42507 .8694 L p 0 .233 .665 r
F P
0 g
s
.43314 .88102 m .42507 .8694 L .4182 .8627 L p 0 .304 .78 r
F P
0 g
s
.79261 .73342 m .75636 .68491 L .75 .67203 L p 0 0 .547 r
F P
0 g
s
.71137 .62901 m .75 .67203 L .75636 .68491 L p .657 .169 0 r
F P
0 g
s
.5905 1.2811 m .61644 1.25052 L .61998 1.28181 L p .781 .977 .911 r
F P
0 g
s
.6551 1.24793 m .61998 1.28181 L .61644 1.25052 L p .826 .943 .901 r
F P
0 g
s
.83474 .94744 m .82536 .8928 L .83634 .86431 L p .836 .687 .149 r
F P
0 g
s
.8195 .80983 m .83634 .86431 L .82536 .8928 L p .989 .755 .37 r
F P
0 g
s
.66329 .59128 m .60802 .56004 L .61729 .56294 L p 0 .25 .699 r
F P
0 g
s
.56736 .53749 m .61729 .56294 L .60802 .56004 L p .386 0 0 r
F P
0 g
s
.44196 .93206 m .44041 .92139 L .46311 .94962 L p .29 .215 .597 r
F P
0 g
s
.45634 .93586 m .46311 .94962 L .44041 .92139 L p .087 .089 .563 r
F P
0 g
s
.4433 .93507 m .43243 .92716 L .47078 .96726 L p .646 .368 .484 r
F P
0 g
s
.45732 .95558 m .47078 .96726 L .43243 .92716 L p .565 .315 .496 r
F P
0 g
s
.43243 .92716 m .4433 .93507 L .40144 .91194 L p .55 .091 .117 r
F P
0 g
s
.30375 .58129 m .25775 .59369 L .28492 .54927 L p .409 .126 .369 r
F P
0 g
s
.28492 .54927 m .33392 .53913 L .30375 .58129 L p .409 .126 .369 r
F P
0 g
s
.54823 .5362 m .48685 .52025 L .51463 .51874 L p .426 0 0 r
F P
0 g
s
.51463 .51874 m .56736 .53749 L .54823 .5362 L p .426 0 0 r
F P
0 g
s
.40177 .85307 m .38843 .84517 L .36935 .82414 L p .182 .513 .914 r
F P
0 g
s
.34975 .82063 m .36935 .82414 L .38843 .84517 L p .082 .503 .9 r
F P
0 g
s
.26075 .75196 m .28521 .74346 L .30533 .78819 L p .327 .466 .847 r
F P
0 g
s
.28521 .74346 m .26075 .75196 L .24491 .70128 L p .38 .394 .749 r
F P
0 g
s
.60802 .56004 m .54823 .5362 L .56736 .53749 L p .386 0 0 r
F P
0 g
s
.4509 .92261 m .44678 .90972 L .46608 .92212 L p .064 .228 .722 r
F P
0 g
s
.45388 .90727 m .46608 .92212 L .44678 .90972 L p 0 .102 .657 r
F P
0 g
s
.61644 1.25052 m .63745 1.21767 L .6551 1.24793 L p .826 .943 .901 r
F P
0 g
s
.68371 1.21086 m .6551 1.24793 L .63745 1.21767 L p .839 .896 .879 r
F P
0 g
s
.39147 .53572 m .33392 .53913 L .37112 .5118 L p .49 .064 .158 r
F P
0 g
s
.37112 .5118 m .42687 .51225 L .39147 .53572 L p .49 .064 .158 r
F P
0 g
s
.81128 1.02487 m .80865 .97253 L .83474 .94744 L p .961 .906 .538 r
F P
0 g
s
.82536 .8928 m .83474 .94744 L .80865 .97253 L p .988 .859 .619 r
F P
0 g
s
.44282 .8936 m .43314 .88102 L .4372 .87435 L p .043 .366 .836 r
F P
0 g
s
.4182 .8627 m .4372 .87435 L .43314 .88102 L p 0 .304 .78 r
F P
0 g
s
.70478 1.1712 m .7175 1.12964 L .75679 1.13474 L p .879 .946 .853 r
F P
0 g
s
.76993 1.08779 m .75679 1.13474 L .7175 1.12964 L p .879 .886 .834 r
F P
0 g
s
.28426 .63357 m .24385 .6464 L .25775 .59369 L p .415 .237 .528 r
F P
0 g
s
.25775 .59369 m .30375 .58129 L .28426 .63357 L p .415 .237 .528 r
F P
0 g
s
.46311 .94962 m .47118 .96404 L .44196 .93206 L p .29 .215 .597 r
F P
0 g
s
.24491 .70128 m .27784 .68985 L .28521 .74346 L p .38 .394 .749 r
F P
0 g
s
.27784 .68985 m .24491 .70128 L .24385 .6464 L p .406 .32 .646 r
F P
0 g
s
.8195 .80983 m .78879 .75769 L .79261 .73342 L p .832 .484 0 r
F P
0 g
s
.75636 .68491 m .79261 .73342 L .78879 .75769 L p .928 .543 .18 r
F P
0 g
s
.36935 .82414 m .34975 .82063 L .32897 .78602 L p .372 .539 .891 r
F P
0 g
s
.30533 .78819 m .32897 .78602 L .34975 .82063 L p .295 .534 .911 r
F P
0 g
s
.75636 .68491 m .70874 .64129 L .71137 .62901 L p .657 .169 0 r
F P
0 g
s
.66329 .59128 m .71137 .62901 L .70874 .64129 L p .76 .247 0 r
F P
0 g
s
.45634 .93586 m .4509 .92261 L .47908 .93825 L p .251 .313 .732 r
F P
0 g
s
.46608 .92212 m .47908 .93825 L .4509 .92261 L p .064 .228 .722 r
F P
0 g
s
.32897 .78602 m .30533 .78819 L .28521 .74346 L p .414 .487 .826 r
F P
0 g
s
.24385 .6464 m .28426 .63357 L .27784 .68985 L p .406 .32 .646 r
F P
0 g
s
.63745 1.21767 m .6528 1.183 L .68371 1.21086 L p .839 .896 .879 r
F P
0 g
s
.70478 1.1712 m .68371 1.21086 L .6528 1.183 L p .834 .847 .856 r
F P
0 g
s
.76993 1.08779 m .77197 1.03968 L .81128 1.02487 L p .944 .942 .755 r
F P
0 g
s
.80865 .97253 m .81128 1.02487 L .77197 1.03968 L p .932 .869 .754 r
F P
0 g
s
.4182 .8627 m .40177 .85307 L .39383 .83023 L p .277 .521 .907 r
F P
0 g
s
.36935 .82414 m .39383 .83023 L .40177 .85307 L p .182 .513 .914 r
F P
0 g
s
.45388 .90727 m .44282 .8936 L .45814 .88822 L p .2 .411 .844 r
F P
0 g
s
.4372 .87435 m .45814 .88822 L .44282 .8936 L p .043 .366 .836 r
F P
0 g
s
.45512 .54009 m .39147 .53572 L .42687 .51225 L p .583 .146 .175 r
F P
0 g
s
.42687 .51225 m .48685 .52025 L .45512 .54009 L p .583 .146 .175 r
F P
0 g
s
.45163 .95401 m .4907 .99546 L p .46131 .96728 L .583 .407 .609 r
F P
0 g
s
.45983 .96585 m .45665 .96126 L p .46131 .96728 L .583 .407 .609 r
F P
0 g
s
.45665 .96126 m .45163 .95401 L p .46131 .96728 L .583 .407 .609 r
F P
0 g
s
.48044 .97927 m .4907 .99546 L .45163 .95401 L p .512 .359 .61 r
F P
0 g
s
.47012 .97864 m .45983 .96585 L .5017 1.01274 L p .642 .449 .607 r
F P
0 g
s
.4907 .99546 m .5017 1.01274 L .46199 .96828 L p .583 .407 .609 r
F P
0 g
s
.46199 .96828 m .45983 .96585 L p .46131 .96728 L .583 .407 .609 r
F P
0 g
s
.4907 .99546 m .46199 .96828 L .46131 .96728 L .583 .407 .609 r
F
.44632 .94531 m .43811 .93611 L .45894 .96378 L p .485 .341 .61 r
F P
0 g
s
.45894 .96378 m .4699 .97835 L p .44764 .94716 L .485 .341 .61 r
F P
0 g
s
.44764 .94716 m .44632 .94531 L .45894 .96378 L .485 .341 .61 r
F
.4699 .97835 m .47012 .97864 L p .47004 .97853 L F P
0 g
s
.47004 .97853 m .44632 .94531 L .4699 .97835 L .485 .341 .61 r
F
.45983 .96585 m .47012 .97864 L .43811 .93611 L p .242 .231 .646 r
F P
0 g
s
.46311 .94962 m .45634 .93586 L .49257 .95572 L p .378 .371 .725 r
F P
0 g
s
.47908 .93825 m .49257 .95572 L .45634 .93586 L p .251 .313 .732 r
F P
0 g
s
.82536 .8928 m .80206 .83953 L .8195 .80983 L p .989 .755 .37 r
F P
0 g
s
.78879 .75769 m .8195 .80983 L .80206 .83953 L p .975 .714 .473 r
F P
0 g
s
.35959 .57517 m .30375 .58129 L .33392 .53913 L p .519 .222 .402 r
F P
0 g
s
.33392 .53913 m .39147 .53572 L .35959 .57517 L p .519 .222 .402 r
F P
0 g
s
.70874 .64129 m .65192 .60403 L .66329 .59128 L p .76 .247 0 r
F P
0 g
s
.60802 .56004 m .66329 .59128 L .65192 .60403 L p .76 .263 .04 r
F P
0 g
s
.6528 1.183 m .66196 1.14703 L .70478 1.1712 L p .834 .847 .856 r
F P
0 g
s
.7175 1.12964 m .70478 1.1712 L .66196 1.14703 L p .819 .802 .836 r
F P
0 g
s
.7175 1.12964 m .72133 1.08699 L .76993 1.08779 L p .879 .886 .834 r
F P
0 g
s
.77197 1.03968 m .76993 1.08779 L .72133 1.08699 L p .862 .828 .813 r
F P
0 g
s
.5905 1.2811 m .56049 1.30909 L .57319 1.25855 L p .844 .895 .874 r
F P
0 g
s
.46608 .92212 m .45388 .90727 L .48028 .90447 L p .321 .444 .83 r
F P
0 g
s
.45814 .88822 m .48028 .90447 L .45388 .90727 L p .2 .411 .844 r
F P
0 g
s
.28521 .74346 m .31889 .73832 L .32897 .78602 L p .414 .487 .826 r
F P
0 g
s
.31889 .73832 m .28521 .74346 L .27784 .68985 L p .468 .433 .736 r
F P
0 g
s
.57319 1.25855 m .58835 1.23043 L .5905 1.2811 L p .844 .895 .874 r
F P
0 g
s
.61644 1.25052 m .5905 1.2811 L .58835 1.23043 L p .837 .846 .852 r
F P
0 g
s
.4372 .87435 m .4182 .8627 L .42234 .8394 L p .36 .528 .887 r
F P
0 g
s
.39383 .83023 m .42234 .8394 L .4182 .8627 L p .277 .521 .907 r
F P
0 g
s
.5219 .55289 m .45512 .54009 L .48685 .52025 L p .657 .204 .164 r
F P
0 g
s
.48685 .52025 m .54823 .5362 L .5219 .55289 L p .657 .204 .164 r
F P
0 g
s
.39383 .83023 m .36935 .82414 L .35963 .78702 L p .437 .545 .868 r
F P
0 g
s
.32897 .78602 m .35963 .78702 L .36935 .82414 L p .372 .539 .891 r
F P
0 g
s
.80865 .97253 m .79301 .92073 L .82536 .8928 L p .988 .859 .619 r
F P
0 g
s
.80206 .83953 m .82536 .8928 L .79301 .92073 L p .95 .785 .642 r
F P
0 g
s
.78879 .75769 m .74538 .70962 L .75636 .68491 L p .928 .543 .18 r
F P
0 g
s
.70874 .64129 m .75636 .68491 L .74538 .70962 L p .904 .527 .304 r
F P
0 g
s
.47118 .96404 m .46311 .94962 L .50617 .97454 L p .468 .415 .715 r
F P
0 g
s
.49257 .95572 m .50617 .97454 L .46311 .94962 L p .378 .371 .725 r
F P
0 g
s
.65192 .60403 m .5886 .57431 L .60802 .56004 L p .76 .263 .04 r
F P
0 g
s
.54823 .5362 m .60802 .56004 L .5886 .57431 L p .718 .244 .123 r
F P
0 g
s
.58835 1.23043 m .59985 1.20111 L .61644 1.25052 L p .837 .846 .852 r
F P
0 g
s
.63745 1.21767 m .61644 1.25052 L .59985 1.20111 L p .822 .8 .831 r
F P
0 g
s
.5017 1.01274 m .51312 1.0312 L .47403 .98343 L p .642 .449 .607 r
F P
0 g
s
.47403 .98343 m .47012 .97864 L p .47311 .98188 L .642 .449 .607 r
F P
0 g
s
.5017 1.01274 m .47403 .98343 L .47311 .98188 L .642 .449 .607 r
F
.45732 .95558 m .44632 .94531 L .46973 .97618 L p .59 .4 .592 r
F P
0 g
s
.46973 .97618 m .48223 .99265 L p .45903 .95812 L .59 .4 .592 r
F P
0 g
s
.45903 .95812 m .45732 .95558 L .46973 .97618 L .59 .4 .592 r
F
.47012 .97864 m .48223 .99265 L .44632 .94531 L p .485 .341 .61 r
F P
0 g
s
.5886 .57431 m .5219 .55289 L .54823 .5362 L p .718 .244 .123 r
F P
0 g
s
.48044 .97927 m .47118 .96404 L .51809 .99383 L p .536 .451 .706 r
F P
0 g
s
.51809 .99383 m .51948 .99471 L p .51798 .99412 L .536 .451 .706 r
F P
0 g
s
.51798 .99412 m .48044 .97927 L .51809 .99383 L .536 .451 .706 r
F
.51312 1.0312 m .5017 1.01274 L .54144 1.05087 L p .679 .542 .692 r
F P
0 g
s
.54144 1.05087 m .55373 1.06266 L p .53853 1.05089 L .679 .542 .692 r
F P
0 g
s
.53853 1.05089 m .51312 1.0312 L .54144 1.05087 L .679 .542 .692 r
F
.48223 .99265 m .47012 .97864 L .51312 1.0312 L p .695 .488 .604 r
F P
0 g
s
.51312 1.0312 m .52456 1.05091 L .48223 .99265 L p .695 .488 .604 r
F P
0 g
s
.49575 1.00809 m .48223 .99265 L .52456 1.05091 L p .747 .528 .598 r
F P
0 g
s
.52456 1.05091 m .53558 1.07187 L .49575 1.00809 L p .747 .528 .598 r
F P
0 g
s
.52456 1.05091 m .51312 1.0312 L .56199 1.08741 L p .717 .573 .692 r
F P
0 g
s
.55373 1.06266 m .56199 1.08741 L .51312 1.0312 L p .679 .542 .692 r
F P
0 g
s
.51017 1.02514 m .49575 1.00809 L .53558 1.07187 L p .804 .571 .585 r
F P
0 g
s
.53558 1.07187 m .54571 1.09407 L .5235 1.05099 L p .804 .571 .585 r
F P
0 g
s
.5235 1.05099 m .51017 1.02514 L p .52422 1.05099 L .804 .571 .585 r
F P
0 g
s
.53558 1.07187 m .5235 1.05099 L .52422 1.05099 L .804 .571 .585 r
F
.54365 1.03887 m .55373 1.06266 L .5017 1.01274 L p .638 .513 .694 r
F P
0 g
s
.51017 1.02514 m .52485 1.04391 L .50921 1.01833 L p .719 .489 .575 r
F P
0 g
s
.4907 .99546 m .48044 .97927 L .5321 1.01618 L p .591 .483 .699 r
F P
0 g
s
.51948 .99471 m .5321 1.01618 L .48044 .97927 L p .536 .451 .706 r
F P
0 g
s
.5017 1.01274 m .4907 .99546 L .54365 1.03887 L p .638 .513 .694 r
F P
0 g
s
.5321 1.01618 m .54365 1.03887 L .4907 .99546 L p .591 .483 .699 r
F P
0 g
s
.50921 1.01833 m .48617 .98064 L p .50812 1.02135 L .719 .489 .575 r
F P
0 g
s
.51017 1.02514 m .50921 1.01833 L .50812 1.02135 L .719 .489 .575 r
F
.47078 .96726 m .48617 .98064 L .4433 .93507 L p .646 .368 .484 r
F P
0 g
s
.35963 .78702 m .32897 .78602 L .31889 .73832 L p .482 .506 .805 r
F P
0 g
s
.33507 .62623 m .28426 .63357 L .30375 .58129 L p .515 .313 .544 r
F P
0 g
s
.30375 .58129 m .35959 .57517 L .33507 .62623 L p .515 .313 .544 r
F P
0 g
s
.47908 .93825 m .46608 .92212 L .50286 .92315 L p .412 .469 .81 r
F P
0 g
s
.48028 .90447 m .50286 .92315 L .46608 .92212 L p .321 .444 .83 r
F P
0 g
s
.77197 1.03968 m .7627 .99159 L .80865 .97253 L p .932 .869 .754 r
F P
0 g
s
.79301 .92073 m .80865 .97253 L .7627 .99159 L p .899 .801 .743 r
F P
0 g
s
.59985 1.20111 m .60733 1.17091 L .63745 1.21767 L p .822 .8 .831 r
F P
0 g
s
.6528 1.183 m .63745 1.21767 L .60733 1.17091 L p .801 .759 .815 r
F P
0 g
s
.27784 .68985 m .32095 .68288 L .31889 .73832 L p .468 .433 .736 r
F P
0 g
s
.32095 .68288 m .27784 .68985 L .28426 .63357 L p .498 .378 .646 r
F P
0 g
s
.66196 1.14703 m .66456 1.11035 L .7175 1.12964 L p .819 .802 .836 r
F P
0 g
s
.72133 1.08699 m .7175 1.12964 L .66456 1.11035 L p .799 .762 .819 r
F P
0 g
s
.50617 .97454 m .51948 .99471 L .47118 .96404 L p .468 .415 .715 r
F P
0 g
s
.28426 .63357 m .33507 .62623 L .32095 .68288 L p .498 .378 .646 r
F P
0 g
s
.45814 .88822 m .4372 .87435 L .45383 .85203 L p .428 .536 .864 r
F P
0 g
s
.42234 .8394 m .45383 .85203 L .4372 .87435 L p .36 .528 .887 r
F P
0 g
s
.42301 .57654 m .35959 .57517 L .39147 .53572 L p .602 .294 .419 r
F P
0 g
s
.39147 .53572 m .45512 .54009 L .42301 .57654 L p .602 .294 .419 r
F P
0 g
s
.47078 .96726 m .45732 .95558 L .49575 1.00809 L p .661 .446 .582 r
F P
0 g
s
.48223 .99265 m .49575 1.00809 L .45732 .95558 L p .59 .4 .592 r
F P
0 g
s
.80206 .83953 m .76565 .7893 L .78879 .75769 L p .975 .714 .473 r
F P
0 g
s
.74538 .70962 m .78879 .75769 L .76565 .7893 L p .921 .655 .518 r
F P
0 g
s
.72133 1.08699 m .71605 1.04416 L .77197 1.03968 L p .862 .828 .813 r
F P
0 g
s
.7627 .99159 m .77197 1.03968 L .71605 1.04416 L p .837 .777 .794 r
F P
0 g
s
.60733 1.17091 m .61057 1.1402 L .6528 1.183 L p .801 .759 .815 r
F P
0 g
s
.66196 1.14703 m .6528 1.183 L .61057 1.1402 L p .778 .724 .802 r
F P
0 g
s
.49257 .95572 m .47908 .93825 L .52505 .94423 L p .482 .492 .791 r
F P
0 g
s
.50286 .92315 m .52505 .94423 L .47908 .93825 L p .412 .469 .81 r
F P
0 g
s
.42234 .8394 m .39383 .83023 L .39626 .79198 L p .492 .553 .846 r
F P
0 g
s
.35963 .78702 m .39626 .79198 L .39383 .83023 L p .437 .545 .868 r
F P
0 g
s
.74538 .70962 m .69115 .66725 L .70874 .64129 L p .904 .527 .304 r
F P
0 g
s
.65192 .60403 m .70874 .64129 L .69115 .66725 L p .85 .489 .368 r
F P
0 g
s
.48028 .90447 m .45814 .88822 L .48707 .86834 L p .486 .545 .843 r
F P
0 g
s
.45383 .85203 m .48707 .86834 L .45814 .88822 L p .428 .536 .864 r
F P
0 g
s
.50617 .97454 m .49257 .95572 L .54606 .96758 L p .539 .513 .775 r
F P
0 g
s
.52505 .94423 m .54606 .96758 L .49257 .95572 L p .482 .492 .791 r
F P
0 g
s
.48617 .98064 m .47078 .96726 L .51017 1.02514 L p .719 .489 .575 r
F P
0 g
s
.49575 1.00809 m .51017 1.02514 L .47078 .96726 L p .661 .446 .582 r
F P
0 g
s
.66456 1.11035 m .66049 1.0736 L .72133 1.08699 L p .799 .762 .819 r
F P
0 g
s
.71605 1.04416 m .72133 1.08699 L .66049 1.0736 L p .777 .727 .806 r
F P
0 g
s
.31889 .73832 m .36071 .73764 L .35963 .78702 L p .482 .506 .805 r
F P
0 g
s
.36071 .73764 m .31889 .73832 L .32095 .68288 L p .536 .466 .725 r
F P
0 g
s
.61057 1.1402 m .60948 1.10937 L .66196 1.14703 L p .778 .724 .802 r
F P
0 g
s
.66456 1.11035 m .66196 1.14703 L .60948 1.10937 L p .754 .693 .793 r
F P
0 g
s
.79301 .92073 m .76483 .87099 L .80206 .83953 L p .95 .785 .642 r
F P
0 g
s
.76565 .7893 m .80206 .83953 L .76483 .87099 L p .901 .719 .647 r
F P
0 g
s
.49118 .58627 m .42301 .57654 L .45512 .54009 L p .671 .351 .424 r
F P
0 g
s
.45512 .54009 m .5219 .55289 L .49118 .58627 L p .671 .351 .424 r
F P
0 g
s
.39626 .79198 m .35963 .78702 L .36071 .73764 L p .537 .524 .789 r
F P
0 g
s
.58835 1.23043 m .57319 1.25855 L .57122 1.19204 L p .845 .777 .785 r
F P
0 g
s
.39437 .62564 m .33507 .62623 L .35959 .57517 L p .591 .372 .552 r
F P
0 g
s
.35959 .57517 m .42301 .57654 L .39437 .62564 L p .591 .372 .552 r
F P
0 g
s
.57122 1.19204 m .57289 1.16548 L .58835 1.23043 L p .845 .777 .785 r
F P
0 g
s
.59985 1.20111 m .58835 1.23043 L .57289 1.16548 L p .817 .731 .77 r
F P
0 g
s
.69115 .66725 m .62863 .63195 L .65192 .60403 L p .85 .489 .368 r
F P
0 g
s
.5886 .57431 m .65192 .60403 L .62863 .63195 L p .792 .446 .402 r
F P
0 g
s
.51948 .99471 m .50617 .97454 L .56512 .99302 L p .586 .534 .763 r
F P
0 g
s
.54606 .96758 m .56512 .99302 L .50617 .97454 L p .539 .513 .775 r
F P
0 g
s
.7627 .99159 m .74235 .94476 L .79301 .92073 L p .899 .801 .743 r
F P
0 g
s
.76483 .87099 m .79301 .92073 L .74235 .94476 L p .861 .742 .73 r
F P
0 g
s
.57289 1.16548 m .5718 1.13904 L .59985 1.20111 L p .817 .731 .77 r
F P
0 g
s
.60733 1.17091 m .59985 1.20111 L .5718 1.13904 L p .787 .693 .76 r
F P
0 g
s
.50286 .92315 m .48028 .90447 L .52075 .88844 L p .534 .556 .824 r
F P
0 g
s
.48707 .86834 m .52075 .88844 L .48028 .90447 L p .486 .545 .843 r
F P
0 g
s
.45383 .85203 m .42234 .8394 L .43747 .80152 L p .538 .563 .828 r
F P
0 g
s
.39626 .79198 m .43747 .80152 L .42234 .8394 L p .492 .553 .846 r
F P
0 g
s
.60948 1.10937 m .60412 1.07883 L .66456 1.11035 L p .754 .693 .793 r
F P
0 g
s
.66049 1.0736 m .66456 1.11035 L .60412 1.07883 L p .729 .665 .788 r
F P
0 g
s
.56085 .60477 m .49118 .58627 L .5219 .55289 L p .733 .401 .419 r
F P
0 g
s
.5219 .55289 m .5886 .57431 L .56085 .60477 L p .733 .401 .419 r
F P
0 g
s
.5718 1.13904 m .5681 1.11294 L .60733 1.17091 L p .787 .693 .76 r
F P
0 g
s
.61057 1.1402 m .60733 1.17091 L .5681 1.11294 L p .758 .659 .753 r
F P
0 g
s
.62863 .63195 m .56085 .60477 L .5886 .57431 L p .792 .446 .402 r
F P
0 g
s
.71605 1.04416 m .70179 1.00212 L .7627 .99159 L p .837 .777 .794 r
F P
0 g
s
.74235 .94476 m .7627 .99159 L .70179 1.00212 L p .809 .733 .78 r
F P
0 g
s
.32095 .68288 m .37273 .68161 L .36071 .73764 L p .536 .466 .725 r
F P
0 g
s
.37273 .68161 m .32095 .68288 L .33507 .62623 L p .569 .424 .645 r
F P
0 g
s
.76565 .7893 m .7176 .74376 L .74538 .70962 L p .921 .655 .518 r
F P
0 g
s
.69115 .66725 m .74538 .70962 L .7176 .74376 L p .864 .601 .539 r
F P
0 g
s
.5321 1.01618 m .51948 .99471 L .58153 1.02027 L p .626 .555 .755 r
F P
0 g
s
.56512 .99302 m .58153 1.02027 L .51948 .99471 L p .586 .534 .763 r
F P
0 g
s
.33507 .62623 m .39437 .62564 L .37273 .68161 L p .569 .424 .645 r
F P
0 g
s
.5681 1.11294 m .56199 1.08741 L .61057 1.1402 L p .758 .659 .753 r
F P
0 g
s
.60948 1.10937 m .61057 1.1402 L .56199 1.08741 L p .727 .629 .749 r
F P
0 g
s
.66049 1.0736 m .64988 1.03747 L .71605 1.04416 L p .777 .727 .806 r
F P
0 g
s
.70179 1.00212 m .71605 1.04416 L .64988 1.03747 L p .753 .696 .797 r
F P
0 g
s
.52505 .94423 m .50286 .92315 L .55348 .91222 L p .575 .569 .809 r
F P
0 g
s
.52075 .88844 m .55348 .91222 L .50286 .92315 L p .534 .556 .824 r
F P
0 g
s
.54365 1.03887 m .5321 1.01618 L .59469 1.049 L p .662 .578 .75 r
F P
0 g
s
.58153 1.02027 m .59469 1.049 L .5321 1.01618 L p .626 .555 .755 r
F P
0 g
s
.56199 1.08741 m .55373 1.06266 L .60948 1.10937 L p .727 .629 .749 r
F P
0 g
s
.60412 1.07883 m .60948 1.10937 L .55373 1.06266 L p .696 .602 .748 r
F P
0 g
s
.60412 1.07883 m .59469 1.049 L .66049 1.0736 L p .729 .665 .788 r
F P
0 g
s
.64988 1.03747 m .66049 1.0736 L .59469 1.049 L p .702 .641 .785 r
F P
0 g
s
.55373 1.06266 m .54365 1.03887 L .60412 1.07883 L p .696 .602 .748 r
F P
0 g
s
.59469 1.049 m .60412 1.07883 L .54365 1.03887 L p .662 .578 .75 r
F P
0 g
s
.54606 .96758 m .52505 .94423 L .58392 .93946 L p .612 .584 .798 r
F P
0 g
s
.55348 .91222 m .58392 .93946 L .52505 .94423 L p .575 .569 .809 r
F P
0 g
s
.48707 .86834 m .45383 .85203 L .48158 .81604 L p .578 .575 .813 r
F P
0 g
s
.43747 .80152 m .48158 .81604 L .45383 .85203 L p .538 .563 .828 r
F P
0 g
s
.43747 .80152 m .39626 .79198 L .40912 .74233 L p .583 .543 .776 r
F P
0 g
s
.36071 .73764 m .40912 .74233 L .39626 .79198 L p .537 .524 .789 r
F P
0 g
s
.53558 1.07187 m .52456 1.05091 L .55892 1.09986 L p .754 .606 .694 r
F P
0 g
s
.55892 1.09986 m .5681 1.11294 L p .55391 1.09502 L .754 .606 .694 r
F P
0 g
s
.55391 1.09502 m .53558 1.07187 L .55892 1.09986 L .754 .606 .694 r
F
.56199 1.08741 m .5681 1.11294 L .52456 1.05091 L p .717 .573 .692 r
F P
0 g
s
.5718 1.13904 m .53558 1.07187 L p .55391 1.09502 L .754 .606 .694 r
F P
0 g
s
.5681 1.11294 m .56919 1.12067 L p .55391 1.09502 L .754 .606 .694 r
F P
0 g
s
.56919 1.12067 m .5718 1.13904 L p .55391 1.09502 L .754 .606 .694 r
F P
0 g
s
.54571 1.09407 m .53558 1.07187 L .5718 1.13904 L p .79 .642 .698 r
F P
0 g
s
.52485 1.04391 m .51017 1.02514 L .54571 1.09407 L p .882 .626 .547 r
F P
0 g
s
.54004 1.08161 m .52779 1.05119 L p .54086 1.0824 L .882 .626 .547 r
F P
0 g
s
.52779 1.05119 m .52485 1.04391 L p .5281 1.05171 L .882 .626 .547 r
F P
0 g
s
.54086 1.0824 m .52779 1.05119 L .5281 1.05171 L .882 .626 .547 r
F
.54571 1.09407 m .55446 1.11742 L .54004 1.08161 L p F P
0 g
s
.54571 1.09407 m .54004 1.08161 L .54086 1.0824 L .882 .626 .547 r
F
.45963 .6328 m .39437 .62564 L .42301 .57654 L p .652 .421 .555 r
F P
0 g
s
.42301 .57654 m .49118 .58627 L .45963 .6328 L p .652 .421 .555 r
F P
0 g
s
.76483 .87099 m .72519 .82479 L .76565 .7893 L p .901 .719 .647 r
F P
0 g
s
.7176 .74376 m .76565 .7893 L .72519 .82479 L p .852 .663 .646 r
F P
0 g
s
.40912 .74233 m .36071 .73764 L .37273 .68161 L p .59 .496 .716 r
F P
0 g
s
.59469 1.049 m .58153 1.02027 L .64988 1.03747 L p .702 .641 .785 r
F P
0 g
s
.56512 .99302 m .54606 .96758 L .61083 .96977 L p .644 .601 .791 r
F P
0 g
s
.58392 .93946 m .61083 .96977 L .54606 .96758 L p .612 .584 .798 r
F P
0 g
s
.57289 1.16548 m .57122 1.19204 L .55446 1.11742 L p .827 .683 .704 r
F P
0 g
s
.5718 1.13904 m .57289 1.16548 L .54571 1.09407 L p .79 .642 .698 r
F P
0 g
s
.55446 1.11742 m .54571 1.09407 L .57289 1.16548 L p .827 .683 .704 r
F P
0 g
s
.58153 1.02027 m .56512 .99302 L .63311 1.00264 L p .674 .62 .786 r
F P
0 g
s
.63311 1.00264 m .64988 1.03747 L .58153 1.02027 L p .674 .62 .786 r
F P
0 g
s
.61083 .96977 m .63311 1.00264 L .56512 .99302 L p .644 .601 .791 r
F P
0 g
s
.7176 .74376 m .66006 .70435 L .69115 .66725 L p .864 .601 .539 r
F P
0 g
s
.62863 .63195 m .69115 .66725 L .66006 .70435 L p .81 .552 .549 r
F P
0 g
s
.64988 1.03747 m .63311 1.00264 L .70179 1.00212 L p .753 .696 .797 r
F P
0 g
s
.74235 .94476 m .71166 .90046 L .76483 .87099 L p .861 .742 .73 r
F P
0 g
s
.72519 .82479 m .76483 .87099 L .71166 .90046 L p .824 .694 .72 r
F P
0 g
s
.67907 .96184 m .70179 1.00212 L .63311 1.00264 L p .729 .669 .792 r
F P
0 g
s
.70179 1.00212 m .67907 .96184 L .74235 .94476 L p .809 .733 .78 r
F P
0 g
s
.71166 .90046 m .74235 .94476 L .67907 .96184 L p .781 .695 .769 r
F P
0 g
s
.52075 .88844 m .48707 .86834 L .52672 .83576 L p .614 .589 .802 r
F P
0 g
s
.48158 .81604 m .52672 .83576 L .48707 .86834 L p .578 .575 .813 r
F P
0 g
s
.43111 .68703 m .37273 .68161 L .39437 .62564 L p .625 .464 .643 r
F P
0 g
s
.39437 .62564 m .45963 .6328 L .43111 .68703 L p .625 .464 .643 r
F P
0 g
s
.37273 .68161 m .43111 .68703 L .40912 .74233 L p .59 .496 .716 r
F P
0 g
s
.63311 1.00264 m .61083 .96977 L .67907 .96184 L p .729 .669 .792 r
F P
0 g
s
.52786 .6483 m .45963 .6328 L .49118 .58627 L p .707 .465 .556 r
F P
0 g
s
.49118 .58627 m .56085 .60477 L .52786 .6483 L p .707 .465 .556 r
F P
0 g
s
.66006 .70435 m .59577 .67227 L .62863 .63195 L p .81 .552 .549 r
F P
0 g
s
.56085 .60477 m .62863 .63195 L .59577 .67227 L p .758 .508 .554 r
F P
0 g
s
.48158 .81604 m .43747 .80152 L .46214 .7531 L p .623 .563 .766 r
F P
0 g
s
.40912 .74233 m .46214 .7531 L .43747 .80152 L p .583 .543 .776 r
F P
0 g
s
.55348 .91222 m .52075 .88844 L .57091 .86062 L p .646 .606 .795 r
F P
0 g
s
.52672 .83576 m .57091 .86062 L .52075 .88844 L p .614 .589 .802 r
F P
0 g
s
.59577 .67227 m .52786 .6483 L .56085 .60477 L p .758 .508 .554 r
F P
0 g
s
.61083 .96977 m .58392 .93946 L .64878 .92428 L p .703 .645 .789 r
F P
0 g
s
.64878 .92428 m .67907 .96184 L .61083 .96977 L p .703 .645 .789 r
F P
0 g
s
.72519 .82479 m .67579 .78354 L .7176 .74376 L p .852 .663 .646 r
F P
0 g
s
.66006 .70435 m .7176 .74376 L .67579 .78354 L p .807 .616 .644 r
F P
0 g
s
.67907 .96184 m .64878 .92428 L .71166 .90046 L p .781 .695 .769 r
F P
0 g
s
.58392 .93946 m .55348 .91222 L .6122 .8903 L p .675 .624 .79 r
F P
0 g
s
.57091 .86062 m .6122 .8903 L .55348 .91222 L p .646 .606 .795 r
F P
0 g
s
.6122 .8903 m .64878 .92428 L .58392 .93946 L p .675 .624 .79 r
F P
0 g
s
.46214 .7531 m .40912 .74233 L .43111 .68703 L p .636 .525 .711 r
F P
0 g
s
.6719 .85991 m .71166 .90046 L .64878 .92428 L p .752 .662 .762 r
F P
0 g
s
.71166 .90046 m .6719 .85991 L .72519 .82479 L p .824 .694 .72 r
F P
0 g
s
.67579 .78354 m .72519 .82479 L .6719 .85991 L p .787 .652 .713 r
F P
0 g
s
.52672 .83576 m .48158 .81604 L .51744 .77033 L p .659 .585 .761 r
F P
0 g
s
.46214 .7531 m .51744 .77033 L .48158 .81604 L p .623 .563 .766 r
F P
0 g
s
.49354 .69985 m .43111 .68703 L .45963 .6328 L p .675 .501 .642 r
F P
0 g
s
.45963 .6328 m .52786 .6483 L .49354 .69985 L p .675 .501 .642 r
F P
0 g
s
.64878 .92428 m .6122 .8903 L .6719 .85991 L p .752 .662 .762 r
F P
0 g
s
.43111 .68703 m .49354 .69985 L .46214 .7531 L p .636 .525 .711 r
F P
0 g
s
.67579 .78354 m .61887 .74842 L .66006 .70435 L p .807 .616 .644 r
F P
0 g
s
.59577 .67227 m .66006 .70435 L .61887 .74842 L p .763 .575 .643 r
F P
0 g
s
.57091 .86062 m .52672 .83576 L .57251 .79411 L p .692 .608 .758 r
F P
0 g
s
.51744 .77033 m .57251 .79411 L .52672 .83576 L p .659 .585 .761 r
F P
0 g
s
.51744 .77033 m .46214 .7531 L .49354 .69985 L p .677 .554 .707 r
F P
0 g
s
.6122 .8903 m .57091 .86062 L .62481 .82417 L p .722 .634 .758 r
F P
0 g
s
.62481 .82417 m .6719 .85991 L .6122 .8903 L p .722 .634 .758 r
F P
0 g
s
.55714 .72035 m .49354 .69985 L .52786 .6483 L p .72 .537 .642 r
F P
0 g
s
.52786 .6483 m .59577 .67227 L .55714 .72035 L p .72 .537 .642 r
F P
0 g
s
.6719 .85991 m .62481 .82417 L .67579 .78354 L p .787 .652 .713 r
F P
0 g
s
.57251 .79411 m .62481 .82417 L .57091 .86062 L p .692 .608 .758 r
F P
0 g
s
.61887 .74842 m .55714 .72035 L .59577 .67227 L p .763 .575 .643 r
F P
0 g
s
.61887 .74842 m .67579 .78354 L .62481 .82417 L p .751 .616 .709 r
F P
0 g
s
.49354 .69985 m .55714 .72035 L .51744 .77033 L p .677 .554 .707 r
F P
0 g
s
.57251 .79411 m .51744 .77033 L .55714 .72035 L p .715 .584 .707 r
F P
0 g
s
.62481 .82417 m .57251 .79411 L .61887 .74842 L p .751 .616 .709 r
F P
0 g
s
.55714 .72035 m .61887 .74842 L .57251 .79411 L p .715 .584 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[13]:=",
  ImageSize->{194.125, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003200017b000`400?l00000o`00003o`P3oool0
0<80oooo00320?ooo`00`P3oool00<80oooo00320?ooo`00`P3oool00<80oooo00320?ooo`00`P3o
ool00<80oooo00320?ooo`00`P3oool00<80oooo00320?ooo`00`P3oool00<80oooo00320?ooo`00
`P3oool00<80oooo00320?ooo`00`P3oool00<80oooo00320?ooo`00`P3oool00<80oooo00320?oo
o`00`P3oool00<80oooo00320?ooo`00`P3oool00<80oooo00320?ooo`00`P3oool00<80oooo0032
0?ooo`00`P3oool00<80oooo00320?ooo`00`P3oool00<80oooo00320?ooo`00`P3oool006`0oooo
1000001B0?ooo`00K03oool010000000cG9R0000002h<00200000500oooo001[0?ooo`040000003=
LV80cG9R0<ebHP80000000<0^3000000003oool0CP3oool006X0oooo0P0000050<ebHP@00000C@3o
ool006T0oooo00<000000<B4SP34Q8h00P0000050<ebHP030000002h<000000004`0oooo001X0?oo
o`0300000034Q8h0a8B>00<0a8B>0P0000040<ebHP<00000B`3oool006L0oooo0P0000070<B4SP80
000000@0cG9R0000003LOEL0g7eG0P00001:0?ooo`00I`3oool20;Z;Y08000001`34Q8h2000000<0
g7eG0P0000190?ooo`00IP3oool00`000000^X^T0;Z;Y0020;Z;Y0<000001034Q8h00`000000dHn=
000000030=amE`800000B03oool006D0oooo00<000000;Z;Y02jRj@01P2jRj@2000000030<B4SP00
0000dHn=0080dHn=0P0000020=amE`800000A`3oool006@0oooo0P00000:0;Z;Y08000001@3AShd2
000000030=amE`000000000004H0oooo001T0?ooo`80[hjc0P0000070;Z;Y00400000034U:D0a9BU
000000H0dHn=00<000000=amE`000000AP3oool006<0oooo00<000000:n>/`2_S[<00P2_S[<20000
00@0^X^T00<000000<BDY@34U:D00P34U:D2000000D0dHn=00<000000>R5@`000000A@3oool006<0
oooo00<000000:n>/`2_S[<0102_S[<2000000030;Z;Y0000000a9BU00H0a9BU00@000000=6?S@3A
Shd0dHn=0P0000020>R5@`030000003oool0oooo0480oooo001R0?ooo`800000202_S[<2000000P0
a9BU00<000000=6?S@0000000P3NVhX010000000j8E30>R5@`0000130?ooo`00HP3oool20:B@`080
00001P2_S[<010000000^9Jc0000000000070<BDY@8000000`3NVhX010000000j8E30>R5@`000012
0?ooo`00H@3oool00`000000Y9300:B@`0020:B@`0030000002_S[<0[hjc0080[hjc00<000000;RF
/`2hU[<00P2hU[<2000000@0a9BU00@000000<nNY@3?WZD000000`3NVhX010000000j8E30>R5@`00
00110?ooo`00H03oool00`000000Y9300:B@`0040:B@`0040000002_S[<0[hjc000000L0^9Jc0P00
00000`34U:D000000<nNY@030<nNY@050000003NVhX0gY^:0=jKRP0000000P3XQD<00`000000oooo
0?ooo`0n0?ooo`00G`3oool2000000P0Y9300P0000090;RF/`8000001@3?WZD01`000000gY^:0=jK
RP3NVhX000000>R5@`000000@03oool005l0oooo0P2CSld3000000@0Y93000<000000:^E_`2[UKl0
0P0000060;RF/`0400000031WK@0`Ifd000000D0cijU00L000000=jKRP3NVhX0gY^:0000003YQA`0
000003l0oooo001O0?ooo`030000002CSld0Tho=0080Tho=00@000000:B@`02TT<0000001@2[UKl0
0`000000^9Jc0;RF/`020;RF/`0300000031WK@0`Ifd0080`Ifd00<000000<nNY@3?WZD00`3?WZD0
10000000gY^:0000000000020>V570030000003oool0oooo03`0oooo001N0?ooo`030000002CSld0
Tho=00D0Tho=0P0000060:^E_`80000000<0^9Jc00000031WK@01@31WK@00`000000cijU0<nNY@03
0<nNY@060000003]ZH@0kJV40000003YQA`00000?P3oool005h0oooo0P00000609>?c@80Vi;:00<0
00000:^E_`2[UKl01@2[UKl00`000000`Ifd0<6M]0060<6M]0040000003?WZD0cijU0<nNY@800000
0`3]ZH@00`000000jHDL0000000m0?ooo`00GP3oool207B:fP8000000`2CSld01@000000Vi;:09^B
bP2KT/X0000000D0ZiFo00<000000;>J_`0000002031WK@00`000000cijU000000020=ZZYP040000
003]ZH@0kJV40>fYQ0800000?@3oool005d0oooo0P00000307B:fP80Tho=00<0000009^BbP2KT/X0
0`2KT/X01@000000ZiFo0:^E_`2[UKl0000000<0/iZo00<000000<6M]031WK@01@31WK@2000000@0
fZZV00@000000>fYQ03]ZH@0kJV40P00000l0?ooo`00G@3oool202E^gP040000001dR]X0M8[J07B:
fP8000001P2KT/X20:^E_`030000002cV[l0/iZo00<0/iZo00<000000<6M]031WK@00`31WK@00`00
0000bJJe000000050=ZZYP040000003]ZH@0kJV40>fYQ0800000>`3oool005h0oooo0P0UK]h207B:
fP0400000020Rm@0P8_D000000D0Vi;:0P0000070;>J_`0500000031WK@0`Ifd0<6M]00000000`39
Y[D00`000000fZZV0=ZZYP020=ZZYP030000003]ZH@0kJV40080kJV400<000000?ooo`3oool0>@3o
ool005l0oooo0P0UK]h00`000000P8_D082;e002082;e0050000002KT/X0Vi;:09^BbP0000000P2R
U/L00`000000/iZo0;>J_`050;>J_`0300000031WK@0000000D0bJJe00<000000=ZZYP3JZZH00P3J
ZZH010000000kJV40>fYQ03]ZH@2000003X0oooo001P0?ooo`0300000013L]X0000000@0P8_D00<0
000009^BbP000000102RU/L00`000000/iZo0;>J_`040;>J_`8000001`39Y[D00`000000fZZV0=ZZ
YP020=ZZYP050000003]ZH@000000?ZhN@000000>P3oool00600oooo00@0000004=bfP13L]X00000
0`20Rm@3000000D0XYK700@000000;>J_`2cV[l0/iZo0P0000020;ZQ_`0300000039Y[D0bJJe00@0
bJJe00<000000=ZZYP3JZZH00P3JZZH200000080n[Qi00<000000?ooo`3oool0>03oool00640oooo
00H0000004=bfP13L]X00000082;e000000308Z<d0030000002RU/L0XYK700<0XYK700<000000;>J
_`0000001@2jXKl00`000000bJJe0<VV]@040<VV]@060000003JZZH000000000003U^:H000000P3j
^7T2000003T0oooo001R0?ooo`80@g;J0P00000508Z<d0030000002RU/L0XYK70080XYK70P000007
0;ZQ_`0300000039Y[D0bJJe00<0bJJe0P0000040>FhYP040000003j^7T0n[Qi000003T0oooo001S
0?ooo`040000001KM]@0FgKD000000D0RXc@00@000000::Fa`00000000000P2YVLH00`000000^Z6o
0;ZQ_`050;ZQ_`0700000039Y[D0bJJe0<VV]@000000dK2g000000040>FhYP040000003j^7T0n[Qi
000003T0oooo001S0?ooo`050000001KM]@0FgKD05]fe0000000102:S=02000000D0ZIW600<00000
0;ZQ_`2jXKl01@2jXKl00`000000bJJe000000030=6`]`030000003U^:H0iKRV0080iKRV00@00000
0?ZhN@0000000000>03oool006@0oooo00H0000005]fe01KM]@0FgKD0000002:S=020000000309>?
c0000000ZIW600D0ZIW600<000000;ZQ_`2jXKl0102jXKl2000000D0dK2g00<000000>FhYP3U^:H0
0P3U^:H00`000000n[Qi0000000h0?ooo`00I@3oool00`000000FgKD05]fe002000000@0Tho<00<0
00000:VIaP2YVLH0102YVLH00`000000^Z6o0;ZQ_`03000000030<6W`0000000dK2g00@0dK2g00<0
00000>FhYP3U^:H00P3U^:H00`000000n[Qi0000000h0?ooo`00I@3oool30000000306ijcP000000
Tho<00@0Tho<00<000000:VIaP2YVLH00`2YVLH3000000D0`JO000<000000=6`]`3A/;L00`3A/;L0
0`000000iKRV0>FhYP020>FhYP800000>03oool006H0oooo00D0000006ijcP1^N/h0KW[>00000005
09>?c0030000002YVLH000000080000000<0/9k500000031Yl001@31Yl000`000000dK2g0=6`]`03
0=6`]`040000003U^:H0iKRV0>FhYP80000000<0o<9M0000003oool0=P3oool006H0oooo0P000003
06ijcP040000002CSl`0Tho<09>?c0<000001@2`W/D00`000000`JO00<6W`0040<6W`0030000003A
/;L0dK2g00<0dK2g00L000000>FhYP000000lLRV0000003l`Ud0000003L0oooo001V0?ooo`<00000
0P1^N/h400000080Vi7900<000000;2Na@2`W/D00`2`W/D00`000000`JO00<6W`0050<6W`0030000
003A/;L0dK2g0080dK2g0P0000030?78YP800000=`3oool006H0oooo0P0000001@11Dkl000000000
001mO/T0000000D0Vi7900<000000;2Na@2`W/D00`2`W/D00`000000`JO00<6W`0040<6W`0030000
003A/;L000000080000000<0f[^j0000003ab:H00P3ab:H2000003L0oooo001W0?ooo`0300000011
Dkl0000000<0OGk900<0000009^Ab@2KTLT00P2KTLT00`000000/9k50;2Na@040;2Na@0300000031
Yl00`JO000<0`JO00P0000040=Zk^P040000003ab:H0lLRV0?78YP800000=`3oool006L0oooo0P00
00000`11Dkl0000007enb@0207enb@030000002KTLT0Vi790080Vi7900<000000;2Na@2`W/D00`2`
W/D00`000000`JO00<6W`003000000030<N_`P000000f[^j00@0f[^j00H000000?78YP3ab:H00000
0?c2G@00000f0?ooo`00I`3oool4000000<0OGk900<0000009^Ab@2KTLT00P2KTLT010000000/9k5
0;2Na@2`W/D5000000D0ajo200<000000=Zk^P3J^kX00P3J^kX01P000000lLRV0?78YP000000o<9M
000003H0oooo001W0?ooo`8000000P1OH;`<000000<0]Z?500<000000<N_`P37[l801037[l800`00
0000f[^j0=Zk^P020=Zk^P040000003ab:H0lLRV0?78YP800000=P3oool006L0oooo0P00000205mP
_0050000002:P/D0RX;508Z2a@000000102SULH00`000000]Z?50;JSa@040;JSa@0300000037[l80
ajo200@0ajo200D000000=Zk^P3J^kX0f[^j000000020?78YP<00000=P3oool006H0oooo10000000
0`1OH;`0000008Z2a@0308Z2a@030000002SULH0XiG60080XiG600<000000;JSa@2fXlD00`2fXlD0
0`000000ajo20<N_`P040<N_`P030000003J^kX0f[^j0080f[^j0P0000000`3kfj8000000000000f
0?ooo`00IP3oool20000000503H`W@000000000005mP_00000000`2:P/D00`000000XiG60:>EaP02
0:>EaP030000002fXlD0]Z?500@0]Z?500<000000<N_`P37[l800`37[l800`000000f[^j0=Zk^P03
00000080nm^R0P00000f0?ooo`00IP3oool20000000303H`W@000000MFZh008000000`2:P/D00`00
0000XiG60:>EaP030:>EaP030000002fXlD0]Z?500<0]Z?500@000000<N_`P37[l80ajo21@000002
0>?9_@030000003kfj80nm^R00800000=P3oool006H0oooo0P000000100f<9d0000007EZ^01eJ[P9
000000030:>EaP000000]Z?50080]Z?51P0000030<jga0050000003SbKd0hlVm0>?9_@0000000P3k
fj82000003H0oooo001U0?ooo`030000000005h00000008000000P1eJ[P00`000000U8K109B6`@02
09B6`@040000002ZVLD0ZYW50:ZIa@D000000`2lZ<H00`000000c[O40<jga0030<jga0030000003S
bKd0hlVm0080hlVm00@000000?_KXP3kfj800000=P3oool006D0oooo00@000000000GP000000G4NP
0P0000000`1eJ[P0000009B6`@0409B6`@030000002ZVLD0ZYW50080ZYW500<000000;bXaP2lZ<H0
0`2lZ<H00`000000c[O40<jga0040<jga0050000003SbKd0hlVm0>?9_@0000000P3kfj800`000000
oooo0?ooo`0d0?ooo`00I03oool300000080G4NP00<0000008Ib]@0000000P00000409B6`@030000
002ZVLD0ZYW500<0ZYW500<000000;bXaP2lZ<H00`2lZ<H00`000000c[O40<jga0030<jga0050000
003SbKd0hlVm0>?9_@0000000P3kfj800`000000oooo0?ooo`0d0?ooo`00H`3oool20000000503TC
M@000000000005a7X00000000`26L[D300000080U8K100<000000:ZIa@2ZVLD00`2ZVLD00`000000
_:S60;bXaP030;bXaP030000003>]l@0c[O400<0c[O400D000000>?9_@3SbKd0hlVm000000020?_K
XP030000003oool0oooo03@0oooo00120?oooa<000003@3oool200000080>A=e00@0000007IGX@00
000000000`26L[D00`000000WX^o09j;_`04000000@0ZYW500<000000;bXaP2lZ<H00`2lZ<H00`00
0000c[O40<jga0030<jga0030000003SbKd0hlVm0080hlVm0`00000f0?ooo`00?@3oool8000000@0
=`001000000805@000P00000103oool00`000000000O00000002000000<0MUNQ0P00000208Ib]@03
0000002NRkl0WX^o00<0WX^o100000020:ZIa@030000002lZ<H0_:S600<0_:S600<000000<jga03>
]l@00`3>]l@00`000000hlVm00000002000000030?SYT`000000oooo03D0oooo000k0?ooo`800000
0P0<00030000000303L000000000000001@00000101W000600000080HC5o0P00000207IGX@060000
002CNK<0000000000026L[D00000102NRkl010000000/9g40;2Ma02`WL@@00000080jmW200<00000
0?SYT`000000=P3oool003T0oooo0P0000000`0<000000000000000500000080G@0L00<0000007d@
:01m42P01`1m42P2000000P0UBD/3@0000001029I:40000007IGX@00000309=i/`800000102NRkl0
0`000000/9g40;2Ma0030;2Ma00300000031[lL0`Jo700<0`Jo700<000000=C1b03D`LP00`3D`LP0
1`000000jmW20>_I`P3[fL8000000?SYT`000000=P3oool003L0oooo1P00000605d0708000002@1m
42P00`000000UBD/09DU;00:09DU;0800000102X=2T9000000@0TgVc0P00000309j;_`030000002`
WL@0/9g400<0/9g400<000000<6_a`31[lL00`31[lL00`000000e<780=C1b0030=C1b0040000003[
fL80jmW20>_I`P800000=`3oool003D0oooo0`00000302l010030000001M01`0G@0L00@0G@0L00<0
000007d@:01m42P01`1m42P2000000`0UBD/00<000000:Pd:@2X=2T0202X=2T6000000<0TgVc00<0
00000:J@_@0000000`0000050;2Ma00300000031[lL0`Jo700<0`Jo700<000000=C1b03D`LP00`3D
`LP010000000jmW20>_I`P3[fL82000003L0oooo000c0?ooo`<00000100_00@00`000000G@0L05d0
700405d070030000001m42P0OA0X0080OA0X3000000609DU;08000003P2X=2T50000000309=i/`00
0000YY2m00<0YY2m0`0000040;2Ma00300000031[lL0`Jo700<0`Jo700<000000=C1b03D`LP00P3D
`LP01P000000jmW20>_I`P000000n>VC000003L0oooo000a0?ooo`@00000100_00@00`000000G@0L
05d0700205d070P000001@24>6H709Y;J`P000003@2X=2T010000000]chO0;Ln7`2g?Ql4000000@0
YY2m00<000000;NSa02gXl@00`0000000`2`WL@000000<6_a`040<6_a`030000003D`LP0e<780080
e<7800H000000>_I`P3[fL8000000?SYT`00000g0?ooo`00<03oool4000000@0;`041P00000206PP
GPX0Q3QV00<0000009Y;J`2JBf/02P2JBf/30:]IK0D000001`2X=2T00`000000]chO0;Ln7`050;Ln
7`<000000P2VT;d00`000000]j?40;NSa0030;NSa0D000000P31[lL00`000000e<780=C1b0020=C1
b0030000003[fL80jmW200<00000=`3oool002l0oooo1000000302l010<000001P1X85h00`000000
Q3QV08@hIP0708@hIP030000002JBf/0VT][00X0VT][00<000000:]IK02[FF`01P2[FF`400000080
Z3@Y00<000000;Ln7`2g?Ql0202g?Ql4000000H0]j?400@000000<NfbP37]/X0akK:1P0000000`3D
`LP000000>_I`P02000000030<_KJ0000000oooo03H0oooo000^0?ooo`@0000000D0;`0400000000
0000000003l0CP0706PPGP0300000024>6H0Q3QV00L0Q3QV00<0000009Y;J`2JBf/02P2JBf/00`00
0000ZeU/0:]IK00;0:]IK0@000002`2g?Ql3000000D0]j?400<000000<NfbP37]/X00`37]/X01000
0000f/g=0=[=c@3JcLd3000000030>o[a@000000bm]X03P0oooo000]0?ooo`H000000`0o04h00`00
0000J21N06PPGP0406PPGP0300000024>6H0Q3QV00P0Q3QV00<0000009Y;J`2JBf/02@2JBf/00`00
0000ZeU/0:]IK00<0:]IK0040000002kIV/0^fI[0;]VJ`<000002P2g?Ql3000000<0]j?400<00000
0<NfbP37]/X00`37]/X00`000000f/g=0=[=c@020=[=c@030000003_jlD0kn_500800000>03oool0
02`0oooo1000000503l0CP030000001X85h0J21N00D0J21N00<0000008@hIP24>6H01`24>6H00`00
0000VT][09Y;J`0909Y;J`030000002[FF`0ZeU/00`0ZeU/00<000000;]VJ`2kIV/01@2kIV/30000
00H0]chO00@000000<932P32@`X0`T<:0`0000060<NfbP030000003JcLd0f/g=0080f/g=00D00000
0>o[a@000000bm]X0000000h0?ooo`00;03oool2000000030000;`0o04h0?`1>00<0?`1>00<00000
06PPGP1X85h01@1X85h00`000000Q3QV08@hIP0708@hIP030000002JBf/0VT][00T0VT][00<00000
0:]IK02[FF`0302[FF`00`000000^fI[0;]VJ`090;]VJ`<000000P2g?Ql00`000000`T<:0<932P04
0<932P8000001037]/X00`000000f/g=0=[=c@020=[=c@030000003_jlD0kn_500800000>@3oool0
02/0oooo0P0000000`0002l0000003l0CP0403l0CP030000001X85h0J21N00@0J21N00<0000008@h
IP24>6H00P24>6HE000000/0ZeU/00<000000;]VJ`2kIV/03@2kIV/3000000P0`T<:00D000000<Nf
bP37]/X0akK:000000040=[=c@030000003_jlD0kn_500800000>@3oool002X0oooo0P0000020000
;`030000000o04h0?`1>0080?`1>00<0000006PPGP1X85h00P1X85h8000000D0Pe2;302GGhd40:I[
SPL000000`2[FF`00`000000^fI[0;]VJ`0?0;]VJ`030000003:LVH00000008000001P32@`X20000
00030<NfbP000000f/g=00<0f/g=00<000000>o[a@3_jlD00P00000i0?ooo`00:P3oool010000000
000_0000;`00000403l0CPH000000P1Z?8L:08=@R`030000002GGhd0Uen=00T0Uen=00<000000:I[
SP2VJhh02@2VJhh5000000l0^fI[00<000000<YbIP3:LVH00`3:LVH2000000H0`T<:10000000103J
cLd000000>o[a@3_jlD2000003X0oooo000Y0?ooo`050000000002l0000_0000;`0000000P0o04h3
000000H0JSb700<0000008=@R`23D8/02023D8/00`000000Uen=09MOS@0909MOS@030000002VJhh0
YV^>00/0YV^>0`2dMhh3000000/0^fI[00<000000<YbIP3:LVH01P3:LVH2000000D0`T<:2@00000j
0?ooo`00:@3oool020000000000_0000;`0002l0000003l0CP000000AB1o201Z?8L00`000000Pe2;
08=@R`0708=@R`030000002GGhd0Uen=00T0Uen=00<000000:I[SP2VJhh02`2VJhh00`000000]7N>
0;AgSP040;AgSP@000001P2kIV/00`000000bW9V0<YbIP090<YbIP<0000000<0`T<:00000032?`00
0P32?`0200000080jO[200<000000?ooo`3oool0>@3oool002P0oooo0P0000020000;`<000000P15
87l00`000000JSb706XlQ`0506XlQ`0300000023D8/0Pe2;00L0Pe2;00<0000009MOS@2GGhd02@2G
Ghd00`000000YV^>0:I[SP0:0:I[SP030000002dMhh0]7N>00T0]7N>0`0000020;]VJ`030000003:
LVH0bW9V00d0bW9V0P0000040<8o00030000003Yn/80jO[203`0oooo000W0?ooo`8000000`0002l0
0`000000AB1o04DPO`0204DPO`030000001Z?8L0JSb700@0JSb700<0000008=@R`23D8/01`23D8/0
0`000000Uen=09MOS@0909MOS@030000002VJhh0YV^>00/0YV^>00<000000;AgSP2dMhh0302dMhh3
000000l0bW9V00<000000=UmGP0000001032?`02000003`0oooo000W0?ooo`80000000<0000_0000
00000000101587l00`000000JSb706XlQ`0506XlQ`0300000023D8/0Pe2;00L0Pe2;00<0000009MO
S@2GGhd02@2GGhd00`000000YV^>0:I[SP0:0:I[SP030000002dMhh0]7N>00h0]7N>00<000000<:2
S@0000000P00000;0<YbIP050000003IOEh0fGeN0=UmGP0000001@32?`000`000000oooo0?ooo`0i
0?ooo`009P3oool40000000300T0K@1587l0AB1o00<0AB1o00<0000006XlQ`1Z?8L0101Z?8L00`00
0000Pe2;08=@R`0708=@R`030000002GGhd0Uen=00T0Uen=00<000000:I[SP2VJhh02P2VJhh00`00
0000]7N>0;AgSP0>0;AgSP0300000032PXd0`X:=00<0`X:=0`0000070<YbIP030000003IOEh0fGeN
00<0fGeN0P0000040<8o00030000003oool0oooo03P0oooo000V0?ooo`<000000P0906d00`000000
AB1o04DPO`0204DPO`030000001Z?8L0JSb700@0JSb700<0000008=@R`23D8/01`23D8/00`000000
Uen=09MOS@0909MOS@030000002VJhh0YV^>00X0YV^>00<000000;AgSP2dMhh03@2dMhh00`000000
`X:=0<:2S@070<:2S@8000001@3:LVH00`000000fGeN0=UmGP050=UmGP0300000032?`00`Sl00080
`Sl000<000000?ooo`3oool0=`3oool002H0oooo0P00000200T0K@030000001587l0AB1o00<0AB1o
00<0000006XlQ`1Z?8L0101Z?8L010000000Pe2;08=@R`23D8/H000000H0YV^>00<000000;AgSP2d
Mhh03@2dMhh00`000000`X:=0<:2S@0:0<:2S@<0000000<0bW9V0000003IOEh0203IOEh2000000<0
`Sl000<000000?ooo`3oool0=P3oool002D0oooo0P00000300T0K@030000001587l0AB1o00<0AB1o
00<0000006XlQ`1Z?8L00P1Z?8L6000000D0Of2U302AK:D709mfY0P000003@2dMhh00`000000`X:=
0<:2S@0>0<:2S@8000002`3IOEh010000000`Sl00<8o0000000h0?ooo`009@3oool00`0000002@1]
00T0K@0200T0K@030000001587l0AB1o0080AB1o00<0000006XlQ`1Z?8L00`0000000`1WDJD0Of2U
07mPY@0807mPY@030000002AK:D0TFbU00P0TFbU00<0000009mfY02OMZ@02P2OMZ@30:b0Y0D00000
1`2dMhh00`000000`X:=0<:2S@0?0<:2S@040000003?SH`00000000000X0fGeN0P0000000`2X:`00
00000?ooo`0f0?ooo`009@3oool2000000<02@1]00<0000004DPO`1587l00P1587l3000000@0Ie6U
00<0000007mPY@1oH:D01P1oH:D00`000000TFbU095/Y@09095/Y@030000002OMZ@0WgJT00T0WgJT
00<000000:b0Y02/P:@01P2/P:@400000080]7N>00<000000<:2S@32PXd03`32PXd00`000000chf<
0<n=S0020<n=S0030000003IOEh0fGeN00P0fGeN0P0000000`2X:`0000000?ooo`0e0?ooo`00903o
ool3000000<02@1]00@0000004DPO`1587l0AB1o0P00000606MAY@030000001oH:D0Of2U00H0Of2U
00<00000095/Y@2AK:D0202AK:D00`000000WgJT09mfY00:09mfY0030000002/P:@0[82T00X0[82T
0`00000@0<:2S@030000003?SH`0chf<00@0chf<0P0000080=UmGP050000003WQTd000000:P[0000
0000=@3oool002@0oooo00<000000000A@0000000P0906d00`000000AB1o04DPO`020000000304Dm
X`1WDJD0Ie6U00D0Ie6U00<0000007mPY@1oH:D01P1oH:D00`000000TFbU095/Y@08095/Y@030000
002OMZ@0WgJT00T0WgJT00<000000:b0Y02/P:@0302/P:@20;R9Y0<000003032PXd00`000000chf<
0<n=S0070<n=S08000001@3IOEh01`000000ihI=0>N6C@3WQTd000000:P[00000000=03oool002@0
oooo0P0004D00`0000002@1]00T0K@03000000<0ACfS00<0000006MAY@1WDJD0101WDJD00`000000
Of2U07mPY@0507mPY@030000002AK:D0TFbU00P0TFbU00<0000009mfY02OMZ@02P2OMZ@00`000000
[82T0:b0Y00;0:b0Y0030000002hRJ@0^8VT00<0^8VT0`0000090<:2S@030000003?SH`0chf<00T0
chf<00D000000=UmGP3IOEh0fGeN000000050>N6C@030000002X:`00oooo03<0oooo000T0?ooo`03
0000000004D0000000802@1]00<0000004DmX`15?J<00`15?J<00`000000Ie6U06MAY@0306MAY@03
0000001oH:D0Of2U00H0Of2U00<00000095/Y@2AK:D0202AK:D00`000000WgJT09mfY00909mfY003
0000002/P:@0[82T00/0[82T00<000000;R9Y02hRJ@01`2hRJ@3000000D0`X:=00<000000<n=S03?
SH`02`3?SH`2000000030=UmGP000000ihI=00D0ihI=0P00000c0?ooo`00903oool00`0000000015
0000000200T0K@H0ACfS00<0000006MAY@1WDJD00`1WDJD00`000000Of2U07mPY@0607mPY@030000
002AK:D0TFbU00L0TFbU00<0000009mfY02OMZ@02P2OMZ@00`000000[82T0:b0Y00;0:b0Y0030000
002hRJ@0^8VT00X0^8VT0`0000000`32PXd000000<n=S00?0<n=S0800000203WQTd00`000000oooo
0?ooo`0`0?ooo`00903oool01000000000150000000906d2000000D0ACfS00<0000006MAY@1WDJD0
0`1WDJD00`000000Of2U07mPY@0607mPY@030000002AK:D0TFbU00L0TFbU00<0000009mfY02OMZ@0
2@2OMZ@00`000000[82T0:b0Y00;0:b0Y0030000002hRJ@0^8VT00h0^8VT0P00000@0<n=S0030000
003MVHT0000000P0ihI=00<000000?ooo`3oool0;`3oool002D0oooo0`000002014NW00300000015
?J<0ACfS0080ACfS00<0000006MAY@1WDJD00`1WDJD00`000000Of2U07mPY@0507mPY@030000002A
K:D0TFbU0080TFbU3000000609mfY0030000002/P:@0[82T00/0[82T00<000000;R9Y02hRJ@03P2h
RJ@010000000`i>T00000000000=0<n=S0050000003MVHT0gIV90=fIR@000000203WQTd00`000000
oooo0?ooo`0^0?ooo`009@3oool2000000<04AjL00<0000004DmX`15?J<00P15?J<00`000000Ie6U
06MAY@0306MAY@040000001oH:D0Of2U07mPY@T000001@29MkT709Mn]`P000002`2/P:@00`000000
^8VT0;R9Y00>0;R9Y00300000033Tj@0`i>T0080`i>T0P00000:0<n=S0030000003MVHT0gIV900<0
gIV900<000000>N6C@3WQTd01P3WQTd00`000000oooo0?ooo`0]0?ooo`009@3oool00`0000004AjL
014NW002014NW00300000015?J<0ACfS0080ACfS00<0000006MAY@1WDJD00P1WDJD5000000@0Mfjl
2P29MkT00`000000Ugjg09Mn]`0909Mn]`<0XXJf100000060:b0Y0030000002hRJ@0^8VT00h0^8VT
00<000000<>CY033Tj@01@33Tj@2000000L0chf<00<000000=fIR@3MVHT01@3MVHT2000000H0ihI=
00<000000?ooo`3oool0;@3oool002D0oooo00<000000000P`0A7Y`00P0A7Y`00`000000ACfS04Dm
X`0204DmX`030000001WDJD000000080000000<0HFBo07M^_01gK[`01P1gK[`00`000000RGNi08Ug
^@0708Ug^@030000002GO[L0Ugjg00P0Ugjg00<000000::6]P2RQ[H01@2RQ[H400000080[82T00<0
00000;R9Y02hRJ@03@2hRJ@00`000000`i>T0<>CY0080<>CY0800000103?SH`00`000000gIV90=fI
R@080=fIR@030000003WQTd0ihI=0080ihI=00<000000>f;;P000000;P3oool002D0oooo00<00000
0000P`0000000P0A7Y`010000000ACfS04DmX`15?J<3000000@0HFBo00<0000007M^_01gK[`01@1g
K[`00`000000RGNi08Ug^@0608Ug^@030000002GO[L0Ugjg00T0Ugjg00<000000::6]P2RQ[H02@2R
Q[H4000000d0^8VT00<000000<>CY033Tj@02`33Tj@2000000030<n=S0000000gIV900/0gIV900@0
00000>N6C@3WQTd000000`3]Rbh00`000000oooo0?ooo`0[0?ooo`009@3oool20000P`090000000A
7Y`04AjL014NW0000000ACfS00000011El80000000H0HFBo00<0000007M^_01gK[`0101gK[`00`00
0000RGNi08Ug^@0608Ug^@030000002GO[L0Ugjg00T0Ugjg00<000000::6]P2RQ[H02P2RQ[H30:f=
]0<000002@2hRJ@00`000000`i>T0<>CY00>0<>CY08000003@3MVHT00`000000ihI=000000040>f;
;P030000003oool0oooo02X0oooo000U0?ooo`040000000008<00023000000804AjL0P000002045G
`P030000001QI;l0HFBo00@0HFBo00<0000007M^_01gK[`0101gK[`00`000000RGNi08Ug^@0608Ug
^@030000002GO[L0Ugjg00P0Ugjg00<000000::6]P2RQ[H02P2RQ[H00`000000[Hfd0:f=]0040:f=
]0<000001@2hRJ@00`000000`i>T0<>CY00>0<>CY0040000003>WJ@0cYfT000000d0gIV900<00000
0>f;;P3]Rbh0103]Rbh00`000000oooo0?ooo`0Y0?ooo`009P3oool00`000000002300000002014N
W00300000011El80@EO20080@EO200<00000065T_`1QI;l00`1QI;l00`000000Mfjl07M^_00407M^
_00300000029MkT0RGNi00H0RGNi00<0000009Mn]`2GO[L0202GO[L00`000000XXJf0::6]P090::6
]P030000002]SK@0[Hfd00P0[Hfd0`0000000`2hRJ@000000<>CY00?0<>CY0030000003>WJ@0cYfT
0080cYfT0P00000;0=fIR@8000001@3]Rbh00`000000oooo0?ooo`0Y0?ooo`009P3oool00`000000
002300000002014NW00300000011El80@EO20080@EO200<00000065T_`1QI;l00`1QI;l00`000000
Mfjl07M^_00407M^_00300000029MkT0RGNi00H0RGNi00<0000009Mn]`2GO[L0202GO[L00`000000
XXJf0::6]P090::6]P030000002]SK@0[Hfd00/0[Hfd0P00000?0<>CY0030000003>WJ@0cYfT00D0
cYfT0P0000080=fIR@040000003[Yh@0jjN4000000D0kH/^00<000000?ooo`3oool0:03oool002H0
oooo00<0001<0000000008<00P0000000`0DA<400000045G`P02045G`P030000001QI;l0HFBo00<0
HFBo00<0000007M^_01gK[`0101gK[`00`000000RGNi08Ug^@0508Ug^@030000002GO[L0Ugjg00P0
Ugjg00<000000::6]P2RQ[H02@2RQ[H00`000000[Hfd0:f=]00<0:f=]080]iFd0`00000;0<>CY003
0000003>WJ@0cYfT00P0cYfT00<000000=fIR@3MVHT0103MVHT00`000000jjN40>^WQ0020>^WQ003
0000003]Rbh0kH/^00<0kH/^00<000000?ooo`3oool09`3oool002L0oooo00<000000000P`000000
0P0DA<400`000000@EO2045G`P02045G`P030000001QI;l0HFBo00<0HFBo00<0000007M^_01gK[`0
0`1gK[`00`000000RGNi08Ug^@0508Ug^@030000002GO[L0Ugjg00P0Ugjg00<000000::6]P2RQ[H0
2@2RQ[H00`000000[Hfd0:f=]00;0:f=]0030000002gUK@0]iFd00<0]iFd0P0000080<>CY0030000
003>WJ@0cYfT00X0cYfT0P0000030=fIR@030000003[Yh@0jjN400@0jjN400<000000>f;;P3]Rbh0
0`3]Rbh00`000000oooo0?ooo`0V0?ooo`00:03oool2000000<054C100D00000045G`P11El80@EO2
00000005065T_`030000001gK[`0Mfjl014000001@2GO[L00`000000XXJf0::6]P080::6]P030000
002]SK@0[Hfd00/0[Hfd00<000000;NE]02gUK@01P2gUK@2000000D0`i>T00<000000<jMY03>WJ@0
3@3>WJ@00`000000gIV9000000080>^WQ0030000003]Rbh0kH/^0080kH/^00<000000?ooo`3oool0
9P3oool002P0oooo0`00000201A4`@0500000011El80@EO2045G`P000000101QI;l4000000<0JGcC
201kPLh608V6b@P000001`2RQ[H00`000000[Hfd0:f=]00;0:f=]0030000002gUK@0]iFd00T0]iFd
0`0000000`33Tj@000000<jMY00@0<jMY0030000003[Yh@0jjN400P0jjN400@000000>f;;P3]Rbh0
kH/^0P00000W0?ooo`00:@3oool01@00000002Rb0000000DA<40000000@0@EO2100000000`1CMmP0
JGcC06Uld`0406Uld`030000001kPLh0Nh7>00D0Nh7>00<0000008V6b@29Q/T01`29Q/T409F;aPD0
00000P2RQ[H00`000000[Hfd0:f=]00:0:f=]0030000002gUK@0]iFd00d0]iFd0P00000@0<jMY003
0000003JZJD0000000X0jjN400D000000>f;;P000000e7/00000000W0?ooo`00:@3oool00`000000
02Rb0000000201A4`@0300000011El80@EO2008000001@1CMmP606Uld`030000001kPLh0Nh7>00@0
Nh7>00<0000008V6b@29Q/T01`29Q/T00`000000UH_609F;aP0609F;aP<00000302]SK@00`000000
]iFd0;NE]00<0;NE]00400000030WKD0`9fe000000h0cYfT00D000000=ZYY@3JZJD0fZVU0000000:
0>^WQ080000000<0e7/00000003oool09P3oool002X0oooo00T00000000X/P00000054C100000011
El80000003I`g00000001@1CMmP00`000000JGcC06Uld`0306Uld`030000001kPLh0Nh7>00@0Nh7>
00<0000008V6b@29Q/T01P29Q/T00`000000UH_609F;aP0809F;aP80Wi340`0000080:f=]0030000
002gUK@0]iFd00`0]iFd00<000000<2M]@30WKD00P30WKD2000000/0cYfT00<000000=ZYY@3JZJD0
0`3JZJD00`000000jjN40>^WQ0080>^WQ0040000003DN`00e7/0000002H0oooo000[0?ooo`800000
0P0DA<401@000000=W3L03I`g00fL=`0000000@0DgOH00<0000006Uld`1YO=<00`1YO=<00`000000
Nh7>07^1cP0407^1cP0300000029Q/T0RHK900H0RHK900<0000009F;aP2ERlH01`2ERlH00`000000
Wi3409n@a00309n@a08000001@2]SK@00`000000]iFd0;NE]00<0;NE]00300000030WKD0`9fe00D0
`9fe0P0000080<jMY0030000003JZJD0fZVU00D0fZVU00<000000>^WQ03[Yh@01`3[Yh@010000000
e7/00=Ak0000000V0?ooo`00:`3oool0100018`000000000000DA<42000000<0=W3L00<0000005=g
f01CMmP00P1CMmP00`000000JGcC06Uld`0206Uld`030000001kPLh0Nh7>00@0Nh7>00<0000008V6
b@29Q/T01P29Q/T00`000000UH_609F;aP0709F;aP030000002OT<@0Wi3400D0Wi340`0000000`2]
SK@000000;NE]00=0;NE]00300000030WKD0`9fe00P0`9fe00<000000<jMY03>WJ@0103>WJ@00`00
0000fZVU0=ZYY@070=ZYY@030000003[Yh@0jjN400D0jjN400<000000?VfN@0000000P3DN`000`00
0000oooo0?ooo`0S0?ooo`00;03oool00`00000002Rb00000002019Wf`040000000fL=`0=W3L0000
00@0DgOH00<0000006Uld`1YO=<00P1YO=<00`000000Nh7>07^1cP0407^1cP0300000029Q/T0RHK9
00D0RHK900<0000009F;aP2ERlH01`2ERlH00`000000Wi3409n@a00909n@a08000003@2gUK@00`00
0000`9fe0<2M]@0:0<2M]@8000000`3>WJ@00`000000fZVU0=ZYY@090=ZYY@030000003[Yh@0jjN4
00<0jjN400L000000?VfN@3i]WT0nKIi0000003DN`00000002D0oooo000]0?ooo`80000000@005_@
019Wf`0BIm/000000P0fL=`01@000000DgOH05=gf01CMmP0000000D0JGcC00<0000007^1cP1kPLh0
0`1kPLh00`000000RHK908V6b@0508V6b@030000002ERlH0UH_600L0UH_600<0000009n@a02OT<@0
2@2OT<@20:RE`P<000002@2gUK@00`000000`9fe0<2M]@0=0<2M]@030000003>WJ@0000000d0fZVU
00D000000>^WQ03[Yh@0jjN4000000040?VfN@030000003DN`00000002D0oooo000^0?ooo`800000
00H005_@019Wf`0BIm/0000003I`g000000405=gf0030000001YO=<0JGcC0080JGcC00<0000007^1
cP1kPLh00`1kPLh00`000000RHK908V6b@0508V6b@030000002ERlH0UH_600H0UH_600<0000009n@
a02OT<@02@2OT<@00`000000Z9G20:RE`P030:RE`P<000001@2gUK@00`000000`9fe0<2M]@0>0<2M
]@<000003P3JZJD00`000000jjN4000000060?VfN@030000003DN`00000002@0oooo000_0?ooo`08
00000000Fm0005_@0000000BIm/0000003I`g000000205=gf14000000P29Q/T00`000000UH_609F;
aP0709F;aP030000002OT<@0Wi3400P0Wi3400<000000:RE`P2XUL801`2XUL83000000030;NE]000
0000`9fe00l0`9fe00D000000<VV]P39Y[H0bJJf0000000>0=ZYY@030000003i]WT0nKIi00D0nKIi
00<000000=Ak00000000903oool00340oooo0`00Fm020000000303I`g000000000000080=HO/00D0
000004^8j@1;R>T0BhSY0000000505n9i0D0Kh_N1@00000609F;aP030000002OT<@0Wi3400P0Wi34
00<000000:RE`P2XUL802P2XUL83000000l0`9fe00<000000<VV]P39Y[H00`39Y[H00`000000fZVU
0=ZYY@0:0=ZYY@800000203i]WT2000002@0oooo000b0?ooo`80000000<005_@0000000000000P0M
Q^T303F7k0050000001;R>T0BhSY04^8j@000000101ORN@00`000000Kh_N06n;gP0406n;gP<0OHgH
1000000209F;aP030000002OT<@0Wi3400P0Wi3400<000000:RE`P2XUL802@2XUL8010000000/I_2
0;6K`P2aVl82000000`0`9fe00<000000<VV]P39Y[H01@39Y[H00`000000fZVU0=ZYY@080=ZYY@04
0000003V^:D0i[RU000000P0nKIi0P00000S0?ooo`00=03oool01000CKL0000000000009QN4201f6
j@040000000eQn`0=HO/000000<0BhSY00<0000005n9i01ORN@00P1ORN@00`000000Kh_N06n;gP03
06n;gP030000001mSMP0OHgH00@0OHgH1000000809n@a0030000002XUL80Z9G200T0Z9G200<00000
0;6K`P2aVl80102aVl800`000000`9fe0<2M]@070<2M]@8000002@39Y[H2000000L0fZVU00<00000
0>JhY@3V^:D00P3V^:D00`000000nKIi0?VfN@050?VfN@8000008`3oool003H0oooo0P00000200V5
h@807HKY00<0000003F7k00000000P1;R>T00`000000GhWT05n9i00205n9i0030000001_Rmh0Kh_N
00<0Kh_N00<0000007f=f01mSMP01@1mSMP308V@d`D000000P2OT<@00`000000Z9G20:RE`P090:RE
`P030000002aVl80/I_200H0/I_20P0000060<2M]@0300000039Y[H0bJJf00/0bJJf00<000000=ZY
Y@3JZJD00`3JZJD00`000000i[RU0>JhY@030>JhY@030000003i]WT0nKIi00H0nKIi00<000000?oo
o`3oool08@3oool003T0oooo0P00QMH01@09QN40000001f6j@0eQn`000000080BhSY00D0000005n9
i01ORN@0GhWT0000000506n;gP030000001mSMP0OHgH00@0OHgH00<0000008V@d`29T=<01P29T=<3
000000X0Z9G200<000000;6K`P2aVl802@2aVl82000000<0`9fe00<000000<VV]P39Y[H03@39Y[H0
1@000000fZVU0=ZYY@3JZJD0000000L0i[RU00<000000?VfN@3i]WT01@3i]WT00`000000oooo0?oo
o`0Q0?ooo`00?@3oool90000000305n9i0000000Kh_N00<0Kh_N00<0000007f=f01mSMP0101mSMP0
0`000000RI3C08V@d`0708V@d`80Ti?@0P0000070:RE`P030000002aVl80/I_200`0/I_200<00000
0<2M]@0000004@39Y[H00`000000fZVU000000090>JhY@030000003i]WT0nKIi00<0nKIi0P00000S
0?ooo`00@@3oool01@00OLh007kL01B0iP000000583V00D0000000<0Kh_N0000001mSMP0101mSMP0
0`000000RI3C08V@d`0708V@d`030000002CTm00Ti?@0080Ti?@0P0000040:RE`P030000002aVl80
/I_200d0/I_20`00000A0<VV]P8000002`3V^:D01@000000nKIi0?VfN@3i]WT000000080oL5N00<0
00000?ooo`3oool0803oool004@0oooo00@007kL01B0iP0DP>H0583V0`0^PnT3000000@0OHgH00<0
000008V@d`29T=<01P29T=<00`000000Ti?@09>Cd00509>Cd080000000<0Z9G20000002aVl803P2a
Vl801@000000^:;20;RR`P2hX/80000000l0bJJf00<000000=:a^00000002`3V^:D01@000000nKIi
0?VfN@3i]WT000000080oL5N00<000000?ooo`3oool0803oool004L0oooo00<0000001B0iP0^PnT0
0P0^PnT204J5j08000000P1mSMP00`000000RI3C08V@d`0508V@d`030000002CTm00Ti?@00L0Ti?@
0`00000=0;6K`P8000001@2hX/800`000000bJJf0<VV]P0:0<VV]P8000000`3B/KP00`000000i[RU
0>JhY@090>JhY@030000003i]WT0000000<0oL5N00<000000?ooo`3oool0803oool004T0oooo00@0
000002j3j@0^PnT000001016QNP3000000D0RI3C00<0000009>Cd02CTm001`2CTm0010000000WIK=
09fFc@2MU/d2000000X0/I_200<000000;RR`P2hX/801P2hX/82000000P0bJJf0P0000060=:a^003
0000003V^:D0i[RU00P0i[RU0P0000050?g1GP030000003oool0oooo01l0oooo001;0?ooo`80;X?Y
00@0000004J5j016QNP0AXGX0`1LQn<30000000308V@d`000000Ti?@00P0Ti?@00<0000009fFc@2M
U/d0102MU/d2000000L0/I_200<000000;RR`P2hX/802@2hX/800`000000bJJf0<VV]P040<VV]P03
0000003B/KP0d[6h00L0d[6h00<000000>JhY@3V^:D01P3V^:D00`000000llRT000000050?g1GP03
0000003oool0oooo01l0oooo001<0?ooo`0302j3j@000000AXGX0080AXGX00<0000005b7h`1LQn<0
0`1LQn<2000000P0Ti?@00<0000009fFc@2MU/d01`2MU/d00`000000/I_20;6K`P020;6K`P800000
3@2hX/8010000000bJJf0<VV]P39Y[H2000000/0d[6h00<000000>JhY@3V^:D0103V^:D01@000000
llRT0??8Y03cb:@0000000@0oL5N00<000000?ooo`3oool07`3oool004d0oooo0P0000000`16QNP0
000005b7h`0505b7h`80KHWM0`00000409>Cd0030000002MU/d0WIK=00T0WIK=0P0000000`2aVl80
00000;RR`P0?0;RR`P0300000039Y[H0000000d0d[6h00<000000>JhY@3V^:D00`3V^:D00`000000
llRT0??8Y0020??8Y0030000003m`Eh0oL5N0080oL5N00<000000?ooo`3oool07`3oool004l0oooo
00<003^Z000000000000101LQn<00`000000KHWM06f9g@0306f9g@80000000<0Ti?@0000002MU/d0
302MU/d300000100^:;20P00000?0=:a^0050000003V^:D0i[RU0>JhY@0000001P3cb:@00`000000
oL5N0?g1GP020?g1GP030000003oool0oooo01h0oooo001@0?ooo`8004g700@0000005b7h`1LQn<0
00001`1]RMd3000000/0WIK=0P0000030:FKb`030000002hX/80^:;200/0^:;20P0000020<2Y``03
0000003B/KP0d[6h00d0d[6h00<000000>JhY@0000001`3cb:@00`000000oL5N0?g1GP020?g1GP03
0000003oool0oooo01h0oooo001A0?ooo`8004g70P1LQn<00`000000KHWM06f9g@0406f9g@050000
001lRmL0O8_G07b;e`000000202MU/d2000000H0YI_;00<000000;RR`P2hX/80202hX/82000000D0
`:W300<000000=:a^03B/KP0303B/KP2000000T0llRT00D000000?g1GP3m`Eh0oL5N0000000P0?oo
o`00DP3oool2001=a`800000101]RMd2000000D0O8_G0P00000409fFc@8000002@2UVl/2000000L0
^:;200<000000<2Y``30ZL<01P30ZL<00`000000d[6h0=:a^0090=:a^080000000<0g;fj0000003c
b:@0203cb:@00`000000oL5N0?g1GP0200000200oooo001C0?ooo`030000000;GMH02egF00800000
00<0KHWM0000001lRmL0201lRmL010000000WIK=00000000000=0:FKb`030000002hX/80^:;20080
^:;20P00000:0<2Y``030000003B/KP0d[6h00L0d[6h00<000000=bm^P3L_KX00P3L_KX00`000000
llRT0??8Y0070??8Y0040000003m`Eh0000000000200oooo001D0?ooo`030000000;GMH02egF00<0
00002@1lRmL3000000l0YI_;00@000000;RR`P00000000003@30ZL<00`000000d[6h0=:a^0040=:a
^08000001P3L_KX00`000000llRT0??8Y0060??8Y0040000003m`Eh0000000000200oooo001B0?oo
o`D000000`0cJMP00`000000O8_G07b;e`0307b;e`<000000`28S]800`000000YI_;0:FKb`0<0:FK
b`<000003`30ZL<010000000d[6h0=:a^03B/KP2000000P0g;fj00<000000??8Y03cb:@01`3cb:@0
0`000000eZlV0000000P0?ooo`00C`3oool40000000303d06@000000000000D0<fWH00<0000007b;
e`0000000P00000708R>dP030000002UVl/0YI_;00P0YI_;0`0000030:bObP0300000030ZL<0`:W3
00d0`:W300<000000=:a^00000002`3L_KX00`000000llRT0??8Y0050??8Y08000000P3F[bH00`00
0000oooo0?ooo`0M0?ooo`00CP3oool9000000<0<fWH1000000:08R>dP030000002UVl/0YI_;00@0
YI_;0`0000070:bObP0300000030ZL<0`:W300`0`:W30P00000<0=bm^P030000003cb:@0llRT00@0
llRT00<000000?cKWP0000000P3F[bH00`000000oooo0?ooo`0M0?ooo`00B`3oool40000000305@0
3@000000000000P00000101BLM@00`000000R8kB08R>dP0808R>dP030000002UVl/0YI_;00<00000
2`2/WlX00`000000`:W30<2Y``080<2Y``<0000000<0ak740000003L_KX0303L_KX00`000000llRT
0??8Y0020??8Y0040000003lfih0o=^N00000080eZlV00<000000?ooo`3oool07@3oool004H0oooo
4@0000000`0@>[P00000059ae005059ae00300000028S]80R8kB00H0R8kB1000000?0:bObP030000
0030ZL<0`:W300@0`:W30`0000050<Naa0030000003L_KX0g;fj00/0g;fj00@000000??8Y03cb:@0
0000103lfih00`000000eZlV0000000O0?ooo`00A@3oool010000000VO;V09WbiP0000020;Sik004
0000003;m^/0boK[0<_fj`T0000000<043Zh0000001BLM@01@1BLM@00`000000R8kB08R>dP050000
00@0Ti7?00<000000:bObP2/WlX03@2/WlX00`000000`:W30<2Y``03000000T0ak7400<000000=bm
^P3L_KX02P3L_KX00`000000llRT000000050?cKWP030000003F[bH0000001l0oooo00140?ooo`04
0000002Il^H0VO;V000000<0^?W/00<000000<_fj`3;m^/00P3;m^/900000003010j^00000000000
00L000002P2CTLl00`000000[9o:0:bObP0;0:bObP@000003@37/L@00`000000g;fj0=bm^P090=bm
^P8000001P3lfih00`000000eZlV0000000O0?ooo`00@`3oool01@000000VO;V09WbiP2Il^H00000
00<0^?W/00<000000<_fj`3;m^/00P3;m^/00`000000dngV091@OP030000000301HFT0000000@52k
008000001`1YN<l00`000000Ti7?09>Ac`0909>Ac`030000002/WlX0[9o:00D0[9o:1@0000020;>U
b@0300000037/L@0ak7400`0ak7400<000000=bm^P3L_KX01P3L_KX3000000030>K=_P000000o=^N
00D0o=^N00<000000=J_9P0000007`3oool00480oooo00<0000009WbiP2Il^H00P2Il^H01@000000
^?W/0;Sik02hnN`000000080boK[1P0000000`2UGW/000000000000200000080@52k00<0000006Uh
c`1YN<l01@1YN<l00`000000Ti7?09>Ac`0909>Ac`030000002/WlX0[9o:00@00000202cYLT00`00
0000ak740<Naa00<0<Naa0030000003L_KX0g;fj00<0g;fj0P0000040>K=_P030000003lfih0o=^N
00@0o=^N00<000000=J_9P0000007`3oool00440oooo3@0000030=3Cf`030000003>b]H0c/[F0080
000000@0BSNH00000000000000000P10D;/600000080JGS?00<0000009>Ac`2CTLl0102CTLl70000
00d0/jG900<000000<Naa037/L@03037/L@00`000000g;fj00000002000000L0i/fn00<000000?cK
WP3lfih0103lfih00`000000oooo0?ooo`0N0?ooo`00@@3oool00`000000cnOW0<oWi`020<oWi`03
0000003AgN40dMgQ0080dMgQ00<000000=3Cf`3@dm/0103@dm/020000000c/[F0000001lEi`00000
04XgV0000000H5ji1000000407]mbPT000001@2LUL`00`000000/jG90;>Ub@0=0;>Ub@0300000037
/L@0ak7400/0ak740P00000:0>K=_P030000003lfih0o=^N00@0o=^N00<000000?ooo`3oool07P3o
ool00400oooo00<000000<oWi`3?inL00`3?inL00`000000dMgQ0=7Mh@030=7Mh@030000003@dm/0
d=?K00@0d=?K00<000000<k:eP0000000P0000000`1:=iP0000000000002061N^@8000001P1kOLX0
0`000000W9G<09bEc00909bEc0030000002cYLT0/jG900`0/jG900<000000<Naa037/L@02037/L@3
000000030<nka`000000i/fn00T0i/fn00<000000?cKWP3lfih0103lfih00`000000oooo0?ooo`0N
0?ooo`00@03oool00`000000cnOW0<oWi`030<oWi`030000003AgN40dMgQ00<0dMgQ00<000000=3C
f`3@dm/0103@dm/00`000000c/[F0<k:eP040000000307MZ]`000000H5ji0080H5ji0`00000407]m
bP030000002LUL`0W9G<00T0W9G<00<000000;>Ub@2cYLT0302cYLT00`000000ak740<Naa0040<Na
a0<000001@3?^lL00`000000i/fn0>K=_P080>K=_P030000003lfih0o=^N0080o=^N0P00000P0?oo
o`00@03oool00`000000cnOW0<oWi`030<oWi`030000003AgN40dMgQ00<0dMgQ00<000000=3Cf`3@
dm/01@3@dm/010000000c/[F0<k:eP1lEi`30000000507MZ]`0000000000061N^@0000000P29PlH3
00000080Ngg:00<0000009bEc02LUL`02@2LUL`00`000000/jG90;>Ub@0<0;>Ub@0300000037/L@0
ak7400<00000203?^lL00`000000i/fn0>K=_P080>K=_P070000003lfih0o=^N0?cKWP000000m^N9
0000000P0?ooo`00?`3oool00`000000cnOW0<oWi`030<oWi`030000003AgN40dMgQ00D0dMgQ00<0
00000=3Cf`3@dm/0103@dm/00`000000c/[F0<k:eP0500000080MfZg0`00000408V3aP@000002`2L
UL`00`000000/jG90;>Ub@050;>Ub@T00000303?^lL00`000000i/fn0>K=_P070>K=_P040000003l
fih0o=^N00000080m^N900<000000?ooo`3oool07P3oool003l0oooo00<000000<oWi`3?inL00`3?
inL00`000000dMgQ0=7Mh@050=7Mh@030000003@dm/0d=?K00D0d=?K00<000000<k:eP3>b]H01P00
000207MZ]`0300000029PlH0RH?600D0RH?6500000070;Z[bP030000003?^lL0ck_700/0ck_700<0
00000>K=_P3VcKh0203VcKh2000000<0m^N900<000000?ooo`3oool07P3oool003l0oooo00<00000
0<oWi`3?inL00`3?inL00`000000dMgQ0=7Mh@050=7Mh@030000003@dm/0d=?K0080d=?K1P000000
1`34/<L0O5NL0000002hOI<0000008Uc]00000000P1gJ[L3000000D0RH?600<000000:BIbP2TVLX0
2@2TVLX00`000000^Z_:0;Z[bP0<0;Z[bP030000003?^lL0ck_700X0ck_700<000000>K=_P3VcKh0
1`3VcKh2000000@0m^N900<000000?ooo`3oool07P3oool003h0oooo1@0000020<oWi`030000003A
gN40dMgQ0080dMgQ200000040<Vhb@0400000034/<L0a;370<B`a`80000000<0^7fC00000029Lk@0
0`00000209J8``<000000`29PlH00`000000Y9W:0:BIbP090:BIbP030000002jZlX0^Z_:00/0^Z_:
00<000000<nka`3?^lL02`3?^lL00`000000i/fn0>K=_P030>K=_P<0000000<0k]k10000003fihT0
0P3fihT00`000000oooo0?ooo`0O0?ooo`00?P3oool00`000000e<_A0=C;d@020=C;d@L00000103?
`Ld00`000000bKS90<Vhb@060<Vhb@0500000034/<L0a;370000002GIYL00`00000208Uc]0800000
102FR<<30000000308V3aP000000Y9W:00X0Y9W:00<000000;Z[bP2jZlX02`2jZlX00`000000ck_7
0<nka`0:0<nka`030000003VcKh0i/fn00<00000103^g/401@000000m^N90?KWR@3fihT000000240
oooo000n0?ooo`030000003Dbm40e<_A00@0e<_A00<000000<o1c@3?`Ld01`3?`Ld00`000000bKS9
0<Vhb@060<Vhb@0500000034/<L0a;370000002GIYL01000000208Uc]0030000002FR<<0UXS300@0
UXS30`00000;0:BIbP030000002jZlX0^Z_:00/0^Z_:00<000000<nka`3?^lL01`3?^lL5000000L0
k]k100D000000?KWR@3fihT0m^N90000000Q0?ooo`00?P3oool00`000000e<_A0=C;d@040=C;d@03
0000003?`Ld0cl7=00L0cl7=00<000000<Vhb@39^<T01`39^<T00`000000a;370<B`a`0400000004
09Mk/P000000RG>d08Uc]08000001`2FR<<8000000@0Y9W:00<000000;Z[bP2jZlX02P2jZlX01000
0000ck_70<nka`3?^lL6000000<0e/K;00<000000>kN`@3^g/401P3^g/401@000000m^N90?KWR@3f
ihT000000240oooo000n0?ooo`030000003Dbm40e<_A00D0e<_A00<000000<o1c@3?`Ld01P3?`Ld0
0`000000bKS90<Vhb@080<Vhb@0300000034/<L0a;370080000000L0^7fC0000002GNk80000008Uc
]0000000X8k100<00000102FR<<00`000000[9k90:bNb@050:bNbAD000002@3Fa//00`000000k]k1
0>kN`@060>kN`@050000003fihT0m^N90?KWR@0000008@3oool003h0oooo00<000000=C;d@3Dbm40
1@3Dbm400`000000cl7=0<o1c@070<o1c@0300000039^<T0bKS900L0bKS900@000000<B`a`34/<L0
a;3710000000102GNk8000000000000000030:2>`@8000000`2FR<<00`000000[9k90:bNb@090:bN
b@0300000030//`0`;;<00X0`;;<00<000000=K6b`3Fa//02P3Fa//00`000000k]k10>kN`@050>kN
`@050000003fihT0m^N90?KWR@0000008@3oool003d0oooo00<000000=C;d@3Dbm401P3Dbm400`00
0000cl7=0<o1c@070<o1c@0300000039^<T0bKS900P0bKS900H000000<B`a`34/<L0a;370000002h
OI<200000080Ug^b00<000000:2>`@2PS/400`2PS/4200000080UXS300<000000:bNb@2/W/T02@2/
W/T00`000000`;;<0<2bc00:0<2bc0030000003Fa//0e/K;00T0e/K;00<000000>kN`@3^g/401@3^
g/4010000000m^N90?KWR@00000R0?ooo`00?@3oool00`000000e<_A0=C;d@060=C;d@030000003?
`Ld0cl7=00P0cl7=00<000000<Vhb@39^<T02039^<T00`000000a;370<B`a`02000000050;QmT`00
000000000000002GNk800P0000050:2>`@<000002`2/W/T00`000000`;;<0<2bc00:0<2bc0030000
003Fa//0e/K;00T0e/K;00<000000>kN`@3^g/401@3^g/4010000000m^N900000000000R0?ooo`00
?@3oool00`000000e<_A0=C;d@060=C;d@030000003?`Ld0cl7=00P0cl7=00<000000<Vhb@39^<T0
1P39^<T5000000040;ZL^@000000000000000080Xh>a0P0000000`2YTkl00000000000060:2>`@<0
00002@2/W/T00`000000`;;<0<2bc0090<2bc0030000003Fa//0e/K;00T0e/K;00<000000>kN`@3^
g/401@3^g/42000000030;g>E@000000oooo0240oooo000m0?ooo`030000003Dbm40e<_A00L0e<_A
00<000000<o1c@3?`Ld01`3?`Ld010000000bKS90<Vhb@39^<T5000000<0`J>j00@000000;ZL^@2j
W;T0^Ybi0`0000020:>3/@8000000P2YTkl2000000@0X8k100<000000;>Tb02cY<P01@0000040:bN
b@0300000030//`0`;;<00X0`;;<00<000000=K6b`3Fa//0203Fa//00`000000k]k10>kN`@040>kN
`@8000000P2mcUDS0?ooo`00?@3oool00`000000e<_A0=C;d@070=C;d@030000003?`Ld0cl7=00<0
cl7=200000090<6S^P040000002jW;T0^Ybi0;ZL^@<000000P2SPk400`000000ZI>o0:VC_`020:VC
_`8000000`2PS/400`000000/jC80;>Tb0040;>Tb0D000003030//`00`000000e/K;0=K6b`090=K6
b`030000003^g/40k]k100<0000000@0lO710000002mcUD000008`3oool003d0oooo400000050<V[
_00300000031XkX0`J>j00X0`J>j00<000000;ZL^@2jW;T0100000020:>3/@800000102YTkl20000
00030:2>`@000000/jC800T0/jC82@0000040<2bc0030000003Fa//0e/K;00T0e/K;0`0000040?7a
`@030000002mcUD0oooo02<0oooo000m0?ooo`030000003@];h0d;Bn00L0d;Bn00<000000<V[_039
Zk`02@39Zk`00`000000`J>j0<6S^P090<6S^P060000002jW;T0^Ybi0;ZL^@000000hJ2<0P000000
102SPk4000000;:J_`0000050:VC_`8000002`2cY<P00`000000a[[>0<JjcP050<JjcQ4000001@3a
lL400`000000_LiE0000000T0?ooo`00?@3oool00`000000d;Bn0=2d_P070=2d_P0300000039Zk`0
bJ^l00T0bJ^l00<000000<6S^P31XkX02P31XkX010000000^Ybi0;ZL^@2jW;T2000000050:f:/@00
0000Xh>a0000002bV[l00P0000050:VC_`030000002cY<P0/jC800P0/jC800<000000<JjcP36^/h0
2P36^/h00`000000g=?@0=cCd0080=cCd0030000003alL40lO7100<0lO7100<000000;g>E@000000
903oool003d0oooo00<000000=2d_P3@];h0203@];h00`000000bJ^l0<V[_0090<V[_00300000031
XkX0`J>j00X0`J>j00<000000;ZL^@2jW;T00`0000000`2]R[400000000000030;:J_`030000002Y
Tkl0ZI>o0080ZI>o00<000000;ZZb@0000000P0000070;>Tb00300000036^/h0a[[>00T0a[[>00<0
00000=cCd03Ldm00203Ldm000`000000lO710?7a`@030?7a`@030000002mcUD0oooo02@0oooo000n
0?ooo`030000003@];h0d;Bn00L0d;Bn00<000000<V[_039Zk`02@39Zk`00`000000`J>j0<6S^P0:
0<6S^P090000002jW;T0^Ybi0;ZL^@000000]i:a0000002]R[40000000@0/YZo0P0000030:VC_`04
0000002jZ/T0^Z[90;ZZb@<00000102cY<P00`000000a[[>0<JjcP090<JjcP030000003Ldm00g=?@
00P0g=?@00<000000?7a`@3alL400`3alL42000002D0oooo000n0?ooo`030000003@];h0d;Bn00L0
d;Bn00<000000<V[_039Zk`02P39Zk`00`000000`J>j0<6S^P0:0<6S^P030000002jW;T0^Ybi0080
000000@0]i:a0000002]R[4000001@2bV[l010000000ZI>o0:VC_`0000060;ZZb@8000000P2cY<P0
0`000000a[[>0<JjcP090<JjcP030000003Ldm00g=?@00P0g=?@00<000000?7a`@3alL400`3alL40
0`000000oooo0?ooo`0T0?ooo`00?P3oool00`000000d;Bn0=2d_P080=2d_P0300000039Zk`0bJ^l
00T0bJ^l00<000000<6S^P31XkX02P31XkX010000000^Ybi0;ZL^@2jW;T3000000040:f:/@000000
^Z6o000000@0/YZo0`0000080;ZZb@@000002`36^/h00`000000g=?@0=cCd0060=cCd0030000003a
lL40lO7100<0lO710P00000V0?ooo`00?P3oool00`000000d;Bn0=2d_P080=2d_P0300000039Zk`0
bJ^l00X0bJ^l00<000000<6S^P31XkX02P31XkX00`000000^Ybi0;ZL^@02000000060;NB/@000000
[HZa0000002jXKl000001@2bV[l2000000X0^Z[90`0000090<JjcP030000003Ldm00g=?@00H0g=?@
00<000000?7a`@3alL400`3alL42000002H0oooo000n0?ooo`030000003@];h0d;Bn00P0d;Bn00<0
00000<V[_039Zk`02P39Zk`00`000000`J>j0<6S^P090<6S^P@0000000@0[hR/000000000000]i:a
0P0000020;ZQ_`030000002bV[l0/YZo00<0/YZo00<000000;ZZb@2jZ/T0202jZ/T00`000000c<?A
0<c3d@04000000D0a[[>00<000000=cCd03Ldm001P3Ldm000`000000lO710?7a`@020?7a`@800000
9`3oool003h0oooo00<000000=2d_P3@];h02@3@];h00`000000bJ^l0<V[_00:0<V[_00300000031
XkX0`J>j00@0`J>j100000020;R?[0040000002_R:`0[hR/0:n8[080000000<0]i:a0000002jXKl0
0P2jXKl2000000<0/YZo00@000000<6ab`00000000001`2jZ/T00`000000c<?A0<c3d@040<c3d@@0
000000<0a[[>0000003Ldm001`3Ldm000`000000lO7100000002000000030>?k]P000000oooo02H0
oooo000n0?ooo`030000003@];h0d;Bn00T0d;Bn00<000000<V[_039Zk`02P39Zk`00`000000`J>j
0<6S^P04000000L0^8n/00<000000:n8[02_R:`00P0000020;NB/@030000002jXKl0^Z6o0080^Z6o
00@000000;:J_`2bV[l000000`31/L/2000000D0^Z[900<000000<c3d@3<`m40203<`m4<000000@0
ho^f:03oool003l0oooo00<000000=2d_P3@];h0203@];h00`000000bJ^l0<V[_0080<V[_0D00000
302hSj`00`000000[hR/0:n8[002000000030;NB/@000000^Z6o00@0^Z6o00<000000;:J_`000000
1@31/L/2000000@0^Z[900<000000<c3d@3<`m40203<`m400`000000hN;E0>7Re@060>7Re@030000
003SnkH0ho^f0080ho^f00<000000?ooo`3oool09P3oool003l0oooo00<000000=2d_P3@];h02@3@
];h00`000000bJ^l0<V[_007000000<0`IN/00<000000;R?[02hSj`02`2hSj`01@000000[hR/0:n8
[0000000`I^a00<000001@2jXKl00`000000/YZo000000060<6ab`8000000P2jZ/T00`000000c<?A
0<c3d@080<c3d@030000003Qh]D0hN;E00H0hN;E00D000000>?k]P3SnkH0ho^f0000000Y0?ooo`00
?`3oool?000000/0`IN/00<000000;R?[02hSj`02`2hSj`00`000000[hR/0:n8[002000000030;NB
/@000000000000D0^Z6o0P0000080<6ab`<000002P3<`m400`000000hN;E0>7Re@050>7Re@030000
003SnkH0ho^f0080ho^f00<000000?ooo`3oool09`3oool003l0oooo00<000000<ZP[@3:X:d02@3:
X:d00`000000`IN/0<6G[00;0<6G[0030000002hSj`0^8n/00`0^8n/00<000000:n8[00000000`00
00000`32Z<0000000;ZQ_`040;ZQ_`0300000031/L/0`K7;00P0`K7;0P0000090<c3d@030000003Q
h]D0hN;E00D0hN;E00<000000>?k]P3SnkH00P3SnkH00`000000oooo0?ooo`0W0?ooo`00?`3oool0
0`000000bZ2]0<ZP[@0:0<ZP[@0300000031Uj`0`IN/00/0`IN/00<000000;R?[02hSj`02`2hSj`0
1P000000[hR/000000000000`I^a00000080`ZS000<000000;ZQ_`2jXKl00P2jXKl00`000000akW=
000000080<6ab`030000003AcMH00000008000001@3<`m400`000000hN;E0>7Re@060>7Re@050000
003SnkH0ho^f0>?k]P000000:P3oool00400oooo00<000000<ZP[@3:X:d02@3:X:d00`000000`IN/
0<6G[00;0<6G[0030000002hSj`0^8n/00`0^8n/00<000000:n8[00000000P0000030<:X`0050000
002jXKl0^Z6o0;ZQ_`0000000P37^Ld2000000H0`K7;00<000000=7=eP3AcMH00P3AcMH2000000<0
c<?A00<000000>7Re@3Qh]D01P3Qh]D01@000000ho^f0>?k]P3SnkH0000002X0oooo00100?ooo`03
0000003:X:d0bZ2]00X0bZ2]00<000000<6G[031Uj`02`31Uj`00`000000^8n/0;R?[00;0;R?[003
0000002_R:`0000000<000000`32Z<0010000000^Z6o0;ZQ_`0000040<Nic@0300000031/L/0`K7;
00<0`K7;00<000000=7=eP3AcMH0103AcMH4000000P0hN;E00@000000>?k]P0000000000:`3oool0
0400oooo00<000000<ZP[@3:X:d02P3:X:d00`000000`IN/0<6G[00<0<6G[0030000002hSj`0^8n/
00/0^8n/0P000000103:Y;8000000000000000030<:X`0030000002jXKl0000000D0akW=00D00000
0<6ab`31/L/0`K7;0000000:0=7=ePD000000`3Qh]D01@000000ho^f0000002^j940000002/0oooo
00110?ooo`030000003:X:d0bZ2]00X0bZ2]00<000000<6G[031Uj`02`31Uj`00`000000^8n/0;R?
[00:0;R?[0H0000000<0bK7200000032Z<000P32Z<02000000H0akW=0P0000000`31/L/000000=7=
eP090=7=eP030000003Ql]X0hO;J0080hO;J100000030:kXTB`0oooo00110?ooo`030000003:X:d0
bZ2]00X0bZ2]00<000000<6G[031Uj`03031Uj`00`000000^8n/0;R?[0040;R?[0D000000P2]NY`2
000000040<ZT/P000000bK72000000@0`ZS000<000000<Nic@37^Ld01P37^Ld2000000X0dLgF00<0
00000>7bfP3Ql]X01@3Ql]X00`000000[^RA0:kXT@0]0?ooo`00@@3oool00`000000bZ2]0<ZP[@0;
0<ZP[@0300000031Uj`0`IN/00/0`IN/00<000000;R?[02hSj`0100000080:ejW0030000003:Y;80
00000080bK7200L000000<:X`032Z<00`ZS00000003=`]00000000L0akW=00<000000=7=eP3AcMH0
1`3AcMH00`000000hO;J0>7bfP050>7bfP030000002^j940[^RA02h0oooo00120?ooo`030000003:
X:d0bZ2]00X0bZ2]00<000000<6G[031Uj`02P31Uj`4000000`0[GZL100000020<Va`P0400000032
Z<00`ZS000000080cL;@00<000000<Nic@37^Ld01037^Ld010000000eMSK0000000000060=7=eP03
0000003Ql]X0hO;J00D0hO;J00<000000:kXT@3oool0;P3oool00480oooo00<000000<ZP[@3:X:d0
2`3:X:d00`000000`IN/0<6G[0040<6G[0D000000P2hPi`00`000000[GZL0:ejW00;0:ejW0@00000
0P39/L8010000000`ZS00<:X`00000030<g2d00300000037^Ld0akW=00<0akW=00@000000=GHf`3E
f=/0eMSK0P0000040=7=eP030000003Ql]X0hO;J00@0hO;J00<000000:kXT@000000;`3oool00480
oooo00<000000<ZP[@3:X:d02`3:X:d00`000000`IN/0<6G[004000000P0^8>L00<000000:ejW02]
NY`02`2]NY`3000000<0bK7200<000000<:X`0000000103=`]000`000000akW=0<Nic@020<Nic@03
0000003Ef=/0eMSK00<0eMSK00D000000=7=eP3AcMH0dLgF000000050>7bfP030000002^j9400000
0300oooo00130?ooo`030000003:X:d0bZ2]00@0bZ2]2@00000=0;R3W0030000002]NY`0[GZL00X0
[GZL0P0000000`3A^lD000000<Va`P020<Va`P8000001@3=`]0010000000akW=0<Nic@0000070=GH
f`<000001P3Ql]X00`000000[^RA0?ooo`0`0?ooo`00@`3oool7000000L0`hbL00<000000;R3W02h
Pi`0302hPi`00`000000[GZL0:ejW00:0:ejW080000000<0dK_500000039/L800`39/L800`000000
cL;@0<g2d0040<g2d00300000037^Ld0000000T0eMSK0P0000040>7bfP030000002^j940oooo0340
oooo00130?ooo`0300000033S9`0`hbL00`0`hbL00<000000;R3W02hPi`0302hPi`00`000000[GZL
0:ejW0090:ejW08000000P3A^lD01@000000bK720<Va`P39/L80000000L0cL;@0P0000090=GHf`03
0000003FoMX000000080000000<0hO;J0000003oool0<P3oool004@0oooo00<000000<><W033S9`0
2`33S9`00`000000^8>L0;R3W00=0;R3W0030000002]NY`0[GZL00P0[GZL0`0000001`3A^lD00000
0<Va`P39/L8000000=;<e00000001`3=`]000`000000eMSK0=GHf`060=GHf`030000003FoMX0e_gJ
00<0e_gJ0P00000c0?ooo`00A03oool00`000000`hbL0<><W00<0<><W0030000002hPi`0^8>L00`0
^8>L00<000000:ejW02]NY`02@2]NY`200000080dK_500<000000<Va`P0000000P3Bc=@00`000000
cL;@0<g2d0040<g2d08000001`3Ef=/00`000000e_gJ0=KmfP030=KmfP030000003oool0oooo0380
oooo00150?ooo`0300000033S9`0`hbL00/0`hbL00<000000;R3W02hPi`03@2hPi`00`000000[GZL
0:ejW0060:ejW0@000000P3A^lD00`000000bK72000000020=;<e0030000003=`]00cL;@00<0cL;@
00@000000=KUh@3FiN4000001@3Ef=/00`000000e_gJ0=KmfP030=KmfP030000003oool0oooo03<0
oooo00150?ooo`0300000033S9`0`hbL00`0`hbL00<000000;R3W02hPi`0302hPi`00`000000[GZL
0:ejW0030:ejW0<000000P2NGhH0103Ha/P000000=6ka@3A^lD2000000@0d/cD00<000000<g2d03=
`]000P3=`]001@000000e^GQ0=KUh@3FiN40000000@0eMSK00<000000=KmfP3FoMX00P3FoMX00`00
0000oooo0?ooo`0d0?ooo`00AP3oool00`000000`hbL0<><W00<0<><W0030000002hPi`0^8>L00`0
^8>L00<000000:ejW00000000P00000509iOQP030000003Ha/P000000080dK_500<000000=;<e03B
c=@00`3Bc=@010000000cL;@0<g2d00000050=KUh@040000003Ef=/0eMSK000000@0e_gJ00<00000
0?ooo`3oool0=@3oool004H0oooo00<000000<><W033S9`03033S9`00`000000^8>L0;R3W00;0;R3
W0<00000202NGhH00`000000f<K8000000020=6ka@030000003Bc=@0d/cD00<0d/cD00@000000<g2
d03=`]0000001P3FiN400`000000eMSK000000040=KmfP030000003oool0oooo03D0oooo00170?oo
o`0300000033S9`0`hbL00`0`hbL00<000000;R3W02hPi`01@2hPi`500000080ZfZ700<0000009iO
QP2NGhH01P2NGhH01`000000f<K80000003A^lD000000=KHfP0000001@3Bc=@00`000000cL;@0000
00070=KUh@8000000`3FoMX00`000000oooo0?ooo`0f0?ooo`00A`3oool00`000000`hbL0<><W00<
0<><W0030000002hPi`0^8>L00D00000202[JXL00`000000WUn609iOQP0509iOQP070000003Ha/P0
00000=6ka@000000e]SJ000000060=;<e0030000003FiN40e^GQ00H0e^GQ00D000000;Slc`000000
e_gJ0000000i0?ooo`00B03oool00`000000`hbL0<><W0090<><W0D000003P2[JXL00`000000WUn6
09iOQP0409iOQP030000003Ha/P0f<K8008000000P3Ff=X00`000000d/cD0=;<e0030=;<e0030000
003FiN40e^GQ00D0e^GQ00D000000;Slc`2ho<l0^?c?0000000j0?ooo`00B03oool00`000000`hbL
0<><W0020<><W0L000000`2gM8L00`000000ZfZ70:]ZQ`0>0:]ZQ`030000002NGhH0WUn600<0WUn6
00@000000=S6b03Ha/P000000`3Ff=X00`000000d/cD0=;<e0020=;<e0030000003ClNH0000000D0
e^GQ00@000000;Slc`2ho<l0^?c??03oool004T0oooo1000000;0;MdQ`030000002[JXL0ZfZ700h0
ZfZ700<0000009iOQP2NGhH00P2NGhH010000000f<K80=S6b00000030=KHfP050000003Bc=@0d/cD
0=;<e00000000P3ClNH00`000000e^GQ0=KUh@020=KUh@040000002ho<l0^?c?000003d0oooo0019
0?ooo`030000002gM8L0]gB700d0]gB700<000000:]ZQ`2[JXL03@2[JXL00`000000WUn609iOQP02
09iOQP040000003Ha/P00000000000@0e]SJ00@000000=;<e03Bc=@000000`3ClNH010000000e^GQ
0=KUh@0000020;Slc`030000003oool0oooo03`0oooo001:0?ooo`030000002gM8L0]gB700`0]gB7
00<000000:]ZQ`2[JXL03P2[JXL01P000000WUn609iOQP2NGhH000000=S6b0800000103Ff=X00`00
0000d/cD000000040=?aiP030000003FiN4000000080^?c?00<000000?ooo`3oool0?@3oool004/0
oooo00<000000;MdQ`2gM8L0302gM8L00`000000ZfZ70:]ZQ`0>0:]ZQ`030000002NGhH000000080
000000<0f>GO0000003Ff=X0103Ff=X00`000000do7V0=?aiP040=?aiP040000002ho<l0^?c?0000
0400oooo001<0?ooo`030000002gM8L0]gB700`0]gB700<000000:]ZQ`2[JXL0302[JXL300000005
084bH@00000000000=SUg`0000001@3Ff=X00`000000do7V0=?aiP020=?aiP0500000020h[000000
0;Slc`000000@@3oool004`0oooo00<000000;MdQ`2gM8L03@2gM8L00`000000ZfZ70:]ZQ`080:]Z
Q`<000000`2DA6H2000000<0f>GO00@000000=KHfP3Ff=X0e]SJ0P0000030=?aiP0500000020h[00
P>:`083R/0000000@P3oool004d0oooo00<000000;MdQ`2gM8L0302gM8L00`000000ZfZ70:]ZQ`04
0:]ZQ`@000001`2DA6H01@000000f>GO0=SUg`3HiMl000000080e]SJ00<000000<Ojj@0000000P3C
lNH010000000P>:`083R/020h[140?ooo`00CP3oool00`000000]gB70;MdQ`0<0;MdQ`030000002[
JXL0ZfZ700<000002`2DA6H01`000000f>GO0=SUg`3HiMl000000=KHfP0000000P37n^T00`000000
do7V00000002083R/4H0oooo001>0?ooo`030000002gM8L0]gB700/0]gB71000000=09A4IP030000
003HiMl0f>GO0080f>GO0P0000030<Ojj@80000000<0P>:`0000003oool0AP3oool004l0oooo00<0
00000;MdQ`2gM8L01@2gM8L5000000@0YE9X00<0000009A4IP2DA6H02P2DA6H00`000000f>GO0=SU
g`020=SUg`0300000037n^T0ao[Y0080ao[Y0P0000190?ooo`00D03oool00`000000]gB70;MdQ`04
000000X0YE9X00<0000009A4IP2DA6H02@2DA6H010000000f>GO0=SUg`3HiMl200000080ao[Y0P00
001;0?ooo`00D@3oool2000000l0YE9X00<0000009A4IP2DA6H01P2DA6H300000080f>GO0P000002
0<Ojj@800000C03oool005<0oooo00<000000:EBJ02UDVP03@2UDVP00`000000U4AV09A4IP0309A4
IP8000000P1O024010000000f>GO0000002_n^D3000004h0oooo001D0?ooo`030000002UDVP0YE9X
00d0YE9X00<0000009A4IP0000000P00000305l08@040000003HiMl000000:oji@<00000C`3oool0
05D0oooo00<000000:EBJ02UDVP0302UDVP3000000D0G`0Q0P0000020:oji@030000003oool0oooo
04l0oooo001F0?ooo`030000002UDVP0YE9X00P0YE9X0`00000307/B;P8000000`1O024010000000
[o[U0:oji@00001B0?ooo`00E`3oool00`000000YE9X0:EBJ0040:EBJ0<00000201k4Rh300000003
0:oji@000000oooo05<0oooo001H0?ooo`030000002UDVP0YE9X00<00000301k4Rh3000005D0oooo
001I0?ooo`800000301k4Rh4000005L0oooo001K0?ooo`<000001P1k4Rh300000003008000000000
oooo05P0oooo001N0?ooo`80000000<0Na8^0000000000001@00001J0?ooo`00H03oool4000005h0
oooo00320?ooo`00`P3oool00<80oooo00320?ooo`00`P3oool00<80oooo00320?ooo`00`P3oool0
0<80oooo00320?ooo`00`P3oool00<80oooo00320?ooo`00`P3oool00<80oooo00320?ooo`00`P3o
ool00<80oooo00320?ooo`00`P3oool00<80oooo00320?ooo`00`P3oool00<80oooo00320?ooo`00
`P3oool00<80oooo0000\
\>"],
  ImageRangeCache->{{{0, 193.125}, {286.938, 0}} -> {0.154208, -0.000827237, \
0.00346087, 0.00346087}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Mirror Definition", "Subsubsection"],

Cell[TextData[{
  "The shape function is brought into the format ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  " uses."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
mirrorfunction = With[{body = 
\tChop[
\t\tseashell[
\t\t\thelix[1, 0.6]
\t\t][0.1][tt, theta]
\t]},
\tWith[{
\t\tf1 = body[[1]],
\t\tf2 = body[[2]],
\t\tf3 = body[[3]]
\t},
\t\tFunction[{tt, theta}, {f1, f2, f3}]
\t]
]/.{tt$ -> tt, theta$ -> theta}\
\>", "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \(Function[{tt, 
        theta}, {Cos[tt] + 
          0.1`\ tt\ \((\(1.1661903789690602`\ Cos[theta]\ \
Cos[tt]\)\/\@\(1.3599999999999999`\ Cos[tt]\^2 + 1.3599999999999999`\ Sin[tt]\
\^2\) + \(0.6`\ Sin[theta]\ Sin[tt]\)\/\@\(1.3599999999999999`\ Cos[tt]\^2 + \
1.3599999999999999`\ Sin[tt]\^2\))\), 
        Sin[tt] + 
          0.1`\ tt\ \((\(-\(\(0.6`\ Cos[tt]\ Sin[
                          theta]\)\/\@\(1.3599999999999999`\ Cos[tt]\^2 + \
1.3599999999999999`\ Sin[tt]\^2\)\)\) + \(1.1661903789690602`\ Cos[theta]\ \
Sin[tt]\)\/\@\(1.3599999999999999`\ Cos[tt]\^2 + 1.3599999999999999`\ Sin[tt]\
\^2\))\), 
        0.6`\ tt + \(0.1`\ tt\ Sin[theta]\)\/\@\(1.3599999999999999`\ Cos[tt]\
\^2 + 1.3599999999999999`\ Sin[tt]\^2\)}]\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell[TextData[{
  "With this function, we define a mirror. The option SurfacePoints creates a \
triangle net on the surface. In total 2*9*24 == 432 triangles are used. The \
preparation of the triangles needs some initialization time. ",
  StyleBox["CircumscribeBoundary -> False", "Input"],
  " creates an approximation that is inscribed in the parameter range of the \
surface, the three-dimensional position of the triangles may inscribe or \
circumscribe the surface. ",
  StyleBox["CircumscribeBoundary -> True", "Input"],
  " make a circumscribed net."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "Timing[seashellmirror = Mirror[\n\tmirrorfunction, \n\t4.75*Pi-1.75*Pi,\n\t\
GraphicDesign -> Solid,\n\tSurfacePoints -> {10, 25},\n\tSurfaceApproximation \
-> TriangleNet,\n\t",
  StyleBox["CircumscribeBoundary -> False", "Input"],
  ",\n\tSurfaceRayIntersections -> Numeric,\n\tOffAxis -> \
{(1.75*Pi+4.75*Pi)/2, 0}]]"
}], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(20.199999999999818`\ Second\), ",", 
        TagBox[\(CustomMirror[
            Function[{tt, 
                theta}, {Cos[tt] + 
                  0.1`\ tt\ \((\(1.1661903789690602`\ Cos[theta]\ Cos[tt]\)\/\
\@\(1.3599999999999999`\ Cos[tt]\^2 + 1.3599999999999999`\ Sin[tt]\^2\) + \
\(0.6`\ Sin[theta]\ Sin[tt]\)\/\@\(1.3599999999999999`\ Cos[tt]\^2 + \
1.3599999999999999`\ Sin[tt]\^2\))\), 
                Sin[tt] + 
                  0.1`\ tt\ \((\(-\(\(0.6`\ Cos[tt]\ Sin[
                                  theta]\)\/\@\(1.3599999999999999`\ \
Cos[tt]\^2 + 1.3599999999999999`\ Sin[tt]\^2\)\)\) + \(1.1661903789690602`\ \
Cos[theta]\ Sin[tt]\)\/\@\(1.3599999999999999`\ Cos[tt]\^2 + \
1.3599999999999999`\ Sin[tt]\^2\))\), 
                0.6`\ tt + \(0.1`\ tt\ Sin[theta]\)\/\@\(1.3599999999999999`\ \
Cos[tt]\^2 + 1.3599999999999999`\ Sin[tt]\^2\)}], 
            9.42477796076938`, {CircumscribeBoundary \[Rule] False, 
              GraphicDesign \[Rule] Solid, 
              OffAxis \[Rule] {10.210176124166827`, 0}, 
              SurfaceApproximation \[Rule] TriangleNet, 
              SurfacePoints \[Rule] {10, 25}, 
              SurfaceRayIntersections \[Rule] Numeric}]\),
          HoldForm]}], "}"}]], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell["\<\
The size of the component in memory is rather large, because all \
the triangles data is stored in the component.\
\>", "Text"],

Cell[CellGroupData[{

Cell["ByteCount[seashellmirror]", "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(1062952\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[TextData[{
  "This shows the triangle facets of the ",
  StyleBox["SurfaceApproximation", "Input"],
  " without the surface itself (",
  StyleBox["GraphicDesign -> Off", "Input"],
  ")."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[seashellmirror, SurfacePoints -> Fill, ShowLabels -> \
False, GraphicDesign -> Off];\
\>", "Input",
  CellLabel->"In[25]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.4645 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.222336 1.48012 1.11022e-16 1.48012 [
[ 0 0 0 0 ]
[ 1 1.4645 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.4645 L
0 1.4645 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49834 .65882 m .42853 .61735 L .60004 .59409 L closepath p .733 .648 .765 r
F P
0 g
s
.65877 .62221 m .60004 .59409 L .49834 .65882 L closepath p .607 .4 .574 r
F P
0 g
s
.54813 .69811 m .49834 .65882 L .65877 .62221 L closepath p .641 .506 .684 r
F P
0 g
s
.49834 .65882 m .42853 .61735 L .41742 .62095 L p .786 .614 .668 r
F P
0 g
s
.41544 .65212 m .49834 .65882 L p .41742 .62095 L .786 .614 .668 r
F P
0 g
s
.38186 .6932 m .33994 .64602 L .49834 .65882 L closepath p .779 .675 .748 r
F P
0 g
s
.60004 .59409 m .50566 .57207 L .66754 .50633 L closepath p .701 .639 .784 r
F P
0 g
s
.60004 .59409 m .50566 .57207 L .42853 .61735 L closepath p .727 .587 .699 r
F P
0 g
s
.50566 .57207 m .42972 .55208 L .5602 .51634 L closepath p .804 .802 .849 r
F P
0 g
s
.66754 .50633 m .5602 .51634 L .50566 .57207 L closepath p .684 .581 .735 r
F P
0 g
s
.42972 .55208 m .3737 .57668 L .44062 .57434 L p .777 .818 .885 r
F P
0 g
s
.44062 .57434 m .47986 .57297 L p .46486 .56672 L .777 .818 .885 r
F P
0 g
s
.46486 .56672 m .42972 .55208 L .44062 .57434 L .777 .818 .885 r
F
.47986 .57297 m .48148 .57291 L p .48014 .57238 L F P
0 g
s
.48014 .57238 m .42972 .55208 L .47986 .57297 L .777 .818 .885 r
F
.48148 .57291 m .50566 .57207 L .49035 .56804 L p F P
0 g
s
.49035 .56804 m .42972 .55208 L p .48148 .57291 L .777 .818 .885 r
F P
0 g
s
.41742 .62095 m .33994 .64602 L .41544 .65212 L p .786 .614 .668 r
F P
0 g
s
.42853 .61735 m .3737 .57668 L .50566 .57207 L closepath p .796 .782 .84 r
F P
0 g
s
.3737 .57668 m .30829 .59827 L .38297 .61012 L p .82 .778 .813 r
F P
0 g
s
.38297 .61012 m .4152 .61524 L p .39861 .59516 L .82 .778 .813 r
F P
0 g
s
.42221 .61267 m .39861 .59516 L p .4152 .61524 L .82 .778 .813 r
F P
0 g
s
.39861 .59516 m .3737 .57668 L p .38297 .61012 L .82 .778 .813 r
F P
0 g
s
.33994 .64602 m .30829 .59827 L .42853 .61735 L closepath p .817 .783 .821 r
F P
0 g
s
.47152 .52851 m .42972 .55208 L .43534 .55054 L p .735 .925 .954 r
F P
0 g
s
.56205 .4344 m .57228 .35571 L .56282 .39994 L .985 .887 .547 r
F
.56114 .47446 m .56542 .42886 L .56205 .4344 L F
.56542 .42886 m .57228 .35571 L .56205 .4344 L F
.50581 .50288 m .49314 .51456 L .49196 .51351 L .218 .048 .425 r
F
.49314 .51456 m .4886 .51801 L .49196 .51351 L F
.48684 .52036 m .48465 .52238 L .48914 .51646 L F
.48793 .51852 m .55937 .47502 L p .50433 .5061 L .537 .911 .745 r
F P
0 g
s
.5562 .476 m .50818 .50382 L p .55898 .43943 L .871 .798 .776 r
F P
0 g
s
.50818 .50382 m .50486 .50574 L p .51044 .4989 L .871 .798 .776 r
F P
0 g
s
.50818 .50382 m .51044 .4989 L .55898 .43943 L .871 .798 .776 r
F
.50486 .50574 m .50458 .50575 L .55898 .43943 L F
.50667 .50102 m .55898 .43943 L p .50458 .50575 L F P
0 g
s
.50486 .50574 m .5045 .50575 L .50363 .50658 L .985 .887 .547 r
F
.50434 .50605 m .50447 .50575 L .50458 .50575 L .871 .798 .776 r
F
.50447 .50575 m .50667 .50102 L .50458 .50575 L F
.5101 .50217 m .51585 .4949 L .5045 .50575 L .985 .887 .547 r
F
.5101 .50217 m .5045 .50575 L .50486 .50574 L F
.50667 .50102 m .53306 .46995 L p .52361 .48664 L 0 0 0 r
F P
0 g
s
.53306 .46995 m .55898 .43943 L p .53489 .47158 L 0 0 0 r
F P
0 g
s
.53489 .47158 m .52361 .48664 L .53306 .46995 L 0 0 0 r
F
.55189 .45109 m .53807 .46855 L p .55898 .43943 L F P
0 g
s
.53807 .46855 m .53669 .46932 L .55898 .43943 L 0 0 0 r
F
.52404 .48627 m .52361 .48664 L .55898 .43943 L F
.53807 .46855 m .52404 .48627 L p .53669 .46932 L F P
0 g
s
.55189 .45109 m .52404 .48627 L p .57228 .35571 L .874 .731 .7 r
F P
0 g
s
.52404 .48627 m .52512 .48301 L .57228 .35571 L .874 .731 .7 r
F
.52414 .48598 m .52131 .48859 L .53325 .45848 L .218 .048 .425 r
F
.52131 .48859 m .51795 .49144 L .53325 .45848 L F
.51795 .49144 m .50727 .50051 L .53195 .46058 L F
.51795 .49144 m .53195 .46058 L .53325 .45848 L F
.50433 .5061 m .50363 .50658 L .48793 .51852 L .537 .911 .745 r
F
.48793 .51852 m .55937 .47502 L p .54954 .48298 L .837 .818 .831 r
F P
0 g
s
.48599 .52181 m .48793 .51852 L .54954 .48298 L .837 .818 .831 r
F
.5169 .49351 m .51248 .49747 L .53031 .48029 L .218 .048 .425 r
F
.51248 .49747 m .48465 .52238 L .51207 .49711 L F
.51248 .49747 m .51207 .49711 L .53031 .48029 L F
.5238 .48657 m .52329 .4866 L .52502 .4833 L .874 .731 .7 r
F
.52131 .48859 m .50581 .50288 L .50727 .50051 L .218 .048 .425 r
F
.54188 .48047 m .51585 .4949 L .5101 .50217 L .985 .887 .547 r
F
.53725 .47864 m .53641 .47292 L .53764 .47401 L 0 0 .271 r
F
.5045 .50575 m .50447 .50575 L .50363 .50658 L .985 .887 .547 r
F
.48684 .52036 m .48745 .51933 L .48833 .51837 L .218 .048 .425 r
F
.50724 .49307 m .50709 .49276 L .53409 .45713 L F
.50667 .50102 m .49196 .51351 L .51551 .48198 L F
.50581 .50288 m .49196 .51351 L .50667 .50102 L F
.48884 .51782 m .50709 .49276 L .5087 .49617 L .183 .006 .391 r
F
.4879 .51854 m .50709 .49276 L .48884 .51782 L F
.4871 .51915 m .48914 .51646 L p .4879 .51854 L F P
0 g
s
.48914 .51646 m .50709 .49276 L p .4879 .51854 L .183 .006 .391 r
F P
0 g
s
.53137 .48004 m .52551 .48502 L .50447 .50575 L .985 .887 .547 r
F
.53031 .48029 m .53409 .45713 L .53725 .47864 L .218 .048 .425 r
F
.53764 .47405 m .53089 .48016 L .53137 .48004 L .985 .887 .547 r
F
.53089 .48016 m .52551 .48502 L .53137 .48004 L F
.53764 .47405 m .50447 .50575 L .5045 .50575 L F
.53764 .47401 m .52551 .48502 L .53764 .47405 L F
.54188 .48047 m .53828 .47343 L .53764 .47405 L F
.53695 .4822 m .53764 .47405 L .52459 .48654 L F
.54188 .48047 m .53764 .47405 L .53695 .4822 L F
.53418 .45567 m .57228 .35571 L p .53448 .45775 L .874 .731 .7 r
F P
0 g
s
.5562 .476 m .50434 .50605 L p .55937 .47502 L .537 .911 .745 r
F P
0 g
s
.50434 .50605 m .50406 .50626 L .55937 .47502 L .537 .911 .745 r
F
.48752 .52394 m .48599 .52181 L .54954 .48298 L .837 .818 .831 r
F
.48297 .52694 m .48488 .5237 L .48752 .52394 L F
.48488 .5237 m .48599 .52181 L .48752 .52394 L F
.54188 .48047 m .50363 .50658 L .48508 .52486 L .985 .887 .547 r
F
.48561 .52486 m .48508 .52486 L .48297 .52694 L F
.54188 .48047 m .48508 .52486 L .48561 .52486 L F
.5602 .51634 m .5634 .47376 L .56114 .47446 L F
.5602 .51634 m .56318 .38431 L .55872 .44292 L F
.59023 .40264 m .58787 .45766 L .58413 .45983 L p .871 .798 .776 r
F P
0 g
s
.58413 .45983 m .58794 .40758 L .59023 .40264 L .871 .798 .776 r
F
.59023 .40264 m .58787 .45766 L .61846 .39907 L p .668 .628 .8 r
F P
0 g
s
.65117 .43974 m .68899 .40789 L .66754 .50633 L p .684 .639 .799 r
F P
0 g
s
.68899 .40789 m .66754 .50633 L .69595 .45169 L p .12 .087 .542 r
F P
0 g
s
.69595 .45169 m .72193 .40173 L .68959 .40778 L p .12 .087 .542 r
F P
0 g
s
.68959 .40778 m .68899 .40789 L p .69595 .45169 L .12 .087 .542 r
F P
0 g
s
.65117 .43974 m .68899 .40789 L .67416 .41519 L p .662 .597 .772 r
F P
0 g
s
.67416 .41519 m .64683 .42864 L p .64912 .4345 L .662 .597 .772 r
F P
0 g
s
.67416 .41519 m .64912 .4345 L .65117 .43974 L .662 .597 .772 r
F
.66754 .50633 m .64912 .4345 L .63097 .4485 L .681 .635 .797 r
F
.66274 .48681 m .6496 .43572 L .66754 .50633 L .961 .674 .444 r
F
.6496 .43572 m .64912 .4345 L .66754 .50633 L F
.63353 .3702 m .65086 .33699 L p .6296 .3546 L .668 .628 .8 r
F P
0 g
s
.65086 .33699 m .66285 .31404 L .64816 .33196 L p .668 .628 .8 r
F P
0 g
s
.64816 .33196 m .6296 .3546 L p .65086 .33699 L .668 .628 .8 r
F P
0 g
s
.72184 .5176 m .66754 .50633 L .72193 .40173 L closepath p .394 .417 .766 r
F P
0 g
s
.68899 .40789 m .67416 .41519 L p .65787 .34961 L .676 .638 .804 r
F P
0 g
s
.67416 .41519 m .64683 .42864 L p .65011 .40515 L .676 .638 .804 r
F P
0 g
s
.67416 .41519 m .65011 .40515 L .65787 .34961 L .676 .638 .804 r
F
.64058 .40117 m .59907 .2393 L .62261 .39367 L .681 .635 .797 r
F
.64683 .42864 m .58787 .45766 L .62152 .39321 L p .676 .638 .804 r
F P
0 g
s
.59907 .2393 m .57228 .35571 L .59023 .40264 L closepath p .695 .649 .8 r
F P
0 g
s
.62261 .39367 m .59907 .2393 L .61398 .37067 L .681 .635 .797 r
F
.61428 .3733 m .59023 .40264 L .59907 .2393 L p .665 .624 .798 r
F P
0 g
s
.62261 .39367 m .59256 .31357 L .62152 .39321 L .681 .635 .797 r
F
.59907 .2393 m .66285 .31404 L .6296 .3546 L p .665 .624 .798 r
F P
0 g
s
.63353 .3702 m .65086 .33699 L p .64683 .42864 L .676 .638 .804 r
F P
0 g
s
.65086 .33699 m .66285 .31404 L p .65787 .34961 L .676 .638 .804 r
F P
0 g
s
.64683 .42864 m .65086 .33699 L .65787 .34961 L .676 .638 .804 r
F
.6496 .43572 m .60871 .27678 L .64912 .4345 L .961 .674 .444 r
F
.60871 .27678 m .59907 .2393 L .60867 .27676 L F
.60871 .27678 m .60867 .27676 L .64912 .4345 L F
.60264 .2474 m .59907 .2393 L .66778 .50638 L F
.6296 .3546 m .61428 .3733 L p .60286 .27269 L .665 .624 .798 r
F P
0 g
s
.60904 .27695 m .60286 .27269 L .59907 .2393 L .665 .624 .798 r
F
.6296 .3546 m .60286 .27269 L .60904 .27695 L F
.60948 .26455 m .60264 .2474 L .60367 .25147 L .961 .674 .444 r
F
.69751 .46244 m .60871 .26116 L .60948 .26455 L F
.60871 .26116 m .60264 .2474 L .60948 .26455 L F
.69751 .46244 m .60502 .25452 L .60871 .26116 L F
.69751 .46244 m .60367 .25147 L .6296 .3546 L F
.61398 .37067 m .59907 .2393 L .59256 .31357 L .681 .635 .797 r
F
.58684 .37873 m .59907 .2393 L .57228 .35571 L F
.69751 .46244 m .56992 .25135 L .59598 .23824 L .961 .674 .444 r
F
.56992 .25135 m .55315 .22362 L .56452 .2275 L F
.56992 .25135 m .56452 .2275 L .59598 .23824 L F
.69751 .46244 m .59598 .23824 L .60502 .25452 L F
.60871 .26116 m .59811 .23897 L .60264 .2474 L F
.60502 .25452 m .59811 .23897 L .60871 .26116 L F
.60502 .25452 m .59598 .23824 L .59811 .23897 L F
.60264 .2474 m .59811 .23897 L .59907 .2393 L F
.59907 .2393 m .66285 .31404 L .57209 .23922 L p .907 .507 .227 r
F P
0 g
s
.57209 .23922 m .55315 .22362 L .56452 .2275 L p .907 .507 .227 r
F P
0 g
s
.56452 .2275 m .59907 .2393 L p .57209 .23922 L .907 .507 .227 r
F P
0 g
s
.61846 .39907 m .62152 .39321 L p .60986 .37869 L .668 .628 .8 r
F P
0 g
s
.6155 .37667 m .60986 .37869 L .62152 .39321 L .668 .628 .8 r
F
.6296 .3546 m .60986 .37869 L p .63353 .3702 L F P
0 g
s
.60986 .37869 m .59023 .40264 L p .61846 .39907 L .668 .628 .8 r
F P
0 g
s
.62152 .39321 m .59256 .31357 L .58684 .37873 L .681 .635 .797 r
F
.66923 .50423 m .6296 .3546 L .66778 .50638 L .961 .674 .444 r
F
.69751 .46244 m .6296 .3546 L .66923 .50423 L F
.72184 .5176 m .69751 .46244 L .66778 .50638 L F
.69998 .4795 m .55315 .22362 L .69751 .46244 L F
.62152 .39321 m .63353 .3702 L p .6155 .37667 L .668 .628 .8 r
F P
0 g
s
.62152 .39321 m .63353 .3702 L p .64058 .40117 L .676 .638 .804 r
F P
0 g
s
.64683 .42864 m .62152 .39321 L .64058 .40117 L .676 .638 .804 r
F
.66385 .50667 m .62992 .4495 L .5602 .51634 L .681 .635 .797 r
F
.58787 .45766 m .57003 .49549 L p .63097 .4485 L .662 .597 .772 r
F P
0 g
s
.63547 .44418 m .58787 .45766 L .63097 .4485 L .662 .597 .772 r
F
.65603 .48812 m .63097 .4485 L .66385 .50667 L .681 .635 .797 r
F
.63097 .4485 m .62992 .4495 L .66385 .50667 L F
.6372 .44369 m .63097 .4485 L .5602 .51634 L .662 .597 .772 r
F
.57003 .49549 m .5602 .51634 L p .63097 .4485 L F P
0 g
s
.64683 .42864 m .58787 .45766 L p .65117 .43974 L .662 .597 .772 r
F P
0 g
s
.63097 .4485 m .60429 .40631 L .62992 .4495 L .681 .635 .797 r
F
.58237 .46101 m .58787 .45766 L .58413 .45983 L p .537 .911 .745 r
F P
0 g
s
.58787 .45766 m .5602 .51634 L p .58221 .46139 L .837 .818 .831 r
F P
0 g
s
.58511 .44629 m .58611 .43265 L .576 .46529 L .681 .635 .797 r
F
.58237 .46101 m .576 .46529 L .5602 .51634 L F
.60429 .40631 m .576 .46529 L .58237 .46101 L F
.58611 .43265 m .56697 .42631 L .5602 .51634 L F
.58732 .41607 m .56697 .42631 L .58611 .43265 L F
.58812 .40513 m .59023 .40264 L p .58794 .40758 L .871 .798 .776 r
F P
0 g
s
.58881 .40443 m .56697 .42631 L .59197 .41373 L .681 .635 .797 r
F
.5602 .51634 m .48297 .52694 L p .49121 .5215 L .837 .818 .831 r
F P
0 g
s
.56836 .49597 m .49121 .5215 L .58221 .46139 L .837 .818 .831 r
F
.5602 .51634 m .49121 .5215 L .56836 .49597 L F
.47152 .52851 m .4733 .52743 L p .47223 .52803 L .537 .911 .745 r
F P
0 g
s
.49794 .52489 m .48561 .52486 L .48297 .52694 L .985 .887 .547 r
F
.4762 .52581 m .47087 .52715 L .48023 .52354 L .666 .311 .362 r
F
.47087 .52715 m .46986 .52629 L .48023 .52354 L F
.38387 .5491 m .38304 .54909 L .4751 .52489 L F
.47509 .52491 m .4751 .52489 L .48023 .52354 L F
.38387 .5491 m .4751 .52489 L .47509 .52491 L F
.48463 .52368 m .4762 .52581 L .48465 .52238 L F
.4762 .52581 m .48023 .52354 L .48465 .52238 L F
.47338 .527 m .3623 .55454 L .4762 .52581 L F
.46896 .52886 m .44783 .53395 L .47338 .527 L F
.44783 .53395 m .3623 .55454 L .47338 .527 L F
.42972 .55208 m .3737 .57668 L .36481 .55656 L p .742 .932 .951 r
F P
0 g
s
.43534 .55054 m .4676 .5417 L p .47604 .52789 L .735 .925 .954 r
F P
0 g
s
.4676 .5417 m .5602 .51634 L .48297 .52694 L p .735 .925 .954 r
F P
0 g
s
.48297 .52694 m .47604 .52789 L p .4676 .5417 L .735 .925 .954 r
F P
0 g
s
.46577 .53361 m .47152 .52851 L .43534 .55054 L .735 .925 .954 r
F
.47604 .52789 m .47152 .52851 L p .46577 .53361 L F P
0 g
s
.46896 .52886 m .4762 .52581 L .4733 .52743 L .666 .311 .362 r
F
.48287 .52695 m .47152 .52851 L .4733 .52743 L p .837 .818 .831 r
F P
0 g
s
.4733 .52743 m .4762 .52581 L .48463 .52368 L .666 .311 .362 r
F
.48463 .52368 m .48465 .52238 L .48488 .5237 L F
.48509 .52491 m .48465 .52238 L .4948 .5133 L .218 .048 .425 r
F
.48297 .52694 m .48287 .52695 L p .48793 .51852 L .837 .818 .831 r
F P
0 g
s
.4879 .51854 m .48793 .51852 L p .48287 .52695 L .837 .818 .831 r
F P
0 g
s
.4879 .51854 m .48793 .51852 L p .48802 .51844 L .537 .911 .745 r
F P
0 g
s
.48465 .52238 m .4871 .51915 L p .48884 .51782 L .183 .006 .391 r
F P
0 g
s
.5602 .51634 m .54188 .48047 L .48561 .52486 L .985 .887 .547 r
F
.53151 .48622 m .52459 .48654 L .51585 .4949 L F
.54188 .48047 m .52459 .48654 L .53151 .48622 L F
.50486 .50574 m .50434 .50605 L p .50458 .50575 L .871 .798 .776 r
F P
0 g
s
.50623 .50461 m .4948 .5133 L .52353 .48757 L .218 .048 .425 r
F
.52348 .48804 m .52353 .48757 L .53008 .48171 L F
.50623 .50461 m .52353 .48757 L .52348 .48804 L F
.4152 .61524 m .42853 .61735 L .42221 .61267 L p .82 .778 .813 r
F P
0 g
s
.38186 .6932 m .53005 .54623 L .35215 .63961 L .676 .519 .665 r
F
.53005 .54623 m .5602 .51634 L .4858 .56014 L F
.53005 .54623 m .4858 .56014 L .33994 .64602 L F
.4858 .56014 m .5602 .51634 L .50238 .52427 L .815 .867 .885 r
F
.4858 .56014 m .50238 .52427 L .47152 .52851 L F
.41491 .66042 m .66754 .50633 L .58945 .51361 L .676 .519 .665 r
F
.41491 .66042 m .58945 .51361 L .53005 .54623 L F
.41417 .67206 m .66754 .50633 L .41491 .66042 L F
.54813 .69811 m .49834 .65882 L .38186 .6932 L closepath p .719 .481 .564 r
F P
0 g
s
.41517 .73533 m .38186 .6932 L .54813 .69811 L closepath p .728 .563 .667 r
F P
0 g
s
.41517 .73533 m .66754 .50633 L .38186 .6932 L .462 .208 .442 r
F
.48835 .54479 m .48862 .54521 L .50036 .61276 L .666 .311 .362 r
F
.48862 .54521 m .48509 .52491 L .493 .54007 L .218 .048 .425 r
F
.34599 .64062 m .44123 .5858 L .41687 .57732 L .815 .867 .885 r
F
.44123 .5858 m .4858 .56014 L .41687 .57732 L F
.41687 .57732 m .4858 .56014 L .47152 .52851 L F
.36481 .55656 m .36482 .55655 L .42972 .55208 L .742 .932 .951 r
F
.36481 .55655 m .38851 .5501 L .42972 .55208 L F
.39182 .5492 m .39322 .54931 L p .38851 .5501 L F P
0 g
s
.39322 .54931 m .42972 .55208 L p .38851 .5501 L .742 .932 .951 r
F P
0 g
s
.39182 .5492 m .41281 .5508 L p .42093 .54956 L .112 .66 .815 r
F P
0 g
s
.41709 .55112 m .42972 .55208 L p .41888 .55101 L .112 .66 .815 r
F P
0 g
s
.33994 .64602 m .43596 .56027 L .30829 .59827 L .815 .867 .885 r
F
.43596 .56027 m .44529 .55194 L .41203 .56319 L F
.35159 .57057 m .3625 .57358 L p .37001 .56832 L .668 .896 .979 r
F P
0 g
s
.3625 .57358 m .3737 .57668 L .37102 .57061 L p .668 .896 .979 r
F P
0 g
s
.37102 .57061 m .37001 .56832 L p .3625 .57358 L .668 .896 .979 r
F P
0 g
s
.30829 .59827 m .30183 .5568 L .3737 .57668 L closepath p .8 .894 .91 r
F P
0 g
s
.43596 .56027 m .41203 .56319 L .30829 .59827 L .815 .867 .885 r
F
.42972 .55208 m .42697 .5513 L p .41888 .55101 L .112 .66 .815 r
F P
0 g
s
.3875 .57149 m .41888 .55101 L .30829 .59827 L .815 .867 .885 r
F
.47152 .52851 m .42972 .55208 L .42697 .5513 L p .583 .945 .856 r
F P
0 g
s
.44529 .55194 m .42697 .5513 L .3875 .57149 L .815 .867 .885 r
F
.42697 .5513 m .41888 .55101 L .3875 .57149 L F
.44529 .55194 m .47152 .52851 L .41888 .55101 L F
.42697 .5513 m .42471 .55064 L p .47152 .52851 L .583 .945 .856 r
F P
0 g
s
.42471 .55064 m .47152 .52851 L .47114 .52915 L .206 0 0 r
F
.42471 .55064 m .47114 .52915 L .43848 .54978 L F
.41888 .55101 m .47152 .52851 L .42471 .55064 L F
.42471 .55064 m .42093 .54956 L p .47152 .52851 L .583 .945 .856 r
F P
0 g
s
.46902 .52942 m .37091 .56132 L .46896 .52886 L .666 .311 .362 r
F
.45909 .53358 m .37091 .56132 L .46902 .52942 L F
.47023 .52892 m .47152 .52851 L p .42093 .54956 L .583 .945 .856 r
F P
0 g
s
.35426 .63759 m .4858 .56014 L .34599 .64062 L .815 .867 .885 r
F
.47436 .5754 m .40269 .57238 L .46914 .53042 L .666 .311 .362 r
F
.47701 .59825 m .45402 .59025 L .47436 .5754 L F
.45402 .59025 m .44767 .57435 L .47436 .5754 L F
.40336 .57261 m .40269 .57238 L .47436 .5754 L F
.72184 .5176 m .66754 .50633 L .60004 .59409 L closepath p .448 .293 .576 r
F P
0 g
s
.65877 .62221 m .60004 .59409 L .72184 .5176 L closepath p .538 .459 .714 r
F P
0 g
s
.41517 .73533 m .72184 .5176 L .66754 .50633 L .462 .208 .442 r
F
.55833 .7337 m .54813 .69811 L .41517 .73533 L closepath p .635 .331 .438 r
F P
0 g
s
.42756 .76968 m .41517 .73533 L .55833 .7337 L closepath p .656 .407 .531 r
F P
0 g
s
.42756 .76968 m .72184 .5176 L .41517 .73533 L .196 0 .164 r
F
.45619 .59567 m .49711 .62049 L .46869 .68802 L .69 .553 .694 r
F
.46096 .67762 m .46869 .68802 L .46243 .70288 L F
.45619 .59567 m .46869 .68802 L .46096 .67762 L F
.45619 .59567 m .46096 .67762 L .47422 .6408 L F
.53288 .76061 m .55833 .7337 L .46568 .75919 L p .449 .021 .134 r
F P
0 g
s
.46568 .75919 m .42756 .76968 L .45424 .76739 L p .449 .021 .134 r
F P
0 g
s
.45424 .76739 m .53288 .76061 L p .46568 .75919 L .449 .021 .134 r
F P
0 g
s
.41806 .79423 m .42756 .76968 L .53288 .76061 L closepath p .489 .103 .234 r
F P
0 g
s
.41806 .79423 m .42756 .76968 L .29786 .7608 L closepath p .741 .362 .334 r
F P
0 g
s
.70272 .56015 m .72184 .5176 L .65877 .62221 L closepath p 0 0 0 r
F P
0 g
s
.42756 .76968 m .65163 .59906 L .72184 .5176 L .196 0 .164 r
F
.41806 .79423 m .70272 .56015 L .42756 .76968 L .738 .992 .841 r
F
.2747 .696 m .2571 .65563 L .38186 .6932 L closepath p .844 .728 .736 r
F P
0 g
s
.41517 .73533 m .38186 .6932 L .2747 .696 L closepath p .826 .562 .541 r
F P
0 g
s
.29023 .73184 m .2747 .696 L .41517 .73533 L closepath p .818 .638 .658 r
F P
0 g
s
.42756 .76968 m .41517 .73533 L .29023 .73184 L closepath p .787 .473 .457 r
F P
0 g
s
.29786 .7608 m .29023 .73184 L .42756 .76968 L closepath p .791 .532 .547 r
F P
0 g
s
.2747 .696 m .2571 .65563 L .20055 .64942 L closepath p .967 .743 .548 r
F P
0 g
s
.20055 .64942 m .2004 .6251 L .2571 .65563 L closepath p .937 .896 .761 r
F P
0 g
s
.25164 .67192 m .41806 .79423 L .42756 .76968 L .93 .607 .404 r
F
.20055 .64942 m .2004 .6251 L .18906 .63714 L closepath p .882 .763 .261 r
F P
0 g
s
.18906 .63714 m .28514 .70305 L .25164 .67192 L .93 .607 .404 r
F
.28514 .70305 m .41806 .79423 L .25164 .67192 L F
.45758 .75566 m .55576 .6347 L .55605 .63498 L .773 .729 .812 r
F
.45758 .75566 m .55605 .63498 L .52165 .70193 L F
.45911 .73922 m .55576 .6347 L .45758 .75566 L F
.29567 .78154 m .29786 .7608 L .41806 .79423 L closepath p .746 .383 .366 r
F P
0 g
s
.39441 .80863 m .41806 .79423 L .29567 .78154 L closepath p .656 .181 .113 r
F P
0 g
s
.29023 .73184 m .2747 .696 L .20274 .67291 L closepath p .947 .663 .466 r
F P
0 g
s
.20274 .67291 m .20055 .64942 L .2747 .696 L closepath p .933 .825 .715 r
F P
0 g
s
.18906 .63714 m .39441 .80863 L .41806 .79423 L .933 .636 .457 r
F
.39643 .80645 m .55572 .63473 L .39671 .80671 L .773 .729 .812 r
F
.50036 .61276 m .48862 .54521 L .49128 .54889 L .218 .048 .425 r
F
.50036 .61276 m .49128 .54889 L .51096 .58757 L F
.48835 .54479 m .50036 .61276 L .5003 .61271 L .666 .311 .362 r
F
.51404 .60284 m .542 .60996 L .55638 .63407 L .69 .553 .694 r
F
.55634 .63411 m .55638 .63407 L .55646 .63419 L F
.51404 .60284 m .55638 .63407 L .55634 .63411 L F
.542 .60996 m .55929 .62824 L .55646 .63419 L F
.55929 .62824 m .55981 .62879 L .55942 .62942 L F
.55929 .62824 m .55942 .62942 L .55646 .63419 L F
.54954 .48298 m .55937 .47502 L .55939 .47647 L .837 .818 .831 r
F
.55462 .49681 m .55789 .40183 L .54267 .45495 L .985 .887 .547 r
F
.5602 .51634 m .55872 .44292 L .55462 .49681 L F
.55872 .44292 m .55789 .40183 L .55462 .49681 L F
.5634 .47376 m .57228 .35571 L .56114 .47446 L F
.55898 .43943 m .58812 .40513 L p .5562 .476 L .871 .798 .776 r
F P
0 g
s
.5562 .476 m .58812 .40513 L .58794 .40758 L .871 .798 .776 r
F
.58812 .40513 m .59023 .40264 L .58881 .40443 L p 0 0 0 r
F P
0 g
s
.57228 .35571 m .59023 .40264 L .58881 .40443 L p .874 .731 .7 r
F P
0 g
s
.59756 .39567 m .57228 .35571 L .56697 .42631 L .681 .635 .797 r
F
.55872 .44292 m .56318 .38431 L .55787 .40096 L .985 .887 .547 r
F
.55898 .43943 m .58812 .40513 L p .55189 .45109 L 0 0 0 r
F P
0 g
s
.58881 .40443 m .55189 .45109 L p .58812 .40513 L 0 0 0 r
F P
0 g
s
.58881 .40443 m .55189 .45109 L p .57228 .35571 L .874 .731 .7 r
F P
0 g
s
.56784 .46986 m .58787 .45766 L p .56822 .47063 L .837 .818 .831 r
F P
0 g
s
.55939 .47647 m .56784 .46986 L .56822 .47063 L .837 .818 .831 r
F
.55937 .47502 m .56784 .46986 L p .55939 .47647 L F P
0 g
s
.62992 .4495 m .60429 .40631 L .5602 .51634 L .681 .635 .797 r
F
.5602 .51634 m .65117 .43974 L p .6372 .44369 L .662 .597 .772 r
F P
0 g
s
.66754 .50633 m .65603 .48812 L .66385 .50667 L .681 .635 .797 r
F
.66754 .50633 m .5602 .51634 L .65117 .43974 L p .684 .639 .799 r
F P
0 g
s
.58413 .45983 m .5562 .476 L p .58794 .40758 L .871 .798 .776 r
F P
0 g
s
.55937 .47502 m .58237 .46101 L p .5562 .476 L .537 .911 .745 r
F P
0 g
s
.58413 .45983 m .5562 .476 L p .58237 .46101 L .537 .911 .745 r
F P
0 g
s
.5602 .51634 m .48561 .52486 L .49794 .52489 L .985 .887 .547 r
F
.54215 .45674 m .53409 .45713 L p .53777 .47204 L .192 .012 .394 r
F P
0 g
s
.53418 .45567 m .53431 .45659 L .53409 .45675 L 0 0 .185 r
F
.53366 .45703 m .53392 .45635 L p .53409 .45675 L F P
0 g
s
.53392 .45635 m .53418 .45567 L p .53409 .45675 L 0 0 .185 r
F P
0 g
s
.53418 .45567 m .55271 .40704 L p .54769 .42588 L 0 0 .185 r
F P
0 g
s
.54769 .42588 m .54062 .4524 L .53418 .45567 L 0 0 .185 r
F
.53409 .45713 m .53412 .45673 L .54205 .45554 L .21 .349 .786 r
F
.53412 .45673 m .54173 .45167 L .54205 .45554 L F
.5602 .51634 m .54173 .45167 L .54406 .47962 L .985 .887 .547 r
F
.56075 .45585 m .53409 .45713 L p .5719 .4496 L .21 .349 .786 r
F P
0 g
s
.53893 .46797 m .54173 .45167 L .53754 .46481 L .985 .887 .547 r
F
.54406 .47962 m .54215 .45674 L .53893 .46797 L F
.54215 .45674 m .54173 .45167 L .53893 .46797 L F
.5602 .51634 m .53893 .46797 L .53778 .47244 L F
.53893 .46797 m .53754 .46481 L .53777 .47204 L F
.53893 .46797 m .53777 .47204 L .53778 .47244 L F
.55563 .60558 m .55916 .60883 L .55626 .60768 L .45 .357 .659 r
F
.5378 .47218 m .54215 .45674 L .53777 .47204 L .192 .012 .394 r
F
.53641 .47292 m .53801 .46793 L .53764 .47401 L 0 0 .271 r
F
.53801 .46793 m .53821 .46731 L .5381 .4686 L F
.53801 .46793 m .5381 .4686 L .53764 .47401 L F
.53821 .46731 m .53821 .46733 L .53764 .47401 L F
.53828 .47343 m .53795 .47277 L .52551 .48502 L .985 .887 .547 r
F
.53005 .54623 m .58945 .51361 L .5602 .51634 L .676 .519 .665 r
F
.53031 .48029 m .53725 .47864 L .5537 .59028 L .218 .048 .425 r
F
.53031 .48029 m .5537 .59028 L .55052 .57948 L F
.63541 .60654 m .56272 .56892 L p .57182 .56137 L .683 .619 .778 r
F P
0 g
s
.54405 .51373 m .54179 .49579 L .54538 .51262 L .45 .357 .659 r
F
.55474 .59859 m .55372 .59049 L .56514 .60713 L F
.63541 .60654 m .56272 .56892 L p .56499 .60473 L .74 .58 .675 r
F P
0 g
s
.56649 .62835 m .5842 .62274 L p .56563 .61475 L .74 .58 .675 r
F P
0 g
s
.55626 .60768 m .56491 .61444 L .55732 .61117 L .45 .357 .659 r
F
.55474 .59859 m .56514 .60713 L .56517 .60746 L F
.55372 .59049 m .54405 .51373 L .55885 .5782 L F
.56563 .61475 m .60061 .61755 L .56499 .60473 L .74 .58 .675 r
F
.55372 .59049 m .55885 .5782 L .56566 .60789 L .45 .357 .659 r
F
.54405 .51373 m .54538 .51262 L .56566 .60789 L F
.5842 .62274 m .60061 .61755 L p .56563 .61475 L .74 .58 .675 r
F P
0 g
s
.55561 .60547 m .55837 .60613 L .55877 .60749 L .45 .357 .659 r
F
.55561 .60547 m .56666 .61255 L .56662 .61565 L F
.5027 .55651 m .55474 .59859 L .55561 .60547 L F
.50305 .55558 m .55474 .59859 L .5027 .55651 L F
.49007 .54351 m .55474 .59859 L .48944 .54425 L F
.52171 .50555 m .52176 .50676 L p .52209 .50588 L .161 .053 .474 r
F P
0 g
s
.5271 .50001 m .48509 .52491 L .53008 .48171 L .218 .048 .425 r
F
.493 .54007 m .48509 .52491 L .52196 .50305 L F
.493 .54007 m .52196 .50305 L .52162 .50644 L F
.48297 .52694 m .47214 .52809 L .47192 .52846 L .985 .887 .547 r
F
.48463 .52368 m .48488 .5237 L .48508 .52486 L .666 .311 .362 r
F
.48463 .52368 m .48508 .52486 L .48484 .52486 L F
.50433 .5061 m .50406 .50626 L .50363 .50658 L .537 .911 .745 r
F
.48509 .52491 m .4948 .5133 L .50623 .50461 L .218 .048 .425 r
F
.50447 .50575 m .50409 .50577 L .50667 .50102 L .871 .798 .776 r
F
.52404 .48627 m .5238 .48657 L p .52512 .48301 L .874 .731 .7 r
F P
0 g
s
.53031 .48029 m .52414 .48598 L .53409 .45713 L .218 .048 .425 r
F
.52414 .48598 m .53325 .45848 L .53409 .45713 L F
.52551 .48502 m .51927 .49069 L .50275 .50718 L .985 .887 .547 r
F
.50363 .50658 m .50249 .50736 L .48793 .51852 L .537 .911 .745 r
F
.52551 .48502 m .50275 .50718 L .50363 .50658 L .985 .887 .547 r
F
.49539 .51067 m .50597 .50184 L .50409 .50577 L .183 .006 .391 r
F
.5026 .50581 m .50597 .50184 L p .50409 .50577 L .871 .798 .776 r
F P
0 g
s
.50597 .50184 m .50667 .50102 L p .50409 .50577 L .871 .798 .776 r
F P
0 g
s
.50581 .50288 m .51551 .48198 L .53409 .45713 L .218 .048 .425 r
F
.50597 .50184 m .50667 .50102 L p .5101 .4984 L 0 0 0 r
F P
0 g
s
.48884 .51782 m .49539 .51067 L .50409 .50577 L .183 .006 .391 r
F
.48884 .51782 m .50409 .50577 L .50249 .50736 L F
.52361 .48664 m .52335 .48698 L .50667 .50102 L 0 0 0 r
F
.52335 .48698 m .51916 .49079 L .50667 .50102 L F
.51927 .49069 m .51871 .49119 L .48962 .5203 L .985 .887 .547 r
F
.48964 .52028 m .48962 .5203 L .48297 .52694 L F
.51927 .49069 m .48962 .5203 L .48964 .52028 L F
.51871 .49119 m .48402 .52581 L .48297 .52694 L F
.51916 .49079 m .5101 .4984 L .50667 .50102 L 0 0 0 r
F
.51844 .49144 m .5101 .4984 L .51916 .49079 L F
.53221 .47769 m .51844 .49144 L .51871 .49119 L .985 .887 .547 r
F
.51844 .49144 m .48402 .52581 L .51871 .49119 L F
.53008 .48171 m .5169 .49351 L .53031 .48029 L .218 .048 .425 r
F
.52264 .48794 m .51844 .49144 L .51916 .49079 L 0 0 0 r
F
.50249 .50736 m .48802 .51844 L .48793 .51852 L .537 .911 .745 r
F
.50363 .50658 m .50275 .50718 L .48297 .52694 L .985 .887 .547 r
F
.49314 .51456 m .48684 .52036 L .4886 .51801 L .218 .048 .425 r
F
.49897 .51644 m .48465 .52238 L p .48884 .51782 L .183 .006 .391 r
F P
0 g
s
.48591 .52186 m .48465 .52238 L .48398 .52304 L p 0 0 0 r
F P
0 g
s
.4733 .52743 m .4774 .52493 L p .48487 .5236 L .837 .818 .831 r
F P
0 g
s
.47502 .52536 m .4791 .5241 L .47821 .52453 L .255 0 0 r
F
.4751 .52489 m .48023 .52354 L p .47502 .52536 L F P
0 g
s
.48023 .52354 m .48465 .52238 L p .4791 .5241 L .255 0 0 r
F P
0 g
s
.48023 .52354 m .4791 .5241 L .47502 .52536 L .255 0 0 r
F
.48287 .52695 m .4733 .52743 L .48487 .5236 L .837 .818 .831 r
F
.48462 .52486 m .46896 .52886 L .48463 .52368 L .666 .311 .362 r
F
.4733 .52743 m .4774 .52493 L p .47223 .52803 L .537 .911 .745 r
F P
0 g
s
.4771 .52508 m .47223 .52803 L .4774 .52493 L .537 .911 .745 r
F
.4771 .52508 m .47515 .52603 L .47223 .52803 L F
.48465 .52238 m .48398 .52304 L p .47821 .52453 L .255 0 0 r
F P
0 g
s
.4791 .5241 m .48465 .52238 L .47821 .52453 L .255 0 0 r
F
.47502 .52536 m .48398 .52304 L .47498 .52563 L F
.4774 .52493 m .4879 .51854 L p .48591 .52186 L .837 .818 .831 r
F P
0 g
s
.48546 .52261 m .48398 .52304 L .48591 .52186 L .837 .818 .831 r
F
.48398 .52304 m .4774 .52493 L .48591 .52186 L F
.48487 .5236 m .4774 .52493 L .48546 .52261 L F
.48944 .5204 m .48591 .52186 L p .48308 .52396 L 0 0 0 r
F P
0 g
s
.5377 .47228 m .53221 .47769 L .51871 .49119 L .985 .887 .547 r
F
.5377 .47228 m .51871 .49119 L .51927 .49069 L F
.52335 .48698 m .52264 .48794 L .51916 .49079 L 0 0 0 r
F
.53795 .47277 m .5377 .47228 L .51927 .49069 L .985 .887 .547 r
F
.52404 .48627 m .5238 .48657 L p .52361 .48664 L 0 0 0 r
F P
0 g
s
.5238 .48657 m .52335 .48698 L .52361 .48664 L 0 0 0 r
F
.53795 .47277 m .51927 .49069 L .52551 .48502 L .985 .887 .547 r
F
.50709 .49276 m .53339 .45804 L p .52289 .48773 L .183 .006 .391 r
F P
0 g
s
.5144 .49481 m .52264 .48793 L .51984 .49634 L .183 .006 .391 r
F
.52264 .48793 m .52252 .48877 L .51984 .49634 L F
.48824 .54194 m .50515 .52313 L .55474 .59859 L .45 .357 .659 r
F
.50515 .52313 m .51879 .50797 L .54383 .57109 L F
.50515 .52313 m .54383 .57109 L .55474 .59859 L F
.50249 .50736 m .49712 .51103 L .48802 .51844 L .537 .911 .745 r
F
.50406 .50626 m .50282 .50711 L .50363 .50658 L F
.50282 .50711 m .50249 .50736 L .50363 .50658 L F
.50406 .50626 m .50357 .50653 L .50282 .50711 L F
.48884 .51782 m .50381 .50635 L .49897 .51644 L .183 .006 .391 r
F
.50302 .50658 m .48997 .51934 L .48854 .5209 L .985 .887 .547 r
F
.5029 .5066 m .48997 .51934 L .50302 .50658 L F
.53409 .45713 m .53221 .47769 L p .52673 .48317 L .183 .006 .391 r
F P
0 g
s
.51879 .50797 m .52115 .50535 L .5216 .50661 L .45 .357 .659 r
F
.51879 .50797 m .5216 .50661 L .55474 .59859 L F
.51746 .50705 m .52115 .50535 L .48824 .54194 L F
.53031 .48029 m .55052 .57948 L .548 .57093 L .218 .048 .425 r
F
.55474 .59859 m .56566 .60789 L .55561 .60547 L .45 .357 .659 r
F
.55877 .60749 m .56566 .60789 L .56666 .61255 L F
.55837 .60613 m .56566 .60789 L .55877 .60749 L F
.54384 .51083 m .56485 .60468 L .55617 .60156 L .751 .554 .629 r
F
.48911 .54463 m .48944 .54425 L .55561 .60547 L .45 .357 .659 r
F
.55562 .6055 m .55561 .60547 L .55913 .60872 L F
.48911 .54463 m .55561 .60547 L .55562 .6055 L F
.48911 .54463 m .55913 .60872 L .55916 .60883 L F
.55916 .60883 m .56563 .61475 L .55626 .60768 L F
.55508 .60721 m .55626 .60768 L .55929 .62824 L .218 .048 .425 r
F
.5605 .62284 m .56649 .62835 L .56162 .61303 L .74 .58 .675 r
F
.56283 .62951 m .56649 .62835 L p .56248 .62465 L F P
0 g
s
.56159 .62594 m .56248 .62465 L .5605 .62284 L .74 .58 .675 r
F
.56283 .62951 m .56248 .62465 L .56159 .62594 L F
.55508 .60721 m .55929 .62824 L .55915 .62809 L .218 .048 .425 r
F
.52115 .50535 m .54483 .56018 L .55474 .59859 L .45 .357 .659 r
F
.52907 .50671 m .52926 .50272 L .548 .57093 L .218 .048 .425 r
F
.52926 .50272 m .53031 .48029 L .53408 .49962 L F
.52926 .50272 m .53408 .49962 L .548 .57093 L F
.48926 .52049 m .48854 .5209 L .48497 .52477 L .985 .887 .547 r
F
.48508 .52474 m .48497 .52477 L .48402 .52581 L F
.52136 .49676 m .52171 .50555 L .52147 .50609 L .752 .501 .553 r
F
.52136 .49676 m .52147 .50609 L .52114 .50532 L F
.5537 .59028 m .54571 .53607 L .55137 .57182 L 0 0 .271 r
F
.54571 .53607 m .53725 .47864 L .54548 .53293 L F
.54571 .53607 m .54548 .53293 L .55137 .57182 L F
.54285 .49757 m .55735 .47487 L .56444 .48752 L .547 .521 .778 r
F
.52171 .50555 m .52176 .50676 L p .52162 .50644 L .752 .501 .553 r
F P
0 g
s
.52162 .50644 m .52196 .50305 L .5271 .50001 L .218 .048 .425 r
F
.53828 .47343 m .53764 .47401 L .53764 .47405 L .985 .887 .547 r
F
.54233 .49056 m .54221 .46783 L .5378 .47218 L .192 .012 .394 r
F
.55137 .57182 m .54548 .53293 L .54405 .51373 L 0 0 .271 r
F
.54483 .56018 m .5537 .59028 L .55474 .59859 L .45 .357 .659 r
F
.54405 .51373 m .53725 .47864 L .53926 .47861 L 0 0 .271 r
F
.54405 .51373 m .53926 .47861 L .54142 .49283 L F
.54548 .53293 m .53725 .47864 L .54405 .51373 L F
.48944 .54425 m .50305 .55558 L .5027 .55651 L .45 .357 .659 r
F
.52176 .50676 m .528 .50307 L .54483 .56018 L F
.52162 .50644 m .52195 .50627 L .52176 .50676 L F
.52195 .50627 m .528 .50307 L .52176 .50676 L F
.5271 .50001 m .53031 .48029 L .52907 .50671 L .218 .048 .425 r
F
.52518 .49783 m .52673 .48317 L .53101 .49087 L .183 .006 .391 r
F
.52171 .50555 m .52518 .49783 L .52482 .49773 L .161 .053 .474 r
F
.52136 .49676 m .52171 .50555 L p .52482 .49773 L F P
0 g
s
.52158 .50213 m .52292 .4972 L .52518 .49783 L .183 .006 .391 r
F
.52292 .4972 m .52673 .48317 L .52518 .49783 L F
.52171 .50555 m .52209 .50588 L .52518 .49783 L .161 .053 .474 r
F
.53221 .47769 m .53101 .49087 L p .52673 .48317 L .183 .006 .391 r
F P
0 g
s
.52115 .50535 m .53883 .48186 L .54179 .49579 L .45 .357 .659 r
F
.53641 .47292 m .53409 .45713 L .53703 .46907 L 0 0 .271 r
F
.53641 .47292 m .53757 .46571 L .53767 .46898 L F
.53409 .45713 m .53101 .49087 L p .53777 .47204 L .192 .012 .394 r
F P
0 g
s
.53314 .47677 m .53315 .47675 L .53221 .47769 L .985 .887 .547 r
F
.53304 .48853 m .53777 .47204 L .53101 .49087 L .192 .012 .394 r
F
.5377 .47228 m .53315 .47675 L .53314 .47677 L .985 .887 .547 r
F
.5377 .47228 m .53767 .47224 L .53315 .47675 L F
.53767 .47224 m .53614 .46923 L .53221 .47769 L F
.52482 .49773 m .52518 .49783 L .53614 .46923 L .161 .053 .474 r
F
.5151 .50974 m .52242 .48945 L .52038 .50356 L .183 .006 .391 r
F
.51665 .50743 m .52025 .50327 L .52038 .50356 L .45 .357 .659 r
F
.51746 .50705 m .52038 .50356 L .52115 .50535 L F
.51665 .50743 m .52038 .50356 L .51746 .50705 L F
.5238 .48657 m .52289 .48773 L p .52335 .48698 L 0 0 0 r
F P
0 g
s
.524 .48458 m .52502 .4833 L p .52329 .4866 L .874 .731 .7 r
F P
0 g
s
.52354 .48634 m .53409 .45713 L .52673 .48317 L .183 .006 .391 r
F
.50709 .49276 m .52289 .48773 L .5144 .49481 L F
.50709 .49276 m .51984 .49634 L .5151 .50974 L F
.51844 .49144 m .51436 .49515 L .5101 .4984 L 0 0 0 r
F
.50409 .50577 m .50597 .50184 L .5085 .50136 L .183 .006 .391 r
F
.50597 .50184 m .50985 .49861 L .51093 .5009 L F
.51844 .49144 m .48497 .52477 L .48508 .52474 L .985 .887 .547 r
F
.52289 .48773 m .52264 .48794 L .52335 .48698 L 0 0 0 r
F
.5238 .48657 m .52289 .48773 L p .52329 .4866 L .874 .731 .7 r
F P
0 g
s
.53339 .45804 m .53409 .45713 L p .5151 .50974 L .183 .006 .391 r
F P
0 g
s
.53221 .47769 m .51817 .49169 L .51844 .49144 L .985 .887 .547 r
F
.52327 .4866 m .48854 .5209 L .48926 .52049 L F
.53221 .47769 m .5232 .4866 L .52327 .4866 L F
.5232 .4866 m .48854 .5209 L .52327 .4866 L F
.52237 .48664 m .524 .48458 L p .52329 .4866 L .874 .731 .7 r
F P
0 g
s
.53221 .47769 m .5029 .5066 L .50302 .50658 L .985 .887 .547 r
F
.51817 .49169 m .48497 .52477 L .51844 .49144 L F
.51629 .49339 m .51436 .49515 L .51567 .494 L F
.51436 .49515 m .5016 .50672 L .51567 .494 L F
.51567 .494 m .5016 .50672 L .48997 .51934 L F
.52354 .48634 m .52673 .48317 L .52126 .50251 L .183 .006 .391 r
F
.50282 .50711 m .49712 .51103 L .50249 .50736 L .537 .911 .745 r
F
.50434 .50605 m .50053 .50825 L p .50406 .50626 L F P
0 g
s
.5151 .50974 m .49897 .51644 L p .50381 .50635 L .183 .006 .391 r
F P
0 g
s
.50282 .50711 m .50053 .50825 L .49712 .51103 L .537 .911 .745 r
F
.49659 .51251 m .50053 .50825 L .49933 .51591 L p .73 .396 .414 r
F P
0 g
s
.47152 .52851 m .48701 .54271 L .48438 .54236 L .45 .357 .659 r
F
.47152 .52851 m .48438 .54236 L .47114 .52915 L F
.48484 .52486 m .48508 .52486 L .48821 .54287 L .666 .311 .362 r
F
.48818 .54287 m .48821 .54287 L .48862 .54521 L F
.48484 .52486 m .48821 .54287 L .48818 .54287 L F
.48297 .52694 m .48497 .52477 L .47214 .52809 L .985 .887 .547 r
F
.48484 .52486 m .48862 .54521 L .48835 .54479 L .666 .311 .362 r
F
.48443 .5387 m .48462 .52486 L .48809 .54439 L F
.48462 .52486 m .48484 .52486 L .48835 .54479 L F
.48462 .52486 m .48835 .54479 L .48809 .54439 L F
.48443 .5387 m .51526 .50968 L .48824 .54194 L .45 .357 .659 r
F
.47376 .52974 m .48443 .53871 L .48589 .54096 L F
.47206 .52817 m .47385 .5297 L .47376 .52974 L F
.47385 .5297 m .48443 .53871 L .47376 .52974 L F
.47206 .52817 m .49007 .54351 L .47206 .52817 L F
.47215 .52805 m .47198 .52809 L .47152 .52851 L .985 .887 .547 r
F
.47515 .52603 m .47476 .52613 L .47152 .52851 L F
.47215 .52807 m .47152 .52851 L p .47223 .52803 L .537 .911 .745 r
F P
0 g
s
.47152 .52851 m .47198 .5281 L .47203 .52814 L .45 .357 .659 r
F
.47192 .52846 m .47214 .52809 L .47152 .52851 L .985 .887 .547 r
F
.47152 .52851 m .47206 .52817 L .48589 .54096 L .45 .357 .659 r
F
.47152 .52851 m .48589 .54096 L .48701 .54271 L F
.47152 .52851 m .47114 .52915 L p .47206 .52817 L 0 0 0 r
F P
0 g
s
.47215 .52807 m .47152 .52851 L p .47206 .52817 L 0 0 0 r
F P
0 g
s
.47152 .52851 m .47203 .52814 L .47206 .52817 L .45 .357 .659 r
F
.48362 .59907 m .46941 .53102 L .47197 .52998 L .666 .311 .362 r
F
.48362 .59907 m .47197 .52998 L .47384 .53184 L F
.48438 .54236 m .47348 .52937 L .48443 .5387 L F
.48362 .59907 m .47384 .53184 L .48438 .54236 L F
.47384 .53184 m .47348 .52937 L .48438 .54236 L F
.26845 .67161 m .42756 .76968 L .41517 .73533 L .909 .526 .28 r
F
.18906 .63714 m .27356 .6841 L .26845 .67161 L F
.29736 .69732 m .42756 .76968 L .29505 .68801 L F
.46251 .7027 m .4625 .70284 L .46243 .70288 L .69 .553 .694 r
F
.49711 .62049 m .4625 .70284 L .46251 .7027 L F
.46383 .72678 m .53342 .65707 L .45914 .73885 L .799 .723 .78 r
F
.53342 .65707 m .55572 .63473 L .53771 .65414 L F
.53342 .65707 m .53771 .65414 L .45914 .73885 L F
.49711 .62049 m .53463 .64326 L .4625 .70284 L .69 .553 .694 r
F
.55572 .63473 m .55576 .6347 L .39671 .80671 L .773 .729 .812 r
F
.53463 .64326 m .54638 .65039 L .53328 .65858 L .69 .553 .694 r
F
.53463 .64326 m .53328 .65858 L .4625 .70284 L F
.39441 .80863 m .57713 .65541 L .42438 .78877 L .773 .729 .812 r
F
.57391 .65822 m .59432 .64203 L .42438 .78877 L F
.57713 .65541 m .57884 .65408 L .57391 .65822 L F
.57884 .65408 m .59432 .64203 L .57391 .65822 L F
.57884 .65408 m .55962 .63052 L .63541 .60654 L p .774 .735 .817 r
F P
0 g
s
.41806 .79423 m .59432 .64203 L .63771 .61361 L .738 .992 .841 r
F
.58945 .6671 m .57782 .65283 L p .58713 .66965 L .844 .742 .751 r
F P
0 g
s
.57782 .65283 m .55962 .63052 L p .5761 .65395 L .844 .742 .751 r
F P
0 g
s
.58713 .66965 m .57782 .65283 L .5761 .65395 L .844 .742 .751 r
F
.65163 .59906 m .67159 .58386 L .70125 .54475 L .196 0 .164 r
F
.65163 .59906 m .70125 .54475 L .72184 .5176 L F
.67159 .58386 m .70272 .56015 L .71376 .53558 L F
.67159 .58386 m .71376 .53558 L .72184 .5176 L F
.63771 .61361 m .63541 .60654 L .70272 .56015 L .738 .992 .841 r
F
.59432 .64203 m .63541 .60654 L .63771 .61361 L F
.57713 .65541 m .63541 .60654 L .59432 .64203 L .773 .729 .812 r
F
.65755 .659 m .65877 .62221 L .54813 .69811 L closepath p .376 .082 .332 r
F P
0 g
s
.55833 .7337 m .54813 .69811 L .65755 .659 L closepath p .448 .222 .478 r
F P
0 g
s
.63541 .60654 m .60964 .69186 L .57884 .65408 L p .774 .735 .817 r
F P
0 g
s
.49083 .77556 m .53288 .76061 L .51755 .7651 L p 0 0 0 r
F P
0 g
s
.51755 .7651 m .41806 .79423 L .46859 .78127 L p 0 0 0 r
F P
0 g
s
.46859 .78127 m .49083 .77556 L p .51755 .7651 L 0 0 0 r
F P
0 g
s
.28539 .79375 m .29567 .78154 L .39441 .80863 L closepath p .642 .151 .07 r
F P
0 g
s
.36619 .81535 m .39441 .80863 L .28539 .79375 L closepath p .517 0 0 r
F P
0 g
s
.20528 .69394 m .20274 .67291 L .29023 .73184 L closepath p .928 .754 .645 r
F P
0 g
s
.29786 .7608 m .29023 .73184 L .20528 .69394 L closepath p .93 .609 .41 r
F P
0 g
s
.18906 .63714 m .36619 .81535 L .39441 .80863 L .933 .617 .418 r
F
.37829 .81247 m .46383 .72678 L .39441 .80863 L .799 .723 .78 r
F
.46383 .72678 m .45914 .73885 L .39441 .80863 L F
.46246 .70326 m .54638 .65039 L .48322 .75194 L .69 .553 .694 r
F
.46246 .70326 m .48322 .75194 L .46618 .76711 L F
.46243 .70288 m .46611 .70058 L .46246 .70326 L F
.46611 .70058 m .54638 .65039 L .46246 .70326 L F
.46246 .70326 m .46383 .72678 L .46469 .67929 L F
.46383 .72678 m .46561 .72218 L .46469 .67929 L F
.55576 .6347 m .56025 .6314 L .57713 .65541 L .773 .729 .812 r
F
.5413 .64533 m .55646 .63419 L .54638 .65039 L .69 .553 .694 r
F
.46469 .67929 m .46561 .72218 L .46709 .71301 L F
.46868 .68377 m .46965 .68252 L .46675 .71926 L .799 .723 .78 r
F
.46965 .68252 m .49402 .65123 L .47762 .69584 L F
.49402 .65123 m .49605 .65615 L .47762 .69584 L F
.46965 .68252 m .47762 .69584 L .46675 .71926 L F
.46561 .72218 m .47053 .70953 L .47198 .68255 L .69 .553 .694 r
F
.48809 .54439 m .48835 .54479 L .5003 .61271 L .666 .311 .362 r
F
.48362 .59907 m .54638 .65039 L .45619 .59567 L .69 .553 .694 r
F
.50024 .61266 m .5003 .61271 L .50468 .63756 L .666 .311 .362 r
F
.48809 .54439 m .5003 .61271 L .50024 .61266 L F
.48843 .62773 m .48443 .5387 L .49873 .60852 L F
.4831 .63767 m .4833 .6229 L .48843 .62773 L F
.4833 .6229 m .48443 .5387 L .48843 .62773 L F
.47701 .59825 m .46896 .52886 L .48362 .59907 L F
.45402 .55847 m .48938 .58461 L .48919 .59347 L .69 .553 .694 r
F
.48443 .5387 m .48809 .54439 L .50468 .63756 L .666 .311 .362 r
F
.48938 .58461 m .55646 .63419 L .48919 .59347 L .69 .553 .694 r
F
.48919 .59347 m .55646 .63419 L .5413 .64533 L F
.52346 .50427 m .54179 .49579 L .52162 .50644 L .45 .357 .659 r
F
.48443 .5387 m .47348 .52937 L .48462 .52486 L .666 .311 .362 r
F
.48497 .52477 m .47223 .52803 L .47214 .52809 L .985 .887 .547 r
F
.47348 .52937 m .47218 .52804 L .48462 .52486 L .666 .311 .362 r
F
.47197 .52998 m .47216 .52825 L .47348 .52937 L F
.47216 .52825 m .47218 .52804 L .47348 .52937 L F
.4775 .52793 m .48043 .52652 L .48443 .5387 L .45 .357 .659 r
F
.47515 .52603 m .47215 .52807 L .47223 .52803 L .537 .911 .745 r
F
.47492 .52594 m .4774 .52493 L .47489 .5261 L .255 0 0 r
F
.47251 .52634 m .4774 .52493 L .47386 .52637 L F
.47511 .52605 m .47215 .52807 L .47515 .52603 L .537 .911 .745 r
F
.47489 .5261 m .4774 .52493 L .47515 .52603 L .255 0 0 r
F
.48398 .52304 m .48301 .52399 L p .47515 .52603 L F P
0 g
s
.4774 .52493 m .48398 .52304 L .47515 .52603 L .255 0 0 r
F
.4774 .52493 m .4879 .51854 L p .4771 .52508 L .537 .911 .745 r
F P
0 g
s
.4879 .51854 m .49712 .51103 L .47515 .52603 L .537 .911 .745 r
F
.4879 .51854 m .47515 .52603 L .4771 .52508 L F
.48462 .52486 m .48463 .52368 L .48484 .52486 L .666 .311 .362 r
F
.48802 .51844 m .49712 .51103 L .4879 .51854 L .537 .911 .745 r
F
.48398 .52304 m .48301 .52399 L p .48591 .52186 L 0 0 0 r
F P
0 g
s
.48497 .52477 m .48854 .5209 L .4788 .52635 L .985 .887 .547 r
F
.48301 .52399 m .48296 .52404 L p .48308 .52396 L 0 0 0 r
F P
0 g
s
.48308 .52396 m .48591 .52186 L .48301 .52399 L 0 0 0 r
F
.4788 .52635 m .49849 .51009 L .47223 .52803 L .985 .887 .547 r
F
.48854 .5209 m .49849 .51009 L .4788 .52635 L F
.47231 .52801 m .47484 .52639 L .47487 .52622 L 0 0 0 r
F
.47231 .52801 m .47487 .52622 L .47488 .5262 L F
.47211 .52813 m .47231 .52801 L .47488 .5262 L F
.47215 .52807 m .47211 .52813 L .47488 .5262 L F
.48301 .52399 m .48043 .52652 L p .47484 .52639 L .255 0 0 r
F P
0 g
s
.47386 .52637 m .47492 .52594 L .47489 .5261 L .255 0 0 r
F
.47135 .52631 m .47502 .52536 L .47172 .52632 L F
.47087 .52715 m .38387 .5491 L .46986 .52629 L .666 .311 .362 r
F
.47502 .52536 m .47498 .52563 L .45891 .53024 L .255 0 0 r
F
.47502 .52536 m .45891 .53024 L .45229 .53196 L F
.38387 .5491 m .3623 .55454 L .38304 .54909 L .666 .311 .362 r
F
.3834 .54908 m .4751 .52489 L .47502 .52536 L .255 0 0 r
F
.3623 .55454 m .38304 .54909 L p .3834 .54908 L F P
0 g
s
.38304 .54909 m .4751 .52489 L p .3834 .54908 L .255 0 0 r
F P
0 g
s
.40283 .55075 m .36382 .55574 L .46896 .52886 L .666 .311 .362 r
F
.37091 .56132 m .36484 .55655 L .40283 .55075 L F
.36484 .55655 m .36382 .55574 L .40283 .55075 L F
.36382 .55574 m .3623 .55454 L .46896 .52886 L F
.38821 .54893 m .39182 .5492 L p .39659 .5487 L .112 .66 .815 r
F P
0 g
s
.39659 .5487 m .39684 .54865 L .38821 .54893 L .112 .66 .815 r
F
.46941 .53102 m .47114 .52915 L .47197 .52998 L .666 .311 .362 r
F
.47114 .52915 m .48438 .54236 L .46495 .53976 L .45 .357 .659 r
F
.48438 .54236 m .48605 .54402 L .46495 .53976 L F
.46495 .53976 m .48605 .54402 L .45402 .55847 L F
.47384 .53184 m .47197 .52998 L .47348 .52937 L .666 .311 .362 r
F
.4878 .52668 m .51526 .50968 L .49698 .52689 L .45 .357 .659 r
F
.48043 .52652 m .49608 .51895 L .4878 .52668 L F
.49608 .51895 m .51526 .50968 L .4878 .52668 L F
.50434 .50605 m .50381 .50635 L p .50398 .506 L .871 .798 .776 r
F P
0 g
s
.50434 .50605 m .5026 .50581 L .50447 .50575 L .871 .798 .776 r
F
.50381 .50635 m .50409 .50577 L .51093 .5009 L .183 .006 .391 r
F
.50409 .50577 m .5085 .50136 L .51093 .5009 L F
.50381 .50635 m .51093 .5009 L .5151 .50974 L F
.50357 .50653 m .50053 .50825 L .50282 .50711 L .537 .911 .745 r
F
.50249 .50736 m .50409 .50577 L .50381 .50635 L .183 .006 .391 r
F
.50053 .50825 m .5026 .50581 L p .50398 .506 L .871 .798 .776 r
F P
0 g
s
.50381 .50635 m .50053 .50825 L p .50398 .506 L .871 .798 .776 r
F P
0 g
s
.5211 .48999 m .50053 .50825 L .49933 .51591 L p .108 0 .251 r
F P
0 g
s
.51725 .54959 m .52303 .57297 L .51691 .55301 L .752 .501 .553 r
F
.52162 .50644 m .52245 .54538 L .51725 .54959 L F
.52245 .54538 m .52303 .57297 L .51725 .54959 L F
.47249 .53348 m .4675 .54023 L .47176 .53697 L 0 0 0 r
F
.48605 .54402 m .48736 .54533 L .45402 .55847 L .45 .357 .659 r
F
.52563 .50898 m .52635 .5046 L .52532 .54852 L .218 .048 .425 r
F
.52509 .54869 m .52532 .54852 L .52478 .57195 L F
.52563 .50898 m .52532 .54852 L .52509 .54869 L F
.48911 .54463 m .50253 .55693 L .51096 .58757 L .45 .357 .659 r
F
.50253 .55693 m .55563 .60558 L .52234 .59216 L F
.50253 .55693 m .52234 .59216 L .51096 .58757 L F
.52331 .59388 m .53004 .59732 L .52197 .6001 L .69 .553 .694 r
F
.52466 .57202 m .52478 .57195 L .52444 .58627 L .218 .048 .425 r
F
.52176 .50676 m .52434 .57221 L p .52162 .50644 L .752 .501 .553 r
F P
0 g
s
.5246 .57205 m .52444 .58627 L .52438 .58565 L .218 .048 .425 r
F
.52465 .57203 m .52444 .58627 L .5246 .57205 L F
.52502 .54875 m .52444 .58627 L .52498 .54878 L F
.53004 .59732 m .53808 .60581 L .51404 .60284 L .69 .553 .694 r
F
.48862 .54521 m .493 .54007 L .514 .58036 L .218 .048 .425 r
F
.48911 .54463 m .51096 .58757 L .45402 .55847 L .45 .357 .659 r
F
.51096 .58757 m .49128 .54889 L .514 .58036 L .218 .048 .425 r
F
.49434 .54788 m .48994 .57609 L p .49321 .56717 L .108 0 .251 r
F P
0 g
s
.45402 .55847 m .52331 .59388 L .51404 .60284 L .69 .553 .694 r
F
.52331 .59388 m .52197 .6001 L .51404 .60284 L F
.4913 .57382 m .49288 .56936 L p .48994 .57609 L .108 0 .251 r
F P
0 g
s
.52434 .57221 m .5243 .57223 L .52162 .50644 L .752 .501 .553 r
F
.514 .58036 m .493 .54007 L .51002 .52007 L .218 .048 .425 r
F
.52081 .55198 m .51759 .55096 L p .51919 .55323 L .602 .275 .388 r
F P
0 g
s
.51919 .55323 m .51759 .55096 L .51785 .55204 L .602 .275 .388 r
F
.52387 .59488 m .52419 .59723 L .52383 .5969 L .218 .048 .425 r
F
.55563 .60558 m .55626 .60768 L .51096 .58757 L .45 .357 .659 r
F
.55626 .60768 m .53004 .59732 L .52331 .59388 L F
.52269 .59277 m .52331 .59388 L .51096 .58757 L F
.55626 .60768 m .52331 .59388 L .52269 .59277 L F
.52563 .50898 m .52422 .59502 L .52387 .59488 L .218 .048 .425 r
F
.52422 .59502 m .52419 .59723 L .52387 .59488 L F
.52907 .50671 m .548 .57093 L .55508 .60721 L F
.55386 .60673 m .55508 .60721 L .55915 .62809 L F
.52907 .50671 m .55508 .60721 L .55386 .60673 L F
.52507 .59206 m .52907 .50671 L .55915 .62809 L F
.56563 .61475 m .56491 .61444 L .55626 .60768 L .45 .357 .659 r
F
.55732 .61117 m .55822 .6023 L .55617 .60156 L .74 .58 .675 r
F
.55981 .62879 m .55942 .62942 L .55943 .62928 L .91 .982 .731 r
F
.55981 .62879 m .55949 .6292 L .55879 .62999 L F
.55949 .6292 m .55809 .631 L .55874 .63007 L F
.55949 .6292 m .55874 .63007 L .55879 .62999 L F
.45402 .55847 m .45568 .55668 L p .48471 .5757 L .73 .396 .414 r
F P
0 g
s
.55943 .62928 m .55678 .63367 L .5579 .63139 L .91 .982 .731 r
F
.55849 .63049 m .5579 .63139 L .55809 .631 L F
.55943 .62928 m .5579 .63139 L .55849 .63049 L F
.55942 .62942 m .55678 .63367 L .55943 .62928 L F
.55678 .63367 m .55675 .63362 L .55809 .631 L F
.55879 .62999 m .55809 .631 L .55834 .63052 L F
.48948 .62577 m .49873 .60852 L .50468 .63756 L .666 .311 .362 r
F
.45402 .55847 m .54638 .65039 L .45502 .57568 L .69 .553 .694 r
F
.53808 .60581 m .542 .60996 L .51404 .60284 L F
.51217 .58881 m .51297 .5867 L .52383 .5969 L .712 .562 .682 r
F
.50875 .60714 m .52646 .60573 L .51061 .59325 L .772 .532 .573 r
F
.51067 .59284 m .50036 .61276 L .51156 .58615 L .218 .048 .425 r
F
.50468 .63756 m .50127 .61795 L .51067 .59284 L F
.50127 .61795 m .50036 .61276 L .51067 .59284 L F
.51065 .63679 m .52001 .61841 L .50002 .60784 L .772 .532 .573 r
F
.52001 .61841 m .52646 .60573 L .50002 .60784 L F
.5003 .61271 m .50036 .61276 L .50468 .63756 L .666 .311 .362 r
F
.50468 .63756 m .51065 .63679 L p .48829 .57589 L .772 .532 .573 r
F P
0 g
s
.48826 .57589 m .48829 .57589 L .48818 .57558 L .772 .532 .573 r
F
.50468 .63756 m .48829 .57589 L .48826 .57589 L F
.50002 .60784 m .50875 .60714 L .48818 .57558 L F
.48611 .57565 m .50468 .63756 L p .48818 .57558 L F P
0 g
s
.4831 .63767 m .47701 .59825 L .48362 .59907 L .666 .311 .362 r
F
.48259 .70413 m .49605 .65615 L .50643 .68135 L .799 .723 .78 r
F
.46675 .71926 m .47762 .69584 L .48259 .70413 L F
.47762 .69584 m .49605 .65615 L .48259 .70413 L F
.46819 .53472 m .45402 .55847 L .47249 .53348 L 0 0 0 r
F
.45667 .53829 m .42873 .54313 L .46914 .53042 L .666 .311 .362 r
F
.37688 .57602 m .38173 .56689 L .41809 .56265 L .206 0 0 r
F
.36915 .57226 m .38173 .56689 L .37688 .57602 L F
.30829 .59827 m .41809 .56265 L .40238 .57258 L F
.38173 .56689 m .41888 .55101 L .42414 .55213 L F
.38173 .56689 m .42414 .55213 L .43209 .55381 L F
.41809 .56265 m .43209 .55381 L .45402 .55847 L F
.38173 .56689 m .43209 .55381 L .41809 .56265 L F
.40679 .58955 m .39286 .57859 L .47701 .59825 L .666 .311 .362 r
F
.30829 .59827 m .36915 .57226 L .37688 .57602 L .206 0 0 r
F
.30829 .59827 m .3815 .57828 L .30368 .5687 L F
.3815 .57828 m .40238 .57258 L .38431 .57187 L F
.3815 .57828 m .38431 .57187 L .379 .57235 L F
.46096 .67762 m .46898 .6812 L .47422 .6408 L .69 .553 .694 r
F
.46898 .6812 m .46937 .68138 L .46961 .67939 L F
.46898 .6812 m .46961 .67939 L .47422 .6408 L F
.48194 .641 m .48325 .65069 L .48029 .64581 L .989 .738 .453 r
F
.48028 .64576 m .48029 .64581 L .48028 .64578 L F
.48194 .641 m .48029 .64581 L .48028 .64576 L F
.39286 .57859 m .40269 .57238 L .47701 .59825 L .666 .311 .362 r
F
.48196 .64095 m .47701 .59825 L .4831 .63767 L F
.46937 .68138 m .47265 .67 L .47422 .6408 L .69 .553 .694 r
F
.46469 .67929 m .46573 .69398 L .46882 .68114 L F
.46573 .69398 m .46709 .71301 L .46868 .68377 L F
.46573 .69398 m .46868 .68377 L .46882 .68114 L F
.47422 .6408 m .47265 .67 L .46232 .66451 L .896 .804 .75 r
F
.45813 .65669 m .46232 .66451 L .45444 .66033 L F
.47422 .6408 m .46232 .66451 L .45813 .65669 L F
.45809 .65662 m .379 .57235 L .47264 .64182 L 0 .126 .674 r
F
.45809 .65662 m .44106 .63476 L .44721 .64503 L F
.47422 .6408 m .45813 .65669 L .47289 .64156 L .896 .804 .75 r
F
.45813 .65669 m .45444 .66033 L .45809 .65662 L F
.45813 .65669 m .45809 .65662 L .47289 .64156 L F
.48962 .65478 m .49402 .65123 L .46868 .68377 L .866 .996 .785 r
F
.49224 .65114 m .46868 .68377 L .46958 .68067 L F
.46882 .68114 m .46709 .71301 L .47198 .68255 L .69 .553 .694 r
F
.46096 .67762 m .46246 .70326 L .46469 .67929 L F
.46958 .68067 m .46868 .68377 L .36619 .81535 L .866 .996 .785 r
F
.28761 .66579 m .41517 .73533 L .38186 .6932 L .888 .474 .211 r
F
.18906 .63714 m .2937 .68258 L .28761 .66579 L F
.2937 .68258 m .41517 .73533 L .28761 .66579 L F
.2707 .79791 m .28539 .79375 L .36619 .81535 L closepath p .44 0 0 r
F P
0 g
s
.20671 .71117 m .20528 .69394 L .29786 .7608 L closepath p .926 .675 .538 r
F P
0 g
s
.29567 .78154 m .29786 .7608 L .20671 .71117 L closepath p .916 .565 .357 r
F P
0 g
s
.33956 .81792 m .36619 .81535 L .2707 .79791 L closepath p .415 0 0 r
F P
0 g
s
.20274 .67291 m .20055 .64942 L .18906 .63714 L closepath p .866 .68 .151 r
F P
0 g
s
.18906 .63714 m .33956 .81792 L .36619 .81535 L .929 .568 .314 r
F
.33956 .81792 m .35438 .80052 L .35632 .79961 L .866 .996 .785 r
F
.33956 .81792 m .46834 .67725 L .36619 .81535 L F
.46834 .67725 m .46929 .68104 L .36619 .81535 L F
.35632 .79961 m .43158 .70982 L .47159 .67371 L F
.48822 .63715 m .4879 .65189 L p .49619 .63504 L .745 .509 .573 r
F P
0 g
s
.48567 .65832 m .48365 .65589 L .49224 .65114 L .866 .996 .785 r
F
.48365 .65589 m .4879 .65189 L .49224 .65114 L F
.49224 .65114 m .49359 .65121 L .48962 .65478 L F
.49359 .65121 m .49402 .65123 L .48962 .65478 L F
.4879 .65189 m .49401 .64615 L .49619 .63504 L .745 .509 .573 r
F
.48822 .63715 m .4879 .65189 L p .48383 .63558 L .989 .738 .453 r
F P
0 g
s
.48146 .63669 m .40679 .58955 L .47701 .59825 L .666 .311 .362 r
F
.48196 .64095 m .47833 .63847 L .48146 .63669 L F
.47833 .63847 m .40679 .58955 L .48146 .63669 L F
.47984 .64702 m .40679 .58955 L .47866 .6387 L F
.48028 .64578 m .47866 .6387 L .48196 .64095 L F
.47984 .64702 m .47866 .6387 L .48028 .64578 L F
.49224 .65114 m .48926 .65061 L .50468 .63756 L .866 .996 .785 r
F
.48677 .64737 m .48308 .6494 L .48068 .63163 L .989 .738 .453 r
F
.48677 .64737 m .48068 .63163 L .48184 .62757 L F
.45473 .65036 m .44106 .63476 L .45641 .65349 L 0 .126 .674 r
F
.45641 .65349 m .44106 .63476 L .45809 .65662 L F
.379 .57235 m .38376 .57192 L .47287 .64159 L F
.48124 .65058 m .48028 .64578 L p .48325 .65069 L .989 .738 .453 r
F P
0 g
s
.48074 .64783 m .48072 .64773 L .48295 .64947 L 0 .126 .674 r
F
.48926 .65061 m .50101 .63957 L .50468 .63756 L .866 .996 .785 r
F
.4879 .65189 m .48308 .6494 L .48677 .64737 L .989 .738 .453 r
F
.4879 .65189 m .48351 .65265 L .48308 .6494 L F
.48365 .65589 m .48183 .6537 L .4879 .65189 L .866 .996 .785 r
F
.48183 .6537 m .48127 .65303 L .48172 .65296 L F
.48183 .6537 m .48172 .65296 L .4879 .65189 L F
.47159 .67371 m .47326 .67014 L .48567 .65832 L F
.47326 .67014 m .48127 .65303 L .48183 .6537 L F
.48288 .66097 m .48183 .6537 L .48567 .65832 L F
.47326 .67014 m .48183 .6537 L .48288 .66097 L F
.48325 .65069 m .48351 .65265 L .48124 .65058 L .989 .738 .453 r
F
.47159 .67371 m .49224 .65114 L .46958 .68067 L .866 .996 .785 r
F
.36619 .81535 m .49291 .69427 L .49409 .69346 L .799 .723 .78 r
F
.49291 .69427 m .5566 .63341 L .49409 .69346 L F
.48731 .68119 m .48938 .6873 L .48914 .6751 L .96 .802 .642 r
F
.49605 .65615 m .50468 .63756 L .50643 .68135 L .799 .723 .78 r
F
.46659 .71967 m .55572 .63473 L .46383 .72678 L F
.48614 .6522 m .48295 .64947 L .49224 .65114 L .866 .996 .785 r
F
.48172 .65296 m .48124 .65058 L p .48351 .65265 L .989 .738 .453 r
F P
0 g
s
.379 .57235 m .47287 .64159 L .47264 .64182 L 0 .126 .674 r
F
.37001 .56832 m .36481 .55656 L p .36439 .557 L .668 .896 .979 r
F P
0 g
s
.36481 .55656 m .3623 .55454 L .36484 .55654 L 0 .126 .674 r
F
.3648 .55656 m .35593 .55902 L .35159 .57057 L .668 .896 .979 r
F
.36436 .55674 m .36431 .55669 L .36481 .55656 L 0 .126 .674 r
F
.36431 .55669 m .3623 .55454 L .36481 .55656 L F
.3623 .55454 m .47135 .52631 L .45567 .53089 L .255 0 0 r
F
.36481 .55655 m .36427 .55533 L p .3682 .55445 L .742 .932 .951 r
F P
0 g
s
.36925 .55534 m .3682 .55445 L .39182 .5492 L .742 .932 .951 r
F
.36481 .55655 m .3682 .55445 L .36925 .55534 L F
.38821 .54893 m .39182 .5492 L p .36427 .55533 L F P
0 g
s
.39197 .54948 m .37586 .55223 L p .38821 .54893 L .255 0 0 r
F P
0 g
s
.38821 .54893 m .45567 .53089 L .39457 .54872 L .255 0 0 r
F
.40269 .57238 m .37091 .56132 L .40876 .54941 L .666 .311 .362 r
F
.42298 .54959 m .40876 .54941 L .42873 .54313 L F
.42697 .5513 m .42093 .54956 L p .41281 .5508 L .112 .66 .815 r
F P
0 g
s
.41888 .55101 m .45988 .54844 L .45402 .55847 L .206 0 0 r
F
.41281 .5508 m .41709 .55112 L p .41888 .55101 L .112 .66 .815 r
F P
0 g
s
.40269 .57238 m .40876 .54941 L .42298 .54959 L .666 .311 .362 r
F
.42093 .54956 m .41567 .54805 L p .39182 .5492 L .112 .66 .815 r
F P
0 g
s
.41567 .54805 m .39709 .54864 L .39182 .5492 L .112 .66 .815 r
F
.38821 .54893 m .39457 .54872 L .39197 .54948 L .255 0 0 r
F
.41567 .54805 m .41218 .54705 L p .39709 .54864 L .112 .66 .815 r
F P
0 g
s
.37586 .55223 m .3623 .55454 L p .45567 .53089 L .255 0 0 r
F P
0 g
s
.36255 .54966 m .3623 .55454 L .36728 .55367 L p .347 .743 .984 r
F P
0 g
s
.37586 .55223 m .3623 .55454 L .36728 .55367 L p .125 .672 .704 r
F P
0 g
s
.36431 .55669 m .36363 .55389 L .3623 .55454 L 0 .126 .674 r
F
.36185 .54692 m .38821 .54893 L p .36363 .55389 L .742 .932 .951 r
F P
0 g
s
.40269 .57238 m .42873 .54313 L .45667 .53829 L .666 .311 .362 r
F
.47198 .52809 m .47206 .52817 L .47206 .52817 L .45 .357 .659 r
F
.47152 .52851 m .47198 .52809 L .47198 .5281 L F
.46941 .53102 m .46896 .52886 L .46949 .52873 L .666 .311 .362 r
F
.47023 .52892 m .47152 .52851 L .47114 .52915 L p .599 .105 .051 r
F P
0 g
s
.47114 .52915 m .46949 .52873 L .47218 .52804 L .666 .311 .362 r
F
.46941 .53102 m .46949 .52873 L .47114 .52915 L F
.44083 .54123 m .43013 .54298 L .47023 .52892 L .583 .945 .856 r
F
.46914 .53042 m .45909 .53358 L .46902 .52942 L .666 .311 .362 r
F
.43848 .54978 m .47114 .52915 L .45988 .54844 L .206 0 0 r
F
.47023 .52892 m .46582 .53695 L .44181 .54098 L .599 .105 .051 r
F
.45373 .53407 m .47023 .52892 L p .41567 .54805 L .583 .945 .856 r
F P
0 g
s
.44181 .54098 m .42895 .54317 L p .44195 .5409 L .255 0 0 r
F P
0 g
s
.45373 .53407 m .47023 .52892 L p .44181 .54098 L .599 .105 .051 r
F P
0 g
s
.42937 .54302 m .44209 .54082 L .42895 .54317 L .255 0 0 r
F
.47114 .52915 m .45402 .55847 L p .47023 .52892 L .599 .105 .051 r
F P
0 g
s
.47114 .52915 m .47218 .52804 L .47197 .52998 L .666 .311 .362 r
F
.47488 .52616 m .48301 .52399 L .47484 .52639 L .255 0 0 r
F
.47489 .5261 m .47515 .52603 L .47488 .52616 L F
.47515 .52603 m .48301 .52399 L .47488 .52616 L F
.49849 .51009 m .50244 .50581 L .47476 .52613 L .985 .887 .547 r
F
.49849 .51009 m .47476 .52613 L .47515 .52603 L F
.50053 .50825 m .47488 .52616 L p .49712 .51103 L .537 .911 .745 r
F P
0 g
s
.47488 .52616 m .47215 .52807 L p .47511 .52605 L .537 .911 .745 r
F P
0 g
s
.49712 .51103 m .47488 .52616 L .47511 .52605 L .537 .911 .745 r
F
.48296 .52404 m .48043 .52652 L p .48973 .52028 L 0 0 0 r
F P
0 g
s
.48468 .52447 m .48973 .52028 L .48043 .52652 L 0 0 0 r
F
.48679 .52271 m .50186 .51581 L .48973 .52028 L F
.50396 .51437 m .48973 .52028 L p .50186 .51581 L F P
0 g
s
.49608 .51895 m .51526 .50968 L .48679 .52271 L 0 0 0 r
F
.48468 .52447 m .49608 .51895 L .48679 .52271 L F
.48973 .52028 m .48944 .5204 L p .48296 .52404 L F P
0 g
s
.48296 .52404 m .48944 .5204 L .48308 .52396 L 0 0 0 r
F
.47206 .52817 m .49968 .51634 L .47386 .5297 L .45 .357 .659 r
F
.51526 .50968 m .50396 .51437 L p .50186 .51581 L 0 0 0 r
F P
0 g
s
.49968 .51634 m .51526 .50968 L .50018 .51697 L .45 .357 .659 r
F
.49968 .51634 m .50018 .51697 L .47386 .5297 L F
.47258 .52784 m .51526 .50968 L .47206 .52817 L F
.51813 .49835 m .5211 .48999 L p .49933 .51591 L .108 0 .251 r
F P
0 g
s
.47526 .52596 m .47511 .52605 L .47515 .52603 L .537 .911 .745 r
F
.49712 .51103 m .47511 .52605 L .47526 .52596 L F
.49712 .51103 m .47511 .52605 L .47511 .52605 L F
.49659 .51251 m .50053 .50825 L p .47488 .5262 L 0 0 0 r
F P
0 g
s
.47484 .52639 m .49659 .51251 L .47488 .5262 L 0 0 0 r
F
.47562 .52641 m .5174 .49667 L .51665 .50743 L .45 .357 .659 r
F
.51526 .50968 m .5151 .50974 L p .52038 .50356 L .183 .006 .391 r
F P
0 g
s
.47488 .52616 m .47215 .52807 L p .47488 .5262 L 0 0 0 r
F P
0 g
s
.50244 .50581 m .47198 .52809 L .47215 .52805 L .985 .887 .547 r
F
.47198 .52809 m .51746 .50705 L .51526 .50968 L .45 .357 .659 r
F
.48043 .52652 m .49698 .52689 L .48443 .5387 L F
.49905 .51775 m .49434 .54788 L p .49579 .51999 L .73 .396 .414 r
F P
0 g
s
.49434 .54788 m .49303 .54643 L .49579 .51999 L .73 .396 .414 r
F
.48994 .57609 m .48981 .57605 L .49298 .54637 L F
.49303 .54643 m .49298 .54637 L .49579 .51999 L F
.48994 .57609 m .49298 .54637 L .49303 .54643 L F
.47386 .5297 m .4775 .52793 L .48443 .5387 L .45 .357 .659 r
F
.47861 .53172 m .47934 .53132 L p .4723 .53655 L .575 .401 .609 r
F P
0 g
s
.49905 .51775 m .49434 .54788 L p .51117 .51284 L .108 0 .251 r
F P
0 g
s
.52176 .50676 m .52457 .57797 L p .52209 .50588 L .161 .053 .474 r
F P
0 g
s
.52457 .57797 m .52462 .57732 L .52209 .50588 L .161 .053 .474 r
F
.55929 .62824 m .55626 .60768 L .55735 .61127 L 0 0 .271 r
F
.55626 .60768 m .55732 .61117 L .53004 .59732 L .45 .357 .659 r
F
.55732 .61117 m .55628 .61073 L .53004 .59732 L F
.52635 .5046 m .52697 .5042 L .5245 .5868 L .218 .048 .425 r
F
.52444 .58627 m .5245 .5868 L .52419 .59723 L F
.52635 .5046 m .5245 .5868 L .52444 .58627 L F
.51018 .52071 m .51002 .52007 L .51068 .51929 L F
.55886 .62993 m .48824 .57558 L p .55818 .6307 L .772 .532 .573 r
F P
0 g
s
.48775 .57105 m .48877 .57556 L .48323 .5724 L .73 .396 .414 r
F
.48381 .56928 m .48323 .5724 L .45568 .55668 L F
.48775 .57105 m .48323 .5724 L .48381 .56928 L F
.48381 .56925 m .48472 .5643 L .4714 .53743 L .602 .275 .388 r
F
.47934 .53132 m .48006 .53211 L .4723 .53655 L .575 .401 .609 r
F
.48443 .53871 m .49007 .54351 L .48589 .54096 L .45 .357 .659 r
F
.48886 .54182 m .4723 .53655 L p .48006 .53211 L .575 .401 .609 r
F P
0 g
s
.48472 .5643 m .48576 .55865 L .47154 .53729 L .602 .275 .388 r
F
.48472 .5643 m .47154 .53729 L .4714 .53743 L F
.4675 .54023 m .46479 .54389 L .4723 .53655 L 0 0 0 r
F
.47249 .53348 m .47176 .53697 L .47231 .53628 L F
.47249 .53348 m .4723 .53655 L .47268 .53618 L F
.55818 .6307 m .48824 .57558 L .48818 .57558 L .772 .532 .573 r
F
.48589 .54096 m .49007 .54351 L .48944 .54425 L .45 .357 .659 r
F
.49579 .51999 m .48981 .57605 L .4854 .56061 L .73 .396 .414 r
F
.50875 .60714 m .51061 .59325 L .48818 .57558 L .772 .532 .573 r
F
.51297 .5867 m .51156 .58615 L .514 .58036 L .218 .048 .425 r
F
.51078 .59254 m .51142 .59083 L .55357 .62484 L .712 .562 .682 r
F
.51067 .59284 m .51156 .58615 L .51297 .5867 L .218 .048 .425 r
F
.49434 .54788 m .48994 .57609 L p .49303 .54643 L .73 .396 .414 r
F P
0 g
s
.48994 .57609 m .49288 .56936 L .49321 .56717 L .108 0 .251 r
F
.48885 .57263 m .52383 .5969 L .5232 .60034 L .712 .562 .682 r
F
.5271 .50001 m .52907 .50671 L .52507 .59217 L .218 .048 .425 r
F
.5271 .50001 m .52507 .59217 L .52496 .59115 L F
.5271 .50001 m .5248 .59781 L .52458 .59761 L F
.55886 .62993 m .48824 .57558 L p .55359 .62486 L .712 .562 .682 r
F P
0 g
s
.48833 .57561 m .55357 .62484 L .48824 .57558 L .712 .562 .682 r
F
.55357 .62484 m .55359 .62486 L .48824 .57558 L F
.5232 .60034 m .52383 .5969 L .55357 .62484 L F
.52444 .59747 m .52431 .60832 L .52413 .60869 L .218 .048 .425 r
F
.5271 .50001 m .52458 .59761 L .52444 .59747 L F
.52458 .59761 m .52431 .60832 L .52444 .59747 L F
.55359 .62486 m .55891 .62985 L .55886 .62993 L .712 .562 .682 r
F
.52001 .61841 m .50931 .65141 L p .51555 .64766 L .744 .572 .661 r
F P
0 g
s
.52433 .62069 m .51555 .64766 L .54353 .63085 L .744 .572 .661 r
F
.52001 .61841 m .51555 .64766 L .52433 .62069 L F
.52001 .61841 m .50931 .65141 L p .51008 .64298 L .985 .886 .642 r
F P
0 g
s
.51459 .62905 m .51008 .64298 L .51065 .63679 L .985 .886 .642 r
F
.52001 .61841 m .51008 .64298 L .51459 .62905 L F
.52001 .61841 m .55818 .6307 L .52646 .60573 L .772 .532 .573 r
F
.50931 .65141 m .54617 .63224 L .54353 .63085 L .744 .572 .661 r
F
.51065 .63679 m .54617 .63224 L p .52001 .61841 L .772 .532 .573 r
F P
0 g
s
.54617 .63224 m .55818 .6307 L p .52001 .61841 L .772 .532 .573 r
F P
0 g
s
.54617 .63224 m .52507 .59206 L .55897 .62979 L .218 .048 .425 r
F
.54617 .63224 m .55897 .62979 L .55818 .6307 L F
.52507 .59206 m .55915 .62809 L .55962 .63052 L F
.55357 .62484 m .55934 .62919 L .55359 .62486 L .712 .562 .682 r
F
.55359 .62486 m .55934 .62919 L .55891 .62985 L F
.50659 .68119 m .50928 .65178 L .55818 .6307 L .799 .723 .78 r
F
.50531 .65349 m .54617 .63224 L .55818 .6307 L F
.50643 .68135 m .55818 .6307 L .5566 .63341 L F
.542 .60996 m .55738 .61388 L .55981 .62879 L .69 .553 .694 r
F
.55738 .61388 m .56159 .62594 L .55981 .62879 L F
.55945 .62904 m .55869 .61176 L .55732 .61117 L .74 .58 .675 r
F
.55981 .62879 m .55879 .62999 L .55996 .6283 L .91 .982 .731 r
F
.55962 .63052 m .55954 .6289 L .55945 .62904 L .74 .58 .675 r
F
.55954 .6289 m .55869 .61176 L .55945 .62904 L F
.54942 .60722 m .55628 .61073 L .542 .60996 L .69 .553 .694 r
F
.55628 .61073 m .55738 .61388 L .542 .60996 L F
.55357 .62484 m .54982 .5974 L .55934 .62919 L .712 .562 .682 r
F
.55626 .60768 m .5537 .59028 L .55726 .61071 L 0 0 .271 r
F
.5537 .59028 m .55137 .57182 L .55726 .61071 L F
.548 .57093 m .55626 .60768 L .55508 .60721 L .218 .048 .425 r
F
.55052 .57948 m .55626 .60768 L .548 .57093 L F
.55052 .57948 m .5537 .59028 L .55626 .60768 L F
.53602 .55617 m .55555 .60134 L .53349 .5827 L .751 .554 .629 r
F
.55869 .61176 m .55822 .6023 L .55732 .61117 L .74 .58 .675 r
F
.54179 .49579 m .54538 .51262 L p .54384 .51083 L .751 .554 .629 r
F P
0 g
s
.56649 .62835 m .56662 .61566 L .5842 .62274 L 0 0 .271 r
F
.56517 .60746 m .56514 .60713 L .56566 .60789 L .45 .357 .659 r
F
.54538 .51262 m .56499 .60473 L p .54384 .51083 L .751 .554 .629 r
F P
0 g
s
.56499 .60473 m .5649 .6047 L .54384 .51083 L .751 .554 .629 r
F
.55916 .60883 m .55913 .60872 L .56662 .61565 L .45 .357 .659 r
F
.56662 .61566 m .56662 .61565 L .56749 .61645 L F
.55916 .60883 m .56662 .61565 L .56662 .61566 L F
.56649 .62835 m .56563 .6148 L .56176 .61347 L .74 .58 .675 r
F
.56563 .6148 m .56499 .60473 L .56176 .61347 L F
.56176 .61347 m .56499 .60473 L .55822 .6023 L F
.56666 .61255 m .56661 .61254 L .54384 .51083 L .751 .554 .629 r
F
.55903 .61861 m .56162 .61303 L .55869 .61176 L .74 .58 .675 r
F
.56038 .62249 m .56162 .61303 L .55903 .61861 L F
.55986 .62844 m .56162 .61303 L .55954 .6289 L F
.55732 .61117 m .56632 .61554 L .55735 .61127 L .45 .357 .659 r
F
.56491 .61444 m .56632 .61554 L .55732 .61117 L F
.55735 .61127 m .55726 .61071 L .55646 .60367 L 0 0 .271 r
F
.55822 .6023 m .56128 .57961 L .55558 .59399 L .74 .58 .675 r
F
.56128 .57961 m .56272 .56892 L .55558 .59399 L F
.55207 .56924 m .55137 .57182 L .5476 .53349 L 0 0 .271 r
F
.55726 .61071 m .55322 .58403 L .55207 .56924 L F
.55322 .58403 m .55137 .57182 L .55207 .56924 L F
.5799 .5151 m .54354 .50676 L p .55918 .55238 L .594 .413 .606 r
F P
0 g
s
.54233 .49056 m .55735 .47487 L p .54249 .4926 L .547 .521 .778 r
F P
0 g
s
.54249 .4926 m .55735 .47487 L .54285 .49757 L .547 .521 .778 r
F
.5799 .5151 m .55047 .50835 L p .56791 .49372 L F P
0 g
s
.61087 .57037 m .56321 .46049 L .63541 .60654 L 0 0 .271 r
F
.54483 .56018 m .54179 .49579 L .552 .57678 L .45 .357 .659 r
F
.528 .50307 m .54179 .49579 L .54483 .56018 L F
.55047 .50835 m .54354 .50676 L p .56444 .48752 L .547 .521 .778 r
F P
0 g
s
.54327 .50312 m .56444 .48752 L .54354 .50676 L .547 .521 .778 r
F
.54405 .51373 m .53963 .47861 L .54145 .47859 L 0 0 .271 r
F
.54179 .49579 m .54208 .49793 L .54157 .49817 L .751 .554 .629 r
F
.54208 .49793 m .54384 .51083 L .54157 .49817 L F
.54157 .49817 m .54384 .51083 L .54071 .50718 L F
.54179 .49579 m .53349 .5827 L .53695 .53046 L F
.53695 .53046 m .53772 .52319 L .5308 .50598 L .594 .413 .606 r
F
.52587 .54081 m .52391 .61686 L .5236 .61665 L .218 .048 .425 r
F
.5271 .50001 m .52599 .5406 L .52587 .54081 L F
.52599 .5406 m .52391 .61686 L .52587 .54081 L F
.52391 .61686 m .52507 .59206 L .54617 .63224 L F
.52458 .59761 m .5248 .59781 L .52431 .60832 L F
.50468 .63756 m .51067 .59284 L .51297 .5867 L F
.48964 .57659 m .51142 .59083 L .51078 .59254 L .712 .562 .682 r
F
.4989 .63759 m .48948 .62577 L .50468 .63756 L .666 .311 .362 r
F
.48843 .62773 m .48948 .62577 L .4989 .63759 L F
.49261 .61371 m .48843 .62773 L .49553 .6227 L .745 .509 .573 r
F
.48887 .60765 m .48843 .62773 L p .49328 .61144 L F P
0 g
s
.50468 .63756 m .49794 .63014 L p .48963 .59241 L .883 .59 .487 r
F P
0 g
s
.48963 .59241 m .48601 .57603 L .49015 .58966 L .883 .59 .487 r
F
.48963 .59241 m .49015 .58966 L .50468 .63756 L F
.48601 .57603 m .48602 .57602 L .50468 .63756 L F
.48611 .57565 m .50468 .63756 L p .48599 .5759 L F P
0 g
s
.48916 .59488 m .48822 .63715 L p .48337 .62536 L .989 .738 .453 r
F P
0 g
s
.48564 .57662 m .48407 .57572 L p .48311 .58067 L .733 .386 .392 r
F P
0 g
s
.48887 .60765 m .49328 .61144 L .49126 .60334 L .745 .509 .573 r
F
.48611 .57565 m .48576 .57638 L .48471 .5757 L .73 .396 .414 r
F
.48671 .57439 m .48471 .5757 L .45568 .55668 L F
.48611 .57565 m .48471 .5757 L .48671 .57439 L F
.48391 .57382 m .48544 .57343 L p .48599 .5759 L .883 .59 .487 r
F P
0 g
s
.48496 .57804 m .48599 .5759 L .49794 .63014 L .883 .59 .487 r
F
.48471 .5757 m .48576 .57638 L .48407 .57572 L .73 .396 .414 r
F
.48564 .57662 m .48407 .57572 L p .48576 .57638 L F P
0 g
s
.48115 .5756 m .47982 .58595 L .48407 .57572 L .733 .386 .392 r
F
.52113 .61494 m .52001 .61841 L p .52581 .61817 L .744 .572 .661 r
F P
0 g
s
.52373 .60203 m .52404 .60193 L .5236 .61665 L .218 .048 .425 r
F
.55962 .63052 m .55944 .62924 L .55945 .62897 L 0 0 .271 r
F
.55944 .62924 m .55929 .62824 L .55945 .62897 L F
.55915 .62809 m .55929 .62824 L .55944 .62924 L .218 .048 .425 r
F
.55939 .62929 m .55944 .62924 L .55962 .63052 L F
.55915 .62809 m .55944 .62924 L .55939 .62929 L F
.55726 .61071 m .5476 .53349 L .54977 .54781 L 0 0 .271 r
F
.55626 .60768 m .55726 .61071 L .55732 .61117 L F
.55778 .61502 m .55617 .60156 L .55417 .60466 L .74 .58 .675 r
F
.55628 .61073 m .56339 .61436 L .55738 .61388 L .69 .553 .694 r
F
.56339 .61436 m .56335 .6154 L .55738 .61388 L F
.55778 .61502 m .56335 .6154 L .5613 .62513 L F
.55738 .61388 m .55766 .61395 L .55778 .61502 L F
.55766 .61395 m .56335 .6154 L .55778 .61502 L F
.55617 .60156 m .55822 .6023 L .55509 .59245 L .74 .58 .675 r
F
.56306 .62323 m .56339 .61436 L .56662 .61566 L 0 0 .271 r
F
.56159 .62594 m .55981 .62879 L .55996 .6283 L .91 .982 .731 r
F
.55962 .63052 m .56283 .62951 L p .5605 .62284 L .74 .58 .675 r
F P
0 g
s
.55962 .63052 m .56251 .6244 L .56649 .62835 L 0 0 .271 r
F
.56251 .6244 m .56662 .61566 L .5666 .61828 L F
.56251 .6244 m .5666 .61828 L .56649 .62835 L F
.55954 .6289 m .56038 .62249 L .55903 .61861 L .74 .58 .675 r
F
.56027 .62775 m .55758 .61202 L .56339 .61436 L 0 0 .271 r
F
.55417 .60466 m .55934 .62919 L p .55778 .61502 L .74 .58 .675 r
F P
0 g
s
.55934 .62919 m .55962 .63052 L p .55945 .62904 L .74 .58 .675 r
F P
0 g
s
.55945 .62897 m .55758 .61202 L .56027 .62775 L 0 0 .271 r
F
.56339 .61436 m .56749 .61645 L .56335 .6154 L .69 .553 .694 r
F
.55869 .61176 m .56162 .61303 L .55822 .6023 L .74 .58 .675 r
F
.56632 .61554 m .56339 .61436 L .55735 .61127 L .45 .357 .659 r
F
.55758 .61202 m .55748 .6112 L .56341 .61376 L 0 0 .271 r
F
.5634 .61403 m .56341 .61376 L .56663 .61515 L F
.55758 .61202 m .56341 .61376 L .5634 .61403 L F
.56662 .61566 m .56663 .61515 L .5842 .62274 L F
.56563 .61475 m .56749 .61645 L .56491 .61444 L .45 .357 .659 r
F
.55758 .61202 m .56663 .61515 L .56662 .61566 L 0 0 .271 r
F
.55748 .6112 m .58243 .61487 L .5842 .62274 L F
.56662 .61565 m .56663 .61551 L .56749 .61645 L .45 .357 .659 r
F
.56663 .61551 m .56666 .61255 L .56749 .61645 L F
.56305 .62359 m .56159 .62594 L .56146 .62596 L .91 .982 .731 r
F
.56335 .6154 m .56308 .62263 L .5613 .62513 L .69 .553 .694 r
F
.56251 .6244 m .56339 .61436 L .56306 .62323 L 0 0 .271 r
F
.56159 .62594 m .55996 .6283 L .56001 .62814 L .91 .982 .731 r
F
.56159 .62594 m .56001 .62814 L .56146 .62596 L F
.55962 .63052 m .56027 .62775 L .56251 .6244 L 0 0 .271 r
F
.56027 .62775 m .56339 .61436 L .56251 .6244 L F
.56146 .62596 m .56001 .62814 L .56062 .62608 L .91 .982 .731 r
F
.56632 .61554 m .56749 .61645 L .56339 .61436 L .45 .357 .659 r
F
.56749 .61645 m .55773 .61297 L p .55659 .60458 L .751 .554 .629 r
F P
0 g
s
.55617 .60156 m .56749 .61645 L .55659 .60458 L .751 .554 .629 r
F
.56485 .60468 m .56749 .61645 L .55617 .60156 L F
.55709 .60833 m .55547 .59482 L .55667 .60448 L 0 0 .271 r
F
.55929 .62824 m .55659 .60458 L .55709 .60833 L F
.55659 .60458 m .55547 .59482 L .55709 .60833 L F
.55945 .62904 m .55778 .61502 L .55934 .62919 L .74 .58 .675 r
F
.55996 .6283 m .55925 .62927 L .56001 .62814 L .91 .982 .731 r
F
.55962 .63052 m .55986 .62844 L .55954 .6289 L .74 .58 .675 r
F
.55962 .63052 m .55945 .62897 L .56027 .62775 L 0 0 .271 r
F
.55945 .62897 m .55929 .62824 L .55667 .60448 L F
.55945 .62897 m .55667 .60448 L .55732 .60967 L F
.55329 .60052 m .55934 .62919 L p .54982 .5974 L .712 .562 .682 r
F P
0 g
s
.56001 .62814 m .55834 .63052 L .56062 .62608 L .91 .982 .731 r
F
.55925 .62927 m .55834 .63052 L .56001 .62814 L F
.56062 .62608 m .56749 .61645 L p .56305 .62359 L F P
0 g
s
.56305 .62359 m .56146 .62596 L .56062 .62608 L .91 .982 .731 r
F
.52496 .59115 m .52507 .59217 L .5248 .59781 L .218 .048 .425 r
F
.53004 .59732 m .54942 .60722 L .53808 .60581 L .69 .553 .694 r
F
.52428 .59123 m .52432 .59127 L .52419 .59723 L .218 .048 .425 r
F
.54942 .60722 m .542 .60996 L .53808 .60581 L .69 .553 .694 r
F
.52383 .5969 m .527 .59122 L .55357 .62484 L .712 .562 .682 r
F
.527 .59122 m .55055 .6027 L .55357 .62484 L F
.50468 .63756 m .51726 .62302 L .51065 .63679 L .218 .048 .425 r
F
.50531 .65349 m .50468 .63756 L .51008 .64298 L .799 .723 .78 r
F
.50931 .65141 m .51008 .64298 L .51535 .64827 L F
.50531 .65349 m .51008 .64298 L .50931 .65141 L F
.50643 .68135 m .50531 .65349 L .50928 .65178 L F
.50933 .64531 m .50468 .63756 L p .50561 .6568 L .866 .712 .688 r
F P
0 g
s
.51535 .64827 m .50468 .63756 L .54617 .63224 L .799 .723 .78 r
F
.36619 .81535 m .46868 .68377 L .46675 .71926 L F
.36619 .81535 m .46659 .71967 L .37829 .81247 L F
.46659 .71967 m .46383 .72678 L .37829 .81247 L F
.46618 .76711 m .48322 .75194 L .46918 .77451 L .69 .553 .694 r
F
.46618 .76711 m .46918 .77451 L .46678 .77756 L F
.46666 .77057 m .46681 .77744 L .46737 .76813 L F
.46681 .77744 m .4669 .777 L .46737 .76813 L F
.46561 .72218 m .46666 .77057 L .47053 .70953 L F
.46666 .77057 m .46737 .76813 L .47053 .70953 L F
.49083 .77556 m .49253 .76296 L p .46807 .77683 L .895 .92 .831 r
F P
0 g
s
.46678 .77756 m .46776 .77748 L .46807 .77683 L .895 .92 .831 r
F
.46776 .77748 m .49083 .77556 L .46807 .77683 L F
.49409 .69346 m .5566 .63341 L .55572 .63473 L .799 .723 .78 r
F
.5566 .63341 m .55675 .63362 L .55572 .63473 L F
.53197 .67356 m .46918 .77451 L p .53061 .67522 L .91 .982 .731 r
F P
0 g
s
.46918 .77451 m .46922 .77443 L .55649 .63339 L .91 .982 .731 r
F
.50931 .65141 m .4937 .69363 L .51008 .64298 L .985 .886 .642 r
F
.52869 .67757 m .51386 .65286 L p .55818 .6307 L .8 .699 .754 r
F P
0 g
s
.54011 .63611 m .55818 .6307 L .51386 .65286 L .8 .699 .754 r
F
.50643 .68135 m .50928 .65178 L .50659 .68119 L .799 .723 .78 r
F
.50931 .65141 m .50753 .6569 L p .54617 .63224 L .744 .572 .661 r
F P
0 g
s
.51008 .64298 m .50933 .64531 L .51065 .63679 L .985 .886 .642 r
F
.51065 .63679 m .55818 .6307 L p .50933 .64531 L .8 .699 .754 r
F P
0 g
s
.52869 .67757 m .52133 .66531 L p .52416 .68314 L .866 .712 .688 r
F P
0 g
s
.47543 .74059 m .48402 .73404 L .47146 .75418 L .894 .986 .792 r
F
.47787 .73227 m .48331 .73165 L .47543 .74059 L F
.48331 .73165 m .48784 .73113 L .47543 .74059 L F
.46678 .77756 m .49253 .76296 L .46747 .77668 L .895 .92 .831 r
F
.46626 .78016 m .49083 .77556 L p .46678 .77756 L F P
0 g
s
.49253 .76296 m .49548 .74102 L p .46918 .77451 L .895 .92 .831 r
F P
0 g
s
.46747 .77668 m .46838 .77618 L .46918 .77451 L .895 .92 .831 r
F
.46838 .77618 m .49253 .76296 L .46918 .77451 L F
.5306 .67524 m .46922 .77443 L .52951 .67657 L .91 .982 .731 r
F
.46922 .77443 m .46925 .77436 L .5567 .63245 L F
.46918 .77451 m .55649 .63339 L .55651 .63336 L F
.50036 .71231 m .52416 .68314 L .52133 .66531 L .866 .712 .688 r
F
.46678 .77756 m .46734 .77685 L .46683 .77829 L .69 .553 .694 r
F
.46908 .77464 m .46918 .77451 L .46683 .77829 L F
.48784 .73113 m .48497 .73517 L p .48402 .73404 L .894 .986 .792 r
F P
0 g
s
.48497 .73517 m .47146 .75418 L p .48402 .73404 L .894 .986 .792 r
F P
0 g
s
.46383 .72678 m .46678 .77756 L .46561 .72218 L .69 .553 .694 r
F
.46678 .77756 m .46681 .77744 L .46561 .72218 L F
.50052 .69387 m .49903 .71394 L p .4978 .70917 L .965 .803 .632 r
F P
0 g
s
.52133 .66531 m .51386 .65286 L p .50652 .67541 L .866 .712 .688 r
F P
0 g
s
.50753 .6569 m .50651 .66005 L p .54617 .63224 L .744 .572 .661 r
F P
0 g
s
.51353 .70251 m .49328 .73536 L .49721 .71617 L .91 .982 .731 r
F
.49892 .71407 m .49721 .71617 L .49739 .71528 L F
.51353 .70251 m .49721 .71617 L .49892 .71407 L F
.49928 .71364 m .52133 .66531 L .50652 .67541 L .866 .712 .688 r
F
.49903 .71394 m .49739 .71528 L .49861 .71427 L .91 .982 .731 r
F
.51353 .70251 m .49892 .71407 L .49903 .71394 L F
.49892 .71407 m .49739 .71528 L .49903 .71394 L F
.50052 .69387 m .49903 .71394 L p .50652 .67541 L .866 .712 .688 r
F P
0 g
s
.49928 .71364 m .50652 .67541 L .49903 .71394 L .866 .712 .688 r
F
.50036 .71231 m .52133 .66531 L .49928 .71364 L F
.49743 .71116 m .49851 .71435 L .49758 .71043 L .96 .802 .642 r
F
.50651 .66005 m .48331 .73165 L p .49258 .71825 L .744 .572 .661 r
F P
0 g
s
.50048 .69396 m .49258 .71825 L .49741 .71128 L .744 .572 .661 r
F
.50651 .66005 m .49258 .71825 L .50048 .69396 L F
.50651 .66005 m .49741 .71128 L .49762 .7102 L F
.49861 .71427 m .49762 .7102 L p .49851 .71435 L .96 .802 .642 r
F P
0 g
s
.50901 .65223 m .48161 .73689 L .4937 .69363 L .985 .886 .642 r
F
.50931 .65141 m .5091 .65207 L p .50901 .65223 L F P
0 g
s
.5091 .65207 m .48161 .73689 L p .50901 .65223 L .985 .886 .642 r
F P
0 g
s
.5004 .66961 m .48307 .73167 L .49127 .68392 L .985 .886 .642 r
F
.49762 .7102 m .49127 .68392 L p .49758 .71043 L .96 .802 .642 r
F P
0 g
s
.49851 .71435 m .49762 .7102 L .49758 .71043 L .96 .802 .642 r
F
.49861 .71427 m .49762 .7102 L p .49903 .71394 L .965 .803 .632 r
F P
0 g
s
.4978 .70917 m .49903 .71394 L .49762 .7102 L .965 .803 .632 r
F
.48331 .73165 m .48843 .72583 L .49741 .71129 L .744 .572 .661 r
F
.48331 .73165 m .49741 .71129 L .49741 .71128 L F
.49646 .71606 m .49851 .71435 L .49743 .71116 L .96 .802 .642 r
F
.49744 .71124 m .48843 .72583 L .49693 .71408 L .744 .572 .661 r
F
.49402 .71949 m .49646 .71606 L p .48843 .72583 L F P
0 g
s
.49646 .71606 m .56216 .62393 L p .49682 .71423 L .744 .572 .661 r
F P
0 g
s
.48843 .72583 m .49646 .71606 L .49682 .71423 L .744 .572 .661 r
F
.49328 .73536 m .49387 .72265 L .49741 .71522 L .91 .982 .731 r
F
.48424 .73059 m .49396 .72062 L .48784 .73113 L .894 .986 .792 r
F
.49387 .72265 m .48784 .73113 L p .49396 .72062 L F P
0 g
s
.49402 .71949 m .4981 .71376 L p .49388 .72247 L .91 .982 .731 r
F P
0 g
s
.49387 .72265 m .49388 .72247 L .4981 .71376 L .91 .982 .731 r
F
.4963 .7169 m .49891 .71555 L p .49396 .72062 L .894 .986 .792 r
F P
0 g
s
.49402 .71949 m .49396 .72062 L .48424 .73059 L .894 .986 .792 r
F
.4963 .7169 m .49396 .72062 L .49402 .71949 L F
.49328 .73536 m .46925 .77436 L .49387 .72265 L .91 .982 .731 r
F
.49548 .74102 m .49891 .71555 L p .4826 .74631 L .895 .92 .831 r
F P
0 g
s
.47053 .70953 m .4669 .777 L .45709 .71869 L .896 .804 .75 r
F
.4669 .777 m .46664 .77714 L .45709 .71869 L F
.46448 .7805 m .46619 .77831 L .46553 .77851 L .895 .92 .831 r
F
.39671 .80671 m .45911 .73922 L .45758 .75566 L .773 .729 .812 r
F
.40939 .79951 m .42438 .78877 L .41806 .79423 L F
.39441 .80863 m .42438 .78877 L .40939 .79951 L F
.2707 .79791 m .33956 .81792 L .29681 .80605 L p .228 0 0 r
F P
0 g
s
.29681 .80605 m .25571 .79464 L .27045 .79785 L p .228 0 0 r
F P
0 g
s
.27045 .79785 m .2707 .79791 L p .29681 .80605 L .228 0 0 r
F P
0 g
s
.48057 .64706 m .48145 .6511 L .48028 .64578 L 0 0 .181 r
F
.48099 .64895 m .48145 .6511 L .48057 .64706 L F
.48143 .65094 m .48144 .651 L .48072 .64771 L F
.48144 .651 m .48145 .6511 L .48099 .64895 L F
.48144 .651 m .48099 .64895 L .48072 .64771 L F
.48144 .651 m .48295 .64947 L .48147 .6512 L .592 .324 .479 r
F
.49127 .68392 m .48307 .73167 L .48597 .69339 L .985 .886 .642 r
F
.49646 .71606 m .49743 .71116 L .48731 .68119 L .96 .802 .642 r
F
.48938 .6873 m .49743 .71116 L .49127 .68392 L F
.50933 .64531 m .50468 .63756 L .51065 .63679 L p .8 .699 .754 r
F P
0 g
s
.50468 .63756 m .50256 .66624 L p .50561 .6568 L .866 .712 .688 r
F P
0 g
s
.49402 .65123 m .50468 .63756 L .49605 .65615 L .799 .723 .78 r
F
.50468 .63756 m .50256 .66624 L p .49332 .65834 L .965 .803 .632 r
F P
0 g
s
.49224 .65114 m .50468 .63756 L .49402 .65123 L .866 .996 .785 r
F
.4879 .65189 m .48744 .67258 L p .49401 .64615 L .745 .509 .573 r
F P
0 g
s
.48914 .6751 m .48815 .67098 L p .48744 .67258 L .96 .802 .642 r
F P
0 g
s
.48744 .67258 m .48744 .67272 L p .48751 .67243 L .745 .509 .573 r
F P
0 g
s
.48744 .67258 m .48751 .67243 L .49401 .64615 L .745 .509 .573 r
F
.48271 .65279 m .48295 .64947 L .48614 .6522 L .866 .996 .785 r
F
.48172 .65296 m .48295 .64947 L .48271 .65279 L F
.48351 .65265 m .48589 .6703 L .48172 .65296 L .989 .738 .453 r
F
.48493 .66888 m .48172 .65296 L p .48589 .6703 L F P
0 g
s
.48642 .67657 m .48914 .6751 L .48744 .67258 L .96 .802 .642 r
F
.48731 .68119 m .48914 .6751 L .48642 .67657 L F
.48121 .66338 m .47861 .68416 L p .48619 .6754 L F P
0 g
s
.48064 .68797 m .48619 .6754 L .47861 .68416 L .96 .802 .642 r
F
.48619 .6754 m .48744 .67258 L .48493 .66888 L F
.48619 .6754 m .48493 .66888 L .48121 .66338 L F
.48172 .65296 m .48028 .64578 L p .48145 .6511 L 0 0 .181 r
F P
0 g
s
.47967 .65331 m .48147 .6512 L .48127 .65303 L .866 .996 .785 r
F
.48147 .6512 m .48295 .64947 L .48163 .65229 L F
.48147 .6512 m .48163 .65229 L .48127 .65303 L F
.48144 .651 m .48144 .651 L .48295 .64947 L .592 .324 .479 r
F
.48163 .65229 m .48295 .64947 L .48172 .65296 L .866 .996 .785 r
F
.48191 .6531 m .48074 .64783 L .48295 .64947 L 0 .126 .674 r
F
.48072 .64773 m .48072 .64771 L .48295 .64947 L F
.48072 .64771 m .48099 .64895 L .48057 .64706 L 0 0 .181 r
F
.36481 .55656 m .36484 .55655 L .38431 .57187 L 0 .126 .674 r
F
.38428 .57187 m .38431 .57187 L .48295 .64947 L F
.36481 .55656 m .38431 .57187 L .38428 .57187 L F
.36481 .55656 m .3648 .55656 L .36439 .557 L .668 .896 .979 r
F
.36436 .55674 m .36481 .55656 L .48072 .64771 L 0 .126 .674 r
F
.36436 .55674 m .48072 .64771 L .48072 .64773 L F
.37127 .5641 m .36436 .55674 L .37357 .56395 L F
.37127 .5641 m .37357 .56395 L .38376 .57192 L F
.379 .57235 m .37127 .5641 L .38376 .57192 L F
.36256 .54949 m .36255 .54966 L p .36261 .54966 L .347 .743 .984 r
F P
0 g
s
.42895 .54317 m .39684 .54865 L p .42937 .54302 L .255 0 0 r
F P
0 g
s
.47114 .52915 m .45402 .55847 L p .47211 .52813 L 0 0 0 r
F P
0 g
s
.39676 .54865 m .47043 .53591 L .39684 .54865 L .255 0 0 r
F
.39197 .54948 m .45891 .53024 L .47043 .53591 L F
.42895 .54317 m .39684 .54865 L p .40583 .54702 L .125 .672 .704 r
F P
0 g
s
.40052 .547 m .40061 .547 L .39197 .54948 L .255 0 0 r
F
.45229 .53196 m .40061 .547 L .40052 .547 L F
.45229 .53196 m .45891 .53024 L .40061 .547 L F
.47135 .52631 m .47172 .52632 L .39197 .54948 L F
.40583 .54702 m .36212 .54683 L p .41018 .54626 L .249 .741 .916 r
F P
0 g
s
.36212 .54683 m .36051 .54682 L p .36214 .5468 L .249 .741 .916 r
F P
0 g
s
.36214 .5468 m .41018 .54626 L .36212 .54683 L .249 .741 .916 r
F
.36214 .5468 m .36307 .54596 L .41018 .54626 L F
.39877 .54182 m .39862 .54169 L p .36275 .54592 L .347 .743 .984 r
F P
0 g
s
.36389 .52434 m .36275 .54592 L p .39862 .54169 L .347 .743 .984 r
F P
0 g
s
.36275 .54592 m .36307 .54596 L .39877 .54182 L .347 .743 .984 r
F
.38804 .53755 m .39559 .54219 L p .36307 .54596 L .249 .741 .916 r
F P
0 g
s
.39817 .54618 m .39834 .54492 L .41018 .54626 L .249 .741 .916 r
F
.39886 .54181 m .40654 .54483 L p .38505 .54341 L F P
0 g
s
.40654 .54483 m .41018 .54626 L p .38505 .54341 L .249 .741 .916 r
F P
0 g
s
.46582 .53695 m .45402 .55847 L .42903 .54839 L .599 .105 .051 r
F
.41169 .546 m .42895 .54317 L .41152 .54607 L .125 .672 .704 r
F
.41018 .54626 m .41152 .54607 L .40583 .54702 L F
.41169 .546 m .41152 .54607 L .41018 .54626 L F
.40913 .5465 m .41512 .5454 L .41627 .54547 L .729 .339 .311 r
F
.41218 .54705 m .36212 .54683 L p .38821 .54893 L .112 .66 .815 r
F P
0 g
s
.39886 .54181 m .41018 .54626 L p .4083 .54652 L .494 0 0 r
F P
0 g
s
.39684 .54865 m .39197 .54948 L p .39676 .54865 L .255 0 0 r
F P
0 g
s
.39709 .54864 m .41218 .54705 L .38821 .54893 L .112 .66 .815 r
F
.39684 .54865 m .37586 .55223 L p .40933 .54638 L .125 .672 .704 r
F P
0 g
s
.41077 .54613 m .40955 .54635 L .40933 .54638 L .125 .672 .704 r
F
.40955 .54635 m .39684 .54865 L .40933 .54638 L F
.40495 .54711 m .40901 .54642 L p .40913 .5465 L .729 .339 .311 r
F P
0 g
s
.40495 .54711 m .39877 .54182 L p .39888 .54184 L 0 .474 .853 r
F P
0 g
s
.40966 .54633 m .41169 .546 L .40583 .54702 L .125 .672 .704 r
F
.41018 .54626 m .41218 .54705 L .40583 .54702 L p .249 .741 .916 r
F P
0 g
s
.41695 .55084 m .42113 .55417 L p .42038 .55376 L .494 0 0 r
F P
0 g
s
.41695 .55084 m .42038 .55376 L .41533 .5505 L .494 0 0 r
F
.41437 .54987 m .41533 .5505 L .4143 .54984 L F
.41695 .55084 m .41533 .5505 L .41437 .54987 L F
.39286 .57859 m .37091 .56132 L .40269 .57238 L .666 .311 .362 r
F
.40238 .57258 m .41809 .56265 L .45402 .55847 L .206 0 0 r
F
.38431 .57187 m .45402 .55847 L .37541 .56382 L F
.36185 .54692 m .38821 .54893 L p .36212 .54683 L .112 .66 .815 r
F P
0 g
s
.36256 .54949 m .36261 .54966 L .38246 .54846 L .347 .743 .984 r
F
.36427 .55533 m .36363 .55389 L p .38821 .54893 L .742 .932 .951 r
F P
0 g
s
.36728 .55367 m .40495 .54711 L p .36255 .54966 L .347 .743 .984 r
F P
0 g
s
.36481 .55655 m .35637 .55784 L .35593 .55902 L .668 .896 .979 r
F
.36481 .55656 m .36481 .55655 L p .3648 .55656 L F P
0 g
s
.36481 .55656 m .36484 .55654 L .36484 .55655 L 0 .126 .674 r
F
.36363 .55389 m .36255 .54966 L .3623 .55454 L F
.36481 .55655 m .36051 .54682 L p .35637 .55784 L .668 .896 .979 r
F P
0 g
s
.36481 .55656 m .36481 .55655 L p .36482 .55655 L .742 .932 .951 r
F P
0 g
s
.379 .57235 m .36256 .54949 L .36431 .55669 L 0 .126 .674 r
F
.37738 .56849 m .36256 .54949 L .379 .57235 L F
.38431 .57187 m .37541 .56382 L .37871 .57165 L .206 0 0 r
F
.379 .57235 m .38431 .57187 L .37871 .57165 L F
.38924 .58204 m .37657 .56658 L .38714 .58102 L 0 .126 .674 r
F
.37657 .56658 m .36256 .54949 L .37738 .56849 L F
.37657 .56658 m .37738 .56849 L .38714 .58102 L F
.37541 .56382 m .45402 .55847 L .37278 .55758 L .206 0 0 r
F
.36307 .54596 m .38505 .54341 L .39834 .54492 L .249 .741 .916 r
F
.36307 .54596 m .39834 .54492 L .39817 .54618 L F
.40495 .54711 m .39877 .54182 L p .36256 .54949 L .347 .743 .984 r
F P
0 g
s
.36275 .546 m .36256 .54949 L p .39877 .54182 L .347 .743 .984 r
F P
0 g
s
.36256 .54949 m .38246 .54846 L .38177 .54841 L .347 .743 .984 r
F
.36728 .55367 m .40495 .54711 L p .37586 .55223 L .125 .672 .704 r
F P
0 g
s
.3971 .59163 m .36346 .54634 L .36256 .54949 L 0 .126 .674 r
F
.36722 .56866 m .36439 .557 L .35159 .57057 L .668 .896 .979 r
F
.37001 .56832 m .36439 .557 L .36722 .56866 L F
.36051 .54682 m .30183 .5568 L .35159 .57057 L p F P
0 g
s
.30368 .5687 m .37541 .56382 L .30183 .5568 L .206 0 0 r
F
.36307 .54596 m .38804 .53755 L p .36375 .54369 L .244 .708 .948 r
F P
0 g
s
.36291 .54557 m .36278 .54542 L .36291 .54557 L 0 .126 .674 r
F
.36307 .54596 m .36375 .54369 L .36275 .54592 L .244 .708 .948 r
F
.39862 .54169 m .36452 .51251 L .36389 .52434 L p .347 .743 .984 r
F P
0 g
s
.36291 .54557 m .36452 .51251 L .36278 .54542 L 0 .126 .674 r
F
.38804 .53755 m .36784 .53451 L p .36375 .54369 L .244 .708 .948 r
F P
0 g
s
.38177 .54841 m .38246 .54846 L .40495 .54711 L .347 .743 .984 r
F
.40238 .57258 m .41522 .56907 L .38431 .57187 L .206 0 0 r
F
.41522 .56907 m .45402 .55847 L .38431 .57187 L F
.40753 .54663 m .40495 .54711 L .39888 .54184 L 0 .474 .853 r
F
.40495 .54711 m .41077 .54613 L p .40114 .54781 L .125 .672 .704 r
F P
0 g
s
.41533 .5505 m .40495 .54711 L p .40913 .5465 L .729 .339 .311 r
F P
0 g
s
.40831 .54706 m .40495 .54711 L p .40753 .54663 L 0 .474 .853 r
F P
0 g
s
.40495 .54711 m .40114 .54781 L .37586 .55223 L .125 .672 .704 r
F
.45402 .59025 m .40336 .57261 L .44767 .57435 L .666 .311 .362 r
F
.37278 .55758 m .4509 .55844 L .40879 .5964 L .666 .35 .428 r
F
.4509 .55844 m .45402 .55847 L .45269 .55959 L F
.4509 .55844 m .45269 .55959 L .40879 .5964 L F
.45502 .57568 m .48362 .59907 L .45619 .59567 L .69 .553 .694 r
F
.45468 .56063 m .45619 .59567 L .47169 .61624 L F
.45408 .55953 m .45619 .59567 L .45468 .56063 L F
.45488 .561 m .47169 .61624 L .46916 .603 L F
.45402 .55847 m .45468 .56063 L .45488 .561 L F
.45468 .56063 m .47169 .61624 L .45488 .561 L F
.45955 .57473 m .46916 .603 L p .48115 .5756 L .733 .386 .392 r
F P
0 g
s
.46916 .603 m .46942 .60375 L p .47086 .60029 L .733 .386 .392 r
F P
0 g
s
.46916 .603 m .47086 .60029 L .48115 .5756 L .733 .386 .392 r
F
.47309 .60274 m .47086 .60029 L p .48496 .57804 L .883 .59 .487 r
F P
0 g
s
.45402 .55847 m .45408 .55953 L .45468 .56063 L .69 .553 .694 r
F
.48514 .61603 m .47086 .60029 L p .47247 .60804 L .89 .581 .455 r
F P
0 g
s
.4763 .62642 m .48134 .62049 L .47247 .60804 L .89 .581 .455 r
F
.48134 .62049 m .48514 .61603 L .47247 .60804 L F
.45619 .59567 m .45866 .60186 L .46105 .60212 L .69 .553 .694 r
F
.45866 .60186 m .47422 .6408 L .46105 .60212 L F
.47877 .63831 m .47086 .60029 L .47072 .60063 L .89 .581 .455 r
F
.46105 .60212 m .4715 .63281 L .47482 .62975 L .69 .553 .694 r
F
.4715 .63281 m .47422 .6408 L .47473 .63136 L F
.4715 .63281 m .47473 .63136 L .47482 .62975 L F
.46105 .60212 m .47482 .62975 L .47214 .61684 L F
.40879 .5964 m .45402 .55847 L .46916 .603 L .666 .35 .428 r
F
.46916 .603 m .47169 .61624 L .47214 .61684 L .69 .553 .694 r
F
.47058 .59998 m .4702 .59956 L p .47877 .63831 L .89 .581 .455 r
F P
0 g
s
.4702 .59956 m .46805 .5972 L p .46956 .60297 L .89 .581 .455 r
F P
0 g
s
.47877 .63831 m .4702 .59956 L .46956 .60297 L .89 .581 .455 r
F
.46916 .603 m .47214 .61684 L .46942 .60375 L .69 .553 .694 r
F
.46661 .61212 m .46916 .603 L .46942 .60375 L .666 .35 .428 r
F
.46648 .61193 m .46916 .603 L .46661 .61212 L F
.46491 .61718 m .46942 .60375 L .46678 .61787 L F
.40879 .5964 m .46916 .603 L .46491 .61718 L F
.45488 .561 m .46942 .60375 L p .45942 .58381 L .897 .477 .142 r
F P
0 g
s
.45488 .561 m .45942 .58381 L .45474 .56339 L .897 .477 .142 r
F
.48407 .57572 m .45402 .55847 L .45955 .57473 L p .733 .386 .392 r
F P
0 g
s
.48407 .57572 m .45402 .55847 L p .48471 .5757 L .73 .396 .414 r
F P
0 g
s
.48544 .57343 m .45474 .56339 L p .45568 .55668 L .729 .339 .311 r
F P
0 g
s
.45474 .56339 m .45116 .56222 L p .45374 .55905 L .729 .339 .311 r
F P
0 g
s
.45474 .56339 m .4318 .55589 L p .45456 .56629 L .695 .233 .151 r
F P
0 g
s
.42093 .54956 m .41567 .54805 L p .43013 .54298 L .583 .945 .856 r
F P
0 g
s
.42093 .54956 m .43013 .54298 L .44083 .54123 L .583 .945 .856 r
F
.41567 .54805 m .41218 .54705 L .45373 .53407 L p F P
0 g
s
.44872 .55702 m .41218 .54705 L .42157 .55453 L p .52 0 0 r
F P
0 g
s
.42157 .55453 m .42249 .55526 L p .4318 .55589 L .52 0 0 r
F P
0 g
s
.42157 .55453 m .4318 .55589 L .44872 .55702 L .52 0 0 r
F
.45116 .56222 m .4318 .55589 L p .45368 .55879 L .729 .339 .311 r
F P
0 g
s
.45368 .55879 m .45402 .55847 L p .45404 .56033 L .897 .477 .142 r
F P
0 g
s
.45368 .55879 m .45393 .55882 L .45374 .55905 L .729 .339 .311 r
F
.45368 .55879 m .45374 .55905 L .45116 .56222 L F
.45456 .56629 m .4318 .55589 L .42809 .55564 L .695 .233 .151 r
F
.45474 .56339 m .45942 .58381 L .45415 .57328 L .897 .477 .142 r
F
.45976 .58002 m .46454 .57879 L p .45417 .57283 L .695 .233 .151 r
F P
0 g
s
.45405 .57488 m .45421 .58202 L .45367 .58132 L .897 .477 .142 r
F
.45421 .58202 m .45422 .58241 L .45378 .58153 L F
.45421 .58202 m .45378 .58153 L .45367 .58132 L F
.4143 .54984 m .41533 .5505 L .41116 .54864 L .494 0 0 r
F
.41533 .5505 m .42038 .55376 L .41949 .55326 L F
.4496 .57327 m .41533 .5505 L .45008 .5742 L .695 .233 .151 r
F
.41533 .5505 m .40495 .54711 L p .45008 .5742 L F P
0 g
s
.41533 .5505 m .41949 .55326 L .41116 .54864 L .494 0 0 r
F
.42113 .55417 m .43446 .56479 L p .41116 .54864 L F P
0 g
s
.45397 .57617 m .45417 .57283 L .41533 .5505 L .695 .233 .151 r
F
.46454 .57879 m .45864 .56793 L .41533 .5505 L F
.45415 .57328 m .45422 .58241 L .45405 .57488 L .897 .477 .142 r
F
.45395 .57653 m .4496 .57327 L .45008 .5742 L .695 .233 .151 r
F
.45397 .57617 m .4496 .57327 L .45395 .57653 L F
.45415 .57328 m .46942 .60375 L .45422 .58241 L .897 .477 .142 r
F
.45385 .58154 m .45976 .58002 L p .45395 .57653 L .695 .233 .151 r
F P
0 g
s
.40495 .54711 m .45366 .5814 L p .45395 .57653 L .695 .233 .151 r
F P
0 g
s
.45366 .5814 m .45385 .58154 L p .45395 .57653 L .695 .233 .151 r
F P
0 g
s
.44397 .56802 m .44596 .56613 L p .45367 .58132 L .897 .477 .142 r
F P
0 g
s
.45367 .58132 m .45422 .58241 L .45365 .58161 L .897 .477 .142 r
F
.44537 .57218 m .42693 .56074 L .45366 .5814 L 0 .327 .811 r
F
.4159 .55481 m .45366 .5814 L p .42693 .56074 L F P
0 g
s
.45367 .58132 m .45365 .58161 L .44397 .56802 L .897 .477 .142 r
F
.45405 .57488 m .45367 .58132 L .44596 .56613 L F
.47982 .58595 m .48311 .58067 L .48407 .57572 L .733 .386 .392 r
F
.47877 .63831 m .46805 .5972 L .47464 .6289 L .89 .581 .455 r
F
.48474 .57806 m .48496 .57804 L .47086 .60029 L .883 .59 .487 r
F
.49328 .61144 m .49261 .61371 L .49374 .61329 L .745 .509 .573 r
F
.50468 .63756 m .50966 .60701 L .51726 .62302 L .218 .048 .425 r
F
.52508 .59014 m .52509 .59008 L .52438 .57018 L .161 .053 .474 r
F
.52438 .57037 m .52438 .57018 L .52209 .50588 L F
.52508 .59014 m .52438 .57018 L .52438 .57037 L F
.51691 .55301 m .52303 .57297 L .51437 .57806 L .752 .501 .553 r
F
.514 .58036 m .51298 .56485 L .51831 .5539 L .218 .048 .425 r
F
.51298 .56485 m .51002 .52007 L .51759 .55096 L F
.51298 .56485 m .51759 .55096 L .51831 .5539 L F
.52081 .55198 m .51759 .55096 L p .51995 .54386 L .575 .401 .609 r
F P
0 g
s
.51831 .5539 m .51919 .55323 L .51785 .55204 L .602 .275 .388 r
F
.53073 .50695 m .53695 .53046 L p .52666 .55385 L .575 .401 .609 r
F P
0 g
s
.52563 .50898 m .52502 .54875 L .52498 .54878 L .218 .048 .425 r
F
.52563 .50898 m .52478 .57195 L .52466 .57202 L F
.52209 .50588 m .5235 .54538 L .53246 .51495 L .161 .053 .474 r
F
.52162 .50644 m .5243 .57223 L .52303 .57297 L .752 .501 .553 r
F
.51995 .54386 m .51018 .52071 L .5271 .50001 L .218 .048 .425 r
F
.51831 .5539 m .51759 .55096 L .51995 .54386 L F
.51759 .55096 m .51018 .52071 L .51995 .54386 L F
.50966 .60701 m .51437 .57806 L .52343 .61653 L F
.52498 .54878 m .52465 .57203 L .5246 .57205 L F
.52482 .54891 m .52495 .58627 L .52799 .55741 L .161 .053 .474 r
F
.5235 .54538 m .52438 .57018 L .52482 .54891 L F
.52438 .57018 m .52495 .58627 L .52482 .54891 L F
.53522 .55657 m .52666 .55385 L p .52885 .55973 L .602 .275 .388 r
F P
0 g
s
.53522 .55657 m .52666 .55385 L p .53695 .53046 L .575 .401 .609 r
F P
0 g
s
.5235 .54538 m .52799 .55741 L .53246 .51495 L .161 .053 .474 r
F
.51437 .57806 m .52563 .50898 L .52434 .57221 L .218 .048 .425 r
F
.51437 .57806 m .52434 .57221 L .52343 .61653 L F
.48964 .57659 m .49098 .57435 L .51142 .59083 L .712 .562 .682 r
F
.49672 .57809 m .51297 .5867 L .51217 .58881 L F
.48885 .57263 m .49975 .57899 L .49672 .57809 L F
.49975 .57899 m .51297 .5867 L .49672 .57809 L F
.51614 .5505 m .49661 .54429 L p .49288 .56936 L .602 .275 .388 r
F P
0 g
s
.50557 .55906 m .51224 .57931 L .50213 .5791 L .752 .501 .553 r
F
.51614 .5505 m .49661 .54429 L p .50942 .52862 L .575 .401 .609 r
F P
0 g
s
.51031 .5315 m .51123 .55447 L .50557 .55906 L .752 .501 .553 r
F
.51123 .55447 m .51224 .57931 L .50557 .55906 L F
.51031 .5315 m .50213 .5791 L .49164 .57399 L F
.52438 .58565 m .52444 .58627 L .52432 .59127 L .218 .048 .425 r
F
.52438 .58565 m .52432 .59127 L .52428 .59123 L F
.50785 .58189 m .52505 .59027 L .52383 .5969 L .712 .562 .682 r
F
.49975 .57899 m .50785 .58189 L .51297 .5867 L F
.51281 .5935 m .50087 .58599 L p .51224 .57931 L .752 .501 .553 r
F P
0 g
s
.48885 .57263 m .50522 .58061 L .49975 .57899 L .712 .562 .682 r
F
.50522 .58061 m .50785 .58189 L .49975 .57899 L F
.50087 .58599 m .48951 .57884 L p .51224 .57931 L .752 .501 .553 r
F P
0 g
s
.51674 .55246 m .51281 .5935 L .51031 .5315 L .752 .501 .553 r
F
.52434 .57221 m .52505 .59027 L p .5243 .57223 L F P
0 g
s
.52505 .59027 m .52504 .59027 L .5243 .57223 L .752 .501 .553 r
F
.54179 .49579 m .53695 .53046 L .53805 .52008 L .751 .554 .629 r
F
.53956 .50585 m .53094 .50387 L p .53542 .50103 L .547 .521 .778 r
F P
0 g
s
.53155 .50283 m .53542 .50103 L .53094 .50387 L .547 .521 .778 r
F
.53073 .50695 m .53695 .53046 L p .5308 .50598 L .594 .413 .606 r
F P
0 g
s
.54055 .49651 m .54179 .49579 L .53805 .52008 L .751 .554 .629 r
F
.55137 .57182 m .54405 .51373 L .54376 .50825 L 0 0 .271 r
F
.52719 .51034 m .53029 .51305 L .53094 .50387 L .161 .053 .474 r
F
.52136 .49676 m .52114 .50532 L .52038 .50356 L .752 .501 .553 r
F
.5213 .49906 m .52121 .50257 L .52055 .50336 L .183 .006 .391 r
F
.52354 .48634 m .52121 .50257 L .5213 .49906 L F
.52354 .48634 m .52126 .50251 L .52121 .50257 L F
.52242 .48945 m .52354 .48634 L .52055 .50336 L F
.52242 .48945 m .52055 .50336 L .52038 .50356 L F
.52155 .50148 m .52673 .48317 L .52158 .50213 L F
.5211 .48999 m .52136 .49676 L p .52745 .48542 L .161 .053 .474 r
F P
0 g
s
.52126 .50251 m .52155 .50148 L .52158 .50213 L .183 .006 .391 r
F
.5211 .48999 m .52136 .49676 L p .51951 .50155 L .752 .501 .553 r
F P
0 g
s
.51813 .49835 m .5211 .48999 L p .51951 .50155 L .752 .501 .553 r
F P
0 g
s
.51018 .52071 m .51068 .51929 L .5271 .50001 L .218 .048 .425 r
F
.5174 .49667 m .52025 .50327 L .51665 .50743 L .45 .357 .659 r
F
.49434 .54788 m .51328 .51199 L .51117 .51284 L .108 0 .251 r
F
.51976 .50781 m .51526 .50968 L p .50841 .51512 L 0 0 0 r
F P
0 g
s
.51976 .50781 m .51526 .50968 L p .52038 .50356 L .183 .006 .391 r
F P
0 g
s
.52136 .49676 m .51929 .51105 L .51031 .5315 L .752 .501 .553 r
F
.50847 .52551 m .50942 .52862 L .49661 .54429 L .575 .401 .609 r
F
.50924 .52801 m .51031 .5315 L .48951 .57884 L .752 .501 .553 r
F
.52136 .49676 m .51031 .5315 L .50924 .52801 L F
.52109 .50695 m .51674 .55246 L .51031 .5315 L F
.51664 .51258 m .51731 .51896 L .50942 .52862 L .575 .401 .609 r
F
.5072 .51445 m .51526 .50968 L .49608 .51895 L 0 0 0 r
F
.47231 .53628 m .47176 .53697 L .4723 .53655 L F
.48701 .54271 m .48911 .54463 L .48605 .54402 L .45 .357 .659 r
F
.48701 .54271 m .48605 .54402 L .48438 .54236 L F
.48605 .54402 m .48911 .54463 L .48736 .54533 L F
.48701 .54271 m .48589 .54096 L .48944 .54425 L F
.48701 .54271 m .48944 .54425 L .48911 .54463 L F
.48886 .54182 m .4723 .53655 L p .48576 .55865 L .602 .275 .388 r
F P
0 g
s
.4723 .53655 m .47071 .53605 L p .47154 .53729 L .602 .275 .388 r
F P
0 g
s
.48576 .55865 m .4723 .53655 L .47154 .53729 L .602 .275 .388 r
F
.47451 .5329 m .48325 .52863 L .48468 .52447 L 0 0 0 r
F
.47368 .53314 m .47326 .53562 L .47661 .53229 L F
.47748 .53204 m .48325 .52863 L .47451 .5329 L F
.48325 .52863 m .49771 .51867 L .48468 .52447 L F
.5072 .51445 m .49608 .51895 L .48468 .52447 L F
.48043 .52652 m .47368 .53314 L p .48468 .52447 L F P
0 g
s
.47451 .5329 m .48468 .52447 L .47368 .53314 L 0 0 0 r
F
.47282 .53818 m .47886 .53165 L p .47326 .53562 L F P
0 g
s
.47748 .53204 m .47934 .53132 L .48325 .52863 L 0 0 0 r
F
.47861 .53172 m .47934 .53132 L p .47748 .53204 L F P
0 g
s
.47886 .53165 m .49367 .51566 L p .47667 .53228 L 0 0 0 r
F P
0 g
s
.47326 .53562 m .47886 .53165 L .47667 .53228 L 0 0 0 r
F
.49367 .51566 m .49659 .51251 L p .47326 .53562 L F P
0 g
s
.47198 .52809 m .47445 .52638 L .47562 .52641 L .45 .357 .659 r
F
.47211 .52813 m .47282 .53818 L .47484 .52639 L 0 0 0 r
F
.47071 .53605 m .47861 .53172 L p .47748 .53204 L F P
0 g
s
.47071 .53605 m .47748 .53204 L .47451 .5329 L 0 0 0 r
F
.50053 .50825 m .47488 .52616 L p .47488 .5262 L F P
0 g
s
.47445 .52638 m .5174 .49667 L .47562 .52641 L .45 .357 .659 r
F
.47211 .52813 m .46819 .53472 L .47249 .53348 L 0 0 0 r
F
.4746 .52617 m .47386 .52637 L .47198 .52809 L .985 .887 .547 r
F
.47198 .52809 m .47386 .52637 L .47445 .52638 L .45 .357 .659 r
F
.48043 .52652 m .47071 .53605 L p .47386 .52637 L .255 0 0 r
F P
0 g
s
.47484 .52639 m .47368 .53314 L .49659 .51251 L 0 0 0 r
F
.47368 .53314 m .47661 .53229 L .49659 .51251 L F
.49245 .52229 m .4854 .56061 L .47886 .53165 L .73 .396 .414 r
F
.49579 .51999 m .4854 .56061 L .49245 .52229 L F
.48325 .52863 m .50841 .51512 L .51526 .50968 L 0 0 0 r
F
.51813 .49835 m .51951 .50155 L .50924 .52801 L .752 .501 .553 r
F
.48951 .57884 m .50847 .52551 L p .50924 .52801 L F P
0 g
s
.50847 .52551 m .51813 .49835 L p .50924 .52801 L .752 .501 .553 r
F P
0 g
s
.47934 .53132 m .5058 .51681 L p .48006 .53211 L .575 .401 .609 r
F P
0 g
s
.50847 .52551 m .51328 .51199 L p .49434 .54788 L .108 0 .251 r
F P
0 g
s
.5058 .51681 m .51646 .51096 L p .50589 .5171 L .575 .401 .609 r
F P
0 g
s
.5058 .51681 m .50589 .5171 L .48006 .53211 L .575 .401 .609 r
F
.51664 .51258 m .50942 .52862 L .50847 .52551 L F
.53409 .45713 m .53409 .45675 L p .53412 .45673 L .21 .349 .786 r
F P
0 g
s
.53756 .46546 m .53409 .45713 L .53409 .45675 L 0 0 .271 r
F
.54221 .46783 m .54215 .45674 L .5378 .47218 L .192 .012 .394 r
F
.54233 .49056 m .55735 .47487 L p .54215 .45674 L F P
0 g
s
.5428 .47858 m .53757 .46571 L .53756 .46546 L 0 0 .271 r
F
.53757 .46571 m .53409 .45713 L .53756 .46546 L F
.5428 .47858 m .53409 .45675 L .54257 .47654 L F
.53703 .46907 m .53409 .45713 L .53757 .46571 L F
.53778 .47244 m .53754 .46481 L .53614 .46923 L .985 .887 .547 r
F
.53764 .47401 m .53821 .46729 L .5428 .47858 L 0 0 .271 r
F
.53725 .47864 m .53764 .47401 L .5428 .47858 L F
.53387 .48757 m .53883 .48186 L .53778 .4722 L .192 .012 .394 r
F
.53387 .48757 m .53778 .4722 L .53771 .47227 L F
.52719 .51034 m .53094 .50387 L .53125 .49963 L .161 .053 .474 r
F
.52038 .50356 m .53883 .48186 L .52115 .50535 L .45 .357 .659 r
F
.53101 .49087 m .53883 .48186 L .52038 .50356 L F
.53038 .49782 m .53025 .49925 L p .53777 .47204 L .192 .012 .394 r
F P
0 g
s
.53088 .49949 m .53777 .47204 L .53025 .49925 L .192 .012 .394 r
F
.52136 .49676 m .52482 .49773 L .52592 .49495 L .161 .053 .474 r
F
.50597 .50184 m .5087 .49617 L .50985 .49861 L .183 .006 .391 r
F
.5026 .50581 m .50597 .50184 L p .51436 .49515 L 0 0 0 r
F P
0 g
s
.5101 .4984 m .51436 .49515 L .50597 .50184 L 0 0 0 r
F
.52237 .48664 m .53366 .45703 L p .53614 .46923 L 0 0 .185 r
F P
0 g
s
.53221 .47769 m .53614 .46923 L .5016 .50672 L .985 .887 .547 r
F
.53221 .47769 m .5016 .50672 L .51629 .49339 L F
.52606 .488 m .52592 .49495 L .53614 .46923 L .161 .053 .474 r
F
.52136 .49676 m .52592 .49495 L .52606 .488 L F
.5174 .49667 m .52859 .48894 L .52025 .50327 L .45 .357 .659 r
F
.52859 .48894 m .53883 .48186 L .52534 .4974 L F
.52859 .48894 m .52534 .4974 L .52025 .50327 L F
.52025 .50327 m .53101 .49087 L .52038 .50356 L F
.53101 .49087 m .53038 .49782 L p .53304 .48853 L .192 .012 .394 r
F P
0 g
s
.52264 .48794 m .5211 .48999 L .51636 .4934 L 0 0 0 r
F
.52289 .48773 m .5211 .48999 L p .52264 .48794 L F P
0 g
s
.52264 .48794 m .51436 .49515 L .51844 .49144 L 0 0 0 r
F
.52289 .48773 m .5211 .48999 L p .52329 .4866 L .874 .731 .7 r
F P
0 g
s
.52264 .48793 m .52289 .48773 L .52252 .48877 L .183 .006 .391 r
F
.53614 .46923 m .5211 .48999 L p .52745 .48542 L .161 .053 .474 r
F P
0 g
s
.5174 .49667 m .53614 .46923 L .53877 .4816 L .45 .357 .659 r
F
.5174 .49667 m .53877 .4816 L .53819 .4823 L F
.53101 .49087 m .53025 .49925 L p .52518 .49783 L .183 .006 .391 r
F P
0 g
s
.52719 .51034 m .53125 .49963 L .52917 .49885 L .161 .053 .474 r
F
.52635 .5046 m .5271 .50001 L .52697 .5042 L .218 .048 .425 r
F
.52115 .50535 m .52346 .50427 L .52162 .50644 L .45 .357 .659 r
F
.52209 .50588 m .52719 .51034 L .53278 .478 L .161 .053 .474 r
F
.52126 .50251 m .52518 .49783 L .52985 .50362 L .183 .006 .391 r
F
.53025 .49925 m .52985 .50362 L p .52518 .49783 L F P
0 g
s
.52917 .49885 m .53025 .49925 L .53278 .478 L .161 .053 .474 r
F
.54142 .49283 m .53926 .47861 L .53963 .47861 L 0 0 .271 r
F
.53155 .50283 m .53395 .49933 L .53542 .50103 L .547 .521 .778 r
F
.53302 .5003 m .53395 .49933 L p .53155 .50283 L F P
0 g
s
.53883 .48186 m .54179 .49579 L p .53362 .50053 L .751 .554 .629 r
F P
0 g
s
.53088 .49949 m .53816 .48425 L .53387 .48757 L .192 .012 .394 r
F
.53816 .48425 m .53989 .48064 L .53883 .48186 L F
.53816 .48425 m .53883 .48186 L .53387 .48757 L F
.53154 .49974 m .53989 .48064 L .53088 .49949 L F
.53956 .50585 m .53094 .50387 L p .53772 .52319 L .594 .413 .606 r
F P
0 g
s
.53094 .50387 m .52985 .50362 L p .5308 .50598 L .594 .413 .606 r
F P
0 g
s
.53772 .52319 m .53094 .50387 L .5308 .50598 L .594 .413 .606 r
F
.53154 .49974 m .54233 .49056 L .53989 .48064 L .192 .012 .394 r
F
.53029 .51305 m .53246 .51495 L .53259 .50014 L .161 .053 .474 r
F
.53029 .51305 m .53259 .50014 L .53125 .49963 L F
.53259 .50014 m .53258 .50106 L .53302 .5003 L F
.52985 .50362 m .53302 .5003 L p .53154 .49974 L .192 .012 .394 r
F P
0 g
s
.53302 .5003 m .54233 .49056 L p .53154 .49974 L .192 .012 .394 r
F P
0 g
s
.53125 .49963 m .53259 .50014 L .53278 .478 L .161 .053 .474 r
F
.52985 .50362 m .53302 .5003 L p .53155 .50283 L .547 .521 .778 r
F P
0 g
s
.53246 .51495 m .53362 .50053 L p .53302 .5003 L .161 .053 .474 r
F P
0 g
s
.53258 .50106 m .53246 .51495 L .53302 .5003 L .161 .053 .474 r
F
.52985 .50362 m .53154 .49974 L .53088 .49949 L .192 .012 .394 r
F
.53278 .478 m .53259 .50014 L .53614 .46923 L .161 .053 .474 r
F
.53362 .50053 m .53614 .46923 L p .53259 .50014 L F P
0 g
s
.53025 .49925 m .53125 .49963 L .53125 .49954 L .161 .053 .474 r
F
.53025 .49925 m .53125 .49954 L .53278 .478 L F
.53025 .49925 m .52985 .50362 L p .53088 .49949 L .192 .012 .394 r
F P
0 g
s
.53362 .50053 m .54055 .49651 L .53219 .55807 L .751 .554 .629 r
F
.54055 .49651 m .53805 .52008 L .53219 .55807 L F
.53542 .50103 m .54285 .49757 L .53956 .50585 L .547 .521 .778 r
F
.54285 .49757 m .56444 .48752 L .54327 .50312 L F
.54285 .49757 m .54327 .50312 L .53956 .50585 L F
.55107 .55639 m .55918 .55238 L p .54354 .50676 L .594 .413 .606 r
F P
0 g
s
.5476 .53349 m .54376 .50825 L .54219 .47858 L 0 0 .271 r
F
.55137 .57182 m .54376 .50825 L .5476 .53349 L F
.54405 .51373 m .54145 .47859 L .54219 .47858 L F
.54071 .50718 m .54912 .54966 L .53602 .55617 L .751 .554 .629 r
F
.54384 .51083 m .54912 .54966 L .54071 .50718 L F
.56272 .56892 m .5516 .56317 L p .56207 .55444 L .683 .619 .778 r
F P
0 g
s
.55107 .55639 m .55918 .55238 L p .5516 .56317 L .683 .619 .778 r
F P
0 g
s
.55918 .55238 m .56566 .54071 L .57005 .56011 L 0 0 .271 r
F
.56444 .48752 m .56791 .49372 L .55047 .50835 L .547 .521 .778 r
F
.57005 .56011 m .55312 .48523 L .61087 .57037 L 0 0 .271 r
F
.55918 .55238 m .57234 .54588 L p .56207 .55444 L .683 .619 .778 r
F P
0 g
s
.55918 .55238 m .56207 .55444 L .5516 .56317 L .683 .619 .778 r
F
.56207 .55444 m .56723 .55811 L .56272 .56892 L F
.54483 .56018 m .552 .57678 L .5537 .59028 L .45 .357 .659 r
F
.54912 .54966 m .55617 .60156 L .53602 .55617 L .751 .554 .629 r
F
.56272 .56892 m .54465 .55957 L p .55558 .59399 L .74 .58 .675 r
F P
0 g
s
.55726 .61071 m .54536 .51079 L .54219 .47858 L 0 0 .271 r
F
.55329 .60052 m .55417 .60466 L p .55617 .60156 L .74 .58 .675 r
F P
0 g
s
.55617 .60156 m .55642 .60333 L .55555 .60134 L .751 .554 .629 r
F
.55617 .60156 m .55555 .60134 L .53602 .55617 L F
.56499 .60473 m .56272 .56892 L .55822 .6023 L .74 .58 .675 r
F
.60061 .61755 m .63541 .60654 L p .56499 .60473 L F P
0 g
s
.55312 .48523 m .55735 .47487 L .61087 .57037 L 0 0 .271 r
F
.55735 .47487 m .56321 .46049 L .61087 .57037 L F
.57005 .56011 m .61087 .57037 L .62833 .60151 L F
.54062 .4524 m .53431 .45659 L .53418 .45567 L 0 0 .185 r
F
.56318 .38431 m .54173 .45167 L p .55271 .40704 L F P
0 g
s
.54173 .45167 m .53614 .46923 L p .54062 .4524 L 0 0 .185 r
F P
0 g
s
.54173 .45167 m .54062 .4524 L .55271 .40704 L 0 0 .185 r
F
.54267 .45495 m .55787 .40096 L .54173 .45167 L .985 .887 .547 r
F
.55789 .40183 m .55787 .40096 L .54267 .45495 L F
.54205 .45554 m .54173 .45167 L .5719 .4496 L .21 .349 .786 r
F
.53799 .40669 m .56258 .43781 L p .54173 .45167 L F P
0 g
s
.56258 .43781 m .5719 .4496 L p .54173 .45167 L .21 .349 .786 r
F P
0 g
s
.53412 .45673 m .53799 .40669 L .54173 .45167 L .21 .349 .786 r
F
.57625 .45511 m .56519 .45564 L p .56321 .46049 L .192 .012 .394 r
F P
0 g
s
.59897 .51667 m .56653 .45916 L .57437 .45601 L .35 .406 .779 r
F
.57601 .45536 m .57625 .45511 L p .56321 .46049 L .192 .012 .394 r
F P
0 g
s
.58535 .50529 m .56321 .46049 L .59897 .51667 L .35 .406 .779 r
F
.56519 .45564 m .54215 .45674 L p .5498 .46587 L .192 .012 .394 r
F P
0 g
s
.56321 .46049 m .56519 .45564 L .5498 .46587 L .192 .012 .394 r
F
.53432 .40204 m .53799 .40669 L p .53412 .45673 L .21 .349 .786 r
F P
0 g
s
.5719 .4496 m .57625 .45511 L .56075 .45585 L p .21 .349 .786 r
F P
0 g
s
.56321 .46049 m .53432 .40204 L .56653 .45916 L .35 .406 .779 r
F
.56321 .46049 m .56653 .45916 L .59897 .51667 L F
.55735 .47487 m .56321 .46049 L .5498 .46587 L .192 .012 .394 r
F
.55271 .40704 m .57228 .35571 L .56318 .38431 L p 0 0 .185 r
F P
0 g
s
.59756 .39567 m .58881 .40443 L .59197 .41373 L .681 .635 .797 r
F
.60429 .40631 m .59756 .39567 L .58611 .43265 L F
.60429 .40631 m .58611 .43265 L .58511 .44629 L F
.56282 .39994 m .57228 .35571 L .56318 .38431 L .985 .887 .547 r
F
.53432 .40204 m .57625 .45511 L .58234 .44332 L p .555 .476 .721 r
F P
0 g
s
.70191 .56071 m .59344 .40631 L .70272 .56015 L .35 .406 .779 r
F
.59344 .40631 m .57894 .38567 L .59344 .40612 L F
.59344 .40631 m .59344 .40612 L .70272 .56015 L F
.57894 .38567 m .57891 .38513 L .70272 .56015 L F
.59176 .45541 m .57625 .45511 L .59093 .47966 L p .7 .581 .718 r
F P
0 g
s
.57894 .38567 m .53432 .40204 L p .58234 .44332 L .555 .476 .721 r
F P
0 g
s
.57894 .38567 m .53432 .40204 L .52821 .31346 L p .592 .603 .832 r
F P
0 g
s
.63541 .60654 m .60411 .52097 L .70191 .56071 L .35 .406 .779 r
F
.60438 .52108 m .63399 .46402 L .70191 .56071 L F
.60411 .52097 m .60426 .52069 L .60438 .52108 L F
.60426 .52069 m .63399 .46402 L .60438 .52108 L F
.63541 .60654 m .5306 .34806 L .60624 .52679 L F
.58884 .47617 m .59093 .47966 L p .58896 .48597 L .547 .521 .778 r
F P
0 g
s
.5799 .5151 m .58743 .48234 L .58896 .48597 L .547 .521 .778 r
F
.58743 .48234 m .58884 .47617 L .58896 .48597 L F
.63541 .60654 m .58535 .50529 L .59897 .51667 L .35 .406 .779 r
F
.60426 .52069 m .5799 .5151 L p .59093 .47966 L .547 .521 .778 r
F P
0 g
s
.61102 .52675 m .61725 .52367 L .60426 .52069 L p .594 .413 .606 r
F P
0 g
s
.60426 .52069 m .60359 .52054 L p .60411 .52097 L .594 .413 .606 r
F P
0 g
s
.61102 .52675 m .60426 .52069 L .60411 .52097 L .594 .413 .606 r
F
.58548 .47774 m .58884 .47617 L .58587 .47866 L .547 .521 .778 r
F
.56791 .49372 m .58884 .47617 L .5799 .5151 L F
.57625 .45511 m .58884 .47617 L p .56444 .48752 L F P
0 g
s
.59197 .41373 m .58732 .41607 L .58611 .43265 L .681 .635 .797 r
F
.61968 .49129 m .52821 .31346 L .63399 .46402 L .35 .406 .779 r
F
.56983 .42724 m .52821 .31346 L .61968 .49129 L F
.6372 .44369 m .63547 .44418 L .63097 .4485 L .662 .597 .772 r
F
.64912 .4345 m .64058 .40117 L .63097 .4485 L .681 .635 .797 r
F
.59176 .45541 m .57625 .45511 L .58234 .44332 L p .692 .643 .797 r
F P
0 g
s
.60411 .52097 m .56983 .42724 L .61968 .49129 L .35 .406 .779 r
F
.61725 .52367 m .64967 .49262 L p .59176 .45541 L .7 .581 .718 r
F P
0 g
s
.64058 .40117 m .62261 .39367 L .63097 .4485 L .681 .635 .797 r
F
.70272 .56015 m .58457 .29431 L .72184 .5176 L .812 .664 .699 r
F
.58457 .29431 m .57234 .25706 L .72184 .5176 L F
.58457 .29431 m .52821 .31346 L .55315 .22362 L F
.63097 .4485 m .62261 .39367 L .58684 .37873 L .681 .635 .797 r
F
.66778 .50638 m .66274 .48681 L .66754 .50633 L .961 .674 .444 r
F
.70272 .56015 m .59346 .4057 L .58457 .29431 L .812 .664 .699 r
F
.58234 .44332 m .58464 .43886 L p .57894 .38567 L .555 .476 .721 r
F P
0 g
s
.59346 .4057 m .57891 .38513 L .58457 .29431 L .812 .664 .699 r
F
.58464 .43886 m .61993 .37062 L .57896 .38566 L p .555 .476 .721 r
F P
0 g
s
.57896 .38566 m .57894 .38567 L p .58464 .43886 L .555 .476 .721 r
F P
0 g
s
.57891 .38513 m .52821 .31346 L .56975 .29935 L .812 .664 .699 r
F
.57891 .38513 m .56975 .29935 L .58457 .29431 L F
.63776 .45633 m .59744 .45553 L p .64967 .49262 L .7 .581 .718 r
F P
0 g
s
.59744 .45553 m .59176 .45541 L p .59773 .45925 L .7 .581 .718 r
F P
0 g
s
.64967 .49262 m .59744 .45553 L .59773 .45925 L .7 .581 .718 r
F
.64967 .49262 m .68656 .45729 L .63776 .45633 L p F P
0 g
s
.58457 .29431 m .55315 .22362 L .57234 .25706 L .812 .664 .699 r
F
.61993 .37062 m .68656 .45729 L .63776 .45633 L p .692 .643 .797 r
F P
0 g
s
.63776 .45633 m .59176 .45541 L p .60892 .40374 L .692 .643 .797 r
F P
0 g
s
.60892 .40374 m .61993 .37062 L .63776 .45633 L .692 .643 .797 r
F
.58234 .44332 m .61993 .37062 L p .59176 .45541 L F P
0 g
s
.59093 .47966 m .61725 .52367 L .60426 .52069 L p .547 .521 .778 r
F P
0 g
s
.55918 .55238 m .5976 .53339 L p .5799 .5151 L .594 .413 .606 r
F P
0 g
s
.55735 .47487 m .57625 .45511 L p .56444 .48752 L .547 .521 .778 r
F P
0 g
s
.60624 .52679 m .5306 .34806 L .52821 .31346 L .35 .406 .779 r
F
.5976 .53339 m .61102 .52675 L p .60271 .52364 L .594 .413 .606 r
F P
0 g
s
.5976 .53339 m .60271 .52364 L .5799 .5151 L .594 .413 .606 r
F
.59093 .47966 m .61725 .52367 L p .59176 .45541 L .7 .581 .718 r
F P
0 g
s
.57894 .38567 m .52821 .31346 L .57891 .38513 L .35 .406 .779 r
F
.52821 .31346 m .61993 .37062 L .57894 .38567 L p .592 .603 .832 r
F P
0 g
s
.55735 .47487 m .57601 .45536 L p .56321 .46049 L .192 .012 .394 r
F P
0 g
s
.57437 .45601 m .53432 .40204 L .5306 .34806 L .35 .406 .779 r
F
.56653 .45916 m .53432 .40204 L .57437 .45601 L F
.60359 .52054 m .5799 .5151 L p .61102 .52675 L .594 .413 .606 r
F P
0 g
s
.56444 .48752 m .58548 .47774 L .56791 .49372 L .547 .521 .778 r
F
.58548 .47774 m .58587 .47866 L .56791 .49372 L F
.57234 .54588 m .61725 .52367 L p .57182 .56137 L .683 .619 .778 r
F P
0 g
s
.56723 .55811 m .57182 .56137 L .56272 .56892 L .683 .619 .778 r
F
.57234 .54588 m .57182 .56137 L .56723 .55811 L F
.55233 .56469 m .55918 .55238 L .58243 .61487 L 0 0 .271 r
F
.55918 .55238 m .57005 .56011 L .58243 .61487 L F
.55659 .60458 m .55646 .60367 L .54219 .47858 L F
.54354 .50676 m .53956 .50585 L p .55107 .55639 L .594 .413 .606 r
F P
0 g
s
.55107 .55639 m .53956 .50585 L .53772 .52319 L .594 .413 .606 r
F
.53017 .55908 m .53219 .55807 L .52901 .57867 L .751 .554 .629 r
F
.53362 .50053 m .53219 .55807 L .53017 .55908 L F
.52777 .57321 m .53246 .51495 L p .52495 .58627 L .161 .053 .474 r
F P
0 g
s
.52666 .55385 m .52081 .55198 L p .52778 .56026 L .602 .275 .388 r
F P
0 g
s
.52744 .57726 m .52885 .55973 L p .52901 .57867 L .751 .554 .629 r
F P
0 g
s
.52885 .55973 m .53362 .50053 L p .53017 .55908 L .751 .554 .629 r
F P
0 g
s
.53017 .55908 m .52901 .57867 L .52885 .55973 L .751 .554 .629 r
F
.5273 .5605 m .52081 .55198 L .51919 .55323 L .602 .275 .388 r
F
.53007 .56298 m .52778 .56026 L .5273 .5605 L F
.52778 .56026 m .52081 .55198 L .5273 .5605 L F
.53007 .56298 m .52885 .55973 L .52778 .56026 L F
.52885 .55973 m .52666 .55385 L .52778 .56026 L F
.53732 .52478 m .53349 .5827 L .52901 .57867 L .751 .554 .629 r
F
.53007 .56298 m .54465 .55957 L p .53233 .58166 L .712 .562 .682 r
F P
0 g
s
.5243 .57223 m .52504 .59027 L .51437 .57806 L .752 .501 .553 r
F
.52505 .59027 m .527 .59122 L .52383 .5969 L .712 .562 .682 r
F
.52383 .5969 m .52404 .60193 L .52373 .60203 L .218 .048 .425 r
F
.52383 .5969 m .52419 .59723 L .52404 .60193 L F
.52504 .59027 m .52549 .60148 L .5187 .58718 L .752 .501 .553 r
F
.52504 .59027 m .5187 .58718 L .51437 .57806 L F
.52744 .57726 m .53233 .58166 L .527 .59122 L .712 .562 .682 r
F
.52744 .57726 m .527 .59122 L .52505 .59027 L F
.53007 .56298 m .53233 .58166 L .52744 .57726 L F
.55555 .60134 m .55329 .60052 L .53349 .5827 L .751 .554 .629 r
F
.527 .59122 m .54465 .55957 L .55055 .6027 L .712 .562 .682 r
F
.52549 .60148 m .52744 .57726 L p .52901 .57867 L .751 .554 .629 r
F P
0 g
s
.52457 .57797 m .52534 .59748 L p .52462 .57732 L .161 .053 .474 r
F P
0 g
s
.52495 .58627 m .52509 .59008 L .52777 .57321 L .161 .053 .474 r
F
.52744 .57726 m .52777 .57321 L p .52509 .59008 L F P
0 g
s
.51437 .57806 m .5187 .58718 L .5137 .58474 L .752 .501 .553 r
F
.5216 .50662 m .51281 .5935 L .52109 .50695 L F
.49617 .57092 m .53007 .56298 L p .52505 .59027 L .712 .562 .682 r
F P
0 g
s
.49617 .57092 m .52505 .59027 L .50785 .58189 L .712 .562 .682 r
F
.49164 .57399 m .50213 .5791 L .48951 .57884 L .752 .501 .553 r
F
.51731 .51896 m .52985 .50362 L .52539 .52747 L .575 .401 .609 r
F
.51995 .54386 m .52539 .52747 L .52081 .55198 L F
.51731 .51896 m .52539 .52747 L .51995 .54386 L F
.49617 .57092 m .51831 .5539 L .51614 .5505 L .602 .275 .388 r
F
.51831 .5539 m .51785 .55204 L .51614 .5505 L F
.51614 .5505 m .51731 .51896 L .51995 .54386 L .575 .401 .609 r
F
.51759 .55096 m .51614 .5505 L p .51995 .54386 L F P
0 g
s
.52001 .61841 m .54353 .63085 L .54386 .63065 L .744 .572 .661 r
F
.52001 .61841 m .54386 .63065 L .527 .619 L F
.52001 .61841 m .55881 .62167 L .55821 .61684 L F
.52113 .61494 m .52001 .61841 L p .51828 .62088 L .985 .886 .642 r
F P
0 g
s
.52001 .61841 m .51065 .63679 L .51828 .62088 L .985 .886 .642 r
F
.51726 .62302 m .52343 .61653 L .52305 .63521 L .218 .048 .425 r
F
.50966 .60701 m .52113 .61494 L .51726 .62302 L F
.52113 .61494 m .52343 .61653 L .51726 .62302 L F
.51828 .62088 m .51065 .63679 L .51117 .63107 L .985 .886 .642 r
F
.52373 .60203 m .5236 .61665 L .52343 .61653 L .218 .048 .425 r
F
.49261 .61371 m .49553 .6227 L .52549 .60148 L .745 .509 .573 r
F
.50087 .58599 m .48951 .57884 L .48887 .60765 L p F P
0 g
s
.50101 .63957 m .50468 .63756 L p .49332 .65834 L .965 .803 .632 r
F P
0 g
s
.48918 .66845 m .50256 .66624 L .49324 .68083 L .965 .803 .632 r
F
.49332 .65834 m .50256 .66624 L .48918 .66845 L F
.49127 .68392 m .48914 .6751 L p .49324 .68083 L F P
0 g
s
.48217 .68874 m .48744 .67258 L .48195 .68501 L .96 .802 .642 r
F
.47681 .71409 m .48744 .67258 L .47547 .70929 L F
.48759 .66593 m .48744 .67272 L p .48571 .66388 L .989 .738 .453 r
F P
0 g
s
.48759 .66593 m .48571 .66388 L .48351 .65265 L .989 .738 .453 r
F
.4879 .65189 m .48759 .66593 L p .48351 .65265 L F P
0 g
s
.48406 .65407 m .48295 .64947 L p .48364 .65158 L .965 .803 .632 r
F P
0 g
s
.48744 .67272 m .49004 .66637 L .49401 .64615 L .745 .509 .573 r
F
.48364 .65158 m .49324 .68083 L .48406 .65407 L .965 .803 .632 r
F
.48914 .6751 m .48406 .65407 L p .49324 .68083 L F P
0 g
s
.49127 .68392 m .48914 .6751 L p .48938 .6873 L .96 .802 .642 r
F P
0 g
s
.48726 .68046 m .50516 .64348 L p .50101 .63957 L .745 .509 .573 r
F P
0 g
s
.49004 .66637 m .48726 .68046 L .50101 .63957 L .745 .509 .573 r
F
.49619 .63504 m .49004 .66637 L .50101 .63957 L F
.48295 .64947 m .49332 .65834 L .48918 .66845 L .965 .803 .632 r
F
.48295 .64947 m .4831 .63767 L .50468 .63756 L .666 .311 .362 r
F
.50299 .63848 m .50468 .63756 L .50069 .63317 L p .89 .581 .455 r
F P
0 g
s
.50069 .63317 m .49794 .63014 L p .50299 .63848 L .89 .581 .455 r
F P
0 g
s
.50101 .63957 m .50299 .63848 L p .49794 .63014 L .89 .581 .455 r
F P
0 g
s
.50516 .64348 m .52549 .60148 L p .49601 .62237 L .745 .509 .573 r
F P
0 g
s
.48843 .62773 m .50008 .63869 L .49601 .62237 L .745 .509 .573 r
F
.50008 .63869 m .50516 .64348 L .49601 .62237 L F
.49794 .63014 m .47309 .60274 L p .48496 .57804 L .883 .59 .487 r
F P
0 g
s
.48097 .63061 m .48514 .61603 L .4763 .62642 L .89 .581 .455 r
F
.48916 .59488 m .4837 .62359 L .47812 .61263 L .989 .738 .453 r
F
.4837 .62359 m .48337 .62536 L .48031 .61795 L F
.4837 .62359 m .48031 .61795 L .47812 .61263 L F
.46942 .60375 m .47529 .62102 L p .47982 .58595 L .733 .386 .392 r
F P
0 g
s
.47086 .60029 m .47982 .58595 L .48115 .5756 L .733 .386 .392 r
F
.46942 .60375 m .47982 .58595 L .47086 .60029 L F
.47086 .60029 m .45385 .58154 L p .48474 .57806 L .883 .59 .487 r
F P
0 g
s
.46321 .58947 m .45385 .58154 L .45638 .58125 L 0 .019 .579 r
F
.45385 .58154 m .46454 .57879 L p .46481 .58022 L .883 .59 .487 r
F P
0 g
s
.45385 .58154 m .4849 .57781 L .48474 .57806 L .883 .59 .487 r
F
.45385 .58154 m .44935 .57279 L p .45638 .58125 L 0 .019 .579 r
F P
0 g
s
.47982 .58595 m .47529 .62102 L .48311 .58067 L .733 .386 .392 r
F
.47812 .61263 m .48951 .57884 L .48916 .59488 L p .989 .738 .453 r
F P
0 g
s
.47529 .62102 m .48951 .57884 L .48564 .57662 L p .733 .386 .392 r
F P
0 g
s
.48474 .57806 m .4849 .57781 L .48496 .57804 L .883 .59 .487 r
F
.48391 .57382 m .48599 .5759 L .48496 .57804 L F
.48311 .58067 m .47529 .62102 L .48564 .57662 L .733 .386 .392 r
F
.4818 .61187 m .46703 .59584 L p .46321 .58947 L 0 .019 .579 r
F P
0 g
s
.46703 .59584 m .45385 .58154 L p .46321 .58947 L 0 .019 .579 r
F P
0 g
s
.4818 .61187 m .48161 .61214 L p .48171 .61225 L 0 0 .408 r
F P
0 g
s
.47877 .63831 m .48097 .63061 L .4763 .62642 L .89 .581 .455 r
F
.48031 .61795 m .47988 .61971 L .47812 .61263 L .989 .738 .453 r
F
.48555 .63066 m .47988 .61971 L .48031 .61795 L F
.48555 .63066 m .48383 .63558 L .47988 .61971 L F
.48295 .64947 m .47984 .64702 L .48196 .64095 L .666 .311 .362 r
F
.48182 .64007 m .48194 .641 L .47986 .64372 L .989 .738 .453 r
F
.48028 .64578 m .47986 .64372 L p .48194 .641 L F P
0 g
s
.47986 .64372 m .47529 .62102 L p .48182 .64007 L .989 .738 .453 r
F P
0 g
s
.47966 .6426 m .48134 .65034 L .48072 .64771 L 0 0 .181 r
F
.47877 .63831 m .47937 .64113 L .47966 .6426 L F
.47937 .64113 m .48134 .65034 L .47966 .6426 L F
.48013 .64508 m .47877 .63831 L p .48072 .64771 L F P
0 g
s
.48822 .63715 m .48383 .63558 L .48555 .63066 L .989 .738 .453 r
F
.48295 .64947 m .48196 .64095 L .4831 .63767 L .666 .311 .362 r
F
.48843 .62773 m .48822 .63715 L p .49619 .63504 L .745 .509 .573 r
F P
0 g
s
.4831 .63767 m .48843 .62773 L .4989 .63759 L .666 .311 .362 r
F
.47529 .62102 m .47812 .61263 L p .48102 .63415 L .989 .738 .453 r
F P
0 g
s
.48102 .63415 m .48182 .64007 L .47529 .62102 L .989 .738 .453 r
F
.47464 .6289 m .46942 .60375 L .45425 .58245 L .89 .581 .455 r
F
.47476 .62961 m .47479 .62975 L p .47482 .62975 L F P
0 g
s
.46758 .6136 m .4682 .61453 L .45385 .58154 L .89 .581 .455 r
F
.47482 .62975 m .47464 .6289 L .45385 .58154 L F
.46758 .6136 m .47106 .62171 L p .47158 .61965 L 0 .108 .634 r
F P
0 g
s
.46678 .61787 m .46758 .6136 L .47158 .61965 L .666 .35 .428 r
F
.46491 .61718 m .46648 .61193 L .46661 .61212 L F
.46678 .61787 m .47158 .61965 L .45952 .61136 L F
.47482 .62975 m .47503 .62978 L .47464 .6289 L .89 .581 .455 r
F
.47214 .61684 m .47482 .62975 L .47529 .62102 L .69 .553 .694 r
F
.47158 .61965 m .46767 .61313 L .47529 .62102 L .666 .35 .428 r
F
.47158 .61965 m .47529 .62102 L .47177 .61887 L F
.46758 .6136 m .46767 .61313 L .47158 .61965 L F
.46942 .60375 m .47214 .61684 L .47529 .62102 L .69 .553 .694 r
F
.46767 .61313 m .46942 .60375 L .47529 .62102 L .666 .35 .428 r
F
.47278 .62095 m .46758 .6136 L .47296 .62174 L 0 .108 .634 r
F
.47529 .62102 m .47728 .63032 L p .47826 .6354 L 0 0 .181 r
F P
0 g
s
.47529 .62102 m .47482 .62975 L .47449 .62972 L .896 .804 .75 r
F
.4731 .62245 m .47158 .61965 L .47431 .62857 L 0 .108 .634 r
F
.47296 .62174 m .47175 .61992 L .4731 .62245 L F
.47175 .61992 m .47158 .61965 L .4731 .62245 L F
.47529 .62102 m .47449 .62972 L .47351 .62323 L .896 .804 .75 r
F
.48295 .64947 m .48514 .61603 L .47853 .63915 L .89 .581 .455 r
F
.47937 .64113 m .48295 .64947 L p .47731 .63047 L 0 .108 .634 r
F P
0 g
s
.47877 .63831 m .47529 .62102 L p .47826 .6354 L 0 0 .181 r
F P
0 g
s
.48744 .67272 m .48726 .68046 L p .48992 .66698 L .745 .509 .573 r
F P
0 g
s
.48744 .67272 m .48726 .68046 L p .48594 .67063 L .989 .738 .453 r
F P
0 g
s
.48744 .67272 m .48594 .67063 L .48351 .65265 L .989 .738 .453 r
F
.48295 .64947 m .48225 .65504 L p .48744 .67258 L .96 .802 .642 r
F P
0 g
s
.48144 .651 m .48168 .65208 L .48295 .64947 L .592 .324 .479 r
F
.48493 .66888 m .48744 .67258 L .48225 .65504 L .96 .802 .642 r
F
.48726 .68046 m .51117 .63107 L p .50807 .64217 L .985 .886 .642 r
F P
0 g
s
.47715 .69587 m .47547 .70929 L p .48217 .68874 L .96 .802 .642 r
F P
0 g
s
.48217 .68874 m .48195 .68501 L .47715 .69587 L .96 .802 .642 r
F
.47547 .70929 m .47302 .7289 L p .47681 .71409 L F P
0 g
s
.47861 .68416 m .47715 .69587 L p .48064 .68797 L .96 .802 .642 r
F P
0 g
s
.50807 .64217 m .49214 .67538 L .48726 .68046 L .985 .886 .642 r
F
.4944 .71778 m .49646 .71606 L .48731 .68119 L .96 .802 .642 r
F
.50153 .6656 m .48872 .68847 L .48726 .68046 L .985 .886 .642 r
F
.47302 .7289 m .48731 .68119 L .48642 .67657 L .96 .802 .642 r
F
.47302 .7289 m .47767 .7265 L p .48731 .68119 L F P
0 g
s
.48212 .73178 m .48597 .69339 L p .47767 .7265 L .979 .88 .513 r
F P
0 g
s
.48212 .73178 m .48597 .69339 L p .48307 .73167 L .985 .886 .642 r
F P
0 g
s
.47767 .7265 m .49442 .71787 L p .48806 .68504 L .96 .802 .642 r
F P
0 g
s
.47767 .7265 m .48806 .68504 L .48731 .68119 L .96 .802 .642 r
F
.48173 .65236 m .48262 .65695 L .48172 .65296 L 0 0 .181 r
F
.48493 .66888 m .48172 .65296 L p .48262 .65695 L F P
0 g
s
.48225 .65504 m .48121 .66338 L p .48493 .66888 L .96 .802 .642 r
F P
0 g
s
.47265 .67 m .45215 .68842 L .4469 .65632 L .896 .804 .75 r
F
.45647 .67632 m .46654 .66611 L .45527 .67958 L .592 .324 .479 r
F
.46654 .66611 m .48144 .651 L .46688 .66812 L F
.20626 .72363 m .20671 .71117 L .29567 .78154 L closepath p .917 .572 .37 r
F P
0 g
s
.28539 .79375 m .29567 .78154 L .20626 .72363 L closepath p .901 .511 .271 r
F P
0 g
s
.3174 .81737 m .33956 .81792 L .25571 .79464 L closepath p .378 0 0 r
F P
0 g
s
.18906 .63714 m .3174 .81737 L .33956 .81792 L .9 .484 .141 r
F
.4469 .65632 m .4524 .68999 L .38042 .75791 L .896 .804 .75 r
F
.38685 .731 m .38042 .75791 L .3174 .81737 L F
.4469 .65632 m .38042 .75791 L .38685 .731 L F
.42405 .71691 m .43091 .71045 L .33956 .81792 L .592 .324 .479 r
F
.4524 .68999 m .43158 .70982 L .3174 .81737 L .896 .804 .75 r
F
.3379 .81788 m .41657 .72395 L .33956 .81792 L .592 .324 .479 r
F
.41657 .72395 m .41914 .72153 L .33956 .81792 L F
.3174 .81737 m .39194 .74177 L .3379 .81788 L F
.39194 .74177 m .45647 .67632 L .3379 .81788 L F
.45647 .67632 m .45527 .67958 L .33956 .81792 L F
.48144 .651 m .48147 .6512 L .46692 .6683 L F
.46688 .66812 m .46692 .6683 L .33956 .81792 L F
.48144 .651 m .46692 .6683 L .46688 .66812 L F
.48225 .65504 m .47526 .71102 L p .47682 .70892 L .038 0 .439 r
F P
0 g
s
.48726 .68046 m .48352 .69142 L p .48441 .69414 L .979 .88 .513 r
F P
0 g
s
.48441 .69414 m .47815 .70714 L .47789 .71764 L .979 .88 .513 r
F
.48441 .69414 m .47789 .71764 L .48116 .70975 L F
.48352 .69142 m .47815 .70714 L p .48441 .69414 L F P
0 g
s
.48597 .69339 m .48726 .68046 L p .47767 .7265 L .979 .88 .513 r
F P
0 g
s
.48597 .69339 m .48726 .68046 L p .48872 .68847 L .985 .886 .642 r
F P
0 g
s
.49025 .6909 m .48726 .68046 L .47815 .70714 L p 0 0 .038 r
F P
0 g
s
.48116 .70975 m .47789 .71764 L .47767 .7265 L .979 .88 .513 r
F
.47815 .70714 m .47534 .72373 L .47767 .7265 L F
.48726 .68046 m .48493 .66888 L p .48589 .6703 L .989 .738 .453 r
F P
0 g
s
.48726 .68046 m .48493 .66888 L p .48583 .67261 L 0 0 .181 r
F P
0 g
s
.49025 .6909 m .48726 .68046 L p .48583 .67261 L 0 0 .181 r
F P
0 g
s
.48225 .65504 m .49025 .6909 L .48262 .65695 L 0 0 .181 r
F
.48262 .65695 m .49025 .6909 L .48493 .66888 L F
.35438 .80052 m .43158 .70982 L .35632 .79961 L .866 .996 .785 r
F
.43158 .70982 m .46632 .77731 L .31906 .81694 L .896 .804 .75 r
F
.46632 .77731 m .46244 .77944 L .31906 .81694 L F
.47799 .65529 m .47967 .65331 L .47159 .67371 L .866 .996 .785 r
F
.47967 .65331 m .48127 .65303 L .47159 .67371 L F
.46937 .68138 m .47198 .68255 L .47261 .67075 L .69 .553 .694 r
F
.47159 .67371 m .47261 .67075 L .47265 .67 L F
.46937 .68138 m .47261 .67075 L .47159 .67371 L F
.43158 .70982 m .47261 .67075 L .47159 .67371 L .866 .996 .785 r
F
.45243 .69017 m .45255 .69089 L .43158 .70982 L .896 .804 .75 r
F
.45255 .69089 m .46664 .77714 L .43158 .70982 L F
.46619 .77831 m .46918 .77451 L .46553 .77851 L .895 .92 .831 r
F
.46664 .77714 m .46683 .77829 L .46632 .77731 L .896 .804 .75 r
F
.46664 .77714 m .46632 .77731 L .43158 .70982 L F
.4661 .77743 m .46918 .77451 L .4826 .74631 L .895 .92 .831 r
F
.46553 .77851 m .46692 .77698 L .4661 .77743 L F
.46692 .77698 m .46918 .77451 L .4661 .77743 L F
.46244 .77944 m .45357 .78176 L p .45107 .78285 L .363 0 0 r
F P
0 g
s
.45094 .78303 m .45843 .78163 L p .46724 .77529 L .895 .92 .831 r
F P
0 g
s
.45843 .78163 m .46448 .7805 L p .4661 .77743 L .895 .92 .831 r
F P
0 g
s
.45843 .78163 m .4661 .77743 L .46724 .77529 L .895 .92 .831 r
F
.46448 .7805 m .46626 .78016 L p .46678 .77756 L F P
0 g
s
.46632 .77731 m .46683 .77829 L .46244 .77944 L .896 .804 .75 r
F
.45107 .78285 m .45103 .78286 L .45103 .78286 L .363 0 0 r
F
.45103 .78286 m .35952 .80649 L .45103 .78286 L F
.35952 .80649 m .35952 .80649 L .45103 .78286 L F
.36946 .80734 m .32603 .81514 L .34607 .81436 L F
.45103 .78286 m .35952 .80649 L .36946 .80734 L F
.35952 .80649 m .32603 .81514 L .36946 .80734 L F
.45357 .78176 m .31906 .81694 L p .45107 .78285 L F P
0 g
s
.45094 .78303 m .451 .78288 L p .45103 .78287 L .894 .986 .792 r
F P
0 g
s
.45094 .78303 m .46724 .77529 L .47014 .76077 L .895 .92 .831 r
F
.49387 .72265 m .45094 .78303 L p .4826 .74631 L F P
0 g
s
.45107 .78285 m .45094 .78303 L p .45103 .78287 L .894 .986 .792 r
F P
0 g
s
.39441 .80863 m .41806 .79423 L .49083 .77556 L closepath p .026 0 0 r
F P
0 g
s
.41783 .79803 m .45094 .78303 L .37139 .81336 L p .394 .849 .793 r
F P
0 g
s
.39441 .80863 m .45094 .78303 L .46675 .78007 L p .446 .881 .863 r
F P
0 g
s
.46675 .78007 m .49083 .77556 L .47916 .77956 L p .446 .881 .863 r
F P
0 g
s
.47916 .77956 m .39441 .80863 L p .46675 .78007 L .446 .881 .863 r
F P
0 g
s
.47146 .75418 m .45107 .78285 L p .47787 .73227 L .894 .986 .792 r
F P
0 g
s
.39441 .80863 m .39643 .80645 L .39671 .80671 L .773 .729 .812 r
F
.36619 .81535 m .39441 .80863 L .41783 .79803 L p .394 .849 .793 r
F P
0 g
s
.37139 .81336 m .36619 .81535 L p .41783 .79803 L .394 .849 .793 r
F P
0 g
s
.45094 .78303 m .36619 .81535 L .41492 .79494 L p .329 .805 .735 r
F P
0 g
s
.36619 .81535 m .41492 .79494 L p .39711 .80037 L .408 .86 .845 r
F P
0 g
s
.33956 .81792 m .36584 .81538 L p .39711 .80037 L .408 .86 .845 r
F P
0 g
s
.36584 .81538 m .36619 .81535 L p .39711 .80037 L .408 .86 .845 r
F P
0 g
s
.45107 .78285 m .40787 .79581 L .41421 .79511 L .363 0 0 r
F
.40787 .79581 m .39535 .79957 L .407 .79681 L F
.40787 .79581 m .407 .79681 L .41421 .79511 L F
.407 .79681 m .33956 .81792 L p .41492 .79494 L .408 .86 .845 r
F P
0 g
s
.407 .79681 m .33956 .81792 L .3959 .80959 L p .135 0 0 r
F P
0 g
s
.41421 .79511 m .34607 .81436 L .36043 .81298 L .363 0 0 r
F
.39535 .79957 m .34607 .81436 L .41421 .79511 L F
.45107 .78285 m .36043 .81298 L .4493 .78355 L F
.41492 .79494 m .42062 .79255 L .407 .79681 L p .408 .86 .845 r
F P
0 g
s
.44935 .78353 m .45094 .78303 L p .41492 .79494 L .329 .805 .735 r
F P
0 g
s
.45107 .78285 m .37936 .81117 L .451 .78288 L .363 0 0 r
F
.42062 .79255 m .44935 .78353 L p .42006 .79324 L .329 .805 .735 r
F P
0 g
s
.41492 .79494 m .42062 .79255 L p .42006 .79324 L .329 .805 .735 r
F P
0 g
s
.42062 .79255 m .44935 .78353 L p .45669 .76659 L .891 .98 .815 r
F P
0 g
s
.47302 .7289 m .42062 .79255 L p .45669 .76659 L .891 .98 .815 r
F P
0 g
s
.451 .78288 m .47302 .7289 L p .44935 .78353 L .891 .98 .815 r
F P
0 g
s
.47787 .73227 m .47036 .74643 L .47035 .74645 L .894 .986 .792 r
F
.47036 .74643 m .45107 .78285 L .47035 .74645 L F
.47035 .74645 m .45107 .78285 L .45103 .78287 L F
.47135 .73301 m .46783 .75118 L .45912 .76302 L F
.47135 .73301 m .47787 .73227 L .46783 .75118 L F
.47302 .7289 m .47532 .72384 L p .47439 .72608 L 0 0 0 r
F P
0 g
s
.451 .78288 m .47135 .73301 L p .45103 .78287 L .894 .986 .792 r
F P
0 g
s
.48161 .73689 m .4621 .75344 L p .46024 .75758 L .91 .978 .78 r
F P
0 g
s
.45823 .7652 m .46172 .76272 L .45103 .78287 L .894 .986 .792 r
F
.45912 .76302 m .46172 .76272 L .45823 .7652 L F
.45912 .76302 m .46783 .75118 L .46172 .76272 L F
.47603 .75252 m .48161 .73689 L p .46024 .75758 L .91 .978 .78 r
F P
0 g
s
.46024 .75758 m .45616 .76668 L .47603 .75252 L .91 .978 .78 r
F
.46024 .75758 m .43606 .78099 L .45616 .76668 L F
.46024 .75758 m .43983 .77323 L .43606 .78099 L F
.42062 .79255 m .43119 .78446 L p .44148 .7708 L .017 0 .085 r
F P
0 g
s
.43688 .7728 m .42062 .79255 L p .44148 .7708 L .017 0 .085 r
F P
0 g
s
.47201 .73138 m .47302 .7289 L p .43119 .78446 L .017 0 .085 r
F P
0 g
s
.4621 .75344 m .42887 .78162 L p .46024 .75758 L .91 .978 .78 r
F P
0 g
s
.459 .76318 m .48161 .73689 L .44181 .77066 L p 0 0 0 r
F P
0 g
s
.43983 .77323 m .42887 .78162 L .4337 .7812 L .91 .978 .78 r
F
.43983 .77323 m .4337 .7812 L .43606 .78099 L F
.42062 .79255 m .43119 .78446 L p .42172 .7912 L .459 .838 .606 r
F P
0 g
s
.4493 .78355 m .36043 .81298 L .37936 .81117 L .363 0 0 r
F
.451 .78288 m .37936 .81117 L .38818 .81033 L F
.44935 .78353 m .45094 .78303 L .451 .78288 L p .891 .98 .815 r
F P
0 g
s
.45107 .78285 m .38818 .81033 L .3959 .80959 L .363 0 0 r
F
.3959 .80959 m .42062 .79255 L .407 .79681 L p .135 0 0 r
F P
0 g
s
.3959 .80959 m .42062 .79255 L p .42172 .7912 L .459 .838 .606 r
F P
0 g
s
.46244 .77944 m .45107 .78285 L .40437 .80549 L .363 0 0 r
F
.40479 .80556 m .40437 .80549 L .3959 .80959 L F
.46244 .77944 m .40437 .80549 L .40479 .80556 L F
.3959 .80959 m .46683 .77829 L .46244 .77944 L p F P
0 g
s
.3959 .80959 m .46238 .78025 L p .43555 .78135 L .91 .978 .78 r
F P
0 g
s
.46678 .77756 m .46683 .77829 L .46681 .77744 L .69 .553 .694 r
F
.47014 .76077 m .46724 .77529 L .4826 .74631 L .895 .92 .831 r
F
.46681 .77744 m .46683 .77829 L .4669 .777 L .69 .553 .694 r
F
.4669 .777 m .46683 .77829 L .46664 .77714 L .896 .804 .75 r
F
.46683 .77829 m .47603 .75252 L p .43606 .78099 L .91 .978 .78 r
F P
0 g
s
.46238 .78025 m .46683 .77829 L p .42887 .78162 L .91 .978 .78 r
F P
0 g
s
.46918 .77451 m .49548 .74102 L .4826 .74631 L .895 .92 .831 r
F
.46925 .77436 m .46683 .77829 L .49388 .72247 L .91 .982 .731 r
F
.46925 .77436 m .49388 .72247 L .49387 .72265 L F
.47135 .73301 m .47302 .7289 L p .48784 .73113 L .894 .986 .792 r
F P
0 g
s
.46683 .77829 m .48161 .73689 L .49402 .71949 L p .91 .982 .731 r
F P
0 g
s
.49388 .72247 m .46683 .77829 L .49402 .71949 L .91 .982 .731 r
F
.54752 .70892 m .49083 .77556 L .49548 .74102 L p .839 .875 .869 r
F P
0 g
s
.50179 .74263 m .49105 .74779 L p .48861 .75312 L .465 .19 .411 r
F P
0 g
s
.48527 .77239 m .48612 .75856 L p .49574 .75213 L .597 .402 .587 r
F P
0 g
s
.49083 .77556 m .53288 .76061 L .54752 .70892 L closepath p .861 .97 .863 r
F P
0 g
s
.50179 .74263 m .48965 .78998 L .49536 .75449 L .778 .572 .62 r
F
.49574 .75213 m .49612 .75154 L p .49536 .75449 L F P
0 g
s
.49612 .75154 m .50179 .74263 L p .49536 .75449 L .778 .572 .62 r
F P
0 g
s
.48527 .77239 m .47288 .83829 L .47622 .82929 L p .532 .326 .546 r
F P
0 g
s
.54617 .63224 m .49744 .71124 L .56216 .62393 L .744 .572 .661 r
F
.49744 .71124 m .49693 .71408 L .56216 .62393 L F
.4981 .71376 m .56062 .62608 L p .51353 .70251 L .91 .982 .731 r
F P
0 g
s
.50707 .70722 m .49741 .71522 L .4981 .71376 L .91 .982 .731 r
F
.51353 .70251 m .49861 .71427 L .50707 .70722 L F
.49861 .71427 m .49741 .71522 L .50707 .70722 L F
.52165 .70193 m .55605 .63498 L .57713 .65541 L .773 .729 .812 r
F
.49891 .71555 m .52864 .7115 L p .52416 .68314 L .866 .712 .688 r
F P
0 g
s
.55808 .63082 m .5306 .67524 L .5567 .63245 L .91 .982 .731 r
F
.5306 .67524 m .52951 .67657 L .5567 .63245 L F
.55572 .63473 m .55962 .63052 L .55576 .6347 L .773 .729 .812 r
F
.55678 .63367 m .55646 .63419 L .55675 .63362 L .91 .982 .731 r
F
.55576 .6347 m .55962 .63052 L .56025 .6314 L .773 .729 .812 r
F
.55096 .64302 m .53197 .67356 L p .55869 .62985 L .91 .982 .731 r
F P
0 g
s
.53197 .67356 m .53061 .67522 L .55869 .62985 L .91 .982 .731 r
F
.55962 .63052 m .54752 .70892 L .52869 .67757 L p .8 .699 .754 r
F P
0 g
s
.55646 .63419 m .55096 .64302 L p .55869 .62985 L .91 .982 .731 r
F P
0 g
s
.5566 .63341 m .55818 .6307 L .55962 .63052 L .799 .723 .78 r
F
.5566 .63341 m .55962 .63052 L .55675 .63362 L F
.55818 .6307 m .55962 .63052 L p .52869 .67757 L .8 .699 .754 r
F P
0 g
s
.53125 .68182 m .52869 .67757 L p .52864 .7115 L .866 .712 .688 r
F P
0 g
s
.52864 .7115 m .52869 .67757 L .52416 .68314 L .866 .712 .688 r
F
.49548 .74102 m .49891 .71555 L .52864 .7115 L p .839 .875 .869 r
F P
0 g
s
.52864 .7115 m .54752 .70892 L p .49548 .74102 L .839 .875 .869 r
F P
0 g
s
.52864 .7115 m .54752 .70892 L .53125 .68182 L p .866 .712 .688 r
F P
0 g
s
.55249 .70756 m .58713 .66965 L .55962 .63052 L .844 .742 .751 r
F
.57713 .65541 m .55962 .63052 L .63541 .60654 L .773 .729 .812 r
F
.55249 .70756 m .60964 .69186 L .58945 .6671 L p .844 .742 .751 r
F P
0 g
s
.60964 .69186 m .65755 .659 L .55833 .7337 L closepath p .507 .875 .657 r
F P
0 g
s
.53288 .76061 m .55833 .7337 L .60964 .69186 L closepath p 0 0 0 r
F P
0 g
s
.54752 .70892 m .60964 .69186 L .53288 .76061 L closepath p .804 .918 .915 r
F P
0 g
s
.60964 .69186 m .65755 .659 L .64074 .61917 L p .917 .898 .793 r
F P
0 g
s
.6493 .80083 m .75624 .8852 L .79942 .77066 L closepath p .544 .572 .833 r
F P
0 g
s
.71843 .81165 m .6493 .80083 L .75624 .8852 L .444 .554 .873 r
F
.64758 .6918 m .66281 .69655 L p .65425 .70308 L .656 .566 .741 r
F P
0 g
s
.6493 .80083 m .7079 .71061 L .63041 .74392 L p .697 .709 .857 r
F P
0 g
s
.63041 .74392 m .6493 .80083 L .63513 .74957 L .719 .694 .825 r
F
.61888 .73011 m .6493 .80083 L .63041 .74392 L F
.61888 .73011 m .5627 .77303 L .6493 .80083 L F
.63041 .74392 m .5627 .77303 L .6493 .80083 L p .697 .709 .857 r
F P
0 g
s
.66281 .69655 m .7079 .71061 L .66661 .72836 L p .656 .566 .741 r
F P
0 g
s
.66661 .72836 m .5627 .77303 L p .65206 .70476 L .656 .566 .741 r
F P
0 g
s
.66281 .69655 m .66661 .72836 L .65206 .70476 L .656 .566 .741 r
F
.5842 .62274 m .57005 .56011 L .63541 .60654 L 0 0 .271 r
F
.62833 .60151 m .61087 .57037 L .63541 .60654 L F
.61725 .52367 m .63541 .60654 L p .57182 .56137 L .683 .619 .778 r
F P
0 g
s
.64074 .61917 m .63541 .60654 L .62676 .63518 L p .917 .898 .793 r
F P
0 g
s
.62676 .63518 m .60964 .69186 L p .64074 .61917 L .917 .898 .793 r
F P
0 g
s
.7079 .71061 m .79942 .77066 L .6493 .80083 L closepath p .533 .488 .751 r
F P
0 g
s
.75624 .8852 m .8319 .98451 L .83919 .83943 L closepath p .18 .251 .701 r
F P
0 g
s
.79942 .77066 m .83919 .83943 L .79344 .86468 L p .105 .087 .551 r
F P
0 g
s
.78432 .86971 m .75624 .8852 L .77487 .83578 L p .105 .087 .551 r
F P
0 g
s
.65755 .659 m .65877 .62221 L .70272 .56015 L closepath p 0 0 .194 r
F P
0 g
s
.63541 .60654 m .70272 .56015 L .65755 .659 L closepath p .861 .886 .853 r
F P
0 g
s
.61815 .68262 m .7079 .71061 L .686 .61019 L closepath p .56 .638 .885 r
F P
0 g
s
.63541 .60654 m .70272 .56015 L .61725 .52367 L closepath p .812 .7 .74 r
F P
0 g
s
.61136 .58671 m .686 .61019 L .61815 .68262 L closepath p .492 .53 .824 r
F P
0 g
s
.61136 .58671 m .686 .61019 L .57542 .53347 L closepath p .215 .573 .941 r
F P
0 g
s
.61488 .58902 m .73102 .83294 L .8319 .98451 L 0 .041 .609 r
F
.60149 .56462 m .61027 .5828 L .61488 .58902 L F
.61027 .5828 m .73102 .83294 L .61488 .58902 L F
.7079 .71061 m .79942 .77066 L .74471 .65208 L closepath p .27 .472 .872 r
F P
0 g
s
.686 .61019 m .74471 .65208 L .7079 .71061 L closepath p .177 .345 .795 r
F P
0 g
s
.74471 .65208 m .74948 .70367 L .66097 .65114 L p .82 .401 .246 r
F P
0 g
s
.61815 .68262 m .61136 .58671 L .57031 .65052 L p .636 .644 .841 r
F P
0 g
s
.57031 .65052 m .55715 .67097 L .5752 .67442 L p .636 .644 .841 r
F P
0 g
s
.5752 .67442 m .61815 .68262 L p .57031 .65052 L .636 .644 .841 r
F P
0 g
s
.50769 .65923 m .49744 .71124 L .54617 .63224 L .744 .572 .661 r
F
.50651 .66005 m .49762 .7102 L .50769 .65923 L F
.49762 .7102 m .49744 .71124 L .50769 .65923 L F
.49743 .71116 m .49758 .71043 L .49127 .68392 L .96 .802 .642 r
F
.51065 .63679 m .4937 .69363 L .51117 .63107 L .985 .886 .642 r
F
.50933 .64531 m .4937 .69363 L .51065 .63679 L F
.49762 .7102 m .49127 .68392 L p .4978 .70917 L .965 .803 .632 r
F P
0 g
s
.49127 .68392 m .50052 .69387 L .4978 .70917 L .965 .803 .632 r
F
.49891 .71555 m .52416 .68314 L .50036 .71231 L .866 .712 .688 r
F
.49025 .6909 m .52039 .71011 L .51 .72853 L p .597 .402 .587 r
F P
0 g
s
.50179 .74263 m .50359 .73222 L p .50635 .73063 L .657 .519 .684 r
F P
0 g
s
.47302 .7289 m .49408 .71804 L p .48424 .73059 L .894 .986 .792 r
F P
0 g
s
.49408 .71804 m .4963 .7169 L p .49402 .71949 L .894 .986 .792 r
F P
0 g
s
.49408 .71804 m .49402 .71949 L .48424 .73059 L .894 .986 .792 r
F
.49645 .71612 m .49891 .71555 L .49851 .71435 L .96 .802 .642 r
F
.49442 .71787 m .4963 .7169 L p .49645 .71612 L F P
0 g
s
.4963 .7169 m .49891 .71555 L p .49645 .71612 L .96 .802 .642 r
F P
0 g
s
.49741 .71128 m .49741 .71129 L .49744 .71124 L .744 .572 .661 r
F
.49442 .71787 m .49851 .71435 L .4944 .71778 L .96 .802 .642 r
F
.49903 .71394 m .49891 .71555 L p .49928 .71364 L .866 .712 .688 r
F P
0 g
s
.49891 .71555 m .50036 .71231 L .49928 .71364 L .866 .712 .688 r
F
.49762 .7102 m .49741 .71128 L .49744 .71124 L .744 .572 .661 r
F
.49891 .71555 m .49861 .71427 L p .49851 .71435 L .96 .802 .642 r
F P
0 g
s
.49861 .71427 m .49739 .71528 L .49741 .71522 L .91 .982 .731 r
F
.49891 .71555 m .49387 .72265 L p .49396 .72062 L .894 .986 .792 r
F P
0 g
s
.49903 .71394 m .49891 .71555 L .49861 .71427 L p .965 .803 .632 r
F P
0 g
s
.49891 .71555 m .49387 .72265 L p .4826 .74631 L .895 .92 .831 r
F P
0 g
s
.48161 .73689 m .49402 .71949 L p .48843 .72583 L .744 .572 .661 r
F P
0 g
s
.42887 .78162 m .3959 .80959 L p .43555 .78135 L .91 .978 .78 r
F P
0 g
s
.43119 .78446 m .459 .76318 L .47201 .73138 L p .017 0 .085 r
F P
0 g
s
.47627 .72484 m .459 .76318 L .48212 .73178 L .979 .88 .513 r
F
.47302 .7289 m .43688 .7728 L p .44148 .7708 L .017 0 .085 r
F P
0 g
s
.459 .76318 m .47201 .73138 L p .47439 .72608 L 0 0 0 r
F P
0 g
s
.47201 .73138 m .47302 .7289 L p .47439 .72608 L 0 0 0 r
F P
0 g
s
.47302 .7289 m .47532 .72384 L p .47682 .70892 L .038 0 .439 r
F P
0 g
s
.47526 .71102 m .47302 .7289 L p .47682 .70892 L .038 0 .439 r
F P
0 g
s
.48494 .66709 m .48225 .65504 L .47532 .72384 L .038 0 .439 r
F
.4733 .72132 m .459 .76318 L p .47627 .72484 L .979 .88 .513 r
F P
0 g
s
.48331 .73165 m .48161 .73689 L p .48843 .72583 L .744 .572 .661 r
F P
0 g
s
.48161 .73689 m .48212 .73178 L p .47843 .73679 L .979 .88 .513 r
F P
0 g
s
.459 .76318 m .47812 .74094 L p .47843 .73679 L .979 .88 .513 r
F P
0 g
s
.47812 .74094 m .48161 .73689 L p .47843 .73679 L .979 .88 .513 r
F P
0 g
s
.48161 .73689 m .48212 .73178 L p .48307 .73167 L .985 .886 .642 r
F P
0 g
s
.50179 .74263 m .459 .76318 L .47207 .73296 L p .579 .403 .607 r
F P
0 g
s
.47207 .73296 m .49025 .6909 L .50179 .74263 L p .579 .403 .607 r
F P
0 g
s
.51484 .75471 m .51423 .75964 L p .51484 .75735 L .41 .291 .606 r
F P
0 g
s
.51425 .76 m .51979 .76773 L p .52483 .71281 L .682 .555 .703 r
F P
0 g
s
.51484 .75735 m .51606 .75285 L .51575 .75333 L .41 .291 .606 r
F
.51484 .75735 m .51575 .75333 L .51484 .75471 L F
.51528 .77705 m .51538 .77664 L p .51541 .77663 L .819 .694 .727 r
F P
0 g
s
.50816 .80841 m .51528 .77705 L p .51518 .77542 L .41 .291 .606 r
F P
0 g
s
.51295 .77711 m .51518 .77542 L .51494 .77131 L .41 .291 .606 r
F
.51295 .77711 m .51494 .77131 L .51447 .7672 L F
.50816 .80841 m .51518 .77542 L .51295 .77711 L F
.50816 .80841 m .51462 .76619 L .51376 .76387 L F
.51418 .76004 m .50816 .80841 L p .51425 .76 L F P
0 g
s
.51528 .77438 m .51979 .76773 L .51494 .77131 L p .765 .548 .603 r
F P
0 g
s
.51425 .76 m .51979 .76773 L .51494 .77131 L p .778 .572 .62 r
F P
0 g
s
.51528 .77705 m .51538 .77664 L p .51425 .76001 L .41 .291 .606 r
F P
0 g
s
.51528 .77705 m .51425 .76001 L .51425 .76 L .41 .291 .606 r
F
.51425 .76 m .51473 .76143 L .51979 .76773 L .819 .466 .389 r
F
.51979 .76773 m .52519 .77445 L .51538 .77664 L .796 .591 .624 r
F
.51528 .77438 m .51979 .76773 L p .51538 .77664 L F P
0 g
s
.51979 .76773 m .54265 .77056 L p .52519 .77445 L .796 .591 .624 r
F P
0 g
s
.51603 .77459 m .51808 .77174 L .52399 .77359 L .819 .694 .727 r
F
.51701 .77141 m .52078 .77128 L .52399 .77359 L F
.52078 .77128 m .52456 .77116 L .52399 .77359 L F
.51473 .76143 m .51718 .7687 L .51979 .76773 L .819 .466 .389 r
F
.51979 .76773 m .51835 .77136 L .52533 .77113 L .082 0 .156 r
F
.51979 .76773 m .52533 .77113 L .54265 .77056 L F
.5401 .76719 m .54382 .68823 L .55671 .76059 L .819 .694 .727 r
F
.51627 .75893 m .51425 .76 L .51979 .76773 L .506 .498 .782 r
F
.54597 .66491 m .55025 .66723 L p .5483 .67071 L .657 .519 .684 r
F P
0 g
s
.54382 .68823 m .52483 .71281 L p .55025 .66723 L .657 .519 .684 r
F P
0 g
s
.55651 .63336 m .55649 .63339 L .55869 .62985 L .91 .982 .731 r
F
.527 .619 m .54386 .63065 L .55881 .62167 L .744 .572 .661 r
F
.56335 .6154 m .56749 .61645 L .56308 .62263 L .69 .553 .694 r
F
.55821 .61684 m .55881 .62167 L .56749 .61645 L .744 .572 .661 r
F
.56499 .60473 m .56666 .61255 L p .5649 .6047 L .751 .554 .629 r
F P
0 g
s
.55748 .6112 m .55233 .56469 L .58243 .61487 L 0 0 .271 r
F
.55735 .61127 m .55646 .60367 L .55659 .60458 L F
.56216 .62393 m .56749 .61645 L p .55881 .62167 L .744 .572 .661 r
F P
0 g
s
.54386 .63065 m .55922 .62501 L .55881 .62167 L .744 .572 .661 r
F
.55922 .62501 m .56216 .62393 L .55881 .62167 L F
.55773 .61297 m .52549 .60148 L p .52901 .57867 L .751 .554 .629 r
F P
0 g
s
.55732 .61117 m .55735 .61127 L .55628 .61073 L .45 .357 .659 r
F
.55732 .61117 m .55726 .61071 L .55735 .61127 L 0 0 .271 r
F
.55642 .60333 m .55773 .61297 L .52901 .57867 L .751 .554 .629 r
F
.55808 .63082 m .5567 .63245 L .56062 .62608 L .91 .982 .731 r
F
.54393 .6307 m .56216 .62393 L .54386 .63065 L .744 .572 .661 r
F
.54617 .63224 m .56216 .62393 L .54353 .63085 L F
.52413 .60869 m .52431 .60832 L .52391 .61686 L .218 .048 .425 r
F
.56749 .61645 m .52549 .60148 L .52113 .61494 L p .744 .572 .661 r
F P
0 g
s
.52113 .61494 m .52581 .61817 L .56749 .61645 L .744 .572 .661 r
F
.55962 .63052 m .55286 .67431 L p .55578 .67204 L .844 .742 .751 r
F P
0 g
s
.55715 .67097 m .55311 .63987 L p .56908 .62529 L .564 .548 .795 r
F P
0 g
s
.56801 .58237 m .54753 .63765 L p .55307 .63999 L .411 .386 .721 r
F P
0 g
s
.55309 .63993 m .56801 .58237 L .55307 .63999 L .411 .386 .721 r
F
.56349 .60343 m .56801 .58237 L .55307 .63999 L F
.57031 .65052 m .55715 .67097 L p .56908 .62529 L .564 .548 .795 r
F P
0 g
s
.58863 .58263 m .61136 .58671 L p .598 .5989 L .564 .548 .795 r
F P
0 g
s
.61136 .58671 m .57031 .65052 L p .56908 .62529 L .564 .548 .795 r
F P
0 g
s
.49617 .57092 m .53007 .56298 L p .51919 .55323 L .602 .275 .388 r
F P
0 g
s
.45402 .55847 m .44872 .55702 L p .44326 .56711 L .52 0 0 r
F P
0 g
s
.44326 .56711 m .44378 .5676 L .45402 .55847 L .52 0 0 r
F
.44271 .56922 m .45402 .55847 L p .44225 .56897 L F P
0 g
s
.42249 .55526 m .43446 .56479 L p .44872 .55702 L .52 0 0 r
F P
0 g
s
.44271 .56922 m .43446 .56479 L .44537 .57218 L 0 .327 .811 r
F
.40831 .54706 m .40495 .54711 L p .44537 .57218 L F P
0 g
s
.43446 .56479 m .44149 .57038 L p .44225 .56897 L .52 0 0 r
F P
0 g
s
.43446 .56479 m .44225 .56897 L .44872 .55702 L .52 0 0 r
F
.41695 .55084 m .40631 .5468 L .4083 .54652 L .494 0 0 r
F
.41218 .54705 m .41695 .55084 L p .41213 .54844 L F P
0 g
s
.45402 .55847 m .41218 .54705 L .41981 .54467 L p .599 .105 .051 r
F P
0 g
s
.41533 .5505 m .42374 .54855 L .42663 .55294 L .729 .339 .311 r
F
.43208 .54662 m .42903 .54839 L .42736 .54771 L .599 .105 .051 r
F
.43208 .54662 m .42736 .54771 L .41981 .54467 L F
.44181 .54098 m .42895 .54317 L p .42171 .54435 L .125 .672 .704 r
F P
0 g
s
.44181 .54098 m .43208 .54662 L .41981 .54467 L .599 .105 .051 r
F
.46582 .53695 m .42903 .54839 L .44181 .54098 L F
.42374 .54855 m .4713 .53753 L .42663 .55294 L .729 .339 .311 r
F
.45402 .55847 m .45488 .561 L p .45474 .56339 L .897 .477 .142 r
F P
0 g
s
.45404 .56033 m .45474 .56339 L .45415 .57328 L .897 .477 .142 r
F
.45402 .55847 m .45474 .56339 L .45404 .56033 L F
.4713 .53753 m .48381 .56928 L p .45568 .55668 L .729 .339 .311 r
F P
0 g
s
.4854 .56061 m .48775 .57105 L .48381 .56928 L .73 .396 .414 r
F
.4713 .53753 m .48544 .57343 L p .4714 .53743 L .602 .275 .388 r
F P
0 g
s
.4723 .53655 m .45402 .55847 L .47268 .53626 L 0 0 0 r
F
.46479 .54389 m .45402 .55847 L .4723 .53655 L F
.45402 .55847 m .47282 .53818 L p .47268 .53626 L F P
0 g
s
.45368 .55877 m .4713 .53753 L .45393 .55882 L .729 .339 .311 r
F
.42663 .55294 m .45046 .54472 L .45368 .55877 L F
.45046 .54472 m .4713 .53753 L .45368 .55877 L F
.43446 .56479 m .42016 .5551 L .41116 .54864 L .494 0 0 r
F
.4318 .55589 m .41533 .5505 L p .45393 .55882 L .729 .339 .311 r
F P
0 g
s
.4318 .55589 m .41533 .5505 L p .42809 .55564 L .695 .233 .151 r
F P
0 g
s
.41218 .54705 m .41213 .54844 L .40939 .54667 L .494 0 0 r
F
.41018 .54626 m .41218 .54705 L p .4083 .54652 L F P
0 g
s
.40913 .5465 m .4713 .53753 L .41533 .5505 L .729 .339 .311 r
F
.41116 .54864 m .44149 .57038 L .40631 .5468 L .494 0 0 r
F
.40939 .54667 m .41213 .54844 L .4083 .54652 L F
.42263 .54687 m .40831 .54706 L p .43446 .56479 L 0 .327 .811 r
F P
0 g
s
.44326 .56711 m .44225 .56897 L .44378 .5676 L .52 0 0 r
F
.42263 .54687 m .43446 .56479 L .44271 .56922 L 0 .327 .811 r
F
.54465 .55957 m .55329 .60052 L p .55509 .59245 L .74 .58 .675 r
F P
0 g
s
.54465 .55957 m .55329 .60052 L p .54982 .5974 L .712 .562 .682 r
F P
0 g
s
.49434 .54788 m .49321 .56717 L .49661 .54429 L .108 0 .251 r
F
.49661 .54429 m .48886 .54182 L p .49288 .56936 L .602 .275 .388 r
F P
0 g
s
.49288 .56936 m .48886 .54182 L .48576 .55865 L .602 .275 .388 r
F
.45568 .55668 m .47886 .53165 L p .4854 .56061 L .73 .396 .414 r
F P
0 g
s
.48885 .57263 m .49288 .56936 L .48576 .55865 L .602 .275 .388 r
F
.48981 .57605 m .48881 .57575 L .4854 .56061 L .73 .396 .414 r
F
.48885 .57263 m .48576 .55865 L .48472 .5643 L .602 .275 .388 r
F
.49288 .56936 m .50847 .52551 L p .49321 .56717 L .108 0 .251 r
F P
0 g
s
.49661 .54429 m .49321 .56717 L .50847 .52551 L .108 0 .251 r
F
.49288 .56936 m .49617 .57092 L .51614 .5505 L .602 .275 .388 r
F
.43595 .5467 m .5511 .5778 L p .52594 .56861 L .217 .596 .948 r
F P
0 g
s
.55667 .60448 m .54219 .47858 L .5428 .47858 L 0 0 .271 r
F
.55547 .59482 m .54219 .47858 L .55667 .60448 L F
.55732 .60967 m .55667 .60448 L .5428 .47858 L F
.5511 .5778 m .55689 .57936 L p .54907 .57665 L .217 .596 .948 r
F P
0 g
s
.54907 .57665 m .52594 .56861 L .5511 .5778 L .217 .596 .948 r
F
.41627 .54547 m .43939 .54147 L .44084 .54193 L .729 .339 .311 r
F
.43939 .54147 m .47071 .53605 L .44084 .54193 L F
.47071 .53605 m .4713 .53753 L p .44084 .54193 L F P
0 g
s
.44209 .54082 m .47043 .53591 L .44195 .5409 L .255 0 0 r
F
.44209 .54082 m .44195 .5409 L .42895 .54317 L F
.41981 .54467 m .45373 .53407 L p .44181 .54098 L .599 .105 .051 r
F P
0 g
s
.47047 .53609 m .44181 .54098 L p .47043 .53591 L .255 0 0 r
F P
0 g
s
.44195 .5409 m .47043 .53591 L .44181 .54098 L .255 0 0 r
F
.41077 .54613 m .47071 .53605 L .44181 .54098 L p .125 .672 .704 r
F P
0 g
s
.41077 .54613 m .44181 .54098 L .42171 .54435 L .125 .672 .704 r
F
.41077 .54613 m .42895 .54317 L .40966 .54633 L F
.41512 .5454 m .47071 .53605 L p .41627 .54547 L .729 .339 .311 r
F P
0 g
s
.52594 .56861 m .48419 .5541 L .46442 .54932 L .217 .596 .948 r
F
.4714 .53743 m .47154 .53729 L .47071 .53605 L .602 .275 .388 r
F
.47206 .52817 m .47211 .52813 L .47215 .52807 L 0 0 0 r
F
.47114 .52915 m .47211 .52813 L .47206 .52817 L F
.47198 .52809 m .47258 .52784 L .47206 .52817 L .45 .357 .659 r
F
.47268 .53618 m .4723 .53655 L .47268 .53626 L 0 0 0 r
F
.47071 .53605 m .4713 .53753 L p .4714 .53743 L .602 .275 .388 r
F P
0 g
s
.4723 .53655 m .47071 .53605 L .47861 .53172 L p .575 .401 .609 r
F P
0 g
s
.47368 .53314 m .47071 .53605 L p .47451 .5329 L 0 0 0 r
F P
0 g
s
.49539 .51067 m .5087 .49617 L .50597 .50184 L .183 .006 .391 r
F
.50244 .50581 m .49606 .506 L .47386 .52637 L .985 .887 .547 r
F
.50244 .50581 m .47386 .52637 L .4746 .52617 L F
.47386 .52637 m .47489 .5261 L .47484 .52639 L .255 0 0 r
F
.45891 .53024 m .47251 .52634 L .47386 .52637 L F
.45891 .53024 m .47386 .52637 L .47071 .53605 L F
.47071 .53605 m .47047 .53609 L p .47043 .53591 L F P
0 g
s
.51636 .4934 m .5211 .48999 L .51436 .49515 L 0 0 0 r
F
.5211 .48999 m .50053 .50825 L .5026 .50581 L p F P
0 g
s
.51436 .49515 m .5211 .48999 L .5026 .50581 L 0 0 0 r
F
.50244 .50581 m .53614 .46923 L .49606 .506 L .985 .887 .547 r
F
.47445 .52638 m .51429 .48947 L .5174 .49667 L .45 .357 .659 r
F
.47386 .52637 m .53614 .46923 L .47445 .52638 L F
.4156 .50726 m .47073 .50819 L .48595 .55469 L p .43 .62 .931 r
F P
0 g
s
.48419 .5541 m .48302 .55369 L .47198 .55002 L .217 .596 .948 r
F
.48302 .55369 m .47228 .55005 L .47198 .55002 L F
.48419 .5541 m .47198 .55002 L .46442 .54932 L F
.47228 .55005 m .46934 .54783 L p .43595 .5467 L .28 .563 .932 r
F P
0 g
s
.46934 .54783 m .4156 .50726 L .42589 .52721 L p .28 .563 .932 r
F P
0 g
s
.42589 .52721 m .43595 .5467 L p .46934 .54783 L .28 .563 .932 r
F P
0 g
s
.36452 .51251 m .4156 .50726 L .43595 .5467 L closepath p .423 .662 .96 r
F P
0 g
s
.43569 .54657 m .43595 .5467 L p .49367 .56075 L .217 .596 .948 r
F P
0 g
s
.52594 .56861 m .43569 .54657 L .49367 .56075 L .217 .596 .948 r
F
.39778 .52843 m .43569 .54657 L p .52594 .56861 L F P
0 g
s
.47228 .55005 m .4156 .50726 L p .48595 .55469 L .43 .62 .931 r
F P
0 g
s
.48555 .55346 m .48595 .55469 L p .54012 .57279 L .427 .617 .93 r
F P
0 g
s
.54571 .57471 m .5435 .57395 L p .55689 .57936 L .217 .596 .948 r
F P
0 g
s
.5435 .57395 m .37981 .51776 L p .53594 .57208 L .217 .596 .948 r
F P
0 g
s
.5435 .57395 m .53594 .57208 L .55689 .57936 L .217 .596 .948 r
F
.53007 .56298 m .54465 .55957 L .53522 .55657 L p .602 .275 .388 r
F P
0 g
s
.53007 .56298 m .53522 .55657 L .52885 .55973 L .602 .275 .388 r
F
.53695 .53046 m .54465 .55957 L .53522 .55657 L p .575 .401 .609 r
F P
0 g
s
.51976 .50781 m .52109 .50695 L .51929 .51105 L .752 .501 .553 r
F
.51802 .51039 m .52985 .50362 L .51731 .51896 L .575 .401 .609 r
F
.51802 .51039 m .51731 .51896 L .51664 .51258 L F
.48325 .52863 m .5072 .51445 L .49771 .51867 L 0 0 0 r
F
.51646 .51096 m .5165 .51126 L .48006 .53211 L .575 .401 .609 r
F
.49661 .54429 m .48886 .54182 L p .51802 .51039 L F P
0 g
s
.48006 .53211 m .51802 .51039 L .48886 .54182 L .575 .401 .609 r
F
.49933 .51591 m .49905 .51775 L p .49659 .51251 L .73 .396 .414 r
F P
0 g
s
.49905 .51775 m .49579 .51999 L .49659 .51251 L .73 .396 .414 r
F
.49933 .51591 m .49905 .51775 L p .51813 .49835 L .108 0 .251 r
F P
0 g
s
.49905 .51775 m .51117 .51284 L .51813 .49835 L .108 0 .251 r
F
.52985 .50362 m .53073 .50695 L p .52081 .55198 L .575 .401 .609 r
F P
0 g
s
.52666 .55385 m .52081 .55198 L p .53073 .50695 L .575 .401 .609 r
F P
0 g
s
.50942 .52862 m .51731 .51896 L .51614 .5505 L .575 .401 .609 r
F
.5058 .51681 m .51646 .51096 L p .50841 .51512 L 0 0 0 r
F P
0 g
s
.51646 .51096 m .51793 .51002 L .50841 .51512 L 0 0 0 r
F
.47934 .53132 m .5058 .51681 L p .48325 .52863 L F P
0 g
s
.5058 .51681 m .50841 .51512 L .48325 .52863 L 0 0 0 r
F
.50841 .51512 m .51793 .51002 L .51976 .50781 L F
.47886 .53165 m .49659 .51251 L p .49579 .51999 L .73 .396 .414 r
F P
0 g
s
.47073 .50819 m .52658 .51559 L .54446 .57419 L p .363 .591 .932 r
F P
0 g
s
.37981 .51776 m .37937 .51767 L .55689 .57936 L .217 .596 .948 r
F
.54499 .57452 m .54571 .57471 L .54012 .57279 L .63 .528 .72 r
F
.45404 .56033 m .45415 .57328 L .45368 .55879 L .897 .477 .142 r
F
.45415 .57328 m .45405 .57488 L .45368 .55879 L F
.44596 .56613 m .45368 .55879 L p .45405 .57488 L F P
0 g
s
.45374 .55905 m .45568 .55668 L .45474 .56339 L .729 .339 .311 r
F
.45649 .56396 m .45474 .56339 L p .45864 .56793 L .695 .233 .151 r
F P
0 g
s
.4626 .56596 m .45649 .56396 L p .47743 .57548 L .695 .233 .151 r
F P
0 g
s
.47743 .57548 m .45649 .56396 L .45864 .56793 L .695 .233 .151 r
F
.46454 .57879 m .47743 .57548 L p .45864 .56793 L F P
0 g
s
.46481 .58022 m .47743 .57548 L .47642 .57882 L .883 .59 .487 r
F
.46454 .57879 m .47743 .57548 L p .46481 .58022 L F P
0 g
s
.47642 .57882 m .48391 .57382 L .4849 .57781 L .883 .59 .487 r
F
.47743 .57548 m .48391 .57382 L p .47642 .57882 L F P
0 g
s
.47743 .57548 m .48544 .57343 L .4626 .56596 L p .695 .233 .151 r
F P
0 g
s
.51386 .65286 m .50933 .64531 L p .54011 .63611 L .8 .699 .754 r
F P
0 g
s
.52343 .61653 m .5236 .61665 L .52305 .63521 L .218 .048 .425 r
F
.52549 .60148 m .50087 .58599 L p .49328 .61144 L .745 .509 .573 r
F P
0 g
s
.49328 .61144 m .49374 .61329 L .52549 .60148 L .745 .509 .573 r
F
.48951 .57884 m .48564 .57662 L p .48576 .57638 L .73 .396 .414 r
F P
0 g
s
.48877 .57556 m .48824 .57558 L .48671 .57439 L .73 .396 .414 r
F
.48824 .57558 m .48611 .57565 L .4864 .57504 L F
.48824 .57558 m .4864 .57504 L .48671 .57439 L F
.48544 .57343 m .49098 .57435 L .48994 .57609 L .712 .562 .682 r
F
.48833 .57561 m .48994 .57609 L .48964 .57659 L F
.48877 .57556 m .48881 .57575 L .48824 .57558 L .73 .396 .414 r
F
.48544 .57343 m .48994 .57609 L .48833 .57561 L .712 .562 .682 r
F
.48601 .57603 m .48599 .5759 L .48602 .57602 L .883 .59 .487 r
F
.48544 .57343 m .48611 .57565 L p .48599 .5759 L F P
0 g
s
.48824 .57558 m .48951 .57884 L .48576 .57638 L .73 .396 .414 r
F
.48824 .57558 m .48576 .57638 L .48611 .57565 L F
.49126 .60334 m .49328 .61144 L .50087 .58599 L .745 .509 .573 r
F
.55555 .60134 m .55642 .60333 L .55329 .60052 L .751 .554 .629 r
F
.55617 .60156 m .55509 .59245 L .55329 .60052 L .74 .58 .675 r
F
.54353 .63085 m .54393 .6307 L .54386 .63065 L .744 .572 .661 r
F
.52305 .63521 m .52391 .61686 L .54617 .63224 L .218 .048 .425 r
F
.48824 .57558 m .48544 .57343 L p .48833 .57561 L .712 .562 .682 r
F P
0 g
s
.48881 .57575 m .48951 .57884 L .48824 .57558 L .73 .396 .414 r
F
.48981 .57605 m .48951 .57884 L .48881 .57575 L F
.4854 .56061 m .48381 .56928 L .45568 .55668 L F
.48544 .57343 m .48885 .57263 L p .48472 .5643 L .602 .275 .388 r
F P
0 g
s
.48544 .57343 m .48472 .5643 L .48381 .56925 L .602 .275 .388 r
F
.48824 .57558 m .48544 .57343 L p .48818 .57558 L .772 .532 .573 r
F P
0 g
s
.51117 .63107 m .52549 .60148 L .52113 .61494 L p .985 .886 .642 r
F P
0 g
s
.52113 .61494 m .51828 .62088 L .51117 .63107 L .985 .886 .642 r
F
.5236 .61665 m .52391 .61686 L .52305 .63521 L .218 .048 .425 r
F
.52505 .59027 m .52549 .60148 L p .52504 .59027 L .752 .501 .553 r
F P
0 g
s
.52534 .59748 m .52535 .59751 L .52509 .59008 L .161 .053 .474 r
F
.52534 .59748 m .52509 .59008 L .52508 .59014 L F
.48994 .57609 m .48951 .57884 L p .48981 .57605 L .73 .396 .414 r
F P
0 g
s
.48544 .57343 m .48611 .57565 L p .48818 .57558 L .772 .532 .573 r
F P
0 g
s
.52509 .59008 m .52535 .59751 L .52744 .57726 L .161 .053 .474 r
F
.52549 .60148 m .52576 .59823 L p .52535 .59751 L F P
0 g
s
.52576 .59823 m .52744 .57726 L p .52535 .59751 L .161 .053 .474 r
F P
0 g
s
.52534 .59748 m .52549 .60148 L p .52535 .59751 L .161 .053 .474 r
F P
0 g
s
.48885 .57263 m .49253 .57177 L p .49288 .56936 L .602 .275 .388 r
F P
0 g
s
.49253 .57177 m .49617 .57092 L p .49288 .56936 L .602 .275 .388 r
F P
0 g
s
.48381 .56928 m .48544 .57343 L p .45568 .55668 L .729 .339 .311 r
F P
0 g
s
.48994 .57609 m .48951 .57884 L .4913 .57382 L p .108 0 .251 r
F P
0 g
s
.48544 .57343 m .48885 .57263 L p .49098 .57435 L .712 .562 .682 r
F P
0 g
s
.48885 .57263 m .49617 .57092 L p .50785 .58189 L .712 .562 .682 r
F P
0 g
s
.52549 .60148 m .51281 .5935 L p .5137 .58474 L .752 .501 .553 r
F P
0 g
s
.5187 .58718 m .52549 .60148 L .5137 .58474 L .752 .501 .553 r
F
.56801 .58237 m .54609 .64154 L .48466 .58864 L p .531 .517 .786 r
F P
0 g
s
.48466 .58864 m .43595 .5467 L .47412 .55701 L p .531 .517 .786 r
F P
0 g
s
.47412 .55701 m .56801 .58237 L p .48466 .58864 L .531 .517 .786 r
F P
0 g
s
.51065 .63679 m .51726 .62302 L .52305 .63521 L .218 .048 .425 r
F
.51952 .65299 m .51509 .64817 L .51929 .63792 L .566 .456 .688 r
F
.49025 .6909 m .49285 .70254 L p .4935 .70095 L .425 .303 .61 r
F P
0 g
s
.50359 .73222 m .49025 .6909 L .51 .72853 L .597 .402 .587 r
F
.50163 .67874 m .50052 .69387 L p .50652 .67541 L .866 .712 .688 r
F P
0 g
s
.50256 .66624 m .50052 .69387 L p .49127 .68392 L .965 .803 .632 r
F P
0 g
s
.50163 .67874 m .50652 .67541 L .50561 .6568 L .866 .712 .688 r
F
.50256 .66624 m .50163 .67874 L p .50561 .6568 L F P
0 g
s
.51386 .65286 m .50933 .64531 L p .50652 .67541 L .866 .712 .688 r
F P
0 g
s
.50652 .67541 m .50933 .64531 L .50561 .6568 L .866 .712 .688 r
F
.49025 .6909 m .52039 .71011 L .50538 .6719 L p .52 .432 .696 r
F P
0 g
s
.50922 .66252 m .49025 .6909 L p .50538 .6719 L .425 .303 .61 r
F P
0 g
s
.48815 .67098 m .48992 .66698 L .49004 .66637 L .745 .509 .573 r
F
.48744 .67272 m .48992 .66698 L .48815 .67098 L F
.48815 .67098 m .48295 .64947 L p .48744 .67258 L .96 .802 .642 r
F P
0 g
s
.48926 .65061 m .48295 .64947 L .50101 .63957 L .866 .996 .785 r
F
.48295 .64947 m .50101 .63957 L p .49332 .65834 L .965 .803 .632 r
F P
0 g
s
.50807 .64217 m .50153 .6656 L .49214 .67538 L .985 .886 .642 r
F
.48295 .64947 m .50101 .63957 L p .48514 .61603 L .89 .581 .455 r
F P
0 g
s
.50153 .6656 m .5004 .66961 L .49127 .68392 L .985 .886 .642 r
F
.50922 .66252 m .49025 .6909 L .4818 .61187 L p .536 .443 .697 r
F P
0 g
s
.52039 .71011 m .49889 .65538 L p .50497 .65468 L .566 .456 .688 r
F P
0 g
s
.51997 .68238 m .50497 .65468 L .51952 .65299 L .566 .456 .688 r
F
.52039 .71011 m .50497 .65468 L .51997 .68238 L F
.51509 .64817 m .4818 .61187 L .51929 .63792 L F
.49794 .63014 m .48514 .61603 L p .50101 .63957 L .89 .581 .455 r
F P
0 g
s
.49889 .65538 m .4818 .61187 L p .51952 .65299 L .566 .456 .688 r
F P
0 g
s
.4818 .61187 m .51783 .64964 L .50922 .66252 L p .536 .443 .697 r
F P
0 g
s
.50538 .6719 m .4818 .61187 L .49025 .6909 L p .52 .432 .696 r
F P
0 g
s
.49025 .6909 m .4935 .70095 L .50538 .6719 L .425 .303 .61 r
F
.51783 .64964 m .50922 .66252 L p .50294 .73022 L F P
0 g
s
.50179 .74263 m .50359 .73222 L p .50294 .73022 L .425 .303 .61 r
F P
0 g
s
.50359 .73222 m .51783 .64964 L p .50294 .73022 L .425 .303 .61 r
F P
0 g
s
.49285 .70254 m .50179 .74263 L p .50922 .66252 L .425 .303 .61 r
F P
0 g
s
.54281 .65029 m .54597 .66491 L .54579 .65315 L .574 .555 .795 r
F
.54609 .64154 m .54765 .65901 L p .54443 .64885 L .819 .694 .727 r
F P
0 g
s
.54481 .65006 m .54579 .65315 L .54575 .64995 L .574 .555 .795 r
F
.54281 .65029 m .54579 .65315 L .54481 .65006 L F
.53384 .65833 m .54597 .66491 L p .54281 .65029 L F P
0 g
s
.54424 .64901 m .54609 .64154 L .54402 .64921 L .41 .291 .606 r
F
.52321 .65256 m .53384 .65833 L p .54281 .65029 L .574 .555 .795 r
F P
0 g
s
.51915 .62911 m .54609 .64154 L .54281 .65029 L p .566 .456 .688 r
F P
0 g
s
.53384 .65833 m .54597 .66491 L p .53155 .70075 L .657 .519 .684 r
F P
0 g
s
.53384 .65833 m .53155 .70075 L .52914 .68677 L .657 .519 .684 r
F
.52914 .68677 m .52039 .71011 L p .51915 .62911 L .566 .456 .688 r
F P
0 g
s
.52039 .71011 m .51484 .75471 L p .52248 .72705 L .41 .291 .606 r
F P
0 g
s
.52248 .72705 m .5261 .70512 L .52039 .71011 L .41 .291 .606 r
F
.52321 .65256 m .51915 .62911 L .54281 .65029 L .566 .456 .688 r
F
.45976 .58002 m .45397 .57617 L .45395 .57653 L .695 .233 .151 r
F
.45976 .58002 m .45417 .57283 L .45397 .57617 L F
.45864 .56793 m .45474 .56339 L .45456 .56629 L F
.54609 .64154 m .43595 .5467 L .4818 .61187 L closepath p .459 .506 .82 r
F P
0 g
s
.52321 .65256 m .53876 .65076 L .54463 .57473 L .574 .555 .795 r
F
.53876 .65076 m .54304 .64075 L .54463 .57473 L F
.54609 .64154 m .54281 .65029 L p .54395 .64927 L .41 .291 .606 r
F P
0 g
s
.54443 .64884 m .54575 .64995 L .54571 .64769 L .574 .555 .795 r
F
.54281 .65029 m .54481 .65006 L .54443 .64884 L F
.54481 .65006 m .54575 .64995 L .54443 .64884 L F
.54597 .66491 m .5483 .67071 L .53155 .70075 L .657 .519 .684 r
F
.53277 .75753 m .54382 .68823 L .53831 .76483 L .819 .694 .727 r
F
.52893 .75246 m .51979 .76773 L .54265 .77056 L .783 .69 .761 r
F
.5268 .76167 m .51979 .76773 L .54265 .77056 L p .771 .721 .806 r
F P
0 g
s
.52461 .77115 m .54382 .68823 L .53063 .77095 L .819 .694 .727 r
F
.51979 .76773 m .53376 .73156 L p .52893 .75246 L .683 .556 .704 r
F P
0 g
s
.52891 .75244 m .51979 .76773 L .52893 .75246 L .783 .69 .761 r
F
.53376 .73156 m .54382 .68823 L .52461 .77115 L .819 .694 .727 r
F
.5268 .76167 m .51979 .76773 L p .52893 .75246 L .683 .556 .704 r
F P
0 g
s
.52456 .77116 m .53376 .73156 L .52461 .77115 L .819 .694 .727 r
F
.55715 .67097 m .5752 .67442 L p .55845 .70312 L .683 .556 .704 r
F P
0 g
s
.5752 .67442 m .57558 .67449 L p .57474 .67591 L .683 .556 .704 r
F P
0 g
s
.5752 .67442 m .57474 .67591 L .55845 .70312 L .683 .556 .704 r
F
.54752 .70892 m .55249 .70756 L p .55578 .67204 L .844 .742 .751 r
F P
0 g
s
.55286 .67431 m .54752 .70892 L p .55578 .67204 L .844 .742 .751 r
F P
0 g
s
.55715 .67097 m .55845 .70312 L .55284 .68342 L .683 .556 .704 r
F
.55906 .77745 m .5593 .77692 L .5591 .7749 L .411 .386 .721 r
F
.55906 .7749 m .5591 .7749 L .55906 .77457 L F
.55906 .77745 m .5591 .7749 L .55906 .7749 L F
.55839 .77938 m .55906 .77457 L .55879 .77183 L F
.5488 .67195 m .55701 .76396 L p .55796 .76354 L F P
0 g
s
.57558 .67449 m .61815 .68262 L .59776 .70026 L p .683 .556 .704 r
F P
0 g
s
.5627 .77303 m .61815 .68262 L .56557 .72812 L p .771 .721 .806 r
F P
0 g
s
.5953 .71988 m .61815 .68262 L p .61401 .73383 L .656 .566 .741 r
F P
0 g
s
.5861 .65392 m .61378 .71827 L .60368 .66134 L .719 .694 .825 r
F
.61815 .68262 m .61888 .73011 L .61472 .72514 L .656 .566 .741 r
F
.61378 .71827 m .61888 .73011 L .61708 .72197 L .719 .694 .825 r
F
.61378 .71827 m .61708 .72197 L .60368 .66134 L F
.59776 .70026 m .56557 .72812 L p .57545 .67519 L .683 .556 .704 r
F P
0 g
s
.57558 .67449 m .59776 .70026 L .57545 .67519 L .683 .556 .704 r
F
.5627 .77303 m .6493 .80083 L .5713 .82092 L p .777 .619 .684 r
F P
0 g
s
.55941 .778 m .55935 .77346 L .55906 .77457 L .411 .386 .721 r
F
.55756 .77006 m .55839 .77938 L p .55879 .77183 L F P
0 g
s
.55903 .78654 m .55941 .778 L p .5593 .77692 L .411 .386 .721 r
F P
0 g
s
.55903 .78654 m .5593 .77692 L .55906 .77745 L .411 .386 .721 r
F
.55839 .77938 m .55903 .78654 L p .55906 .77457 L F P
0 g
s
.55879 .77183 m .55845 .70312 L .5488 .67195 L .411 .386 .721 r
F
.55906 .77457 m .55904 .77219 L .55879 .77183 L F
.5589 .77199 m .55845 .70312 L .55879 .77183 L F
.55904 .77219 m .55904 .77139 L .5589 .77199 L F
.55904 .77139 m .55845 .70312 L .5589 .77199 L F
.55934 .77262 m .55845 .70312 L .55904 .77183 L F
.55934 .77262 m .55904 .77183 L .55906 .77457 L F
.5627 .77303 m .56021 .77492 L p .55959 .77329 L .796 .591 .624 r
F P
0 g
s
.55931 .77019 m .55934 .77262 L .5627 .77303 L .783 .69 .761 r
F
.55934 .77262 m .5602 .77272 L p .55942 .772 L .771 .721 .806 r
F P
0 g
s
.5602 .77272 m .56013 .77222 L .55942 .772 L .771 .721 .806 r
F
.57558 .67449 m .56557 .72812 L .55882 .70444 L .683 .556 .704 r
F
.56078 .76229 m .5627 .77303 L .56557 .72812 L .771 .721 .806 r
F
.56008 .7626 m .5627 .77303 L .56078 .76229 L .783 .69 .761 r
F
.55921 .76299 m .56092 .76791 L .56008 .7626 L F
.56092 .76791 m .5627 .77303 L .56008 .7626 L F
.55927 .76741 m .55931 .77019 L .56044 .77114 L F
.56092 .76791 m .56044 .77114 L .5627 .77303 L F
.5488 .67195 m .55671 .76059 L p .54382 .68823 L .819 .694 .727 r
F P
0 g
s
.54578 .7243 m .56044 .77114 L .56092 .76791 L .783 .69 .761 r
F
.55942 .772 m .5627 .77303 L .56078 .76229 L .771 .721 .806 r
F
.56078 .76229 m .5627 .77303 L .56117 .76212 L .783 .69 .761 r
F
.55845 .70312 m .55263 .68268 L .5488 .67195 L .411 .386 .721 r
F
.55263 .68268 m .55715 .67097 L .5514 .67841 L p .682 .555 .703 r
F P
0 g
s
.55263 .68268 m .55145 .67853 L .5514 .67841 L .411 .386 .721 r
F
.55263 .68268 m .5514 .67841 L .5488 .67195 L F
.53831 .76483 m .54382 .68823 L .5401 .76719 L .819 .694 .727 r
F
.53941 .71692 m .55263 .68268 L p .54382 .68823 L .682 .555 .703 r
F P
0 g
s
.5514 .67841 m .54382 .68823 L p .55263 .68268 L .682 .555 .703 r
F P
0 g
s
.54582 .72434 m .55921 .76299 L .55869 .7538 L .783 .69 .761 r
F
.54578 .7243 m .55921 .76299 L .54582 .72434 L F
.55889 .77222 m .55887 .77256 L .55934 .77262 L F
.53047 .74799 m .53191 .74748 L .52893 .75246 L .683 .556 .704 r
F
.55284 .68342 m .53191 .74748 L .53047 .74799 L F
.53376 .73156 m .55715 .67097 L p .52893 .75246 L F P
0 g
s
.51979 .76773 m .53941 .71692 L p .52483 .71281 L .682 .555 .703 r
F P
0 g
s
.52273 .7443 m .51979 .76773 L .52891 .75244 L .783 .69 .761 r
F
.518 .75824 m .51979 .76773 L .52273 .7443 L F
.51979 .76773 m .51921 .77016 L .51835 .77136 L .082 0 .156 r
F
.51718 .7687 m .51921 .77016 L .51979 .76773 L .819 .466 .389 r
F
.51538 .77664 m .51718 .7687 L p .51541 .77663 L .819 .694 .727 r
F P
0 g
s
.54382 .68823 m .53 .70612 L p .53763 .71488 L .682 .555 .703 r
F P
0 g
s
.53 .70612 m .52483 .71281 L p .53941 .71692 L .682 .555 .703 r
F P
0 g
s
.52914 .68677 m .53155 .70075 L .52483 .71281 L .657 .519 .684 r
F
.52273 .7443 m .54609 .64154 L p .51709 .7586 L .41 .291 .606 r
F P
0 g
s
.51627 .75893 m .51979 .76773 L .518 .75824 L .506 .498 .782 r
F
.518 .75824 m .51709 .7586 L .51497 .76713 L .41 .291 .606 r
F
.52273 .7443 m .51709 .7586 L .518 .75824 L F
.49025 .6909 m .49991 .74408 L .50179 .74263 L .142 0 0 r
F
.49872 .73749 m .49025 .6909 L .50179 .74263 L .895 .6 .481 r
F
.49831 .73526 m .49025 .6909 L .49832 .73525 L .597 .402 .587 r
F
.50141 .73874 m .5002 .73828 L .50359 .73222 L F
.49872 .73749 m .50179 .74263 L .5002 .73828 L .895 .6 .481 r
F
.5002 .73828 m .4959 .73664 L .4965 .7363 L .597 .402 .587 r
F
.5002 .73828 m .4965 .7363 L .50359 .73222 L F
.4956 .73682 m .49025 .6909 L .49831 .73526 L F
.459 .76318 m .48527 .77239 L .48612 .75856 L p .514 .332 .572 r
F P
0 g
s
.46922 .77443 m .46683 .77829 L .46925 .77436 L .91 .982 .731 r
F
.46918 .77451 m .46683 .77829 L p .46922 .77443 L F P
0 g
s
.459 .76318 m .48527 .77239 L .4694 .78615 L p .548 .227 .376 r
F P
0 g
s
.46349 .7731 m .49569 .75217 L .50179 .74263 L .465 .19 .411 r
F
.45913 .77657 m .46368 .77353 L .46349 .7731 L F
.46368 .77353 m .49569 .75217 L .46349 .7731 L F
.47767 .77397 m .48527 .77239 L .48612 .75856 L .788 .566 .601 r
F
.48527 .77239 m .48251 .76644 L .48612 .75856 L .63 .528 .72 r
F
.48463 .7618 m .49081 .7598 L .49181 .75759 L .465 .19 .411 r
F
.4842 .76205 m .48457 .76193 L .48463 .7618 L F
.48457 .76193 m .49081 .7598 L .48463 .7618 L F
.45809 .77739 m .48319 .7639 L .4842 .76205 L F
.48319 .7639 m .49081 .7598 L .4842 .76205 L F
.45809 .77739 m .49181 .75759 L .48619 .75854 L F
.45809 .77739 m .48157 .76686 L .48319 .7639 L F
.45809 .77739 m .49569 .75217 L .45913 .77657 L F
.459 .76318 m .4581 .77725 L p .48861 .75312 L F P
0 g
s
.4581 .77725 m .45809 .77739 L p .45913 .77657 L .465 .19 .411 r
F P
0 g
s
.4581 .77725 m .45913 .77657 L .48861 .75312 L .465 .19 .411 r
F
.48619 .75854 m .49181 .75759 L .49363 .75355 L F
.48319 .7639 m .4882 .76389 L .49081 .7598 L F
.48157 .76686 m .4882 .76389 L .48319 .7639 L F
.49105 .74779 m .459 .76318 L p .48861 .75312 L F P
0 g
s
.48829 .76385 m .49068 .76008 L p .4882 .76389 L .465 .19 .411 r
F P
0 g
s
.49068 .76008 m .50179 .74263 L p .49081 .7598 L .465 .19 .411 r
F P
0 g
s
.4882 .76389 m .49068 .76008 L .49081 .7598 L .465 .19 .411 r
F
.48612 .75856 m .48828 .72327 L p .49727 .75112 L .597 .402 .587 r
F P
0 g
s
.48828 .72327 m .49025 .6909 L p .49554 .73626 L .597 .402 .587 r
F P
0 g
s
.48828 .72327 m .49554 .73626 L .49727 .75112 L .597 .402 .587 r
F
.48802 .76341 m .49491 .75026 L .49268 .74816 L .63 .528 .72 r
F
.48527 .77239 m .4887 .76452 L .48802 .76341 L F
.47622 .82929 m .48549 .79306 L .48527 .77239 L .532 .326 .546 r
F
.49536 .75449 m .49174 .76091 L p .48549 .79306 L F P
0 g
s
.49174 .76091 m .48527 .77239 L p .48549 .79306 L .532 .326 .546 r
F P
0 g
s
.45569 .81507 m .46055 .82739 L p .46391 .81991 L .765 .548 .603 r
F P
0 g
s
.51538 .77664 m .5146 .75826 L .51423 .75964 L .41 .291 .606 r
F
.50816 .80841 m .47288 .83829 L .4809 .81664 L p .894 .733 .676 r
F P
0 g
s
.51391 .7622 m .50816 .80841 L p .48355 .81584 L .894 .733 .676 r
F P
0 g
s
.4809 .81664 m .50307 .78007 L .48355 .81584 L .894 .733 .676 r
F
.50307 .78007 m .51391 .7622 L .48355 .81584 L F
.50307 .78007 m .49771 .78404 L p .51318 .76156 L .778 .572 .62 r
F P
0 g
s
.48512 .79498 m .4809 .81664 L .50034 .78459 L .765 .548 .603 r
F
.51494 .77131 m .48549 .79306 L p .51528 .77438 L F P
0 g
s
.48512 .79498 m .51528 .77438 L .48549 .79306 L .765 .548 .603 r
F
.50179 .74263 m .51412 .75983 L p .49771 .78404 L .778 .572 .62 r
F P
0 g
s
.51412 .75983 m .51318 .76156 L .49771 .78404 L .778 .572 .62 r
F
.49536 .75449 m .48527 .77239 L p .49574 .75213 L .597 .402 .587 r
F P
0 g
s
.49574 .75213 m .49271 .77097 L .4887 .76452 L .778 .572 .62 r
F
.48527 .77239 m .48782 .76406 L .48647 .76466 L .63 .528 .72 r
F
.48527 .77239 m .48384 .76584 L .48251 .76644 L F
.48612 .75856 m .48777 .73161 L p .459 .76318 L .514 .332 .572 r
F P
0 g
s
.48777 .73161 m .49025 .6909 L .47391 .72869 L p .514 .332 .572 r
F P
0 g
s
.47391 .72869 m .459 .76318 L p .48777 .73161 L .514 .332 .572 r
F P
0 g
s
.45809 .77739 m .45782 .78169 L p .46061 .78061 L .465 .19 .411 r
F P
0 g
s
.48527 .77239 m .4694 .78615 L p .46731 .79681 L .627 .337 .458 r
F P
0 g
s
.45569 .81507 m .46731 .79681 L p .46815 .79607 L .778 .572 .62 r
F P
0 g
s
.4787 .78687 m .48527 .77239 L p .46731 .79681 L .627 .337 .458 r
F P
0 g
s
.4805 .77287 m .48527 .77239 L .47767 .77397 L .883 .644 .572 r
F
.47121 .8036 m .45569 .81507 L p .46815 .79607 L .778 .572 .62 r
F P
0 g
s
.47238 .77098 m .47154 .77525 L .47854 .76822 L .465 .19 .411 r
F
.47154 .77525 m .46851 .7907 L .47854 .76822 L F
.47854 .76822 m .46851 .7907 L .48157 .76686 L F
.45809 .77739 m .46851 .7907 L .47238 .77098 L F
.46061 .78061 m .45575 .81398 L .46851 .7907 L F
.45782 .78169 m .45575 .81398 L p .46061 .78061 L F P
0 g
s
.42297 .78968 m .3959 .80959 L p .42172 .7912 L .459 .838 .606 r
F P
0 g
s
.459 .76318 m .42297 .78968 L p .42172 .7912 L .459 .838 .606 r
F P
0 g
s
.43119 .78446 m .459 .76318 L p .42172 .7912 L .459 .838 .606 r
F P
0 g
s
.3959 .80959 m .459 .76318 L .45571 .81469 L p .546 .256 .425 r
F P
0 g
s
.45571 .81469 m .45569 .81507 L .3959 .80959 L p .546 .256 .425 r
F P
0 g
s
.3959 .80959 m .39944 .82258 L p .43887 .81731 L .456 0 .038 r
F P
0 g
s
.44154 .81377 m .3959 .80959 L p .43887 .81731 L .456 0 .038 r
F P
0 g
s
.43879 .84635 m .40922 .84781 L p .42616 .83605 L .878 .593 .501 r
F P
0 g
s
.4373 .81939 m .44592 .85909 L p .43907 .8479 L .886 .511 .323 r
F P
0 g
s
.40694 .84829 m .4106 .84413 L .40347 .84702 L .606 .171 .188 r
F
.4106 .84413 m .40557 .84512 L .40059 .84819 L F
.3174 .81737 m .33956 .81792 L .3959 .80959 L closepath p .171 .708 .791 r
F P
0 g
s
.3959 .80959 m .40532 .84419 L p .39108 .84056 L .502 .011 .023 r
F P
0 g
s
.35797 .81335 m .3959 .80959 L p .39108 .84056 L .502 .011 .023 r
F P
0 g
s
.4187 .84734 m .43907 .8479 L .43899 .84749 L .834 .47 .366 r
F
.43879 .84635 m .43836 .84638 L p .43899 .84749 L F P
0 g
s
.43836 .84638 m .4187 .84734 L p .43899 .84749 L .834 .47 .366 r
F P
0 g
s
.42016 .84793 m .43907 .8479 L .4187 .84734 L .834 .47 .366 r
F
.44046 .85561 m .4398 .85195 L .44592 .85909 L .886 .511 .323 r
F
.42016 .84793 m .43917 .85556 L .43907 .8479 L .834 .47 .366 r
F
.43917 .85556 m .44046 .85561 L .43907 .8479 L F
.39944 .82258 m .40532 .84419 L p .42879 .83028 L .456 0 .038 r
F P
0 g
s
.42864 .83088 m .43457 .82301 L .43907 .8479 L .886 .511 .323 r
F
.43457 .82301 m .4373 .81939 L .43907 .8479 L F
.45569 .81507 m .46748 .84494 L .44507 .84605 L p .878 .593 .501 r
F P
0 g
s
.45569 .81507 m .44507 .84605 L .44897 .82751 L .878 .593 .501 r
F
.45061 .81968 m .45091 .81825 L .44728 .81855 L .627 .337 .458 r
F
.40861 .84849 m .41263 .85449 L .43804 .85552 L .834 .47 .366 r
F
.40922 .84781 m .41149 .84523 L .40716 .84885 L .606 .171 .188 r
F
.40732 .84912 m .40716 .84885 L .40449 .85109 L F
.40922 .84781 m .40716 .84885 L .40732 .84912 L F
.41149 .84523 m .41466 .83951 L .40449 .85109 L F
.42864 .83088 m .41877 .83697 L .41149 .84523 L F
.41877 .83697 m .41466 .83951 L .41149 .84523 L F
.43917 .85556 m .44592 .85909 L .44046 .85561 L .883 .644 .572 r
F
.55903 .78654 m .50816 .80841 L .51528 .77705 L p .819 .694 .727 r
F P
0 g
s
.55671 .76059 m .55903 .78654 L p .51528 .77705 L .819 .694 .727 r
F P
0 g
s
.52757 .83218 m .48692 .84265 L .49511 .83513 L p .777 .619 .684 r
F P
0 g
s
.53343 .80702 m .52757 .83218 L .49511 .83513 L .777 .619 .684 r
F
.54196 .79388 m .51596 .80506 L p .53422 .7992 L .648 .316 .396 r
F P
0 g
s
.48692 .84265 m .53422 .7992 L p .49428 .82665 L .885 .968 .839 r
F P
0 g
s
.47879 .83845 m .48692 .84265 L .49428 .82665 L .885 .968 .839 r
F
.47247 .84436 m .48692 .84265 L p .47783 .83796 L F P
0 g
s
.54831 .79469 m .52757 .83218 L .53534 .79884 L .777 .619 .684 r
F
.55173 .79359 m .54196 .79388 L .53422 .7992 L .648 .316 .396 r
F
.49511 .83513 m .53554 .79799 L p .53343 .80702 L .777 .619 .684 r
F P
0 g
s
.55173 .79359 m .55903 .78654 L .54196 .79388 L p .648 .316 .396 r
F P
0 g
s
.55669 .78995 m .55173 .79359 L .55903 .78654 L .156 0 0 r
F
.55669 .78995 m .55903 .78654 L .54939 .79273 L F
.54939 .79273 m .55803 .78719 L .55861 .77706 L .908 .809 .739 r
F
.55779 .77755 m .55861 .77706 L .55867 .77594 L F
.54939 .79273 m .55861 .77706 L .55779 .77755 L F
.5713 .82092 m .52757 .83218 L p .54915 .79442 L .777 .619 .684 r
F P
0 g
s
.55941 .778 m .55961 .77334 L p .55934 .77262 L .411 .386 .721 r
F P
0 g
s
.55803 .78719 m .55941 .778 L .55947 .77654 L .908 .809 .739 r
F
.55923 .77668 m .55947 .77654 L .55961 .77334 L F
.55803 .78719 m .55947 .77654 L .55923 .77668 L F
.56347 .78983 m .5713 .82092 L .54915 .79442 L .777 .619 .684 r
F
.55921 .7767 m .55961 .77334 L .55959 .77336 L .908 .809 .739 r
F
.55803 .78719 m .55923 .77668 L .55921 .7767 L F
.55923 .77668 m .55961 .77334 L .55921 .7767 L F
.55935 .77346 m .55934 .77286 L .55928 .77321 L .411 .386 .721 r
F
.55935 .77346 m .55928 .77321 L .55906 .77457 L F
.55934 .77286 m .55931 .77279 L .55906 .77457 L F
.51528 .77705 m .51603 .77459 L .52399 .77359 L .819 .694 .727 r
F
.5602 .77272 m .55966 .77328 L .51347 .77706 L .796 .591 .624 r
F
.50816 .80841 m .49428 .82665 L p .50585 .81871 L .648 .316 .396 r
F P
0 g
s
.50585 .81871 m .53323 .79988 L .51399 .80643 L .648 .316 .396 r
F
.50585 .81871 m .51399 .80643 L .50816 .80841 L F
.50049 .82193 m .50816 .80841 L .49428 .82665 L p .506 .148 .294 r
F P
0 g
s
.54915 .79442 m .52757 .83218 L .54831 .79469 L .777 .619 .684 r
F
.51596 .80506 m .50816 .80841 L p .55173 .79359 L .648 .316 .396 r
F P
0 g
s
.50816 .80841 m .47288 .83829 L .47153 .84204 L p .602 .252 .349 r
F P
0 g
s
.47259 .84131 m .50816 .80841 L .47153 .84204 L .602 .252 .349 r
F
.49428 .82665 m .49262 .82885 L p .53323 .79988 L .648 .316 .396 r
F P
0 g
s
.46366 .87912 m .44151 .88871 L .46297 .87988 L .453 .096 .269 r
F
.44151 .88871 m .44098 .88921 L .46297 .87988 L F
.46182 .86167 m .4094 .90261 L .46366 .87912 L F
.63927 .96839 m .53292 .92285 L p .54559 .87329 L .816 .672 .704 r
F P
0 g
s
.54877 .86085 m .55558 .86894 L p .54559 .87329 L .816 .672 .704 r
F P
0 g
s
.55558 .86894 m .63927 .96839 L p .54559 .87329 L .816 .672 .704 r
F P
0 g
s
.4094 .90261 m .45498 .88948 L .46341 .918 L p .98 .844 .635 r
F P
0 g
s
.42935 .94926 m .38813 .94185 L .35287 1.00087 L .784 .964 .921 r
F
.47202 .92046 m .45639 .92445 L .42935 .94926 L F
.45639 .92445 m .38813 .94185 L .42935 .94926 L F
.48192 .90101 m .45498 .88948 L .46341 .918 L p .718 .741 .869 r
F P
0 g
s
.4094 .90261 m .45498 .88948 L .45386 .89913 L p .638 .113 0 r
F P
0 g
s
.4785 .91609 m .45101 .91447 L .47202 .92046 L .784 .964 .921 r
F
.46794 .90882 m .45101 .91447 L .4785 .91609 L F
.49337 .89603 m .45101 .91447 L .51018 .89471 L F
.45101 .91447 m .38813 .94185 L .47202 .92046 L F
.44478 .89287 m .45498 .88948 L .45386 .89913 L p .878 .47 .03 r
F P
0 g
s
.45498 .88948 m .53285 .86571 L p .53264 .87893 L .816 .672 .704 r
F P
0 g
s
.51018 .89471 m .46794 .90882 L .4785 .91609 L .784 .964 .921 r
F
.53524 .8778 m .49337 .89603 L .51018 .89471 L F
.46961 .93899 m .35287 1.00087 L .46576 .9685 L F
.47202 .92046 m .42935 .94926 L .46961 .93899 L F
.42935 .94926 m .35287 1.00087 L .46961 .93899 L F
.53524 .8778 m .47202 .92046 L .49607 .93225 L F
.48965 1.00684 m .63927 .96839 L .53292 .92285 L p .718 .741 .869 r
F P
0 g
s
.48442 .93522 m .48965 1.00684 L .53292 .92285 L .718 .741 .869 r
F
.53292 .92285 m .49607 .93225 L .53154 .94964 L .784 .964 .921 r
F
.53524 .8778 m .49607 .93225 L .53292 .92285 L F
.46961 .93899 m .48965 1.00684 L p .48442 .93522 L .718 .741 .869 r
F P
0 g
s
.46961 .93899 m .48965 1.00684 L .46499 .97482 L p .98 .844 .635 r
F P
0 g
s
.35287 1.00087 m .48965 1.00684 L .49621 1.02224 L p .793 .587 .622 r
F P
0 g
s
.49621 1.02224 m .57184 1.19984 L .47891 1.1154 L p .793 .587 .622 r
F P
0 g
s
.47891 1.1154 m .35287 1.00087 L p .49621 1.02224 L .793 .587 .622 r
F P
0 g
s
.48965 1.00684 m .57184 1.19984 L .73395 1.11094 L closepath p .639 .517 .698 \
r
F P
0 g
s
.63927 .96839 m .73395 1.11094 L .55152 1.0332 L p .669 .479 .618 r
F P
0 g
s
.55152 1.0332 m .48965 1.00684 L .5834 .98275 L p .669 .479 .618 r
F P
0 g
s
.5834 .98275 m .63927 .96839 L p .55152 1.0332 L .669 .479 .618 r
F P
0 g
s
.73395 1.11094 m .8319 .98451 L .71641 .97485 L p .497 .423 .703 r
F P
0 g
s
.71641 .97485 m .63927 .96839 L .72786 1.10175 L p .497 .423 .703 r
F P
0 g
s
.72786 1.10175 m .73395 1.11094 L p .71641 .97485 L .497 .423 .703 r
F P
0 g
s
.75624 .8852 m .8319 .98451 L .63927 .96839 L closepath p .504 .355 .612 r
F P
0 g
s
.63927 .96839 m .75624 .8852 L .5623 .86244 L p .659 .649 .828 r
F P
0 g
s
.5623 .86244 m .54877 .86085 L .55558 .86894 L p .659 .649 .828 r
F P
0 g
s
.55558 .86894 m .63927 .96839 L p .5623 .86244 L .659 .649 .828 r
F P
0 g
s
.48192 .90101 m .45498 .88948 L p .53264 .87893 L .816 .672 .704 r
F P
0 g
s
.54877 .86085 m .53292 .92285 L .53316 .91804 L .816 .672 .704 r
F
.53285 .86571 m .54877 .86085 L p .53196 .92244 L F P
0 g
s
.6493 .80083 m .75624 .8852 L .54877 .86085 L closepath p .687 .571 .719 r
F P
0 g
s
.57217 .85288 m .38639 .94261 L .53524 .8778 L .784 .964 .921 r
F
.48692 .84265 m .54877 .86085 L .60132 .82948 L p .776 .863 .914 r
F P
0 g
s
.60132 .82948 m .6493 .80083 L .57224 .82068 L p .776 .863 .914 r
F P
0 g
s
.57224 .82068 m .48692 .84265 L p .60132 .82948 L .776 .863 .914 r
F P
0 g
s
.45498 .88948 m .54877 .86085 L .50203 .87531 L p 0 0 0 r
F P
0 g
s
.44478 .89287 m .45498 .88948 L p .50203 .87531 L 0 0 0 r
F P
0 g
s
.48692 .84265 m .54877 .86085 L .50203 .87531 L p .911 .673 .566 r
F P
0 g
s
.3886 .94141 m .43199 .89641 L .38639 .94261 L .784 .964 .921 r
F
.51354 .87404 m .43955 .89434 L .3886 .94141 L F
.43955 .89434 m .43199 .89641 L .3886 .94141 L F
.48692 .84265 m .50203 .87531 L .46849 .87904 L .911 .673 .566 r
F
.46371 .87957 m .4486 .88598 L .51354 .87404 L .784 .964 .921 r
F
.4486 .88598 m .44631 .8881 L .51354 .87404 L F
.44098 .88921 m .43199 .89641 L .43955 .89434 L F
.44631 .8881 m .43955 .89434 L .51354 .87404 L F
.44098 .88921 m .43955 .89434 L .44631 .8881 L F
.46258 .86882 m .48692 .84265 L p .47447 .86722 L .911 .673 .566 r
F P
0 g
s
.50203 .87531 m .44956 .89155 L p .44478 .89287 L 0 0 0 r
F P
0 g
s
.51354 .87404 m .38639 .94261 L .53278 .8719 L .784 .964 .921 r
F
.43199 .89641 m .4094 .90261 L .39671 .92467 L F
.43199 .89641 m .39671 .92467 L .38639 .94261 L F
.46341 .918 m .46961 .93899 L p .4094 .90261 L .98 .844 .635 r
F P
0 g
s
.35287 1.00087 m .48965 1.00684 L .46499 .97482 L p .689 .833 .953 r
F P
0 g
s
.46576 .9685 m .35287 1.00087 L .46499 .97482 L .698 .574 .713 r
F
.38813 .94185 m .38639 .94261 L .38534 .94442 L .784 .964 .921 r
F
.38813 .94185 m .38534 .94442 L .35287 1.00087 L F
.46499 .97482 m .4094 .90261 L .35287 1.00087 L p .689 .833 .953 r
F P
0 g
s
.46499 .97482 m .35287 1.00087 L .45479 1.05904 L .698 .574 .713 r
F
.46494 .97475 m .4094 .90261 L p .46935 .93884 L .98 .844 .635 r
F P
0 g
s
.46961 .93899 m .46576 .9685 L .46935 .93884 L .98 .844 .635 r
F
.46576 .9685 m .46494 .97475 L .46935 .93884 L F
.43912 .90028 m .44505 .9324 L p .44457 .93201 L .638 .113 0 r
F P
0 g
s
.44457 .93201 m .4094 .90261 L .42433 .90144 L .638 .113 0 r
F
.44457 .93201 m .42433 .90144 L .43912 .90028 L F
.71212 .92723 m .53154 .94964 L .52917 1.1015 L .698 .574 .713 r
F
.35287 1.00087 m .38148 1.24217 L .57184 1.19984 L closepath p .734 .601 .708 \
r
F P
0 g
s
.75624 .8852 m .47125 1.15667 L .8319 .98451 L .698 .574 .713 r
F
.46961 .93899 m .46499 .97482 L .46576 .9685 L .98 .844 .635 r
F
.53154 .94964 m .46576 .9685 L .52917 1.1015 L .698 .574 .713 r
F
.47202 .92046 m .46676 .96081 L .53154 .94964 L .784 .964 .921 r
F
.46676 .96081 m .46576 .9685 L .47103 .96699 L F
.46676 .96081 m .47103 .96699 L .53154 .94964 L F
.45459 .9467 m .44468 .93217 L p .44923 .93904 L .602 .163 0 r
F P
0 g
s
.45459 .9467 m .44923 .93904 L .45131 .94218 L .602 .163 0 r
F
.44809 .94888 m .44522 .93331 L p .44644 .93506 L .878 .47 .03 r
F P
0 g
s
.44644 .93506 m .44735 .93636 L .44741 .93733 L .878 .47 .03 r
F
.44644 .93506 m .44741 .93733 L .44809 .94888 L F
.47447 .86722 m .46449 .88693 L .46258 .86882 L .911 .673 .566 r
F
.46258 .86882 m .48692 .84265 L .47624 .85593 L p 0 0 0 r
F P
0 g
s
.47934 .86187 m .46182 .86167 L .46366 .87912 L .453 .096 .269 r
F
.48692 .84265 m .47624 .85593 L p .47268 .84912 L .923 .598 .408 r
F P
0 g
s
.47033 .84461 m .47416 .84416 L p .47268 .84912 L .923 .598 .408 r
F P
0 g
s
.47416 .84416 m .48692 .84265 L p .47268 .84912 L .923 .598 .408 r
F P
0 g
s
.52273 .81411 m .47419 .85201 L .47934 .86187 L .453 .096 .269 r
F
.47419 .85201 m .46182 .86167 L .47934 .86187 L F
.55803 .78719 m .55939 .77513 L .5592 .7753 L .908 .809 .739 r
F
.50319 .81716 m .50816 .80841 L p .47486 .8392 L .602 .252 .349 r
F P
0 g
s
.53422 .7992 m .53734 .79633 L p .47805 .83771 L .885 .968 .839 r
F P
0 g
s
.47783 .83796 m .53422 .7992 L .47805 .83771 L .885 .968 .839 r
F
.50319 .81716 m .47486 .8392 L .47259 .84131 L .602 .252 .349 r
F
.50319 .81716 m .47259 .84131 L .47415 .84022 L F
.47064 .84288 m .47429 .84038 L .47408 .84048 L .885 .968 .839 r
F
.46772 .84492 m .47052 .84299 L .47064 .84288 L F
.47052 .84299 m .47783 .83796 L .47064 .84288 L F
.46772 .84492 m .47805 .83771 L .47195 .84175 L F
.47805 .83771 m .53734 .79633 L .47843 .83725 L F
.47805 .83771 m .47843 .83725 L .47195 .84175 L F
.47288 .83829 m .47153 .84204 L p .47237 .84125 L .322 0 .233 r
F P
0 g
s
.47238 .84124 m .47288 .83829 L p .47237 .84125 L .322 0 .233 r
F P
0 g
s
.47622 .82929 m .4809 .81664 L p .48549 .79306 L .532 .326 .546 r
F P
0 g
s
.48527 .77239 m .47288 .83829 L .47191 .83904 L p .948 .743 .592 r
F P
0 g
s
.47451 .81902 m .48527 .77239 L .47191 .83904 L .948 .743 .592 r
F
.47979 .78445 m .48527 .77239 L p .46946 .84093 L F P
0 g
s
.48772 .76671 m .48869 .76454 L .48527 .77239 L .908 .809 .739 r
F
.48829 .76385 m .49068 .76008 L p .4887 .76452 L .778 .572 .62 r
F P
0 g
s
.4887 .76452 m .49491 .75026 L .48802 .76341 L .63 .528 .72 r
F
.4966 .74662 m .49354 .74897 L .49582 .7483 L .819 .466 .389 r
F
.42616 .83605 m .42864 .83088 L p .41149 .84523 L .606 .171 .188 r
F P
0 g
s
.42616 .83605 m .41149 .84523 L .40922 .84781 L .606 .171 .188 r
F
.39944 .82258 m .4488 .81843 L .45384 .81531 L .456 0 .038 r
F
.43631 .81484 m .44409 .85069 L p .44507 .84605 L .627 .337 .458 r
F P
0 g
s
.45569 .81507 m .44154 .81377 L p .43887 .81731 L .456 0 .038 r
F P
0 g
s
.44507 .84605 m .45061 .81968 L .4379 .81538 L .627 .337 .458 r
F
.44507 .84605 m .4379 .81538 L .43631 .81484 L F
.40532 .84419 m .40711 .84417 L .42893 .8307 L .456 0 .038 r
F
.42879 .83028 m .42893 .8307 L .4488 .81843 L F
.40532 .84419 m .42893 .8307 L .42879 .83028 L F
.46748 .84494 m .47011 .84107 L p .46683 .84037 L .765 .548 .603 r
F P
0 g
s
.47239 .84124 m .46748 .84494 L p .47226 .84123 L .796 .591 .624 r
F P
0 g
s
.47068 .84111 m .47226 .84123 L .46881 .84391 L .796 .591 .624 r
F
.46772 .84492 m .47247 .84436 L p .47783 .83796 L .885 .968 .839 r
F P
0 g
s
.47211 .842 m .47218 .84178 L .4714 .84241 L .602 .252 .349 r
F
.49262 .82885 m .49099 .83099 L p .49809 .82617 L .648 .316 .396 r
F P
0 g
s
.47624 .85593 m .46737 .86694 L p .46258 .86882 L 0 0 0 r
F P
0 g
s
.46436 .86986 m .46258 .86882 L .46737 .86694 L 0 0 0 r
F
.43852 .8965 m .44478 .89287 L .44624 .91764 L .878 .47 .03 r
F
.43852 .8965 m .44624 .91764 L .44356 .91601 L F
.43815 .89508 m .44692 .929 L .4455 .92575 L F
.42216 .91786 m .4094 .90261 L p .44505 .9324 L .638 .113 0 r
F P
0 g
s
.48502 .95779 m .50145 .99297 L .45459 .9467 L .498 .362 .626 r
F
.44966 .93533 m .45459 .9467 L .44468 .93217 L F
.48502 .95779 m .45459 .9467 L .44966 .93533 L F
.44927 .93873 m .44519 .8998 L .45386 .89913 L .638 .113 0 r
F
.449 .94107 m .44874 .93833 L .44927 .93873 L F
.44874 .93833 m .44519 .8998 L .44927 .93873 L F
.44759 .9404 m .44741 .93732 L p .449 .94107 L F P
0 g
s
.44741 .93732 m .44519 .8998 L p .44874 .93833 L .638 .113 0 r
F P
0 g
s
.44741 .93732 m .44874 .93833 L .449 .94107 L .638 .113 0 r
F
.53188 1.05777 m .5644 1.10767 L .53471 1.06413 L .498 .362 .626 r
F
.48852 .96002 m .53431 1.04912 L .53188 1.05777 L F
.53431 1.04912 m .5644 1.10767 L .53188 1.05777 L F
.59149 1.08852 m .60546 1.06771 L p .54926 .99581 L .586 .451 .663 r
F P
0 g
s
.61999 1.04374 m .54926 .99581 L p .60546 1.06771 L .586 .451 .663 r
F P
0 g
s
.53994 1.02904 m .59149 1.08852 L p .54926 .99581 L .586 .451 .663 r
F P
0 g
s
.53994 1.02904 m .59149 1.08852 L .50917 1.00021 L p .05 .273 .766 r
F P
0 g
s
.5644 1.10767 m .59149 1.08852 L .50917 1.00021 L p .648 .425 .566 r
F P
0 g
s
.38148 1.24217 m .57184 1.19984 L .64158 1.23605 L p .44 0 .056 r
F P
0 g
s
.64158 1.23605 m .67709 1.25448 L .62829 1.25245 L p .44 0 .056 r
F P
0 g
s
.62829 1.25245 m .38148 1.24217 L p .64158 1.23605 L .44 0 .056 r
F P
0 g
s
.57184 1.19984 m .64158 1.23605 L p .66274 1.2079 L .324 .123 .445 r
F P
0 g
s
.72326 1.15891 m .57184 1.19984 L p .71164 1.21224 L .324 .123 .445 r
F P
0 g
s
.57184 1.19984 m .73395 1.11094 L .73608 1.11351 L p .125 0 0 r
F P
0 g
s
.73608 1.11351 m .75787 1.13992 L p .70026 1.15848 L .125 0 0 r
F P
0 g
s
.73608 1.11351 m .70026 1.15848 L .57184 1.19984 L .125 0 0 r
F
.72326 1.15891 m .69352 1.16695 L p .75787 1.13992 L F P
0 g
s
.69352 1.16695 m .57184 1.19984 L p .70026 1.15848 L .125 0 0 r
F P
0 g
s
.75787 1.13992 m .69352 1.16695 L .70026 1.15848 L .125 0 0 r
F
.38148 1.24217 m .56676 1.33276 L .67709 1.25448 L closepath p .547 .297 .488 \
r
F P
0 g
s
.73293 1.1145 m .44097 1.20814 L .50958 1.27612 L .534 .313 .526 r
F
.73293 1.1145 m .50958 1.27612 L .68181 1.18164 L F
.76304 1.07168 m .73395 1.11094 L .8319 .98451 L p .584 .833 .465 r
F P
0 g
s
.8319 .98451 m .76683 1.02173 L .76277 1.07531 L .534 .313 .526 r
F
.8319 .98451 m .80285 1.01794 L .76304 1.07168 L p .584 .833 .465 r
F P
0 g
s
.76304 1.07168 m .73395 1.11094 L .73608 1.11351 L p 0 0 .239 r
F P
0 g
s
.73608 1.11351 m .76277 1.07531 L .76304 1.07168 L 0 0 .239 r
F
.76277 1.07531 m .76212 1.07284 L .73293 1.1145 L .534 .313 .526 r
F
.76212 1.07284 m .75119 1.03068 L .73435 1.108 L F
.76212 1.07284 m .73435 1.108 L .73293 1.1145 L F
.73608 1.11351 m .75787 1.13992 L p .76277 1.07531 L 0 0 .239 r
F P
0 g
s
.76683 1.02173 m .75119 1.03068 L .76277 1.07531 L .534 .313 .526 r
F
.76787 1.06801 m .77106 1.06344 L .82243 .99541 L F
.80285 1.01794 m .76304 1.07168 L p .7631 1.07484 L 0 0 .239 r
F P
0 g
s
.77106 1.06344 m .77259 1.06126 L .82243 .99541 L .534 .313 .526 r
F
.82243 .99541 m .77259 1.06126 L .80285 1.01794 L F
.76277 1.07531 m .7631 1.07484 L .76304 1.07168 L 0 0 .239 r
F
.68181 1.18164 m .50958 1.27612 L .56306 1.3291 L .534 .313 .526 r
F
.57921 1.3164 m .56306 1.3291 L .56676 1.33276 L F
.68181 1.18164 m .56306 1.3291 L .57921 1.3164 L F
.75119 1.03068 m .44097 1.20814 L .73293 1.1145 L F
.77259 1.06126 m .6748 1.19045 L .76693 1.06633 L F
.79382 1.03087 m .76693 1.06633 L .80285 1.01794 L F
.77259 1.06126 m .76693 1.06633 L .79382 1.03087 L F
.47125 1.15667 m .46415 1.19488 L .8319 .98451 L .698 .574 .713 r
F
.63382 .97409 m .73489 1.10859 L p .62795 1.04943 L .828 .754 .782 r
F P
0 g
s
.8319 .98451 m .73293 1.1145 L .82243 .99541 L .534 .313 .526 r
F
.75787 1.13992 m .76436 1.1478 L p .7631 1.07484 L 0 0 .239 r
F P
0 g
s
.75787 1.13992 m .7631 1.07484 L .76277 1.07531 L 0 0 .239 r
F
.68181 1.18164 m .6748 1.19045 L .77259 1.06126 L .534 .313 .526 r
F
.68181 1.18164 m .77259 1.06126 L .77106 1.06344 L F
.73293 1.1145 m .68181 1.18164 L .77106 1.06344 L F
.73293 1.1145 m .77106 1.06344 L .76787 1.06801 L F
.6748 1.19045 m .66319 1.20502 L .72189 1.1264 L F
.75077 1.0881 m .72189 1.1264 L .80285 1.01794 L F
.6748 1.19045 m .72189 1.1264 L .75077 1.0881 L F
.59149 1.08852 m .60546 1.06771 L p .66355 1.20374 L .827 .789 .816 r
F P
0 g
s
.62237 1.0494 m .66355 1.20374 L p .60546 1.06771 L .827 .789 .816 r
F P
0 g
s
.65735 1.21196 m .59149 1.08852 L .66355 1.20374 L .827 .789 .816 r
F
.65132 1.20453 m .59149 1.08852 L .56676 1.33276 L p .797 .779 .836 r
F P
0 g
s
.56676 1.33276 m .5644 1.10767 L .59149 1.08852 L closepath p .827 .805 .83 r
F P
0 g
s
.65132 1.20453 m .56676 1.33276 L .57074 1.10528 L .801 .786 .838 r
F
.65735 1.21196 m .56676 1.33276 L .65132 1.20453 L F
.68181 1.18164 m .62185 1.2604 L .6748 1.19045 L .534 .313 .526 r
F
.6748 1.19045 m .62185 1.2604 L .66319 1.20502 L F
.64158 1.23605 m .67709 1.25448 L p .66274 1.2079 L .324 .123 .445 r
F P
0 g
s
.62185 1.2604 m .56676 1.33276 L .61079 1.27404 L .534 .313 .526 r
F
.73312 1.11093 m .62795 1.04943 L .73489 1.10859 L .828 .754 .782 r
F
.62185 1.2604 m .61249 1.27194 L .80285 1.01794 L .534 .313 .526 r
F
.70318 1.10368 m .62795 1.04943 L p .66355 1.20374 L .781 .764 .838 r
F P
0 g
s
.80285 1.01794 m .63382 .97409 L .73489 1.10859 L p .776 .745 .825 r
F P
0 g
s
.61249 1.27194 m .66071 1.20753 L .80285 1.01794 L .534 .313 .526 r
F
.76436 1.1478 m .80285 1.01794 L p .7631 1.07484 L 0 0 .239 r
F P
0 g
s
.73489 1.10859 m .76436 1.1478 L .80285 1.01794 L p .776 .745 .825 r
F P
0 g
s
.66071 1.20753 m .68333 1.17732 L .80285 1.01794 L .534 .313 .526 r
F
.68071 .98625 m .62247 1.04929 L .65835 .98045 L .801 .786 .838 r
F
.62247 1.04929 m .60546 1.06771 L .61999 1.04374 L F
.62247 1.04929 m .61999 1.04374 L .65835 .98045 L F
.44732 .93385 m .44468 .93217 L .44449 .93081 L .498 .362 .626 r
F
.44732 .93385 m .44449 .93081 L .44299 .91995 L F
.44966 .93533 m .44732 .93385 L .44299 .91995 L F
.43815 .89508 m .44444 .92331 L .44385 .92195 L .878 .47 .03 r
F
.44257 .91899 m .44203 .91605 L p .44385 .92195 L F P
0 g
s
.44203 .91605 m .43815 .89508 L p .44385 .92195 L .878 .47 .03 r
F P
0 g
s
.43815 .89508 m .4455 .92575 L .44444 .92331 L .878 .47 .03 r
F
.42325 .90962 m .43296 .91491 L .41845 .91343 L .453 .096 .269 r
F
.43296 .91491 m .43457 .91732 L .41845 .91343 L F
.43862 .89492 m .44478 .89287 L p .43852 .8965 L .878 .47 .03 r
F P
0 g
s
.43815 .89508 m .43862 .89492 L p .43852 .8965 L .878 .47 .03 r
F P
0 g
s
.45386 .89913 m .44927 .93873 L p .44478 .89287 L .878 .47 .03 r
F P
0 g
s
.44478 .89287 m .44927 .93873 L .44919 .9386 L .878 .47 .03 r
F
.44809 .94888 m .42216 .91786 L p .44468 .93217 L .638 .113 0 r
F P
0 g
s
.44505 .9324 m .44513 .93285 L p .44468 .93217 L .638 .113 0 r
F P
0 g
s
.44513 .93285 m .44809 .94888 L p .44468 .93217 L .638 .113 0 r
F P
0 g
s
.44478 .89287 m .44556 .90104 L .44525 .90078 L .878 .47 .03 r
F
.44556 .90104 m .44923 .93904 L .44525 .90078 L F
.448 .93729 m .44163 .92786 L .44644 .93506 L .602 .163 0 r
F
.44809 .94888 m .44759 .9404 L p .449 .94107 L .638 .113 0 r
F P
0 g
s
.44923 .93904 m .44809 .94888 L p .44735 .93636 L .878 .47 .03 r
F P
0 g
s
.44468 .93217 m .43527 .91837 L p .45131 .94218 L .602 .163 0 r
F P
0 g
s
.43527 .91837 m .43847 .92319 L .45131 .94218 L .602 .163 0 r
F
.44525 .90078 m .44923 .93904 L .44735 .93636 L .878 .47 .03 r
F
.46449 .88693 m .45958 .88845 L p .46395 .88186 L .911 .673 .566 r
F P
0 g
s
.43815 .89508 m .44289 .8935 L p .44956 .89155 L 0 0 0 r
F P
0 g
s
.44289 .8935 m .44478 .89287 L p .44956 .89155 L 0 0 0 r
F P
0 g
s
.45958 .88845 m .43815 .89508 L p .46395 .88186 L .911 .673 .566 r
F P
0 g
s
.4486 .88598 m .44098 .88921 L .44631 .8881 L .784 .964 .921 r
F
.46366 .87912 m .46297 .87988 L .46371 .87957 L .453 .096 .269 r
F
.43815 .89508 m .46258 .86882 L p .46395 .88186 L .911 .673 .566 r
F P
0 g
s
.50434 .83435 m .46366 .87912 L .54344 .80398 L .453 .096 .269 r
F
.53868 .80631 m .54344 .80398 L .55496 .79312 L F
.53868 .80631 m .55496 .79312 L .55463 .79328 L F
.50434 .83435 m .54344 .80398 L .53868 .80631 L F
.51778 .81653 m .55173 .79359 L .53323 .79988 L .648 .316 .396 r
F
.43815 .89508 m .43889 .89567 L p .43964 .9 L .154 0 .282 r
F P
0 g
s
.44163 .92786 m .44269 .92947 L .44644 .93506 L .602 .163 0 r
F
.43964 .9 m .44215 .91498 L .43853 .89693 L .154 0 .282 r
F
.44215 .91498 m .44215 .91498 L .43853 .89693 L F
.43853 .89693 m .43853 .89693 L .43815 .89508 L F
.44215 .91498 m .43853 .89693 L .43853 .89693 L F
.44215 .91498 m .44185 .91496 L .43815 .89508 L F
.44215 .91502 m .44214 .91501 L .44215 .91498 L F
.44214 .91501 m .44185 .91496 L .44215 .91498 L F
.43964 .9 m .43853 .89693 L .43872 .89695 L F
.44299 .91995 m .44468 .93217 L .43869 .92338 L .498 .362 .626 r
F
.44192 .91973 m .43869 .92338 L .43527 .91837 L F
.44299 .91995 m .43869 .92338 L .44192 .91973 L F
.44202 .91962 m .43527 .91837 L .43872 .9185 L F
.44299 .91995 m .44192 .91973 L .44202 .91962 L F
.44192 .91973 m .43527 .91837 L .44202 .91962 L F
.44259 .91897 m .44183 .91495 L .44185 .91496 L .154 0 .282 r
F
.43296 .91491 m .43962 .91854 L .43457 .91732 L .453 .096 .269 r
F
.44215 .91502 m .44278 .91876 L .44185 .91496 L .154 0 .282 r
F
.44278 .91876 m .44259 .91897 L .44185 .91496 L F
.44258 .91899 m .44183 .91495 L .44259 .91897 L F
.44257 .91899 m .44183 .91495 L p .44258 .91899 L F P
0 g
s
.44183 .91495 m .43815 .89508 L p .44185 .91496 L .154 0 .282 r
F P
0 g
s
.44199 .91496 m .43962 .91854 L .42325 .90962 L .453 .096 .269 r
F
.43962 .91854 m .42216 .91786 L .41845 .91343 L F
.44221 .9194 m .43932 .91852 L .44106 .91859 L .498 .362 .626 r
F
.44202 .91962 m .43872 .9185 L .44221 .9194 L F
.43872 .9185 m .43434 .91701 L .43932 .91852 L F
.43872 .9185 m .43932 .91852 L .44221 .9194 L F
.46441 .87688 m .44302 .89946 L .43977 .89648 L .453 .096 .269 r
F
.46387 .87868 m .44008 .90257 L .46441 .87688 L F
.45786 .87569 m .46258 .86882 L .46436 .86986 L 0 0 0 r
F
.46284 .87133 m .4633 .87565 L .45312 .88074 L .453 .096 .269 r
F
.46737 .86694 m .4633 .87565 L .46284 .87133 L F
.46062 .87348 m .46436 .86986 L .46481 .87013 L 0 0 0 r
F
.45786 .87569 m .46436 .86986 L .46062 .87348 L F
.4513 .88094 m .46258 .86882 L p .45786 .87569 L F P
0 g
s
.50224 .82414 m .4094 .90261 L .52273 .81411 L .453 .096 .269 r
F
.47268 .84912 m .46737 .86694 L .4094 .90261 L F
.47033 .84461 m .47268 .84912 L .46545 .86089 L .923 .598 .408 r
F
.43828 .89511 m .43815 .89508 L .43889 .89567 L p 0 .06 .599 r
F P
0 g
s
.43872 .89695 m .43853 .89693 L .43815 .89508 L .154 0 .282 r
F
.44098 .88921 m .4094 .90261 L .43199 .89641 L .784 .964 .921 r
F
.47044 .87208 m .42357 .90936 L .45312 .88074 L .453 .096 .269 r
F
.44426 .89577 m .46344 .87511 L .44441 .89446 L .648 .316 .396 r
F
.48096 .85622 m .51778 .81653 L .48226 .85426 L F
.46481 .87013 m .464 .87113 L p .45691 .87707 L 0 0 0 r
F P
0 g
s
.45416 .88108 m .45691 .87707 L .45773 .87639 L 0 0 0 r
F
.45763 .87758 m .45773 .87639 L .464 .87113 L F
.45416 .88108 m .45773 .87639 L .45763 .87758 L F
.44457 .89299 m .46374 .87297 L .45388 .88136 L .648 .316 .396 r
F
.46737 .86694 m .46503 .87478 L .4633 .87565 L .453 .096 .269 r
F
.50224 .82414 m .47044 .87208 L .46503 .87478 L F
.47624 .85593 m .46737 .86694 L p .47268 .84912 L .923 .598 .408 r
F P
0 g
s
.50224 .82414 m .46503 .87478 L .47268 .84912 L .453 .096 .269 r
F
.46374 .87297 m .48363 .8522 L .464 .87113 L .648 .316 .396 r
F
.48363 .8522 m .51163 .82296 L .48549 .8494 L F
.48363 .8522 m .48549 .8494 L .464 .87113 L F
.46374 .87297 m .464 .87113 L .45388 .88136 L F
.45691 .87707 m .46062 .87348 L .46481 .87013 L 0 0 0 r
F
.44827 .88704 m .44177 .8922 L .4513 .88094 L F
.44042 .89264 m .4513 .88094 L p .44177 .8922 L F P
0 g
s
.45691 .87707 m .45786 .87569 L .46062 .87348 L 0 0 0 r
F
.46344 .87511 m .46353 .87446 L .44441 .89446 L .648 .316 .396 r
F
.48096 .85622 m .48226 .85426 L .46358 .8741 L F
.46353 .87446 m .46358 .8741 L .44441 .89446 L F
.48096 .85622 m .46358 .8741 L .46353 .87446 L F
.45324 .87564 m .45019 .88221 L .4094 .90261 L .453 .096 .269 r
F
.45691 .87707 m .4513 .88094 L .45786 .87569 L 0 0 0 r
F
.45416 .88108 m .4498 .88396 L .45691 .87707 L F
.45364 .88161 m .4498 .88396 L .45416 .88108 L F
.4401 .89587 m .43828 .89511 L .4414 .89762 L 0 .06 .599 r
F
.441 .89672 m .4414 .89762 L .44289 .89868 L F
.43986 .89554 m .4401 .89587 L .441 .89672 L F
.4401 .89587 m .4414 .89762 L .441 .89672 L F
.4498 .88396 m .4513 .88094 L .45691 .87707 L 0 0 0 r
F
.46737 .86694 m .45019 .88221 L .45324 .87564 L .453 .096 .269 r
F
.46737 .86694 m .45312 .88074 L .45019 .88221 L F
.46737 .86694 m .46481 .87013 L p .46436 .86986 L 0 0 0 r
F P
0 g
s
.46737 .86694 m .464 .87113 L p .47268 .84912 L .923 .598 .408 r
F P
0 g
s
.47268 .84912 m .464 .87113 L .46481 .86541 L .923 .598 .408 r
F
.46667 .8589 m .46481 .86541 L .46545 .86089 L F
.47268 .84912 m .46481 .86541 L .46667 .8589 L F
.44828 .88702 m .4498 .88396 L .45364 .88161 L 0 0 0 r
F
.441 .89672 m .45234 .88292 L .44869 .88661 L .648 .316 .396 r
F
.44112 .89684 m .45234 .88292 L .441 .89672 L F
.44828 .88702 m .45364 .88161 L .44869 .88661 L 0 0 0 r
F
.55803 .78719 m .55924 .77492 L .55867 .77594 L .908 .809 .739 r
F
.55803 .78719 m .55903 .78654 L .55941 .778 L F
.55989 .77562 m .56347 .78983 L .54915 .79442 L .777 .619 .684 r
F
.55989 .77562 m .5627 .77303 L p .5713 .82092 L F P
0 g
s
.55686 .79134 m .46366 .87912 L .58155 .82957 L .453 .096 .269 r
F
.4431 .89953 m .44218 .91469 L .44008 .90257 L F
.58668 .83459 m .46371 .87957 L .51354 .87404 L .784 .964 .921 r
F
.58274 .83562 m .46371 .87957 L .58668 .83459 L F
.57216 .83356 m .46371 .87957 L .58924 .83322 L F
.46366 .87912 m .46371 .87957 L .58155 .82957 L .453 .096 .269 r
F
.47044 .87208 m .44877 .90474 L .4431 .89953 L F
.44877 .90474 m .44218 .91469 L .4431 .89953 L F
.44076 .89718 m .44384 .89965 L p .4411 .89741 L 0 .06 .599 r
F P
0 g
s
.43828 .89511 m .44076 .89718 L .4411 .89741 L 0 .06 .599 r
F
.43828 .89511 m .44384 .89965 L .44357 .89937 L F
.43977 .89648 m .44008 .90257 L .43912 .89699 L .453 .096 .269 r
F
.44302 .89946 m .44008 .90257 L .43977 .89648 L F
.44299 .91995 m .44202 .91962 L .44221 .9194 L .498 .362 .626 r
F
.44257 .91899 m .44299 .91995 L .44221 .9194 L F
.44483 .93121 m .44257 .91899 L p .4469 .93472 L .878 .47 .03 r
F P
0 g
s
.44638 .93284 m .44487 .93122 L p .44635 .93273 L .05 .273 .766 r
F P
0 g
s
.44444 .92331 m .44735 .93636 L .44257 .91899 L .878 .47 .03 r
F
.44488 .92526 m .44712 .93251 L .44735 .93636 L F
.44487 .93122 m .44488 .93122 L .4481 .93451 L .05 .273 .766 r
F
.4481 .93451 m .4481 .93451 L .46081 .94748 L F
.44487 .93122 m .4481 .93451 L .4481 .93451 L F
.44638 .93284 m .44635 .93273 L .4481 .93451 L F
.44803 .93451 m .4481 .93451 L .46081 .94748 L F
.44638 .93284 m .4481 .93451 L .44803 .93451 L F
.44287 .91866 m .44278 .91876 L .43964 .9 L .154 0 .282 r
F
.50434 .83435 m .55588 .79226 L .55564 .79234 L .453 .096 .269 r
F
.53844 .80643 m .55173 .79359 L p .51778 .81653 L .648 .316 .396 r
F P
0 g
s
.54887 .79788 m .53844 .80643 L .55173 .79359 L .156 0 0 r
F
.50203 .87531 m .46449 .88693 L p .46849 .87904 L .911 .673 .566 r
F P
0 g
s
.48815 .88981 m .53113 .82477 L .51735 .84726 L .156 0 0 r
F
.48772 .88961 m .53318 .82141 L .48815 .88981 L F
.53318 .82141 m .55173 .79359 L .53113 .82477 L F
.53318 .82141 m .53113 .82477 L .48815 .88981 L F
.5543 .79343 m .55173 .79359 L .55669 .78995 L F
.51735 .84726 m .54911 .79769 L .5543 .79343 L F
.54911 .79769 m .55173 .79359 L .5543 .79343 L F
.55632 .7905 m .55669 .78995 L .55617 .79027 L F
.55632 .7905 m .55617 .79027 L .54155 .7994 L F
.53113 .82477 m .55173 .79359 L .51735 .84726 L F
.5543 .79343 m .55632 .7905 L .54155 .7994 L F
.53734 .79633 m .55779 .77755 L p .53149 .79722 L .885 .968 .839 r
F P
0 g
s
.46441 .86821 m .49809 .82617 L .46446 .86789 L .648 .316 .396 r
F
.49099 .83099 m .44869 .88661 L p .49809 .82617 L F P
0 g
s
.51778 .81653 m .53323 .79988 L .49262 .82885 L .648 .316 .396 r
F
.49428 .82665 m .47798 .8481 L p .50049 .82193 L .506 .148 .294 r
F P
0 g
s
.47798 .8481 m .46481 .86541 L p .4816 .84496 L .506 .148 .294 r
F P
0 g
s
.50049 .82193 m .47798 .8481 L .4816 .84496 L .506 .148 .294 r
F
.44132 .89705 m .45388 .88136 L .44113 .89686 L .648 .316 .396 r
F
.45388 .88136 m .46441 .86821 L .45302 .88224 L F
.45388 .88136 m .45302 .88224 L .44113 .89686 L F
.44008 .90257 m .43089 .9118 L .43912 .89699 L .453 .096 .269 r
F
.43945 .89893 m .43945 .89891 L .43748 .90135 L .648 .316 .396 r
F
.43889 .89567 m .44384 .89965 L p .43964 .9 L .154 0 .282 r
F P
0 g
s
.52273 .81411 m .50434 .83435 L .53844 .80643 L .453 .096 .269 r
F
.46606 .87228 m .53844 .80643 L .51778 .81653 L .648 .316 .396 r
F
.46463 .87645 m .53844 .80643 L .46606 .87228 L F
.55779 .77755 m .55989 .77562 L p .54915 .79442 L .777 .619 .684 r
F P
0 g
s
.54915 .79442 m .54831 .79469 L .55779 .77755 L .777 .619 .684 r
F
.46441 .86821 m .44462 .89256 L .44461 .89258 L .648 .316 .396 r
F
.46441 .86821 m .46446 .86789 L .43945 .89891 L F
.44869 .88661 m .45364 .88161 L .45391 .88144 L 0 0 0 r
F
.45234 .88292 m .49809 .82617 L .44869 .88661 L .648 .316 .396 r
F
.46481 .86541 m .441 .89672 L p .4642 .86756 L .506 .148 .294 r
F P
0 g
s
.44426 .89577 m .46463 .87645 L .46606 .87228 L .648 .316 .396 r
F
.44456 .89828 m .44407 .89754 L .44524 .89767 L .156 0 0 r
F
.46441 .86821 m .51778 .81653 L .49809 .82617 L .648 .316 .396 r
F
.45388 .88136 m .46401 .87109 L .46441 .86821 L F
.46401 .87109 m .51778 .81653 L .46441 .86821 L F
.51163 .82296 m .51778 .81653 L .45388 .88136 L F
.44341 .89904 m .44407 .89754 L .44456 .89828 L .156 0 0 r
F
.44475 .89999 m .44472 .89996 L .44459 .90011 L .506 .148 .294 r
F
.44441 .89446 m .51778 .81653 L .44457 .89299 L .648 .316 .396 r
F
.47044 .87208 m .46387 .87868 L .46441 .87688 L .453 .096 .269 r
F
.44407 .89754 m .53844 .80643 L p .44426 .89577 L .648 .316 .396 r
F P
0 g
s
.53706 .81003 m .47044 .87208 L .53844 .80643 L .156 0 0 r
F
.49051 .85571 m .47044 .87208 L .53706 .81003 L F
.52798 .82631 m .47044 .87208 L .5328 .82123 L F
.52498 .80492 m .53734 .79633 L .53466 .79674 L .885 .968 .839 r
F
.52498 .80492 m .53466 .79674 L .53149 .79722 L F
.464 .87113 m .46272 .87271 L p .45416 .88108 L 0 0 0 r
F P
0 g
s
.464 .87113 m .46272 .87271 L p .46481 .86541 L .923 .598 .408 r
F P
0 g
s
.50049 .82193 m .46481 .86541 L .4642 .86756 L .506 .148 .294 r
F
.44461 .89258 m .43945 .89891 L .43945 .89893 L .648 .316 .396 r
F
.44462 .89256 m .43945 .89891 L .44461 .89258 L F
.50049 .82193 m .441 .89672 L .44124 .89695 L .506 .148 .294 r
F
.54939 .79273 m .54831 .79469 L .53554 .79799 L .777 .619 .684 r
F
.54831 .79469 m .53534 .79884 L .53554 .79799 L F
.53554 .79799 m .55779 .77755 L p .54939 .79273 L F P
0 g
s
.53206 .80384 m .50224 .82414 L .52273 .81411 L .453 .096 .269 r
F
.55128 .78269 m .51905 .80993 L .53206 .80384 L F
.51905 .80993 m .50224 .82414 L .53206 .80384 L F
.55669 .78995 m .54939 .79273 L .53206 .80384 L .156 0 0 r
F
.52 .81184 m .44142 .91861 L .49539 .83478 L .453 .096 .269 r
F
.55669 .78995 m .53206 .80384 L .54155 .7994 L .156 0 0 r
F
.52369 .80841 m .53519 .80183 L .53591 .79779 L .908 .809 .739 r
F
.52091 .81099 m .53519 .80183 L .52369 .80841 L F
.50049 .82193 m .50319 .81716 L p .48541 .8324 L .602 .252 .349 r
F P
0 g
s
.48541 .8324 m .50319 .81716 L .47415 .84022 L .602 .252 .349 r
F
.47931 .8362 m .53982 .79098 L .53933 .79107 L .885 .968 .839 r
F
.47166 .84195 m .47924 .83628 L .47931 .8362 L F
.47924 .83628 m .53982 .79098 L .47931 .8362 L F
.46772 .84492 m .47195 .84175 L .47166 .84195 L F
.47195 .84175 m .53983 .79098 L .47166 .84195 L F
.53983 .79098 m .55779 .77755 L .53982 .79098 L F
.53983 .79098 m .53982 .79098 L .47166 .84195 L F
.47408 .84048 m .47783 .83796 L .47805 .83771 L F
.47429 .84038 m .47783 .83796 L .47408 .84048 L F
.47783 .83796 m .47879 .83845 L .49428 .82665 L F
.47909 .83782 m .48541 .8324 L .47218 .84178 L .602 .252 .349 r
F
.48541 .8324 m .47415 .84022 L .47218 .84178 L F
.46344 .87511 m .48096 .85622 L .46353 .87446 L .648 .316 .396 r
F
.44215 .91498 m .44215 .91502 L .44215 .91498 L .154 0 .282 r
F
.44142 .91861 m .43962 .91854 L .50224 .82414 L .453 .096 .269 r
F
.47401 .86863 m .4931 .83497 L p .46701 .87539 L .506 .148 .294 r
F P
0 g
s
.4931 .83497 m .50049 .82193 L p .4914 .83644 L .506 .148 .294 r
F P
0 g
s
.4931 .83497 m .4914 .83644 L .46701 .87539 L .506 .148 .294 r
F
.46701 .87539 m .50049 .82193 L .47071 .85964 L F
.49856 .82533 m .50049 .82193 L p .47909 .83782 L .602 .252 .349 r
F P
0 g
s
.50049 .82193 m .48541 .8324 L .47909 .83782 L .602 .252 .349 r
F
.49189 .8279 m .52498 .80492 L .53149 .79722 L .885 .968 .839 r
F
.46229 .8862 m .45272 .89109 L .46155 .88735 L .506 .148 .294 r
F
.46155 .88735 m .45272 .89109 L .44472 .89996 L F
.44289 .89868 m .4414 .89762 L .44357 .89937 L 0 .06 .599 r
F
.43759 .9017 m .44441 .89446 L .44457 .89299 L .648 .316 .396 r
F
.46913 .86637 m .45197 .88336 L .44124 .89695 L .506 .148 .294 r
F
.46272 .87271 m .46023 .87581 L p .45391 .88144 L 0 0 0 r
F P
0 g
s
.45886 .87721 m .45391 .88144 L .46023 .87581 L 0 0 0 r
F
.45208 .8841 m .45366 .88181 L .45886 .87721 L F
.45366 .88181 m .45391 .88144 L .45886 .87721 L F
.44426 .89577 m .44441 .89446 L .43759 .9017 L .648 .316 .396 r
F
.4605 .88423 m .44746 .8948 L .47044 .87208 L .156 0 0 r
F
.44746 .8948 m .44407 .89754 L .44641 .89528 L F
.44746 .8948 m .44641 .89528 L .47044 .87208 L F
.46477 .88493 m .46609 .8793 L .45272 .89109 L .506 .148 .294 r
F
.46477 .88493 m .46229 .8862 L .46155 .88735 L F
.46477 .88493 m .44472 .89996 L .44475 .89999 L F
.44356 .91601 m .44624 .91764 L .44692 .929 L .878 .47 .03 r
F
.45901 .89737 m .4544 .91911 L .44142 .91861 L .453 .096 .269 r
F
.44398 .93146 m .44644 .93506 L p .43847 .92319 L .602 .163 0 r
F P
0 g
s
.53519 .80183 m .55183 .78355 L .55144 .78295 L .908 .809 .739 r
F
.53933 .79107 m .55779 .77755 L .55548 .77893 L .885 .968 .839 r
F
.53982 .79098 m .55779 .77755 L .53933 .79107 L F
.55183 .78355 m .55703 .77783 L .55144 .78295 L .908 .809 .739 r
F
.55144 .78295 m .55703 .77783 L .55272 .78147 L F
.53519 .80183 m .54939 .79273 L .55703 .77783 L F
.54939 .79273 m .55867 .77594 L .55868 .77579 L F
.55752 .77687 m .55868 .77579 L .55876 .77445 L F
.54939 .79273 m .55868 .77579 L .55752 .77687 L F
.55261 .78065 m .46899 .84381 L p .55543 .77896 L .885 .968 .839 r
F P
0 g
s
.46912 .84372 m .55543 .77896 L .46899 .84381 L .885 .968 .839 r
F
.46748 .84494 m .46772 .84492 L p .55548 .77893 L F P
0 g
s
.46748 .84494 m .55548 .77893 L .55543 .77896 L .885 .968 .839 r
F
.53519 .80183 m .55429 .77965 L .53749 .79787 L .908 .809 .739 r
F
.55429 .77965 m .55876 .77445 L .55374 .77997 L F
.55429 .77965 m .55374 .77997 L .53749 .79787 L F
.55128 .78269 m .52369 .80841 L .52529 .80466 L .453 .096 .269 r
F
.55959 .77329 m .55961 .77334 L .47239 .84124 L .796 .591 .624 r
F
.55261 .78065 m .47239 .84124 L p .55961 .77334 L F P
0 g
s
.47238 .84124 m .47288 .83829 L .46946 .84093 L p .736 .35 .32 r
F P
0 g
s
.55959 .77329 m .47239 .84124 L .47226 .84123 L .796 .591 .624 r
F
.52744 .77592 m .55959 .77329 L .47264 .84093 L F
.48869 .76454 m .4887 .76452 L .48527 .77239 L .908 .809 .739 r
F
.49271 .77097 m .48965 .78998 L .48836 .76527 L .778 .572 .62 r
F
.49271 .77097 m .48836 .76527 L .4887 .76452 L F
.48965 .78998 m .47708 .79927 L p .48836 .76527 L F P
0 g
s
.50179 .74263 m .49771 .78404 L .49044 .78693 L .778 .572 .62 r
F
.48549 .79306 m .50261 .75238 L .49536 .75449 L .532 .326 .546 r
F
.50179 .74263 m .50135 .74666 L .51061 .7585 L .819 .466 .389 r
F
.50179 .74263 m .50007 .74395 L .50135 .74666 L F
.50007 .74395 m .49991 .74408 L .50057 .74526 L F
.50007 .74395 m .50057 .74526 L .50135 .74666 L F
.50135 .74666 m .5013 .74716 L .5017 .74765 L F
.50135 .74666 m .5017 .74765 L .51061 .7585 L F
.50074 .74495 m .49727 .75112 L p .50002 .74289 L .597 .402 .587 r
F P
0 g
s
.4949 .75028 m .49491 .75026 L .4887 .76452 L .908 .809 .739 r
F
.49354 .74897 m .49409 .75202 L .49491 .75026 L .819 .466 .389 r
F
.49489 .75029 m .4887 .76452 L .48869 .76454 L .908 .809 .739 r
F
.49354 .74897 m .49491 .75026 L .49582 .7483 L .819 .466 .389 r
F
.49727 .75112 m .4956 .73682 L .4959 .73664 L .597 .402 .587 r
F
.52039 .71011 m .51505 .753 L p .51433 .75308 L .894 .733 .676 r
F P
0 g
s
.51468 .74171 m .52039 .71011 L .51433 .75308 L .894 .733 .676 r
F
.50179 .74263 m .51412 .75983 L p .51508 .72852 L .682 .555 .703 r
F P
0 g
s
.51475 .73001 m .51507 .72886 L .51259 .75328 L .894 .733 .676 r
F
.51507 .72886 m .52039 .71011 L .51468 .74171 L F
.51507 .72886 m .51468 .74171 L .51259 .75328 L F
.51518 .72529 m .51483 .72575 L p .51518 .72551 L .682 .555 .703 r
F P
0 g
s
.51518 .72529 m .50179 .74263 L p .51532 .72378 L .657 .519 .684 r
F P
0 g
s
.50568 .73239 m .51532 .72378 L .50179 .74263 L .657 .519 .684 r
F
.51483 .72575 m .50179 .74263 L p .51508 .72852 L .682 .555 .703 r
F P
0 g
s
.51532 .72378 m .52039 .71011 L p .51475 .73001 L .894 .733 .676 r
F P
0 g
s
.51508 .72852 m .52325 .71985 L .51518 .72551 L .682 .555 .703 r
F
.51508 .72852 m .51518 .72551 L .51483 .72575 L F
.50375 .73962 m .50179 .74263 L .50941 .74178 L .506 .498 .782 r
F
.50923 .74022 m .51522 .72405 L p .51028 .74442 L .894 .733 .676 r
F P
0 g
s
.51522 .72405 m .51522 .72422 L .51028 .74444 L .894 .733 .676 r
F
.50941 .74178 m .50179 .74263 L .51054 .74547 L .506 .498 .782 r
F
.50179 .74263 m .51061 .7585 L .51412 .75983 L .819 .466 .389 r
F
.5013 .74716 m .50346 .75579 L .51061 .7585 L F
.51505 .753 m .5142 .75985 L p .51412 .75981 L .894 .733 .676 r
F P
0 g
s
.51249 .75329 m .51505 .753 L .51412 .75981 L .894 .733 .676 r
F
.51054 .74547 m .50179 .74263 L .51412 .75983 L .506 .498 .782 r
F
.50403 .75426 m .5142 .75985 L .50813 .75756 L .894 .733 .676 r
F
.51425 .76 m .51425 .76001 L .51423 .75964 L .41 .291 .606 r
F
.51423 .75964 m .51418 .76004 L p .51425 .76 L F P
0 g
s
.51412 .75983 m .51425 .76 L p .51508 .72852 L .682 .555 .703 r
F P
0 g
s
.51259 .75328 m .51468 .74171 L .51433 .75308 L .894 .733 .676 r
F
.50941 .74178 m .51054 .74547 L .50997 .74318 L .506 .498 .782 r
F
.508 .7538 m .51475 .73001 L .51259 .75328 L .894 .733 .676 r
F
.51094 .7456 m .51054 .74547 L .51425 .76 L .506 .498 .782 r
F
.51054 .74547 m .51412 .75983 L .51425 .76 L F
.50403 .75426 m .51249 .75329 L .51412 .75981 L .894 .733 .676 r
F
.5142 .75985 m .51391 .7622 L p .50813 .75756 L F P
0 g
s
.51412 .75983 m .51425 .76 L p .51318 .76156 L .778 .572 .62 r
F P
0 g
s
.50307 .78007 m .5131 .76171 L .51391 .7622 L .894 .733 .676 r
F
.50346 .75579 m .50813 .75756 L .51391 .7622 L F
.51447 .7672 m .51494 .77131 L .51462 .76619 L .41 .291 .606 r
F
.51376 .76387 m .51462 .76619 L .51425 .76 L F
.51494 .77131 m .50307 .78007 L p .51425 .76 L .778 .572 .62 r
F P
0 g
s
.51425 .76 m .50307 .78007 L .51318 .76156 L .778 .572 .62 r
F
.51718 .7687 m .51721 .76872 L .51541 .77663 L .819 .694 .727 r
F
.54443 .64884 m .54443 .64885 L .51721 .76872 L F
.51721 .76872 m .51721 .76872 L .51541 .77663 L F
.54443 .64884 m .51721 .76872 L .51721 .76872 L F
.51497 .76713 m .54424 .64901 L .5146 .75826 L .41 .291 .606 r
F
.51538 .77664 m .52273 .7443 L p .51497 .76713 L F P
0 g
s
.51412 .75983 m .51715 .76868 L .51425 .76 L .819 .466 .389 r
F
.54597 .66491 m .55715 .67097 L .55311 .63987 L p .574 .555 .795 r
F P
0 g
s
.54609 .64154 m .5488 .67195 L p .55544 .64099 L .411 .386 .721 r
F P
0 g
s
.54597 .66491 m .55038 .64942 L .54575 .64995 L .574 .555 .795 r
F
.51771 .76908 m .54443 .64885 L .54847 .66822 L .819 .694 .727 r
F
.51541 .77663 m .51721 .76872 L .51771 .76908 L F
.51721 .76872 m .54443 .64885 L .51771 .76908 L F
.49771 .78404 m .48965 .78998 L p .49044 .78693 L .778 .572 .62 r
F P
0 g
s
.4809 .81664 m .50346 .75579 L p .5131 .76171 L .894 .733 .676 r
F P
0 g
s
.4809 .81664 m .5131 .76171 L .50307 .78007 L .894 .733 .676 r
F
.51061 .7585 m .51568 .76762 L .51412 .75983 L .819 .466 .389 r
F
.51835 .77136 m .51742 .77372 L .52112 .77251 L .082 0 .156 r
F
.52399 .77359 m .52456 .77116 L .53063 .77095 L .819 .694 .727 r
F
.52078 .77128 m .52112 .77251 L .52533 .77113 L .082 0 .156 r
F
.51835 .77136 m .52112 .77251 L .52078 .77128 L F
.51835 .77136 m .51858 .77284 L .5182 .77174 L F
.5181 .77199 m .51858 .77284 L .51742 .77372 L F
.51603 .77459 m .51701 .77141 L .51808 .77174 L .819 .694 .727 r
F
.51701 .77141 m .54847 .66822 L .52456 .77116 L F
.51568 .76762 m .51858 .77284 L .51715 .76868 L .819 .466 .389 r
F
.51568 .76762 m .51715 .76868 L .51412 .75983 L F
.51715 .76868 m .51858 .77284 L .51718 .7687 L F
.51715 .76868 m .51718 .7687 L .51425 .76 L F
.51028 .74442 m .51028 .74444 L .508 .7538 L .894 .733 .676 r
F
.51522 .72405 m .51028 .74444 L .51028 .74442 L F
.51532 .72378 m .51475 .73001 L .508 .7538 L F
.50997 .74318 m .51054 .74547 L .51094 .7456 L .506 .498 .782 r
F
.52039 .71011 m .51 .72853 L p .51166 .72705 L .532 .326 .546 r
F P
0 g
s
.49727 .75112 m .4959 .73664 L .49875 .73773 L .597 .402 .587 r
F
.5002 .73828 m .50056 .73928 L .50375 .73962 L .506 .498 .782 r
F
.50056 .73928 m .50179 .74263 L .50375 .73962 L F
.49981 .74352 m .49875 .73773 L .50141 .73874 L .597 .402 .587 r
F
.49727 .75112 m .49875 .73773 L .49981 .74352 L F
.49875 .73773 m .4966 .74662 L .4993 .74076 L .142 0 0 r
F
.49025 .6909 m .49488 .73147 L .49875 .73773 L F
.49488 .73147 m .4966 .74662 L .49875 .73773 L F
.49025 .6909 m .459 .76318 L p .47439 .72608 L 0 0 0 r
F P
0 g
s
.47532 .72384 m .48323 .70639 L p .47439 .72608 L 0 0 0 r
F P
0 g
s
.48323 .70639 m .49025 .6909 L p .47439 .72608 L 0 0 0 r
F P
0 g
s
.47532 .72384 m .49025 .6909 L p .47976 .69763 L .038 0 .439 r
F P
0 g
s
.49025 .6909 m .48494 .66709 L .47976 .69763 L .038 0 .439 r
F
.47815 .70714 m .4733 .72132 L p .47534 .72373 L .979 .88 .513 r
F P
0 g
s
.47815 .70714 m .459 .76318 L .49025 .6909 L p 0 0 .038 r
F P
0 g
s
.49025 .6909 m .48295 .64947 L .48225 .65504 L p .038 0 .439 r
F P
0 g
s
.48173 .65236 m .49025 .6909 L .48225 .65504 L 0 0 .181 r
F
.48145 .6511 m .48173 .65236 L .48172 .65296 L F
.48167 .65206 m .48173 .65236 L .48145 .6511 L F
.48127 .65303 m .48163 .65229 L .48172 .65296 L .866 .996 .785 r
F
.47265 .67 m .47261 .67075 L .45215 .68842 L .896 .804 .75 r
F
.46834 .67725 m .47159 .67371 L .46929 .68104 L .866 .996 .785 r
F
.47159 .67371 m .46958 .68067 L .46929 .68104 L F
.47261 .67075 m .47053 .70953 L .45301 .68941 L .896 .804 .75 r
F
.47261 .67075 m .45301 .68941 L .45215 .68842 L F
.46801 .67514 m .47799 .65529 L .47261 .67075 L .866 .996 .785 r
F
.47053 .70953 m .45709 .71869 L .45215 .68842 L .896 .804 .75 r
F
.43158 .70982 m .46692 .6683 L .46801 .67514 L .866 .996 .785 r
F
.46692 .6683 m .47799 .65529 L .46801 .67514 L F
.46657 .66615 m .49025 .6909 L .48144 .651 L .592 .324 .479 r
F
.48168 .65208 m .48404 .66276 L .48295 .64947 L F
.48404 .66276 m .49025 .6909 L .48497 .66093 L F
.48404 .66276 m .48497 .66093 L .48295 .64947 L F
.47826 .6354 m .48176 .65228 L .47937 .64113 L 0 0 .181 r
F
.47826 .6354 m .47937 .64113 L .47877 .63831 L F
.47529 .62102 m .47351 .62323 L .47728 .63032 L .896 .804 .75 r
F
.47177 .61887 m .47529 .62102 L .47728 .63032 L .778 .506 .523 r
F
.45422 .58241 m .46758 .6136 L p .47195 .61734 L 0 .108 .634 r
F P
0 g
s
.46433 .60248 m .46487 .60338 L .4628 .60231 L .897 .477 .142 r
F
.47529 .62102 m .46916 .61184 L p .46487 .60338 L F P
0 g
s
.46916 .61184 m .4628 .60231 L p .46487 .60338 L .897 .477 .142 r
F P
0 g
s
.47853 .63915 m .47877 .63831 L .47503 .62978 L .89 .581 .455 r
F
.47449 .62972 m .47422 .6408 L .46882 .62906 L .896 .804 .75 r
F
.47482 .62975 m .47473 .63136 L .47449 .62972 L F
.47473 .63136 m .47422 .6408 L .47449 .62972 L F
.47292 .61924 m .47512 .63119 L .4736 .62059 L 0 .108 .634 r
F
.47195 .61734 m .47393 .62598 L .47292 .61924 L F
.47393 .62598 m .47512 .63119 L .47292 .61924 L F
.47449 .62972 m .47853 .63915 L p .47503 .62978 L .89 .581 .455 r
F P
0 g
s
.4736 .62059 m .47512 .63119 L .47628 .63068 L 0 .108 .634 r
F
.46942 .60375 m .47529 .62102 L p .44397 .56802 L .897 .477 .142 r
F P
0 g
s
.47529 .62102 m .46916 .61184 L p .47128 .61184 L 0 .217 .735 r
F P
0 g
s
.47128 .61184 m .47195 .61734 L .4736 .62059 L 0 .108 .634 r
F
.46805 .5972 m .45385 .58154 L p .45425 .58245 L .89 .581 .455 r
F P
0 g
s
.46942 .60375 m .46805 .5972 L .45425 .58245 L .89 .581 .455 r
F
.46703 .59584 m .47069 .61184 L .47128 .61184 L 0 .108 .634 r
F
.47069 .61184 m .47195 .61734 L .47128 .61184 L F
.48184 .62757 m .48068 .63163 L .47812 .61263 L .989 .738 .453 r
F
.4818 .61187 m .47529 .62102 L p .47128 .61184 L 0 .217 .735 r
F P
0 g
s
.47179 .61184 m .46703 .59584 L .47178 .61184 L 0 .108 .634 r
F
.48161 .61214 m .47788 .61738 L p .48159 .61274 L 0 0 .408 r
F P
0 g
s
.48295 .64947 m .4818 .61187 L p .47728 .63032 L 0 .108 .634 r
F P
0 g
s
.48159 .61274 m .48186 .61241 L .48171 .61225 L 0 0 .408 r
F
.48159 .61274 m .48171 .61225 L .48161 .61214 L F
.48295 .64947 m .4818 .61187 L .48409 .63322 L p 0 0 .231 r
F P
0 g
s
.48409 .63322 m .49025 .6909 L .48295 .64947 L p 0 0 .231 r
F P
0 g
s
.47788 .61738 m .48843 .68006 L .48186 .61241 L 0 0 .408 r
F
.47728 .63032 m .47731 .63047 L .48295 .64947 L 0 .108 .634 r
F
.47788 .61738 m .47529 .62102 L .4792 .63929 L p 0 0 .408 r
F P
0 g
s
.49025 .6909 m .48191 .6531 L .48295 .64947 L 0 .126 .674 r
F
.48552 .66878 m .49025 .6909 L p .48173 .65236 L 0 0 .181 r
F P
0 g
s
.48552 .66878 m .48173 .65236 L .48167 .65206 L 0 0 .181 r
F
.49025 .6909 m .47558 .67526 L .48191 .6531 L 0 .126 .674 r
F
.48552 .66878 m .48176 .65243 L .48148 .65107 L 0 0 .181 r
F
.48176 .65243 m .48167 .65206 L .48165 .65193 L F
.48176 .65243 m .48165 .65193 L .48148 .65107 L F
.4792 .63929 m .49025 .6909 L p .47788 .61738 L 0 0 .408 r
F P
0 g
s
.4818 .61187 m .47155 .60074 L p .47728 .63032 L 0 .108 .634 r
F P
0 g
s
.47086 .60029 m .47058 .59998 L p .47072 .60063 L .89 .581 .455 r
F P
0 g
s
.47155 .60074 m .46703 .59584 L p .47728 .63032 L 0 .108 .634 r
F P
0 g
s
.46703 .59584 m .47128 .61184 L .47139 .61184 L 0 .108 .634 r
F
.46703 .59584 m .47937 .64113 L .47731 .63047 L F
.46703 .59584 m .45422 .58241 L .47195 .61734 L F
.46271 .59222 m .4818 .61187 L p .47128 .61184 L 0 .217 .735 r
F P
0 g
s
.47728 .63032 m .47179 .61184 L .47724 .63023 L 0 .108 .634 r
F
.47179 .61184 m .47178 .61184 L .47724 .63023 L F
.47728 .63032 m .47724 .63023 L .47724 .63025 L F
.47728 .63032 m .47724 .63025 L .47727 .63035 L F
.47853 .63915 m .47937 .64113 L p .47553 .62703 L F P
0 g
s
.47139 .61184 m .4752 .6264 L .47553 .62703 L 0 .108 .634 r
F
.4752 .6264 m .47853 .63915 L .47553 .62703 L F
.47128 .61184 m .47853 .63915 L .47139 .61184 L F
.47728 .63032 m .47727 .63035 L .47731 .63047 L F
.47826 .6354 m .48087 .6471 L .48131 .65013 L 0 0 .181 r
F
.47728 .63032 m .48087 .6471 L p .47826 .6354 L F P
0 g
s
.47512 .63119 m .47853 .63915 L p .47628 .63068 L 0 .108 .634 r
F P
0 g
s
.48134 .65034 m .48176 .65228 L .48139 .65067 L 0 0 .181 r
F
.48134 .65034 m .48139 .65067 L .48072 .64771 L F
.33581 .7987 m .33777 .79733 L .43026 .70313 L .592 .324 .479 r
F
.41657 .72395 m .45647 .67632 L .41914 .72153 L F
.46654 .66611 m .46688 .66812 L .43091 .71045 L F
.46654 .66611 m .43091 .71045 L .42405 .71691 L F
.43009 .70308 m .43026 .70313 L .48144 .651 L F
.33581 .7987 m .43026 .70313 L .43009 .70308 L F
.50779 .74006 m .50781 .74 L .50776 .74006 L .532 .326 .546 r
F
.50781 .74 m .52039 .71011 L .50522 .73954 L F
.50876 .74017 m .50375 .73962 L .50941 .74178 L .506 .498 .782 r
F
.50781 .74 m .50522 .73954 L .5013 .74716 L .532 .326 .546 r
F
.5051 .73977 m .50522 .73954 L .50375 .73962 L F
.50522 .73954 m .51166 .72705 L .50394 .73931 L F
.50522 .73954 m .50394 .73931 L .50375 .73962 L F
.54424 .64901 m .54402 .64921 L .5146 .75826 L .41 .291 .606 r
F
.51606 .75285 m .54609 .64154 L .51484 .75471 L F
.51508 .72852 m .51425 .76 L .52325 .71985 L .682 .555 .703 r
F
.50997 .74318 m .51627 .75893 L .51026 .74043 L .506 .498 .782 r
F
.50659 .72999 m .50692 .73128 L .50568 .73239 L .657 .519 .684 r
F
.51738 .70163 m .50692 .73128 L .50659 .72999 L F
.50876 .74017 m .50997 .74318 L .50922 .74025 L .506 .498 .782 r
F
.4809 .81664 m .50346 .75579 L p .48549 .79306 L .532 .326 .546 r
F P
0 g
s
.50346 .75579 m .50302 .75404 L .48549 .79306 L .532 .326 .546 r
F
.50922 .74025 m .50781 .74 L .50261 .75238 L F
.50302 .75404 m .50261 .75238 L .48549 .79306 L F
.50922 .74025 m .50261 .75238 L .50302 .75404 L F
.50048 .75466 m .50027 .75656 L .50382 .75722 L .819 .466 .389 r
F
.50346 .75579 m .50382 .75722 L .51061 .7585 L F
.50048 .75466 m .50382 .75722 L .50346 .75579 L F
.50027 .75656 m .49709 .78571 L .50823 .77487 L F
.50439 .75952 m .50823 .77487 L .51568 .76762 L F
.50027 .75656 m .50823 .77487 L .50439 .75952 L F
.50346 .75579 m .50922 .74025 L p .50302 .75404 L .532 .326 .546 r
F P
0 g
s
.50922 .74025 m .52039 .71011 L p .50781 .74 L .532 .326 .546 r
F P
0 g
s
.51 .72853 m .50375 .73962 L p .51166 .72705 L .532 .326 .546 r
F P
0 g
s
.51738 .70163 m .51532 .72378 L .50692 .73128 L .657 .519 .684 r
F
.51 .72853 m .50516 .73711 L p .50359 .73222 L .597 .402 .587 r
F P
0 g
s
.51783 .64964 m .53384 .65833 L p .50635 .73063 L .657 .519 .684 r
F P
0 g
s
.50359 .73222 m .51783 .64964 L p .50635 .73063 L .657 .519 .684 r
F P
0 g
s
.50432 .72907 m .50876 .74017 L .50559 .72608 L .506 .498 .782 r
F
.50876 .74017 m .50922 .74025 L .50559 .72608 L F
.50922 .74025 m .50923 .74022 L p .50923 .74027 L .894 .733 .676 r
F P
0 g
s
.50922 .74025 m .51026 .74043 L .50559 .72608 L .506 .498 .782 r
F
.50997 .74318 m .51026 .74043 L .50922 .74025 L F
.50516 .73711 m .50074 .74495 L p .50297 .73406 L .597 .402 .587 r
F P
0 g
s
.49832 .73525 m .49025 .6909 L .50359 .73222 L .597 .402 .587 r
F
.50297 .73406 m .50359 .73222 L .50396 .73337 L F
.50297 .73406 m .50396 .73337 L .50516 .73711 L F
.50251 .72453 m .50375 .73962 L .50876 .74017 L .506 .498 .782 r
F
.47558 .67526 m .47665 .66819 L .47682 .66865 L 0 .126 .674 r
F
.39194 .74177 m .48144 .651 L .48144 .651 L .592 .324 .479 r
F
.33581 .7987 m .39194 .74177 L .39194 .74177 L F
.39194 .74177 m .48144 .651 L .39194 .74177 L F
.47665 .66819 m .47982 .64715 L .47682 .66865 L 0 .126 .674 r
F
.47682 .66865 m .47982 .64715 L .48074 .64783 L F
.48146 .65109 m .48145 .6511 L .48143 .65095 L 0 0 .181 r
F
.48139 .65067 m .48145 .6511 L .48145 .6511 L F
.47558 .67526 m .48074 .64783 L .48191 .6531 L 0 .126 .674 r
F
.48148 .65107 m .48146 .65109 L .48139 .65067 L 0 0 .181 r
F
.48146 .65109 m .48143 .65095 L .48139 .65067 L F
.48167 .65206 m .48145 .6511 L .48148 .65107 L F
.48139 .65066 m .48143 .65094 L .48072 .64771 L F
.48139 .65067 m .48145 .6511 L .48139 .65066 L F
.48131 .65013 m .48142 .65059 L .48141 .65059 L F
.48142 .65059 m .48552 .66878 L .48141 .65059 L F
.48141 .65059 m .48552 .66878 L .48176 .65228 L F
.48087 .6471 m .48552 .66878 L p .48131 .65013 L F P
0 g
s
.48028 .64578 m .48013 .64508 L p .48072 .64771 L 0 0 .181 r
F P
0 g
s
.47264 .64182 m .47287 .64159 L .48072 .64773 L 0 .126 .674 r
F
.47264 .64182 m .48072 .64773 L .48074 .64783 L F
.46882 .62906 m .47404 .6404 L .45529 .6514 L .896 .804 .75 r
F
.45473 .65036 m .45425 .64946 L .44106 .63476 L 0 .126 .674 r
F
.46882 .62906 m .45529 .6514 L .45352 .64809 L .896 .804 .75 r
F
.45425 .64946 m .43873 .63086 L .44106 .63476 L 0 .126 .674 r
F
.47404 .6404 m .47289 .64156 L .45536 .65152 L .896 .804 .75 r
F
.47404 .6404 m .45536 .65152 L .45529 .6514 L F
.47558 .67526 m .45809 .65662 L .47982 .64715 L 0 .126 .674 r
F
.45809 .65662 m .47264 .64182 L .47982 .64715 L F
.45536 .65152 m .45444 .66033 L .4469 .65632 L .896 .804 .75 r
F
.47289 .64156 m .45809 .65662 L .45536 .65152 L F
.45809 .65662 m .45444 .66033 L .45536 .65152 L F
.45352 .64809 m .44153 .62941 L .43873 .63086 L 0 .126 .674 r
F
.44153 .62941 m .42653 .61048 L .43873 .63086 L F
.47728 .63032 m .4753 .63263 L .49025 .6909 L .896 .804 .75 r
F
.45908 .65155 m .45778 .65306 L .49025 .6909 L F
.46442 .66079 m .45352 .64809 L .45425 .64946 L 0 .126 .674 r
F
.45352 .64809 m .43873 .63086 L .45425 .64946 L F
.45529 .6514 m .45536 .65152 L .4469 .65632 L .896 .804 .75 r
F
.45352 .64809 m .45529 .6514 L .4469 .65632 L F
.46613 .66336 m .46442 .66079 L .45425 .64946 L 0 .126 .674 r
F
.46613 .66336 m .45425 .64946 L .45473 .65036 L F
.47296 .62174 m .47431 .62857 L .47393 .62598 L 0 .108 .634 r
F
.47106 .62171 m .47512 .63119 L p .47158 .61965 L F P
0 g
s
.47351 .62323 m .47449 .62972 L .46882 .62906 L .896 .804 .75 r
F
.47393 .62598 m .47431 .62857 L .47512 .63119 L 0 .108 .634 r
F
.47351 .62323 m .45352 .64809 L .47728 .63032 L .896 .804 .75 r
F
.45963 .65595 m .45473 .65036 L .46507 .66407 L 0 .126 .674 r
F
.45473 .65036 m .45641 .65349 L .46507 .66407 L F
.46507 .66407 m .45641 .65349 L .45809 .65662 L F
.45352 .64809 m .42595 .68239 L .45778 .65306 L .896 .804 .75 r
F
.42595 .68239 m .4301 .68535 L .45778 .65306 L F
.45352 .64809 m .45778 .65306 L .47728 .63032 L F
.4704 .61601 m .46758 .6136 L .47278 .62095 L 0 .108 .634 r
F
.47158 .61965 m .47177 .61887 L .45952 .61136 L .666 .35 .428 r
F
.40879 .5964 m .46678 .61787 L .39749 .57439 L F
.36452 .51251 m .38804 .53755 L .36784 .53451 L p .442 .77 .997 r
F P
0 g
s
.38471 .57044 m .37212 .52492 L .36784 .53451 L 0 .126 .674 r
F
.37088 .55467 m .36784 .53451 L .36291 .54557 L F
.38471 .57044 m .36784 .53451 L .37088 .55467 L F
.37219 .52476 m .36452 .51251 L .36291 .54557 L F
.36784 .53451 m .32326 .5278 L .36452 .51251 L p .442 .77 .997 r
F P
0 g
s
.40879 .5964 m .37212 .52492 L .38471 .57044 L 0 .126 .674 r
F
.41067 .60007 m .40879 .5964 L .38471 .57044 L F
.44721 .64503 m .37639 .56148 L .3971 .59163 L F
.37639 .56148 m .36299 .54567 L .36805 .55249 L F
.37639 .56148 m .36805 .55249 L .3971 .59163 L F
.36299 .54567 m .36298 .54569 L .3971 .59163 L F
.36481 .55655 m .35593 .55902 L .3648 .55656 L .668 .896 .979 r
F
.37541 .56382 m .37278 .55758 L .30183 .5568 L .206 0 0 r
F
.37871 .57165 m .37541 .56382 L .30368 .5687 L F
.46678 .61787 m .45952 .61136 L .39669 .57283 L .666 .35 .428 r
F
.41067 .60007 m .37216 .55613 L .41285 .60432 L 0 .126 .674 r
F
.37216 .55613 m .37246 .55683 L .44721 .64503 L F
.363 .54567 m .36299 .54567 L .44721 .64503 L F
.3815 .57828 m .37871 .57165 L .30368 .5687 L .206 0 0 r
F
.38714 .58102 m .37738 .56849 L .379 .57235 L 0 .126 .674 r
F
.3971 .59163 m .38924 .58204 L .38714 .58102 L F
.30183 .5568 m .37278 .55758 L .40879 .5964 L .666 .35 .428 r
F
.36363 .55389 m .36256 .54949 L .36255 .54966 L 0 .126 .674 r
F
.36363 .55389 m .36051 .54682 L .36185 .54692 L p .742 .932 .951 r
F P
0 g
s
.30183 .5568 m .32326 .5278 L .36051 .54682 L closepath p .626 .905 .984 r
F P
0 g
s
.39749 .57439 m .39669 .57283 L .32326 .5278 L .666 .35 .428 r
F
.46678 .61787 m .39669 .57283 L .39749 .57439 L F
.44106 .63476 m .41067 .60007 L .44721 .64503 L 0 .126 .674 r
F
.41067 .60007 m .41285 .60432 L .44721 .64503 L F
.47404 .6404 m .47422 .6408 L .47289 .64156 L .896 .804 .75 r
F
.39669 .57283 m .47177 .61887 L .49025 .6909 L .778 .506 .523 r
F
.46587 .66174 m .3869 .54428 L .46442 .66079 L 0 .126 .674 r
F
.46601 .66265 m .46442 .66079 L .46613 .66336 L F
.46587 .66174 m .46442 .66079 L .46601 .66265 L F
.46442 .66079 m .44339 .62918 L .45352 .64809 L F
.44339 .62918 m .3869 .54428 L .45352 .64809 L F
.4697 .66744 m .46587 .66174 L .46613 .66336 L F
.47923 .67832 m .46605 .66327 L .47965 .6796 L F
.46605 .66327 m .46442 .66141 L .46607 .66338 L F
.46605 .66327 m .46607 .66338 L .47965 .6796 L F
.4524 .68999 m .45243 .69017 L .43158 .70982 L .896 .804 .75 r
F
.46643 .66551 m .46442 .66141 L .46507 .66407 L 0 .126 .674 r
F
.47965 .6796 m .46607 .66338 L .46643 .66551 L F
.46607 .66338 m .46442 .66141 L .46643 .66551 L F
.49025 .6909 m .47923 .67832 L .47965 .6796 L F
.43535 .69795 m .49025 .6909 L .46657 .66615 L .592 .324 .479 r
F
.43158 .70982 m .31906 .81694 L .3174 .81737 L .896 .804 .75 r
F
.39235 .74174 m .46358 .70952 L .43535 .69795 L .592 .324 .479 r
F
.41967 .74017 m .46358 .70952 L .39235 .74174 L F
.46358 .70952 m .49025 .6909 L .43535 .69795 L F
.49001 .69062 m .45734 .64425 L .4697 .66744 L 0 .126 .674 r
F
.45734 .64425 m .3869 .54428 L .4697 .66744 L F
.46442 .66141 m .45963 .65595 L .46507 .66407 L F
.49008 .69065 m .36452 .51251 L .49001 .69062 L F
.45778 .65306 m .4301 .68535 L .49025 .6909 L .896 .804 .75 r
F
.4301 .68535 m .42514 .69114 L .43813 .69109 L F
.4301 .68535 m .43813 .69109 L .49025 .6909 L F
.49025 .6909 m .49008 .69065 L .49001 .69062 L 0 .126 .674 r
F
.47482 .67582 m .47267 .6687 L .49025 .6909 L .778 .506 .523 r
F
.30183 .5568 m .40879 .5964 L .32326 .5278 L .666 .35 .428 r
F
.32326 .5278 m .47267 .6687 L .47482 .67582 L .778 .506 .523 r
F
.40879 .5964 m .39749 .57439 L .32326 .5278 L .666 .35 .428 r
F
.44106 .63476 m .37219 .52476 L .37212 .52492 L 0 .126 .674 r
F
.44106 .63476 m .37212 .52492 L .41067 .60007 L F
.3869 .54428 m .36452 .51251 L .44106 .63476 L F
.32326 .5278 m .39669 .57283 L .47267 .6687 L .778 .506 .523 r
F
.44153 .62941 m .3869 .54428 L .42653 .61048 L 0 .126 .674 r
F
.33671 .80119 m .46406 .70971 L .33581 .7987 L .592 .324 .479 r
F
.46406 .70971 m .49025 .6909 L .46358 .70952 L F
.46406 .70971 m .46358 .70952 L .33581 .7987 L F
.42514 .69114 m .46057 .71196 L .49025 .6909 L .896 .804 .75 r
F
.33777 .79733 m .41967 .74017 L .39235 .74174 L .592 .324 .479 r
F
.3252 .80946 m .33671 .80119 L .33581 .7987 L F
.42514 .69114 m .32452 .80852 L .46057 .71196 L .896 .804 .75 r
F
.32567 .81132 m .46107 .71225 L .3252 .80946 L .592 .324 .479 r
F
.46107 .71225 m .49025 .6909 L .46068 .71214 L F
.46107 .71225 m .46068 .71214 L .3252 .80946 L F
.3174 .81737 m .32567 .81132 L .3252 .80946 L F
.32452 .80852 m .32567 .81132 L .46107 .71225 L .896 .804 .75 r
F
.46057 .71196 m .46107 .71225 L .49025 .6909 L F
.32452 .80852 m .46107 .71225 L .46057 .71196 L F
.49025 .6909 m .46107 .71225 L .46962 .70923 L .142 0 0 r
F
.45814 .71943 m .47152 .75188 L .48023 .72352 L .788 .566 .601 r
F
.45289 .72409 m .47152 .75188 L .45814 .71943 L F
.46706 .70579 m .49025 .6909 L .46107 .71225 L F
.46706 .70579 m .48023 .72352 L .49025 .6909 L F
.44858 .71765 m .46706 .70579 L .43422 .73027 L F
.46706 .70579 m .46107 .71225 L .42319 .73996 L F
.32452 .80852 m .3174 .81737 L .32567 .81132 L .896 .804 .75 r
F
.43422 .73027 m .42319 .73996 L .3174 .81737 L .788 .566 .601 r
F
.46706 .70579 m .42319 .73996 L .43422 .73027 L F
.47335 .72225 m .48023 .72352 L .47105 .71116 L F
.3174 .81737 m .35797 .81335 L p .39108 .84056 L .502 .011 .023 r
F P
0 g
s
.32603 .81514 m .31906 .81694 L .32881 .81601 L .363 0 0 r
F
.31906 .81694 m .3174 .81737 L .31832 .81728 L p F P
0 g
s
.31832 .81728 m .3959 .80959 L p .31906 .81694 L .363 0 0 r
F P
0 g
s
.37377 .82832 m .3959 .80959 L .3174 .81737 L closepath p .399 0 0 r
F P
0 g
s
.3174 .81737 m .37377 .82832 L .34389 .8204 L p 0 .509 .79 r
F P
0 g
s
.3217 .81787 m .3174 .81737 L .32112 .81828 L .142 0 0 r
F
.45289 .72409 m .3174 .81737 L .3217 .81787 L F
.35952 .80649 m .32603 .81514 L .35952 .80649 L .363 0 0 r
F
.32603 .81514 m .32881 .81601 L .34607 .81436 L F
.34426 .82061 m .32112 .81828 L .34131 .82323 L .142 0 0 r
F
.37377 .82832 m .34389 .8204 L p .3581 .82768 L .333 0 0 r
F P
0 g
s
.40082 .84605 m .3174 .81737 L p .40557 .84512 L .502 .011 .023 r
F P
0 g
s
.33286 .82116 m .35498 .82658 L p .38952 .84125 L 0 .405 .757 r
F P
0 g
s
.37377 .82832 m .39465 .84379 L p .38517 .8391 L .51 0 0 r
F P
0 g
s
.37195 .83255 m .37348 .82899 L p .38517 .8391 L .51 0 0 r
F P
0 g
s
.37348 .82899 m .37377 .82832 L p .38517 .8391 L .51 0 0 r
F P
0 g
s
.53206 .80384 m .52273 .81411 L .55235 .79435 L .453 .096 .269 r
F
.54155 .7994 m .53206 .80384 L .52091 .81099 L .156 0 0 r
F
.54155 .7994 m .52091 .81099 L .52199 .81161 L F
.5328 .82123 m .49051 .85571 L .53706 .81003 L F
.52369 .80841 m .52026 .8116 L .52529 .80466 L .453 .096 .269 r
F
.45209 .90572 m .45138 .90508 L .52071 .81088 L F
.52076 .81091 m .52071 .81088 L .52529 .80466 L F
.45209 .90572 m .52071 .81088 L .52076 .81091 L F
.51413 .8308 m .45209 .90572 L .52026 .8116 L F
.51413 .8308 m .52026 .8116 L .52091 .81099 L F
.52273 .81411 m .53844 .80643 L .55686 .79134 L F
.5543 .79343 m .54155 .7994 L .52199 .81161 L .156 0 0 r
F
.5543 .79343 m .52199 .81161 L .52318 .81229 L F
.52226 .81176 m .52091 .81099 L .52369 .80841 L .453 .096 .269 r
F
.51413 .8308 m .52091 .81099 L .52226 .81176 L F
.53211 .82302 m .53844 .80643 L .54887 .79788 L .156 0 0 r
F
.53335 .81807 m .5543 .79343 L .52318 .81229 L F
.53625 .81973 m .54159 .81195 L .53335 .81807 L F
.54159 .81195 m .5543 .79343 L .53335 .81807 L F
.55331 .78584 m .54634 .79664 L .55686 .79134 L .453 .096 .269 r
F
.55128 .78269 m .54634 .79664 L .55331 .78584 L F
.51972 .75755 m .54443 .64884 L p .51973 .7576 L .819 .694 .727 r
F P
0 g
s
.51292 .73137 m .54757 .76243 L .54763 .76222 L .783 .69 .761 r
F
.54757 .76243 m .55887 .77256 L .54763 .76222 L F
.54763 .76222 m .55887 .77256 L .55889 .77222 L F
.51292 .73137 m .54265 .77056 L .55887 .77256 L F
.54582 .72434 m .55869 .7538 L .55773 .74773 L F
.55934 .77262 m .56209 .71591 L .55845 .70312 L .411 .386 .721 r
F
.54265 .77056 m .55934 .77262 L p .51347 .77706 L .796 .591 .624 r
F P
0 g
s
.55934 .77286 m .55934 .77262 L .55931 .77279 L .411 .386 .721 r
F
.55934 .77262 m .55941 .7728 L .51347 .77706 L .796 .591 .624 r
F
.54121 .71901 m .54578 .7243 L .53191 .74748 L .683 .556 .704 r
F
.55756 .77006 m .55879 .77183 L .55796 .76354 L .411 .386 .721 r
F
.55701 .76396 m .55756 .77006 L p .55796 .76354 L F P
0 g
s
.51292 .73137 m .55934 .77262 L .55931 .77019 L .783 .69 .761 r
F
.53519 .80183 m .53749 .79787 L .53588 .79964 L .908 .809 .739 r
F
.51347 .77706 m .52744 .77592 L .47226 .84123 L .796 .591 .624 r
F
.52744 .77592 m .47264 .84093 L .47226 .84123 L F
.51742 .77372 m .52419 .79196 L .55572 .77512 L .082 0 .156 r
F
.55284 .68342 m .55845 .70312 L .54578 .7243 L .683 .556 .704 r
F
.54578 .7243 m .53199 .74733 L .55931 .77019 L .783 .69 .761 r
F
.54578 .7243 m .5268 .76167 L .52893 .75246 L .683 .556 .704 r
F
.55845 .70312 m .54653 .72517 L .54578 .7243 L F
.57558 .67449 m .55882 .70444 L .55845 .70312 L F
.54582 .72434 m .55773 .74773 L .55587 .73598 L .783 .69 .761 r
F
.54578 .7243 m .55931 .77019 L .55927 .76741 L F
.55882 .70444 m .5268 .76167 L .55845 .70312 L .683 .556 .704 r
F
.55845 .70312 m .56257 .70616 L .55836 .6957 L .411 .386 .721 r
F
.56209 .71591 m .56257 .70616 L .55845 .70312 L F
.55934 .77262 m .5602 .77272 L p .55941 .7728 L .796 .591 .624 r
F P
0 g
s
.55934 .77262 m .55962 .77303 L .5602 .77272 L .082 0 .156 r
F
.55961 .77334 m .56257 .70616 L p .55934 .77262 L .411 .386 .721 r
F P
0 g
s
.55587 .73598 m .55962 .75965 L .56213 .71605 L .908 .809 .739 r
F
.55587 .73598 m .55842 .74908 L .55613 .73628 L .783 .69 .761 r
F
.55773 .74773 m .55842 .74908 L .55587 .73598 L F
.55989 .77562 m .5627 .77303 L .56021 .77492 L p .885 .968 .839 r
F P
0 g
s
.5627 .77303 m .56023 .77512 L .6493 .80083 L .453 .096 .269 r
F
.5627 .77303 m .56121 .77532 L .56023 .77512 L F
.55953 .77308 m .56121 .77532 L .55966 .77308 L .082 0 .156 r
F
.51742 .77372 m .55572 .77512 L .55953 .77308 L F
.53519 .80183 m .54113 .78291 L .53829 .78443 L .908 .809 .739 r
F
.55128 .78269 m .53206 .80384 L .54634 .79664 L .453 .096 .269 r
F
.53206 .80384 m .55235 .79435 L .55686 .79134 L F
.55272 .78147 m .55703 .77783 L .55876 .77445 L .908 .809 .739 r
F
.53167 .7644 m .53277 .75753 L .53808 .76799 L .819 .694 .727 r
F
.53277 .75753 m .53831 .76483 L .53808 .76799 L F
.53808 .76799 m .53831 .76483 L .5401 .76719 L F
.54265 .77056 m .55934 .77262 L p .5268 .76167 L .771 .721 .806 r
F P
0 g
s
.55934 .77262 m .55942 .772 L .5268 .76167 L .771 .721 .806 r
F
.5268 .76167 m .55942 .772 L .55978 .76944 L F
.5268 .76167 m .55978 .76944 L .55887 .76226 L F
.54265 .77056 m .52926 .77354 L .55953 .77308 L .082 0 .156 r
F
.55937 .77359 m .55962 .77303 L .55942 .77314 L .908 .809 .739 r
F
.55956 .77306 m .55953 .77308 L .55966 .77308 L .082 0 .156 r
F
.54265 .77056 m .55953 .77308 L .55956 .77306 L F
.53749 .79787 m .55876 .77445 L .55882 .77346 L .908 .809 .739 r
F
.54265 .77056 m .55956 .77306 L .55934 .77262 L .082 0 .156 r
F
.55956 .77339 m .55962 .77303 L .55937 .77359 L .908 .809 .739 r
F
.55956 .77306 m .55966 .77308 L .55962 .77303 L .082 0 .156 r
F
.55956 .77306 m .55962 .77303 L .55934 .77262 L F
.55962 .75965 m .56008 .7626 L .56213 .71605 L .908 .809 .739 r
F
.56557 .72812 m .55613 .73628 L p .56078 .76229 L .771 .721 .806 r
F P
0 g
s
.55921 .76299 m .56117 .76212 L .55779 .73803 L .783 .69 .761 r
F
.55874 .76116 m .55928 .76546 L .55962 .75965 L .908 .809 .739 r
F
.55564 .73671 m .55962 .75965 L .55587 .73598 L F
.55564 .73671 m .5268 .76167 L p .55887 .76226 L .771 .721 .806 r
F P
0 g
s
.54113 .78291 m .55869 .76081 L .55564 .73671 L .908 .809 .739 r
F
.55869 .76081 m .55962 .75965 L .55564 .73671 L F
.55773 .74773 m .55869 .7538 L .55842 .74908 L .783 .69 .761 r
F
.55613 .73628 m .55564 .73671 L p .56078 .76229 L .771 .721 .806 r
F P
0 g
s
.54798 .77925 m .55962 .75965 L .54113 .78291 L .908 .809 .739 r
F
.53749 .79787 m .55962 .75965 L .53588 .79964 L F
.55928 .76546 m .56008 .7626 L .55962 .75965 L F
.55887 .76226 m .56078 .76229 L .55564 .73671 L .771 .721 .806 r
F
.55882 .70444 m .56213 .71605 L .5268 .76167 L .683 .556 .704 r
F
.56557 .72812 m .55613 .73628 L p .56213 .71605 L F P
0 g
s
.56213 .71605 m .55613 .73628 L .55587 .73598 L .683 .556 .704 r
F
.5561 .73608 m .55613 .73628 L .55779 .73803 L .783 .69 .761 r
F
.55613 .73628 m .55842 .74908 L .5578 .73821 L F
.55613 .73628 m .5578 .73821 L .55779 .73803 L F
.55613 .73628 m .55564 .73671 L p .55587 .73598 L .683 .556 .704 r
F P
0 g
s
.55564 .73671 m .5268 .76167 L p .56213 .71605 L .683 .556 .704 r
F P
0 g
s
.55587 .73598 m .56213 .71605 L .55166 .70938 L .908 .809 .739 r
F
.55284 .68342 m .54578 .7243 L .54121 .71901 L .683 .556 .704 r
F
.54574 .7242 m .54582 .72434 L .55584 .73579 L .783 .69 .761 r
F
.55584 .73579 m .55584 .73579 L .5561 .73608 L F
.54574 .7242 m .55584 .73579 L .55584 .73579 L F
.54582 .72434 m .55613 .73628 L .5561 .73608 L F
.52529 .80466 m .52 .81184 L .50224 .82414 L .453 .096 .269 r
F
.47195 .84175 m .49189 .8279 L .53149 .79722 L .885 .968 .839 r
F
.52369 .80841 m .53608 .79686 L .53829 .78443 L .908 .809 .739 r
F
.52369 .80841 m .53829 .78443 L .52907 .78935 L F
.54653 .72517 m .5268 .76167 L .54578 .7243 L .683 .556 .704 r
F
.54574 .7242 m .54578 .7243 L .54582 .72434 L .783 .69 .761 r
F
.52281 .70365 m .52039 .71011 L p .52931 .70232 L .41 .291 .606 r
F P
0 g
s
.52722 .67573 m .51865 .72081 L .51532 .72378 L .657 .519 .684 r
F
.52722 .67573 m .51532 .72378 L .51738 .70163 L F
.52483 .71281 m .51518 .72529 L p .52325 .71985 L .682 .555 .703 r
F P
0 g
s
.52931 .70232 m .54395 .64927 L .52281 .70365 L .41 .291 .606 r
F
.54281 .65029 m .52281 .70365 L p .54395 .64927 L F P
0 g
s
.52483 .71281 m .51865 .72081 L p .52722 .67573 L .657 .519 .684 r
F P
0 g
s
.53384 .65833 m .52914 .68677 L .52722 .67573 L .657 .519 .684 r
F
.52914 .68677 m .52483 .71281 L .52722 .67573 L F
.54281 .65029 m .52914 .68677 L p .52321 .65256 L .566 .456 .688 r
F P
0 g
s
.53763 .71488 m .53941 .71692 L .54382 .68823 L .682 .555 .703 r
F
.52828 .6739 m .53199 .74733 L .54578 .7243 L .783 .69 .761 r
F
.46962 .70923 m .43597 .73314 L .45289 .72409 L .142 0 0 r
F
.46107 .71225 m .42319 .73996 L .46962 .70923 L F
.42319 .73996 m .3174 .81737 L .43597 .73314 L F
.42319 .73996 m .43597 .73314 L .46962 .70923 L F
.46772 .7075 m .46781 .70679 L .46706 .70579 L .788 .566 .601 r
F
.47335 .72225 m .46781 .70679 L .46772 .7075 L F
.47335 .72225 m .47105 .71116 L .46781 .70679 L F
.44858 .71765 m .47335 .72225 L .46706 .70579 L F
.47152 .75188 m .47927 .76343 L .49025 .6909 L F
.47767 .77397 m .48612 .75856 L .49025 .6909 L F
.48612 .75856 m .46498 .71578 L .49025 .6909 L .63 .528 .72 r
F
.46531 .71545 m .45289 .72409 L .46085 .71984 L .142 0 0 r
F
.47947 .70532 m .46962 .70923 L .47904 .7059 L F
.49025 .6909 m .47125 .70778 L .47947 .70532 L F
.47125 .70778 m .46962 .70923 L .47947 .70532 L F
.46962 .70923 m .45289 .72409 L .46531 .71545 L F
.47276 .70812 m .46531 .71545 L .47904 .7059 L F
.46962 .70923 m .46531 .71545 L .47276 .70812 L F
.48251 .76644 m .46085 .71984 L .48612 .75856 L .63 .528 .72 r
F
.32326 .5278 m .35749 .54527 L p .36375 .54369 L .244 .708 .948 r
F P
0 g
s
.36784 .53451 m .32326 .5278 L p .36375 .54369 L .244 .708 .948 r
F P
0 g
s
.36275 .54592 m .36375 .54369 L .35749 .54527 L .244 .708 .948 r
F
.363 .54567 m .36291 .54557 L .36299 .54567 L 0 .126 .674 r
F
.36291 .54557 m .36291 .54557 L .36299 .54567 L F
.37216 .55613 m .363 .54567 L .37246 .55683 L F
.35749 .54527 m .36051 .54682 L .36307 .54596 L p .244 .708 .948 r
F P
0 g
s
.36275 .54592 m .36275 .546 L p .36307 .54596 L .347 .743 .984 r
F P
0 g
s
.36051 .54682 m .36268 .54609 L p .36214 .5468 L .249 .741 .916 r
F P
0 g
s
.36268 .54609 m .36307 .54596 L p .36214 .5468 L .249 .741 .916 r
F P
0 g
s
.36299 .54567 m .36278 .54542 L .36298 .54569 L 0 .126 .674 r
F
.36212 .54683 m .36051 .54682 L .36185 .54692 L p .112 .66 .815 r
F P
0 g
s
.36346 .54634 m .36278 .54542 L .36272 .54661 L 0 .126 .674 r
F
.36346 .54634 m .36272 .54661 L .36256 .54949 L F
.32326 .5278 m .46285 .66413 L .36452 .51251 L .778 .506 .523 r
F
.46085 .71984 m .36452 .51251 L .46498 .71578 L .63 .528 .72 r
F
.46085 .71984 m .46498 .71578 L .48612 .75856 L F
.46285 .66413 m .49025 .6909 L .46451 .65437 L .778 .506 .523 r
F
.46202 .66117 m .46451 .65437 L .45723 .64405 L F
.46285 .66413 m .46451 .65437 L .46202 .66117 L F
.46285 .66413 m .45723 .64405 L .36452 .51251 L F
.46498 .71578 m .36452 .51251 L .49025 .6909 L .63 .528 .72 r
F
.49025 .6909 m .47947 .70532 L .49482 .73098 L .142 0 0 r
F
.36452 .51251 m .49025 .6909 L .47953 .7053 L .895 .6 .481 r
F
.36452 .51251 m .47953 .7053 L .46973 .65898 L F
.47953 .7053 m .49025 .6909 L .49872 .73749 L F
.47953 .7053 m .48801 .71952 L .48337 .70416 L F
.47953 .7053 m .48337 .70416 L .46973 .65898 L F
.47904 .7059 m .46531 .71545 L .47378 .71293 L .142 0 0 r
F
.46531 .71545 m .46085 .71984 L .47378 .71293 L F
.48828 .70263 m .4948 .72225 L .49494 .72228 L .506 .498 .782 r
F
.47631 .6673 m .48821 .70266 L .48828 .70263 L F
.48821 .70266 m .4948 .72225 L .48828 .70263 L F
.46873 .69994 m .46481 .70338 L .46647 .71684 L .63 .528 .72 r
F
.46883 .71557 m .46647 .71684 L .46898 .73732 L F
.46873 .69994 m .46647 .71684 L .46883 .71557 L F
.47631 .6673 m .48338 .68818 L .48399 .68754 L .506 .498 .782 r
F
.48251 .67453 m .49745 .72303 L .50251 .72453 L F
.49523 .69064 m .50432 .72907 L .50808 .72023 L F
.4818 .61187 m .51915 .62911 L p .51929 .63792 L .566 .456 .688 r
F P
0 g
s
.51783 .64964 m .48841 .56222 L .48483 .58915 L p .348 .4 .774 r
F P
0 g
s
.48483 .58915 m .4818 .61187 L .49808 .62894 L p .348 .4 .774 r
F P
0 g
s
.49808 .62894 m .51783 .64964 L p .48483 .58915 L .348 .4 .774 r
F P
0 g
s
.48841 .56222 m .54463 .57473 L .544 .57417 L p .427 .617 .93 r
F P
0 g
s
.48841 .56222 m .544 .57417 L .54333 .57393 L .427 .617 .93 r
F
.48595 .55469 m .48841 .56222 L p .54386 .57404 L F P
0 g
s
.47177 .61887 m .47728 .63032 L .49025 .6909 L .778 .506 .523 r
F
.48948 .68363 m .4818 .61187 L p .48843 .68006 L 0 0 .408 r
F P
0 g
s
.46475 .65204 m .48426 .61981 L .46017 .64567 L .63 .528 .72 r
F
.48841 .56222 m .54463 .57473 L .51783 .64964 L closepath p .55 .529 .784 r
F P
0 g
s
.48426 .61981 m .51745 .56501 L .48088 .6165 L .63 .528 .72 r
F
.48426 .61981 m .48088 .6165 L .46017 .64567 L F
.47293 .66239 m .51745 .56501 L .46475 .65204 L F
.49025 .6909 m .48948 .68363 L p .48843 .68006 L 0 0 .408 r
F P
0 g
s
.49771 .69224 m .51745 .56501 L .47293 .66239 L .63 .528 .72 r
F
.48251 .67453 m .47293 .66239 L .47264 .66302 L F
.49771 .69224 m .47293 .66239 L .48251 .67453 L F
.48251 .67453 m .50432 .72907 L .49523 .69064 L .506 .498 .782 r
F
.47631 .6673 m .49745 .72303 L .48251 .67453 L F
.48954 .70219 m .49911 .73462 L .5019 .73476 L F
.48828 .70263 m .49911 .73462 L .48954 .70219 L F
.49494 .72228 m .49725 .72935 L .49715 .72881 L F
.4948 .72225 m .49893 .73451 L .49494 .72228 L F
.49482 .73098 m .47378 .71293 L .4966 .74662 L .142 0 0 r
F
.47947 .70532 m .47378 .71293 L .49482 .73098 L F
.4955 .73208 m .49593 .73238 L .49191 .72112 L .895 .6 .481 r
F
.4955 .73208 m .49191 .72112 L .49159 .72099 L F
.48801 .71952 m .4955 .73208 L .49159 .72099 L F
.47264 .66302 m .5002 .73828 L .47631 .6673 L .506 .498 .782 r
F
.49629 .73341 m .49733 .73363 L .47103 .66078 L .895 .6 .481 r
F
.47264 .66302 m .47293 .66239 L .46475 .65204 L .63 .528 .72 r
F
.48705 .55805 m .48841 .56222 L .47799 .55435 L p .43 .62 .931 r
F P
0 g
s
.47799 .55435 m .47228 .55005 L p .48705 .55805 L .43 .62 .931 r
F P
0 g
s
.48595 .55469 m .48705 .55805 L p .47228 .55005 L .43 .62 .931 r
F P
0 g
s
.43595 .5467 m .48841 .56222 L .47228 .55005 L p .28 .563 .932 r
F P
0 g
s
.46442 .54932 m .37937 .51767 L .39778 .52843 L .217 .596 .948 r
F
.47262 .55008 m .37937 .51767 L .46442 .54932 L F
.47195 .61734 m .4704 .61601 L .47278 .62095 L 0 .108 .634 r
F
.44149 .57038 m .44397 .56802 L p .46433 .60248 L .897 .477 .142 r
F P
0 g
s
.44149 .57038 m .46271 .59222 L p .47128 .61184 L 0 .217 .735 r
F P
0 g
s
.4628 .60231 m .44149 .57038 L p .46433 .60248 L .897 .477 .142 r
F P
0 g
s
.46916 .61184 m .44149 .57038 L p .47128 .61184 L 0 .217 .735 r
F P
0 g
s
.44935 .57279 m .43595 .5467 L .46372 .58616 L p 0 .019 .579 r
F P
0 g
s
.46372 .58616 m .4818 .61187 L p .44935 .57279 L 0 .019 .579 r
F P
0 g
s
.44149 .57038 m .44271 .56922 L p .44225 .56897 L .52 0 0 r
F P
0 g
s
.43446 .56479 m .44149 .57038 L p .42016 .5551 L .494 0 0 r
F P
0 g
s
.45385 .58154 m .43595 .5467 L .42263 .54687 L p 0 .327 .811 r
F P
0 g
s
.45366 .5814 m .45385 .58154 L p .42263 .54687 L 0 .327 .811 r
F P
0 g
s
.46703 .59584 m .45385 .58154 L .45422 .58241 L p 0 .108 .634 r
F P
0 g
s
.4083 .54652 m .40753 .54663 L .39886 .54181 L .494 0 0 r
F
.40753 .54663 m .40631 .5468 L .39898 .54189 L F
.40753 .54663 m .39898 .54189 L .39886 .54181 L F
.40901 .54642 m .41512 .5454 L p .40913 .5465 L .729 .339 .311 r
F P
0 g
s
.40495 .54711 m .4159 .55481 L p .42693 .56074 L 0 .327 .811 r
F P
0 g
s
.39877 .54182 m .39862 .54169 L p .39878 .54178 L 0 .474 .853 r
F P
0 g
s
.39878 .54178 m .39886 .54181 L p .39898 .54189 L .494 0 0 r
F P
0 g
s
.40047 .52971 m .43595 .5467 L p .39877 .54182 L 0 .474 .853 r
F P
0 g
s
.44149 .57038 m .38804 .53755 L .39878 .54178 L p .494 0 0 r
F P
0 g
s
.39898 .54189 m .44149 .57038 L .39878 .54178 L .494 0 0 r
F
.36452 .51251 m .40047 .52971 L p .39878 .54178 L 0 .474 .853 r
F P
0 g
s
.39862 .54169 m .36452 .51251 L p .39878 .54178 L 0 .474 .853 r
F P
0 g
s
.43595 .5467 m .40831 .54706 L p .39888 .54184 L 0 .474 .853 r
F P
0 g
s
.38804 .53755 m .43595 .5467 L .44149 .57038 L closepath p .229 .532 .921 r
F P
0 g
s
.38804 .53755 m .43595 .5467 L .36452 .51251 L closepath p .118 .551 .918 r
F P
0 g
s
.44149 .57038 m .4818 .61187 L .43595 .5467 L closepath p 0 .166 .705 r
F P
0 g
s
.43595 .5467 m .48841 .56222 L .4818 .61187 L closepath p .457 .505 .82 r
F P
0 g
s
.45625 .6402 m .51445 .56923 L .4334 .53616 L .63 .528 .72 r
F
.45809 .6486 m .46017 .64567 L .45625 .6402 L F
.48171 .61225 m .48186 .61241 L .4818 .61187 L 0 0 .408 r
F
.46017 .64567 m .51445 .56923 L .45625 .6402 L .63 .528 .72 r
F
.49872 .73749 m .5002 .73828 L .47264 .66302 L .895 .6 .481 r
F
.43975 .67443 m .4334 .53616 L .41374 .61844 L .63 .528 .72 r
F
.45809 .6486 m .4334 .53616 L .43975 .67443 L F
.37981 .51776 m .36452 .51251 L p .37937 .51767 L .217 .596 .948 r
F P
0 g
s
.36452 .51251 m .37238 .51627 L p .37937 .51767 L .217 .596 .948 r
F P
0 g
s
.37238 .51627 m .39778 .52843 L p .37937 .51767 L .217 .596 .948 r
F P
0 g
s
.39659 .5487 m .39709 .54864 L .39684 .54865 L .112 .66 .815 r
F
.41374 .61844 m .4334 .53616 L .36452 .51251 L .63 .528 .72 r
F
.47103 .66078 m .47264 .66302 L .4156 .50726 L .895 .6 .481 r
F
.49872 .73749 m .47264 .66302 L .47103 .66078 L F
.46973 .65898 m .47103 .66078 L .4156 .50726 L F
.49629 .73341 m .47103 .66078 L .46973 .65898 L F
.49523 .69064 m .50808 .72023 L .50582 .70405 L .506 .498 .782 r
F
.50808 .72023 m .51292 .73137 L .50928 .71738 L F
.50808 .72023 m .50928 .71738 L .50582 .70405 L F
.52245 .65711 m .51919 .69468 L .52828 .6739 L .783 .69 .761 r
F
.51581 .68077 m .51919 .69468 L .52245 .65711 L F
.53158 .66603 m .53756 .70063 L .53575 .67011 L F
.52245 .65711 m .52828 .6739 L .53158 .66603 L F
.52828 .6739 m .53756 .70063 L .53158 .66603 L F
.54458 .5769 m .54466 .57693 L .54463 .57473 L .574 .555 .795 r
F
.54281 .65029 m .54466 .57693 L .54458 .5769 L F
.54443 .64884 m .54609 .64154 L p .54443 .64885 L .819 .694 .727 r
F P
0 g
s
.54281 .65029 m .54571 .64769 L .54466 .57693 L .574 .555 .795 r
F
.54753 .63765 m .54609 .64154 L p .55544 .64099 L .411 .386 .721 r
F P
0 g
s
.55311 .63987 m .54463 .57473 L p .54575 .64995 L .574 .555 .795 r
F P
0 g
s
.54463 .57473 m .51783 .64964 L .52321 .65256 L p .574 .555 .795 r
F P
0 g
s
.55845 .70312 m .55836 .6957 L .55145 .67853 L .411 .386 .721 r
F
.56257 .70616 m .56595 .6292 L p .55556 .68751 L F P
0 g
s
.56666 .61255 m .56749 .61645 L p .56661 .61254 L .751 .554 .629 r
F P
0 g
s
.55879 .62999 m .55834 .63052 L .55996 .6283 L .91 .982 .731 r
F
.55869 .62985 m .55808 .63082 L .56062 .62608 L F
.55818 .6307 m .55962 .63052 L .55886 .62993 L p .772 .532 .573 r
F P
0 g
s
.55818 .6307 m .55897 .62979 L .55962 .63052 L .218 .048 .425 r
F
.55934 .62919 m .55962 .63052 L .55886 .62993 L p .712 .562 .682 r
F P
0 g
s
.57184 .57962 m .58863 .58263 L p .55311 .63987 L .564 .548 .795 r
F P
0 g
s
.58863 .58263 m .598 .5989 L .55311 .63987 L .564 .548 .795 r
F
.56595 .6292 m .56801 .58237 L p .55556 .68751 L .411 .386 .721 r
F P
0 g
s
.55025 .66723 m .55715 .67097 L .54382 .68823 L p .657 .519 .684 r
F P
0 g
s
.55556 .68751 m .56801 .58237 L .54913 .6704 L .411 .386 .721 r
F
.56257 .70616 m .54913 .6704 L .55145 .67853 L F
.54981 .69765 m .55166 .70938 L .56595 .6292 L .908 .809 .739 r
F
.53756 .70063 m .54988 .69811 L .54813 .68701 L .783 .69 .761 r
F
.53063 .77095 m .53167 .7644 L .53808 .76799 L .819 .694 .727 r
F
.52533 .77113 m .52926 .77354 L .54265 .77056 L .082 0 .156 r
F
.53756 .70063 m .54574 .7242 L .55073 .70347 L .783 .69 .761 r
F
.54988 .69811 m .55073 .70347 L .55213 .69765 L F
.53756 .70063 m .55073 .70347 L .54988 .69811 L F
.52686 .72621 m .51928 .73669 L .53199 .74733 L F
.54463 .57473 m .54663 .57509 L p .55127 .6215 L .564 .548 .795 r
F P
0 g
s
.55311 .63987 m .55084 .62249 L p .55127 .6215 L .564 .548 .795 r
F P
0 g
s
.55084 .62249 m .54463 .57473 L p .55127 .6215 L .564 .548 .795 r
F P
0 g
s
.50569 .64075 m .54494 .57703 L .51714 .567 L .63 .528 .72 r
F
.51518 .72551 m .52325 .71985 L .51518 .72529 L .682 .555 .703 r
F
.51865 .72081 m .51518 .72529 L p .51532 .72378 L .657 .519 .684 r
F P
0 g
s
.47378 .71293 m .49354 .74897 L .4966 .74662 L .142 0 0 r
F
.49491 .75026 m .4988 .74132 L .49268 .74816 L .63 .528 .72 r
F
.51522 .72405 m .51532 .72378 L p .51522 .72422 L .894 .733 .676 r
F P
0 g
s
.51364 .70737 m .51292 .73137 L .51928 .73669 L .783 .69 .761 r
F
.51148 .69615 m .51209 .71093 L .51364 .70737 L F
.51209 .71093 m .51292 .73137 L .51364 .70737 L F
.49854 .74192 m .4949 .75028 L .49489 .75029 L .908 .809 .739 r
F
.50873 .70595 m .51025 .71514 L .51148 .69615 L .783 .69 .761 r
F
.51025 .71514 m .51292 .73137 L .51209 .71093 L F
.51025 .71514 m .51209 .71093 L .51148 .69615 L F
.50582 .70405 m .50928 .71738 L .50836 .70727 L .506 .498 .782 r
F
.50928 .71738 m .51292 .73137 L .50997 .71577 L F
.50928 .71738 m .50997 .71577 L .50836 .70727 L F
.49911 .73462 m .50038 .73834 L .50139 .73596 L F
.49911 .73462 m .50139 .73596 L .5019 .73476 L F
.50002 .74289 m .50297 .73406 L .50074 .74495 L .597 .402 .587 r
F
.49745 .72303 m .50375 .73962 L .50251 .72453 L .506 .498 .782 r
F
.49911 .73462 m .5002 .73828 L .50038 .73834 L F
.49893 .73451 m .5002 .73828 L .49911 .73462 L F
.49751 .69352 m .51521 .65004 L .50569 .64075 L .63 .528 .72 r
F
.49806 .69422 m .51559 .65041 L .49751 .69352 L F
.51559 .65041 m .54494 .57703 L .51521 .65004 L F
.51559 .65041 m .51521 .65004 L .49751 .69352 L F
.5025 .70459 m .54494 .57703 L .49698 .69691 L F
.50836 .70727 m .50997 .71577 L .50851 .70676 L .783 .69 .761 r
F
.50997 .71577 m .51025 .71514 L .50873 .70595 L F
.49725 .72935 m .49893 .73451 L .49715 .72881 L .506 .498 .782 r
F
.49715 .72881 m .49893 .73451 L .49911 .73462 L F
.49629 .73341 m .49872 .73749 L .49733 .73363 L .895 .6 .481 r
F
.49268 .74816 m .50367 .72396 L .50725 .71121 L .63 .528 .72 r
F
.50496 .70801 m .50725 .71121 L .54425 .57949 L F
.49268 .74816 m .50725 .71121 L .50496 .70801 L F
.4955 .73208 m .49629 .73341 L .49593 .73238 L .895 .6 .481 r
F
.54452 .57439 m .54463 .57473 L .54811 .57536 L p .438 .648 .947 r
F P
0 g
s
.49283 .74767 m .49879 .72819 L .48993 .74238 L .63 .528 .72 r
F
.49879 .72819 m .5457 .57477 L .49301 .73312 L F
.49879 .72819 m .49301 .73312 L .48993 .74238 L F
.55689 .57936 m .56801 .58237 L .54571 .57471 L p .217 .596 .948 r
F P
0 g
s
.55818 .58118 m .56801 .58237 L .54886 .57579 L .63 .528 .72 r
F
.54663 .57509 m .54886 .57579 L .55181 .62024 L .564 .548 .795 r
F
.54663 .57509 m .55181 .62024 L .55127 .6215 L F
.54886 .57579 m .56645 .58595 L .55181 .62024 L F
.51581 .68077 m .51698 .69973 L .51919 .69468 L .783 .69 .761 r
F
.51148 .69615 m .51364 .70737 L .51581 .68077 L F
.51364 .70737 m .51928 .73669 L .51698 .69973 L F
.51364 .70737 m .51698 .69973 L .51581 .68077 L F
.5126 .70961 m .56801 .58237 L .51103 .70778 L .63 .528 .72 r
F
.50997 .71577 m .50873 .70595 L .50851 .70676 L .783 .69 .761 r
F
.5126 .70961 m .51103 .70778 L .50367 .72396 L .63 .528 .72 r
F
.5126 .70961 m .50367 .72396 L .50187 .73037 L F
.4988 .74132 m .51259 .70964 L .50187 .73037 L F
.4988 .74132 m .50187 .73037 L .49268 .74816 L F
.53078 .66675 m .51184 .71137 L .49854 .74192 L .908 .809 .739 r
F
.49576 .74828 m .49854 .74192 L .49489 .75029 L F
.53078 .66675 m .49854 .74192 L .49576 .74828 L F
.5664 .58592 m .56801 .58237 L .55818 .58118 L .63 .528 .72 r
F
.54886 .57579 m .5682 .58186 L .56645 .58595 L .564 .548 .795 r
F
.4988 .74132 m .51259 .70964 L .4988 .74132 L .63 .528 .72 r
F
.508 .72018 m .4988 .74132 L .49871 .74152 L .908 .809 .739 r
F
.5675 .58352 m .53167 .66583 L .53167 .66581 L F
.56679 .58515 m .53164 .66588 L .53167 .66583 L F
.50367 .72396 m .5664 .58592 L .54425 .57949 L .63 .528 .72 r
F
.51521 .65004 m .54494 .57703 L .50569 .64075 L F
.54452 .57439 m .54463 .57473 L .544 .57417 L p .363 .591 .932 r
F P
0 g
s
.54494 .57703 m .54559 .57474 L .51714 .567 L .63 .528 .72 r
F
.5457 .57477 m .54499 .57452 L .51714 .567 L F
.51714 .567 m .54452 .57439 L .51745 .56501 L F
.54452 .57439 m .5441 .57421 L .51745 .56501 L F
.54386 .57404 m .47073 .50819 L p .54446 .57419 L .363 .591 .932 r
F P
0 g
s
.54499 .57452 m .54012 .57279 L .51745 .56501 L .63 .528 .72 r
F
.51759 .55096 m .51614 .5505 L p .51785 .55204 L .602 .275 .388 r
F P
0 g
s
.54386 .57404 m .47073 .50819 L .48555 .55346 L p .427 .617 .93 r
F P
0 g
s
.54012 .57279 m .54386 .57404 L .48555 .55346 L .427 .617 .93 r
F
.56679 .58516 m .53164 .66588 L .56679 .58515 L .908 .809 .739 r
F
.53164 .66588 m .53164 .66588 L .56679 .58515 L F
.55544 .64099 m .56349 .60343 L .55307 .63999 L .411 .386 .721 r
F
.55181 .62024 m .56741 .59123 L .55311 .63987 L .564 .548 .795 r
F
.56741 .59123 m .56752 .5935 L .55311 .63987 L F
.56717 .58636 m .56752 .5935 L .56801 .58237 L .908 .809 .739 r
F
.56645 .58595 m .56935 .58762 L .55181 .62024 L .564 .548 .795 r
F
.56679 .58516 m .53158 .66603 L .53164 .66588 L .908 .809 .739 r
F
.56679 .58516 m .53158 .66603 L .56679 .58516 L F
.56679 .58515 m .53167 .66581 L .53168 .6658 L F
.56679 .58515 m .53167 .66581 L .56679 .58515 L F
.55127 .6215 m .55181 .62024 L .55311 .63987 L .564 .548 .795 r
F
.56679 .58516 m .56645 .58595 L .53158 .66603 L .908 .809 .739 r
F
.52245 .65711 m .53158 .66603 L .52895 .56581 L .783 .69 .761 r
F
.53158 .66603 m .53502 .65784 L .52847 .54749 L F
.5675 .58352 m .51269 .70941 L .5127 .70939 L .908 .809 .739 r
F
.53569 .65625 m .54366 .63729 L .53113 .54803 L .783 .69 .761 r
F
.53569 .65625 m .53113 .54803 L .53526 .65726 L F
.53502 .65784 m .53113 .54803 L .52847 .54749 L F
.53526 .65726 m .53113 .54803 L .53502 .65784 L F
.53078 .66675 m .55455 .61288 L .51184 .71137 L .908 .809 .739 r
F
.55455 .61288 m .5675 .58352 L .55216 .61875 L F
.55455 .61288 m .55216 .61875 L .51184 .71137 L F
.5664 .58592 m .55818 .58118 L .54425 .57949 L .63 .528 .72 r
F
.54425 .57949 m .55818 .58118 L .54571 .57471 L F
.55818 .58118 m .54886 .57579 L .54571 .57471 L F
.54886 .57579 m .57184 .57962 L .57088 .5827 L .564 .548 .795 r
F
.54811 .57536 m .57184 .57962 L p .54886 .57579 L F P
0 g
s
.53805 .52008 m .53695 .53046 L .53732 .52478 L .751 .554 .629 r
F
.54465 .55957 m .55107 .55639 L p .53772 .52319 L .594 .413 .606 r
F P
0 g
s
.53695 .53046 m .54465 .55957 L p .53772 .52319 L .594 .413 .606 r
F P
0 g
s
.55918 .55238 m .54176 .44706 L .56566 .54071 L 0 0 .271 r
F
.55233 .56469 m .55027 .54606 L .55918 .55238 L F
.54062 .4524 m .53614 .46923 L .53431 .45659 L 0 0 .185 r
F
.55027 .54606 m .53432 .40204 L .55918 .55238 L 0 0 .271 r
F
.56207 .55444 m .57234 .54588 L .56723 .55811 L .683 .619 .778 r
F
.5516 .56317 m .54465 .55957 L .55107 .55639 L p F P
0 g
s
.54977 .54781 m .5476 .53349 L .54536 .51079 L 0 0 .271 r
F
.61136 .58671 m .52658 .51559 L .54446 .57419 L p .438 .648 .947 r
F P
0 g
s
.54527 .57453 m .61136 .58671 L .54446 .57419 L .438 .648 .947 r
F
.54811 .57536 m .61136 .58671 L p .54452 .57439 L F P
0 g
s
.54176 .44706 m .54634 .45523 L .56566 .54071 L 0 0 .271 r
F
.52658 .51559 m .57542 .53347 L .61136 .58671 L closepath p .067 .459 .884 r
F P
0 g
s
.52658 .51559 m .56129 .59628 L .57542 .53347 L .719 .694 .825 r
F
.5675 .58352 m .56801 .58237 L .56714 .58436 L .908 .809 .739 r
F
.56708 .58448 m .56717 .58636 L .56801 .58237 L F
.56645 .58595 m .57088 .5827 L .56935 .58762 L .564 .548 .795 r
F
.5675 .58352 m .56679 .58516 L .56679 .58515 L .908 .809 .739 r
F
.5675 .58352 m .56679 .58516 L .56679 .58516 L F
.5675 .58352 m .56679 .58515 L .56679 .58515 L F
.5675 .58352 m .56714 .58436 L .56645 .58595 L F
.5675 .58352 m .56645 .58595 L .56679 .58516 L F
.5682 .58186 m .57088 .5827 L .56645 .58595 L .564 .548 .795 r
F
.56741 .59123 m .56935 .58762 L .56752 .5935 L F
.56006 .60039 m .56595 .6292 L .56752 .5935 L .908 .809 .739 r
F
.56006 .60039 m .56752 .5935 L .56708 .58448 L F
.56129 .59628 m .5861 .65392 L .57746 .5565 L .719 .694 .825 r
F
.56129 .59628 m .57746 .5565 L .57542 .53347 L F
.53876 .65076 m .54281 .65029 L .54304 .64075 L .574 .555 .795 r
F
.54119 .64316 m .56595 .6292 L .56006 .60039 L .908 .809 .739 r
F
.53158 .66603 m .53575 .67011 L .53502 .65784 L .783 .69 .761 r
F
.53164 .66588 m .51175 .71156 L .53164 .66588 L .908 .809 .739 r
F
.53167 .66583 m .51175 .71156 L .5118 .71145 L F
.53164 .66588 m .51175 .71156 L .53167 .66583 L F
.55307 .63999 m .55309 .63993 L .55307 .63999 L .411 .386 .721 r
F
.55038 .64942 m .55311 .63987 L .54575 .64995 L .574 .555 .795 r
F
.54765 .65901 m .54847 .66822 L p .54443 .64885 L .819 .694 .727 r
F P
0 g
s
.54525 .66884 m .56595 .6292 L .54119 .64316 L .908 .809 .739 r
F
.55145 .67853 m .54913 .6704 L .5488 .67195 L .411 .386 .721 r
F
.54847 .66822 m .5488 .67195 L p .54382 .68823 L .819 .694 .727 r
F P
0 g
s
.54525 .66884 m .5494 .69505 L .56595 .6292 L .908 .809 .739 r
F
.5363 .67064 m .55025 .68427 L .54366 .63729 L .783 .69 .761 r
F
.5363 .67064 m .54366 .63729 L .53569 .65625 L F
.5363 .67064 m .53569 .65625 L .53575 .67011 L F
.53569 .65625 m .53526 .65726 L .53575 .67011 L F
.53167 .66581 m .50798 .72024 L .508 .72018 L .908 .809 .739 r
F
.53167 .66583 m .50798 .72024 L .53167 .66581 L F
.4988 .74132 m .5126 .70961 L .51259 .70964 L .63 .528 .72 r
F
.50798 .72024 m .4988 .74132 L .508 .72018 L .908 .809 .739 r
F
.50997 .71577 m .51292 .73137 L .51025 .71514 L .783 .69 .761 r
F
.53168 .6658 m .49871 .74152 L .49859 .74179 L .908 .809 .739 r
F
.53167 .66581 m .49871 .74152 L .53168 .6658 L F
.53575 .67011 m .53526 .65726 L .53502 .65784 L .783 .69 .761 r
F
.53756 .70063 m .5363 .67064 L .53575 .67011 L F
.51269 .70941 m .51183 .71138 L .5127 .70939 L .908 .809 .739 r
F
.51183 .71138 m .49859 .74179 L .51184 .71137 L F
.51183 .71138 m .51184 .71137 L .5127 .70939 L F
.49859 .74179 m .4949 .75028 L .49858 .74181 L F
.49859 .74179 m .49858 .74181 L .5127 .70939 L F
.5127 .70939 m .49858 .74181 L .49854 .74192 L F
.49858 .74181 m .4949 .75028 L .49854 .74192 L F
.49859 .74179 m .49491 .75026 L .4949 .75028 L F
.49871 .74152 m .49491 .75026 L .49859 .74179 L F
.52248 .72705 m .52931 .70232 L .5261 .70512 L .41 .291 .606 r
F
.51919 .69468 m .51928 .73669 L .52686 .72621 L .783 .69 .761 r
F
.51698 .69973 m .51928 .73669 L .51919 .69468 L F
.53756 .70063 m .55025 .68427 L .5363 .67064 L F
.53164 .66588 m .53158 .66603 L .51175 .71156 L .908 .809 .739 r
F
.5118 .71145 m .51175 .71156 L .4988 .74132 L F
.51919 .69468 m .53199 .74733 L .52828 .6739 L .783 .69 .761 r
F
.49871 .74152 m .4988 .74132 L .49491 .75026 L .908 .809 .739 r
F
.5019 .73476 m .50038 .73834 L .50375 .73962 L .506 .498 .782 r
F
.50297 .75151 m .50779 .74006 L .5013 .74716 L .532 .326 .546 r
F
.50779 .74006 m .50776 .74006 L .5013 .74716 L F
.50559 .72608 m .51026 .74043 L .50808 .72023 L .506 .498 .782 r
F
.51026 .74043 m .51244 .74082 L .50808 .72023 L F
.50057 .74526 m .49536 .75449 L p .5013 .74716 L .532 .326 .546 r
F P
0 g
s
.49582 .7483 m .49559 .75091 L .50116 .7468 L .819 .466 .389 r
F
.50113 .74673 m .50116 .7468 L .50135 .74666 L F
.49582 .7483 m .50116 .7468 L .50113 .74673 L F
.50261 .75238 m .5013 .74716 L .49536 .75449 L .532 .326 .546 r
F
.4949 .75028 m .4887 .76452 L .49489 .75029 L .908 .809 .739 r
F
.49068 .76008 m .49574 .75213 L p .4887 .76452 L .778 .572 .62 r
F P
0 g
s
.49409 .75202 m .49489 .75029 L .49416 .75197 L .908 .809 .739 r
F
.49409 .75202 m .49416 .75197 L .48915 .76348 L F
.49403 .75215 m .49409 .75202 L .48915 .76348 L F
.49363 .75355 m .49081 .7598 L .49569 .75217 L .465 .19 .411 r
F
.49727 .75112 m .49536 .75449 L p .49574 .75213 L .597 .402 .587 r
F P
0 g
s
.50118 .74686 m .49409 .75202 L .49384 .75542 L .819 .466 .389 r
F
.50135 .74666 m .50116 .7468 L .50118 .74686 L F
.50116 .7468 m .49409 .75202 L .50118 .74686 L F
.50135 .74666 m .49384 .75542 L .50048 .75466 L F
.4966 .74662 m .49582 .7483 L .50135 .74666 L F
.50074 .74495 m .50057 .74526 L p .5013 .74716 L .532 .326 .546 r
F P
0 g
s
.5013 .74716 m .5051 .73977 L .50074 .74495 L .532 .326 .546 r
F
.50375 .73962 m .50074 .74495 L p .5051 .73977 L F P
0 g
s
.49491 .75026 m .49559 .75091 L .49582 .7483 L .819 .466 .389 r
F
.50261 .75238 m .50297 .75151 L .5013 .74716 L .532 .326 .546 r
F
.5013 .74716 m .50048 .75466 L .50346 .75579 L .819 .466 .389 r
F
.4694 .78615 m .43631 .81484 L .45004 .78359 L p .548 .227 .376 r
F P
0 g
s
.45004 .78359 m .459 .76318 L p .46595 .77853 L .548 .227 .376 r
F P
0 g
s
.45004 .78359 m .46595 .77853 L .4694 .78615 L .548 .227 .376 r
F
.45289 .72409 m .32112 .81828 L .37195 .79601 L .142 0 0 r
F
.43597 .73314 m .3174 .81737 L .45289 .72409 L F
.42595 .68239 m .32452 .80852 L .4301 .68535 L .896 .804 .75 r
F
.18906 .63714 m .30469 .81002 L .3174 .81737 L .728 .272 0 r
F
.30469 .81002 m .44858 .71765 L .3174 .81737 L .788 .566 .601 r
F
.44858 .71765 m .43422 .73027 L .3174 .81737 L F
.44181 .77066 m .41938 .78968 L p .459 .76318 L 0 0 0 r
F P
0 g
s
.42973 .78471 m .459 .76318 L p .41938 .78968 L 0 0 0 r
F P
0 g
s
.3959 .80959 m .43631 .81484 L .45004 .78359 L p .471 .149 .338 r
F P
0 g
s
.45004 .78359 m .459 .76318 L .41352 .79663 L p .471 .149 .338 r
F P
0 g
s
.41352 .79663 m .3959 .80959 L p .45004 .78359 L .471 .149 .338 r
F P
0 g
s
.30469 .81002 m .47767 .77397 L .47927 .76343 L .788 .566 .601 r
F
.39489 .78595 m .47776 .77338 L .37281 .79563 L .883 .644 .572 r
F
.30469 .81002 m .47927 .76343 L .44858 .71765 L .788 .566 .601 r
F
.40787 .78026 m .47776 .77338 L .39489 .78595 L .883 .644 .572 r
F
.48157 .76686 m .45571 .81469 L .47791 .77997 L .465 .19 .411 r
F
.4805 .77287 m .47776 .78038 L .48527 .77239 L .883 .644 .572 r
F
.47776 .78038 m .47844 .78508 L .48527 .77239 L F
.47789 .78124 m .4787 .78687 L .46815 .79607 L .778 .572 .62 r
F
.45215 .8457 m .44507 .84605 L p .44737 .85589 L .834 .47 .366 r
F P
0 g
s
.44592 .85909 m .44737 .85589 L .44631 .85585 L .627 .337 .458 r
F
.45091 .81825 m .45569 .81507 L p .44897 .82751 L .878 .593 .501 r
F P
0 g
s
.448 .84161 m .45839 .82231 L p .45061 .81968 L .627 .337 .458 r
F P
0 g
s
.44775 .86682 m .44753 .87139 L .45241 .87743 L .834 .47 .366 r
F
.43815 .89508 m .44042 .89264 L p .44177 .8922 L 0 0 0 r
F P
0 g
s
.44151 .88871 m .4094 .90261 L .44098 .88921 L .453 .096 .269 r
F
.45312 .88074 m .41845 .91343 L .4094 .90261 L F
.43986 .89554 m .43815 .89508 L p .44827 .88704 L 0 0 0 r
F P
0 g
s
.42357 .90936 m .41845 .91343 L .45312 .88074 L .453 .096 .269 r
F
.44876 .8853 m .45241 .87743 L p .44753 .87139 L .834 .47 .366 r
F P
0 g
s
.44592 .85909 m .44723 .86795 L p .4538 .85378 L .736 .35 .32 r
F P
0 g
s
.44661 .86089 m .44592 .85909 L .44723 .86795 L p 0 0 .307 r
F P
0 g
s
.44409 .85069 m .44592 .85909 L p .45061 .81968 L .627 .337 .458 r
F P
0 g
s
.42616 .83605 m .43745 .84526 L .44592 .85909 L .886 .511 .323 r
F
.44046 .85561 m .44592 .85909 L .44737 .85589 L .883 .644 .572 r
F
.44055 .85612 m .44592 .85909 L .43917 .85556 L .763 .323 0 r
F
.4213 .84621 m .43917 .85556 L .43683 .85405 L .883 .644 .572 r
F
.40532 .84419 m .40212 .84403 L .39108 .84056 L .502 .011 .023 r
F
.4256 .82038 m .42671 .82381 L .43086 .81994 L .456 0 .038 r
F
.42671 .82381 m .42879 .83028 L .43086 .81994 L F
.43086 .81994 m .42879 .83028 L .4488 .81843 L F
.39944 .82258 m .42879 .83028 L .4256 .82038 L F
.40532 .84419 m .40557 .84512 L p .40212 .84403 L .502 .011 .023 r
F P
0 g
s
.40082 .84605 m .3174 .81737 L .33286 .82116 L p 0 .405 .757 r
F P
0 g
s
.43631 .81484 m .37377 .82832 L .40059 .84819 L p .606 .171 .188 r
F P
0 g
s
.35498 .82658 m .39179 .83953 L .40082 .84605 L 0 .405 .757 r
F
.36473 .832 m .37117 .83436 L p .34389 .8204 L .333 0 0 r
F P
0 g
s
.37195 .79601 m .33172 .81363 L .34426 .82061 L .142 0 0 r
F
.4106 .84413 m .41466 .83951 L .40557 .84512 L .606 .171 .188 r
F
.40532 .84419 m .40557 .84512 L p .40711 .84417 L .456 0 .038 r
F P
0 g
s
.41466 .83951 m .43631 .81484 L .40059 .84819 L .606 .171 .188 r
F
.42616 .83605 m .42864 .83088 L p .43745 .84526 L .886 .511 .323 r
F P
0 g
s
.4488 .81843 m .41187 .8441 L .45091 .81825 L .456 0 .038 r
F
.40634 .84795 m .41212 .8441 L p .41187 .8441 L F P
0 g
s
.41212 .8441 m .45091 .81825 L p .41187 .8441 L .456 0 .038 r
F P
0 g
s
.40557 .84512 m .40634 .84795 L p .4488 .81843 L .456 0 .038 r
F P
0 g
s
.40634 .84795 m .42528 .83533 L p .42616 .83605 L .878 .593 .501 r
F P
0 g
s
.40922 .84781 m .40634 .84795 L p .42616 .83605 L .878 .593 .501 r
F P
0 g
s
.40909 .84795 m .44055 .85612 L .42016 .84793 L .834 .47 .366 r
F
.40861 .84849 m .44055 .85612 L .40909 .84795 L F
.44524 .89767 m .44407 .89754 L .44746 .8948 L .156 0 0 r
F
.44966 .89378 m .44746 .8948 L .4605 .88423 L F
.44524 .89767 m .44746 .8948 L .44966 .89378 L F
.45272 .89109 m .46913 .86637 L .4519 .88526 L .506 .148 .294 r
F
.45 .89247 m .4519 .88526 L .44124 .89695 L F
.45272 .89109 m .4519 .88526 L .45 .89247 L F
.45209 .90572 m .44142 .91861 L .45138 .90508 L .453 .096 .269 r
F
.45212 .90724 m .46477 .88493 L p .44542 .89949 L .506 .148 .294 r
F P
0 g
s
.44556 .90104 m .44542 .89949 L .44459 .90011 L .506 .148 .294 r
F
.45212 .90724 m .44542 .89949 L .44556 .90104 L F
.44384 .89965 m .44556 .90104 L p .44349 .90275 L .154 0 .282 r
F P
0 g
s
.44571 .90261 m .44349 .90275 L .44556 .90104 L .154 0 .282 r
F
.44384 .89965 m .44556 .90104 L p .44357 .89937 L 0 .06 .599 r
F P
0 g
s
.44357 .89937 m .44556 .90104 L .44534 .90082 L 0 .06 .599 r
F
.44357 .89937 m .44737 .90249 L .44709 .90221 L F
.44589 .90447 m .44349 .90275 L .44571 .90261 L .154 0 .282 r
F
.44349 .90275 m .43964 .9 L .44384 .89965 L F
.56021 .77492 m .55261 .78065 L p .55697 .77764 L .885 .968 .839 r
F P
0 g
s
.55697 .77764 m .55989 .77562 L .56012 .7751 L .885 .968 .839 r
F
.55697 .77764 m .56012 .7751 L .56021 .77492 L F
.55543 .77896 m .55989 .77562 L .55261 .78065 L F
.55779 .77755 m .55989 .77562 L p .55548 .77893 L F P
0 g
s
.55543 .77896 m .55548 .77893 L .55989 .77562 L .885 .968 .839 r
F
.56023 .77512 m .55128 .78269 L .55245 .78451 L .453 .096 .269 r
F
.56023 .77512 m .55286 .78515 L .55686 .79134 L F
.56023 .77512 m .4544 .91911 L .45901 .89737 L F
.47032 .87557 m .47044 .87208 L .50991 .84068 L .156 0 0 r
F
.46341 .918 m .46961 .93899 L p .48192 .90101 L .718 .741 .869 r
F P
0 g
s
.56023 .77512 m .46699 .9196 L .4544 .91911 L .453 .096 .269 r
F
.48128 .87557 m .47456 .88866 L .52353 .831 L .082 0 .156 r
F
.47456 .88866 m .46304 .91111 L .47848 .89066 L F
.47456 .88866 m .47848 .89066 L .52353 .831 L F
.46477 .88493 m .46983 .876 L p .46609 .8793 L .506 .148 .294 r
F P
0 g
s
.45353 .892 m .44912 .90424 L p .46983 .876 L .602 .252 .349 r
F P
0 g
s
.45212 .90724 m .44556 .90104 L .44625 .90823 L .506 .148 .294 r
F
.43912 .89699 m .43089 .9118 L .4273 .9064 L .453 .096 .269 r
F
.44008 .90257 m .44199 .91496 L .43089 .9118 L F
.4273 .9064 m .43089 .9118 L .42325 .90962 L F
.44257 .91899 m .44221 .9194 L .4302 .91094 L .498 .362 .626 r
F
.44163 .92786 m .43847 .92319 L .44269 .92947 L .602 .163 0 r
F
.43544 .92583 m .44423 .93134 L .43215 .92981 L .453 .096 .269 r
F
.44142 .91861 m .44409 .93071 L .43544 .92583 L F
.44409 .93071 m .44423 .93134 L .43544 .92583 L F
.44477 .93111 m .44474 .93108 L p .44475 .93109 L .05 .273 .766 r
F P
0 g
s
.44477 .93111 m .44474 .93108 L p .44446 .93215 L .648 .425 .566 r
F P
0 g
s
.44398 .93146 m .44446 .93215 L p .44474 .93108 L .648 .425 .566 r
F P
0 g
s
.44446 .93215 m .44644 .93506 L p .44484 .93129 L .648 .425 .566 r
F P
0 g
s
.44477 .93111 m .44446 .93215 L .44484 .93129 L .648 .425 .566 r
F
.44522 .93331 m .44505 .9324 L p .44507 .93244 L .878 .47 .03 r
F P
0 g
s
.44546 .93365 m .44523 .93271 L p .44735 .93636 L .878 .47 .03 r
F P
0 g
s
.44927 .93873 m .44923 .93904 L p .44919 .9386 L .878 .47 .03 r
F P
0 g
s
.44644 .93506 m .45131 .94218 L p .448 .93729 L .602 .163 0 r
F P
0 g
s
.50145 .99297 m .53471 1.06413 L .45905 .95323 L .498 .362 .626 r
F
.50145 .99297 m .45905 .95323 L .45459 .9467 L F
.45131 .94218 m .51778 1.03944 L p .45459 .9467 L .602 .163 0 r
F P
0 g
s
.53471 1.06413 m .45459 .9467 L p .51778 1.03944 L .602 .163 0 r
F P
0 g
s
.44702 .93591 m .51778 1.03944 L p .44751 .93516 L .648 .425 .566 r
F P
0 g
s
.44751 .93516 m .51778 1.03944 L .51711 1.03787 L .648 .425 .566 r
F
.44558 .93274 m .44735 .93636 L .44505 .9324 L .878 .47 .03 r
F
.44644 .93506 m .44702 .93591 L p .44486 .93125 L .648 .425 .566 r
F P
0 g
s
.4469 .93472 m .44735 .93636 L .44483 .93121 L .878 .47 .03 r
F
.44486 .93125 m .44702 .93591 L .44751 .93516 L .648 .425 .566 r
F
.44477 .93111 m .44484 .93129 L .44486 .93125 L F
.44505 .9324 m .44483 .93121 L p .44558 .93274 L .878 .47 .03 r
F P
0 g
s
.44484 .93129 m .44644 .93506 L .44486 .93125 L .648 .425 .566 r
F
.4481 .93451 m .44822 .93452 L .46081 .94748 L .05 .273 .766 r
F
.44504 .93125 m .44509 .93127 L .44824 .93452 L F
.44822 .93452 m .44824 .93452 L .46081 .94748 L F
.44504 .93125 m .44824 .93452 L .44822 .93452 L F
.60325 1.03291 m .44966 .93533 L .44603 .92697 L .498 .362 .626 r
F
.449 .92419 m .44603 .92697 L .44299 .91995 L F
.45522 .89122 m .45381 .89187 L .45164 .89777 L .322 0 .233 r
F
.44804 .91444 m .45212 .90724 L p .44625 .90823 L .506 .148 .294 r
F P
0 g
s
.46961 .93899 m .48442 .93522 L .48192 .90101 L .718 .741 .869 r
F
.52662 .9789 m .44659 .92733 L .449 .92419 L .498 .362 .626 r
F
.44659 .92733 m .44603 .92697 L .44677 .92628 L F
.44659 .92733 m .44677 .92628 L .449 .92419 L F
.44232 .90889 m .44121 .90908 L .43964 .9 L .154 0 .282 r
F
.53251 .98524 m .44603 .92697 L .52662 .9789 L .498 .362 .626 r
F
.53292 .92285 m .48192 .90101 L p .48442 .93522 L .718 .741 .869 r
F P
0 g
s
.51304 .93663 m .47702 .92546 L .50602 .93353 L .498 .362 .626 r
F
.47702 .92546 m .47197 .92358 L .50431 .93278 L F
.47702 .92546 m .50431 .93278 L .50602 .93353 L F
.70954 .89859 m .53154 .94964 L .71212 .92723 L .698 .574 .713 r
F
.53524 .8778 m .53154 .94964 L .75624 .8852 L .784 .964 .921 r
F
.47197 .92358 m .47194 .92351 L .51144 .93478 L .498 .362 .626 r
F
.51172 .93489 m .51144 .93478 L .55059 .94595 L F
.47197 .92358 m .51144 .93478 L .51172 .93489 L F
.47412 .88312 m .46304 .91111 L .48128 .87557 L .082 0 .156 r
F
.47702 .92546 m .4687 .92288 L .47121 .9233 L .498 .362 .626 r
F
.4687 .92288 m .45686 .9192 L .46577 .92175 L F
.4687 .92288 m .46577 .92175 L .47121 .9233 L F
.45814 .94546 m .44487 .93122 L p .45273 .94287 L .648 .425 .566 r
F P
0 g
s
.44487 .93122 m .44486 .93125 L .45273 .94287 L .648 .425 .566 r
F
.56023 .77512 m .55686 .79134 L .56422 .78531 L .453 .096 .269 r
F
.45814 .94546 m .44638 .93284 L p .46081 .94748 L .05 .273 .766 r
F P
0 g
s
.57517 1.00647 m .61987 1.04348 L p .63382 .97409 L .564 .499 .74 r
F P
0 g
s
.63037 1.01834 m .62289 1.02847 L .63382 .97409 L .801 .786 .838 r
F
.57517 1.00647 m .61987 1.04348 L p .54964 .99597 L .318 .46 .846 r
F P
0 g
s
.63382 .97409 m .58093 1.00329 L .44939 .92382 L .498 .362 .626 r
F
.63382 .97409 m .44939 .92382 L .45106 .92224 L F
.60963 1.02064 m .55251 .99715 L .449 .92419 L F
.44939 .92382 m .449 .92419 L .44299 .91995 L F
.60963 1.02064 m .449 .92419 L .44939 .92382 L F
.56023 .77512 m .58155 .82957 L .6493 .80083 L .453 .096 .269 r
F
.56121 .77532 m .46717 .9196 L .56023 .77512 L F
.63382 .97409 m .45106 .92224 L .45172 .92163 L .498 .362 .626 r
F
.46304 .91111 m .50687 .8578 L .5234 .83218 L .082 0 .156 r
F
.46304 .91111 m .46602 .91809 L .50687 .8578 L F
.46602 .91809 m .46629 .91871 L .46643 .91849 L F
.46602 .91809 m .46643 .91849 L .50687 .8578 L F
.47051 .92678 m .45179 .92156 L .45195 .92141 L .498 .362 .626 r
F
.4715 .92733 m .45172 .92163 L .47051 .92678 L F
.45172 .92163 m .44257 .91899 L .45179 .92156 L F
.45172 .92163 m .45179 .92156 L .47051 .92678 L F
.46717 .9196 m .46705 .9196 L .56023 .77512 L .453 .096 .269 r
F
.46778 .92259 m .45195 .92141 L .45686 .9192 L .498 .362 .626 r
F
.52626 .94073 m .47222 .92728 L .46778 .92259 L F
.52772 .94336 m .47222 .92728 L .52626 .94073 L F
.48398 .89335 m .48398 .89334 L .56023 .77512 L .453 .096 .269 r
F
.47222 .92728 m .45195 .92141 L .46778 .92259 L .498 .362 .626 r
F
.45567 .93725 m .48398 .89334 L .48398 .89335 L .453 .096 .269 r
F
.45567 .93725 m .45566 .93725 L .48398 .89334 L F
.46304 .91111 m .48474 .88273 L .48477 .88233 L .082 0 .156 r
F
.46491 .94247 m .48542 .96613 L p .46452 .94802 L .05 .273 .766 r
F P
0 g
s
.44444 .92331 m .44712 .93251 L .44488 .92526 L .878 .47 .03 r
F
.4455 .92575 m .44712 .93251 L .44444 .92331 L F
.4455 .92575 m .44692 .929 L .44712 .93251 L F
.46452 .94802 m .44539 .93145 L .45567 .93725 L .05 .273 .766 r
F
.46452 .94802 m .45567 .93725 L .46491 .94247 L F
.45493 .93838 m .45488 .93836 L .56023 .77512 L .453 .096 .269 r
F
.46717 .9196 m .45567 .93725 L .46705 .9196 L F
.46535 .92214 m .45564 .93722 L .46577 .92175 L .082 0 .156 r
F
.45564 .93722 m .45567 .93725 L .46577 .92175 L F
.45195 .92141 m .44279 .91875 L .45438 .91912 L .498 .362 .626 r
F
.45195 .92141 m .45438 .91912 L .45686 .9192 L F
.45195 .92141 m .44257 .91899 L .44279 .91875 L F
.45179 .92156 m .44257 .91899 L .45195 .92141 L F
.45172 .92163 m .44299 .91995 L .44257 .91899 L F
.45106 .92224 m .44299 .91995 L .45172 .92163 L F
.45106 .92224 m .44939 .92382 L .44299 .91995 L F
.46699 .9196 m .45561 .93722 L .44328 .92104 L .453 .096 .269 r
F
.44498 .93098 m .44487 .93122 L .44278 .91876 L .154 0 .282 r
F
.44503 .93125 m .44487 .93122 L .44498 .93098 L F
.44487 .93122 m .44487 .93122 L .44498 .93098 L F
.44279 .91875 m .44287 .91866 L .45686 .9192 L .498 .362 .626 r
F
.44504 .93125 m .44278 .91876 L .44287 .91866 L .154 0 .282 r
F
.44546 .93368 m .44503 .93125 L .44504 .93125 L F
.44503 .93125 m .44278 .91876 L .44504 .93125 L F
.44278 .91876 m .44487 .93122 L .44259 .91897 L F
.44487 .93122 m .44258 .91899 L .44259 .91897 L F
.44483 .93121 m .44257 .91899 L p .44487 .93122 L F P
0 g
s
.44487 .93122 m .44257 .91899 L .44258 .91899 L .154 0 .282 r
F
.45561 .93722 m .44409 .93071 L .44142 .91861 L .453 .096 .269 r
F
.46699 .9196 m .44328 .92104 L .44287 .91866 L F
.44816 .92827 m .44655 .93151 L .44287 .91866 L .154 0 .282 r
F
.44655 .93151 m .44504 .93125 L .44287 .91866 L F
.46304 .91111 m .46138 .9153 L .46629 .91871 L .082 0 .156 r
F
.45686 .9192 m .45493 .91861 L .46535 .92158 L .498 .362 .626 r
F
.46564 .9217 m .46687 .92007 L .46685 .92004 L .082 0 .156 r
F
.45686 .9192 m .46546 .92163 L .46574 .92174 L .498 .362 .626 r
F
.46566 .92171 m .46577 .92175 L .46687 .92007 L .082 0 .156 r
F
.47194 .92351 m .51127 .93471 L .51144 .93478 L .498 .362 .626 r
F
.46457 .92128 m .46717 .9196 L .46656 .9183 L .082 0 .156 r
F
.45686 .9192 m .46574 .92174 L .46577 .92175 L .498 .362 .626 r
F
.45686 .9192 m .46535 .92158 L .46546 .92163 L F
.46564 .9217 m .46717 .9196 L .46457 .92128 L .082 0 .156 r
F
.46566 .92171 m .46687 .92007 L .46564 .9217 L F
.45975 .91942 m .46457 .92128 L .46549 .91991 L F
.45493 .91861 m .4567 .91891 L .46815 .92221 L .498 .362 .626 r
F
.46802 .92235 m .46815 .92221 L .55059 .94595 L F
.45493 .91861 m .46815 .92221 L .46802 .92235 L F
.46138 .9153 m .45975 .91942 L .46549 .91991 L .082 0 .156 r
F
.46138 .9153 m .46549 .91991 L .46629 .91871 L F
.46056 .91956 m .46052 .91955 L .46195 .91571 L F
.46197 .91573 m .46195 .91571 L .46407 .91003 L F
.46056 .91956 m .46195 .91571 L .46197 .91573 L F
.45548 .93702 m .44567 .93136 L .45167 .93239 L .05 .273 .766 r
F
.45471 .93609 m .46564 .9217 L .46457 .92128 L .082 0 .156 r
F
.44539 .93145 m .44519 .93128 L .45563 .9372 L .05 .273 .766 r
F
.44539 .93145 m .45563 .9372 L .45567 .93725 L F
.44487 .93123 m .44487 .93122 L .44487 .93122 L .154 0 .282 r
F
.44487 .93123 m .44487 .93123 L .44487 .93122 L F
.44487 .93122 m .44477 .93111 L p .44486 .93125 L .648 .425 .566 r
F P
0 g
s
.44488 .93122 m .44504 .93125 L .44822 .93452 L .05 .273 .766 r
F
.44488 .93122 m .44822 .93452 L .4481 .93451 L F
.44546 .93368 m .44487 .93123 L .44503 .93125 L .154 0 .282 r
F
.44487 .93123 m .44487 .93122 L .44503 .93125 L F
.44546 .93368 m .44522 .93331 L .44487 .93123 L F
.44546 .93368 m .44487 .93123 L .44487 .93123 L F
.44477 .93111 m .44507 .93125 L .44488 .93122 L .05 .273 .766 r
F
.44522 .93331 m .44483 .93121 L p .44487 .93122 L .154 0 .282 r
F P
0 g
s
.44487 .93122 m .44477 .93111 L p .44488 .93122 L .05 .273 .766 r
F P
0 g
s
.46081 .94748 m .44507 .93125 L .46465 .94818 L .05 .273 .766 r
F
.46946 .95404 m .46465 .94818 L .48542 .96613 L F
.46081 .94748 m .46465 .94818 L .46946 .95404 L F
.44507 .93125 m .44519 .93128 L .48542 .96613 L F
.45493 .93838 m .44809 .94888 L .45488 .93836 L .453 .096 .269 r
F
.45178 .94317 m .4518 .94319 L .45564 .93722 L .082 0 .156 r
F
.45563 .9372 m .45564 .93722 L .46535 .92214 L F
.45178 .94317 m .45564 .93722 L .45563 .9372 L F
.45561 .93722 m .44809 .94888 L .44504 .93125 L .453 .096 .269 r
F
.45087 .94185 m .45178 .94317 L .45563 .9372 L .082 0 .156 r
F
.44519 .93128 m .44567 .93136 L .45548 .93702 L .05 .273 .766 r
F
.44519 .93128 m .45548 .93702 L .45563 .9372 L F
.45087 .94185 m .45563 .9372 L .45492 .93634 L .082 0 .156 r
F
.45087 .94185 m .45492 .93634 L .45491 .93633 L F
.45087 .94185 m .45491 .93633 L .45471 .93609 L F
.45366 .93481 m .45087 .94185 L .45471 .93609 L F
.45492 .93634 m .45563 .9372 L .46535 .92214 L F
.45491 .93633 m .46566 .92171 L .46564 .9217 L F
.45492 .93634 m .46566 .92171 L .45491 .93633 L F
.45491 .93633 m .46564 .9217 L .45471 .93609 L F
.4455 .91568 m .44778 .91623 L .44841 .91644 L .498 .362 .626 r
F
.4455 .91568 m .44841 .91644 L .44879 .91663 L F
.44841 .91644 m .44928 .91667 L .44905 .91665 L F
.44841 .91644 m .44905 .91665 L .44879 .91663 L F
.44415 .91721 m .44287 .91866 L .44121 .90908 L .154 0 .282 r
F
.44465 .91664 m .44121 .90908 L .44232 .90889 L F
.44415 .91721 m .44121 .90908 L .44465 .91664 L F
.4455 .91568 m .44669 .91592 L .44778 .91623 L .498 .362 .626 r
F
.44841 .91644 m .44778 .91623 L .44928 .91667 L F
.46059 .91957 m .46407 .91003 L .46415 .90995 L .082 0 .156 r
F
.4567 .91891 m .45749 .91904 L .46822 .92214 L .498 .362 .626 r
F
.46815 .92221 m .46822 .92214 L .55059 .94595 L F
.4567 .91891 m .46822 .92214 L .46815 .92221 L F
.46056 .91956 m .46407 .91003 L .46059 .91957 L .082 0 .156 r
F
.44879 .91663 m .44928 .91667 L .45749 .91904 L .498 .362 .626 r
F
.44879 .91663 m .45749 .91904 L .4567 .91891 L F
.45226 .94188 m .45001 .94778 L .45224 .94181 L .082 0 .156 r
F
.48444 .89153 m .48437 .89234 L .52798 .82631 L F
.46656 .9183 m .48437 .89234 L .48444 .89153 L F
.46656 .9183 m .46684 .91889 L .48437 .89234 L F
.46684 .91889 m .46732 .91937 L .52798 .82631 L F
.46656 .9183 m .52798 .82631 L .52755 .82676 L F
.53196 .92244 m .48192 .90101 L p .53264 .87893 L .816 .672 .704 r
F P
0 g
s
.48449 .89084 m .48191 .92318 L .46642 .90782 L .082 0 .156 r
F
.55059 .94595 m .45749 .91904 L .46534 .92037 L .498 .362 .626 r
F
.5013 .92928 m .46534 .92037 L .48461 .92364 L F
.55059 .94595 m .46534 .92037 L .5013 .92928 L F
.4593 .91887 m .46109 .90829 L p .4517 .91699 L .322 0 .233 r
F P
0 g
s
.48191 .92318 m .47619 .92221 L .46642 .90782 L .082 0 .156 r
F
.46455 .90957 m .46074 .91959 L .46415 .90995 L F
.46067 .91978 m .45612 .93174 L .46457 .92128 L F
.45975 .91942 m .45612 .93174 L .46067 .91978 L F
.45975 .91942 m .45369 .93474 L .45612 .93174 L F
.45369 .93474 m .45369 .93477 L .46457 .92128 L F
.45366 .93481 m .45471 .93609 L .46457 .92128 L F
.46074 .91959 m .45492 .93487 L .46059 .91957 L F
.46074 .91959 m .46059 .91957 L .46415 .90995 L F
.46577 .92175 m .47193 .9235 L .47194 .92351 L .498 .362 .626 r
F
.46574 .92174 m .47193 .9235 L .46577 .92175 L F
.47193 .9235 m .51127 .93471 L .47194 .92351 L F
.46799 .92238 m .46802 .92235 L .51127 .93471 L F
.63382 .97409 m .4715 .92733 L .47051 .92678 L F
.47197 .92358 m .47121 .9233 L .47194 .92351 L F
.46602 .90819 m .47911 .92665 L .4702 .93087 L .082 0 .156 r
F
.44912 .90424 m .44719 .9096 L p .45013 .90524 L .602 .252 .349 r
F P
0 g
s
.45013 .90524 m .46983 .876 L .44912 .90424 L .602 .252 .349 r
F
.45205 .90717 m .46983 .876 L .45013 .90524 L F
.45522 .89122 m .45164 .89777 L .44923 .90434 L .322 0 .233 r
F
.44804 .91444 m .44625 .90823 L .44682 .9142 L .506 .148 .294 r
F
.44778 .91623 m .44669 .91592 L .44699 .91598 L .498 .362 .626 r
F
.45493 .91861 m .44847 .9166 L .4567 .91891 L F
.44847 .9166 m .4455 .91568 L .44879 .91663 L F
.44847 .9166 m .44879 .91663 L .4567 .91891 L F
.44682 .9142 m .44465 .91664 L .44268 .9101 L .154 0 .282 r
F
.44218 .91469 m .44199 .91496 L .44008 .90257 L .453 .096 .269 r
F
.44662 .91211 m .44682 .9142 L .44268 .9101 L .154 0 .282 r
F
.44714 .91602 m .44804 .91444 L p .44682 .9142 L .506 .148 .294 r
F P
0 g
s
.44702 .91598 m .45205 .90717 L .44719 .9096 L .602 .252 .349 r
F
.45205 .90717 m .45013 .90524 L .44719 .9096 L F
.44464 .90357 m .44268 .9101 L .44349 .90275 L .154 0 .282 r
F
.45439 .88961 m .45521 .88733 L .45272 .89109 L .506 .148 .294 r
F
.44857 .91349 m .46983 .876 L p .44855 .91331 L .602 .252 .349 r
F P
0 g
s
.46617 .88472 m .45451 .89155 L .46497 .87877 L .156 0 0 r
F
.46645 .88605 m .4647 .88686 L .46617 .88472 L F
.4647 .88686 m .45451 .89155 L .46617 .88472 L F
.46415 .90995 m .46407 .91003 L .47356 .88452 L .082 0 .156 r
F
.47415 .88435 m .46455 .90957 L .47356 .88452 L F
.46455 .90957 m .46415 .90995 L .47356 .88452 L F
.47653 .88058 m .47032 .87557 L .52686 .82748 L .156 0 0 r
F
.47012 .88122 m .47032 .87557 L .48772 .88961 L F
.48474 .88273 m .52755 .82676 L .48477 .88233 L .082 0 .156 r
F
.48477 .88233 m .52755 .82676 L .52353 .831 L F
.5234 .83218 m .50687 .8578 L .52755 .82676 L F
.47032 .87557 m .50991 .84068 L .53211 .82302 L .156 0 0 r
F
.46462 .90951 m .46455 .90957 L .47454 .88332 L .082 0 .156 r
F
.47998 .92763 m .48834 .93455 L p .4939 .94576 L .318 .46 .846 r
F P
0 g
s
.48834 .93455 m .50311 .94678 L p .49796 .94621 L .318 .46 .846 r
F P
0 g
s
.49796 .94621 m .4939 .94576 L .48834 .93455 L .318 .46 .846 r
F
.46642 .90782 m .47991 .92769 L .46602 .90819 L .082 0 .156 r
F
.4939 .94576 m .47884 .928 L .47903 .92794 L .318 .46 .846 r
F
.48398 .93284 m .47903 .92794 L .47998 .92763 L F
.4939 .94576 m .47903 .92794 L .48398 .93284 L F
.47991 .92769 m .47987 .92772 L .46602 .90819 L .082 0 .156 r
F
.47911 .92665 m .47947 .92717 L .47469 .92907 L F
.47911 .92665 m .47469 .92907 L .4702 .93087 L F
.47947 .92717 m .47983 .92768 L .47771 .92838 L F
.47947 .92717 m .47771 .92838 L .4702 .93087 L F
.4939 .94576 m .45996 .93425 L .47884 .928 L .318 .46 .846 r
F
.46574 .92174 m .46802 .92235 L .46799 .92238 L .498 .362 .626 r
F
.46546 .92163 m .46802 .92235 L .46574 .92174 L F
.46546 .92163 m .46535 .92158 L .46802 .92235 L F
.46535 .92214 m .46577 .92175 L .46566 .92171 L .082 0 .156 r
F
.46685 .92004 m .46687 .92007 L .46717 .9196 L F
.46684 .91889 m .46717 .9196 L .46732 .91937 L F
.55251 .99715 m .53251 .98524 L .52662 .9789 L .498 .362 .626 r
F
.61999 1.04374 m .54926 .99581 L p .61987 1.04348 L .318 .46 .846 r
F P
0 g
s
.54926 .99581 m .54962 .99596 L .61987 1.04348 L .318 .46 .846 r
F
.54653 .99469 m .53251 .98524 L .55251 .99715 L .498 .362 .626 r
F
.46936 .94167 m .46939 .94167 L .61987 1.04348 L .318 .46 .846 r
F
.60325 1.03291 m .54653 .99469 L .55251 .99715 L .498 .362 .626 r
F
.54926 .99581 m .46936 .94167 L p .54962 .99596 L .318 .46 .846 r
F P
0 g
s
.48852 .96002 m .53471 1.06413 L .48502 .95779 L .498 .362 .626 r
F
.60325 1.03291 m .5644 1.10767 L .48852 .96002 L F
.54926 .99581 m .45893 .93459 L p .53994 1.02904 L .586 .451 .663 r
F P
0 g
s
.46484 .9093 m .46842 .92445 L .45498 .93488 L .082 0 .156 r
F
.46842 .92445 m .45986 .93359 L .45498 .93488 L F
.45849 .93506 m .53994 1.02904 L p .45893 .93459 L .586 .451 .663 r
F P
0 g
s
.46936 .94167 m .45893 .93459 L p .46939 .94167 L .318 .46 .846 r
F P
0 g
s
.45893 .93459 m .45893 .93459 L .46939 .94167 L .318 .46 .846 r
F
.46996 .93094 m .45765 .93502 L .45498 .93488 L .082 0 .156 r
F
.46939 .94167 m .45893 .93459 L .5074 .95034 L .318 .46 .846 r
F
.45893 .93459 m .45991 .93427 L .5074 .95034 L F
.45698 .93327 m .45703 .93326 L .5074 .95034 L F
.45548 .93702 m .45366 .93481 L .45631 .93495 L .05 .273 .766 r
F
.45563 .9372 m .45548 .93702 L .46491 .94247 L F
.45567 .93725 m .45563 .9372 L .46491 .94247 L F
.46996 .93094 m .47109 .93573 L .45765 .93502 L .082 0 .156 r
F
.46491 .94247 m .45548 .93702 L .45631 .93495 L .05 .273 .766 r
F
.45696 .9333 m .45849 .93506 L p .45631 .93495 L F P
0 g
s
.45849 .93506 m .46491 .94247 L p .45631 .93495 L .05 .273 .766 r
F P
0 g
s
.45567 .93725 m .45493 .93838 L .45566 .93725 L .453 .096 .269 r
F
.45564 .93722 m .4518 .94319 L .45567 .93725 L .082 0 .156 r
F
.45814 .94546 m .45273 .94287 L .51711 1.03787 L .648 .425 .566 r
F
.45453 .93605 m .47109 .93573 L .45001 .94778 L .082 0 .156 r
F
.45498 .93488 m .45765 .93502 L .45453 .93605 L F
.45765 .93502 m .47109 .93573 L .45453 .93605 L F
.45893 .93459 m .45698 .93327 L .45991 .93427 L .318 .46 .846 r
F
.45226 .94188 m .45224 .94181 L .45482 .93487 L .082 0 .156 r
F
.45492 .93487 m .45226 .94188 L .45482 .93487 L F
.45087 .94185 m .44809 .94888 L .4518 .94319 L F
.45498 .93488 m .45001 .94778 L .45492 .93487 L F
.45482 .93487 m .45001 .94778 L .45366 .93481 L F
.46074 .94165 m .45344 .94581 L p .45248 .93915 L .154 0 .282 r
F P
0 g
s
.45893 .93459 m .45698 .93327 L p .45893 .93459 L .318 .46 .846 r
F P
0 g
s
.46602 .90819 m .47109 .93573 L .46484 .9093 L .082 0 .156 r
F
.45498 .93488 m .45492 .93487 L .46455 .90957 L F
.45498 .93488 m .46455 .90957 L .46462 .90951 L F
.48461 .92364 m .48239 .92555 L .57517 1.00647 L .564 .499 .74 r
F
.47998 .92763 m .48834 .93455 L p .48239 .92555 L F P
0 g
s
.48834 .93455 m .57517 1.00647 L p .48239 .92555 L .564 .499 .74 r
F P
0 g
s
.49037 .89087 m .48137 .92985 L .48883 .89014 L .082 0 .156 r
F
.482 .92687 m .48205 .92692 L .48227 .92596 L .819 .466 .389 r
F
.52353 .831 m .52755 .82676 L .53333 .81808 L .082 0 .156 r
F
.53323 .81816 m .53333 .81808 L .53368 .81755 L F
.52353 .831 m .53333 .81808 L .53323 .81816 L F
.45547 .88714 m .45521 .88733 L .45463 .8894 L .506 .148 .294 r
F
.45463 .8894 m .45521 .88733 L .45439 .88961 L F
.46523 .88006 m .46497 .87877 L .46609 .8793 L .156 0 0 r
F
.47009 .8812 m .46497 .87877 L .47044 .87208 L F
.46609 .8793 m .46913 .86637 L .45521 .88733 L .506 .148 .294 r
F
.45272 .89109 m .44357 .89915 L .44459 .90011 L F
.45451 .89155 m .44966 .89378 L .4605 .88423 L .156 0 0 r
F
.46609 .8793 m .45547 .88714 L .45463 .8894 L .506 .148 .294 r
F
.45886 .87721 m .45353 .892 L p .45803 .88537 L .602 .252 .349 r
F P
0 g
s
.45803 .88537 m .46023 .87581 L .45886 .87721 L .602 .252 .349 r
F
.45391 .88144 m .45416 .88108 L .46272 .87271 L 0 0 0 r
F
.45391 .88144 m .45364 .88161 L .45416 .88108 L F
.46913 .86637 m .47071 .85964 L .45197 .88336 L .506 .148 .294 r
F
.46272 .87271 m .46023 .87581 L p .46481 .86541 L .923 .598 .408 r
F P
0 g
s
.46481 .86541 m .46023 .87581 L .46151 .87025 L .923 .598 .408 r
F
.46545 .86089 m .46481 .86541 L .46151 .87025 L F
.46545 .86089 m .46151 .87025 L .46176 .86916 L F
.46292 .865 m .46176 .86916 L .46259 .86554 L F
.46545 .86089 m .46176 .86916 L .46292 .865 L F
.46176 .86916 m .45886 .87721 L p .46035 .87528 L .602 .252 .349 r
F P
0 g
s
.47409 .86171 m .49746 .82727 L .45886 .87721 L .602 .252 .349 r
F
.44341 .89904 m .44456 .89828 L .44357 .89915 L .156 0 0 r
F
.44341 .89904 m .44289 .89868 L .44407 .89754 L F
.44222 .89798 m .44426 .89577 L .44202 .89777 L .648 .316 .396 r
F
.44349 .90275 m .44268 .9101 L .43964 .9 L .154 0 .282 r
F
.4302 .91094 m .44407 .89754 L p .44426 .89577 L .648 .316 .396 r
F P
0 g
s
.45272 .89109 m .44124 .89695 L .44357 .89915 L .506 .148 .294 r
F
.44353 .89655 m .45208 .8841 L .45754 .87855 L 0 0 0 r
F
.44353 .89655 m .45754 .87855 L .45751 .87891 L F
.46462 .90951 m .47454 .88332 L .47456 .88333 L .082 0 .156 r
F
.4748 .88345 m .46484 .9093 L .47463 .88337 L F
.49041 .8397 m .49746 .82727 L p .48844 .84056 L .602 .252 .349 r
F P
0 g
s
.49041 .8397 m .48844 .84056 L .45353 .892 L .602 .252 .349 r
F
.46531 .88044 m .46523 .88006 L .46561 .88015 L .156 0 0 r
F
.46523 .88006 m .46609 .8793 L .47009 .8812 L F
.46983 .88764 m .47044 .87208 L .4699 .88757 L F
.46609 .8793 m .47401 .86863 L .46701 .87539 L .506 .148 .294 r
F
.46983 .876 m .47401 .86863 L p .46609 .8793 L F P
0 g
s
.46983 .876 m .49041 .8397 L p .45353 .892 L .602 .252 .349 r
F P
0 g
s
.46035 .87528 m .49746 .82727 L .46176 .86916 L .602 .252 .349 r
F
.53749 .79787 m .55114 .77756 L .54839 .77903 L .908 .809 .739 r
F
.53749 .79787 m .55882 .77346 L .55114 .77756 L F
.53588 .79964 m .54798 .77925 L .54113 .78291 L F
.52369 .80841 m .53591 .79779 L .53608 .79686 L F
.56023 .77512 m .52745 .81471 L .52369 .80841 L .453 .096 .269 r
F
.52745 .81471 m .51413 .8308 L .52226 .81176 L F
.52745 .81471 m .52226 .81176 L .52369 .80841 L F
.48593 .85329 m .52382 .82514 L .48524 .84196 L .156 0 0 r
F
.46679 .85147 m .46545 .86089 L .46292 .865 L .923 .598 .408 r
F
.44353 .89655 m .44827 .88704 L .45391 .88144 L 0 0 0 r
F
.45016 .88517 m .45112 .88421 L .44883 .88794 L .923 .598 .408 r
F
.44827 .88704 m .44869 .88661 L .45391 .88144 L 0 0 0 r
F
.4549 .87527 m .45112 .88421 L .45016 .88517 L .923 .598 .408 r
F
.45506 .87552 m .45112 .88421 L .4549 .87527 L F
.45998 .86467 m .46292 .865 L .45578 .87662 L F
.45506 .87552 m .45578 .87662 L .45112 .88421 L F
.45998 .86467 m .45578 .87662 L .45506 .87552 L F
.45998 .86467 m .44883 .88794 L .44879 .88637 L F
.46023 .87581 m .45972 .87645 L p .45886 .87721 L 0 0 0 r
F P
0 g
s
.46066 .87309 m .44719 .9096 L .4472 .90964 L .322 0 .233 r
F
.4607 .87294 m .44719 .9096 L .46066 .87309 L F
.45926 .87686 m .45603 .8854 L .45607 .88551 L F
.45603 .8854 m .45353 .892 L .45607 .88551 L F
.45607 .88551 m .45353 .892 L .4537 .89192 L F
.45921 .8769 m .45353 .892 L .45926 .87686 L F
.46098 .87194 m .45353 .892 L .4607 .87294 L F
.46176 .86916 m .45353 .892 L p .46098 .87194 L F P
0 g
s
.47033 .84461 m .46545 .86089 L .46679 .85147 L .923 .598 .408 r
F
.46243 .86837 m .49746 .82727 L .47211 .842 L .602 .252 .349 r
F
.46243 .86837 m .47211 .842 L .4714 .84241 L F
.4714 .84241 m .46176 .86916 L p .46243 .86837 L F P
0 g
s
.46023 .87581 m .45972 .87645 L p .46151 .87025 L .923 .598 .408 r
F P
0 g
s
.46151 .87025 m .45972 .87645 L .46142 .87038 L .923 .598 .408 r
F
.4487 .91317 m .44268 .9101 L .44464 .90357 L .154 0 .282 r
F
.44682 .9142 m .44625 .90823 L .44584 .9083 L .506 .148 .294 r
F
.44682 .9142 m .44584 .9083 L .44441 .91373 L F
.45686 .9192 m .44287 .91866 L .4455 .91568 L .498 .362 .626 r
F
.44714 .91602 m .44682 .9142 L .44699 .91598 L .506 .148 .294 r
F
.44714 .91602 m .44799 .91443 L .44702 .91598 L .602 .252 .349 r
F
.44714 .91602 m .44857 .91349 L p .44799 .91443 L F P
0 g
s
.44857 .91349 m .44855 .91331 L .44702 .91598 L .602 .252 .349 r
F
.44701 .91625 m .44714 .91602 L p .44699 .91598 L .506 .148 .294 r
F P
0 g
s
.44714 .91602 m .44699 .91598 L .44702 .91598 L .498 .362 .626 r
F
.44778 .91623 m .44699 .91598 L .44714 .91602 L F
.44701 .91625 m .44714 .91602 L p .44702 .91598 L .602 .252 .349 r
F P
0 g
s
.44928 .91667 m .44778 .91623 L .45056 .91671 L .498 .362 .626 r
F
.44778 .91623 m .44702 .91598 L .45126 .91683 L F
.4487 .91317 m .44816 .92827 L .44662 .91211 L .154 0 .282 r
F
.46109 .90829 m .44892 .91371 L .4517 .91699 L .322 0 .233 r
F
.45011 .9166 m .44917 .91641 L .4487 .91317 L .154 0 .282 r
F
.44928 .91667 m .45056 .91671 L .45094 .9168 L .498 .362 .626 r
F
.4887 .89891 m .48137 .92985 L .48866 .89827 L .082 0 .156 r
F
.48907 .89344 m .48276 .92328 L .4855 .91198 L .819 .466 .389 r
F
.48772 .88961 m .47653 .88058 L .53211 .82302 L .156 0 0 r
F
.47653 .88058 m .52686 .82748 L .53211 .82302 L F
.44719 .9096 m .44587 .91325 L p .44707 .91391 L .602 .252 .349 r
F P
0 g
s
.44718 .90994 m .44587 .91325 L .44598 .91322 L .322 0 .233 r
F
.47415 .84022 m .47259 .84131 L .4714 .84241 L .602 .252 .349 r
F
.47238 .84124 m .46764 .85413 L .46766 .8541 L .322 0 .233 r
F
.47153 .84204 m .4714 .84241 L p .47259 .84131 L .602 .252 .349 r
F P
0 g
s
.47238 .84124 m .4607 .87294 L .46066 .87309 L .322 0 .233 r
F
.46763 .85415 m .46098 .87194 L .4607 .87294 L F
.47238 .84124 m .46756 .85422 L .46763 .85415 L F
.46756 .85422 m .46098 .87194 L .46763 .85415 L F
.47153 .84204 m .46176 .86916 L p .47238 .84124 L F P
0 g
s
.47238 .84124 m .46176 .86916 L .46098 .87194 L .322 0 .233 r
F
.46748 .84494 m .46772 .84492 L p .46252 .85601 L .923 .598 .408 r
F P
0 g
s
.44491 .86033 m .44396 .87501 L .44775 .86682 L .834 .47 .366 r
F
.44592 .85909 m .44108 .85908 L p .44374 .85995 L .72 .21 .01 r
F P
0 g
s
.44365 .85992 m .44396 .87501 L .44491 .86033 L .834 .47 .366 r
F
.44763 .87066 m .44787 .87038 L .44784 .8701 L .736 .35 .32 r
F
.46237 .85596 m .46748 .84494 L p .46252 .85601 L .923 .598 .408 r
F P
0 g
s
.46772 .84492 m .47033 .84461 L p .46679 .85147 L .923 .598 .408 r
F P
0 g
s
.46772 .84492 m .46679 .85147 L .45998 .86467 L .923 .598 .408 r
F
.45845 .86471 m .45998 .86467 L .44879 .88637 L F
.45845 .86471 m .44879 .88637 L .44876 .8854 L F
.44353 .89655 m .43986 .89554 L p .44051 .89489 L 0 0 0 r
F P
0 g
s
.44353 .89655 m .44051 .89489 L .44827 .88704 L 0 0 0 r
F
.44353 .89655 m .42184 .87377 L p .41232 .8576 L .713 .229 0 r
F P
0 g
s
.39835 .84654 m .41157 .85633 L p .40999 .8561 L .51 0 0 r
F P
0 g
s
.41157 .85633 m .41524 .85958 L .41232 .8576 L .713 .229 0 r
F
.41266 .85621 m .41524 .85958 L p .41157 .85633 L F P
0 g
s
.4106 .85644 m .40999 .8561 L p .41157 .85633 L .51 0 0 r
F P
0 g
s
.33286 .82116 m .38952 .84125 L .39465 .84379 L 0 .405 .757 r
F
.40999 .8561 m .37117 .83436 L p .39835 .84654 L .51 0 0 r
F P
0 g
s
.37117 .83436 m .38234 .83981 L p .39549 .8475 L 0 .301 .696 r
F P
0 g
s
.39549 .8475 m .40937 .85561 L .39538 .84783 L 0 .301 .696 r
F
.39549 .8475 m .39538 .84783 L .37117 .83436 L F
.4106 .85644 m .37117 .83436 L p .40937 .85561 L F P
0 g
s
.40762 .84962 m .41266 .85621 L p .41157 .85633 L .713 .229 0 r
F P
0 g
s
.40777 .84944 m .41263 .85449 L .40861 .84849 L .834 .47 .366 r
F
.4187 .84734 m .40922 .84781 L p .42016 .84793 L F P
0 g
s
.40909 .84795 m .42016 .84793 L .40922 .84781 L .834 .47 .366 r
F
.40449 .85109 m .4056 .85191 L p .40922 .84781 L .606 .171 .188 r
F P
0 g
s
.40059 .84819 m .40449 .85109 L p .40694 .84829 L .606 .171 .188 r
F P
0 g
s
.40694 .84829 m .40347 .84702 L .40059 .84819 L .606 .171 .188 r
F
.40634 .84795 m .44353 .89655 L .44664 .88986 L p .834 .47 .366 r
F P
0 g
s
.40651 .85258 m .42616 .83605 L .40922 .84781 L .606 .171 .188 r
F
.4056 .85191 m .40651 .85258 L p .40922 .84781 L F P
0 g
s
.40922 .84781 m .40634 .84795 L p .40909 .84795 L .834 .47 .366 r
F P
0 g
s
.42163 .84444 m .42196 .84447 L .42178 .84436 L .883 .644 .572 r
F
.42233 .84406 m .41552 .845 L .4198 .84543 L .606 .171 .188 r
F
.4213 .84621 m .42167 .84522 L .41947 .84494 L .883 .644 .572 r
F
.42167 .84522 m .42196 .84447 L .41947 .84494 L F
.42233 .84406 m .42616 .83605 L p .41552 .845 L .606 .171 .188 r
F P
0 g
s
.41947 .84494 m .42196 .84447 L .41831 .84414 L .883 .644 .572 r
F
.4213 .84621 m .43683 .85405 L .42196 .84447 L F
.37377 .82832 m .3959 .80959 L .43631 .81484 L closepath p .356 0 0 r
F P
0 g
s
.4213 .84621 m .37634 .81508 L .37575 .81573 L .883 .644 .572 r
F
.45575 .81398 m .45571 .81469 L p .48157 .76686 L .465 .19 .411 r
F P
0 g
s
.47986 .77294 m .47938 .77311 L .37281 .79563 L .883 .644 .572 r
F
.41715 .84404 m .4213 .84621 L .41819 .84413 L F
.48157 .76686 m .47791 .77997 L .4829 .76626 L .465 .19 .411 r
F
.4805 .77287 m .47767 .77397 L .37195 .79601 L .883 .644 .572 r
F
.4805 .77287 m .37195 .79601 L .37281 .79563 L F
.39602 .78546 m .34131 .82323 L .35381 .82629 L .142 0 0 r
F
.39805 .78349 m .39395 .78636 L .39602 .78546 L F
.39395 .78636 m .34131 .82323 L .39602 .78546 L F
.45289 .72409 m .34131 .82323 L .45373 .72962 L F
.47639 .73689 m .47166 .71406 L .46898 .73732 L .63 .528 .72 r
F
.47166 .71406 m .46883 .71557 L .46898 .73732 L F
.46898 .73732 m .46647 .71684 L .46085 .71984 L F
.48399 .68754 m .48828 .70263 L .48954 .70219 L .506 .498 .782 r
F
.48338 .68818 m .48828 .70263 L .48399 .68754 L F
.49159 .72099 m .49191 .72112 L .46973 .65898 L .895 .6 .481 r
F
.48801 .71952 m .49159 .72099 L .46973 .65898 L F
.47746 .73683 m .49698 .69691 L .45809 .6486 L .63 .528 .72 r
F
.48384 .76584 m .45809 .6486 L .48251 .76644 L F
.46422 .71803 m .45373 .72962 L .47378 .71293 L .142 0 0 r
F
.45289 .72409 m .45373 .72962 L .46422 .71803 L F
.48527 .77239 m .48693 .76167 L .48072 .75167 L .63 .528 .72 r
F
.4559 .81473 m .48829 .76385 L p .45571 .81469 L .465 .19 .411 r
F P
0 g
s
.45571 .81469 m .48829 .76385 L .4882 .76389 L .465 .19 .411 r
F
.44728 .81855 m .46731 .79681 L .44375 .81736 L .627 .337 .458 r
F
.45091 .81825 m .45569 .81507 L p .45384 .81531 L .456 0 .038 r
F P
0 g
s
.4488 .81843 m .45091 .81825 L .45384 .81531 L .456 0 .038 r
F
.48549 .79306 m .48015 .797 L p .48512 .79498 L .765 .548 .603 r
F P
0 g
s
.48015 .797 m .45569 .81507 L p .48019 .79834 L .765 .548 .603 r
F P
0 g
s
.48019 .79834 m .48512 .79498 L .48015 .797 L .765 .548 .603 r
F
.47191 .83904 m .46946 .84093 L p .47451 .81902 L .948 .743 .592 r
F P
0 g
s
.45569 .81507 m .47859 .82855 L .48512 .79498 L .765 .548 .603 r
F
.4633 .81721 m .46418 .81269 L .46161 .81735 L .627 .337 .458 r
F
.46418 .81269 m .46731 .79681 L .46161 .81735 L F
.45571 .81469 m .45569 .81507 L .4559 .81473 L p .465 .19 .411 r
F P
0 g
s
.46161 .81735 m .46731 .79681 L .44728 .81855 L .627 .337 .458 r
F
.43879 .84635 m .44046 .85561 L .44289 .85571 L .834 .47 .366 r
F
.44661 .86089 m .45241 .87743 L .4487 .86157 L F
.44491 .86033 m .44576 .86226 L .44661 .86089 L F
.44576 .86226 m .45241 .87743 L .44661 .86089 L F
.44661 .86089 m .44789 .85881 L .44592 .85909 L .156 0 0 r
F
.44661 .86089 m .44592 .85909 L p .44374 .85995 L .72 .21 .01 r
F P
0 g
s
.47708 .79927 m .47121 .8036 L p .4787 .78687 L .778 .572 .62 r
F P
0 g
s
.46391 .81991 m .46683 .84037 L .47017 .83701 L .765 .548 .603 r
F
.46391 .81991 m .47017 .83701 L .47239 .8249 L F
.47238 .84124 m .46946 .84093 L .47011 .84107 L .736 .35 .32 r
F
.47011 .84107 m .47859 .82855 L p .46683 .84037 L .765 .548 .603 r
F P
0 g
s
.45435 .85259 m .44592 .85909 L .44737 .85589 L p .948 .743 .592 r
F P
0 g
s
.46748 .84494 m .45767 .84543 L p .45482 .85665 L .834 .47 .366 r
F P
0 g
s
.45767 .84543 m .45611 .8455 L p .4556 .84988 L .834 .47 .366 r
F P
0 g
s
.4556 .84988 m .45482 .85665 L .45767 .84543 L .834 .47 .366 r
F
.45435 .85259 m .44592 .85909 L p .4538 .85378 L .736 .35 .32 r
F P
0 g
s
.4522 .85184 m .45241 .87743 L .45611 .8455 L .834 .47 .366 r
F
.46778 .84451 m .51347 .77706 L p .46881 .84391 L .796 .591 .624 r
F P
0 g
s
.46055 .82739 m .46557 .84011 L p .46391 .81991 L .765 .548 .603 r
F P
0 g
s
.46557 .84011 m .46748 .84494 L p .46683 .84037 L .765 .548 .603 r
F P
0 g
s
.46557 .84011 m .46683 .84037 L .46391 .81991 L .765 .548 .603 r
F
.4644 .84484 m .45435 .85259 L p .47202 .84147 L .736 .35 .32 r
F P
0 g
s
.47238 .84124 m .47192 .84145 L .47202 .84147 L .736 .35 .32 r
F
.47192 .84145 m .4644 .84484 L .47202 .84147 L F
.47238 .84124 m .47238 .84124 L p .47237 .84125 L .322 0 .233 r
F P
0 g
s
.47238 .84124 m .45435 .85259 L .4538 .85378 L .736 .35 .32 r
F
.45611 .8455 m .45215 .8457 L p .4522 .85184 L .834 .47 .366 r
F P
0 g
s
.46946 .84093 m .45435 .85259 L p .47979 .78445 L .948 .743 .592 r
F P
0 g
s
.44592 .85909 m .44805 .85726 L .44682 .85737 L .908 .809 .739 r
F
.44838 .85802 m .44879 .85735 L .44592 .85909 L .156 0 0 r
F
.44592 .85909 m .4489 .85719 L .44805 .85726 L .908 .809 .739 r
F
.44737 .85589 m .4477 .85729 L .45215 .8457 L .834 .47 .366 r
F
.4489 .85719 m .45241 .87743 L .45224 .85688 L F
.44801 .85862 m .45241 .87743 L .4489 .85719 L F
.4489 .85719 m .45224 .85688 L .4522 .85184 L F
.46237 .85596 m .46748 .84494 L p .45482 .85665 L F P
0 g
s
.46772 .84492 m .45998 .86467 L .45845 .86471 L .923 .598 .408 r
F
.45241 .87743 m .46237 .85596 L p .45482 .85665 L .834 .47 .366 r
F P
0 g
s
.44787 .87038 m .47238 .84124 L .44784 .8701 L .736 .35 .32 r
F
.46899 .84381 m .46748 .84494 L p .46912 .84372 L .885 .968 .839 r
F P
0 g
s
.46748 .84494 m .46778 .84451 L p .46881 .84391 L .796 .591 .624 r
F P
0 g
s
.44784 .8701 m .47238 .84124 L .4538 .85378 L .736 .35 .32 r
F
.44396 .87501 m .44664 .88986 L .44775 .86682 L .834 .47 .366 r
F
.44723 .86795 m .44763 .87066 L p .4538 .85378 L .736 .35 .32 r
F P
0 g
s
.45803 .88537 m .47409 .86171 L .46023 .87581 L .602 .252 .349 r
F
.49746 .82727 m .4723 .84171 L .47227 .8419 L F
.4723 .84171 m .47218 .84178 L .47227 .8419 L F
.47227 .8419 m .47218 .84178 L .47211 .842 L F
.46763 .86945 m .47238 .84124 L p .45935 .87678 L .322 0 .233 r
F P
0 g
s
.52 .81184 m .49539 .83478 L .50224 .82414 L .453 .096 .269 r
F
.49746 .82727 m .49856 .82533 L p .47909 .83782 L .602 .252 .349 r
F P
0 g
s
.45831 .86472 m .45845 .86471 L .45166 .87921 L .923 .598 .408 r
F
.45831 .86472 m .45166 .87921 L .4516 .87918 L F
.46237 .85596 m .46252 .85601 L .45845 .86471 L F
.45831 .86472 m .46237 .85596 L p .45845 .86471 L F P
0 g
s
.46766 .8541 m .44587 .91325 L .44718 .90994 L .322 0 .233 r
F
.46764 .85413 m .44587 .91325 L .46766 .8541 L F
.45998 .86467 m .45506 .87552 L .4549 .87527 L .923 .598 .408 r
F
.46662 .8518 m .46304 .86457 L .45998 .86467 L F
.46304 .86457 m .46292 .865 L .45998 .86467 L F
.46679 .85147 m .46292 .865 L .46662 .8518 L F
.46259 .86554 m .46151 .87025 L .44353 .89655 L F
.46833 .86529 m .47238 .84124 L p .44763 .87066 L .736 .35 .32 r
F P
0 g
s
.52318 .81229 m .52199 .81161 L .44884 .85727 L .156 0 0 r
F
.44879 .85735 m .44884 .85727 L .44592 .85909 L F
.52318 .81229 m .44884 .85727 L .44879 .85735 L F
.4477 .85729 m .4489 .85719 L .45215 .8457 L .834 .47 .366 r
F
.4489 .85719 m .4522 .85184 L .45215 .8457 L F
.48593 .85329 m .48524 .84196 L .44838 .85802 L .156 0 0 r
F
.44789 .85881 m .44838 .85802 L .44592 .85909 L F
.44884 .85727 m .4489 .85719 L .44592 .85909 L F
.42159 .8456 m .4334 .85215 L .41988 .84543 L .763 .323 0 r
F
.37281 .79563 m .37195 .79601 L .30469 .81002 L .883 .644 .572 r
F
.39655 .77723 m .34131 .82323 L .39805 .78349 L .142 0 0 r
F
.45373 .72962 m .35381 .82629 L .37167 .82024 L F
.45373 .72962 m .39655 .77723 L .39805 .78349 L F
.33398 .78778 m .40787 .78026 L .34889 .79728 L .883 .644 .572 r
F
.33398 .78778 m .34889 .79728 L .30469 .81002 L F
.31362 .78986 m .33398 .78778 L .30469 .81002 L F
.40787 .78026 m .37281 .79563 L .30469 .81002 L F
.42864 .83088 m .43631 .81484 L p .41466 .83951 L .606 .171 .188 r
F P
0 g
s
.43917 .85556 m .44046 .85561 L .33398 .78778 L .883 .644 .572 r
F
.43804 .85552 m .44664 .88986 L .44055 .85612 L .834 .47 .366 r
F
.41263 .85449 m .44664 .88986 L .43804 .85552 L F
.43917 .85556 m .44055 .85612 L .44046 .85561 L F
.44507 .84605 m .43879 .84635 L p .4436 .85734 L F P
0 g
s
.4436 .85734 m .44494 .85788 L .44507 .84605 L .834 .47 .366 r
F
.42159 .8456 m .42233 .84406 L p .4198 .84543 L .606 .171 .188 r
F P
0 g
s
.42159 .8456 m .42233 .84406 L p .44592 .85909 L .886 .511 .323 r
F P
0 g
s
.44289 .85571 m .44296 .85709 L .4436 .85734 L .834 .47 .366 r
F
.44592 .85909 m .44108 .85908 L p .44055 .85612 L .886 .511 .323 r
F P
0 g
s
.44489 .85786 m .44592 .85909 L .44055 .85612 L .763 .323 0 r
F
.44046 .85561 m .44396 .87501 L .44289 .85571 L .834 .47 .366 r
F
.44489 .85786 m .43917 .85556 L .41868 .84484 L .763 .323 0 r
F
.41518 .859 m .42159 .8456 L p .44055 .85612 L .886 .511 .323 r
F P
0 g
s
.44108 .85908 m .41518 .859 L p .44055 .85612 L .886 .511 .323 r
F P
0 g
s
.4436 .85734 m .44491 .86033 L .44494 .85788 L .834 .47 .366 r
F
.44495 .85704 m .44737 .85589 L .44507 .84605 L F
.46205 .82355 m .4633 .81721 L .45091 .81825 L .627 .337 .458 r
F
.46205 .82355 m .45091 .81825 L .45061 .81968 L F
.4787 .78687 m .47121 .8036 L .46815 .79607 L .778 .572 .62 r
F
.46205 .82355 m .4787 .78687 L p .46731 .79681 L .627 .337 .458 r
F P
0 g
s
.44046 .85561 m .44737 .85589 L .47979 .78445 L .883 .644 .572 r
F
.44046 .85561 m .47979 .78445 L .47974 .78265 L F
.42528 .83533 m .45091 .81825 L p .43879 .84635 L .878 .593 .501 r
F P
0 g
s
.44897 .82751 m .43879 .84635 L .45091 .81825 L .878 .593 .501 r
F
.44507 .84605 m .43879 .84635 L p .44897 .82751 L F P
0 g
s
.42233 .84406 m .42616 .83605 L p .4398 .85195 L .886 .511 .323 r
F P
0 g
s
.42233 .84406 m .4398 .85195 L .44046 .85561 L .886 .511 .323 r
F
.42864 .83088 m .43631 .81484 L .4373 .81939 L p F P
0 g
s
.4694 .78615 m .43631 .81484 L p .44375 .81736 L .627 .337 .458 r
F P
0 g
s
.46731 .79681 m .4694 .78615 L .44375 .81736 L .627 .337 .458 r
F
.41938 .78968 m .3959 .80959 L .42973 .78471 L p 0 0 0 r
F P
0 g
s
.33398 .78778 m .44046 .85561 L .47108 .79875 L .883 .644 .572 r
F
.43582 .84701 m .44489 .85786 L .4334 .85215 L .763 .323 0 r
F
.43582 .84701 m .4334 .85215 L .42159 .8456 L F
.44489 .85786 m .44661 .86089 L .44592 .85909 L F
.44491 .86033 m .44661 .86089 L .4477 .85729 L .834 .47 .366 r
F
.44661 .86089 m .4487 .86157 L .44801 .85862 L F
.44661 .86089 m .44801 .85862 L .4477 .85729 L F
.52199 .81161 m .52091 .81099 L .4489 .85719 L .156 0 0 r
F
.52199 .81161 m .4489 .85719 L .44884 .85727 L F
.48593 .85329 m .44838 .85802 L .44789 .85881 L F
.4477 .85729 m .44801 .85862 L .4489 .85719 L .834 .47 .366 r
F
.44737 .85589 m .47979 .78445 L p .45435 .85259 L .948 .743 .592 r
F P
0 g
s
.44592 .85909 m .44667 .85739 L .44728 .85608 L .908 .809 .739 r
F
.44494 .85754 m .44667 .85739 L .44737 .85589 L .834 .47 .366 r
F
.44592 .85909 m .44728 .85608 L .44731 .85604 L .908 .809 .739 r
F
.44494 .85754 m .44737 .85589 L .44495 .85704 L .834 .47 .366 r
F
.47974 .78265 m .47979 .78445 L .48527 .77239 L .883 .644 .572 r
F
.48836 .76527 m .4787 .78687 L .47789 .78124 L .778 .572 .62 r
F
.44737 .85589 m .48427 .77446 L .47979 .78445 L .908 .809 .739 r
F
.44592 .85909 m .44731 .85604 L .44737 .85589 L F
.44731 .85604 m .48427 .77446 L .44737 .85589 L F
.44491 .86033 m .44569 .85949 L .44494 .85754 L .834 .47 .366 r
F
.44667 .85739 m .4477 .85729 L .44737 .85589 L F
.44731 .85604 m .48393 .77517 L .48241 .77857 L .908 .809 .739 r
F
.44728 .85608 m .48393 .77517 L .44731 .85604 L F
.48241 .77857 m .48393 .77517 L .48427 .77446 L F
.47979 .78445 m .48427 .77446 L .48527 .77239 L F
.48303 .77705 m .48825 .76548 L .48527 .77239 L F
.48836 .76527 m .47945 .79213 L .4787 .78687 L .778 .572 .62 r
F
.47945 .79213 m .47708 .79927 L .4787 .78687 L F
.44728 .85608 m .47205 .79986 L .48393 .77517 L .908 .809 .739 r
F
.44667 .85739 m .47205 .79986 L .44728 .85608 L F
.4887 .76452 m .48836 .76527 L .48829 .76385 L .778 .572 .62 r
F
.48829 .76385 m .48836 .76527 L .46815 .79607 L F
.47205 .79986 m .49311 .7542 L .48825 .76548 L .908 .809 .739 r
F
.47205 .79986 m .48825 .76548 L .48303 .77705 L F
.4829 .76626 m .47791 .77997 L .4882 .76389 L .465 .19 .411 r
F
.46731 .79681 m .48829 .76385 L p .46815 .79607 L .778 .572 .62 r
F P
0 g
s
.40434 .78416 m .47108 .79875 L .47776 .78038 L .883 .644 .572 r
F
.39653 .79278 m .47108 .79875 L .40434 .78416 L F
.40787 .78026 m .47986 .77294 L .47776 .77338 L F
.33398 .78778 m .47776 .78038 L .47674 .77325 L F
.48251 .76644 m .47639 .73689 L .46898 .73732 L .63 .528 .72 r
F
.48693 .76167 m .49698 .69691 L .48072 .75167 L F
.48963 .75621 m .49283 .74767 L .48757 .75759 L F
.48757 .75759 m .49283 .74767 L .48993 .74238 L F
.48782 .76406 m .49283 .74767 L .48647 .76466 L F
.49354 .74897 m .42872 .79884 L .49409 .75202 L .819 .466 .389 r
F
.42872 .79884 m .43024 .79855 L .49409 .75202 L F
.41715 .84404 m .41819 .84413 L .33398 .78778 L .883 .644 .572 r
F
.41831 .84414 m .42163 .84444 L .37634 .81508 L F
.42163 .84444 m .42178 .84436 L .37634 .81508 L F
.43466 .84562 m .41715 .84404 L .43083 .84386 L .763 .323 0 r
F
.31362 .78986 m .41715 .84404 L .33398 .78778 L .883 .644 .572 r
F
.43083 .84386 m .41715 .84404 L .37167 .82024 L .763 .323 0 r
F
.43083 .84386 m .37167 .82024 L .37622 .81869 L F
.33398 .78778 m .39653 .79278 L .40434 .78416 L .883 .644 .572 r
F
.40854 .81437 m .43316 .84383 L .38309 .81636 L .763 .323 0 r
F
.47378 .71293 m .45373 .72962 L .40312 .80461 L .142 0 0 r
F
.40325 .80518 m .40312 .80461 L .39877 .81104 L F
.47378 .71293 m .40312 .80461 L .40325 .80518 L F
.40854 .81437 m .38309 .81636 L .3991 .81093 L .763 .323 0 r
F
.45373 .72962 m .37167 .82024 L .39877 .81104 L .142 0 0 r
F
.37575 .81573 m .37634 .81508 L .33398 .78778 L .883 .644 .572 r
F
.32225 .783 m .38309 .81636 L .31362 .78986 L .763 .323 0 r
F
.38309 .81636 m .43316 .84383 L .37695 .81845 L F
.38309 .81636 m .37695 .81845 L .31362 .78986 L F
.37195 .83255 m .37377 .82832 L p .3581 .82768 L .333 0 0 r
F P
0 g
s
.43316 .84383 m .43083 .84386 L .31362 .78986 L .763 .323 0 r
F
.37167 .82024 m .35381 .82629 L .36394 .82877 L .142 0 0 r
F
.37117 .83436 m .37195 .83255 L p .3581 .82768 L .333 0 0 r
F P
0 g
s
.47378 .71293 m .39877 .81104 L .40097 .8103 L .142 0 0 r
F
.33352 .77404 m .40854 .81437 L .32225 .783 L .763 .323 0 r
F
.50187 .73037 m .50367 .72396 L .49268 .74816 L .63 .528 .72 r
F
.48072 .75167 m .48526 .73638 L .47746 .73683 L F
.48526 .73638 m .49698 .69691 L .47746 .73683 L F
.47378 .71293 m .40097 .8103 L .49354 .74897 L .142 0 0 r
F
.40444 .808 m .40854 .81437 L .49354 .74897 L F
.40097 .8103 m .40854 .81437 L .40444 .808 L F
.40854 .81437 m .40854 .81437 L .40444 .808 L F
.35834 .75431 m .40854 .81437 L .33352 .77404 L .763 .323 0 r
F
.40854 .81437 m .40854 .81437 L .33352 .77404 L F
.43316 .84383 m .43466 .84562 L .43083 .84386 L F
.40854 .81437 m .43359 .84517 L .43316 .84383 L F
.40854 .81437 m .43359 .84517 L .40854 .81437 L F
.40876 .81476 m .40891 .81494 L .40854 .81437 L F
.40891 .81494 m .43359 .84517 L .40854 .81437 L F
.40097 .8103 m .38625 .82999 L .40854 .81437 L .142 0 0 r
F
.35498 .82658 m .37365 .83115 L p .39179 .83953 L 0 .405 .757 r
F P
0 g
s
.37365 .83115 m .37767 .83251 L .39179 .83953 L 0 .405 .757 r
F
.37767 .83251 m .382 .83397 L .38264 .83433 L F
.37767 .83251 m .38264 .83433 L .39179 .83953 L F
.40854 .81437 m .38715 .83082 L .40885 .81492 L .819 .466 .389 r
F
.38715 .83082 m .38698 .83095 L .38716 .83082 L F
.38715 .83082 m .38716 .83082 L .40885 .81492 L F
.39877 .81104 m .36394 .82877 L .37463 .83139 L .142 0 0 r
F
.3762 .8312 m .37767 .83251 L .37578 .83125 L .287 .546 .921 r
F
.39877 .81104 m .37463 .83139 L .38142 .83058 L .142 0 0 r
F
.3861 .8301 m .37767 .83251 L p .3762 .8312 L .287 .546 .921 r
F P
0 g
s
.39877 .81104 m .38142 .83058 L .38596 .83003 L .142 0 0 r
F
.37167 .82024 m .36394 .82877 L .39877 .81104 L F
.3861 .8301 m .3762 .8312 L .386 .83003 L .287 .546 .921 r
F
.40097 .8103 m .39877 .81104 L .38596 .83003 L .142 0 0 r
F
.38698 .83095 m .38338 .83155 L .39172 .83724 L .266 .432 .841 r
F
.38338 .83155 m .38115 .83193 L .38667 .83554 L F
.38115 .83193 m .37767 .83251 L .38386 .83459 L F
.38115 .83193 m .38386 .83459 L .38667 .83554 L F
.39465 .84379 m .38952 .84125 L .40082 .84605 L 0 .405 .757 r
F
.37117 .83436 m .37195 .83255 L p .39835 .84654 L .51 0 0 r
F P
0 g
s
.39465 .84379 m .39835 .84654 L p .37195 .83255 L .51 0 0 r
F P
0 g
s
.41232 .8576 m .39466 .84524 L .38836 .83759 L .713 .229 0 r
F
.40651 .85258 m .41518 .859 L .42159 .8456 L p .606 .171 .188 r
F P
0 g
s
.42159 .8456 m .4198 .84543 L .40651 .85258 L .606 .171 .188 r
F
.4198 .84543 m .41552 .845 L .40651 .85258 L F
.40634 .84795 m .40082 .84605 L p .40503 .84522 L .502 .011 .023 r
F P
0 g
s
.40557 .84512 m .40634 .84795 L p .40503 .84522 L .502 .011 .023 r
F P
0 g
s
.40634 .84795 m .40762 .84962 L p .40692 .84915 L .713 .229 0 r
F P
0 g
s
.38356 .83358 m .40381 .84708 L .40082 .84605 L p 0 .405 .757 r
F P
0 g
s
.37767 .83251 m .37117 .83436 L p .39014 .83975 L .266 .432 .841 r
F P
0 g
s
.40634 .84795 m .40692 .84915 L .38688 .83579 L .713 .229 0 r
F
.38667 .83554 m .40634 .84795 L p .38688 .83579 L F P
0 g
s
.40762 .84962 m .41232 .8576 L .38836 .83759 L .713 .229 0 r
F
.37961 .83261 m .38448 .83424 L .39179 .83953 L 0 .405 .757 r
F
.40762 .84962 m .38836 .83759 L .38688 .83579 L .713 .229 0 r
F
.40097 .8103 m .38596 .83003 L .38624 .83 L .142 0 0 r
F
.38625 .82999 m .38629 .83004 L .40854 .81437 L F
.38629 .83004 m .38715 .83082 L .40854 .81437 L F
.38698 .83095 m .38704 .83101 L .40885 .81492 L .819 .466 .389 r
F
.38667 .83554 m .39014 .83975 L .39835 .84208 L .266 .432 .841 r
F
.38667 .83554 m .39835 .84208 L .39475 .83855 L F
.4516 .87918 m .45166 .87921 L .44353 .89655 L .923 .598 .408 r
F
.45972 .87645 m .45935 .87678 L .45381 .89187 L .322 0 .233 r
F
.46763 .86945 m .45972 .87645 L .45381 .89187 L F
.45972 .87645 m .44888 .88991 L p .45886 .87721 L 0 0 0 r
F P
0 g
s
.44877 .88994 m .45886 .87721 L .44888 .88991 L 0 0 0 r
F
.45751 .87891 m .45754 .87855 L .45886 .87721 L F
.4607 .87294 m .45921 .8769 L .45926 .87686 L .322 0 .233 r
F
.44888 .88991 m .44353 .89655 L p .44877 .88994 L 0 0 0 r
F P
0 g
s
.45972 .87645 m .44353 .89655 L p .46142 .87038 L .923 .598 .408 r
F P
0 g
s
.45353 .892 m .44719 .9096 L p .4537 .89192 L .322 0 .233 r
F P
0 g
s
.44915 .89811 m .44966 .89378 L .45451 .89155 L .156 0 0 r
F
.45522 .89122 m .44923 .90434 L .44949 .90455 L .322 0 .233 r
F
.45522 .89122 m .44725 .90975 L .44734 .90997 L F
.45734 .89025 m .45522 .89122 L .44598 .91322 L F
.46109 .90829 m .4647 .88686 L p .44598 .91322 L F P
0 g
s
.4647 .88686 m .45734 .89025 L .44598 .91322 L .322 0 .233 r
F
.46196 .89083 m .44915 .89811 L .45451 .89155 L .156 0 0 r
F
.46109 .90829 m .4647 .88686 L p .45468 .90139 L .736 .35 .32 r
F P
0 g
s
.46731 .89031 m .46022 .89335 L .46196 .89083 L .156 0 0 r
F
.46022 .89335 m .44915 .89811 L .46196 .89083 L F
.46731 .89031 m .45451 .89155 L .46645 .88605 L F
.45889 .89918 m .45639 .89891 L .46731 .89031 L F
.45639 .89891 m .44915 .89811 L .46022 .89335 L F
.45639 .89891 m .46022 .89335 L .46731 .89031 L F
.52382 .82514 m .52318 .81229 L .44879 .85735 L F
.52382 .82514 m .44879 .85735 L .44838 .85802 L F
.53335 .81807 m .52318 .81229 L .52382 .82514 L F
.52013 .81149 m .52369 .80841 L .54981 .69765 L .908 .809 .739 r
F
.52013 .81149 m .54981 .69765 L .5494 .69505 L F
.55166 .70938 m .56213 .71605 L .56595 .6292 L F
.54574 .7242 m .55779 .73803 L .55213 .69765 L .783 .69 .761 r
F
.52805 .7899 m .55166 .70938 L .54981 .69765 L .908 .809 .739 r
F
.52369 .80841 m .52907 .78935 L .52805 .7899 L F
.52907 .78935 m .55166 .70938 L .52805 .7899 L F
.56023 .77512 m .52369 .80841 L .55128 .78269 L .453 .096 .269 r
F
.5034 .82222 m .52013 .81149 L .50721 .80634 L .908 .809 .739 r
F
.51742 .77372 m .50645 .80144 L .52419 .79196 L .082 0 .156 r
F
.50721 .80634 m .52013 .81149 L .52535 .79073 L .908 .809 .739 r
F
.52013 .81149 m .52091 .81099 L .52369 .80841 L F
.52419 .79196 m .4969 .84514 L .53368 .81755 L .082 0 .156 r
F
.4969 .84514 m .48128 .87557 L .53295 .81837 L F
.4969 .84514 m .53295 .81837 L .53368 .81755 L F
.4879 .88574 m .49342 .8782 L .49408 .87532 L .156 0 0 r
F
.49342 .8782 m .53625 .81973 L .49408 .87532 L F
.48128 .87557 m .52353 .831 L .53368 .81755 L .082 0 .156 r
F
.52755 .82676 m .52798 .82631 L .53335 .81807 L F
.52755 .82676 m .53335 .81807 L .53333 .81808 L F
.53211 .82302 m .52798 .82631 L .5328 .82123 L .156 0 0 r
F
.49408 .87532 m .53625 .81973 L .52382 .82514 L F
.48815 .88978 m .53625 .81973 L .4879 .88574 L F
.47412 .88312 m .48128 .87557 L .52419 .79196 L .082 0 .156 r
F
.46484 .9093 m .47581 .88004 L .47603 .87965 L F
.46484 .9093 m .46462 .90951 L .47581 .88004 L F
.48705 .85046 m .47574 .88017 L .52419 .79196 L F
.46484 .9093 m .48593 .85339 L .48593 .85341 L F
.48567 .87606 m .48449 .89084 L .46578 .90687 L F
.48449 .89084 m .46642 .90782 L .46578 .90687 L F
.48599 .8544 m .48567 .87606 L .46578 .90687 L F
.48599 .85324 m .47412 .88312 L .47574 .88017 L F
.48593 .85329 m .47412 .88312 L .48599 .85324 L F
.4879 .88574 m .52382 .82514 L .48593 .85329 L .156 0 0 r
F
.48777 .84979 m .4866 .8644 L .48599 .8544 L .082 0 .156 r
F
.4866 .8644 m .48567 .87606 L .48599 .8544 L F
.47011 .88163 m .47012 .88122 L .4718 .88202 L .156 0 0 r
F
.48705 .85046 m .48593 .85329 L .48599 .85324 L .082 0 .156 r
F
.48705 .85046 m .47415 .88435 L .47356 .88452 L F
.48833 .89281 m .48137 .92985 L .4866 .8644 L F
.45369 .93474 m .45366 .93481 L .45369 .93477 L F
.47356 .88452 m .45482 .93487 L .45366 .93481 L F
.46884 .91793 m .47011 .88163 L .48772 .88961 L .156 0 0 r
F
.46866 .91779 m .46983 .88764 L .46884 .91793 L F
.46983 .88764 m .4699 .88757 L .46884 .91793 L F
.46109 .90829 m .44838 .91243 L .44892 .91371 L .322 0 .233 r
F
.4593 .91887 m .46017 .9137 L p .45665 .91422 L .736 .35 .32 r
F P
0 g
s
.46017 .9137 m .46109 .90829 L p .45842 .91185 L .736 .35 .32 r
F P
0 g
s
.46017 .9137 m .45842 .91185 L .45665 .91422 L .736 .35 .32 r
F
.4567 .91726 m .45671 .91791 L .4487 .91317 L .154 0 .282 r
F
.44892 .91371 m .45015 .91661 L .4517 .91699 L .322 0 .233 r
F
.45671 .91791 m .45015 .91661 L .4487 .91317 L .154 0 .282 r
F
.4593 .91887 m .45665 .91422 L .45671 .91791 L .736 .35 .32 r
F
.46484 .9093 m .45498 .93488 L .46462 .90951 L .082 0 .156 r
F
.45749 .91904 m .44928 .91667 L .48272 .92326 L .498 .362 .626 r
F
.45658 .9099 m .46109 .90829 L .45647 .90331 L .736 .35 .32 r
F
.45665 .91422 m .45842 .91185 L .45658 .9099 L F
.45842 .91185 m .46109 .90829 L .45658 .9099 L F
.44657 .90126 m .44456 .89828 L .44915 .89811 L .156 0 0 r
F
.44456 .89828 m .44524 .89767 L .44915 .89811 L F
.45196 .90506 m .45086 .90463 L .45285 .90596 L 0 .06 .599 r
F
.44998 .90367 m .45086 .90463 L .45196 .90506 L F
.44949 .90455 m .44923 .90434 L .44725 .90975 L .322 0 .233 r
F
.45268 .91521 m .4487 .91317 L .44465 .9036 L .154 0 .282 r
F
.45268 .91521 m .44465 .9036 L .44464 .90357 L F
.45749 .91904 m .48272 .92326 L .48291 .92335 L .498 .362 .626 r
F
.48815 .88981 m .53625 .81973 L .48815 .88978 L .156 0 0 r
F
.49059 .89097 m .4887 .89891 L .50313 .83559 L .082 0 .156 r
F
.4887 .89891 m .48866 .89827 L .50313 .83559 L F
.48276 .92328 m .48291 .92335 L .49059 .89097 L .819 .466 .389 r
F
.47011 .88163 m .4718 .88202 L .48772 .88961 L .156 0 0 r
F
.46763 .86945 m .45381 .89187 L .45734 .89025 L .322 0 .233 r
F
.4517 .89818 m .46833 .86529 L .44763 .87066 L .736 .35 .32 r
F
.46934 .90034 m .46531 .88044 L .47009 .8812 L .156 0 0 r
F
.47456 .88333 m .47454 .88332 L .48705 .85046 L .082 0 .156 r
F
.46531 .88044 m .46561 .88015 L .47009 .8812 L .156 0 0 r
F
.4647 .88686 m .46763 .86945 L p .45734 .89025 L .322 0 .233 r
F P
0 g
s
.45662 .91214 m .45268 .91521 L .44464 .90357 L .154 0 .282 r
F
.4567 .91715 m .45268 .91521 L .45662 .91214 L F
.48212 .923 m .48276 .92328 L .48907 .89344 L .819 .466 .389 r
F
.48284 .92329 m .44928 .91667 L .48201 .92295 L .498 .362 .626 r
F
.48378 .90779 m .48187 .9229 L .48212 .923 L .819 .466 .389 r
F
.48454 .90085 m .48212 .923 L .48907 .89344 L F
.44928 .91667 m .45126 .91683 L .48336 .92321 L .498 .362 .626 r
F
.47718 .92771 m .45268 .91521 L .47805 .92747 L .154 0 .282 r
F
.44737 .90249 m .45658 .9099 L p .44709 .90221 L 0 .06 .599 r
F P
0 g
s
.45658 .9099 m .45647 .90331 L .45587 .90915 L .736 .35 .32 r
F
.45658 .9099 m .46977 .92051 L p .45645 .90976 L 0 .06 .599 r
F P
0 g
s
.44709 .90221 m .45658 .9099 L .45645 .90976 L 0 .06 .599 r
F
.45587 .90915 m .45647 .90331 L .45468 .90139 L .736 .35 .32 r
F
.45642 .90973 m .46977 .92051 L .46978 .9205 L 0 .06 .599 r
F
.44709 .90221 m .45645 .90976 L .45642 .90973 L F
.45645 .90976 m .46977 .92051 L .45642 .90973 L F
.45262 .90437 m .45285 .90596 L p .45468 .90139 L .736 .35 .32 r
F P
0 g
s
.45285 .90596 m .45086 .90463 L .45425 .90743 L 0 .06 .599 r
F
.45071 .90453 m .45292 .90691 L .45644 .90975 L F
.45042 .90427 m .4506 .90446 L .45071 .90453 L F
.4506 .90446 m .45292 .90691 L .45071 .90453 L F
.45461 .90781 m .45468 .90139 L .45285 .90596 L .736 .35 .32 r
F
.45461 .90781 m .45587 .90915 L .45468 .90139 L F
.47022 .92003 m .45845 .90968 L p .4685 .91766 L 0 .056 .566 r
F P
0 g
s
.4685 .91766 m .45845 .90968 L .46187 .91238 L 0 .056 .566 r
F
.46883 .91803 m .47022 .92003 L .4685 .91766 L F
.46578 .90687 m .46642 .90782 L .46602 .90819 L .082 0 .156 r
F
.46578 .90687 m .46602 .90819 L .46484 .9093 L F
.46864 .91824 m .4537 .90281 L .46934 .90034 L .156 0 0 r
F
.4537 .90281 m .45639 .89891 L .46934 .90034 L F
.45839 .89157 m .46833 .86529 L .45695 .88781 L .736 .35 .32 r
F
.45839 .89157 m .45695 .88781 L .4517 .89818 L F
.4537 .90281 m .44915 .89811 L .45639 .89891 L .156 0 0 r
F
.45468 .90139 m .45839 .89157 L .4517 .89818 L .736 .35 .32 r
F
.45845 .90968 m .45683 .90802 L .45683 .9084 L 0 0 .307 r
F
.46187 .91238 m .45974 .91054 L .45845 .90968 L F
.45974 .91054 m .45683 .90802 L .45845 .90968 L F
.47022 .92003 m .45845 .90968 L p .4699 .92037 L 0 .06 .599 r
F P
0 g
s
.45713 .9088 m .4699 .92037 L .45845 .90968 L 0 .06 .599 r
F
.46187 .91238 m .45683 .9084 L .46814 .9178 L 0 0 .307 r
F
.45496 .9064 m .4548 .90626 L .45488 .9073 L F
.46428 .91373 m .45974 .91054 L .44915 .89811 L .156 0 0 r
F
.45974 .91054 m .44758 .90002 L .44915 .89811 L F
.45602 .90732 m .45488 .9073 L .45599 .90804 L 0 0 .307 r
F
.4647 .88686 m .46833 .86529 L p .45468 .90139 L .736 .35 .32 r
F P
0 g
s
.45678 .88736 m .45496 .9064 L .45602 .90732 L 0 0 .307 r
F
.45496 .9064 m .45488 .9073 L .45602 .90732 L F
.46842 .92445 m .46996 .93094 L .45986 .93359 L .082 0 .156 r
F
.48191 .92318 m .48137 .92985 L .47619 .92221 L F
.47935 .92711 m .47998 .92763 L p .47877 .92792 L .318 .46 .846 r
F P
0 g
s
.47877 .92792 m .4595 .93258 L .47832 .92739 L .318 .46 .846 r
F
.47877 .92792 m .47832 .92739 L .47935 .92711 L F
.44737 .90249 m .46977 .92051 L p .4473 .90547 L .154 0 .282 r
F P
0 g
s
.46776 .92011 m .4473 .90547 L .46977 .92051 L .154 0 .282 r
F
.457 .90871 m .4699 .92037 L .45713 .9088 L 0 .06 .599 r
F
.45015 .91661 m .45011 .9166 L .4487 .91317 L .154 0 .282 r
F
.44682 .9142 m .44816 .92827 L .44465 .91664 L F
.44699 .91598 m .44682 .9142 L .4302 .91094 L .506 .148 .294 r
F
.45366 .93481 m .45001 .94778 L .45218 .93854 L .082 0 .156 r
F
.45218 .93854 m .45001 .94778 L .44809 .94888 L F
.4487 .91317 m .45344 .94581 L .44816 .92827 L .154 0 .282 r
F
.44587 .91325 m .44511 .91536 L p .44707 .91391 L .602 .252 .349 r
F P
0 g
s
.44622 .91572 m .44707 .91391 L .44511 .91536 L .602 .252 .349 r
F
.44622 .91572 m .44702 .91598 L .44707 .91391 L F
.44892 .91371 m .44598 .91322 L .44518 .91538 L .322 0 .233 r
F
.44892 .91371 m .44518 .91538 L .45015 .91661 L F
.44587 .91325 m .44511 .91536 L p .44598 .91322 L F P
0 g
s
.44669 .91592 m .4426 .91474 L .44842 .91618 L .498 .362 .626 r
F
.4455 .91568 m .44242 .91864 L .4408 .91491 L F
.4455 .91568 m .4408 .91491 L .44187 .91456 L F
.44287 .91866 m .44242 .91864 L .4455 .91568 L F
.44187 .91456 m .4408 .91491 L .44046 .91412 L F
.44279 .91875 m .44242 .91864 L .44287 .91866 L F
.44816 .92827 m .44287 .91866 L .44415 .91721 L .154 0 .282 r
F
.44279 .91875 m .44257 .91899 L .44242 .91864 L .498 .362 .626 r
F
.44816 .92827 m .44415 .91721 L .44465 .91664 L .154 0 .282 r
F
.44046 .91412 m .44257 .91899 L .4302 .91094 L .498 .362 .626 r
F
.44287 .91866 m .44328 .92104 L .44142 .91861 L .453 .096 .269 r
F
.44142 .91861 m .43215 .92981 L .43962 .91854 L F
.44106 .91859 m .43434 .91701 L .4374 .91601 L .498 .362 .626 r
F
.43932 .91852 m .43434 .91701 L .44106 .91859 L F
.43962 .91854 m .43215 .92981 L .42216 .91786 L .453 .096 .269 r
F
.43527 .91837 m .4302 .91094 L p .43847 .92319 L .602 .163 0 r
F P
0 g
s
.44423 .93134 m .4366 .93513 L .43215 .92981 L .453 .096 .269 r
F
.4302 .91094 m .44092 .92698 L .44398 .93146 L p .602 .163 0 r
F P
0 g
s
.43847 .92319 m .4302 .91094 L .44398 .93146 L .602 .163 0 r
F
.43872 .9185 m .43527 .91837 L .43434 .91701 L .498 .362 .626 r
F
.4374 .91601 m .43434 .91701 L .4302 .91094 L F
.4302 .91094 m .44092 .92698 L .44701 .91625 L p .506 .148 .294 r
F P
0 g
s
.44598 .91322 m .44511 .91536 L .44518 .91538 L .322 0 .233 r
F
.44842 .91618 m .44046 .91412 L .45447 .91709 L .498 .362 .626 r
F
.4426 .91474 m .44046 .91412 L .44842 .91618 L F
.4455 .91568 m .44046 .91412 L .44669 .91592 L F
.46776 .92011 m .4567 .91715 L .45662 .91214 L .154 0 .282 r
F
.457 .90871 m .45285 .90596 L .4699 .92037 L 0 .06 .599 r
F
.45285 .90596 m .45425 .90743 L .4699 .92037 L F
.45493 .90805 m .45644 .90975 L .46978 .9205 L F
.45086 .90463 m .46978 .9205 L .4699 .92037 L F
.45042 .90427 m .45083 .90461 L .45086 .90463 L F
.45083 .90461 m .46978 .9205 L .45086 .90463 L F
.45083 .90461 m .45644 .90975 L .45493 .90805 L F
.45071 .90453 m .45644 .90975 L .45083 .90461 L F
.45285 .90596 m .4545 .91709 L p .45461 .90781 L .736 .35 .32 r
F P
0 g
s
.45341 .90973 m .4545 .91709 L p .45401 .90673 L 0 0 .307 r
F P
0 g
s
.4517 .89818 m .45262 .90437 L p .45468 .90139 L .736 .35 .32 r
F P
0 g
s
.45319 .8897 m .45337 .90566 L .45398 .90615 L 0 0 .307 r
F
.45683 .9084 m .45599 .90804 L .45683 .9086 L F
.45678 .88736 m .456 .90775 L .45683 .9084 L F
.456 .90775 m .45599 .90804 L .45683 .9084 L F
.46864 .91824 m .45974 .91054 L .46428 .91373 L .156 0 0 r
F
.46934 .90034 m .45889 .89918 L .46731 .89031 L F
.46836 .9175 m .45678 .88736 L p .45683 .90802 L 0 0 .307 r
F P
0 g
s
.45678 .88736 m .45341 .88845 L .4548 .90626 L 0 0 .307 r
F
.45678 .88736 m .4548 .90626 L .45496 .9064 L F
.44723 .86795 m .44852 .87664 L p .44661 .86089 L F P
0 g
s
.44852 .87664 m .45041 .88942 L p .44847 .87485 L 0 0 .307 r
F P
0 g
s
.44661 .86089 m .44852 .87664 L .44847 .87485 L 0 0 .307 r
F
.44827 .88704 m .44828 .88702 L .44869 .88661 L 0 0 0 r
F
.44876 .8854 m .44879 .88637 L .44353 .89655 L .923 .598 .408 r
F
.45678 .88736 m .4482 .86502 L p .45041 .88942 L 0 0 .307 r
F P
0 g
s
.44879 .88637 m .44883 .88794 L .44353 .89655 L .923 .598 .408 r
F
.4482 .86502 m .44847 .87485 L .45041 .88942 L 0 0 .307 r
F
.4545 .91709 m .45665 .91422 L .45587 .90915 L .736 .35 .32 r
F
.4545 .91709 m .45587 .90915 L .45461 .90781 L F
.45671 .91791 m .45665 .91422 L .4545 .91709 L F
.45319 .8897 m .4545 .91709 L .45553 .91717 L 0 0 .307 r
F
.45413 .89919 m .45398 .89899 L .45463 .90666 L F
.45341 .88845 m .45398 .89899 L .45413 .89919 L F
.45341 .88845 m .45319 .8897 L .45398 .89899 L F
.45341 .88845 m .45463 .90666 L .45464 .90667 L F
.45341 .88845 m .45468 .90717 L .4548 .90725 L F
.45341 .88845 m .45553 .91717 L .45564 .91718 L F
.4517 .89818 m .45341 .90973 L p .45319 .8897 L F P
0 g
s
.45041 .88942 m .4517 .89818 L p .45341 .88845 L 0 0 .307 r
F P
0 g
s
.44296 .85709 m .44396 .87501 L .4436 .85734 L .834 .47 .366 r
F
.44664 .88986 m .44876 .8853 L p .44753 .87139 L F P
0 g
s
.46737 .91657 m .45306 .87769 L .42856 .86561 L .72 .21 .01 r
F
.46836 .9175 m .45306 .87769 L p .46737 .91657 L F P
0 g
s
.45597 .89669 m .46697 .9154 L .45633 .89257 L .763 .323 0 r
F
.48777 .84979 m .4748 .88345 L .48705 .85046 L .082 0 .156 r
F
.4748 .88345 m .47463 .88337 L .48705 .85046 L F
.46836 .9175 m .4879 .88574 L .45306 .87769 L .156 0 0 r
F
.46883 .91792 m .4879 .88574 L .46836 .9175 L F
.44915 .89811 m .44524 .89767 L .44966 .89378 L F
.4645 .91281 m .42856 .86561 L .42133 .86582 L .72 .21 .01 r
F
.41524 .85958 m .44353 .89655 L p .41232 .8576 L .713 .229 0 r
F P
0 g
s
.43571 .88775 m .46775 .91693 L .44746 .89986 L 0 .056 .566 r
F
.4658 .91509 m .46775 .91693 L .43571 .88775 L F
.46885 .91794 m .48815 .88981 L .46883 .91792 L .156 0 0 r
F
.4696 .9168 m .48772 .88961 L .48815 .88981 L F
.48815 .88981 m .48815 .88978 L .46883 .91792 L F
.46883 .91792 m .48815 .88978 L .4879 .88574 L F
.46814 .91219 m .47267 .91619 L .469 .91805 L .521 .533 .809 r
F
.4677 .9118 m .469 .91805 L .46855 .9176 L F
.46058 .90169 m .4611 .90251 L .45633 .89257 L .763 .323 0 r
F
.46737 .91657 m .4645 .91281 L .4658 .91509 L .72 .21 .01 r
F
.45306 .87769 m .42935 .86558 L .42856 .86561 L F
.4482 .86502 m .44661 .86089 L p .44847 .87485 L 0 0 .307 r
F P
0 g
s
.45306 .87769 m .4482 .86502 L p .42935 .86558 L .72 .21 .01 r
F P
0 g
s
.43989 .86936 m .4658 .91509 L .46792 .91702 L 0 .142 .671 r
F
.46751 .91656 m .4611 .90251 L .46058 .90169 L .763 .323 0 r
F
.46751 .91656 m .46821 .91733 L .4611 .90251 L F
.47603 .87965 m .47581 .88004 L .48593 .85339 L .082 0 .156 r
F
.4879 .88574 m .48593 .85329 L .45306 .87769 L .156 0 0 r
F
.45306 .87769 m .48593 .85329 L .44789 .85881 L F
.45306 .87769 m .44789 .85881 L .44661 .86089 L F
.45633 .89257 m .45678 .88736 L .45367 .87927 L .763 .323 0 r
F
.45206 .87811 m .45367 .87927 L .4482 .86502 L F
.45633 .89257 m .45367 .87927 L .45206 .87811 L F
.4482 .86502 m .44661 .86089 L p .42935 .86558 L .72 .21 .01 r
F P
0 g
s
.44661 .86089 m .44374 .85995 L .42935 .86558 L .72 .21 .01 r
F
.42935 .86558 m .44374 .85995 L .41647 .85901 L F
.44108 .85908 m .41647 .85901 L p .44374 .85995 L F P
0 g
s
.40634 .84795 m .40861 .84849 L .40909 .84795 L .834 .47 .366 r
F
.40634 .84795 m .40777 .84944 L .40861 .84849 L F
.38704 .83101 m .40091 .84457 L .43956 .86907 L .819 .466 .389 r
F
.43308 .86457 m .43352 .86478 L p .43304 .86458 L 0 .301 .696 r
F P
0 g
s
.39583 .84646 m .39466 .84524 L p .41232 .8576 L .713 .229 0 r
F P
0 g
s
.42356 .86058 m .40532 .85287 L .4234 .86049 L 0 .301 .696 r
F
.39547 .84622 m .40968 .85315 L p .40532 .85287 L F P
0 g
s
.43956 .86907 m .40091 .84457 L .40968 .85315 L .819 .466 .389 r
F
.43956 .86907 m .40968 .85315 L .43954 .86912 L F
.40968 .85315 m .43308 .86457 L p .4234 .86049 L 0 .301 .696 r
F P
0 g
s
.4234 .86049 m .40532 .85287 L .40968 .85315 L 0 .301 .696 r
F
.43699 .86728 m .43098 .86455 L .43352 .86478 L F
.43098 .86455 m .40532 .85287 L .42356 .86058 L F
.43098 .86455 m .42356 .86058 L .43352 .86478 L F
.39835 .84208 m .39014 .83975 L .40323 .84685 L .266 .432 .841 r
F
.37767 .83251 m .39014 .83975 L .38667 .83554 L F
.38356 .83358 m .38667 .83554 L p .38688 .83579 L .713 .229 0 r
F P
0 g
s
.48579 .86802 m .45393 .87682 L .47363 .88736 L .819 .466 .389 r
F
.43466 .84562 m .43582 .84701 L .41868 .84484 L .763 .323 0 r
F
.43582 .84701 m .41988 .84543 L .41868 .84484 L F
.43466 .84562 m .41868 .84484 L .41715 .84404 L F
.40885 .81492 m .38704 .83101 L .43956 .86907 L .819 .466 .389 r
F
.40953 .81611 m .41013 .81684 L .40942 .81592 L .763 .323 0 r
F
.41013 .81684 m .43359 .84517 L .40891 .81494 L F
.41013 .81684 m .40891 .81494 L .40422 .8092 L F
.4436 .85734 m .44365 .85992 L .44491 .86033 L .834 .47 .366 r
F
.43359 .84517 m .45633 .89257 L .44759 .8641 L .763 .323 0 r
F
.44132 .8545 m .44759 .8641 L .44661 .86089 L F
.43359 .84517 m .44759 .8641 L .44132 .8545 L F
.39583 .84646 m .39466 .84524 L p .39585 .8464 L 0 .056 .566 r
F P
0 g
s
.39014 .83975 m .39466 .84524 L .43352 .86478 L .266 .432 .841 r
F
.39547 .84622 m .39585 .8464 L p .39466 .84524 L F P
0 g
s
.39585 .8464 m .43352 .86478 L p .39466 .84524 L .266 .432 .841 r
F P
0 g
s
.42133 .86582 m .4658 .91509 L p .4645 .91281 L .72 .21 .01 r
F P
0 g
s
.41647 .85901 m .41518 .859 L p .42856 .86561 L .72 .21 .01 r
F P
0 g
s
.42935 .86558 m .41647 .85901 L .42856 .86561 L .72 .21 .01 r
F
.41518 .859 m .42133 .86582 L p .42856 .86561 L F P
0 g
s
.43989 .86936 m .41518 .859 L .4658 .91509 L p 0 .142 .671 r
F P
0 g
s
.44531 .87921 m .43329 .88253 L .4495 .89847 L .819 .466 .389 r
F
.46102 .90691 m .4495 .89847 L .46475 .91348 L F
.44531 .87921 m .4495 .89847 L .46102 .90691 L F
.44579 .88302 m .45444 .89587 L .45358 .8938 L .763 .323 0 r
F
.44554 .87962 m .45358 .8938 L .44507 .87308 L F
.44579 .88302 m .45358 .8938 L .44554 .87962 L F
.44184 .87076 m .44507 .87308 L .43359 .84517 L F
.44592 .85909 m .46282 .82673 L .46135 .82411 L .908 .809 .739 r
F
.46282 .82673 m .4828 .78845 L .46135 .82411 L F
.45444 .89587 m .45633 .89257 L .43359 .84517 L .763 .323 0 r
F
.45576 .89909 m .45586 .89798 L .45444 .89587 L F
.45586 .89798 m .45633 .89257 L .45444 .89587 L F
.47986 .77294 m .4805 .77287 L .47938 .77311 L .883 .644 .572 r
F
.47674 .77325 m .47776 .78038 L .4805 .77287 L F
.47776 .78038 m .47108 .79875 L .47844 .78508 L F
.43316 .84383 m .44661 .86089 L .44489 .85786 L .763 .323 0 r
F
.43359 .84517 m .44661 .86089 L .43316 .84383 L F
.40953 .81611 m .43961 .86916 L .43359 .84517 L F
.43989 .86936 m .41872 .86049 L p .43961 .86916 L 0 .301 .696 r
F P
0 g
s
.43961 .86916 m .44357 .87615 L .44184 .87076 L .763 .323 0 r
F
.43961 .86916 m .44184 .87076 L .43359 .84517 L F
.43961 .86916 m .41872 .86049 L .43098 .86455 L 0 .301 .696 r
F
.44034 .86955 m .43989 .86936 L p .43961 .86916 L F P
0 g
s
.48647 .76466 m .48963 .75621 L .48757 .75759 L .63 .528 .72 r
F
.49409 .75202 m .40885 .81492 L .43956 .86907 L .819 .466 .389 r
F
.44569 .85949 m .4477 .85729 L .44667 .85739 L .834 .47 .366 r
F
.44569 .85949 m .44667 .85739 L .44494 .85754 L F
.49839 .81361 m .52535 .79073 L .51479 .78885 L .908 .809 .739 r
F
.51229 .79689 m .51199 .79725 L .51347 .79084 L .082 0 .156 r
F
.51371 .79048 m .51347 .79084 L .51742 .77372 L F
.51229 .79689 m .51347 .79084 L .51371 .79048 L F
.47239 .8249 m .47017 .83701 L .47859 .82855 L .765 .548 .603 r
F
.51347 .77706 m .47226 .84123 L .47068 .84111 L .796 .591 .624 r
F
.47859 .82855 m .51528 .77438 L p .50034 .78459 L .765 .548 .603 r
F P
0 g
s
.4809 .81664 m .47859 .82855 L .50034 .78459 L .765 .548 .603 r
F
.44682 .85737 m .49839 .81361 L .49709 .78571 L .908 .809 .739 r
F
.52533 .77113 m .51742 .77372 L .52926 .77354 L .082 0 .156 r
F
.51858 .77284 m .51479 .78885 L .51742 .77372 L F
.51479 .78885 m .51311 .7959 L .51436 .7895 L F
.51479 .78885 m .51436 .7895 L .51742 .77372 L F
.50048 .75466 m .49704 .78572 L .49709 .78571 L .819 .466 .389 r
F
.44682 .85737 m .49709 .78571 L .4828 .78845 L .908 .809 .739 r
F
.47205 .79986 m .47656 .78965 L .49311 .7542 L F
.46135 .82411 m .4828 .78845 L .47656 .78965 L F
.44805 .85726 m .52535 .79073 L .44682 .85737 L F
.46946 .84093 m .46935 .84101 L p .47011 .84107 L .736 .35 .32 r
F P
0 g
s
.47238 .84124 m .47238 .84124 L p .4644 .84484 L .736 .35 .32 r
F P
0 g
s
.46935 .84101 m .4644 .84484 L p .47238 .84124 L .736 .35 .32 r
F P
0 g
s
.45325 .85278 m .48559 .83365 L .50721 .80634 L .908 .809 .739 r
F
.45488 .85335 m .48559 .83365 L .45325 .85278 L F
.48559 .83365 m .5034 .82222 L .50634 .80997 L F
.48559 .83365 m .50634 .80997 L .50721 .80634 L F
.48593 .85341 m .48593 .85339 L .48705 .85046 L .082 0 .156 r
F
.50645 .80144 m .48705 .85046 L .52419 .79196 L F
.50464 .80601 m .48777 .84979 L .48705 .85046 L F
.4916 .78676 m .46089 .82328 L .48579 .86802 L .819 .466 .389 r
F
.47656 .78965 m .49355 .75318 L .49311 .7542 L .908 .809 .739 r
F
.48825 .76548 m .48915 .76348 L .48869 .76454 L F
.48825 .76548 m .48869 .76454 L .48772 .76671 L F
.49355 .75318 m .48915 .76348 L .48825 .76548 L F
.49403 .75215 m .48915 .76348 L .49355 .75318 L F
.49409 .75202 m .47656 .78965 L .4916 .78676 L .819 .466 .389 r
F
.47656 .78965 m .46089 .82328 L .4916 .78676 L F
.49823 .84012 m .48833 .89281 L .48777 .84979 L .082 0 .156 r
F
.48833 .89281 m .4866 .8644 L .48777 .84979 L F
.50464 .80601 m .49823 .84012 L .48777 .84979 L F
.50048 .75466 m .49384 .75542 L .48187 .9229 L .819 .466 .389 r
F
.51026 .74043 m .51627 .75893 L .51244 .74082 L .506 .498 .782 r
F
.50572 .7497 m .50922 .74025 L p .508 .7538 L .894 .733 .676 r
F P
0 g
s
.50922 .74025 m .50923 .74027 L .508 .7538 L .894 .733 .676 r
F
.50923 .74022 m .51028 .74442 L .508 .7538 L F
.50403 .75426 m .50572 .7497 L p .508 .7538 L F P
0 g
s
.50666 .75776 m .50382 .75722 L .51238 .76473 L .819 .466 .389 r
F
.50666 .75776 m .51238 .76473 L .51568 .76762 L F
.51061 .7585 m .50666 .75776 L .51568 .76762 L F
.50382 .75722 m .50027 .75656 L .50439 .75952 L F
.50382 .75722 m .50439 .75952 L .51568 .76762 L F
.50346 .75579 m .50403 .75426 L p .50813 .75756 L .894 .733 .676 r
F P
0 g
s
.50808 .72023 m .51627 .75893 L .51292 .73137 L .506 .498 .782 r
F
.51627 .75893 m .518 .75824 L .51292 .73137 L F
.51292 .73137 m .518 .75824 L .52273 .7443 L .783 .69 .761 r
F
.51094 .7456 m .51425 .76 L .51627 .75893 L .506 .498 .782 r
F
.48533 .78362 m .49709 .78571 L .5494 .69505 L .908 .809 .739 r
F
.51311 .7959 m .51229 .79689 L .51742 .77372 L .082 0 .156 r
F
.51229 .79689 m .51229 .79689 L .51742 .77372 L F
.51742 .77372 m .51199 .79725 L .50464 .80601 L F
.49839 .81361 m .51479 .78885 L .49709 .78571 L .908 .809 .739 r
F
.51347 .77706 m .51528 .77438 L p .51538 .77664 L .796 .591 .624 r
F P
0 g
s
.50888 .79668 m .50956 .79656 L .51568 .76762 L .819 .466 .389 r
F
.49709 .78571 m .50345 .78684 L .51568 .76762 L F
.49563 .79913 m .50888 .79668 L .51568 .76762 L F
.51199 .79725 m .50313 .83559 L .50464 .80601 L .082 0 .156 r
F
.51568 .76762 m .50854 .80138 L .51858 .77284 L .819 .466 .389 r
F
.50387 .83491 m .50313 .83559 L .51199 .79725 L .082 0 .156 r
F
.50387 .83491 m .51199 .79725 L .51229 .79689 L F
.51311 .7959 m .50388 .83485 L .51229 .79689 L F
.50388 .83485 m .50388 .83485 L .51229 .79689 L F
.50388 .83485 m .51229 .79689 L .51229 .79689 L F
.50854 .80138 m .5116 .80231 L .51858 .77284 L .819 .466 .389 r
F
.49709 .78571 m .51479 .78885 L .51738 .78181 L .908 .809 .739 r
F
.51718 .7687 m .51972 .75755 L p .51721 .76872 L .819 .694 .727 r
F P
0 g
s
.51972 .75755 m .51973 .7576 L .51721 .76872 L .819 .694 .727 r
F
.51921 .77016 m .51858 .77284 L .51835 .77136 L .082 0 .156 r
F
.51718 .7687 m .51858 .77284 L .51921 .77016 L .819 .466 .389 r
F
.49709 .78571 m .51738 .78181 L .5494 .69505 L .908 .809 .739 r
F
.51479 .78885 m .52535 .79073 L .53257 .76199 L F
.51479 .78885 m .53257 .76199 L .5494 .69505 L F
.4828 .78845 m .49709 .78571 L .48533 .78362 L F
.49709 .78571 m .4835 .90817 L .48378 .90779 L .819 .466 .389 r
F
.49704 .78572 m .4835 .90817 L .49709 .78571 L F
.44805 .85726 m .45488 .85335 L .45325 .85278 L .908 .809 .739 r
F
.4489 .85719 m .45488 .85335 L .44805 .85726 L F
.44759 .8641 m .4482 .86502 L .44661 .86089 L .763 .323 0 r
F
.45633 .89257 m .4482 .86502 L .44759 .8641 L F
.46089 .82328 m .43956 .86907 L .48579 .86802 L .819 .466 .389 r
F
.43956 .86907 m .43329 .88253 L .44531 .87921 L F
.44579 .88302 m .44507 .87308 L .44184 .87076 L .763 .323 0 r
F
.45633 .89257 m .46821 .91733 L .45678 .88736 L F
.46141 .86857 m .46228 .87452 L .48579 .86802 L .819 .466 .389 r
F
.43956 .86907 m .46228 .87452 L .46141 .86857 L F
.46821 .91733 m .46836 .9175 L .45678 .88736 L .763 .323 0 r
F
.46784 .91568 m .43989 .86936 L .46792 .91702 L 0 .142 .671 r
F
.46632 .91083 m .43989 .86936 L .46784 .91568 L F
.44034 .86955 m .43989 .86936 L p .46632 .91083 L F P
0 g
s
.4677 .9118 m .46855 .9176 L .46631 .91078 L .521 .533 .809 r
F
.46868 .91773 m .46811 .91726 L .46854 .91759 L 0 .056 .566 r
F
.46867 .91779 m .46883 .91803 L .4685 .91766 L F
.46885 .91794 m .46889 .918 L .46867 .91779 L F
.46864 .91824 m .46866 .91779 L .46884 .91793 L .156 0 0 r
F
.46864 .91824 m .46883 .91792 L .46836 .9175 L F
.46855 .9176 m .46864 .91824 L .46839 .91744 L .521 .533 .809 r
F
.46855 .9176 m .46839 .91744 L .46631 .91078 L F
.46854 .91759 m .46811 .91726 L .46775 .91693 L 0 .056 .566 r
F
.44034 .86955 m .46632 .91083 L .46631 .91078 L 0 .142 .671 r
F
.43956 .86907 m .44531 .87921 L .46228 .87452 L .819 .466 .389 r
F
.47363 .88736 m .44625 .87894 L .4626 .9049 L F
.45393 .87682 m .44625 .87894 L .47363 .88736 L F
.46667 .90888 m .4626 .9049 L .466 .9103 L F
.48579 .86802 m .4626 .9049 L .46667 .90888 L F
.48579 .86802 m .466 .9103 L .47033 .91412 L F
.40854 .81437 m .40925 .81463 L .49409 .75202 L F
.43795 .70741 m .4677 .9118 L .46574 .90898 L .521 .533 .809 r
F
.45514 .87573 m .44034 .86955 L .43961 .86916 L 0 .301 .696 r
F
.46162 .87911 m .45672 .87655 L .40813 .72498 L .521 .533 .809 r
F
.46471 .90148 m .46225 .89784 L .45537 .87585 L F
.45672 .87655 m .45537 .87585 L .40813 .72498 L F
.46471 .90148 m .45537 .87585 L .45672 .87655 L F
.43699 .86728 m .43961 .86916 L .43098 .86455 L 0 .301 .696 r
F
.41157 .85633 m .41518 .859 L .4106 .85644 L p .51 0 0 r
F P
0 g
s
.43098 .86455 m .41872 .86049 L .40532 .85287 L 0 .301 .696 r
F
.41872 .86049 m .41518 .859 L p .38234 .83981 L F P
0 g
s
.43954 .86912 m .40968 .85315 L .43531 .87821 L .819 .466 .389 r
F
.43632 .86389 m .44357 .87615 L .43751 .86545 L .763 .323 0 r
F
.40812 .82547 m .44357 .87615 L .40439 .80991 L F
.42293 .84905 m .39835 .84208 L .43083 .86078 L .266 .432 .841 r
F
.39014 .83975 m .43352 .86478 L .43191 .8624 L F
.43304 .86458 m .42356 .86058 L .43308 .86457 L 0 .301 .696 r
F
.42356 .86058 m .4234 .86049 L .43308 .86457 L F
.39835 .84208 m .40323 .84685 L .43191 .8624 L .266 .432 .841 r
F
.39835 .84208 m .43191 .8624 L .43083 .86078 L F
.3943 .83811 m .42293 .84905 L .42181 .84739 L F
.39475 .83855 m .42293 .84905 L .3943 .83811 L F
.39475 .83855 m .39835 .84208 L .42293 .84905 L F
.4063 .82433 m .38661 .82995 L p .39649 .81304 L .287 .546 .921 r
F P
0 g
s
.3989 .81459 m .39649 .81304 L .39703 .81212 L .287 .546 .921 r
F
.4063 .82433 m .39649 .81304 L .3989 .81459 L F
.3991 .81093 m .38309 .81636 L .32225 .783 L .763 .323 0 r
F
.38029 .78568 m .44579 .88302 L .44357 .87615 L F
.45218 .87419 m .43961 .86916 L .43699 .86728 L 0 .301 .696 r
F
.45514 .87573 m .43961 .86916 L .45218 .87419 L F
.45537 .87585 m .44034 .86955 L p .45514 .87573 L F P
0 g
s
.42872 .79884 m .40854 .81437 L .43024 .79855 L .819 .466 .389 r
F
.40813 .72498 m .44553 .84442 L .36354 .75124 L .521 .533 .809 r
F
.44553 .84442 m .42032 .82829 L .36354 .75124 L F
.40439 .80991 m .40953 .81611 L .40422 .8092 L .763 .323 0 r
F
.40953 .81611 m .40942 .81592 L .40422 .8092 L F
.40439 .80991 m .43632 .86389 L .40953 .81611 L F
.43632 .86389 m .43751 .86545 L .40953 .81611 L F
.40422 .8092 m .40876 .81476 L .40854 .81437 L F
.3628 .75969 m .40812 .82547 L .40439 .80991 L F
.35834 .75431 m .38029 .78568 L .3628 .75969 L F
.38029 .78568 m .40812 .82547 L .3628 .75969 L F
.41171 .82278 m .4063 .82433 L p .42877 .84812 L .266 .432 .841 r
F P
0 g
s
.4063 .82433 m .38629 .83004 L p .41971 .84426 L .266 .432 .841 r
F P
0 g
s
.4063 .82433 m .41971 .84426 L .42877 .84812 L .266 .432 .841 r
F
.40854 .81437 m .40885 .81492 L .40925 .81463 L .819 .466 .389 r
F
.40854 .81437 m .40925 .81463 L .40854 .81437 L F
.35834 .75431 m .40439 .80991 L .40422 .8092 L .763 .323 0 r
F
.45537 .87585 m .44316 .86949 L .36354 .75124 L .521 .533 .809 r
F
.44553 .84442 m .45537 .87585 L .42032 .82829 L F
.38629 .83004 m .38698 .83095 L .38715 .83082 L .142 0 0 r
F
.38629 .83004 m .39172 .83724 L .4471 .85591 L .266 .432 .841 r
F
.40267 .81955 m .44656 .88543 L .44579 .88302 L .763 .323 0 r
F
.35834 .75431 m .3989 .81459 L .40267 .81955 L F
.3989 .81459 m .44656 .88543 L .40267 .81955 L F
.35834 .75431 m .44579 .88302 L .38029 .78568 L F
.41171 .82278 m .4063 .82433 L p .3989 .81459 L .287 .546 .921 r
F P
0 g
s
.43352 .86478 m .44316 .86949 L p .43699 .86728 L 0 .301 .696 r
F P
0 g
s
.45218 .87419 m .43699 .86728 L .44316 .86949 L 0 .301 .696 r
F
.43083 .86078 m .43191 .8624 L .46129 .87833 L .266 .432 .841 r
F
.43093 .85132 m .42293 .84905 L .43625 .85922 L F
.42293 .84905 m .43083 .86078 L .46129 .87833 L F
.43352 .86478 m .46129 .87833 L p .43191 .8624 L F P
0 g
s
.46558 .90993 m .44531 .87921 L .46268 .90736 L .819 .466 .389 r
F
.4835 .90817 m .48187 .9229 L .48378 .90779 L F
.47315 .91662 m .4789 .92171 L .46947 .91852 L .521 .533 .809 r
F
.48579 .86802 m .47033 .91412 L .48187 .9229 L .819 .466 .389 r
F
.47267 .91619 m .46947 .91852 L .469 .91805 L .521 .533 .809 r
F
.47315 .91662 m .46947 .91852 L .47267 .91619 L F
.47033 .91412 m .47009 .91483 L .4789 .92171 L .819 .466 .389 r
F
.47033 .91412 m .4789 .92171 L .48187 .9229 L F
.49021 .89159 m .4855 .91198 L .49059 .89097 L F
.48907 .89344 m .4855 .91198 L .49021 .89159 L F
.6493 .80083 m .53524 .8778 L .75624 .8852 L .784 .964 .921 r
F
.54756 .87825 m .47315 .91662 L .47267 .91619 L .521 .533 .809 r
F
.43795 .70741 m .46162 .87911 L .40813 .72498 L F
.43949 .71803 m .46814 .91219 L .4677 .9118 L F
.43795 .70741 m .43952 .71805 L .43949 .71803 L F
.43952 .71805 m .46814 .91219 L .43949 .71803 L F
.36354 .75124 m .36391 .75182 L .35834 .75431 L F
.46864 .91824 m .46836 .9175 L p .46787 .91817 L 0 0 .307 r
F P
0 g
s
.46851 .91755 m .46766 .91294 L p .46792 .91702 L 0 .142 .671 r
F P
0 g
s
.45587 .89783 m .46751 .91656 L .46697 .9154 L .763 .323 0 r
F
.45587 .89783 m .46697 .9154 L .45597 .89669 L F
.46102 .90691 m .46751 .91656 L .45587 .89783 L F
.46631 .91078 m .46839 .91744 L .46102 .90691 L .521 .533 .809 r
F
.45398 .90615 m .45338 .90631 L .45401 .90673 L 0 0 .307 r
F
.45337 .90566 m .45338 .90631 L .45398 .90615 L F
.45464 .90667 m .45463 .90666 L .45468 .90717 L F
.45974 .91054 m .44657 .90126 L .44758 .90002 L .156 0 0 r
F
.46877 .91783 m .44888 .90126 L .44746 .89986 L 0 .056 .566 r
F
.46878 .91783 m .44888 .90126 L .46877 .91783 L F
.4686 .91769 m .44888 .90126 L .46883 .91787 L F
.46885 .91794 m .46187 .91238 L .46836 .9175 L F
.46836 .9175 m .46187 .91238 L .46814 .9178 L 0 0 .307 r
F
.46864 .91824 m .46836 .9175 L p .46778 .91695 L .72 .21 .01 r
F P
0 g
s
.45338 .90631 m .45341 .90973 L .45401 .90673 L 0 0 .307 r
F
.46814 .9178 m .45805 .90941 L .45801 .91006 L F
.46814 .9178 m .45801 .91006 L .45766 .91735 L F
.46814 .9178 m .45766 .91735 L .46787 .91817 L F
.45665 .91422 m .45659 .91036 L .45634 .91217 L .736 .35 .32 r
F
.45938 .91844 m .4567 .91715 L .46776 .92011 L .154 0 .282 r
F
.45683 .9086 m .45564 .91718 L .45685 .91728 L 0 0 .307 r
F
.45659 .91036 m .45658 .9099 L .45634 .91217 L .736 .35 .32 r
F
.45634 .91217 m .45658 .9099 L .45587 .90915 L F
.45599 .90804 m .45564 .91718 L .45683 .9086 L 0 0 .307 r
F
.45645 .90822 m .457 .90871 L .45647 .90823 L 0 .06 .599 r
F
.457 .90871 m .45713 .9088 L .44608 .8988 L F
.45805 .90941 m .45683 .9084 L .45683 .9086 L 0 0 .307 r
F
.46889 .918 m .47022 .92003 L .46867 .91779 L 0 .056 .566 r
F
.45492 .93487 m .4562 .93139 L .45621 .9314 L .082 0 .156 r
F
.4562 .93139 m .46056 .91956 L .45621 .9314 L F
.45621 .9314 m .46056 .91956 L .46059 .91957 L F
.45492 .93487 m .45482 .93487 L .46052 .91955 L F
.45492 .93487 m .46052 .91955 L .46056 .91956 L F
.45697 .93274 m .45698 .93327 L .45011 .9166 L .154 0 .282 r
F
.45508 .92074 m .45697 .93274 L .4593 .91887 L p .322 0 .233 r
F P
0 g
s
.45712 .93309 m .45011 .9166 L .45015 .91661 L .154 0 .282 r
F
.45631 .93495 m .45167 .93239 L .45696 .9333 L .05 .273 .766 r
F
.45366 .93481 m .45167 .93239 L .45631 .93495 L F
.45698 .93327 m .45183 .93469 L .44917 .91641 L .154 0 .282 r
F
.45698 .93327 m .44917 .91641 L .45011 .9166 L F
.44927 .93198 m .4485 .93184 L .44816 .92827 L F
.44921 .93939 m .44546 .93368 L .44816 .92827 L F
.45689 .93321 m .45504 .92075 L p .44092 .92698 L .322 0 .233 r
F P
0 g
s
.4593 .91887 m .4517 .91699 L .44092 .92698 L .322 0 .233 r
F
.45697 .93274 m .4593 .91887 L p .45671 .91791 L .736 .35 .32 r
F P
0 g
s
.47718 .92771 m .45697 .93274 L .45671 .91791 L .154 0 .282 r
F
.4588 .91833 m .45671 .91791 L .4567 .91726 L F
.47718 .92771 m .45671 .91791 L .4588 .91833 L F
.48336 .92321 m .48044 .92259 L .48013 .92212 L .498 .362 .626 r
F
.47475 .92139 m .47044 .92047 L .46947 .91852 L F
.45126 .91683 m .45447 .91709 L .48336 .92321 L F
.48192 .92483 m .46947 .91852 L .48239 .92555 L .564 .499 .74 r
F
.4789 .92171 m .46947 .91852 L p .48192 .92483 L F P
0 g
s
.46947 .91852 m .46983 .91887 L .48239 .92555 L .564 .499 .74 r
F
.48239 .92555 m .46983 .91887 L .47998 .92763 L F
.46921 .91826 m .47022 .92003 L .46885 .91794 L 0 .056 .566 r
F
.44625 .87894 m .44531 .87921 L .466 .91055 L .819 .466 .389 r
F
.46766 .91294 m .46632 .91083 L .46784 .91568 L 0 .142 .671 r
F
.46613 .91065 m .466 .91055 L .46747 .91278 L .819 .466 .389 r
F
.44625 .87894 m .466 .91055 L .46613 .91065 L F
.46631 .91078 m .46632 .91083 L .46766 .91294 L 0 .142 .671 r
F
.44625 .87894 m .46747 .91278 L .46766 .91294 L .819 .466 .389 r
F
.4677 .9118 m .46631 .91078 L .46577 .90907 L .521 .533 .809 r
F
.46814 .91219 m .469 .91805 L .4677 .9118 L F
.47311 .91718 m .46909 .91813 L .46814 .91331 L .47 .559 .865 r
F
.46909 .91813 m .46766 .91294 L .46814 .91331 L F
.47033 .91412 m .466 .9103 L .46966 .91611 L .819 .466 .389 r
F
.45537 .87585 m .44034 .86955 L p .46631 .91078 L 0 .142 .671 r
F P
0 g
s
.46839 .91744 m .46751 .91656 L .46102 .90691 L .521 .533 .809 r
F
.46851 .91755 m .46766 .91294 L p .46909 .91813 L .47 .559 .865 r
F P
0 g
s
.44531 .87921 m .46475 .91348 L .4691 .91777 L .819 .466 .389 r
F
.42181 .84739 m .42293 .84905 L .4471 .85591 L .266 .432 .841 r
F
.4677 .9118 m .3989 .81459 L .40124 .81608 L .521 .533 .809 r
F
.46162 .87911 m .46471 .90148 L .45672 .87655 L F
.46471 .90148 m .46574 .90898 L .46225 .89784 L F
.46766 .91294 m .46129 .87833 L .45537 .87585 L p 0 .142 .671 r
F P
0 g
s
.45537 .87585 m .46631 .91078 L .46766 .91294 L 0 .142 .671 r
F
.44656 .88543 m .45576 .89909 L .45444 .89587 L .763 .323 0 r
F
.44656 .88543 m .45444 .89587 L .44579 .88302 L F
.46558 .90993 m .46268 .90736 L .4691 .91777 L .819 .466 .389 r
F
.45576 .89909 m .46102 .90691 L .45587 .89783 L .763 .323 0 r
F
.46577 .90907 m .46102 .90691 L .3989 .81459 L .521 .533 .809 r
F
.46966 .91611 m .46558 .90993 L .4691 .91777 L .819 .466 .389 r
F
.46631 .91078 m .46102 .90691 L .46577 .90907 L .521 .533 .809 r
F
.36391 .75182 m .46574 .90898 L .35834 .75431 L F
.46225 .89784 m .46574 .90898 L .36354 .75124 L F
.47656 .78965 m .53078 .66675 L .49355 .75318 L .908 .809 .739 r
F
.56735 .87827 m .55071 .88175 L .55705 .86957 L .562 .583 .833 r
F
.50387 .83491 m .49059 .89097 L .50313 .83559 L .082 0 .156 r
F
.53625 .81973 m .53335 .81807 L .52382 .82514 L .156 0 0 r
F
.49491 .75026 m .49409 .75202 L .49559 .75091 L .819 .466 .389 r
F
.53078 .66675 m .49403 .75215 L .49355 .75318 L .908 .809 .739 r
F
.49991 .74408 m .4966 .74662 L .50135 .74666 L .819 .466 .389 r
F
.53078 .66675 m .49489 .75029 L .49403 .75215 L .908 .809 .739 r
F
.4993 .74076 m .4966 .74662 L .49991 .74408 L .142 0 0 r
F
.47656 .78965 m .54525 .66884 L .54119 .64316 L .908 .809 .739 r
F
.4828 .78845 m .54525 .66884 L .47656 .78965 L F
.48533 .78362 m .5494 .69505 L .54525 .66884 L F
.50313 .83559 m .49037 .89087 L .49823 .84012 L .082 0 .156 r
F
.49037 .89087 m .48883 .89014 L .49823 .84012 L F
.50313 .83559 m .49823 .84012 L .50464 .80601 L F
.48454 .90085 m .48907 .89344 L .50956 .79656 L .819 .466 .389 r
F
.48454 .90085 m .50956 .79656 L .50888 .79668 L F
.49709 .78571 m .49563 .79913 L .50345 .78684 L F
.49563 .79913 m .48454 .90085 L .50888 .79668 L F
.50144 .83496 m .48907 .89344 L .50387 .83491 L F
.48907 .89344 m .49059 .89097 L .50387 .83491 L F
.50854 .80138 m .50144 .83496 L .5116 .80231 L F
.50388 .83485 m .50387 .83491 L .50388 .83485 L .082 0 .156 r
F
.50144 .83496 m .50387 .83491 L .5116 .80231 L .819 .466 .389 r
F
.59653 .82928 m .52322 .86882 L .57217 .85288 L .784 .964 .921 r
F
.52322 .86882 m .51354 .87404 L .55504 .85906 L F
.52322 .86882 m .55504 .85906 L .57217 .85288 L F
.51354 .87404 m .53278 .8719 L .57217 .85288 L F
.43795 .70741 m .55912 .87239 L .47267 .91619 L .521 .533 .809 r
F
.43795 .70741 m .47267 .91619 L .46814 .91219 L F
.42392 .8193 m .35834 .75431 L .482 .77757 L p .583 .543 .775 r
F P
0 g
s
.52907 .78935 m .53829 .78443 L .55166 .70938 L .908 .809 .739 r
F
.53829 .78443 m .55563 .73663 L .55166 .70938 L F
.54839 .77903 m .55928 .76546 L .55874 .76116 L F
.55114 .77756 m .55928 .76546 L .54839 .77903 L F
.55114 .77756 m .55882 .77346 L .55928 .76546 L F
.55928 .76546 m .55978 .76944 L .56008 .7626 L F
.55887 .76226 m .55978 .76944 L .56078 .76229 L .771 .721 .806 r
F
.55867 .77594 m .55901 .77396 L .55877 .77421 L .908 .809 .739 r
F
.55924 .77492 m .55978 .76944 L .55867 .77594 L F
.5592 .7753 m .55956 .77339 L .55937 .77359 L F
.55939 .77513 m .55962 .77303 L .5592 .7753 L F
.56021 .77492 m .55261 .78065 L p .55961 .77334 L .796 .591 .624 r
F P
0 g
s
.55877 .77421 m .55978 .76944 L .55928 .76546 L .908 .809 .739 r
F
.55901 .77396 m .55978 .76944 L .55877 .77421 L F
.55959 .77336 m .55961 .77334 L .55962 .77303 L F
.55572 .77512 m .56121 .77532 L .55953 .77308 L .082 0 .156 r
F
.54113 .78291 m .55587 .73598 L .53829 .78443 L .908 .809 .739 r
F
.55572 .77512 m .53368 .81755 L .56121 .77532 L .082 0 .156 r
F
.52419 .79196 m .53368 .81755 L .55572 .77512 L F
.53333 .81808 m .53335 .81807 L .53368 .81755 L F
.56422 .78531 m .55686 .79134 L .58155 .82957 L .453 .096 .269 r
F
.58924 .83322 m .58274 .83562 L .58668 .83459 L .784 .964 .921 r
F
.55463 .79328 m .55496 .79312 L .55588 .79226 L .453 .096 .269 r
F
.55564 .79234 m .55588 .79226 L .55686 .79134 L F
.6493 .80083 m .57216 .83356 L .58924 .83322 L .784 .964 .921 r
F
.6493 .80083 m .59653 .82928 L .57217 .85288 L F
.55782 .73823 m .56117 .76212 L .56661 .7351 L .719 .694 .825 r
F
.5602 .77272 m .5627 .77303 L p .55966 .77328 L .796 .591 .624 r
F P
0 g
s
.5602 .77272 m .55966 .77308 L .5627 .77303 L .082 0 .156 r
F
.55962 .77303 m .55966 .77308 L .5602 .77272 L F
.55942 .77314 m .55962 .77303 L .55978 .76944 L .908 .809 .739 r
F
.56117 .76212 m .5627 .77303 L .57442 .70459 L .719 .694 .825 r
F
.56117 .76212 m .57442 .70459 L .58395 .64895 L F
.5602 .77272 m .5627 .77303 L p .56013 .77222 L .771 .721 .806 r
F P
0 g
s
.55966 .77308 m .56121 .77532 L .5627 .77303 L .082 0 .156 r
F
.5627 .77303 m .5953 .71988 L p .61401 .73383 L .656 .566 .741 r
F P
0 g
s
.61472 .72514 m .61888 .73011 L .61401 .73383 L .656 .566 .741 r
F
.58395 .64895 m .5627 .77303 L .61888 .73011 L .719 .694 .825 r
F
.5261 .65642 m .59805 .86859 L .52291 .80874 L .825 .655 .673 r
F
.5494 .69505 m .54981 .69765 L .56595 .6292 L .908 .809 .739 r
F
.55025 .68427 m .55213 .69765 L .57426 .66378 L .719 .694 .825 r
F
.54813 .68701 m .55213 .69765 L .55025 .68427 L .783 .69 .761 r
F
.54988 .69811 m .55213 .69765 L .54813 .68701 L F
.55563 .73663 m .55428 .7259 L .55166 .70938 L .908 .809 .739 r
F
.75624 .8852 m .70954 .89859 L .71212 .92723 L .698 .574 .713 r
F
.55213 .69765 m .55782 .73823 L .58395 .64895 L .719 .694 .825 r
F
.55782 .73823 m .56661 .7351 L .58395 .64895 L F
.55191 .71942 m .80285 1.01794 L .65891 .9806 L .825 .655 .673 r
F
.5261 .65642 m .55806 .69816 L .55191 .71942 L F
.55806 .69816 m .80285 1.01794 L .55191 .71942 L F
.55563 .73663 m .55587 .73598 L .55428 .7259 L .908 .809 .739 r
F
.5261 .65642 m .65891 .9806 L .615 .91857 L .825 .655 .673 r
F
.70132 .77837 m .71843 .81165 L .70895 .79162 L .444 .554 .873 r
F
.5861 .65392 m .60368 .66134 L .57542 .53347 L .719 .694 .825 r
F
.73102 .83294 m .75624 .8852 L .7926 .93293 L 0 .041 .609 r
F
.73102 .83294 m .7926 .93293 L .8319 .98451 L F
.71843 .81165 m .75624 .8852 L .73102 .83294 L .444 .554 .873 r
F
.71843 .81165 m .73102 .83294 L .60149 .56462 L F
.61815 .68262 m .64758 .6918 L p .61888 .73011 L .656 .566 .741 r
F P
0 g
s
.64758 .6918 m .65425 .70308 L .61888 .73011 L .656 .566 .741 r
F
.61888 .73011 m .63513 .74957 L .57542 .53347 L .719 .694 .825 r
F
.57542 .53347 m .63513 .74957 L .71843 .81165 L .444 .554 .873 r
F
.63513 .74957 m .6493 .80083 L .71843 .81165 L F
.61199 .65489 m .8046 .94246 L .80285 1.01794 L .938 .571 .189 r
F
.58691 .60719 m .607 .63813 L .61199 .65489 L F
.607 .63813 m .8046 .94246 L .61199 .65489 L F
.57542 .53347 m .70132 .77837 L .60149 .56462 L .444 .554 .873 r
F
.70132 .77837 m .70895 .79162 L .60149 .56462 L F
.60149 .56462 m .61152 .58289 L .58691 .60719 L 0 .041 .609 r
F
.61152 .58289 m .8031 .93203 L .60705 .63745 L F
.61152 .58289 m .60705 .63745 L .58691 .60719 L F
.8031 .93203 m .8046 .94246 L .58691 .60719 L F
.56129 .59628 m .55025 .68427 L .58395 .64895 L .719 .694 .825 r
F
.54366 .63729 m .55025 .68427 L .56129 .59628 L F
.55025 .68427 m .57426 .66378 L .58395 .64895 L F
.58691 .60719 m .80285 1.01794 L .5261 .65642 L .938 .571 .189 r
F
.74948 .70367 m .67463 .75066 L .63255 .72396 L p .789 .505 .508 r
F P
0 g
s
.63255 .72396 m .5261 .65642 L .61825 .67591 L p .789 .505 .508 r
F P
0 g
s
.61825 .67591 m .74948 .70367 L p .63255 .72396 L .789 .505 .508 r
F P
0 g
s
.67463 .75066 m .54251 .78895 L .53377 .78214 L p .708 .53 .645 r
F P
0 g
s
.46085 .71984 m .46481 .70338 L .45657 .71062 L .63 .528 .72 r
F
.46647 .71684 m .46481 .70338 L .46085 .71984 L F
.46143 .71708 m .52291 .80874 L .45282 .72515 L .825 .655 .673 r
F
.48302 .55369 m .47262 .55008 L .47228 .55005 L .217 .596 .948 r
F
.51445 .56923 m .51745 .56501 L .47444 .55024 L .63 .528 .72 r
F
.51445 .56923 m .47444 .55024 L .4334 .53616 L F
.50851 .70676 m .50873 .70595 L .48109 .53802 L .783 .69 .761 r
F
.4758 .53501 m .50836 .70727 L .48109 .53802 L F
.50836 .70727 m .50851 .70676 L .48109 .53802 L F
.48109 .53802 m .50873 .70595 L .51148 .69615 L F
.48109 .53802 m .51148 .69615 L .51581 .68077 L F
.49133 .68904 m .49334 .68715 L .47264 .66302 L .63 .528 .72 r
F
.49698 .69691 m .49334 .68715 L .49133 .68904 L F
.49698 .69691 m .49771 .69224 L .49334 .68715 L F
.4156 .50726 m .49523 .69064 L .45487 .50792 L .506 .498 .782 r
F
.49523 .69064 m .50582 .70405 L .45487 .50792 L F
.49698 .69691 m .49806 .69422 L .49751 .69352 L .63 .528 .72 r
F
.48993 .74238 m .5025 .70459 L .49698 .69691 L F
.48109 .53802 m .51581 .68077 L .52245 .65711 L .783 .69 .761 r
F
.45487 .50792 m .50582 .70405 L .47073 .50819 L .506 .498 .782 r
F
.50582 .70405 m .50836 .70727 L .47073 .50819 L F
.4156 .50726 m .48251 .67453 L .49523 .69064 L F
.47166 .71406 m .46873 .69994 L .46883 .71557 L .63 .528 .72 r
F
.49698 .69691 m .46017 .64567 L .45809 .6486 L F
.5261 .65642 m .52291 .80874 L .46143 .71708 L .825 .655 .673 r
F
.44858 .71765 m .45289 .72409 L .45814 .71943 L .788 .566 .601 r
F
.44173 .70523 m .45282 .72515 L .43795 .70741 L .825 .655 .673 r
F
.46873 .69994 m .45809 .6486 L .46481 .70338 L .63 .528 .72 r
F
.45657 .71062 m .45726 .6824 L .43975 .67443 L F
.46481 .70338 m .45809 .6486 L .45657 .71062 L F
.5261 .65642 m .45282 .72515 L .44173 .70523 L .825 .655 .673 r
F
.53377 .78214 m .43795 .70741 L .54949 .72779 L p .708 .53 .645 r
F P
0 g
s
.54949 .72779 m .67463 .75066 L p .53377 .78214 L .708 .53 .645 r
F P
0 g
s
.67463 .75066 m .54251 .78895 L .62976 .82277 L p .741 .655 .764 r
F P
0 g
s
.62976 .82277 m .77378 .87858 L .67729 .75409 L p .741 .655 .764 r
F P
0 g
s
.67729 .75409 m .67463 .75066 L p .62976 .82277 L .741 .655 .764 r
F P
0 g
s
.59805 .86859 m .615 .91857 L .58676 .88489 L .825 .655 .673 r
F
.59805 .86859 m .58676 .88489 L .52291 .80874 L F
.57244 .88258 m .55071 .88175 L p .63382 .97409 L .573 .547 .788 r
F P
0 g
s
.615 .91857 m .55705 .86957 L .4586 .73553 L .825 .655 .673 r
F
.45282 .72515 m .4586 .73553 L .43795 .70741 L F
.615 .91857 m .4586 .73553 L .45282 .72515 L F
.52252 .79406 m .49509 .80108 L p .51032 .78289 L .583 .543 .775 r
F P
0 g
s
.49509 .80108 m .42392 .8193 L p .48978 .79155 L .583 .543 .775 r
F P
0 g
s
.49509 .80108 m .48978 .79155 L .51032 .78289 L .583 .543 .775 r
F
.58999 .88325 m .55071 .88175 L p .584 .87479 L .562 .583 .833 r
F P
0 g
s
.615 .91857 m .63382 .97409 L .55705 .86957 L .825 .655 .673 r
F
.615 .91857 m .65891 .9806 L .63382 .97409 L F
.63382 .97409 m .61069 .88404 L .57244 .88258 L p .573 .547 .788 r
F P
0 g
s
.482 .77757 m .51032 .78289 L p .48978 .79155 L .583 .543 .775 r
F P
0 g
s
.48978 .79155 m .42392 .8193 L .482 .77757 L .583 .543 .775 r
F
.55887 .86608 m .584 .87479 L p .56735 .87827 L .562 .583 .833 r
F P
0 g
s
.56735 .87827 m .55705 .86957 L .55887 .86608 L .562 .583 .833 r
F
.584 .87479 m .61069 .88404 L .58999 .88325 L p F P
0 g
s
.55912 .87239 m .48461 .92364 L .4789 .92171 L .521 .533 .809 r
F
.55912 .87239 m .4789 .92171 L .47315 .91662 L F
.53292 .92285 m .53196 .92244 L p .53316 .91804 L .816 .672 .704 r
F P
0 g
s
.55912 .87239 m .63382 .97409 L .48461 .92364 L .521 .533 .809 r
F
.48461 .92364 m .46947 .91852 L p .51394 .90755 L .47 .559 .865 r
F P
0 g
s
.46926 .91831 m .46945 .91849 L .46921 .91826 L 0 .056 .566 r
F
.46945 .91849 m .46945 .91849 L .46926 .91831 L F
.469 .91805 m .46947 .91852 L .46864 .91824 L .521 .533 .809 r
F
.46947 .91852 m .46864 .91824 L p .46909 .91813 L .47 .559 .865 r
F P
0 g
s
.46947 .91852 m .46909 .91813 L .51394 .90755 L .47 .559 .865 r
F
.46943 .91845 m .46945 .91849 L .46926 .91831 L 0 .056 .566 r
F
.48175 .92465 m .47496 .92012 L .48162 .92643 L .819 .466 .389 r
F
.48177 .92424 m .48076 .92363 L .48175 .92465 L F
.48076 .92363 m .47496 .92012 L .48175 .92465 L F
.48187 .9229 m .4789 .92171 L .48177 .92424 L F
.4789 .92171 m .47496 .92012 L .48076 .92363 L F
.4789 .92171 m .48076 .92363 L .48177 .92424 L F
.48461 .92364 m .48284 .92329 L .48336 .92321 L .498 .362 .626 r
F
.48284 .92329 m .48201 .92295 L .48336 .92321 L F
.48291 .92335 m .48272 .92326 L .48461 .92364 L F
.48236 .9255 m .48239 .92555 L .48291 .92335 L .819 .466 .389 r
F
.48276 .92328 m .48231 .92542 L .48291 .92335 L F
.48231 .92542 m .48236 .9255 L .48291 .92335 L F
.48212 .923 m .48187 .9229 L .48137 .92985 L F
.48212 .923 m .48137 .92985 L .48276 .92328 L F
.48461 .92364 m .48013 .92212 L p .48192 .92483 L .564 .499 .74 r
F P
0 g
s
.48251 .92544 m .48192 .92483 L .48239 .92555 L .564 .499 .74 r
F
.48461 .92364 m .48192 .92483 L .48251 .92544 L F
.48013 .92212 m .4789 .92171 L p .48192 .92483 L F P
0 g
s
.46945 .91849 m .47022 .92003 L .46921 .91826 L 0 .056 .566 r
F
.46945 .91848 m .47022 .92003 L .46943 .91845 L F
.47044 .92047 m .45447 .91709 L .46947 .91852 L .498 .362 .626 r
F
.46947 .91852 m .46864 .91824 L p .46983 .91887 L .564 .499 .74 r
F P
0 g
s
.46945 .91847 m .46945 .91848 L .46943 .91845 L 0 .056 .566 r
F
.46947 .91852 m .46892 .91846 L .46864 .91824 L .498 .362 .626 r
F
.46849 .91842 m .45447 .91709 L .46864 .91824 L F
.4699 .92037 m .46978 .9205 L .47831 .92738 L 0 .06 .599 r
F
.4699 .92037 m .47831 .92738 L .47814 .92717 L F
.46977 .92051 m .47832 .92739 L p .46776 .92011 L .154 0 .282 r
F P
0 g
s
.47805 .92747 m .46776 .92011 L .47832 .92739 L .154 0 .282 r
F
.46977 .92051 m .47832 .92739 L p .46978 .9205 L 0 .06 .599 r
F P
0 g
s
.46978 .9205 m .47832 .92739 L .47831 .92738 L 0 .06 .599 r
F
.47805 .92747 m .45938 .91844 L .46776 .92011 L .154 0 .282 r
F
.47718 .92771 m .45717 .93322 L .45697 .93274 L F
.47755 .92649 m .47022 .92003 L p .46994 .91896 L 0 .056 .566 r
F P
0 g
s
.47022 .92003 m .4699 .92037 L .47814 .92717 L 0 .06 .599 r
F
.47755 .92649 m .47022 .92003 L p .47814 .92717 L F P
0 g
s
.45689 .93321 m .46864 .91824 L .47214 .92114 L p .318 .46 .846 r
F P
0 g
s
.47214 .92114 m .47935 .92711 L p .47844 .92736 L .318 .46 .846 r
F P
0 g
s
.45996 .93425 m .45703 .93326 L .47877 .92792 L .318 .46 .846 r
F
.45703 .93326 m .4595 .93258 L .47998 .92763 L F
.45698 .93327 m .45698 .93327 L .45893 .93459 L F
.45893 .93459 m .45698 .93327 L p .45849 .93506 L .586 .451 .663 r
F P
0 g
s
.46074 .94165 m .45248 .93915 L .45712 .93309 L .154 0 .282 r
F
.47844 .92736 m .45689 .93321 L .47214 .92114 L .318 .46 .846 r
F
.45094 .9168 m .45056 .91671 L .45126 .91683 L .498 .362 .626 r
F
.44701 .91625 m .44699 .91598 L .44405 .9151 L .506 .148 .294 r
F
.45805 .90941 m .45683 .9086 L .45685 .91728 L 0 0 .307 r
F
.45671 .91791 m .45697 .93274 L .45519 .92854 L .154 0 .282 r
F
.44701 .91625 m .44405 .9151 L .444 .9153 L .506 .148 .294 r
F
.44511 .91536 m .44092 .92698 L p .44622 .91572 L .602 .252 .349 r
F P
0 g
s
.44092 .92698 m .44701 .91625 L p .44702 .91598 L .602 .252 .349 r
F P
0 g
s
.44092 .92698 m .44702 .91598 L .44622 .91572 L .602 .252 .349 r
F
.4517 .91699 m .44518 .91538 L .44092 .92698 L .322 0 .233 r
F
.45126 .91683 m .45519 .92854 L .45015 .91661 L .154 0 .282 r
F
.45671 .91791 m .45519 .92854 L .45126 .91683 L F
.4545 .91709 m .45689 .93321 L .45697 .93274 L p .736 .35 .32 r
F P
0 g
s
.45697 .93274 m .45671 .91791 L .4545 .91709 L .736 .35 .32 r
F
.45766 .91735 m .45685 .91728 L .45689 .93321 L 0 0 .307 r
F
.45805 .90941 m .45685 .91728 L .45766 .91735 L F
.45599 .90804 m .45488 .9073 L .45564 .91718 L F
.4548 .90725 m .45468 .90717 L .45553 .91717 L F
.45447 .91709 m .44046 .91412 L .46864 .91824 L .498 .362 .626 r
F
.44441 .91373 m .44584 .9083 L .4302 .91094 L .506 .148 .294 r
F
.44046 .91412 m .4302 .91094 L .43751 .91232 L .498 .362 .626 r
F
.44046 .91412 m .43751 .91232 L .46864 .91824 L F
.444 .9153 m .44405 .9151 L .4302 .91094 L .506 .148 .294 r
F
.45712 .93309 m .45698 .93327 L .45698 .93327 L .154 0 .282 r
F
.45712 .93309 m .45698 .93327 L .45697 .93274 L F
.45845 .90968 m .45817 .90943 L p .45713 .9088 L 0 .06 .599 r
F P
0 g
s
.45662 .90834 m .45713 .9088 L .45817 .90943 L 0 .06 .599 r
F
.45845 .90968 m .45817 .90943 L p .46187 .91238 L 0 .056 .566 r
F P
0 g
s
.44647 .8992 m .45285 .90596 L .457 .90871 L 0 .06 .599 r
F
.44353 .89655 m .45285 .90596 L .44647 .8992 L F
.44357 .89915 m .44456 .89828 L .44657 .90126 L .156 0 0 r
F
.44353 .89655 m .44063 .89576 L p .45086 .90463 L 0 .06 .599 r
F P
0 g
s
.44063 .89576 m .4431 .89822 L .45086 .90463 L 0 .06 .599 r
F
.4431 .89822 m .45292 .90691 L .45042 .90427 L F
.46864 .91824 m .44657 .90126 L .45974 .91054 L .156 0 0 r
F
.46836 .9175 m .45683 .90802 L .46187 .91238 L 0 0 .307 r
F
.45817 .90943 m .44888 .90126 L p .4686 .91769 L 0 .056 .566 r
F P
0 g
s
.46864 .91824 m .46778 .91695 L .46737 .91657 L .72 .21 .01 r
F
.46821 .91733 m .46864 .91824 L .46836 .9175 L .763 .323 0 r
F
.46825 .91738 m .46826 .9174 L .46811 .91726 L 0 .056 .566 r
F
.46869 .91774 m .46826 .9174 L .46825 .91738 L F
.46662 .91583 m .46839 .91744 L .46775 .91693 L F
.46839 .91744 m .46875 .91777 L .46854 .91759 L F
.46839 .91744 m .46854 .91759 L .46775 .91693 L F
.46864 .91824 m .46851 .91755 L p .46792 .91702 L 0 .142 .671 r
F P
0 g
s
.38234 .83981 m .39547 .84622 L p .40532 .85287 L 0 .301 .696 r
F P
0 g
s
.42184 .87377 m .39583 .84646 L p .41232 .8576 L .713 .229 0 r
F P
0 g
s
.40585 .85699 m .46957 .91846 L .46875 .91777 L 0 .056 .566 r
F
.40585 .85699 m .46875 .91777 L .46662 .91583 L F
.46775 .91693 m .46811 .91726 L .44746 .89986 L F
.46187 .91238 m .45817 .90943 L .4686 .91769 L F
.4658 .91509 m .46864 .91824 L p .46737 .91657 L .72 .21 .01 r
F P
0 g
s
.4658 .91509 m .46864 .91824 L p .46792 .91702 L 0 .142 .671 r
F P
0 g
s
.46751 .91656 m .46864 .91824 L .46821 .91733 L .763 .323 0 r
F
.46839 .91744 m .46864 .91824 L .46751 .91656 L .521 .533 .809 r
F
.46883 .91787 m .46878 .91783 L .46877 .91783 L 0 .056 .566 r
F
.51032 .78289 m .54251 .78895 L .52252 .79406 L p .583 .543 .775 r
F P
0 g
s
.46129 .87833 m .42392 .8193 L .55887 .86608 L p .562 .583 .833 r
F P
0 g
s
.55432 .87482 m .54761 .87831 L .54756 .87825 L .521 .533 .809 r
F
.55429 .87487 m .54761 .87831 L .55432 .87482 L F
.54761 .87831 m .47315 .91662 L .54756 .87825 L F
.55071 .88175 m .46129 .87833 L p .55887 .86608 L .562 .583 .833 r
F P
0 g
s
.55912 .87239 m .55429 .87487 L .55432 .87482 L .521 .533 .809 r
F
.55071 .88175 m .46129 .87833 L .63382 .97409 L p .573 .547 .788 r
F P
0 g
s
.46129 .87833 m .51394 .90755 L p .47311 .91718 L .47 .559 .865 r
F P
0 g
s
.47311 .91718 m .46814 .91331 L .46129 .87833 L .47 .559 .865 r
F
.47009 .91483 m .4691 .91777 L .4789 .92171 L .819 .466 .389 r
F
.46957 .91846 m .46869 .91774 L .46854 .91759 L 0 .056 .566 r
F
.46869 .91774 m .46868 .91773 L .46855 .9176 L F
.46869 .91774 m .46855 .9176 L .46854 .91759 L F
.46766 .91294 m .46129 .87833 L p .46814 .91331 L .47 .559 .865 r
F P
0 g
s
.46766 .91294 m .46747 .91278 L .46966 .91611 L .819 .466 .389 r
F
.40124 .81608 m .3989 .81459 L .35834 .75431 L .521 .533 .809 r
F
.39703 .81212 m .42392 .8193 L .41171 .82278 L p .287 .546 .921 r
F P
0 g
s
.41171 .82278 m .3989 .81459 L .39703 .81212 L .287 .546 .921 r
F
.45537 .87585 m .46225 .89784 L .44316 .86949 L .521 .533 .809 r
F
.44316 .86949 m .46129 .87833 L p .45218 .87419 L 0 .301 .696 r
F P
0 g
s
.4471 .85591 m .42392 .8193 L .41171 .82278 L p .266 .432 .841 r
F P
0 g
s
.41171 .82278 m .42877 .84812 L .4471 .85591 L .266 .432 .841 r
F
.46129 .87833 m .45514 .87573 L .45218 .87419 L 0 .301 .696 r
F
.46129 .87833 m .45537 .87585 L p .45514 .87573 L F P
0 g
s
.46129 .87833 m .4471 .85591 L p .43093 .85132 L .266 .432 .841 r
F P
0 g
s
.43093 .85132 m .43625 .85922 L .46129 .87833 L .266 .432 .841 r
F
.46884 .91789 m .4686 .91769 L .46883 .91787 L 0 .056 .566 r
F
.46889 .91793 m .4686 .91769 L .46884 .91789 L F
.46869 .91774 m .46879 .91784 L .46826 .9174 L F
.46864 .91824 m .46884 .91793 L .46885 .91794 L .156 0 0 r
F
.46885 .91794 m .46836 .9175 L .4686 .91769 L 0 .056 .566 r
F
.46864 .91824 m .46885 .91794 L .46883 .91792 L .156 0 0 r
F
.46855 .9176 m .469 .91805 L .46864 .91824 L .521 .533 .809 r
F
.46864 .91824 m .46851 .91755 L p .46909 .91813 L .47 .559 .865 r
F P
0 g
s
.46939 .91834 m .46889 .91793 L .46884 .91789 L 0 .056 .566 r
F
.46989 .91877 m .46939 .91835 L .46939 .91834 L F
.46939 .91835 m .4686 .91769 L .46939 .91834 L F
.45689 .93321 m .46864 .91824 L p .46787 .91817 L 0 0 .307 r
F P
0 g
s
.37117 .83436 m .39547 .84622 L p .39014 .83975 L .266 .432 .841 r
F P
0 g
s
.37961 .83261 m .38356 .83358 L p .38448 .83424 L 0 .405 .757 r
F P
0 g
s
.39466 .84524 m .38356 .83358 L p .38836 .83759 L .713 .229 0 r
F P
0 g
s
.38688 .83579 m .38836 .83759 L .38356 .83358 L .713 .229 0 r
F
.40091 .84457 m .38356 .83358 L .40066 .84833 L .819 .466 .389 r
F
.41518 .859 m .4106 .85644 L p .40937 .85561 L 0 .301 .696 r
F P
0 g
s
.40968 .85315 m .40066 .84833 L .43531 .87821 L .819 .466 .389 r
F
.40091 .84457 m .40066 .84833 L .40968 .85315 L F
.43531 .87821 m .40066 .84833 L .43329 .88253 L F
.40066 .84833 m .38356 .83358 L .39603 .84585 L F
.40066 .84833 m .39603 .84585 L .43329 .88253 L F
.46957 .91846 m .46883 .91787 L .46879 .91784 L 0 .056 .566 r
F
.46957 .91846 m .46879 .91784 L .46869 .91774 L F
.42377 .87545 m .4658 .91509 L .43571 .88775 L F
.40585 .85699 m .46775 .91693 L .42377 .87545 L F
.46957 .91846 m .46989 .91877 L .46883 .91787 L F
.44511 .91536 m .44092 .92698 L p .44518 .91538 L .322 0 .233 r
F P
0 g
s
.44669 .91592 m .45447 .91709 L .45126 .91683 L .498 .362 .626 r
F
.46787 .91817 m .45766 .91735 L .45689 .93321 L 0 0 .307 r
F
.4595 .93258 m .45689 .93321 L .47935 .92711 L .318 .46 .846 r
F
.4702 .93087 m .47987 .92772 L .47102 .93535 L .082 0 .156 r
F
.47983 .92768 m .47987 .92772 L .4702 .93087 L F
.47987 .92772 m .48137 .92985 L .47102 .93535 L F
.47814 .92717 m .47831 .92738 L .48137 .92985 L 0 .06 .599 r
F
.47884 .928 m .47877 .92792 L .47998 .92763 L .318 .46 .846 r
F
.45996 .93425 m .47877 .92792 L .47884 .928 L F
.45703 .93326 m .45689 .93321 L .4595 .93258 L F
.47832 .92739 m .48137 .92985 L p .47805 .92747 L .154 0 .282 r
F P
0 g
s
.47832 .92739 m .48137 .92985 L p .47831 .92738 L 0 .06 .599 r
F P
0 g
s
.45042 .90427 m .45071 .90453 L .45083 .90461 L 0 .06 .599 r
F
.44647 .8992 m .45645 .90822 L .44608 .8988 L F
.45645 .90822 m .45647 .90823 L .44608 .8988 L F
.45817 .90943 m .44608 .8988 L p .45662 .90834 L F P
0 g
s
.44608 .8988 m .44353 .89655 L p .44647 .8992 L 0 .06 .599 r
F P
0 g
s
.48137 .92985 m .47718 .92771 L .47805 .92747 L .154 0 .282 r
F
.44838 .91243 m .44598 .91322 L .44892 .91371 L .322 0 .233 r
F
.44719 .9096 m .44587 .91325 L p .4472 .90964 L F P
0 g
s
.44734 .90997 m .44725 .90975 L .44598 .91322 L .322 0 .233 r
F
.4431 .89822 m .44709 .90221 L .45292 .90691 L 0 .06 .599 r
F
.43986 .89554 m .44357 .89937 L .44709 .90221 L F
.43986 .89554 m .44709 .90221 L .4431 .89822 L F
.44625 .90823 m .44459 .90011 L .4302 .91094 L .506 .148 .294 r
F
.44556 .90104 m .44459 .90011 L .44625 .90823 L F
.4473 .90547 m .44589 .90447 L .44737 .90249 L .154 0 .282 r
F
.44589 .90447 m .44571 .90261 L .44737 .90249 L F
.44556 .90104 m .44737 .90249 L p .44571 .90261 L F P
0 g
s
.44556 .90104 m .44737 .90249 L p .44534 .90082 L 0 .06 .599 r
F P
0 g
s
.46864 .91824 m .43751 .91232 L .44657 .90126 L .156 0 0 r
F
.44353 .89655 m .44998 .90367 L .45196 .90506 L 0 .06 .599 r
F
.46941 .91838 m .46945 .91847 L .46885 .91794 L 0 .056 .566 r
F
.38667 .83554 m .39475 .83855 L .3943 .83811 L .266 .432 .841 r
F
.38338 .83155 m .38667 .83554 L .39172 .83724 L F
.38704 .83101 m .38356 .83358 L .40091 .84457 L .819 .466 .389 r
F
.37622 .81869 m .37167 .82024 L .31362 .78986 L .763 .323 0 r
F
.38494 .82882 m .386 .83003 L .33645 .79595 L .287 .546 .921 r
F
.38661 .82995 m .38624 .83 L .38494 .82882 L F
.38624 .83 m .386 .83003 L .38494 .82882 L F
.33645 .79595 m .39703 .81212 L p .38661 .82995 L F P
0 g
s
.38356 .83358 m .39603 .84585 L p .39585 .8464 L 0 .056 .566 r
F P
0 g
s
.39466 .84524 m .38356 .83358 L p .39585 .8464 L 0 .056 .566 r
F P
0 g
s
.3861 .8301 m .37767 .83251 L p .38698 .83095 L .266 .432 .841 r
F P
0 g
s
.38624 .83 m .38596 .83003 L .38356 .83358 L .142 0 0 r
F
.38629 .83004 m .3861 .8301 L p .38698 .83095 L .266 .432 .841 r
F P
0 g
s
.38629 .83004 m .38356 .83358 L .38698 .83095 L .142 0 0 r
F
.38625 .82999 m .38624 .83 L .38629 .83004 L F
.38629 .83004 m .3861 .8301 L p .38624 .83 L .287 .546 .921 r
F P
0 g
s
.38624 .83 m .38356 .83358 L .38629 .83004 L .142 0 0 r
F
.38624 .83 m .3861 .8301 L .386 .83003 L .287 .546 .921 r
F
.38661 .82995 m .38629 .83004 L p .38624 .83 L F P
0 g
s
.386 .83003 m .3762 .8312 L .33645 .79595 L .287 .546 .921 r
F
.38596 .83003 m .37961 .83261 L .38409 .8328 L .142 0 0 r
F
.38142 .83058 m .37961 .83261 L .38596 .83003 L F
.36074 .8263 m .31362 .78986 L p .37767 .83251 L .287 .546 .921 r
F P
0 g
s
.38142 .83058 m .37463 .83139 L .37961 .83261 L .142 0 0 r
F
.31362 .78986 m .33645 .79595 L p .3762 .8312 L .287 .546 .921 r
F P
0 g
s
.3762 .8312 m .37578 .83125 L .31362 .78986 L .287 .546 .921 r
F
.37365 .83115 m .37961 .83261 L p .382 .83397 L 0 .405 .757 r
F P
0 g
s
.37767 .83251 m .37117 .83436 L .36074 .8263 L p .287 .546 .921 r
F P
0 g
s
.38698 .83095 m .38356 .83358 L .38704 .83101 L .819 .466 .389 r
F
.33172 .81363 m .32112 .81828 L .34426 .82061 L .142 0 0 r
F
.34389 .8204 m .30469 .81002 L .3174 .81737 L p 0 .509 .79 r
F P
0 g
s
.34389 .8204 m .30469 .81002 L .36473 .832 L p .333 0 0 r
F P
0 g
s
.30469 .81002 m .36473 .832 L p .3558 .82464 L .099 .459 .887 r
F P
0 g
s
.31362 .78986 m .30565 .80786 L p .3558 .82464 L .099 .459 .887 r
F P
0 g
s
.30565 .80786 m .30469 .81002 L p .3558 .82464 L .099 .459 .887 r
F P
0 g
s
.36473 .832 m .37117 .83436 L .36831 .83215 L p .099 .459 .887 r
F P
0 g
s
.36831 .83215 m .31362 .78986 L p .36473 .832 L .099 .459 .887 r
F P
0 g
s
.38409 .8328 m .37961 .83261 L .38356 .83358 L .142 0 0 r
F
.39583 .84646 m .41817 .86764 L .40585 .85699 L 0 .056 .566 r
F
.39603 .84585 m .41817 .86764 L p .39583 .84646 L F P
0 g
s
.44353 .89655 m .43548 .8881 L p .4448 .89725 L 0 .056 .566 r
F P
0 g
s
.4448 .89725 m .44746 .89986 L .44353 .89655 L 0 .056 .566 r
F
.48205 .92692 m .48206 .92694 L .48227 .92596 L .819 .466 .389 r
F
.48227 .92596 m .48206 .92694 L .48239 .92555 L F
.482 .92687 m .48239 .92555 L .48236 .9255 L F
.45698 .93327 m .45689 .93321 L p .45698 .93327 L .318 .46 .846 r
F P
0 g
s
.45698 .93327 m .45248 .93915 L .45183 .93469 L .154 0 .282 r
F
.45698 .93327 m .45689 .93321 L .45696 .9333 L p .586 .451 .663 r
F P
0 g
s
.45696 .9333 m .45849 .93506 L p .45698 .93327 L .586 .451 .663 r
F P
0 g
s
.45698 .93327 m .45689 .93321 L .45703 .93326 L .318 .46 .846 r
F
.47102 .93535 m .48137 .92985 L .47109 .93573 L .082 0 .156 r
F
.48137 .92985 m .46074 .94165 L p .45717 .93322 L .154 0 .282 r
F P
0 g
s
.48137 .92985 m .45717 .93322 L .47718 .92771 L .154 0 .282 r
F
.46989 .91877 m .47022 .92003 L .46941 .91838 L 0 .056 .566 r
F
.46864 .91824 m .47214 .92114 L p .46983 .91887 L .564 .499 .74 r
F P
0 g
s
.47214 .92114 m .47998 .92763 L p .46983 .91887 L .564 .499 .74 r
F P
0 g
s
.48137 .92985 m .47795 .92684 L p .46989 .91877 L 0 .056 .566 r
F P
0 g
s
.47795 .92684 m .47755 .92649 L p .47601 .92493 L 0 .056 .566 r
F P
0 g
s
.46989 .91877 m .47795 .92684 L .47601 .92493 L 0 .056 .566 r
F
.46989 .91877 m .47755 .92649 L .46994 .91896 L F
.47991 .92769 m .48137 .92985 L .47987 .92772 L .082 0 .156 r
F
.48231 .92542 m .482 .92687 L .48236 .9255 L .819 .466 .389 r
F
.482 .92687 m .48137 .92985 L .48206 .92694 L F
.48162 .92643 m .4691 .91777 L .48137 .92985 L F
.47496 .92012 m .4691 .91777 L .48162 .92643 L F
.50311 .94678 m .5074 .95034 L p .50656 .95005 L .318 .46 .846 r
F P
0 g
s
.50656 .95005 m .4939 .94576 L .50311 .94678 L .318 .46 .846 r
F
.48137 .92985 m .47755 .92649 L p .47814 .92717 L 0 .06 .599 r
F P
0 g
s
.46989 .91877 m .46885 .91794 L .4686 .91769 L 0 .056 .566 r
F
.45685 .91728 m .45564 .91718 L .45689 .93321 L 0 0 .307 r
F
.44063 .89576 m .43986 .89554 L p .4431 .89822 L 0 .06 .599 r
F P
0 g
s
.51394 .90755 m .63382 .97409 L .48461 .92364 L p .47 .559 .865 r
F P
0 g
s
.51144 .93478 m .51127 .93471 L .55059 .94595 L .498 .362 .626 r
F
.63382 .97409 m .52772 .94336 L .52626 .94073 L F
.50602 .93353 m .50431 .93278 L .55059 .94595 L F
.63382 .97409 m .51304 .93663 L .55059 .94595 L F
.51304 .93663 m .50602 .93353 L .55059 .94595 L F
.63382 .97409 m .48461 .92364 L p .57517 1.00647 L .564 .499 .74 r
F P
0 g
s
.4545 .91709 m .45689 .93321 L p .45553 .91717 L 0 0 .307 r
F P
0 g
s
.45564 .91718 m .45553 .91717 L .45689 .93321 L 0 0 .307 r
F
.45174 .94322 m .44921 .93939 L .44863 .93328 L .154 0 .282 r
F
.45174 .94322 m .44863 .93328 L .4485 .93184 L F
.45344 .94581 m .45174 .94322 L .4485 .93184 L F
.45344 .94581 m .4485 .93184 L .44927 .93198 L F
.44507 .93125 m .44452 .93069 L .44519 .93128 L .05 .273 .766 r
F
.45344 .94581 m .44809 .94888 L .44522 .93331 L p .154 0 .282 r
F P
0 g
s
.44504 .93125 m .44809 .94888 L .44409 .93071 L .453 .096 .269 r
F
.44567 .93136 m .44452 .93069 L .45148 .93215 L .05 .273 .766 r
F
.45167 .93239 m .45148 .93215 L .45696 .9333 L F
.44567 .93136 m .45148 .93215 L .45167 .93239 L F
.41817 .86764 m .4691 .91777 L p .40585 .85699 L 0 .056 .566 r
F P
0 g
s
.4691 .91777 m .48137 .92985 L p .46933 .91822 L 0 .056 .566 r
F P
0 g
s
.4691 .91777 m .46933 .91822 L .40585 .85699 L 0 .056 .566 r
F
.4518 .93222 m .44452 .93069 L .45176 .93217 L .05 .273 .766 r
F
.4518 .93222 m .45176 .93217 L .45689 .93321 L F
.45689 .93321 m .45696 .9333 L p .4518 .93222 L F P
0 g
s
.44519 .93128 m .44452 .93069 L .44567 .93136 L .05 .273 .766 r
F
.44504 .93125 m .44507 .93125 L .44509 .93127 L F
.44655 .93151 m .44546 .93368 L .44504 .93125 L .154 0 .282 r
F
.44888 .90126 m .44353 .89655 L p .44746 .89986 L 0 .056 .566 r
F P
0 g
s
.65132 1.20453 m .59149 1.08852 L p .65735 1.21196 L .827 .789 .816 r
F P
0 g
s
.5862 1.09946 m .5644 1.10767 L .65835 .98045 L .801 .786 .838 r
F
.61987 1.04348 m .62105 1.04446 L .63382 .97409 L p .564 .499 .74 r
F P
0 g
s
.62289 1.02847 m .5644 1.10767 L .63382 .97409 L .801 .786 .838 r
F
.63382 .97409 m .60963 1.02064 L .58093 1.00329 L .498 .362 .626 r
F
.60963 1.02064 m .60325 1.03291 L .55251 .99715 L F
.5074 .95034 m .57517 1.00647 L p .46939 .94167 L .318 .46 .846 r
F P
0 g
s
.54964 .99597 m .46939 .94167 L .57517 1.00647 L .318 .46 .846 r
F
.51778 1.03944 m .5644 1.10767 L .53471 1.06413 L p .602 .163 0 r
F P
0 g
s
.51778 1.03944 m .5644 1.10767 L p .51711 1.03787 L .648 .425 .566 r
F P
0 g
s
.44475 .93109 m .44092 .92698 L .44452 .93069 L .05 .273 .766 r
F
.44474 .93108 m .44092 .92698 L p .44475 .93109 L F P
0 g
s
.52785 .55884 m .52895 .56581 L .52847 .54749 L .783 .69 .761 r
F
.52245 .65711 m .52895 .56581 L .52785 .55884 L F
.54663 .57509 m .54811 .57536 L p .54886 .57579 L .564 .548 .795 r
F P
0 g
s
.54494 .57703 m .5457 .57477 L .54559 .57474 L .63 .528 .72 r
F
.544 .57417 m .54386 .57404 L p .54333 .57393 L .427 .617 .93 r
F P
0 g
s
.5457 .57477 m .54571 .57471 L .54499 .57452 L .63 .528 .72 r
F
.54452 .57439 m .54499 .57452 L .5441 .57421 L F
.54446 .57419 m .54452 .57439 L p .54386 .57404 L .363 .591 .932 r
F P
0 g
s
.544 .57417 m .54386 .57404 L p .54452 .57439 L .363 .591 .932 r
F P
0 g
s
.54446 .57419 m .54452 .57439 L p .54527 .57453 L .438 .648 .947 r
F P
0 g
s
.53175 .52761 m .54366 .63729 L .56129 .59628 L .719 .694 .825 r
F
.53072 .52522 m .53103 .5279 L .53175 .52761 L F
.53103 .5279 m .54366 .63729 L .53175 .52761 L F
.52809 .52632 m .54366 .63729 L .53072 .52522 L F
.48109 .53802 m .52245 .65711 L .52847 .54749 L .783 .69 .761 r
F
.4156 .50726 m .47631 .6673 L .48251 .67453 L .506 .498 .782 r
F
.45726 .6824 m .45809 .6486 L .44719 .66395 L .63 .528 .72 r
F
.4156 .50726 m .47264 .66302 L .47631 .6673 L .506 .498 .782 r
F
.36452 .51251 m .46973 .65898 L .4156 .50726 L .895 .6 .481 r
F
.33994 .64602 m .35426 .63759 L .34599 .64062 L .815 .867 .885 r
F
.34248 .64887 m .35215 .63961 L .33994 .64602 L .676 .519 .665 r
F
.38186 .6932 m .35215 .63961 L .34248 .64887 L F
.33994 .64602 m .30829 .59827 L .24518 .61407 L closepath p .885 .792 .752 r
F P
0 g
s
.2571 .65563 m .24518 .61407 L .29043 .62933 L p .864 .817 .801 r
F P
0 g
s
.29043 .62933 m .33994 .64602 L .28128 .65283 L p .864 .817 .801 r
F P
0 g
s
.28128 .65283 m .2571 .65563 L p .29043 .62933 L .864 .817 .801 r
F P
0 g
s
.30829 .59827 m .30183 .5568 L .24528 .57528 L closepath p .836 .913 .889 r
F P
0 g
s
.24518 .61407 m .24528 .57528 L .30829 .59827 L closepath p .858 .907 .866 r
F P
0 g
s
.2571 .65563 m .24518 .61407 L .2004 .6251 L closepath p .973 .847 .655 r
F P
0 g
s
.24518 .61407 m .24528 .57528 L .2037 .60172 L closepath p .94 .949 .758 r
F P
0 g
s
.2004 .6251 m .2037 .60172 L .24518 .61407 L closepath p .923 .96 .785 r
F P
0 g
s
.18906 .63714 m .30168 .60043 L .30183 .5568 L .949 .947 .738 r
F
.30168 .60043 m .30829 .59827 L .30664 .5877 L F
.30168 .60043 m .30664 .5877 L .30183 .5568 L F
.18906 .63714 m .33994 .64602 L .30829 .59827 L .975 .756 .544 r
F
.25176 .64073 m .58691 .60719 L .5261 .65642 L .446 .093 .273 r
F
.18906 .63714 m .27703 .63052 L .25176 .64073 L F
.27703 .63052 m .58691 .60719 L .25176 .64073 L F
.27703 .63052 m .60149 .56462 L .58691 .60719 L .451 .107 .29 r
F
.18906 .63714 m .31401 .61517 L .27703 .63052 L F
.31401 .61517 m .60149 .56462 L .27703 .63052 L F
.52658 .51559 m .52809 .52632 L .53072 .52522 L .719 .694 .825 r
F
.43548 .8881 m .40585 .85699 L p .44746 .89986 L 0 .056 .566 r
F P
0 g
s
.45726 .6824 m .44719 .66395 L .43975 .67443 L .63 .528 .72 r
F
.44423 .93134 m .44809 .94888 L .4366 .93513 L .453 .096 .269 r
F
.44474 .93108 m .44092 .92698 L .44398 .93146 L p .648 .425 .566 r
F P
0 g
s
.44477 .93111 m .44452 .93069 L .44507 .93125 L .05 .273 .766 r
F
.43759 .9017 m .44132 .89705 L .43748 .90135 L .648 .316 .396 r
F
.44132 .89705 m .44113 .89686 L .43748 .90135 L F
.44459 .90011 m .44357 .89915 L .4302 .91094 L .506 .148 .294 r
F
.44322 .89946 m .44341 .89904 L .44357 .89915 L .156 0 0 r
F
.43751 .91232 m .43809 .90332 L .44289 .89868 L F
.43751 .91232 m .44289 .89868 L .44341 .89904 L F
.43788 .90265 m .44222 .89798 L .43759 .9017 L .648 .316 .396 r
F
.44222 .89798 m .44202 .89777 L .43759 .9017 L F
.4302 .91094 m .43788 .90265 L .43759 .9017 L F
.43751 .91232 m .4302 .91094 L .43809 .90332 L .156 0 0 r
F
.43748 .90135 m .4302 .91094 L p .43759 .9017 L .648 .316 .396 r
F P
0 g
s
.44357 .89915 m .44124 .89695 L .4302 .91094 L .506 .148 .294 r
F
.43751 .91232 m .44322 .89946 L .44657 .90126 L .156 0 0 r
F
.44322 .89946 m .44357 .89915 L .44657 .90126 L F
.43889 .89567 m .44076 .89718 L p .43828 .89511 L 0 .06 .599 r
F P
0 g
s
.43748 .90135 m .44112 .89684 L .441 .89672 L .648 .316 .396 r
F
.441 .89672 m .4302 .91094 L p .44124 .89695 L .506 .148 .294 r
F P
0 g
s
.43986 .89554 m .43971 .8955 L p .4401 .89587 L 0 .06 .599 r
F P
0 g
s
.43971 .8955 m .43828 .89511 L p .4401 .89587 L 0 .06 .599 r
F P
0 g
s
.61987 1.04348 m .62105 1.04446 L .61999 1.04374 L p .318 .46 .846 r
F P
0 g
s
.62237 1.0494 m .66355 1.20374 L p .62795 1.04943 L .781 .764 .838 r
F P
0 g
s
.70318 1.10368 m .62795 1.04943 L p .73312 1.11093 L .828 .754 .782 r
F P
0 g
s
.80285 1.01794 m .60546 1.06771 L .68071 .98625 L .801 .786 .838 r
F
.62795 1.04943 m .62105 1.04446 L .62237 1.0494 L p .781 .764 .838 r
F P
0 g
s
.67671 1.04974 m .5862 1.09946 L .60546 1.06771 L .801 .786 .838 r
F
.80285 1.01794 m .71765 1.05 L .67671 1.04974 L F
.71765 1.05 m .5862 1.09946 L .67671 1.04974 L F
.70318 1.10368 m .66355 1.20374 L .68333 1.17732 L .781 .764 .838 r
F
.61249 1.27194 m .61079 1.27404 L .68333 1.17732 L .534 .313 .526 r
F
.67709 1.25448 m .71164 1.21224 L p .66274 1.2079 L .324 .123 .445 r
F P
0 g
s
.66355 1.20374 m .66985 1.22735 L p .68333 1.17732 L .781 .764 .838 r
F P
0 g
s
.70318 1.10368 m .65735 1.21196 L .62519 1.08479 L .801 .786 .838 r
F
.73312 1.11093 m .68333 1.17732 L .70318 1.10368 L F
.68333 1.17732 m .65735 1.21196 L .70318 1.10368 L F
.75787 1.13992 m .76436 1.1478 L .72326 1.15891 L p .125 0 0 r
F P
0 g
s
.71164 1.21224 m .76436 1.1478 L .72326 1.15891 L p .324 .123 .445 r
F P
0 g
s
.76436 1.1478 m .70318 1.10368 L p .67376 1.24203 L .781 .764 .838 r
F P
0 g
s
.66985 1.22735 m .67376 1.24203 L p .70318 1.10368 L .781 .764 .838 r
F P
0 g
s
.72609 1.1202 m .70318 1.10368 L p .73312 1.11093 L .828 .754 .782 r
F P
0 g
s
.62519 1.08479 m .65735 1.21196 L .57074 1.10528 L .801 .786 .838 r
F
.80285 1.01794 m .73312 1.11093 L .62519 1.08479 L F
.56676 1.33276 m .67709 1.25448 L .65132 1.20453 L p .797 .779 .836 r
F P
0 g
s
.65605 1.21369 m .65132 1.20453 L p .65735 1.21196 L .827 .789 .816 r
F P
0 g
s
.57074 1.10528 m .56676 1.33276 L .5644 1.10767 L .801 .786 .838 r
F
.60546 1.06771 m .62105 1.04446 L .62237 1.0494 L p .827 .789 .816 r
F P
0 g
s
.66355 1.20374 m .67709 1.25448 L .65605 1.21369 L p .827 .789 .816 r
F P
0 g
s
.73489 1.10859 m .76436 1.1478 L .72609 1.1202 L p .828 .754 .782 r
F P
0 g
s
.67376 1.24203 m .67709 1.25448 L .71164 1.21224 L p .781 .764 .838 r
F P
0 g
s
.71164 1.21224 m .76436 1.1478 L p .67376 1.24203 L .781 .764 .838 r
F P
0 g
s
.62795 1.04943 m .62105 1.04446 L .63382 .97409 L p .828 .754 .782 r
F P
0 g
s
.65835 .98045 m .63037 1.01834 L .63382 .97409 L .801 .786 .838 r
F
.60546 1.06771 m .62105 1.04446 L .61999 1.04374 L p .586 .451 .663 r
F P
0 g
s
.50917 1.00021 m .45814 .94546 L p .53994 1.02904 L .05 .273 .766 r
F P
0 g
s
.45814 .94546 m .46081 .94748 L .53994 1.02904 L .05 .273 .766 r
F
.48542 .96613 m .53994 1.02904 L p .46081 .94748 L F P
0 g
s
.44092 .92698 m .44275 .9277 L p .44452 .93069 L .05 .273 .766 r
F P
0 g
s
.44275 .9277 m .45689 .93321 L p .44452 .93069 L .05 .273 .766 r
F P
0 g
s
.50917 1.00021 m .49419 .98413 L p .5644 1.10767 L .648 .425 .566 r
F P
0 g
s
.49419 .98413 m .45814 .94546 L p .51711 1.03787 L .648 .425 .566 r
F P
0 g
s
.49419 .98413 m .51711 1.03787 L .5644 1.10767 L .648 .425 .566 r
F
.44097 1.20814 m .38148 1.24217 L .4105 1.25636 L .534 .313 .526 r
F
.44097 1.20814 m .4105 1.25636 L .56676 1.33276 L F
.47125 1.15667 m .38148 1.24217 L .46415 1.19488 L .698 .574 .713 r
F
.46499 .97482 m .46494 .97475 L p .46576 .9685 L .98 .844 .635 r
F P
0 g
s
.46576 .9685 m .45479 1.05904 L .52917 1.1015 L .698 .574 .713 r
F
.52917 1.1015 m .35287 1.00087 L .38148 1.24217 L F
.52847 .54749 m .53113 .54803 L .52658 .51559 L .783 .69 .761 r
F
.47073 .50819 m .48109 .53802 L .52658 .51559 L F
.48109 .53802 m .52847 .54749 L .52658 .51559 L F
.47073 .50819 m .4758 .53501 L .48109 .53802 L F
.66097 .65114 m .58691 .60719 L .63945 .62214 L p .82 .401 .246 r
F P
0 g
s
.63945 .62214 m .74471 .65208 L p .66097 .65114 L .82 .401 .246 r
F P
0 g
s
.8046 .94246 m .8319 .98451 L .8201 .9981 L .938 .571 .189 r
F
.8046 .94246 m .8201 .9981 L .80285 1.01794 L F
.79344 .86468 m .78432 .86971 L p .78532 .80807 L .105 .087 .551 r
F P
0 g
s
.77487 .83578 m .78532 .80807 L p .78432 .86971 L .105 .087 .551 r
F P
0 g
s
.78532 .80807 m .79942 .77066 L p .79344 .86468 L .105 .087 .551 r
F P
0 g
s
.8031 .93203 m .8319 .98451 L .8046 .94246 L 0 .041 .609 r
F
.53094 .50387 m .52985 .50362 L p .53155 .50283 L .547 .521 .778 r
F P
0 g
s
.52985 .50362 m .53073 .50695 L p .5308 .50598 L .594 .413 .606 r
F P
0 g
s
.54354 .50676 m .53956 .50585 L p .54327 .50312 L .547 .521 .778 r
F P
0 g
s
.54176 .44706 m .53432 .40204 L .54634 .45523 L 0 0 .271 r
F
.51328 .51199 m .51813 .49835 L p .51117 .51284 L .108 0 .251 r
F P
0 g
s
.51646 .51096 m .52985 .50362 L p .5165 .51126 L .575 .401 .609 r
F P
0 g
s
.51646 .51096 m .52985 .50362 L p .51793 .51002 L 0 0 0 r
F P
0 g
s
.27356 .6841 m .29736 .69732 L .26845 .67161 L .909 .526 .28 r
F
.29736 .69732 m .29505 .68801 L .26845 .67161 L F
.52038 .50356 m .52109 .50695 L .51976 .50781 L .752 .501 .553 r
F
.52114 .50532 m .52109 .50695 L .52038 .50356 L F
.5211 .48999 m .52237 .48664 L p .52329 .4866 L .874 .731 .7 r
F P
0 g
s
.52055 .50336 m .52126 .50251 L .51976 .50781 L .183 .006 .391 r
F
.52038 .50356 m .52055 .50336 L .51976 .50781 L F
.52171 .50555 m .5216 .50662 L .52109 .50695 L .752 .501 .553 r
F
.53395 .49933 m .54233 .49056 L p .53542 .50103 L .547 .521 .778 r
F P
0 g
s
.54233 .49056 m .54249 .4926 L .53542 .50103 L .547 .521 .778 r
F
.53542 .50103 m .54249 .4926 L .54285 .49757 L F
.52114 .50532 m .52147 .50609 L .52109 .50695 L .752 .501 .553 r
F
.52985 .50362 m .52427 .50594 L p .51793 .51002 L 0 0 0 r
F P
0 g
s
.52427 .50594 m .51976 .50781 L p .51793 .51002 L 0 0 0 r
F P
0 g
s
.53819 .4823 m .53877 .4816 L .53883 .48186 L .45 .357 .659 r
F
.52985 .50362 m .51976 .50781 L p .52126 .50251 L .183 .006 .391 r
F P
0 g
s
.53614 .46923 m .5211 .48999 L .52237 .48664 L p 0 0 .185 r
F P
0 g
s
.51429 .48947 m .53614 .46923 L .5174 .49667 L .45 .357 .659 r
F
.53771 .47227 m .53778 .4722 L .53777 .47204 L .192 .012 .394 r
F
.53883 .48186 m .53989 .48064 L .53955 .47927 L F
.53883 .48186 m .53955 .47927 L .53777 .47204 L F
.53362 .50053 m .53614 .46923 L .53883 .48186 L p .751 .554 .629 r
F P
0 g
s
.53821 .46731 m .53821 .46729 L .53821 .46733 L 0 0 .271 r
F
.53431 .45659 m .53614 .46923 L .53366 .45703 L 0 0 .185 r
F
.53409 .45675 m .53432 .40204 L p .53412 .45673 L .21 .349 .786 r
F P
0 g
s
.54257 .47654 m .53409 .45675 L .53432 .40204 L 0 0 .271 r
F
.55312 .48523 m .53432 .40204 L .56321 .46049 L F
.61993 .37062 m .63665 .33929 L p .58241 .30659 L .743 .551 .634 r
F P
0 g
s
.65931 .29684 m .66073 .30375 L p .58991 .25099 L 0 .376 .82 r
F P
0 g
s
.55315 .22362 m .65931 .29684 L p .58991 .25099 L 0 .376 .82 r
F P
0 g
s
.66073 .30375 m .66285 .31404 L .6328 .28927 L p 0 .376 .82 r
F P
0 g
s
.6328 .28927 m .55315 .22362 L p .66073 .30375 L 0 .376 .82 r
F P
0 g
s
.63665 .33929 m .65931 .29684 L .61305 .30271 L p .743 .551 .634 r
F P
0 g
s
.61305 .30271 m .58241 .30659 L p .63665 .33929 L .743 .551 .634 r
F P
0 g
s
.58241 .30659 m .52821 .31346 L .59311 .35391 L p .743 .551 .634 r
F P
0 g
s
.59311 .35391 m .61993 .37062 L p .58241 .30659 L .743 .551 .634 r
F P
0 g
s
.66285 .31404 m .68771 .40327 L p .65787 .34961 L .676 .638 .804 r
F P
0 g
s
.68771 .40327 m .68899 .40789 L p .65787 .34961 L .676 .638 .804 r
F P
0 g
s
.72184 .5176 m .69998 .4795 L .69751 .46244 L .961 .674 .444 r
F
.53767 .46898 m .53757 .46571 L .53821 .46729 L 0 0 .271 r
F
.38186 .6932 m .41417 .67206 L .41491 .66042 L .676 .519 .665 r
F
.38186 .6932 m .33994 .64602 L .2571 .65563 L closepath p .864 .665 .632 r
F P
0 g
s
.18906 .63714 m .38186 .6932 L .33994 .64602 L .924 .562 .32 r
F
0 g
.51593 .4811 m
.51731 .47927 L
s
.51731 .47927 m
.53267 .45899 L
s
.53267 .45899 m
.53316 .45835 L
s
.5067 .49328 m
.51593 .4811 L
s
.50272 .49853 m
.5067 .49328 L
s
.49935 .50298 m
.50272 .49853 L
s
.61993 .37062 m .68656 .45729 L .69913 .43755 L p .869 .661 .619 r
F P
0 g
s
.72193 .40173 m .68899 .40789 L .65931 .29684 L closepath p .173 .384 .829 r
F P
0 g
s
.69913 .43755 m .72193 .40173 L .68574 .3907 L p .869 .661 .619 r
F P
0 g
s
.66285 .31404 m .68899 .40789 L .66476 .31725 L p 0 0 .226 r
F P
0 g
s
.68574 .3907 m .61993 .37062 L p .69913 .43755 L .869 .661 .619 r
F P
0 g
s
.66476 .31725 m .65931 .29684 L .66027 .30153 L p 0 0 .226 r
F P
0 g
s
.66027 .30153 m .66285 .31404 L p .66476 .31725 L 0 0 .226 r
F P
0 g
s
.53614 .46923 m
.53754 .46481 L
s
.68656 .45729 m .72193 .40173 L .72184 .5176 L closepath p .974 .88 .676 r
F P
0 g
s
.70272 .56015 m .72184 .5176 L .68656 .45729 L closepath p 1 .828 .524 r
F P
0 g
s
.01 w
.72184 .5176 Mdot
.72184 .5176 Mdot
.72184 .5176 Mdot
.72184 .5176 Mdot
.72184 .5176 Mdot
.72184 .5176 Mdot
.5 Mabswid
.53409 .45675 m
.53432 .40204 L
s
.01 w
.59907 .2393 Mdot
.59907 .2393 Mdot
.59907 .2393 Mdot
.5 Mabswid
.53614 .46923 m
.53883 .48186 L
s
.01 w
.53614 .46923 Mdot
.53614 .46923 Mdot
.53614 .46923 Mdot
.5 Mabswid
.61725 .52367 m .68656 .45729 L .70272 .56015 L closepath p .781 .727 .803 r
F P
0 g
s
.01 w
.70272 .56015 Mdot
.70272 .56015 Mdot
.70272 .56015 Mdot
.70272 .56015 Mdot
.70272 .56015 Mdot
.70272 .56015 Mdot
.52985 .50362 Mdot
.52985 .50362 Mdot
.52985 .50362 Mdot
.52985 .50362 Mdot
.52985 .50362 Mdot
.52985 .50362 Mdot
.5 Mabswid
.61993 .37062 m .65931 .29684 L .72193 .40173 L closepath p .858 .704 .69 r
F P
0 g
s
.01 w
.72193 .40173 Mdot
.72193 .40173 Mdot
.72193 .40173 Mdot
.72193 .40173 Mdot
.72193 .40173 Mdot
.72193 .40173 Mdot
.5 Mabswid
.30183 .5568 m .32326 .5278 L .25963 .5428 L closepath p .648 .935 .968 r
F P
0 g
s
.24528 .57528 m .25963 .5428 L .30183 .5568 L closepath p .777 .96 .927 r
F P
0 g
s
.18906 .63714 m .30183 .5568 L .32326 .5278 L .663 .948 .701 r
F
0 g
.01 w
.53432 .40204 Mdot
.53432 .40204 Mdot
.53432 .40204 Mdot
.5 Mabswid
.20403 .7307 m .20626 .72363 L .28539 .79375 L closepath p .867 .422 .112 r
F P
0 g
s
.2707 .79791 m .28539 .79375 L .20403 .7307 L closepath p .872 .431 .126 r
F P
0 g
s
.01 w
.61725 .52367 Mdot
.61725 .52367 Mdot
.61725 .52367 Mdot
.61725 .52367 Mdot
.61725 .52367 Mdot
.61725 .52367 Mdot
.68656 .45729 Mdot
.68656 .45729 Mdot
.68656 .45729 Mdot
.68656 .45729 Mdot
.68656 .45729 Mdot
.68656 .45729 Mdot
.5 Mabswid
.52821 .31346 m .55315 .22362 L .65931 .29684 L closepath p .752 .6 .688 r
F P
0 g
s
.52821 .31346 m
.53432 .40204 L
s
.55315 .22362 m
.59907 .2393 L
s
.01 w
.65931 .29684 Mdot
.65931 .29684 Mdot
.65931 .29684 Mdot
.65931 .29684 Mdot
.65931 .29684 Mdot
.65931 .29684 Mdot
.5 Mabswid
.24528 .57528 m .25963 .5428 L .21097 .58094 L closepath p .82 1 .803 r
F P
0 g
s
.2037 .60172 m .21097 .58094 L .24528 .57528 L closepath p .861 .997 .784 r
F P
0 g
s
.20528 .69394 m .20274 .67291 L .18906 .63714 L closepath p .838 .622 .075 r
F P
0 g
s
.20671 .71117 m .20528 .69394 L .18906 .63714 L closepath p .839 .624 .078 r
F P
0 g
s
.20626 .72363 m .20671 .71117 L .18906 .63714 L closepath p .871 .67 .142 r
F P
0 g
s
.52821 .31346 m
.55315 .22362 L
s
.01 w
.55315 .22362 Mdot
.55315 .22362 Mdot
.55315 .22362 Mdot
.5 Mabswid
.20087 .7321 m .20403 .7307 L .2707 .79791 L closepath p .721 .216 0 r
F P
0 g
s
.25571 .79464 m .2707 .79791 L .20087 .7321 L closepath p .793 .306 0 r
F P
0 g
s
.20403 .7307 m .20626 .72363 L .18906 .63714 L closepath p .9 .71 .203 r
F P
0 g
s
.01 w
.52821 .31346 Mdot
.52821 .31346 Mdot
.52821 .31346 Mdot
.61993 .37062 Mdot
.61993 .37062 Mdot
.61993 .37062 Mdot
.61993 .37062 Mdot
.61993 .37062 Mdot
.61993 .37062 Mdot
.18906 .63714 m .32326 .5278 L .36452 .51251 L 0 0 0 r
F
.5 Mabswid
.32326 .5278 m .36452 .51251 L .28613 .5187 L closepath p .399 .835 .949 r
F P
0 g
s
.25963 .5428 m .28613 .5187 L .32326 .5278 L closepath p .619 .933 .964 r
F P
0 g
s
.2004 .6251 m .2037 .60172 L .18906 .63714 L closepath p .838 .812 .326 r
F P
0 g
s
.35287 1.00087 m
.38148 1.24217 L
s
.38148 1.24217 m
.56676 1.33276 L
s
.01 w
.38148 1.24217 Mdot
.38148 1.24217 Mdot
.38148 1.24217 Mdot
.5 Mabswid
.20087 .7321 m .20403 .7307 L .18906 .63714 L closepath p .899 .709 .2 r
F P
0 g
s
.01 w
.35287 1.00087 Mdot
.35287 1.00087 Mdot
.35287 1.00087 Mdot
.5 Mabswid
.35287 1.00087 m
.4094 .90261 L
s
.25963 .5428 m .28613 .5187 L .22174 .56419 L closepath p .556 .91 .707 r
F P
0 g
s
.21097 .58094 m .22174 .56419 L .25963 .5428 L closepath p .729 .98 .756 r
F P
0 g
s
.2037 .60172 m .21097 .58094 L .18906 .63714 L closepath p .696 .771 .283 r
F P
0 g
s
.19814 .72775 m .20087 .7321 L .18906 .63714 L closepath p .842 .646 .102 r
F P
0 g
s
.19814 .72775 m .20087 .7321 L .25571 .79464 L closepath p 0 0 .517 r
F P
0 g
s
.01 w
.20087 .7321 Mdot
.20087 .7321 Mdot
.20087 .7321 Mdot
.20087 .7321 Mdot
.20087 .7321 Mdot
.5 Mabswid
.24455 .78385 m .25571 .79464 L .19814 .72775 L closepath p .594 .113 0 r
F P
0 g
s
.24455 .78385 m .25571 .79464 L .3174 .81737 L closepath p 0 .436 .809 r
F P
0 g
s
.01 w
.25571 .79464 Mdot
.25571 .79464 Mdot
.25571 .79464 Mdot
.25571 .79464 Mdot
.25571 .79464 Mdot
.25571 .79464 Mdot
.18906 .63714 m .36452 .51251 L .4156 .50726 L .331 0 .171 r
F
.5 Mabswid
.36452 .51251 m .4156 .50726 L .32015 .50345 L closepath p .229 .73 .905 r
F P
0 g
s
.28613 .5187 m .32015 .50345 L .36452 .51251 L closepath p .453 .854 .971 r
F P
0 g
s
.21097 .58094 m .22174 .56419 L .18906 .63714 L closepath p 0 0 0 r
F P
0 g
s
.01 w
.21097 .58094 Mdot
.21097 .58094 Mdot
.21097 .58094 Mdot
.21097 .58094 Mdot
.21097 .58094 Mdot
.5 Mabswid
.1974 .71776 m .19814 .72775 L .24455 .78385 L closepath p 0 .123 .671 r
F P
0 g
s
.1974 .71776 m .19814 .72775 L .18906 .63714 L closepath p 0 0 .09 r
F P
0 g
s
.01 w
.19814 .72775 Mdot
.19814 .72775 Mdot
.19814 .72775 Mdot
.19814 .72775 Mdot
.19814 .72775 Mdot
.5 Mabswid
.22174 .56419 m .23457 .55254 L .28613 .5187 L closepath p .529 .893 .684 r
F P
0 g
s
.28613 .5187 m .32015 .50345 L .23457 .55254 L closepath p 0 0 0 r
F P
0 g
s
.01 w
.28613 .5187 Mdot
.28613 .5187 Mdot
.28613 .5187 Mdot
.28613 .5187 Mdot
.28613 .5187 Mdot
.28613 .5187 Mdot
.5 Mabswid
.37463 .83139 m
.38356 .83358 L
s
.30469 .81002 m .3174 .81737 L .24455 .78385 L closepath p 0 .317 .681 r
F P
0 g
s
.3174 .81737 m
.33967 .82283 L
s
.01 w
.3174 .81737 Mdot
.3174 .81737 Mdot
.3174 .81737 Mdot
.3174 .81737 Mdot
.3174 .81737 Mdot
.3174 .81737 Mdot
.3174 .81737 Mdot
.3174 .81737 Mdot
.3174 .81737 Mdot
.5 Mabswid
.22174 .56419 m .23457 .55254 L .18906 .63714 L closepath p 0 0 .093 r
F P
0 g
s
.01 w
.22174 .56419 Mdot
.22174 .56419 Mdot
.22174 .56419 Mdot
.22174 .56419 Mdot
.22174 .56419 Mdot
.5 Mabswid
.242 .76451 m .24455 .78385 L .30469 .81002 L closepath p .048 .429 .87 r
F P
0 g
s
.242 .76451 m .24455 .78385 L .1974 .71776 L closepath p 0 .116 .666 r
F P
0 g
s
.01 w
.24455 .78385 Mdot
.24455 .78385 Mdot
.24455 .78385 Mdot
.24455 .78385 Mdot
.24455 .78385 Mdot
.24455 .78385 Mdot
.18906 .63714 m .57542 .53347 L .60149 .56462 L .481 .173 .366 r
F
.18906 .63714 m .52658 .51559 L .57542 .53347 L .502 .216 .412 r
F
.18906 .63714 m .47073 .50819 L .52658 .51559 L .497 .207 .403 r
F
.18906 .63714 m .4156 .50726 L .47073 .50819 L .456 .138 .337 r
F
.18906 .63714 m .31362 .78986 L .30469 .81002 L 0 .129 .676 r
F
.18906 .63714 m .35834 .75431 L .31362 .78986 L .289 .295 .692 r
F
.18906 .63714 m .43795 .70741 L .35834 .75431 L .439 .267 .55 r
F
.18906 .63714 m .5261 .65642 L .43795 .70741 L .464 .17 .38 r
F
.5 Mabswid
.26411 .56729 m .2579 .5859 L .18906 .63714 L closepath p 0 0 .223 r
F P
0 g
s
.26402 .55414 m .26411 .56729 L .18906 .63714 L closepath p .014 0 .265 r
F P
0 g
s
.25795 .5472 m .26402 .55414 L .18906 .63714 L closepath p .05 0 .31 r
F P
0 g
s
.24741 .54672 m .25795 .5472 L .18906 .63714 L closepath p .051 0 .311 r
F P
0 g
s
.23457 .55254 m .24741 .54672 L .18906 .63714 L closepath p 0 0 .244 r
F P
0 g
s
.20009 .70243 m .1974 .71776 L .18906 .63714 L closepath p 0 0 .299 r
F P
0 g
s
.2071 .68245 m .20009 .70243 L .18906 .63714 L closepath p 0 0 .417 r
F P
0 g
s
.21832 .65898 m .2071 .68245 L .18906 .63714 L closepath p 0 0 .428 r
F P
0 g
s
.2323 .6337 m .21832 .65898 L .18906 .63714 L closepath p .017 0 .371 r
F P
0 g
s
.24649 .60864 m .2323 .6337 L .18906 .63714 L closepath p .011 0 .288 r
F P
0 g
s
.2579 .5859 m .24649 .60864 L .18906 .63714 L closepath p 0 0 .227 r
F P
0 g
s
.01 w
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.18906 .63714 Mdot
.5 Mabswid
.20009 .70243 m .1974 .71776 L .242 .76451 L closepath p 0 .198 .718 r
F P
0 g
s
.01 w
.1974 .71776 Mdot
.1974 .71776 Mdot
.1974 .71776 Mdot
.1974 .71776 Mdot
.1974 .71776 Mdot
.5 Mabswid
.4156 .50726 m .47073 .50819 L .35639 .49692 L closepath p .108 .647 .85 r
F P
0 g
s
.32015 .50345 m .35639 .49692 L .4156 .50726 L closepath p .27 .751 .928 r
F P
0 g
s
.8319 .98451 m .80285 1.01794 L .77378 .87858 L closepath p .968 .738 .303 r
F P
0 g
s
.83919 .83943 m .77378 .87858 L .8319 .98451 L closepath p .966 .92 .704 r
F P
0 g
s
.01 w
.8319 .98451 Mdot
.8319 .98451 Mdot
.8319 .98451 Mdot
.8319 .98451 Mdot
.8319 .98451 Mdot
.8319 .98451 Mdot
.5 Mabswid
.23457 .55254 m .24741 .54672 L .32015 .50345 L closepath p 0 0 0 r
F P
0 g
s
.01 w
.23457 .55254 Mdot
.23457 .55254 Mdot
.23457 .55254 Mdot
.23457 .55254 Mdot
.23457 .55254 Mdot
.5 Mabswid
.32015 .50345 m .35639 .49692 L .24741 .54672 L closepath p .11 0 0 r
F P
0 g
s
.01 w
.32015 .50345 Mdot
.32015 .50345 Mdot
.32015 .50345 Mdot
.32015 .50345 Mdot
.32015 .50345 Mdot
.32015 .50345 Mdot
.5 Mabswid
.79942 .77066 m .83919 .83943 L .74948 .70367 L closepath p .665 .235 0 r
F P
0 g
s
.74471 .65208 m .74948 .70367 L .79942 .77066 L closepath p .893 .563 .07 r
F P
0 g
s
.01 w
.79942 .77066 Mdot
.79942 .77066 Mdot
.79942 .77066 Mdot
.79942 .77066 Mdot
.79942 .77066 Mdot
.79942 .77066 Mdot
.5 Mabswid
.2533 .73566 m .242 .76451 L .20009 .70243 L closepath p .098 .263 .745 r
F P
0 g
s
.2071 .68245 m .20009 .70243 L .2533 .73566 L closepath p .147 .258 .723 r
F P
0 g
s
.01 w
.20009 .70243 Mdot
.20009 .70243 Mdot
.20009 .70243 Mdot
.20009 .70243 Mdot
.20009 .70243 Mdot
.4094 .90261 Mdot
.4094 .90261 Mdot
.4094 .90261 Mdot
.5 Mabswid
.4366 .93513 m
.44809 .94888 L
s
.42289 .91874 m
.4366 .93513 L
s
.42216 .91786 m
.42289 .91874 L
s
.4094 .90261 m
.42216 .91786 L
s
.35639 .49692 m .38927 .49948 L .47073 .50819 L closepath p 0 .541 .73 r
F P
0 g
s
.47073 .50819 m .52658 .51559 L .38927 .49948 L closepath p .116 0 0 r
F P
0 g
s
.01 w
.47073 .50819 Mdot
.47073 .50819 Mdot
.47073 .50819 Mdot
.47073 .50819 Mdot
.47073 .50819 Mdot
.47073 .50819 Mdot
.5 Mabswid
.24741 .54672 m .25795 .5472 L .35639 .49692 L closepath p .053 0 0 r
F P
0 g
s
.01 w
.24741 .54672 Mdot
.24741 .54672 Mdot
.24741 .54672 Mdot
.24741 .54672 Mdot
.24741 .54672 Mdot
.5 Mabswid
.31362 .78986 m .30469 .81002 L .242 .76451 L closepath p .093 .451 .883 r
F P
0 g
s
.01 w
.30469 .81002 Mdot
.30469 .81002 Mdot
.30469 .81002 Mdot
.30469 .81002 Mdot
.30469 .81002 Mdot
.30469 .81002 Mdot
.5 Mabswid
.2533 .73566 m .242 .76451 L .31362 .78986 L closepath p .234 .428 .848 r
F P
0 g
s
.01 w
.242 .76451 Mdot
.242 .76451 Mdot
.242 .76451 Mdot
.242 .76451 Mdot
.242 .76451 Mdot
.242 .76451 Mdot
.5 Mabswid
.35639 .49692 m .38927 .49948 L .25795 .5472 L closepath p .3 0 .064 r
F P
0 g
s
.01 w
.35639 .49692 Mdot
.35639 .49692 Mdot
.35639 .49692 Mdot
.35639 .49692 Mdot
.35639 .49692 Mdot
.35639 .49692 Mdot
.5 Mabswid
.2815 .69791 m .2533 .73566 L .2071 .68245 L closepath p .299 .305 .699 r
F P
0 g
s
.21832 .65898 m .2071 .68245 L .2815 .69791 L closepath p .292 .317 .716 r
F P
0 g
s
.01 w
.2071 .68245 Mdot
.2071 .68245 Mdot
.2071 .68245 Mdot
.2071 .68245 Mdot
.2071 .68245 Mdot
.5 Mabswid
.686 .61019 m .74471 .65208 L .60149 .56462 L closepath p .494 0 0 r
F P
0 g
s
.57542 .53347 m .60149 .56462 L .686 .61019 L closepath p .676 .135 0 r
F P
0 g
s
.01 w
.686 .61019 Mdot
.686 .61019 Mdot
.686 .61019 Mdot
.686 .61019 Mdot
.686 .61019 Mdot
.686 .61019 Mdot
.67709 1.25448 Mdot
.67709 1.25448 Mdot
.67709 1.25448 Mdot
.67709 1.25448 Mdot
.67709 1.25448 Mdot
.67709 1.25448 Mdot
.5 Mabswid
.5644 1.10767 m
.56676 1.33276 L
s
.01 w
.56676 1.33276 Mdot
.56676 1.33276 Mdot
.56676 1.33276 Mdot
.5 Mabswid
.25795 .5472 m .26402 .55414 L .38927 .49948 L closepath p .315 0 .089 r
F P
0 g
s
.01 w
.25795 .5472 Mdot
.25795 .5472 Mdot
.25795 .5472 Mdot
.25795 .5472 Mdot
.25795 .5472 Mdot
.4302 .91094 Mdot
.4302 .91094 Mdot
.4302 .91094 Mdot
.5 Mabswid
.52658 .51559 m .57542 .53347 L .41233 .51211 L closepath p .452 0 0 r
F P
0 g
s
.38927 .49948 m .41233 .51211 L .52658 .51559 L closepath p .456 0 0 r
F P
0 g
s
.01 w
.52658 .51559 Mdot
.52658 .51559 Mdot
.52658 .51559 Mdot
.52658 .51559 Mdot
.52658 .51559 Mdot
.52658 .51559 Mdot
.44353 .89655 Mdot
.44353 .89655 Mdot
.44353 .89655 Mdot
.44353 .89655 Mdot
.44353 .89655 Mdot
.44353 .89655 Mdot
.5 Mabswid
.32346 .65435 m .2815 .69791 L .21832 .65898 L closepath p .4 .291 .614 r
F P
0 g
s
.2323 .6337 m .21832 .65898 L .32346 .65435 L closepath p .405 .364 .7 r
F P
0 g
s
.01 w
.21832 .65898 Mdot
.21832 .65898 Mdot
.21832 .65898 Mdot
.21832 .65898 Mdot
.21832 .65898 Mdot
.5 Mabswid
.26402 .55414 m .26411 .56729 L .41233 .51211 L closepath p .465 .147 .341 r
F P
0 g
s
.38927 .49948 m .41233 .51211 L .26402 .55414 L closepath p .402 .031 .216 r
F P
0 g
s
.01 w
.26402 .55414 Mdot
.26402 .55414 Mdot
.26402 .55414 Mdot
.26402 .55414 Mdot
.26402 .55414 Mdot
.76436 1.1478 Mdot
.76436 1.1478 Mdot
.76436 1.1478 Mdot
.76436 1.1478 Mdot
.76436 1.1478 Mdot
.76436 1.1478 Mdot
.44092 .92698 Mdot
.44092 .92698 Mdot
.44092 .92698 Mdot
.44092 .92698 Mdot
.44092 .92698 Mdot
.44092 .92698 Mdot
.38927 .49948 Mdot
.38927 .49948 Mdot
.38927 .49948 Mdot
.38927 .49948 Mdot
.38927 .49948 Mdot
.38927 .49948 Mdot
.5 Mabswid
.36865 .60968 m .32346 .65435 L .2323 .6337 L closepath p .446 .252 .523 r
F P
0 g
s
.24649 .60864 m .2323 .6337 L .36865 .60968 L closepath p .481 .382 .666 r
F P
0 g
s
.01 w
.2323 .6337 Mdot
.2323 .6337 Mdot
.2323 .6337 Mdot
.2323 .6337 Mdot
.2323 .6337 Mdot
.5 Mabswid
.26411 .56729 m .2579 .5859 L .41863 .53544 L closepath p .523 .292 .506 r
F P
0 g
s
.41233 .51211 m .41863 .53544 L .26411 .56729 L closepath p .448 .117 .312 r
F P
0 g
s
.01 w
.26411 .56729 Mdot
.26411 .56729 Mdot
.26411 .56729 Mdot
.26411 .56729 Mdot
.26411 .56729 Mdot
.5 Mabswid
.35834 .75431 m .31362 .78986 L .2533 .73566 L closepath p .391 .476 .827 r
F P
0 g
s
.2815 .69791 m .2533 .73566 L .35834 .75431 L closepath p .407 .454 .797 r
F P
0 g
s
.01 w
.2533 .73566 Mdot
.2533 .73566 Mdot
.2533 .73566 Mdot
.2533 .73566 Mdot
.2533 .73566 Mdot
.2533 .73566 Mdot
.5 Mabswid
.83919 .83943 m .77378 .87858 L .67463 .75066 L closepath p .919 .632 .483 r
F P
0 g
s
.74948 .70367 m .67463 .75066 L .83919 .83943 L closepath p .893 .737 .681 r
F P
0 g
s
.01 w
.83919 .83943 Mdot
.83919 .83943 Mdot
.83919 .83943 Mdot
.83919 .83943 Mdot
.83919 .83943 Mdot
.83919 .83943 Mdot
.37117 .83436 Mdot
.37117 .83436 Mdot
.37117 .83436 Mdot
.37117 .83436 Mdot
.37117 .83436 Mdot
.37117 .83436 Mdot
.5 Mabswid
.40353 .56876 m .36865 .60968 L .24649 .60864 L closepath p .462 .208 .443 r
F P
0 g
s
.2579 .5859 m .24649 .60864 L .40353 .56876 L closepath p .522 .363 .606 r
F P
0 g
s
.01 w
.24649 .60864 Mdot
.24649 .60864 Mdot
.24649 .60864 Mdot
.24649 .60864 Mdot
.24649 .60864 Mdot
.5 Mabswid
.41863 .53544 m .40353 .56876 L .2579 .5859 L closepath p .463 .168 .378 r
F P
0 g
s
.01 w
.2579 .5859 Mdot
.2579 .5859 Mdot
.2579 .5859 Mdot
.2579 .5859 Mdot
.2579 .5859 Mdot
.5 Mabswid
.60149 .56462 m .58691 .60719 L .74471 .65208 L closepath p .864 .541 .438 r
F P
0 g
s
.01 w
.74471 .65208 Mdot
.74471 .65208 Mdot
.74471 .65208 Mdot
.74471 .65208 Mdot
.74471 .65208 Mdot
.74471 .65208 Mdot
.5 Mabswid
.35834 .75431 m .31362 .78986 L .42392 .8193 L closepath p .402 .498 .842 r
F P
0 g
s
.01 w
.31362 .78986 Mdot
.31362 .78986 Mdot
.31362 .78986 Mdot
.31362 .78986 Mdot
.31362 .78986 Mdot
.31362 .78986 Mdot
.5 Mabswid
.57542 .53347 m .60149 .56462 L .41863 .53544 L closepath p .634 .183 .163 r
F P
0 g
s
.41233 .51211 m .41863 .53544 L .57542 .53347 L closepath p .67 .252 .244 r
F P
0 g
s
.01 w
.57542 .53347 Mdot
.57542 .53347 Mdot
.57542 .53347 Mdot
.57542 .53347 Mdot
.57542 .53347 Mdot
.57542 .53347 Mdot
.45689 .93321 Mdot
.45689 .93321 Mdot
.45689 .93321 Mdot
.45689 .93321 Mdot
.45689 .93321 Mdot
.45689 .93321 Mdot
.44809 .94888 Mdot
.44809 .94888 Mdot
.44809 .94888 Mdot
.5 Mabswid
.45344 .94581 m
.47109 .93573 L
s
.47109 .93573 m
.48137 .92985 L
s
.44809 .94888 m
.45344 .94581 L
s
.01 w
.41233 .51211 Mdot
.41233 .51211 Mdot
.41233 .51211 Mdot
.41233 .51211 Mdot
.41233 .51211 Mdot
.41233 .51211 Mdot
.5 Mabswid
.4691 .91777 m
.48137 .92985 L
s
.46475 .91348 m
.4691 .91777 L
s
.45091 .89986 m
.46475 .91348 L
s
.4495 .89847 m
.45091 .89986 L
s
.4218 .87121 m
.4495 .89847 L
s
.39603 .84585 m
.4218 .87121 L
s
.38356 .83358 m
.39603 .84585 L
s
.01 w
.38356 .83358 Mdot
.38356 .83358 Mdot
.38356 .83358 Mdot
.5 Mabswid
.80285 1.01794 m .63382 .97409 L .61069 .88404 L closepath p .811 .694 .735 r
F P
0 g
s
.77378 .87858 m .61069 .88404 L .80285 1.01794 L closepath p .767 .709 .798 r
F P
0 g
s
.01 w
.80285 1.01794 Mdot
.80285 1.01794 Mdot
.80285 1.01794 Mdot
.80285 1.01794 Mdot
.80285 1.01794 Mdot
.80285 1.01794 Mdot
.5 Mabswid
.43795 .70741 m .35834 .75431 L .2815 .69791 L closepath p .537 .453 .708 r
F P
0 g
s
.32346 .65435 m .2815 .69791 L .43795 .70741 L closepath p .532 .487 .751 r
F P
0 g
s
.01 w
.2815 .69791 Mdot
.2815 .69791 Mdot
.2815 .69791 Mdot
.2815 .69791 Mdot
.2815 .69791 Mdot
.2815 .69791 Mdot
.46864 .91824 Mdot
.46864 .91824 Mdot
.46864 .91824 Mdot
.46864 .91824 Mdot
.46864 .91824 Mdot
.46864 .91824 Mdot
.48137 .92985 Mdot
.48137 .92985 Mdot
.48137 .92985 Mdot
.5 Mabswid
.41863 .53544 m .40353 .56876 L .60149 .56462 L closepath p .706 .427 .5 r
F P
0 g
s
.01 w
.41863 .53544 Mdot
.41863 .53544 Mdot
.41863 .53544 Mdot
.41863 .53544 Mdot
.41863 .53544 Mdot
.41863 .53544 Mdot
.5 Mabswid
.60149 .56462 m .58691 .60719 L .40353 .56876 L closepath p .671 .322 .374 r
F P
0 g
s
.01 w
.60149 .56462 Mdot
.60149 .56462 Mdot
.60149 .56462 Mdot
.60149 .56462 Mdot
.60149 .56462 Mdot
.60149 .56462 Mdot
.46129 .87833 Mdot
.46129 .87833 Mdot
.46129 .87833 Mdot
.46129 .87833 Mdot
.46129 .87833 Mdot
.46129 .87833 Mdot
.5 Mabswid
.58691 .60719 m .5261 .65642 L .74948 .70367 L closepath p .788 .604 .651 r
F P
0 g
s
.01 w
.74948 .70367 Mdot
.74948 .70367 Mdot
.74948 .70367 Mdot
.74948 .70367 Mdot
.74948 .70367 Mdot
.74948 .70367 Mdot
.5 Mabswid
.5261 .65642 m .43795 .70741 L .32346 .65435 L closepath p .614 .422 .599 r
F P
0 g
s
.36865 .60968 m .32346 .65435 L .5261 .65642 L closepath p .618 .505 .702 r
F P
0 g
s
.01 w
.32346 .65435 Mdot
.32346 .65435 Mdot
.32346 .65435 Mdot
.32346 .65435 Mdot
.32346 .65435 Mdot
.32346 .65435 Mdot
.5 Mabswid
.43795 .70741 m .35834 .75431 L .54251 .78895 L closepath p .581 .547 .782 r
F P
0 g
s
.01 w
.35834 .75431 Mdot
.35834 .75431 Mdot
.35834 .75431 Mdot
.35834 .75431 Mdot
.35834 .75431 Mdot
.35834 .75431 Mdot
.5 Mabswid
.40353 .56876 m .36865 .60968 L .58691 .60719 L closepath p .677 .494 .63 r
F P
0 g
s
.01 w
.40353 .56876 Mdot
.40353 .56876 Mdot
.40353 .56876 Mdot
.40353 .56876 Mdot
.40353 .56876 Mdot
.40353 .56876 Mdot
.5 Mabswid
.54251 .78895 m .42392 .8193 L .61069 .88404 L closepath p .588 .567 .798 r
F P
0 g
s
.01 w
.42392 .8193 Mdot
.42392 .8193 Mdot
.42392 .8193 Mdot
.42392 .8193 Mdot
.42392 .8193 Mdot
.42392 .8193 Mdot
.5 Mabswid
.58691 .60719 m .5261 .65642 L .36865 .60968 L closepath p .656 .384 .496 r
F P
0 g
s
.01 w
.36865 .60968 Mdot
.36865 .60968 Mdot
.36865 .60968 Mdot
.36865 .60968 Mdot
.36865 .60968 Mdot
.36865 .60968 Mdot
.5644 1.10767 Mdot
.5644 1.10767 Mdot
.5644 1.10767 Mdot
.62105 1.04446 Mdot
.62105 1.04446 Mdot
.62105 1.04446 Mdot
.62105 1.04446 Mdot
.62105 1.04446 Mdot
.62105 1.04446 Mdot
.5 Mabswid
.77378 .87858 m .61069 .88404 L .54251 .78895 L closepath p .771 .617 .688 r
F P
0 g
s
.01 w
.77378 .87858 Mdot
.77378 .87858 Mdot
.77378 .87858 Mdot
.77378 .87858 Mdot
.77378 .87858 Mdot
.77378 .87858 Mdot
.58691 .60719 Mdot
.58691 .60719 Mdot
.58691 .60719 Mdot
.58691 .60719 Mdot
.58691 .60719 Mdot
.58691 .60719 Mdot
.63382 .97409 Mdot
.63382 .97409 Mdot
.63382 .97409 Mdot
.63382 .97409 Mdot
.63382 .97409 Mdot
.63382 .97409 Mdot
.5 Mabswid
.5261 .65642 m .43795 .70741 L .67463 .75066 L closepath p .694 .587 .732 r
F P
0 g
s
.01 w
.43795 .70741 Mdot
.43795 .70741 Mdot
.43795 .70741 Mdot
.43795 .70741 Mdot
.43795 .70741 Mdot
.43795 .70741 Mdot
.61069 .88404 Mdot
.61069 .88404 Mdot
.61069 .88404 Mdot
.61069 .88404 Mdot
.61069 .88404 Mdot
.61069 .88404 Mdot
.67463 .75066 Mdot
.67463 .75066 Mdot
.67463 .75066 Mdot
.67463 .75066 Mdot
.67463 .75066 Mdot
.67463 .75066 Mdot
.5261 .65642 Mdot
.5261 .65642 Mdot
.5261 .65642 Mdot
.5261 .65642 Mdot
.5261 .65642 Mdot
.5261 .65642 Mdot
.54251 .78895 Mdot
.54251 .78895 Mdot
.54251 .78895 Mdot
.54251 .78895 Mdot
.54251 .78895 Mdot
.54251 .78895 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[25]:=",
  ImageSize->{196.625, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003400017b000`400?l00000o`00003oa03oool0
0<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03o
ool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00
a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?oo
o`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo0034
0?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo
001[0?ooo`D00000E03oool006`0oooo00<000000<2I/00000001000001A0?ooo`00K03oool00`00
0000`9V`0<2I/002000000040>R1>P0000000000000004l0oooo001[0?ooo`0300000030VK00`9V`
00<0`9V`00<000000>R1>P3XPCX00P00001>0?ooo`00J`3oool00`000000`9V`0<2I/0040<2I/004
0000003XPCX0j84j000004h0oooo001[0?ooo`0300000030VK00`9V`00D0`9V`0P0000000`3XPCX0
00000?ooo`1<0?ooo`00JP3oool00`000000`9V`0<2I/0080<2I/0030000003XPCX0000004`0oooo
001Z0?ooo`0300000030VK00`9V`00T0`9V`0`00001;0?ooo`00JP3oool00`000000`9V`0<2I/00;
0<2I/0800000BP3oool006T0oooo00<000000<2I/030VK003@30VK02000004T0oooo001Y0?ooo`03
00000030VK00`9V`00l0`9V`00<000000?ooo`3oool0AP3oool006T0oooo00<000000<2I/030VK00
4030VK000`000000oooo0?ooo`150?ooo`00J@3oool00`000000`9V`0<2I/00A0<2I/0800000A@3o
ool006P0oooo00<000000<2I/030VK005030VK000`000000oooo0?ooo`120?ooo`00J03oool00`00
0000`9V`0<2I/00A0<2I/0D00000@`3oool006P0oooo00<000000<2I/030VK002030VK09000000@0
_XfR0P0000120?ooo`00I`3oool010000000`9V`0<2I/030VK09000000/0_XfR00<000000=^d/000
0000@P3oool006L0oooo1@00000C0;j=XP040000003K];00fkB`00000440oooo001V0?ooo`800000
00<0Ui[D0000002nSJ804`2nSJ801@000000fkB`0=^d/03K];0000000440oooo001W0?ooo`030000
002GV]@0Ui[D008000004P2nSJ800`000000fkB`0=^d/0020=^d/0030000003oool0oooo03h0oooo
001W0?ooo`030000001IIlL0Ui[D0080Ui[D0P00000?0;j=XP030000003K];00fkB`00@0fkB`00<0
00000?ooo`3oool0?@3oool006L0oooo00<0000005UWa`2GV]@0102GV]@00`000000_XfR0;j=XP0<
0;j=XP030000003K];00fkB`00@0fkB`00<000000?ooo`3oool0?@3oool006L0oooo00<0000005UW
a`1IIlL01@2GV]@2000000/0_XfR00<000000=^d/03K];001P3K];000`000000oooo0?ooo`0l0?oo
o`00I`3oool010000000FFO705UWa`1IIlL609NJe08000002@2nSJ800`000000fkB`0=^d/0070=^d
/0030000003oool0oooo03/0oooo001W0?ooo`030000001IIlL0FFO70080FFO71`2GV]@00`000000
_XfR0;j=XP050;j=XP030000003K];00fkB`00P0fkB`00<000000?ooo`3oool0>`3oool006L0oooo
00<0000005UWa`1IIlL00P1IIlL809NJe08000001@2nSJ800`000000fkB`0=^d/0090=^d/0030000
003oool0oooo03X0oooo001W0?ooo`0305UWa`000000FFO700<0FFO72@2GV]@200000080_XfR00<0
00000=^d/03K];002P3K];000`000000oooo0?ooo`0j0?ooo`00I`3oool00`1IIlL0000005UWa`04
05UWa`X0Ui[D00<000000;j=XP0000003@3K];000`000000oooo0?ooo`0i0?ooo`00I`3oool00`1I
IlL0000005UWa`0405UWa`X0Ui[D1000000=0=^d/0030000003oool0oooo03P0oooo001W0?ooo`03
05UWa`000000FFO700D0FFO71P2GV]@500000080gZVN0`00000:0=^d/0030000003oool0oooo03P0
oooo001X0?ooo`040000001IIlL0FFO709NJe0@0FFO70P2GV]@3000000<0SWVh00<000000;6Tc000
0000103NZIh3000000P0fkB`00<000000?ooo`3oool0=`3oool006P0oooo00<0000005UWa`1IIlL0
1@1IIlL2000000H0SWVh00@000000;6Tc02aY<`000001P3NZIh4000000D0fkB`00<000000?ooo`3o
ool0=P3oool006P0oooo00<0000005UWa`1IIlL01P1IIlL608ii^0030000002aY<`0/JC<0080/JC<
00<000000=jYWP3NZIh01P3NZIh400000080fkB`00<000000?ooo`3oool0=P3oool006P0oooo00<0
000005UWa`1IIlL01P1IIlL608ii^0030000002aY<`0/JC<0080/JC<00<000000=jYWP3NZIh02P3N
ZIh4000003L0oooo001X0?ooo`030000001IIlL0FFO700H0FFO71@2>NKP00`000000cjVb0;6Tc004
0;6Tc0030000003NZIh0gZVN00`0gZVN0P00000f0?ooo`00J03oool00`000000FFO705UWa`0605UW
a`D0SWVh00<000000;6Tc02aY<`01@2aY<`00`000000gZVN0=jYWP0;0=jYWP800000=P3oool006P0
oooo00<0000005UWa`1IIlL01P1IIlL408ii^0030000002aY<`0/JC<00L0/JC<00<000000=jYWP3N
ZIh02P3NZIh2000003H0oooo001X0?ooo`030000001IIlL0FFO700H0FFO70`2>NKP00`000000/JC<
0<nY/P090;6Tc0030000003NZIh0gZVN00P0gZVN00<000000?WQ[@000000=P3oool006P0oooo00<0
00000000A@1IIlL01P1IIlL308ii^0030000002aY<`0/JC<00T0/JC<00<000000=jYWP3NZIh01`3N
ZIh2000000030?WQ[@000000oooo03D0oooo001X0?ooo`030000000004D0FFO700H0FFO70P2>NKP0
0`000000/JC<0;6Tc00;0;6Tc0030000003NZIh0gZVN00H0gZVN00@000000?WQ[@3ihJd00000=P3o
ool006P0oooo00<000000000A@0004D01P1IIlL208ii^0030000002aY<`0FFO700`0/JC<00<00000
0=jYWP3NZIh0103NZIh01@000000nN6]0?WQ[@3ihJd0000003H0oooo001X0?ooo`030000000eFLT0
001500@0FFO700@0SWVh05UWa`2>NKP00000402aY<`00`000000gZVN0=jYWP020=jYWP8000000`3i
hJd00`000000oooo0?ooo`0d0?ooo`00J03oool010000000=EW90000A@0004D505UWa`0308ii^000
0000/JC<00l0/JC<00<000000=jYWP3NZIh00P3NZIh00`000000nN6]0?WQ[@020?WQ[@030000003o
ool0oooo03@0oooo001X0?ooo`040000000004D000150000A@D0FFO700<000000;6Tc02aY<`0402a
Y<`00`000000gZVN0=jYWP02000000@0nN6]00<000000?ooo`3oool0=03oool006P0oooo00<00000
0000A@0004D00P0004D305UWa`0308ii^01IIlL0/JC<0180/JC<00<000000=jYWP0000001@3ihJd0
0`000000oooo0?ooo`0d0?ooo`00J03oool00`00000000150000A@020000A@<0FFO700@0000005UW
a`1IIlL0/JC<4`0000060?WQ[@030000003oool0oooo03@0oooo001X0?ooo`030000000004D0<@=T
00<0001500<0FFO70343I00000000P1IIlLA0;>D]`<000001P3ihJd00`000000oooo0?ooo`0d0?oo
o`00I`3oool3000000070343I00004D000150000A@0a0f@0000008b5a`0205UWaa00/iBg00<00000
0<Njc@37^/d00P0000050?WQ[@030000003oool0oooo03@0oooo001V0?ooo`<000001@0004D00`00
0000S8G708b5a`0205UWa`l0/iBg00@000000<Njc@37^/d0ak[=0P0000050?WQ[@030000003oool0
oooo03@0oooo001U0?ooo`@00000100004D00`000000S8G708b5a`0308b5a`h0/iBg00<000000<Nj
c@37^/d00`37^/d2000000@0nN6]00<000000?ooo`3oool0=03oool006@0oooo0`0000001P1cFjP0
00000000000004D0<@=T0000A@D0S8G700<0FFO70000002cU;L02`2cU;L00`000000ak[=0<Njc@04
0<Njc@030000003odhH0000000<0nN6]00<000000?ooo`3oool0=03oool006@0oooo00D0000002h1
I01cFjP0Le^X000000020000A@030000000004D0001500@0S8G700<0FFO70000002cU;L02P2cU;L0
0`000000ak[=0<Njc@050<Njc@030000003odhH0000000<0nN6]00<000000?ooo`3oool0=03oool0
06<0oooo0P00000207=KZ00402T=N@0000000000000000@000151@2<QLL00`000000/iBg0;>D]`07
0;>D]`0300000037^/d0ak[=00H0ak[=00@000000?oCQP3odhH000000P3ihJd00`000000oooo0?oo
o`0d0?ooo`00@P3oool?00000140oooo00<0000007=KZ01cFjP00P1cFjP20000000308b5a`0004D0
001500<00015102<QLL00`1IIlL0S8G7000000070;>D]`0300000037^/d0ak[=00L0ak[=00@00000
0?oCQP3odhH000000P3ihJd00`000000oooo0?ooo`0d0?ooo`00?@3oool7000000@0C00@10000002
06H7=`030000001d0000000000P00000203oool010000000Le^X07=KZ01cFjP40000000408b5a`00
04D0001508b5a`<000151@2<QLL00`000000/iBg0;>D]`040;>D]`0300000037^/d0ak[=00P0ak[=
00L000000?oCQP3odhH0om>60000003ihJd0000003H0oooo000j0?ooo`<0000000<070000000000L
00000P00000304`040@000001P1V1cL00`000000M00007@0000507@000X000000`1cFjP700000003
0000A@0000000015008000151P2<QLL00`000000/iBg0;>D]`020;>D]`0300000037^/d0ak[=00T0
ak[=00<000000?oCQP3odhH00P3odhH2000003H0oooo000h0?ooo`@000000P0L0002000000<0C00@
0`00000806H7=`l0000000<0M0000000000000001P000000102CIY/0:@ei0000002HJI/20000A@04
09QYV`0004D000150000A@H0S8G700D000000;>D]`2cU;L0/iBg0000000=0<Njc@040000003odhH0
om>60?oCQP800000=P3oool003H0oooo1000000201`0008000000P1<0104000000L0IPLg10000000
0`1b7Dl000000:]0?P030:]0?QD000001`0004D400000080S8G700<000000;>D]`0000003P37^/d0
10000000om>60?oCQP3odhH2000003H0oooo000e0?ooo`L000000P1<0104000000D0IPLg1@000004
078MC`030000002[@3h0Zd0n00X0Zd0n2000000507<000<00000100004D409QYV`D000003P37^/d0
0`000000om>60?oCQP020?oCQP030000003oool0oooo03@0oooo000c0?ooo``00000101V1cL60000
00P0LQe?00<000000:]0?P2[@3h04@2[@3h;000000030000A@2HJI/0V6VK0080V6VK0P0000000`2^
W/L000000<nc_@03000000/0ak[=00D000000?oCQP3odhH0om>60000000g0?ooo`00<P3oool;0000
00<0IPLg0`000000101g9EL0000000000000000:078MC`030000002[@3h0Zd0n00d0Zd0n4@000000
0`2HJI/00000000000030:jNa`030000003?/kd0ck>m0080ck>m0P0000090<Njc@050000003odhH0
om>60?oCQP000000=`3oool00340oooo1`000000101@01H000000000001V1cL40000000407LUE`00
00000000000000/0LQe?4P00000?0:8^:@030000002]8P00000000H0[Yk700<000000<nc_@3?/kd0
0`3?/kd3000000H0ak[=00@000000?oCQP3odhH00000>03oool002l0oooo3@00000307LUE`800000
2@1b7Dl500000080MR]P00<000000;A]O`2dKGl00P2dKGl7000001@0XRhY00@000000:dR00000000
0000102^W/L00`000000ck>m0<nc_@060<nc_@8000001037^/d010000000om>60?oCQP00000h0?oo
o`00;P3oool50000000305005P000000000000800000101g9EL3000000H0LQe?1`00000407H[H003
0000002dKGl0]6eo00X0]6eo1`00000>0:8^:@040000002]8P00[B80000000<0[Yk700<000000<nc
_@3?/kd0203?/kd2000000<0ak[=0P00000i0?ooo`00;@3oool2000000030000?P0000003@1?00<0
00001@1g9EL2000000@0LQe?2000000807H[H0030000002dKGl0]6eo0140]6eo1`0000080:8^:@03
0000002]8P00[B800080000000<0[Yk70000003?/kd02`3?/kd5000003T0oooo000/0?ooo`800000
00H0000n0000000=04l0000000`0C`00000307LUE`<0000000<0LQe?0000000000000`0000000`25
BX40000000000002000000X0MR]P00<000000;A]O`2dKGl06@2dKGl700000080XRhY00L000000:dR
002]8P00[B800000002^W/L0000000d0ck>m0P00000j0?ooo`00:`3oool2000000050000?P000000
3@1?0000000<04l02@00000308E:P@<000003P1f:f000`000000]6eo0;A]O`0@0;A]OaD000000P2]
8P02000000`0ck>m00<000000=cRfP000000>P3oool002X0oooo0`000000100003h000000000000<
04l5000000D0QDZ10`00000;07H[H1T000004`2[DUl010000000gHY`0000000000020:dR00030000
003?/kd0ck>m00L0ck>m0P0000000`3Lh]X000000?ooo`0j0?ooo`00:P3oool2000000040000?P00
0000000000`0C`80000000<0000i00000025BX400P25BX44000000D0MR]P3000000207HeL@030000
002]OZ40[GjQ00D000007P2[DUl010000000gHY`0=f:L03MRW03000000030:dR00000000ck>m00H0
ck>m00D000000=cRfP3Lh]X0g>;J0000000k0?ooo`00:@3oool2000000040000?P000000000000`0
C`80000000<0000i00000025BX403000000508ELV`<000001@1f=G400`000000[GjQ0:enX@060:en
X@@000006P2[DUl00`000000gHY`0=f:L0030=f:L0D000000`3?/kd2000000<0g>;J00<000000?oo
o`3oool0>P3oool002P0oooo100000001@0=04l00000000000000000000i00H000002P25G9/40000
00L0MSEa00<000000:enX@2]OZ402`2]OZ45000001D0Ze9O00<000000=f:L03MRW001@3MRW040000
00030<nc_@000000g>;J00@0g>;J00<000000?ooo`3oool0>P3oool002P0oooo0P0000000`0003h0
000000000002000000040000>@000000000j000000X0QEbK1000000:07HeL@030000002]OZ40[GjQ
0140[GjQ1000000@0:]BG`030000003MRW00gHY`00L0gHY`1@0000050=cRfP030000003oool0oooo
03X0oooo000X0?ooo`P0000000<0000j00000025G9/01P25G9/4000000h0MSEa00<000000:enX@2]
OZ405@2]OZ45000000/0Ze9O00<000000=f:L03MRW002@3MRW04000000<0g>;J00<000000?ooo`3o
ool0>`3oool002L0oooo1`0000030000>P0300000025G9/0QEbK0080QEbK0`00000A07HeL@030000
002]OZ40[GjQ01/0[GjQ100000070:]BG`030000003MRW00gHY`00/0gHY`100000000`3Lh]X00000
0?ooo`0l0?ooo`009`3oool4000000030000>@000000000j00<0000j1@00000C07HeL@030000002]
OZ40[GjQ0200[GjQ1@0000000`2[DUl000000=f:L00>0=f:L0@00000?P3oool002H0oooo1P000003
0000>TH000003`3MRW04000003`0oooo000V0?ooo`@000000P0003X3000000030080B@000000Nf6Z
00h0Nf6Z1@0000020790Q@040000002NPK<0WX6c09j1/`<000008P2WHWh010000000bIZV0<VJYP39
VZH5000000d0gHY`00<0000007h000000000>`3oool002D0oooo100000000`0003X0000000000003
0080B@030000001kHJX0Nf6Z00P0Nf6Z1P0000060790Q@030000002NPK<0WX6c00D0WX6c0`00000N
0:MROP0300000039VZH0bIZV00@0bIZV0P0000000`3AISh0000000000002000000X0gHY`0`00000j
0?ooo`009@3oool2000000030000>P000000000000@00P1900<0000007]QZP1kHJX0101kHJX50000
00/0LT2500<0000009j1/`2NPK<02@2NPK<4000001P0Yf9n0P0000080<VJYP<000000`3AISh40000
00P0gHY`0`00000h0?ooo`009@3oool3000000H00P1900<0000007]QZP0000001000000?0790Q@03
0000002NPK<0WX6c00h0WX6c0`00000D0:MROP0300000039VZH0bIZV00X0bIZV0P0000060=5V?P<0
00001`3MRW02000003L0oooo000T0?ooo``000004`1b@8D00`000000WX6c09j1/`0B09j1/`<00000
402WHWh00`000000bIZV0<VJYP0=0<VJYP8000001`3AISh4000000@0gHY`0`00000e0?ooo`00903o
ool00`000000001]0000000600@0GP030000001WGK<0Iefc00D000003@1b@8D00`000000WX6c09j1
/`0F09j1/`@000002P2WHWh200000180bIZV0P0000090=5V?P@000000P3MRW02000003@0oooo000T
0?ooo`80000000<0001]0000000405h00`0405h00`000000Iefc06MM/`0606MM/`@00000201b@8D0
0`000000WX6c09j1/`0K09j1/`<000001P2WHWh00`000000bIZV0<VJYP0D0<VJYP030000003AISh0
dFHn00X0dFHn1@00000c0?ooo`00903oool200000080001]00@0000000@0GP0405h000003@1WGK<5
00000080LT2500<0000009j1/`2NPK<07`2NPK<300000080Yf9n00<000000<VJYP39VZH05P39VZH2
000000h0dFHn0P00000b0?ooo`00903oool300000080001]00<0000000@0GP0000002@1WGK<d0000
01T0bIZV0`00000<0=5V?P030000003oool0oooo0300oooo000U0?ooo`8000000`0006d;000000T0
ITZM00<0000008Ql`028O<000P00000P09e/V@80000000<0/IJk0000002aU[/01P00000F0<VJYP80
00002`3AISh200000340oooo000U0?ooo`8000000`0006d010000000BU6g00000000000?06I:W@03
00000028O<00R7c000<0R7c00`00000L09e/V@030000002aU[/0/IJk00@0/IJk0P0000030<V1PPD0
00004`39VZH2000000T0dFHn0P00000a0?ooo`009@3oool3000000030000K@000000BU6g00<0BU6g
0P00000<06I:W@0300000028O<00R7c000L0R7c00P00000H09e/V@8000002@2aU[/2000000D0bH62
1P00000?0<VJYP<000001`3AISh00`000000i90A0000000`0?ooo`009@3oool3000000030000K@00
0000BU6g00D0BU6g0P00000906I:W@0300000028O<00R7c000X0R7c00P00000D09e/V@800000302a
U[/2000000T0bH621P00000<0<VJYP8000001P3AISh00`000000i90A0000000`0?ooo`009@3oool2
000000030000JP0000000000008000001P1:DKL00`000000ITZM06I:W@0506I:W@0300000028O<00
R7c000d0R7c00P00000A09e/V@030000002aU[/0/IJk00h0/IJk0P00000<0<V1PPH000002@39VZH2
000000D0dFHn00<000000>B@4@000000;`3oool002D0oooo0P0000000`0006X0000004a>/P0204a>
/PD000000P1:DKL2000000@0ITZM00<0000008Ql`028O<004028O<02000000d0WFbI0P00000B0;6F
^`<000003`39PH86000000H0bIZV0P0000030=5V?P030000003TT140000002l0oooo000U0?ooo`80
000000<0001Z0000000000001`1<C[860000000306I:W@000000R7c001@0R7c00`00000809e/V@80
00005P2aU[/2000001<0bH621P0000030<VJYP060000003AISh0dFHn0000003TT1400000;`3oool0
02D0oooo00<000000000C00000000P0U@[T00`000000C4jb04a>/P0904a>/PX000004@28O<020000
00D0WFbI00<000000;6F^`2aU[/05`2aU[/3000001H0bH62200000020>B@4@030000003oool0oooo
02`0oooo000U0?ooo`@000000P0U@[T00`000000C4jb04a>/P0804a>/P80000000<0J7C<00000029
LkD01@29LkD?000000@0R7c00P0000000`2MK9T000000000000L0;6F^`8000006P39PH8300000080
i90A00<000000?ooo`3oool0;03oool002H0oooo0P0000001@0I@kh0000002E2^@0U@[T0000000T0
C4jb00D0000006Qdc01XM<`0J7C<0000000D08Uc]@X000007@2aU[/2000001P0bH6200<000000>Bl
[P0000000`3TT1400`000000oooo0?ooo`0[0?ooo`009P3oool01000000003:g0000000I@kh20000
000302E2^@000000C4jb00H0C4jb00<0000006Qdc01XM<`00`1XM<`2000001D0RG>e0P0000001@2D
S<P0000009B<b0000000]HNU00D000006@2aU[/3000001@0bH620P0000030>Bl[P040000003TT140
i90A000002d0oooo000V0?ooo`0400000000<[L003:g000000806D>n0P00000604a>/P030000001X
M<`0J7C<00H0J7C<00<0000008Uc]@29LkD04@29LkD00`000000U8c809B<b00409B<b0030000002e
QjD0]HNU00<0]HNU1@00000F0;6F^`8000004P39PH800`000000i;b^0>Bl[P040>Bl[P040000003T
T140i90A000002`0oooo000V0?ooo`80000000<003:g0000000I@kh00P0I@kh2000000D0C4jb00<0
000006Qdc01XM<`01`1XM<`2000000l0RG>e0P00000809B<b0800000202eQjD500000180/IJk0P00
000?0<V1PP8000001`3T_:h2000000030>B@4@000000oooo02/0oooo000V0?ooo`<0000000<003:g
0000000I@kh00P0I@kh2000000<0C4jb00<0000006Qdc01XM<`02P1XM<`00`000000RG>e08Uc]@0:
08Uc]@800000302DS<P00`000000]HNU0;F7Y@0:0;F7Y@D000003`2aU[/2000000`0bH6200<00000
0>Bl[P3T_:h0203T_:h010000000i90A0>B@4@00000[0?ooo`009P3oool01P00000001n[00000000
000003:g000000@06D>n00<0000004a>/P0000003P1XM<`00`000000RG>e08Uc]@0808Uc]@030000
002DS<P0U8c800d0U8c800<000000;F7Y@2eQjD03P2eQjD5000000/0/IJk0P0000090<V1PP800000
303T_:h00`000000i90A0000000[0?ooo`009`3oool200000003000MZP000000000000D06D>n1@00
000<06Qdc08000001P29LkD200000140U8c80P00000C0;F7Y@D00000202aU[/2000000H0bH6200<0
00000>Bl[P3T_:h0303T_:h2000000030>B@4@000000oooo02T0oooo000X0?ooo`80000000<001fZ
000000000000100I@kh00`000000>fgI0000000206Aid`L000001`1XM<`010000000RG>e08Uc]@29
LkD2000001D0U8c800<000000;F7Y@2eQjD05@2eQjD5000000@0/IJk0P0000030<V1PP800000403T
_:h00`000000i90A0000000Z0?ooo`00:@3oool200000003000MZP000000000000806D>n00D00000
03]]f@0kKMT0>fgI0000000806Aid`L0000000@0J7C<00000029LkD00000602DS<P00`000000]HNU
0;F7Y@0I0;F7Y@D0000000@0/IJk00000039PH8000004`3T_:h2000002X0oooo000Z0?ooo`800000
00D001fZ0000000I@kh06D>n0000000403]]f@030000001TNM<0I7WC00`0I7WC1P00000G09B<b003
0000002eQjD0]HNU01d0]HNU1000000C0>Bl[P<00000:@3oool002/0oooo00H00000000MZP007JX0
000001U3_P00000503]]f@030000001TNM<0I7WC00/0I7WC0`00000209F;aPH000004`2DS<P20000
01X0]HNU0`0000020;fW``040000003[XG/0000000000180i;b^0P00000Y0?ooo`00:`3oool20000
008001fZ0P00000603]]f@8000002P1TNM<01@000000IWoG06Ioe`1VOmL0000000H0UH_61P00000@
09B<b0030000002eQjD0]HNU01<0]HNU100000060;fW``030000003[XG/0jj5k008000004@3T_:h2
000002P0oooo000/0?ooo`@0000000@036gN00000000000000001@0kKMT00`000000I7WC06Aid`05
06Aid`8000001@1VOmL00`000000UH_609F;aP0809F;aPH00000302DS<P00`000000]HNU0;F7Y@0>
0;F7Y@@000002`2mYl<010000000jj5k0>^QN`3[XG/2000000l0i;b^0P00000X0?ooo`00;@3oool0
0`00000001fZ0000000200a]gP030000000GLn800000008000000`0kKMT00`000000I7WC06Aid`03
06Aid`030000001VOmL0IWoG00H0IWoG00<0000009F;aP2ERlH0302ERlH6000000P0U8c80P00000;
0;F7Y@<00000402mYl<00`000000jj5k0>^QN`020>^QN`8000003P3T_:h2000002L0oooo000^0?oo
o`8000000`0<KMh2000000805g?R0`0000000`0kKMT0000006Aid`0206Aid`030000001VOmL0IWoG
00P0IWoG00<0000009F;aP2ERlH0402ERlH6000000D0U8c800<000000;F7Y@2eQjD0102eQjD40000
01@0_JO300<000000>^QN`3[XG/00`3[XG/2000000d0i;b^00<000000?ooo`3oool09@3oool002l0
oooo0P00000400a]gP030000000GLn805g?R00805g?R0`0000000`1TNM<0000006Ioe`0;06Ioe`03
0000002ERlH0UH_601@0UH_61P000000102DS<P000000;F7Y@2eQjD3000001P0_JO300<000000>^Q
N`3[XG/01@3[XG/2000000/0i;b^0P00000V0?ooo`00;`3oool00`000000oooo0000000200000080
36gN00<0000001MchP0GLn80100GLn83000000`0IWoG00<0000009F;aP2ERlH06@2ERlH4000001`0
_JO300<000000>^QN`3[XG/01P3[XG/2000000X0i;b^0P00000U0?ooo`00<P3oool40000000300a]
gP000000000000<05g?R0P0000000`0IMN<0000000000002000000X0IWoG00<0000009F;aP2ERlH0
4`2ERlH50000000409JAc000000000000<FM/0<000006P2mYl<00`000000jj5k0>^QN`070>^QN`80
00002@3T_:h00`000000oooo0?ooo`0S0?ooo`00<@3oool00`000000oooo0?ooo`040000000500a]
gP0000005g?R01MchP0000000`0IMN<00`000000BH_[04V;j`04000000L0IWoG00<0000009F;aP2E
RlH03@2ERlH6000000L0UY7<00@000000<FM/035WK00aIf`0P00000I0;fW``030000003[XG/0jj5k
00P0jj5k00<000000>Bl[P3T_:h01P3T_:h2000002@0oooo000g0?ooo`@0000000<05g?R0000000I
MN<00`0IMN<00`000000BH_[04V;j`0304V;j`<000001@1VOmL00`000000UH_609F;aP0909F;aPD0
0000302FTL`00`000000aIf`0<FM/0020<FM/0<000005`2mYl<00`000000jj5k0>^QN`080>^QN`80
00001`3T_:h00`000000oooo0?ooo`0R0?ooo`00>@3oool4000000D06GGS0P00000604V;j`@00000
0P1VOmL00`000000UH_609F;aP0509F;aP@00000402FTL`00`000000aIf`0<FM/0050<FM/0800000
5@2mYl<00`000000jj5k0>^QN`0:0>^QN`8000001P3T_:h00`000000oooo0?ooo`0Q0?ooo`00>`3o
ool3000000H06GGS00<0000004V;j`19Rn/01P19Rn/500000080UH_61000000E09JAc00300000035
WK00aIf`00H0aIf`0`00000C0;fW``030000003[XG/0jj5k00/0jj5k0P0000040>Bl[P8000008P3o
ool003d0oooo1000000401Ueh`0300000019Rn/0BH_[00H0BH_[00<0QHS?04V;j`19Rn/00`00000J
09JAc00300000035WK00aIf`00P0aIf`0P00000B0;fW``030000003[XG/0jj5k00`0jj5k0P000003
0>Bl[P030000003oool0oooo0200oooo00110?ooo`<000000P0IMN<2000000D0BH_[00L000000<=B
0025R<l0000004A^e`000000SiGE00<000005`2FTL`00`000000aIf`0<FM/00:0<FM/0<00000402m
Yl<00`000000jj5k0>^QN`0=0>^QN`8000000P3T_:h00`000000oooo0?ooo`0O0?ooo`00A03oool2
0000000301Ueh`000000900000@000000P14K]L01@33DP00A6kG04A^e`14K]L0000000<0SiGE0`00
000E09JAc00300000035WK00aIf`00`0aIf`0P00000?0;fW``030000003[XG/0jj5k00h0jj5k0`00
000Q0?ooo`00A`3oool00`0IMN<0000000000002000000P0A6kG00<0000008nEe@2?UMD00`2?UMD3
000001<0UY7<00<000000<FM/035WK003@35WK03000000`0_JO300<000000>^QN`3[XG/0403[XG/2
00000200oooo001:0?ooo`030000002f>P00000000<0A6kG00<0`e8008F8c`14K]L00P14K]L00`00
0000SiGE08nEe@0508nEe@<000004@2FTL`00`000000aIf`0<FM/00?0<FM/08000002`2mYl<00`00
0000jj5k0>^QN`0@0>^QN`8000007`3oool004`0oooo00<004fb00000014K]L00P14K]L01@33DP00
A6kG04A^e`14K]L0000000X0SiGE0`00000>09JAc00300000035WK00aIf`0140aIf`0`0000090;fW
``030000003[XG/0jj5k00h0jj5k00<000000?O[]00000007`3oool004d0oooo0P00000304A^e`05
0<=B0014K]L0A6kG04A^e`000000302?UMD3000000`0UY7<00<000000<FM/035WK004`35WK020000
00P0_JO300<000000>^QN`3[XG/02`3[XG/200000080mn^d00<000000?ooo`3oool07@3oool004h0
oooo0`00000204A^e`0508F8c`14K]L0A6kG04A^e`0000003P2?UMD2000000/0UY7<00<000000<FM
/035WK005035WK03000000H0_JO300<000000>^QN`3[XG/0203[XG/2000000@0mn^d00<000000?oo
o`3oool07@3oool004l0oooo100000001@33DP00QHS?04A^e`14K]L000000100SiGE0`00000809JA
c00300000035WK00aIf`01L0aIf`0P0000040;fW``030000003[XG/0jj5k00L0jj5k00<000000?O[
]03gjk@0103gjk@00`000000oooo0?ooo`0M0?ooo`00D03oool200000080dGMS0`25R<l00`14K]L0
000008nEe@0A08nEe@<000001P2FTL`00`000000aIf`0<FM/00H0<FM/0<000000P2mYl<00`000000
jj5k0>^QN`040>^QN`8000001`3gjk@00`000000oooo0?ooo`0M0?ooo`00D@3oool200000080dGMS
00D0QHS?000000000000A6kG0000000D08nEe@<00000102FTL`00`000000aIf`0<FM/00J0<FM/080
000000<0_JO30000003[XG/00P3[XG/2000000T0mn^d00<000000?ooo`3oool07@3oool00580oooo
0P000000103AMf<0`e8008F8c`25R<l2000001L0SiGE0`0000000`2FTL`000000<FM/00M0<FM/0<0
000000<0jj5k0000003gjk@02P3gjk@00`000000oooo0?ooo`0M0?ooo`00D`3oool2000000040=5g
H`25R<l0QHS?08F8ca<000000P25R<l208nEe@8000000P2?UMD300000100aIf`4@00000;0?O[]003
0000003oool0oooo01h0oooo001D0?ooo`80000000H0dGMS08F8c`25R<l002B[0000001hSmd20000
00d0TXc91025R<l409:<bA@000004034]L`00`000000mn^d0?O[]0090?O[]0030000003oool0oooo
01h0oooo001C0?ooo`80LaQ40P0000001033DP00QHS?08F8c`00000307R?g@800000302BS<T308F8
c`030=>W[02BS<T0TXc900D0TXc900<000000<na_00000007@34]L`2000000X0mn^d00<000000?oo
o`3oool07P3oool00580oooo0`1c64@300000080QHS?00<0000007R?g@1hSmd00`1hSmd2000000/0
TXc90`25R<l00`3CYj`0TXc909:<b@0409:<b@030000003?/K`0ck6l008000007034]L`00`000000
mn^d0?O[]0080?O[]0030000003oool0oooo01h0oooo001@0?ooo`030000001c64@0LaQ40080LaQ4
100000000`25R<l002B[0000000607R?g@8000002P2BS<T308F8c`L0TXc900D000000<na_03?/K`0
ck6l0000000K0<Bec08000002@3gjk@00`000000oooo0?ooo`0N0?ooo`00C`3oool2000000@0LaQ4
00L0000002L0000W00009`0000000025R<l0000000P0N8oM0P00000909:<b@<0QHS?1P2BS<T00`00
0000ck6l0<na_0020<na_08000006@34]L`2000000T0mn^d00<000000?ooo`3oool07P3oool004l0
oooo00@000000;3El`000000LaQ40P00000502L0008000002P1hSmd2000000P0TXc90P25R<l00`3C
Yj`0TXc909:<b@0309:<b@030000003?/K`0ck6l00@0ck6l00<000000<Bec034]L`05P34]L`00`00
0000mka=000000080?O[]0030000003oool0oooo01h0oooo001?0?ooo`080000002`eO<0/=Gc0000
001c64@00000084UB`1oG:02000000809`0000<0000007R?g@1hSmd02P1hSmd00`000000TXc909:<
b@0609:<b@80QHS?1@2BS<T00`000000ck6l0<na_0050<na_08000005P34]L`010000000mka=0?Nl
C@0000070?O[]0030000003oool0oooo01h0oooo001>0?ooo`050000002`eO<0/=Gc0;3El`000000
0P1c64@010000000PBE;0000000000020000CPD000002@1hSmd2000000L0TXc90P25R<l509:<b@03
0000003?/K`0ck6l00H0ck6l00<000000<Bec034]L`05034]L`00`000000mka=000000070?O[]003
0000003oool0oooo01h0oooo001>0?ooo`030000002`eO<0/=Gc0080/=Gc00<0000007<HA02J:@00
10000000100004h0DGGH055ef0000002091o_@<00000201hSmd2000000H0TXc900<0QHS?0=>W[02B
S<T00`2BS<T00`000000ck6l0<na_0070<na_00300000034]L`0a;G<01<0a;G<00@000000?NlC@3g
_4d000001P3gjk@00`000000oooo0?ooo`0N0?ooo`00C@3oool00`000000/=Gc0;3El`040;3El`80
00000`0<AL@010000000DGGH02L0B00W04P2000000@0T7nm0`00000707R?g@800000102BS<T208F8
c`@0TXc900<000000<na_03?/K`0203?/K`2000001<0a;G<00@000000?NlC@3g_4d000001P3gjk@0
0`000000oooo0?ooo`0N0?ooo`00C03oool00`000000/=Gc0;3El`060;3El`040000001c64@00000
000000809`180P000002055ef08000001@2@Okd3000000H0N8oM0P00000309:<b@80QHS?0`2BS<T0
0`000000ck6l0<na_00:0<na_00300000034]L`0a;G<0100a;G<00D000000?NlC@3g_4d0mka=0000
00050?O[]0030000003oool0oooo01h0oooo001<0?ooo`030000002`eO<0/=Gc00H0/=Gc0`000000
1@0W04P000000000001AMMP0000000@0DGGH00<00000091o_@2@Okd01@2@Okd3000000D0N8oM00H0
000009:<b@2BS<T0TXc908F8c`3CYj`209:<b@030000003?/K`0ck6l00/0ck6l0P00000A0<Bec004
0000003g_4d0mka=000000D0mn^d00<000000?ooo`3oool07P3oool004/0oooo00<000000;3El`2`
eO<0202`eO<50000000309IcZ@000000DGGH00@0DGGH00<00000091o_@2@Okd01`2@Okd3000000<0
N8oM0P00000209:<b@0508F8c`2BS<T0TXc909:<b@0000003P3?/K`00`000000a;G<0<Bec00>0<Be
c0050000003g_4d0mka=0?NlC@000000103gjk@00`000000oooo0?ooo`0N0?ooo`00B`3oool00`00
0000/=Gc0;3El`090;3El`80000000<0YFb@0000000000000P2FLjT4055ef00307mLX00000000000
00X0T7nm0`00000207R?g@80000000D0TXc908F8c`2BS<T0TXc90000000?0<na_08000003P34]L`0
1@000000mka=0?NlC@3g_4d0000000<0mn^d00<000000?ooo`3oool07`3oool004X0oooo00<00000
0;3El`2`eO<02`2`eO<2000000030:E/T000000000000080UW>Y00<00000055ef01AMMP00`1AMMP0
0`000000T7nm091o_@0:091o_@<0000000H0N8oM000000000000QHS?09:<b@00000A0<na_0030000
0034]L`0a;G<00/0a;G<00<000000?NlC@3g_4d00P3g_4d010000000mn^d0?O[]000000Q0?ooo`00
BP3oool00`000000/=Gc0;3El`0;0;3El`040000003jf:80YFb@0:E/T08000000`2FLjT5055ef003
0000002@Okd0T7nm00`0T7nm100000000`2BS<T000000<na_00A0<na_08000002`34]L`00`000000
mka=0?NlC@030?NlC@030000003gjk@000000240oooo00190?ooo`030000002`eO<0/=Gc00d0/=Gc
0P0000020:E/T08000000`2FLjT00`000000DGGH055ef002055ef0030000002@Okd0T7nm00h0T7nm
1000000C0<na_00300000034]L`0a;G<00T0a;G<00<000000?NlC@3g_4d00P3g_4d00`000000mn^d
0000000Q0?ooo`00B@3oool00`000000/=Gc0;3El`0>0;3El`040?[HXP000000YFb@0:E/T0800000
102FLjT4055ef0030000002@Okd0T7nm0100T7nm0`00000B0<na_08000002@34]L`00`000000mka=
0?NlC@030?NlC@8000008@3oool004P0oooo00<000000;3El`2`eO<03@2`eO<20;:B]P030000002b
T[H0YFb@0080YFb@0P00000409IcZ@@0DGGH0P00000?091o_@0407mLX0000000cLWF0=>W[0@00000
403?/K`00`000000a;G<0<Bec0060<Bec0030000003g_4d0mka=00<0mka=0P00000Q0?ooo`00A`3o
ool00`000000/=Gc0;3El`0;0;3El`D0/Y:f00<0/=Gc0;:B]P2bT[H00`2UK902000000D0UW>Y101A
MMP00`000000T7nm091o_@0:091o_@<0OebP1@3=bMH20=>W[0<000003P3?/K`2000000H0a;G<00<0
00000?NlC@3g_4d0103g_4d00`000000oooo0?ooo`0O0?ooo`00A`3oool00`000000/=Gc0;3El`07
0;3El`T0/Y:f00@0/=Gc0;:B]P2bT[H000000`2UK9000`000000UW>Y09IcZ@0409IcZ@@0DGGH00<0
0000091o_@2@Okd0202@Okd307mLX0T0cLWF0P3CYj`4000000`0ck6l00<000000<Bec034]L`01034
]L`00`000000mka=0?NlC@030?NlC@030000003oool0oooo01l0oooo00160?ooo`030000002`eO<0
/=Gc00D0/=Gc402bT[H01@000000YFb@0:E/T02UK900000000L0UW>Y0`1AMMP00`000000T7nm091o
_@05091o_@D0OebP00<000000<g9eP3=bMH02`3=bMH00`3CYj`0000000000002000000T0ck6l00<0
00000<Bec034]L`00`34]L`00`000000mka=0?NlC@020?NlC@030000003oool0oooo0200oooo0016
0?ooo`040000002`eO<0/=Gc0;3ElaD0/Y:f102UK9000`000000UW>Y09IcZ@0509IcZ@<0DGGH00<0
0000091o_@2@Okd00P2@Okd607mLX0030<g9eP000000cLWF00P0cLWF00<0a[kC0<g9eP3=bMH01@3=
bMH00`3CYj`0000000000002000000H0ck6l0P0000030<Bec0050000003g_4d0mka=0?NlC@000000
8`3oool004@0oooo0`00000B0;:B]P030;3El`2bT[H0/Y:f00<0/Y:f00H000000:E/T02UK900YFb@
07mLX000000609IcZ@80OebP0P1AMMP00`000000T7nm091o_@0707mLX0030<g9eP000000cLWF0080
cLWF00<0dl780<g9eP3=bMH00P3=bMH00`36_]<0cLWF0<g9eP0:0<g9eP030=>W[000000000000080
0000103?/K`010000000a;G<0<Bec00000020?NlC@030000003oool0oooo0280oooo00150?ooo`03
0000002bT[H000000140/Y:f00<000000;:B]P2bT[H0102bT[H01P000000YFb@0:E/T02UK900OebP
000000D0UW>Y0`1oG:000`000000OebP0000000807mLX0030<g9eP000000cLWF00H0cLWF00<0a[kC
0<g9eP3=bMH03`3=bMH0103CYj`000000000000000020<na_0<000000P3g_4d00`000000oooo0?oo
o`0R0?ooo`00A@3oool00`000000/Y:f0;:B]P0A0;:B]P030<^FW`2bT[H0/Y:f00D0/Y:f0`2UK902
07mLX0040000002FLjT0UW>Y09IcZ@h0OebP0P3=bMH00`000000cLWF0<g9eP040<g9eP030000003=
bMH0cLWF01@0cLWF1`00000U0?ooo`00A@3oool00`000000/Y:f0;:B]P0A0;:B]P030<^FW`2bT[H0
/Y:f00D0/Y:f00@000000:E/T02UK900YFb@0P1oG:000`000000UW>Y09IcZ@0707mLX0030000001o
G:00OebP00@0OebP0P3=bMH00`000000cLWF0<g9eP030<g9eP030=?1b03=bMH0cLWF01T0cLWF0P00
000V0?ooo`00A@3oool00`000000/Y:f0;:B]P0J0;:B]P030000002UK900YFb@00<0OebP00<00000
09IcZ@1oG:00301oG:030<g9eP030000003=bMH0cLWF0080cLWF00<0dl780<g9eP3=bMH06`3=bMH0
0`000000oooo0?ooo`0T0?ooo`00A@3oool00`000000/Y:f0;:B]P0K0;:B]P<0YFb@0`1oG:000`00
0000OebP07mLX00;07mLX080cLWF00<000000<g9eP3C`LP00P3=bMH00`3C`LP0cLWF0<g9eP0L0<g9
eP030000003oool0oooo02@0oooo00160?ooo`030000002bT[H0/Y:f01X0/Y:f00<000000:E/T02U
K900401oG:030<g9eP050000003=bMH0cLWF0<g9eP3C`LP07P3=bMH00`000000oooo0?ooo`0U0?oo
o`00AP3oool00`000000/Y:f0;:B]P0K0;:B]P030000002UK900YFb@00h0OebP103=bMH010000000
cLWF0<g9eP3C`LPF0<g9eP030<Jnd`3=bMH0cLWF00D0cLWF00<0a[kC0000003oool09P3oool004H0
oooo00<000000;:B]P2bT[H0702bT[H20:E/T0h0OebP103=bMH00`000000cLWF0=?1b00D0<g9eP03
0<Jnd`3=bMH0cLWF00L0cLWF0P36_]<00`000000oooo0?ooo`0U0?ooo`00AP3oool00`000000/Y:f
0;:B]P0?0;:B]P030<^FW`2bT[H0/Y:f00/0/Y:f0P2UK90<07mLX0D0cLWF0P00000B0<g9eP030<Jn
d`3=bMH0cLWF00T0cLWF0P36_]<00`000000oooo0?ooo`0V0?ooo`00AP3oool00`000000/Y:f0;:B
]P0M0;:B]P030000002UK900YFb@00/0OebP0P3=bMH0102FLjT0cLWF00000000000O0<g9eP80a[kC
00<000000?ooo`3oool09P3oool004H0oooo00<000000;:B]P2bT[H07P2bT[H20:E/T0X0OebP103=
bMH00`000000dlW@0<g9eP0>0<g9eP030<Jnd`3=bMH0cLWF00d0cLWF0`36_]<00`000000oooo0?oo
o`0V0?ooo`00AP3oool00`000000/Y:f0;:B]P0O0;:B]P80YFb@2@1oG:040<g9eP030000003=bMH0
cLWF00/0cLWF00<0dl780<g9eP3=bMH03`3=bMH30<Jnd`030000003oool0oooo02L0oooo00160?oo
o`030000002bT[H0/Y:f01l0/Y:f00<000000:E/T01oG:001`1oG:040<g9eP030000003=bMH0cLWF
01d0cLWF00D0R5260<Jnd`36_]<0a[kC0000000Y0?ooo`00AP3oool00`000000/Y:f0;:B]P0P0;:B
]P030000002UK900OebP00H0OebP00<0cLWF09IcZ@3=bMH02`3=bMH00`37`mH0cLWF0<g9eP0C0<g9
eP@0a[kC00<000000?ooo`3oool09`3oool004L0oooo00<000000;:B]P2bT[H0802bT[H00`2UK900
OebP07mLX00407mLX0@0cLWF00<000000<g9eP3=bMH07@3=bMH40<Jnd`030000003oool0oooo02P0
oooo00170?ooo`030000002bT[H0/Y:f0240/Y:f00<0YFb@07mLX01oG:000`1oG:0S0<g9ePD0a[kC
00<000000?ooo`3oool0:03oool004L0oooo00<000000;:B]P2bT[H08@2bT[H2000000<0OebP203=
bMH00`3CbM00cLWF0<g9eP0H0<g9eP0308Q@QP36_]<0a[kC00<0a[kC00<000000?ooo`3oool0:03o
ool004L0oooo00<000000;:B]P2bT[H08P2bT[H0102UK900OebP07mLX01oG:0R0<g9ePH0a[kC00<0
00000?ooo`3oool0:@3oool004L0oooo00<000000;:B]P2bT[H08`2bT[H00`000000OebP0<g9eP0D
0<g9eP80al?F303=bMH60<Jnd`030000003oool0oooo02T0oooo00170?ooo`030000002bT[H0/Y:f
01`0/Y:f00<0biJO0;:B]P2bT[H01@2bT[H00`000000cLWF0<g9eP0G0<g9eP030<O3eP000000cLWF
00H0cLWF1`36_]<00`000000oooo0?ooo`0Y0?ooo`00A`3oool00`000000/Y:f0;:B]P0K0;:B]P03
0<^FW`2bT[H0/Y:f00D0/Y:f0P00000J0<g9eP80al?F0P000000103C`LP0cLWF00000028D8H60<Jn
d`030000003oool0oooo02X0oooo00170?ooo`030000002bT[H0/Y:f01X0/Y:f00<0biJO0;:B]P2b
T[H01`2bT[H00`000000cLWF0<g9eP0H0<g9eP<0al?F0P0000000`3C`LP000000<Jnd`060<Jnd`03
0000003oool0oooo02X0oooo00170?ooo`030000002bT[H0/Y:f01T0/Y:f00<0biJO0;:B]P2bT[H0
202bT[H00`000000cLWF0<g9eP0H0<g9ePD0al?F0`0000060<Jnd`030000003oool0oooo02X0oooo
00180?ooo`030000002bT[H0/Y:f01L0/Y:f00<0biJO0;:B]P2bT[H02@2bT[H00`000000cLWF0<g9
eP0G0<g9ePL0al?F0`0000040<Jnd`030000003oool0oooo02/0oooo00180?ooo`030000002bT[H0
/Y:f01H0/Y:f00<000000;:B]P2bT[H02P2bT[H00`000000cLWF0<g9eP0G0<g9ePT0al?F0P000003
0<Jnd`030000003oool0oooo02/0oooo00180?ooo`030000002bT[H0/Y:f01D0/Y:f00<0^iVe0;:B
]P2bT[H02`2bT[H00`000000cLWF0<g9eP0G0<g9ePX0al?F0P0000020<Jnd`030000003oool0oooo
02/0oooo00180?ooo`030000002bT[H0/Y:f01@0/Y:f00<0^iVe0;:B]P2bT[H0302bT[H00`000000
cLWF0<g9eP0G0<g9eP`0al?F0P00000^0?ooo`00B03oool00`000000/Y:f0;:B]P0C0;:B]P030;^I
]@2bT[H0/Y:f00/0/Y:f0P28D8H00`000000cLWF0<g9eP0F0<g9ePh0al?F00<000000?ooo`3oool0
;03oool004P0oooo00<000000;:B]P2bT[H04P2bT[H00`2kVKD0/Y:f0;:B]P0:0;:B]P@0R52600<0
00000<g9eP3=bMH05P3=bMH>0<O3eP030000003oool0oooo02`0oooo00180?ooo`030000002bT[H0
/Y:f0140/Y:f00<0^iVe0;:B]P2bT[H02P2bT[H508Q@QP030000003=bMH0cLWF01H0cLWF3@37`mH0
0`000000oooo0?ooo`0]0?ooo`00B03oool00`000000/Y:f0;:B]P0L0;:B]PL0R52600<000000<g9
eP3=bMH05P3=bMH<0<O3eP030000003oool0oooo02h0oooo00180?ooo`030000002bT[H0/Y:f01X0
/Y:f2@28D8H00`000000cLWF0<g9eP0E0<g9eP`0al?F00<000000?ooo`3oool0;`3oool004P0oooo
00<000000;:B]P2bT[H0602bT[H;08Q@QP030000003=bMH0cLWF01D0cLWF3037`mH00`000000oooo
0?ooo`0_0?ooo`00B@3oool00`000000/Y:f0;:B]P0F0;:B]P`0R52600<000000<g9eP3=bMH05@3=
bMH;0<O3eP030000003oool0oooo0300oooo00190?ooo`030000002bT[H0/Y:f01@0/Y:f3P28D8H0
0`000000cLWF0<g9eP0D0<g9eP0308Q@QP37`mH0al?F00P0al?F00<000000?ooo`3oool0<@3oool0
04T0oooo00<000000;:B]P2bT[H04P2bT[H@08Q@QP030000003=bMH0cLWF01@0cLWF2P37`mH00`00
0000oooo0?ooo`0b0?ooo`00B@3oool00`000000/Y:f0;:B]P0A0;:B]Q40R52600<000000<g9eP3=
bMH04`3=bMH:0<O3eP030000003oool0oooo03<0oooo00190?ooo`030000002bT[H0/Y:f00l0/Y:f
4`28D8H00`000000cLWF0<g9eP0B0<g9eP030<O3eP1B7g40al?F00P0al?F00<000000?ooo`3oool0
<`3oool004T0oooo00<000000;:B]P2bT[H03@2bT[HE08Q@QP030000003=bMH0cLWF00h0cLWF00<0
00000<g9eP0000000P37`mH00`1B7g40al?F0<O3eP060<O3eP030000003oool0oooo03@0oooo0019
0?ooo`030000002bT[H0/Y:f00/0/Y:f5`28D8H00`000000cLWF0<g9eP0>0<g9eP030000003=bMH0
000000X0al?F00<000000?ooo`3oool0=@3oool004T0oooo00<000000;:B]P2bT[H02P2bT[H00`2k
VKD0R52608Q@QP0E08Q@QP030000003=bMH0cLWF00h0cLWF00@0c<OF00000000000000002037`mH0
0`000000oooo0?ooo`0f0?ooo`00B@3oool00`000000/Y:f0;:B]P080;:B]P<0R52600<0^iVe08Q@
QP28D8H05028D8H00`000000cLWF0<g9eP0=0<g9eP80c<OF00<000000=?9d00000002037`mH00`00
0000oooo0?ooo`0f0?ooo`00BP3oool00`000000/Y:f0;:B]P050;:B]PH0R52600<0^iVe08Q@QP28
D8H04`28D8H00`000000cLWF0<g9eP0<0<g9eP@0c<OF0P0000000`1B7g40al?F0<O3eP040<O3eP03
0000003oool0oooo03L0oooo001:0?ooo`030000002bT[H0/Y:f00<0/Y:f2@28D8H00`000000R526
08Q@QP0B08Q@QP030000003=bMH0cLWF00`0cLWF103<amH3000000D0al?F00<000000?ooo`3oool0
>03oool004X0oooo00@000000;:B]P2bT[H0/Y:f3028D8H00`1`00h0R52608Q@QP0A08Q@QP030000
003=bMH0cLWF00/0cLWF1P3<amH2000000@0al?F00<000000?ooo`3oool0>@3oool004X0oooo00<0
00000;:B]P2bT[H03P28D8H00`1`00h0R52608Q@QP0@08Q@QP030000003=bMH0cLWF00X0cLWF1`3<
amH2000000<0al?F00<000000?ooo`3oool0>P3oool004X0oooo0P00000@08Q@QP0307003P28D8H0
R52600l0R52600<000000<g9eP3=bMH02P3=bMH80<c7eP0400000037`mH0al?F000003d0oooo001<
0?ooo`8000003`28D8H00`000000R52608Q@QP0>08Q@QP030000003=bMH0cLWF00T0cLWF2@3<amH0
0`000000al?F0000000n0?ooo`00CP3oool2000000h0R52600<0S4al08Q@QP28D8H03@28D8H00`00
0000cLWF0<g9eP080<g9ePX0c<OF0P00000o0?ooo`00D03oool2000000d0R52600<0S4al08Q@QP28
D8H03028D8H00`000000cLWF0<g9eP080<g9ePT0c<OF00<000000?ooo`000000?`3oool00580oooo
0P00000<08Q@QP0308a<O028D8H0R52600/0R52600<000000<g9eP3=bMH01`3=bMH90<c7eP030000
003oool0oooo0400oooo001D0?ooo`8000002`28D8H00`2<C7`0R52608Q@QP0:08Q@QP030000003=
bMH0cLWF00H0cLWF203<amH2000004<0oooo001F0?ooo`8000002P28D8H00`2<C7`0R52608Q@QP09
08Q@QP030000003=bMH0cLWF00H0cLWF1`3<amH00`000000oooo0?ooo`130?ooo`00F03oool20000
00T0R52600<0S4al08Q@QP28D8H02028D8H00`000000cLWF0<g9eP050<g9ePH0c<OF0P0000160?oo
o`00FP3oool2000000P0R52600<0S4al08Q@QP28D8H01`28D8H00`000000cLWF0<g9eP050<g9ePD0
c<OF00<000000?ooo`3oool0AP3oool005`0oooo0P00000708Q@QP0308a<O028D8H0R52600H0R526
00<000000<g9eP3=bMH0103=bMH50<c7eP030000003oool0oooo04L0oooo001N0?ooo`8000001P28
D8H00`2<C7`0R52608Q@QP0508Q@QP030000003=bMH0cLWF00<0cLWF103<amH2000004X0oooo001P
0?ooo`8000001@28D8H00`2<C7`0R52608Q@QP0408Q@QP030000003=bMH0cLWF00<0cLWF0`3<amH0
0`000000oooo0?ooo`1:0?ooo`00HP3oool2000000@0R52600<0S4al08Q@QP28D8H00`28D8H00`00
0000cLWF0<g9eP020<g9eP<0c<OF00<000000?ooo`3oool0B`3oool006@0oooo0P00000308Q@QP03
08a<O028D8H0R5260080R52600@000000<g9eP3=bMH0cLWF0P3<amH2000004h0oooo001V0?ooo`80
00000P28D8H01@2<C7`0R52608Q@QP28D8H0000000<0cLWF00<0c<OF0000003oool0C`3oool006P0
oooo0P0000001@28D8H0S4al08Q@QP28D8H000000080cLWF0P00001A0?ooo`00JP3oool200000005
08a<O028D8H000000<g9eP000000D`3oool006`0oooo1000001D0?ooo`00KP3oool00`000000oooo
0?ooo`1C0?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool0
0<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03o
ool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00
a03oool00001\
\>"],
  ImageRangeCache->{{{0, 195.625}, {286.938, 0}} -> {0.150211, -0.000772853, \
0.00345369, 0.00345369}}]
}, Open  ]],

Cell["\<\
The triangles approximate the shape quite good. Plotting the mirror \
can take some time.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Timing[ShowSystem[seashellmirror, SurfacePoints -> Mesh, ShowLabels \
-> False, PlotPoints -> 40];]\
\>", "Input",
  CellLabel->"In[27]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.45284 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.217119 1.4694 2.22045e-16 1.4694 [
[ 0 0 0 0 ]
[ 1 1.45284 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.45284 L
0 1.45284 L
closepath
clip
newpath
.5396 .62019 m .5934 .53462 L .50905 .60785 L .667 .555 .719 r
F
.5396 .62019 m .63121 .53603 L .5934 .53462 L F
.41803 .67217 m .5396 .62019 L .50905 .60785 L .731 .575 .68 r
F
.56678 .63262 m .63121 .53603 L .5396 .62019 L .604 .471 .673 r
F
.43609 .68863 m .5396 .62019 L .41803 .67217 L .699 .516 .637 r
F
.43609 .68863 m .56678 .63262 L .5396 .62019 L F
.50905 .60785 m .55302 .53386 L .47752 .59545 L .721 .634 .761 r
F
.50905 .60785 m .5934 .53462 L .55302 .53386 L F
.39856 .65511 m .50905 .60785 L .47752 .59545 L .761 .636 .722 r
F
.41803 .67217 m .50905 .60785 L .39856 .65511 L .731 .575 .68 r
F
.56678 .63262 m .66298 .53919 L .63121 .53603 L .604 .471 .673 r
F
.58867 .64535 m .66298 .53919 L .56678 .63262 L .522 .368 .613 r
F
.4516 .70437 m .56678 .63262 L .43609 .68863 L .663 .454 .592 r
F
0 g
.5 Mabswid
[ ] 0 setdash
.53394 .62855 m
.56876 .60638 L
s
.4516 .70437 m .58867 .64535 L .56678 .63262 L .663 .454 .592 r
F
0 g
.52248 .67385 m
.52591 .67656 L
s
.52398 .63489 m
.53394 .62855 L
s
.51506 .64842 m
.51729 .64791 L
s
.47752 .59545 m .51406 .5331 L .44761 .58303 L .767 .717 .806 r
F
.47752 .59545 m .55302 .53386 L .51406 .5331 L F
0 g
.50907 .56865 m
.5091 .56866 L
s
.5091 .56866 m
.57774 .58468 L
s
.37899 .63763 m .47752 .59545 L .44761 .58303 L .788 .701 .768 r
F
.39856 .65511 m .47752 .59545 L .37899 .63763 L .761 .636 .722 r
F
0 g
.44081 .62014 m
.46743 .63595 L
s
.46743 .63595 m
.47178 .63854 L
s
.43967 .61018 m
.5797 .59119 L
s
.47322 .65099 m
.47398 .65105 L
s
.58867 .64535 m .68624 .54515 L .66298 .53919 L .522 .368 .613 r
F
.60395 .65846 m .68624 .54515 L .58867 .64535 L .404 .224 .52 r
F
0 g
.61946 .55861 m
.62457 .55196 L
s
.60765 .58172 m
.60876 .58102 L
s
.4637 .71928 m .58867 .64535 L .4516 .70437 L .623 .387 .539 r
F
0 g
.45338 .66533 m
.45789 .664 L
s
.4637 .71928 m .60395 .65846 L .58867 .64535 L .623 .387 .539 r
F
0 g
.53878 .68672 m
.54492 .69156 L
s
.5934 .53462 m .59395 .46347 L .55302 .53386 L .708 .651 .79 r
F
.5934 .53462 m .63586 .44765 L .59395 .46347 L F
.63121 .53603 m .63586 .44765 L .5934 .53462 L .622 .56 .763 r
F
0 g
.49716 .5657 m
.49717 .5657 L
s
.51108 .56397 m
.51112 .56396 L
s
.49247 .56761 m
.49247 .56761 L
s
.45784 .59377 m
.47379 .58441 L
s
.55302 .53386 m .55234 .479 L .51406 .5331 L .782 .747 .821 r
F
.55302 .53386 m .59395 .46347 L .55234 .479 L F
0 g
.51112 .56396 m
.51445 .5626 L
s
.30487 .7015 m .43609 .68863 L .41803 .67217 L .798 .578 .603 r
F
.31246 .71583 m .43609 .68863 L .30487 .7015 L .781 .536 .566 r
F
.31246 .71583 m .4516 .70437 L .43609 .68863 L F
.30487 .7015 m .41803 .67217 L .29648 .68638 L .798 .578 .603 r
F
.29648 .68638 m .41803 .67217 L .39856 .65511 L .815 .622 .641 r
F
0 g
.40531 .67951 m
.45338 .66533 L
s
.55953 .68154 m
.56784 .67584 L
s
.54492 .69156 m
.55953 .68154 L
s
.54492 .69156 m
.55221 .68895 L
s
.40139 .68732 m
.40404 .68739 L
s
.51158 .69058 m
.51587 .6907 L
s
.52872 .69108 m
.54492 .69156 L
s
.51089 .70109 m
.54492 .69156 L
s
.31883 .72923 m .4516 .70437 L .31246 .71583 L .764 .496 .529 r
F
.31883 .72923 m .4637 .71928 L .4516 .70437 L F
.66298 .53919 m .67266 .43358 L .63121 .53603 L .499 .443 .726 r
F
.63121 .53603 m .67266 .43358 L .63586 .44765 L .622 .56 .763 r
F
.28778 .67062 m .39856 .65511 L .37899 .63763 L .831 .668 .681 r
F
.29648 .68638 m .39856 .65511 L .28778 .67062 L .815 .622 .641 r
F
.47182 .73321 m .60395 .65846 L .4637 .71928 L .574 .307 .474 r
F
0 g
.49816 .70465 m
.49834 .7046 L
s
.57602 .67022 m
.57615 .67013 L
s
.32367 .74159 m .4637 .71928 L .31883 .72923 L .747 .456 .49 r
F
.32367 .74159 m .47182 .73321 L .4637 .71928 L F
0 g
.44173 .72044 m
.44193 .72038 L
s
.56051 .51192 m
.65082 .5035 L
s
.44761 .58303 m .4805 .53241 L .42178 .57092 L .803 .817 .863 r
F
.44761 .58303 m .51406 .5331 L .4805 .53241 L F
.36069 .61998 m .44761 .58303 L .42178 .57092 L .807 .772 .821 r
F
.37899 .63763 m .44761 .58303 L .36069 .61998 L .788 .701 .768 r
F
.60395 .65846 m .69962 .55456 L .68624 .54515 L .404 .224 .52 r
F
0 g
.62457 .55196 m
.64773 .52183 L
s
.61195 .67187 m .69962 .55456 L .60395 .65846 L .21 0 .351 r
F
0 g
.63177 .62177 m
.63239 .62163 L
s
.63239 .62163 m
.63303 .62148 L
s
.51729 .64791 m
.63177 .62177 L
s
.62341 .6377 m
.62347 .63766 L
s
.47182 .73321 m .61195 .67187 L .60395 .65846 L .574 .307 .474 r
F
0 g
.57615 .67013 m
.62341 .6377 L
s
.44193 .72038 m
.49326 .70602 L
s
.40404 .68739 m
.51158 .69058 L
s
.49326 .70602 m
.49816 .70465 L
s
.51406 .5331 m .51676 .49376 L .4805 .53241 L .848 .877 .862 r
F
.51406 .5331 m .55234 .479 L .51676 .49376 L F
0 g
.51435 .52389 m
.54735 .51485 L
s
.50531 .52636 m
.51435 .52389 L
s
.51445 .5626 m
.65182 .5068 L
s
.66298 .53919 m .7004 .42403 L .67266 .43358 L .499 .443 .726 r
F
.68624 .54515 m .7004 .42403 L .66298 .53919 L .275 .239 .636 r
F
0 g
.35508 .67893 m
.35546 .67904 L
s
.3358 .68787 m
.33829 .68781 L
s
.47576 .74604 m .61195 .67187 L .47182 .73321 L .509 .203 .383 r
F
0 g
.54907 .70611 m
.54917 .70644 L
s
.56429 .68463 m
.56569 .68413 L
s
.3268 .75283 m .47182 .73321 L .32367 .74159 L .729 .414 .448 r
F
.3268 .75283 m .47576 .74604 L .47182 .73321 L F
.27929 .65441 m .37899 .63763 L .36069 .61998 L .846 .718 .723 r
F
0 g
.36155 .63305 m
.39866 .62105 L
s
.28778 .67062 m .37899 .63763 L .27929 .65441 L .831 .668 .681 r
F
0 g
.37475 .71734 m
.37943 .71865 L
s
.37943 .71865 m
.38067 .71899 L
s
.35893 .72672 m
.3592 .72672 L
s
.59395 .46347 m .56369 .42803 L .55234 .479 L .812 .75 .794 r
F
0 g
.56175 .5081 m
.56203 .50787 L
s
.59395 .46347 m .59936 .39544 L .56369 .42803 L .812 .75 .794 r
F
0 g
.56203 .50787 m
.57814 .4943 L
s
.63586 .44765 m .59936 .39544 L .59395 .46347 L .717 .663 .796 r
F
.61195 .67187 m .70283 .56733 L .69962 .55456 L .21 0 .351 r
F
.6127 .68522 m .70283 .56733 L .61195 .67187 L 0 0 0 r
F
.47576 .74604 m .6127 .68522 L .61195 .67187 L .509 .203 .383 r
F
0 g
.55094 .71265 m
.55107 .7131 L
s
.63586 .44765 m .63291 .36204 L .59936 .39544 L .717 .663 .796 r
F
.67266 .43358 m .63291 .36204 L .63586 .44765 L .602 .583 .804 r
F
.47561 .75759 m .6127 .68522 L .47576 .74604 L .407 .048 .24 r
F
0 g
.55223 .71714 m
.55494 .72664 L
s
.52272 .72701 m
.52279 .72701 L
s
.43666 .728 m
.52272 .72701 L
s
.53377 .72689 m
.55494 .72664 L
s
.32814 .76286 m .47576 .74604 L .3268 .75283 L .708 .367 .397 r
F
.32814 .76286 m .47561 .75759 L .47576 .74604 L F
.42178 .57092 m .4555 .53265 L .40207 .55975 L .792 .935 .924 r
F
.42178 .57092 m .4805 .53241 L .46088 .5326 L F
.46088 .5326 m .4684 .52683 L .4555 .53265 L .781 .998 .813 r
F
.4684 .52683 m .46805 .52692 L .4555 .53265 L F
.4805 .53241 m .49054 .51139 L .46088 .5326 L F
.4694 .52624 m .45697 .53134 L .46962 .52613 L 0 0 0 r
F
.45697 .53134 m .45199 .53338 L .45691 .53135 L F
.45697 .53134 m .45691 .53135 L .46962 .52613 L F
.4636 .53065 m .46333 .53072 L .46088 .5326 L .781 .998 .813 r
F
.46805 .52692 m .46962 .52613 L .46922 .52664 L 0 0 0 r
F
.4793 .51942 m .46962 .52613 L .4818 .51701 L F
.46922 .52664 m .46962 .52613 L .4793 .51942 L F
.51632 .48455 m .50287 .50124 L .52232 .47602 L F
.4805 .53241 m .51676 .49376 L .50433 .5013 L .781 .998 .813 r
F
.50174 .50305 m .50433 .5013 L .50196 .50274 L F
.4805 .53241 m .50433 .5013 L .50174 .50305 L F
.49721 .5061 m .49822 .50523 L .50169 .50308 L 0 0 0 r
F
.49822 .50523 m .50287 .50124 L .50178 .50294 L F
.49822 .50523 m .50178 .50294 L .50169 .50308 L F
.4805 .53241 m .50196 .50274 L .4926 .51459 L .781 .998 .813 r
F
.51676 .49376 m .5167 .49336 L .50433 .5013 L .744 .873 .454 r
F
.515 .49445 m .51575 .48981 L .50433 .5013 L F
.51575 .48981 m .51294 .49184 L .50433 .5013 L F
.51158 .56315 m .51444 .55873 L .51816 .56757 L .543 .31 .512 r
F
.51093 .55837 m .51444 .55873 L .51158 .56315 L F
.50708 .51923 m .50963 .51222 L .51057 .5174 L .21 0 .352 r
F
.49626 .51201 m .50723 .49893 L .50963 .51222 L F
.49626 .51201 m .50963 .51222 L .50708 .51923 L F
.50939 .4944 m .52232 .47602 L .51973 .48342 L 0 0 0 r
F
.51676 .49376 m .5307 .46488 L .51973 .48342 L .744 .873 .454 r
F
.51642 .49154 m .51973 .48342 L .51611 .48954 L F
.51676 .49376 m .51973 .48342 L .51642 .49154 L F
.52423 .47238 m .52232 .47602 L .53098 .45384 L 0 0 0 r
F
.52138 .47938 m .52232 .47602 L .52423 .47238 L F
.52118 .47986 m .5219 .47743 L .52138 .47938 L F
.5219 .47743 m .52232 .47602 L .52138 .47938 L F
.50939 .4944 m .51973 .48342 L .51611 .48954 L F
.5307 .46488 m .53381 .45844 L .52008 .48256 L .744 .873 .454 r
F
.51973 .48342 m .52008 .48256 L .51611 .48954 L F
.5307 .46488 m .52008 .48256 L .51973 .48342 L F
.53172 .48756 m .53381 .45844 L .51676 .49376 L .917 .885 .786 r
F
.55234 .479 m .53381 .45844 L .53172 .48756 L F
.53381 .45844 m .53625 .42532 L .5357 .4321 L .716 .629 .065 r
F
.53381 .45844 m .53298 .46576 L .53047 .46912 L F
.52801 .49832 m .52949 .48863 L .54433 .51157 L .285 .208 .591 r
F
.52949 .48863 m .53298 .46576 L .54138 .49966 L F
.52949 .48863 m .54138 .49966 L .54433 .51157 L F
.52956 .46612 m .53011 .46795 L .52059 .48232 L .716 .629 .065 r
F
.53381 .45844 m .53047 .46912 L .52956 .46612 L F
.53165 .45584 m .53098 .45384 L .53331 .43438 L 0 0 .006 r
F
.52934 .46629 m .53381 .45844 L .52945 .46578 L .744 .873 .454 r
F
.51973 .48342 m .52232 .47602 L .52118 .47986 L 0 0 0 r
F
.51611 .48954 m .52934 .46629 L .51595 .48853 L .744 .873 .454 r
F
.52934 .46629 m .52945 .46578 L .51595 .48853 L F
.53381 .45844 m .52059 .48232 L .52138 .47938 L .716 .629 .065 r
F
.52145 .48117 m .53011 .46795 L .52888 .48806 L 0 0 0 r
F
.52888 .48806 m .53011 .46795 L .53047 .46912 L 0 0 .006 r
F
.52059 .48232 m .53047 .46912 L .51768 .48993 L .285 .208 .591 r
F
.53047 .46912 m .53298 .46576 L .53041 .46983 L F
.53047 .46912 m .53041 .46983 L .51768 .48993 L F
.53059 .46953 m .53066 .46687 L .53165 .45584 L 0 0 .006 r
F
.53066 .46687 m .53084 .45951 L .53154 .45632 L F
.53066 .46687 m .53154 .45632 L .53165 .45584 L F
.53084 .45951 m .53098 .45384 L .53165 .45584 L F
.52114 .48088 m .53098 .45384 L .53011 .46795 L 0 0 0 r
F
.53011 .46795 m .52145 .48117 L .52059 .48232 L .716 .629 .065 r
F
.52114 .48088 m .53011 .46795 L .52145 .48117 L 0 0 0 r
F
.53011 .46795 m .53047 .46912 L .52145 .48117 L .716 .629 .065 r
F
.51768 .48993 m .53041 .46983 L .52801 .49832 L .285 .208 .591 r
F
.50981 .4941 m .51595 .48853 L .51065 .49299 L .744 .873 .454 r
F
.50433 .5013 m .51294 .49184 L .50981 .4941 L F
.51294 .49184 m .51595 .48853 L .50981 .4941 L F
.50433 .5013 m .51065 .49299 L .50196 .50274 L F
.50691 .49794 m .50939 .4944 L .50874 .50362 L 0 0 0 r
F
.5167 .49336 m .51642 .49154 L .515 .49445 L .744 .873 .454 r
F
.51062 .50948 m .51809 .48811 L .51902 .48621 L 0 0 0 r
F
.51768 .48993 m .54433 .51157 L .5146 .49852 L .285 .208 .591 r
F
.5146 .49852 m .51902 .48621 L .51924 .48575 L 0 0 0 r
F
.51062 .50948 m .51902 .48621 L .5146 .49852 L F
.5146 .49852 m .54433 .51157 L .5428 .51206 L .285 .208 .591 r
F
.54372 .56269 m .55977 .56786 L .54567 .56618 L .55 .438 .679 r
F
.53195 .54155 m .5543 .56268 L .54372 .56269 L F
.5543 .56268 m .55977 .56786 L .54372 .56269 L F
.52194 .56533 m .5328 .56572 L .54367 .57428 L .666 .547 .71 r
F
.5328 .56572 m .54522 .56801 L .54367 .57428 L F
.52307 .5627 m .54372 .56269 L .54522 .56801 L .494 .321 .575 r
F
.52297 .56391 m .5328 .56572 L .52194 .56533 L .666 .547 .71 r
F
.54567 .56618 m .55977 .56786 L .54367 .57428 L F
.53002 .56521 m .54522 .56801 L .54605 .571 L .494 .321 .575 r
F
.52307 .5627 m .54522 .56801 L .53002 .56521 L F
.52297 .56391 m .52307 .5627 L .53002 .56521 L F
.54522 .56801 m .54469 .56615 L .54567 .56618 L .474 .357 .64 r
F
.53195 .54155 m .53551 .53293 L .5543 .56268 L .55 .438 .679 r
F
.5267 .51896 m .52694 .51598 L .53527 .53254 L .494 .321 .575 r
F
.5146 .49852 m .53333 .50751 L .53127 .51024 L .285 .208 .591 r
F
.52694 .51598 m .52962 .51243 L .53527 .53254 L .494 .321 .575 r
F
.53527 .53254 m .52962 .51243 L .53547 .532 L .474 .357 .64 r
F
.53551 .53293 m .54433 .51157 L .5543 .56268 L .55 .438 .679 r
F
.5428 .51206 m .54433 .51157 L .53195 .54155 L F
.54567 .56618 m .52962 .51243 L .54611 .56439 L .474 .357 .64 r
F
.5543 .56268 m .54433 .51157 L .55977 .56786 L .55 .438 .679 r
F
.54611 .56439 m .52962 .51243 L .54658 .51196 L .474 .357 .64 r
F
.5146 .49852 m .53666 .51403 L .51184 .51901 L .285 .208 .591 r
F
.52694 .51598 m .52778 .50586 L .52962 .51243 L .494 .321 .575 r
F
.53127 .51024 m .5428 .51206 L .53419 .5123 L .285 .208 .591 r
F
.53333 .50751 m .5428 .51206 L .53127 .51024 L F
.51447 .52501 m .5428 .51206 L .53195 .54155 L .55 .438 .679 r
F
.50995 .51987 m .51057 .5174 L .51106 .52012 L .21 0 .352 r
F
.50708 .51923 m .51057 .5174 L .50995 .51987 L F
.51404 .52523 m .51019 .52161 L .51041 .52138 L .494 .321 .575 r
F
.51404 .52523 m .51041 .52138 L .51341 .52114 L F
.4946 .5142 m .50169 .50308 L .50196 .50274 L 0 0 0 r
F
.48623 .52725 m .49442 .51443 L .4946 .5142 L F
.48706 .52612 m .50105 .52364 L .49399 .52666 L .523 .324 .553 r
F
.48621 .52727 m .49399 .52666 L .48327 .53124 L F
.48706 .52612 m .49399 .52666 L .48621 .52727 L F
.49935 .50465 m .50196 .50274 L .49973 .50409 L .781 .998 .813 r
F
.4926 .51459 m .50169 .50308 L .49935 .50465 L F
.50169 .50308 m .50196 .50274 L .49935 .50465 L F
.4805 .53241 m .49973 .50409 L .49054 .51139 L F
.46785 .5296 m .46882 .52887 L .47789 .52709 L 0 0 0 r
F
.46785 .5296 m .47789 .52709 L .47785 .52714 L F
.47732 .52797 m .49013 .51956 L .47975 .52778 L F
.48322 .5172 m .4818 .51701 L .49721 .5061 L F
.47206 .52643 m .4818 .51701 L .48413 .51732 L F
.49054 .51139 m .46333 .53072 L .4636 .53065 L .781 .998 .813 r
F
.49822 .50523 m .4818 .51701 L .5022 .50181 L 0 0 0 r
F
.49721 .5061 m .49471 .50787 L .49822 .50523 L F
.49471 .50787 m .4818 .51701 L .49822 .50523 L F
.50939 .4944 m .50196 .50274 L .51632 .48455 L F
.50169 .50308 m .50287 .50124 L .51632 .48455 L F
.5022 .50181 m .4818 .51701 L .50287 .50124 L F
.49973 .50409 m .51065 .49299 L .4917 .50896 L .744 .873 .454 r
F
.50196 .50274 m .50283 .50177 L .49973 .50409 L F
.50283 .50177 m .51065 .49299 L .49973 .50409 L F
.45199 .53338 m .45191 .5334 L .46962 .52613 L 0 0 0 r
F
.46805 .52692 m .46138 .52963 L .4694 .52624 L F
.46138 .52963 m .42437 .54469 L .4694 .52624 L F
.49054 .51139 m .4917 .50896 L .46333 .53072 L .781 .998 .813 r
F
.46432 .53047 m .46805 .52692 L .46575 .53018 L 0 0 0 r
F
.46315 .52938 m .46805 .52692 L .46432 .53047 L F
.46805 .52692 m .46922 .52664 L .46539 .53146 L F
.46506 .53116 m .46539 .53146 L .46206 .53566 L F
.46506 .53116 m .46206 .53566 L .46189 .53566 L F
.46575 .53018 m .46539 .53146 L .46506 .53116 L F
.46805 .52692 m .46619 .53009 L .46575 .53018 L F
.46619 .53009 m .46539 .53146 L .46575 .53018 L F
.46805 .52692 m .458 .53101 L .4555 .53265 L .781 .998 .813 r
F
.4555 .53265 m .458 .53101 L .46369 .52989 L 0 0 0 r
F
.46882 .52887 m .4798 .52409 L .47789 .52709 L F
.46785 .5296 m .46922 .52664 L .47206 .52643 L F
.46663 .53053 m .46708 .52985 L .46785 .5296 L F
.46708 .52985 m .46922 .52664 L .46785 .5296 L F
.47116 .52845 m .47785 .52714 L .47209 .52838 L F
.47952 .52453 m .49013 .51956 L .47893 .52691 L F
.47785 .52714 m .47893 .52691 L .47732 .52797 L F
.47952 .52453 m .47893 .52691 L .47785 .52714 L F
.46449 .53375 m .46663 .53053 L .46785 .5296 L F
.47093 .52728 m .4798 .52409 L .46882 .52887 L F
.46539 .53146 m .46653 .53002 L .46663 .53053 L F
.46653 .53002 m .46922 .52664 L .46708 .52985 L F
.46653 .53002 m .46708 .52985 L .46663 .53053 L F
.47785 .52714 m .47746 .52723 L .46909 .52921 L F
.47179 .52664 m .4798 .52409 L .47093 .52728 L F
.47206 .52643 m .46922 .52664 L .4793 .51942 L F
.47952 .52453 m .49721 .5061 L .49013 .51956 L F
.48413 .51732 m .49721 .5061 L .47952 .52453 L F
.48413 .51732 m .48322 .5172 L .48686 .51431 L F
.49064 .51173 m .48686 .51431 L .49721 .5061 L F
.48413 .51732 m .48686 .51431 L .49064 .51173 L F
.51642 .49154 m .51595 .48853 L .515 .49445 L .744 .873 .454 r
F
.50939 .4944 m .51809 .48811 L .51062 .50948 L 0 0 0 r
F
.51341 .52114 m .51041 .52138 L .51305 .51877 L .494 .321 .575 r
F
.51019 .52161 m .51184 .51901 L .51305 .51877 L F
.50723 .49893 m .51239 .51497 L .51184 .51901 L .21 0 .352 r
F
.51108 .52021 m .51184 .51901 L .51142 .52213 L F
.50723 .49893 m .51184 .51901 L .51108 .52021 L F
.52694 .51598 m .51294 .51729 L .52778 .50586 L .494 .321 .575 r
F
.51294 .51729 m .50772 .51778 L .51563 .51308 L F
.51294 .51729 m .51563 .51308 L .52778 .50586 L F
.50874 .50362 m .51062 .50948 L .50772 .51778 L 0 0 0 r
F
.50939 .4944 m .51062 .50948 L .50874 .50362 L F
.49442 .51443 m .50169 .50308 L .4946 .5142 L F
.48636 .52707 m .50196 .50274 L .50311 .50144 L F
.48623 .52725 m .50196 .50274 L .48636 .52707 L F
.48541 .52851 m .50311 .50144 L .4872 .52597 L F
.47975 .52778 m .49013 .51956 L .48606 .52728 L F
.48621 .52727 m .49442 .51443 L .48623 .52725 L F
.49721 .5061 m .50169 .50308 L .48621 .52727 L F
.49721 .5061 m .48621 .52727 L .48606 .52728 L F
.47943 .52747 m .48706 .52612 L .48621 .52727 L .523 .324 .553 r
F
.47975 .52778 m .48621 .52727 L .48327 .53124 L F
.47943 .52747 m .48621 .52727 L .47975 .52778 L F
.48606 .52728 m .48621 .52727 L .48541 .52851 L 0 0 0 r
F
.48447 .52607 m .48741 .52564 L .47943 .52747 L .523 .324 .553 r
F
.48741 .52564 m .50105 .52364 L .48706 .52612 L F
.48741 .52564 m .48706 .52612 L .47943 .52747 L F
.48541 .52851 m .48623 .52725 L .48636 .52707 L 0 0 0 r
F
.49626 .51201 m .50967 .52096 L .48914 .52298 L .21 0 .352 r
F
.50967 .52096 m .50863 .52153 L .48109 .52378 L F
.50105 .52364 m .50669 .52701 L .51093 .55837 L .523 .324 .553 r
F
.50551 .53752 m .50722 .52231 L .50907 .52335 L .543 .31 .512 r
F
.50722 .52231 m .50863 .52153 L .50907 .52335 L F
.51012 .52717 m .50866 .52153 L .51404 .52523 L .494 .321 .575 r
F
.50967 .52096 m .51032 .52139 L .50863 .52153 L .21 0 .352 r
F
.50866 .52153 m .5082 .51974 L .50999 .52142 L .494 .321 .575 r
F
.50866 .52153 m .50999 .52142 L .51404 .52523 L F
.5199 .56813 m .50907 .52335 L .52051 .56729 L F
.50708 .51923 m .51098 .52036 L .51032 .52139 L .21 0 .352 r
F
.50907 .52335 m .5082 .51974 L .50912 .52328 L .494 .321 .575 r
F
.50907 .52335 m .50912 .52328 L .52051 .56729 L F
.50708 .51923 m .51106 .52012 L .51098 .52036 L .21 0 .352 r
F
.51032 .52139 m .51098 .52036 L .51059 .52157 L F
.48109 .52378 m .50692 .52237 L .48447 .52607 L F
.50692 .52237 m .50105 .52364 L .48447 .52607 L F
.51098 .52036 m .51106 .52012 L .51108 .52021 L F
.51019 .52161 m .5082 .51974 L .51184 .51901 L .494 .321 .575 r
F
.51032 .52139 m .51059 .52157 L .48109 .52378 L .21 0 .352 r
F
.51059 .52157 m .50692 .52237 L .48109 .52378 L F
.50722 .52231 m .49859 .52217 L .50772 .51778 L .543 .31 .512 r
F
.50669 .52701 m .50105 .52364 L .50722 .52231 L F
.50105 .52364 m .49859 .52217 L .50722 .52231 L F
.51059 .52157 m .51142 .52213 L .50692 .52237 L .21 0 .352 r
F
.50692 .52237 m .51142 .52213 L .50105 .52364 L F
.48327 .53124 m .50105 .52364 L .51093 .55837 L .523 .324 .553 r
F
.50551 .53752 m .48541 .52851 L .49099 .52583 L .543 .31 .512 r
F
.49941 .524 m .49099 .52583 L .49859 .52217 L F
.50551 .53752 m .49099 .52583 L .49941 .524 L F
.49099 .52583 m .48777 .52516 L .49859 .52217 L 0 0 0 r
F
.48541 .52851 m .4872 .52597 L .49099 .52583 L F
.4872 .52597 m .48777 .52516 L .49099 .52583 L F
.4793 .52627 m .48447 .52607 L .47885 .5269 L .21 0 .352 r
F
.48109 .52378 m .48447 .52607 L .4793 .52627 L F
.51575 .48981 m .51595 .48853 L .51294 .49184 L .744 .873 .454 r
F
.51065 .49299 m .51595 .48853 L .49626 .51201 L .21 0 .352 r
F
.50691 .49794 m .50311 .50144 L .50939 .4944 L 0 0 0 r
F
.4872 .52597 m .49626 .51201 L .50691 .49794 L F
.49626 .51201 m .50311 .50144 L .50691 .49794 L F
.49054 .51139 m .49973 .50409 L .4917 .50896 L .781 .998 .813 r
F
.4917 .50896 m .49626 .51201 L .48109 .52378 L .21 0 .352 r
F
.49626 .51201 m .48914 .52298 L .48109 .52378 L F
.4917 .50896 m .50645 .49653 L .50269 .50351 L F
.50645 .49653 m .51065 .49299 L .50691 .49794 L F
.50645 .49653 m .50691 .49794 L .50269 .50351 L F
.49322 .50998 m .50269 .50351 L .49626 .51201 L F
.4917 .50896 m .50269 .50351 L .49322 .50998 L F
.46805 .52692 m .46205 .52836 L .458 .53101 L .781 .998 .813 r
F
.4555 .53265 m .46369 .52989 L .46406 .53022 L 0 0 0 r
F
.458 .53101 m .46315 .52938 L .46369 .52989 L F
.46432 .53047 m .46882 .52887 L .46785 .5296 L F
.4555 .53265 m .46406 .53022 L .46432 .53047 L F
.46406 .53022 m .46882 .52887 L .46432 .53047 L F
.4555 .53265 m .46432 .53047 L .46042 .53127 L F
.40207 .55975 m .4555 .53265 L .4534 .53301 L .549 .93 .848 r
F
.40207 .55975 m .43213 .54409 L .42579 .54468 L F
.43213 .54409 m .4534 .53301 L .42634 .54445 L F
.43213 .54409 m .42634 .54445 L .42579 .54468 L F
.45065 .53512 m .42439 .54469 L .45253 .53323 L 0 0 0 r
F
.44713 .537 m .43578 .54084 L .45037 .53523 L F
.43578 .54084 m .42439 .54469 L .45065 .53512 L F
.44534 .54418 m .46088 .5326 L .4555 .53265 L .792 .935 .924 r
F
.42178 .57092 m .46088 .5326 L .44534 .54418 L F
.44961 .53616 m .44713 .537 L .45065 .53512 L 0 0 0 r
F
.44713 .537 m .45037 .53523 L .45065 .53512 L F
.42942 .54407 m .42439 .54469 L .44961 .53616 L F
.42439 .54469 m .42437 .54469 L .46805 .52692 L F
.4684 .52683 m .4917 .50896 L .46205 .52836 L .781 .998 .813 r
F
.458 .53101 m .4917 .50896 L .48758 .51472 L 0 0 0 r
F
.47179 .52664 m .48758 .51472 L .48117 .52366 L F
.45864 .53163 m .45253 .53323 L .46805 .52692 L F
.458 .53101 m .48758 .51472 L .47179 .52664 L F
.47785 .52714 m .46909 .52921 L .46904 .52923 L F
.46785 .5296 m .47785 .52714 L .46904 .52923 L F
.46909 .52921 m .47746 .52723 L .47096 .52862 L F
.47043 .52907 m .47206 .52643 L .48413 .51732 L F
.46038 .53699 m .478 .53501 L .47773 .53759 L .455 .123 .313 r
F
.46206 .53566 m .478 .53501 L .46038 .53699 L F
.45199 .53338 m .42437 .54469 L .45191 .5334 L 0 0 0 r
F
.42613 .54446 m .42437 .54469 L .42634 .54445 L .124 .673 .727 r
F
.42285 .54473 m .44072 .53519 L .41995 .54496 L .549 .93 .848 r
F
.42613 .54446 m .4265 .54423 L .42285 .54473 L F
.4265 .54423 m .44072 .53519 L .42285 .54473 L F
.42285 .54473 m .39689 .54825 L .42437 .54469 L .124 .673 .727 r
F
.39689 .54825 m .39483 .54857 L .42437 .54469 L F
.38685 .54962 m .38677 .54963 L .39978 .54792 L F
.39956 .54795 m .39978 .54792 L .42437 .54469 L F
.38685 .54962 m .39978 .54792 L .39956 .54795 L F
.39689 .54825 m .38685 .54962 L .39483 .54857 L F
.37768 .55058 m .36453 .54799 L .37592 .55105 L .164 .683 .886 r
F
.36453 .54799 m .35527 .54616 L .36434 .54831 L F
.36453 .54799 m .36434 .54831 L .37592 .55105 L F
.37309 .54387 m .38531 .54366 L .38811 .54032 L .317 .806 .849 r
F
.3969 .5558 m .44072 .53519 L .38979 .55037 L .549 .93 .848 r
F
.41833 .54489 m .44072 .53519 L .42131 .54432 L .067 0 0 r
F
.41671 .5452 m .41721 .545 L .41833 .54489 L F
.41721 .545 m .44072 .53519 L .41833 .54489 L F
.45864 .53163 m .46315 .52938 L .46432 .53047 L 0 0 0 r
F
.4555 .53265 m .46628 .52963 L .4534 .53301 L F
.44961 .53616 m .45253 .53323 L .45864 .53163 L F
.42613 .54446 m .4534 .53301 L .44072 .53519 L .549 .93 .848 r
F
.42579 .54468 m .42634 .54445 L .42613 .54446 L F
.42634 .54445 m .4534 .53301 L .42613 .54446 L F
.47561 .75759 m .60678 .69801 L .6127 .68522 L .407 .048 .24 r
F
.47174 .76773 m .60678 .69801 L .47561 .75759 L .224 0 0 r
F
.32771 .77165 m .47561 .75759 L .32814 .76286 L .683 .31 .333 r
F
.32771 .77165 m .47174 .76773 L .47561 .75759 L F
.32563 .77916 m .47174 .76773 L .32771 .77165 L .649 .238 .251 r
F
.32563 .77916 m .46474 .77634 L .47174 .76773 L F
.32209 .7854 m .46474 .77634 L .32563 .77916 L .6 .145 .143 r
F
.32209 .7854 m .45531 .78341 L .46474 .77634 L F
.31734 .7904 m .45531 .78341 L .32209 .7854 L .533 .032 .01 r
F
.31734 .7904 m .44421 .78901 L .45531 .78341 L F
.31163 .7942 m .44421 .78901 L .31734 .7904 L .449 0 0 r
F
.31163 .7942 m .43216 .7933 L .44421 .78901 L F
.30524 .79687 m .43216 .7933 L .31163 .7942 L .364 0 0 r
F
.30524 .79687 m .41977 .79653 L .43216 .7933 L F
.41977 .79653 m .50268 .74157 L .52201 .73787 L .78 .948 .93 r
F
.50268 .74157 m .50378 .74084 L .50454 .74071 L F
.50268 .74157 m .50454 .74071 L .52201 .73787 L F
.29843 .79848 m .41976 .79653 L .30524 .79687 L .3 0 0 r
F
.41976 .79653 m .41977 .79653 L .41976 .79653 L F
.41976 .79653 m .41976 .79653 L .30524 .79687 L F
.29143 .7991 m .39578 .80107 L .40754 .79902 L .275 0 0 r
F
.39578 .80107 m .39763 .79991 L .40754 .79902 L .786 .975 .912 r
F
.29843 .79848 m .40754 .79902 L .41977 .79653 L .3 0 0 r
F
.29143 .7991 m .39671 .79902 L .29843 .79848 L .275 0 0 r
F
.20771 .73496 m .29143 .7991 L .29843 .79848 L .836 .368 .065 r
F
.20771 .73496 m .2559 .7687 L .20936 .73535 L F
.2559 .7687 m .26585 .77567 L .25697 .76933 L F
.2559 .7687 m .25697 .76933 L .20936 .73535 L F
.19057 .63127 m .20771 .73496 L .20936 .73535 L .914 .703 .204 r
F
.19057 .63127 m .20614 .7337 L .20771 .73496 L .892 .677 .161 r
F
.20614 .7337 m .26994 .78262 L .20771 .73496 L .815 .331 0 r
F
.26994 .78262 m .27676 .78785 L .20771 .73496 L F
.28835 .79673 m .28827 .79667 L .26514 .77895 L F
.26523 .77902 m .26514 .77895 L .20771 .73496 L F
.28835 .79673 m .26514 .77895 L .26523 .77902 L F
.27596 .78275 m .29843 .79848 L .28401 .78826 L .836 .368 .065 r
F
.26994 .78262 m .28835 .79673 L .27676 .78785 L .815 .331 0 r
F
.28835 .79673 m .29143 .7991 L .28827 .79667 L F
.22114 .7452 m .28448 .79876 L .29143 .7991 L F
.34662 .80005 m .38408 .80083 L .34119 .80003 L .292 0 0 r
F
.38408 .80083 m .3842 .80084 L .29143 .7991 L F
.28448 .79876 m .34662 .80005 L .29143 .7991 L F
.34662 .80005 m .34119 .80003 L .29143 .7991 L F
.39258 .801 m .39354 .80102 L .29143 .7991 L F
.39474 .80105 m .39477 .80105 L .29143 .7991 L F
.39522 .80106 m .39525 .80106 L .29143 .7991 L F
.3109 .79987 m .38466 .80297 L .32927 .79969 L F
.38408 .80083 m .39258 .801 L .3842 .80084 L F
.39258 .801 m .39474 .80105 L .39354 .80102 L F
.39474 .80105 m .39522 .80106 L .39477 .80105 L F
.39522 .80106 m .39578 .80107 L .39525 .80106 L F
.34662 .80005 m .38421 .80294 L .39578 .80107 L F
.32927 .79969 m .34939 .80088 L .34662 .80005 L F
.34939 .80088 m .38421 .80294 L .34662 .80005 L F
.35589 .80149 m .38406 .80294 L .3518 .80158 L .342 0 0 r
F
.29128 .7989 m .3109 .79987 L .32927 .79969 L .292 0 0 r
F
.38359 .80292 m .38362 .80293 L .36219 .80202 L .342 0 0 r
F
.36222 .80202 m .36219 .80202 L .28448 .79876 L F
.38359 .80292 m .36219 .80202 L .36222 .80202 L F
.38406 .80294 m .38414 .80295 L .38362 .80293 L F
.38406 .80294 m .38362 .80293 L .38359 .80292 L F
.35589 .80149 m .36499 .8041 L .38406 .80294 L F
.27103 .78758 m .28448 .79876 L .27032 .78679 L .815 .331 0 r
F
.21457 .7407 m .27103 .78758 L .22114 .7452 L F
.27103 .78758 m .27032 .78679 L .22114 .7452 L F
.20614 .7337 m .21457 .7407 L .22114 .7452 L F
.19057 .63127 m .20475 .73158 L .20614 .7337 L .856 .64 .102 r
F
.20475 .73158 m .25304 .77227 L .20614 .7337 L .785 .288 0 r
F
.25304 .77227 m .26347 .78105 L .25515 .77418 L F
.25304 .77227 m .25515 .77418 L .20614 .7337 L F
.26347 .78105 m .2697 .78644 L .20614 .7337 L F
.2802 .79515 m .28002 .79505 L .20614 .7337 L F
.26347 .78105 m .2802 .79515 L .2697 .78644 L F
.2802 .79515 m .28448 .79876 L .28002 .79505 L F
.26347 .78105 m .27779 .79749 L .28448 .79876 L F
.22629 .74973 m .27779 .79749 L .26347 .78105 L F
.21786 .74263 m .22107 .74631 L .22629 .74973 L F
.22107 .74631 m .27779 .79749 L .22629 .74973 L F
.26585 .77567 m .26791 .77702 L .20936 .73535 L .836 .368 .065 r
F
.27596 .78275 m .28401 .78826 L .20936 .73535 L F
.20936 .73535 m .29843 .79848 L .30524 .79687 L .851 .401 .131 r
F
.20475 .73158 m .21204 .73816 L .21786 .74263 L .785 .288 0 r
F
.21204 .73816 m .22107 .74631 L .21786 .74263 L F
.20936 .73535 m .30524 .79687 L .21099 .73487 L .851 .401 .131 r
F
.19057 .63127 m .20936 .73535 L .21099 .73487 L .927 .719 .232 r
F
.19057 .63127 m .20364 .72861 L .20475 .73158 L .805 .589 .028 r
F
.20364 .72861 m .24596 .76792 L .20475 .73158 L .742 .238 0 r
F
.24596 .76792 m .2491 .77133 L .20475 .73158 L F
.26443 .78508 m .26339 .78449 L .20475 .73158 L F
.21527 .73941 m .22745 .75197 L .23111 .75412 L F
.24596 .76792 m .26443 .78508 L .2491 .77133 L F
.26443 .78508 m .27227 .79235 L .26339 .78449 L F
.27227 .79235 m .27779 .79749 L .27189 .79216 L F
.27227 .79235 m .27189 .79216 L .26339 .78449 L F
.28448 .79876 m .29148 .79905 L .29128 .7989 L .292 0 0 r
F
.29148 .79905 m .3109 .79987 L .29128 .7989 L F
.27779 .79749 m .35589 .80149 L .28448 .79876 L .342 0 0 r
F
.28511 .79786 m .29376 .79872 L .30836 .79905 L F
.35589 .80149 m .3518 .80158 L .28448 .79876 L F
.30836 .79905 m .36163 .8038 L .35589 .80149 L F
.36163 .8038 m .36499 .8041 L .35589 .80149 L F
.29376 .79872 m .36419 .80414 L .30836 .79905 L F
.36419 .80414 m .36499 .8041 L .30836 .79905 L F
.23111 .75412 m .27158 .79527 L .27583 .79567 L .742 .238 0 r
F
.27779 .79749 m .28551 .79808 L .28511 .79786 L .342 0 0 r
F
.28551 .79808 m .29376 .79872 L .28511 .79786 L F
.39671 .79902 m .40056 .79899 L .29843 .79848 L .275 0 0 r
F
.40684 .79902 m .40689 .79901 L .29843 .79848 L F
.27158 .79527 m .36258 .80382 L .27779 .79749 L .407 0 0 r
F
.36429 .80416 m .37429 .80371 L .36544 .80439 L .799 .946 .92 r
F
.36258 .80382 m .36321 .80395 L .27779 .79749 L .407 0 0 r
F
.36321 .80395 m .36419 .80414 L .36209 .80398 L F
.36321 .80395 m .36209 .80398 L .27779 .79749 L F
.48827 .7482 m .49728 .74405 L .4966 .74479 L .803 .728 .781 r
F
.40754 .79902 m .45266 .76755 L .488 .74924 L .792 .953 .922 r
F
.48851 .75007 m .488 .74924 L .50114 .74243 L F
.40754 .79902 m .488 .74924 L .48851 .75007 L F
.51145 .66498 m .51063 .66126 L .51259 .66253 L .872 .767 .743 r
F
.51063 .66126 m .51055 .66088 L .51078 .66084 L F
.48664 .63111 m .48391 .5954 L .49569 .64475 L .859 .611 .562 r
F
.48617 .64817 m .49488 .65427 L .48857 .68612 L .803 .643 .683 r
F
.47696 .63169 m .47432 .61495 L .48536 .65165 L .957 .664 .437 r
F
.47432 .61495 m .47932 .62451 L .48544 .64925 L F
.49488 .65427 m .50819 .66359 L .50292 .66964 L .803 .643 .683 r
F
.49631 .64568 m .50819 .66359 L .48617 .64817 L F
.49026 .60917 m .5107 .66077 L .50576 .6518 L .732 .556 .654 r
F
.48031 .58182 m .49379 .61684 L .49026 .60917 L F
.49379 .61684 m .51073 .66087 L .49026 .60917 L F
.49978 .64483 m .49234 .61744 L .49987 .63914 L .784 .572 .613 r
F
.48541 .63616 m .48857 .68612 L .48563 .6577 L .803 .643 .683 r
F
.48544 .64925 m .48563 .6577 L .48546 .65601 L F
.48541 .63616 m .48563 .6577 L .48544 .64925 L F
.43703 .54238 m .47436 .5738 L .43638 .54276 L .627 .339 .461 r
F
.44628 .53746 m .46685 .53755 L .46672 .54581 L .455 .123 .313 r
F
.44856 .53657 m .47773 .53759 L .44628 .53746 L F
.44368 .5364 m .46206 .53566 L .46038 .53699 L F
.44087 .5405 m .46081 .5457 L .43824 .54197 L F
.46738 .57339 m .43634 .54433 L .43671 .5442 L .68 .316 .35 r
F
.43327 .54413 m .43638 .54276 L .43655 .54332 L .462 0 .036 r
F
.43623 .54416 m .43655 .54332 L .43682 .54417 L F
.43327 .54413 m .43655 .54332 L .43623 .54416 L F
.44822 .56514 m .43605 .54464 L .43835 .54744 L .745 .291 .174 r
F
.44958 .5661 m .43835 .54744 L .45931 .57295 L F
.44822 .56514 m .43835 .54744 L .44958 .5661 L F
.47432 .61495 m .4714 .59647 L .47932 .62451 L .957 .664 .437 r
F
.44958 .5661 m .47449 .59938 L .45858 .58105 L .722 .458 .527 r
F
.47449 .59938 m .475 .60006 L .47407 .59898 L F
.47449 .59938 m .47407 .59898 L .45858 .58105 L F
.44958 .5661 m .48074 .58805 L .47647 .60202 L F
.46929 .58578 m .44822 .56514 L .46969 .58559 L .745 .291 .174 r
F
.45348 .57995 m .47059 .5957 L .47069 .59647 L .797 .547 .561 r
F
.45542 .58417 m .47069 .59647 L .47174 .60452 L F
.45542 .58417 m .47174 .60452 L .45962 .59333 L F
.43703 .54238 m .42942 .54407 L .44396 .53837 L 0 0 0 r
F
.43674 .54255 m .4365 .5426 L .43703 .54238 L F
.4365 .5426 m .42942 .54407 L .43703 .54238 L F
.43703 .54238 m .45088 .54498 L .47093 .56812 L .627 .339 .461 r
F
.43703 .54238 m .47093 .56812 L .47436 .5738 L F
.48074 .5807 m .51073 .66087 L .48031 .58182 L .732 .556 .654 r
F
.51862 .56772 m .51938 .56885 L .51575 .57205 L .666 .547 .71 r
F
.55842 .64163 m .56026 .63082 L .56046 .63099 L .684 .561 .71 r
F
.55835 .6413 m .55538 .62434 L .56026 .63082 L F
.55339 .65127 m .55562 .64785 L .55208 .66146 L .743 .634 .739 r
F
.55562 .64785 m .55871 .6431 L .55654 .64912 L F
.55562 .64785 m .55654 .64912 L .55208 .66146 L F
.51938 .56885 m .5532 .61986 L .51905 .57604 L .666 .547 .71 r
F
.55835 .6413 m .55871 .6431 L .55339 .65127 L .743 .634 .739 r
F
.55692 .65362 m .56046 .63099 L .58171 .64862 L .684 .561 .71 r
F
.5532 .61986 m .56049 .63085 L .55196 .61979 L .666 .547 .71 r
F
.55608 .65379 m .56046 .63099 L .55692 .65362 L .684 .561 .71 r
F
.56026 .63082 m .58015 .63368 L .58171 .64862 L F
.56049 .63085 m .56201 .63315 L .56026 .63082 L .666 .547 .71 r
F
.56049 .63085 m .56026 .63082 L .55196 .61979 L F
.5532 .61986 m .55196 .61979 L .51905 .57604 L F
.53822 .62386 m .53893 .61908 L .55531 .64742 L .699 .548 .679 r
F
.53893 .61908 m .55196 .61979 L .55531 .64742 L F
.55531 .64742 m .55196 .61979 L .55835 .6413 L .684 .561 .71 r
F
.54367 .57428 m .55977 .56786 L .56026 .58112 L .666 .547 .71 r
F
.51972 .56837 m .56026 .58112 L .5618 .62248 L F
.51941 .56797 m .5199 .56813 L .51972 .56837 L F
.5199 .56813 m .56026 .58112 L .51972 .56837 L F
.52297 .56391 m .51969 .56197 L .52307 .5627 L .494 .321 .575 r
F
.52051 .56729 m .51969 .56197 L .52297 .56391 L F
.52051 .56729 m .51012 .52717 L .51404 .52523 L F
.51938 .56885 m .51903 .57638 L .51575 .57205 L .666 .547 .71 r
F
.50551 .53752 m .50907 .52335 L .5199 .56813 L .543 .31 .512 r
F
.51862 .56772 m .5618 .62248 L .56049 .63085 L .666 .547 .71 r
F
.51941 .56797 m .5618 .62248 L .51862 .56772 L F
.51816 .56757 m .5199 .56813 L .52193 .57651 L .543 .31 .512 r
F
.50551 .53752 m .5199 .56813 L .51816 .56757 L F
.5152 .56256 m .51941 .56797 L .51862 .56772 L .666 .547 .71 r
F
.5152 .56256 m .56026 .58112 L .51941 .56797 L F
.52193 .57651 m .52051 .56729 L .52297 .56391 L .494 .321 .575 r
F
.55196 .61979 m .54605 .571 L .55538 .62434 L .684 .561 .71 r
F
.55196 .61979 m .55538 .62434 L .55835 .6413 L F
.55835 .6413 m .56026 .63082 L .55842 .64163 L F
.51817 .6172 m .52008 .59652 L .52254 .60769 L .732 .552 .648 r
F
.52002 .61933 m .52254 .60769 L .52681 .62715 L F
.51817 .6172 m .52254 .60769 L .52002 .61933 L F
.52201 .73787 m .54122 .69047 L .54767 .69951 L .794 .728 .79 r
F
.51259 .66253 m .5107 .66077 L .5108 .66072 L .872 .767 .743 r
F
.51905 .57604 m .53007 .59071 L .51903 .57638 L .666 .547 .71 r
F
.53007 .59071 m .5622 .63344 L .52993 .59079 L F
.53007 .59071 m .52993 .59079 L .51903 .57638 L F
.56201 .63315 m .5622 .63344 L .51905 .57604 L F
.51575 .57205 m .56021 .63081 L .53996 .62086 L F
.53822 .62386 m .53313 .60905 L .53893 .61908 L .699 .548 .679 r
F
.51575 .57205 m .53996 .62086 L .51619 .5798 L .666 .547 .71 r
F
.52957 .63033 m .52441 .594 L .53822 .62386 L .699 .548 .679 r
F
.52441 .594 m .52193 .57651 L .53313 .60905 L F
.52441 .594 m .53313 .60905 L .53822 .62386 L F
.56021 .63081 m .55611 .63022 L .54065 .62205 L .666 .547 .71 r
F
.52602 .63298 m .55002 .65387 L .54456 .67511 L .743 .634 .739 r
F
.52002 .61933 m .52957 .63033 L .52602 .63298 L F
.52957 .63033 m .55002 .65387 L .52602 .63298 L F
.52002 .61933 m .54456 .67511 L .53586 .68971 L F
.52373 .61311 m .5274 .61505 L .53333 .65684 L .732 .552 .648 r
F
.52008 .59652 m .5274 .61505 L .52373 .61311 L F
.52008 .59652 m .52441 .594 L .5274 .61505 L F
.48115 .58178 m .49344 .59072 L .51071 .66076 L .732 .556 .654 r
F
.48074 .5807 m .51071 .66076 L .5107 .66077 L F
.51217 .65572 m .51304 .65685 L .51105 .6609 L .743 .634 .739 r
F
.51063 .66126 m .488 .74924 L .48905 .72833 L .803 .728 .781 r
F
.47717 .72401 m .48307 .74465 L .43402 .77462 L .839 .839 .846 r
F
.48362 .72444 m .50351 .68194 L .48828 .73079 L .872 .767 .743 r
F
.488 .74924 m .48695 .74751 L .48713 .74528 L .803 .728 .781 r
F
.488 .74924 m .48713 .74528 L .48819 .74557 L F
.51997 .68204 m .51334 .66194 L .52304 .67625 L .829 .73 .755 r
F
.50944 .66888 m .51051 .67022 L .49728 .74405 L .803 .728 .781 r
F
.51065 .6704 m .51334 .66194 L .51997 .68204 L .829 .73 .755 r
F
.5112 .66665 m .51279 .66211 L .51105 .6677 L .872 .767 .743 r
F
.51065 .66135 m .51145 .66498 L .51051 .67022 L .803 .728 .781 r
F
.51065 .66135 m .51051 .67022 L .50944 .66888 L F
.51145 .66498 m .50033 .74076 L .49728 .74405 L F
.46201 .74939 m .46672 .73829 L .47361 .74583 L .935 .84 .726 r
F
.46672 .73829 m .47543 .72665 L .47361 .74583 L F
.47653 .71519 m .48843 .68713 L .48021 .72421 L F
.48707 .69328 m .4894 .69415 L .48021 .72421 L F
.48843 .68713 m .4888 .68985 L .48707 .69328 L F
.4888 .68985 m .4894 .69415 L .48707 .69328 L F
.48857 .68612 m .49357 .68042 L .4888 .68985 L .803 .643 .683 r
F
.39671 .79902 m .40684 .79902 L .40056 .79899 L .275 0 0 r
F
.39578 .80107 m .42696 .77894 L .43322 .77557 L .786 .975 .912 r
F
.42885 .78022 m .43322 .77557 L .45402 .76435 L F
.39578 .80107 m .43322 .77557 L .42885 .78022 L F
.43402 .77462 m .47019 .7547 L .43193 .77708 L .839 .839 .846 r
F
.47019 .7547 m .47251 .75371 L .43193 .77708 L F
.48307 .74465 m .4838 .7472 L .43402 .77462 L F
.43322 .77557 m .47361 .74583 L .45402 .76435 L .786 .975 .912 r
F
.45342 .75482 m .45704 .75235 L .46201 .74939 L .486 .876 .693 r
F
.476 .72537 m .44533 .76136 L .46404 .74184 L .839 .839 .846 r
F
.46471 .74096 m .46404 .74184 L .46415 .74173 L F
.476 .72537 m .46404 .74184 L .46471 .74096 L F
.46201 .74939 m .46471 .74096 L .46672 .73829 L .935 .84 .726 r
F
.45967 .75065 m .46459 .74112 L .46201 .74939 L .964 .935 .627 r
F
.45641 .75241 m .45835 .74973 L .45967 .75065 L F
.4588 .74912 m .46459 .74112 L .45858 .74989 L F
.44533 .76136 m .44856 .75875 L .46415 .74173 L .839 .839 .846 r
F
.44279 .76562 m .46201 .74939 L .47361 .74583 L .721 .988 .872 r
F
.43515 .7734 m .43591 .77262 L .44868 .75865 L .839 .839 .846 r
F
.44856 .75875 m .44868 .75865 L .46415 .74173 L F
.43402 .77462 m .44868 .75865 L .44856 .75875 L F
.44533 .76136 m .43402 .77462 L .44856 .75875 L F
.45172 .75655 m .46201 .74939 L .44279 .76562 L .721 .988 .872 r
F
.44279 .76562 m .47361 .74583 L .43623 .77236 L F
.43623 .77236 m .47361 .74583 L .43322 .77557 L .786 .975 .912 r
F
.39763 .79991 m .42885 .78022 L .40868 .79822 L F
.42885 .78022 m .45402 .76435 L .41812 .79117 L F
.42885 .78022 m .41812 .79117 L .40868 .79822 L F
.43322 .77557 m .43193 .77708 L .44782 .76 L .839 .839 .846 r
F
.45402 .76435 m .47251 .75371 L .40868 .79822 L .786 .975 .912 r
F
.40754 .79902 m .48851 .75007 L .41977 .79653 L .792 .953 .922 r
F
.48851 .75007 m .50114 .74243 L .48937 .75026 L F
.48851 .75007 m .48937 .75026 L .41977 .79653 L F
.51063 .66126 m .51078 .66084 L .51259 .66253 L .872 .767 .743 r
F
.51073 .66087 m .49728 .74405 L .48827 .7482 L .803 .728 .781 r
F
.50114 .74243 m .47251 .75371 L .50378 .74084 L .792 .953 .922 r
F
.48827 .7482 m .4966 .74479 L .49465 .74579 L .803 .728 .781 r
F
.48827 .7482 m .4962 .74521 L .48783 .74992 L F
.45266 .76755 m .47251 .75371 L .50114 .74243 L .792 .953 .922 r
F
.47251 .75371 m .50186 .74112 L .50378 .74084 L F
.488 .74924 m .48783 .74992 L .48695 .74751 L .803 .728 .781 r
F
.50114 .74243 m .50268 .74157 L .41977 .79653 L .792 .953 .922 r
F
.48783 .74992 m .48629 .75591 L .48678 .7497 L .803 .728 .781 r
F
.48783 .74992 m .48678 .7497 L .48695 .74751 L F
.43193 .77708 m .48629 .75591 L .41864 .79267 L .839 .839 .846 r
F
.4838 .7472 m .48629 .75591 L .43193 .77708 L F
.43193 .77708 m .41864 .79267 L .43918 .76968 L F
.43193 .77708 m .43918 .76968 L .44782 .76 L F
.43718 .77123 m .44782 .76 L .46415 .74173 L F
.43322 .77557 m .43922 .76918 L .43718 .77123 L F
.43922 .76918 m .44782 .76 L .43718 .77123 L F
.45342 .75482 m .46201 .74939 L .45179 .75647 L .486 .876 .693 r
F
.45429 .75412 m .45704 .75235 L .45342 .75482 L F
.46091 .74606 m .4517 .75621 L .45736 .7508 L .839 .839 .846 r
F
.4517 .75621 m .44763 .76071 L .45337 .75486 L F
.46415 .74173 m .44782 .76 L .46091 .74606 L F
.44782 .76 m .41864 .79267 L .46091 .74606 L F
.39575 .79529 m .45179 .75647 L .38983 .79956 L .721 .988 .872 r
F
.45179 .75647 m .46201 .74939 L .45172 .75655 L F
.44027 .76316 m .39575 .79529 L .37934 .80245 L .799 .946 .92 r
F
.39575 .79529 m .38923 .79999 L .38919 .8 L F
.39575 .79529 m .38919 .8 L .37934 .80245 L F
.4517 .75621 m .45429 .75412 L .45736 .7508 L .839 .839 .846 r
F
.44211 .76198 m .45342 .75482 L .39919 .79282 L .486 .876 .693 r
F
.45179 .75647 m .45172 .75655 L .38981 .79958 L .721 .988 .872 r
F
.38983 .79956 m .38981 .79958 L .38816 .80072 L F
.45179 .75647 m .38981 .79958 L .38983 .79956 L F
.45342 .75482 m .45179 .75647 L .39575 .79529 L .486 .876 .693 r
F
.44211 .76198 m .39575 .79529 L .44027 .76316 L .799 .946 .92 r
F
.39919 .79282 m .39575 .79529 L .38792 .80071 L .486 .876 .693 r
F
.45342 .75482 m .39575 .79529 L .39919 .79282 L F
.38816 .80072 m .45172 .75655 L .44279 .76562 L .721 .988 .872 r
F
.44211 .76198 m .45429 .75412 L .45342 .75482 L .486 .876 .693 r
F
.45429 .75412 m .38923 .79999 L .39575 .79529 L .799 .946 .92 r
F
.45429 .75412 m .39575 .79529 L .44211 .76198 L F
.45429 .75412 m .37934 .80245 L .37429 .80371 L F
.38137 .80039 m .44211 .76198 L .38792 .80071 L .486 .876 .693 r
F
.44211 .76198 m .39919 .79282 L .38792 .80071 L F
.45337 .75486 m .41864 .79267 L .45429 .75412 L .839 .839 .846 r
F
.44763 .76071 m .41864 .79267 L .45337 .75486 L F
.43402 .77462 m .43497 .77365 L .43591 .77262 L F
.43402 .77462 m .43591 .77262 L .43515 .7734 L F
.43402 .77462 m .43322 .77557 L .43497 .77365 L F
.38891 .80024 m .44279 .76562 L .42696 .77894 L .721 .988 .872 r
F
.44279 .76562 m .43623 .77236 L .42696 .77894 L F
.42696 .77894 m .43623 .77236 L .43322 .77557 L .786 .975 .912 r
F
.39251 .8 m .42696 .77894 L .39781 .79963 L .721 .988 .872 r
F
.38891 .80024 m .42696 .77894 L .39251 .8 L F
.45429 .75412 m .41864 .79267 L .38923 .79999 L .799 .946 .92 r
F
.38792 .80071 m .39575 .79529 L .38816 .80072 L .721 .988 .872 r
F
.39575 .79529 m .38983 .79956 L .38816 .80072 L F
.4577 .74873 m .47974 .6925 L .46459 .74112 L .964 .935 .627 r
F
.45858 .74989 m .46459 .74112 L .45967 .75065 L F
.47432 .61495 m .48544 .64925 L .48545 .65194 L .957 .664 .437 r
F
.48387 .65715 m .48688 .67428 L .48211 .68644 L .874 .745 .717 r
F
.48546 .65859 m .48688 .67428 L .48387 .65715 L F
.48743 .67511 m .4873 .67462 L .48546 .65601 L .803 .643 .683 r
F
.4805 .65411 m .47696 .63169 L .48274 .64713 L .957 .664 .437 r
F
.4888 .68985 m .48843 .68713 L .48546 .65601 L .803 .643 .683 r
F
.48843 .68713 m .4875 .67973 L .48546 .65601 L F
.46459 .74112 m .46471 .74096 L .46201 .74939 L .964 .935 .627 r
F
.48021 .72421 m .48556 .74735 L .47717 .72401 L .839 .839 .846 r
F
.48556 .74735 m .4854 .74744 L .47717 .72401 L F
.48562 .74808 m .48422 .74868 L .47717 .72401 L F
.48362 .72444 m .48449 .73467 L .48021 .72421 L F
.48449 .73467 m .48556 .74735 L .48021 .72421 L F
.51304 .65685 m .51624 .66101 L .51386 .66177 L .743 .634 .739 r
F
.51304 .65685 m .51407 .66301 L .51243 .6606 L F
.51304 .65685 m .51225 .66173 L .51105 .6609 L F
.51131 .65682 m .50833 .64226 L .5135 .65404 L .784 .572 .613 r
F
.50038 .60346 m .51131 .65682 L .51073 .66087 L .732 .556 .654 r
F
.5072 .63969 m .50719 .61755 L .5135 .65404 L .784 .572 .613 r
F
.51817 .6172 m .51185 .60379 L .51244 .60206 L .732 .552 .648 r
F
.51614 .60521 m .51244 .60206 L .51455 .59581 L F
.51817 .6172 m .51244 .60206 L .51614 .60521 L F
.5072 .63674 m .50224 .5941 L .50719 .61755 L .784 .572 .613 r
F
.50651 .6334 m .50224 .5941 L .5072 .63674 L F
.50224 .5941 m .50314 .59416 L .50719 .61755 L F
.50718 .5877 m .50811 .56538 L .5147 .59537 L .65 .463 .618 r
F
.50718 .59443 m .5147 .59537 L .51244 .60206 L F
.49169 .57193 m .50718 .5877 L .50718 .59443 L F
.50718 .5877 m .5147 .59537 L .50718 .59443 L F
.48285 .58046 m .47103 .55794 L .4815 .55712 L .608 .314 .444 r
F
.48265 .57701 m .50079 .594 L .48286 .58067 L .65 .463 .618 r
F
.48215 .58129 m .46468 .54583 L .48285 .58046 L .608 .314 .444 r
F
.50079 .594 m .48288 .58094 L .48286 .58067 L .65 .463 .618 r
F
.48288 .58094 m .48285 .58046 L .48306 .58085 L .608 .314 .444 r
F
.48215 .58129 m .48285 .58046 L .48288 .58094 L F
.48175 .58149 m .49344 .59072 L .48115 .58178 L .732 .556 .654 r
F
.48031 .58182 m .50576 .6518 L .49995 .63932 L F
.48031 .58182 m .49995 .63932 L .49961 .63839 L F
.49987 .63914 m .48296 .58294 L .48302 .58293 L .784 .572 .613 r
F
.50079 .594 m .50052 .59398 L .48288 .58094 L .65 .463 .618 r
F
.50052 .59398 m .49244 .58888 L .48288 .58094 L F
.50052 .59398 m .50224 .5941 L .50651 .6334 L .784 .572 .613 r
F
.5057 .62941 m .50651 .6334 L .5072 .63969 L F
.50052 .59398 m .50651 .6334 L .5057 .62941 L F
.50314 .59416 m .50079 .594 L .48196 .57637 L .65 .463 .618 r
F
.48192 .57611 m .48196 .57637 L .47936 .57393 L F
.50314 .59416 m .48196 .57637 L .48192 .57611 L F
.50038 .60346 m .49244 .58888 L .50052 .59398 L .784 .572 .613 r
F
.49344 .59072 m .50038 .60346 L .51071 .66075 L .732 .556 .654 r
F
.49344 .59072 m .51071 .66075 L .51071 .66076 L F
.49987 .63914 m .50052 .59398 L .5072 .63969 L .784 .572 .613 r
F
.50811 .56538 m .51575 .57205 L .51674 .58935 L .65 .463 .618 r
F
.51905 .60769 m .5154 .59331 L .52008 .59652 L .732 .552 .648 r
F
.5154 .59331 m .51674 .58935 L .52008 .59652 L F
.51817 .6172 m .51614 .60521 L .51905 .60769 L F
.50811 .56538 m .51674 .58935 L .5147 .59537 L .65 .463 .618 r
F
.51614 .60521 m .51159 .5783 L .51905 .60769 L .732 .552 .648 r
F
.5147 .59537 m .51674 .58935 L .51793 .61004 L .65 .463 .618 r
F
.5154 .59331 m .51159 .5783 L .51674 .58935 L .732 .552 .648 r
F
.4814 .55535 m .46468 .54583 L .48106 .5495 L .608 .314 .444 r
F
.47103 .55794 m .46468 .54583 L .48413 .55691 L F
.47644 .54978 m .4815 .55712 L .47936 .57393 L .65 .463 .618 r
F
.4815 .55712 m .51244 .60206 L .48263 .57671 L F
.4815 .55712 m .48263 .57671 L .47936 .57393 L F
.48413 .55691 m .4814 .55535 L .48443 .55026 L .608 .314 .444 r
F
.4814 .55535 m .48106 .5495 L .48443 .55026 L F
.49169 .57193 m .49932 .56889 L .50718 .5877 L .65 .463 .618 r
F
.49932 .56889 m .50717 .56576 L .50717 .57507 L F
.49932 .56889 m .50717 .57507 L .50718 .5877 L F
.4845 .58229 m .49244 .58888 L .48074 .5807 L .732 .556 .654 r
F
.49244 .58888 m .49291 .58975 L .48074 .5807 L F
.49841 .59384 m .49861 .5948 L .48074 .5807 L F
.48416 .55694 m .4847 .54483 L .49678 .56688 L .608 .314 .444 r
F
.47962 .52788 m .49349 .54138 L .49104 .54234 L .523 .324 .553 r
F
.47975 .52778 m .49358 .54134 L .47962 .52788 L F
.49358 .54134 m .51093 .55837 L .49349 .54138 L F
.49358 .54134 m .49349 .54138 L .47962 .52788 L F
.4815 .55712 m .48474 .55739 L .49169 .57193 L .65 .463 .618 r
F
.4847 .54483 m .48967 .54288 L .49678 .56688 L .608 .314 .444 r
F
.50289 .56083 m .50326 .55757 L .52104 .57666 L .543 .31 .512 r
F
.50037 .56333 m .49648 .56585 L .50018 .55424 L F
.49678 .56688 m .49648 .56585 L .50037 .56333 L F
.50326 .55757 m .51093 .55837 L .51158 .56315 L F
.50326 .55757 m .51816 .56757 L .51077 .56519 L F
.51616 .57142 m .50326 .55757 L .51647 .57097 L F
.50466 .55908 m .5152 .56256 L .49169 .57193 L .65 .463 .618 r
F
.50072 .58018 m .50018 .55424 L .50326 .55757 L .543 .31 .512 r
F
.49104 .54234 m .51093 .55837 L .50192 .55612 L .523 .324 .553 r
F
.49349 .54138 m .51093 .55837 L .49104 .54234 L F
.47867 .52864 m .50192 .55612 L .47845 .53074 L F
.47854 .52864 m .47116 .52845 L .47886 .52848 L 0 0 0 r
F
.47043 .52907 m .47116 .52845 L .47854 .52864 L F
.46279 .53509 m .47507 .52883 L .478 .53501 L .455 .123 .313 r
F
.47507 .52883 m .47867 .52864 L .478 .53501 L F
.44628 .53746 m .46672 .54581 L .44087 .5405 L F
.46672 .54581 m .46934 .54688 L .46468 .54583 L F
.46672 .54581 m .46468 .54583 L .44087 .5405 L F
.46648 .56072 m .4627 .54585 L .46666 .54985 L .68 .316 .35 r
F
.4627 .54585 m .46468 .54583 L .46666 .54985 L F
.46429 .55709 m .46216 .54586 L .46648 .56072 L F
.46216 .54586 m .4627 .54585 L .46648 .56072 L F
.46429 .55709 m .45026 .54442 L .46216 .54586 L F
.46934 .54688 m .47644 .54978 L .46147 .54587 L .455 .123 .313 r
F
.46468 .54583 m .46147 .54587 L .44087 .5405 L F
.46934 .54688 m .46147 .54587 L .46468 .54583 L F
.46216 .54586 m .46058 .53753 L .4627 .54585 L .68 .316 .35 r
F
.4627 .54585 m .46058 .53753 L .46468 .54583 L F
.44627 .54082 m .45864 .53163 L .46058 .53753 L 0 0 0 r
F
.43795 .54201 m .45036 .54451 L .43703 .54238 L .627 .339 .461 r
F
.45036 .54451 m .47644 .54978 L .45088 .54498 L F
.45036 .54451 m .45088 .54498 L .43703 .54238 L F
.46081 .5457 m .45026 .54442 L .43824 .54197 L .455 .123 .313 r
F
.46216 .54586 m .45026 .54442 L .46058 .53753 L .68 .316 .35 r
F
.43824 .54197 m .47644 .54978 L .43795 .54201 L .627 .339 .461 r
F
.45026 .54442 m .43736 .54287 L .44627 .54082 L .68 .316 .35 r
F
.45026 .54442 m .44627 .54082 L .46058 .53753 L F
.43736 .54287 m .43937 .5418 L .44627 .54082 L 0 0 0 r
F
.43937 .5418 m .45864 .53163 L .44627 .54082 L F
.43497 .54338 m .42942 .54407 L .43695 .54251 L F
.42996 .54386 m .4215 .54475 L .43463 .54341 L .124 .673 .727 r
F
.42996 .54386 m .43463 .54341 L .43436 .54343 L F
.42131 .54432 m .44072 .53519 L .43599 .5415 L .067 0 0 r
F
.39689 .54825 m .44072 .53519 L .41671 .5452 L F
.38907 .54929 m .42431 .54344 L .38531 .54366 L F
.42747 .54292 m .43599 .5415 L .38531 .54366 L F
.41671 .5452 m .43599 .5415 L .38907 .54929 L F
.38531 .54366 m .43638 .54276 L .43497 .54338 L .462 0 .036 r
F
.43259 .54358 m .42996 .54386 L .43436 .54343 L .124 .673 .727 r
F
.38531 .54366 m .43497 .54338 L .4267 .54407 L .462 0 .036 r
F
.37323 .54896 m .38907 .54929 L .38531 .54366 L .615 .938 .956 r
F
.3759 .54993 m .38907 .54929 L .37323 .54896 L F
.35527 .54616 m .34967 .54529 L .37592 .55105 L .164 .683 .886 r
F
.36474 .54764 m .38531 .54366 L .36599 .54555 L .317 .806 .849 r
F
.37323 .54896 m .38531 .54366 L .36474 .54764 L .615 .938 .956 r
F
.36275 .54514 m .33928 .54301 L .37768 .55058 L .164 .683 .886 r
F
.3459 .54302 m .38811 .54032 L .34336 .54263 L .317 .806 .849 r
F
.37309 .54387 m .38811 .54032 L .3459 .54302 L F
.37859 .55063 m .38907 .54929 L .37039 .5502 L .615 .938 .956 r
F
.42285 .54473 m .42437 .54469 L .42613 .54446 L .124 .673 .727 r
F
.42613 .54446 m .41995 .54496 L .3969 .5558 L .549 .93 .848 r
F
.38531 .54366 m .42325 .54403 L .40089 .54621 L .462 0 .036 r
F
.42325 .54403 m .41742 .54484 L .40089 .54621 L F
.41742 .54484 m .39471 .54839 L .42285 .54473 L .124 .673 .727 r
F
.39471 .54839 m .39183 .54891 L .42285 .54473 L F
.38824 .5494 m .39232 .54887 L .42285 .54473 L F
.40387 .54671 m .38659 .54965 L .41742 .54484 L F
.38979 .55037 m .39689 .54825 L .41671 .5452 L .067 0 0 r
F
.38979 .55037 m .41671 .5452 L .38907 .54929 L F
.40387 .54671 m .37592 .55105 L .38659 .54965 L .124 .673 .727 r
F
.40089 .54621 m .41223 .54556 L .40918 .54598 L .462 0 .036 r
F
.42579 .54468 m .42613 .54446 L .3969 .5558 L .549 .93 .848 r
F
.40207 .55975 m .42579 .54468 L .3969 .5558 L F
.40089 .54621 m .43313 .5453 L .40573 .547 L .462 0 .036 r
F
.42325 .54403 m .4267 .54407 L .41742 .54484 L F
.4145 .5449 m .41742 .54484 L .43371 .54346 L .124 .673 .727 r
F
.41742 .54484 m .41934 .5448 L .43118 .5437 L F
.41742 .54484 m .43118 .5437 L .43371 .54346 L F
.41934 .5448 m .4215 .54475 L .43371 .54346 L F
.4215 .54475 m .42285 .54473 L .42613 .54446 L F
.4215 .54475 m .42634 .54445 L .43528 .54334 L F
.4267 .54407 m .43632 .54416 L .40089 .54621 L .462 0 .036 r
F
.38531 .54366 m .43599 .5415 L .43638 .54276 L F
.38531 .54366 m .40391 .5467 L .38811 .54032 L F
.40391 .5467 m .4089 .54579 L .38811 .54032 L F
.4089 .54579 m .40976 .54547 L .38811 .54032 L F
.39736 .54702 m .39761 .54751 L .40903 .54574 L .164 .683 .886 r
F
.38811 .54032 m .40976 .54547 L .39983 .54578 L .643 .215 .214 r
F
.38657 .54819 m .40903 .54574 L .40978 .54546 L .164 .683 .886 r
F
.41529 .54488 m .40387 .54671 L .41742 .54484 L .124 .673 .727 r
F
.4145 .5449 m .41218 .5453 L .41529 .54488 L F
.41218 .5453 m .40387 .54671 L .41529 .54488 L F
.41218 .5453 m .39851 .54745 L .40387 .54671 L F
.4145 .5449 m .41125 .54542 L .41218 .5453 L F
.41125 .54542 m .39851 .54745 L .41218 .5453 L F
.40976 .54547 m .40903 .54574 L .41111 .54542 L .164 .683 .886 r
F
.39619 .54409 m .39983 .54578 L .39872 .54382 L .643 .215 .214 r
F
.39983 .54578 m .40324 .54408 L .4021 .54347 L F
.39872 .54382 m .4021 .54347 L .39695 .54069 L F
.39983 .54578 m .4021 .54347 L .39872 .54382 L F
.39417 .54314 m .39619 .54409 L .3964 .54315 L F
.39417 .54314 m .3964 .54315 L .39695 .54069 L F
.38811 .54032 m .39417 .54314 L .39695 .54069 L F
.39619 .54409 m .39872 .54382 L .39695 .54069 L F
.40502 .54316 m .405 .54317 L .40525 .54317 L .264 .671 .967 r
F
.40701 .54406 m .39923 .54479 L .40978 .54546 L .164 .683 .886 r
F
.4018 .5441 m .39923 .54479 L .40701 .54406 L F
.39923 .54479 m .3894 .54786 L .40978 .54546 L F
.40976 .54547 m .41016 .54556 L .39983 .54578 L .643 .215 .214 r
F
.40456 .54659 m .40612 .54685 L .4089 .54579 L .462 0 .036 r
F
.40391 .5467 m .40612 .54685 L .40456 .54659 L F
.40391 .5467 m .40573 .547 L .40612 .54685 L F
.40918 .54598 m .43632 .54416 L .43313 .5453 L F
.41223 .54556 m .43632 .54416 L .40918 .54598 L F
.40573 .547 m .43313 .5453 L .42125 .54954 L F
.43632 .54416 m .43619 .54438 L .42125 .54954 L F
.44177 .55428 m .43232 .55136 L .43605 .54464 L .745 .291 .174 r
F
.43605 .54464 m .43614 .5444 L .46969 .58559 L F
.46738 .57339 m .43671 .5442 L .46651 .5688 L .68 .316 .35 r
F
.43671 .5442 m .4357 .54325 L .43682 .54417 L F
.43671 .5442 m .43682 .54417 L .46651 .5688 L F
.43632 .54416 m .43682 .54417 L .43619 .54438 L .462 0 .036 r
F
.45952 .5731 m .43528 .54334 L .46738 .57339 L .68 .316 .35 r
F
.43232 .55136 m .43682 .54417 L .43942 .55252 L .462 0 .036 r
F
.42125 .54954 m .43619 .54438 L .43232 .55136 L F
.43619 .54438 m .43682 .54417 L .43232 .55136 L F
.45251 .57236 m .42918 .55701 L .44822 .56514 L .745 .291 .174 r
F
.4383 .56461 m .42918 .55701 L .45251 .57236 L F
.37768 .55058 m .37859 .55063 L .4145 .5449 L .164 .683 .886 r
F
.4089 .54579 m .42781 .54996 L .41016 .54556 L .462 0 .036 r
F
.42781 .54996 m .42499 .54909 L .41016 .54556 L F
.40573 .547 m .43232 .55136 L .4089 .54579 L F
.43232 .55136 m .42781 .54996 L .4089 .54579 L F
.41016 .54556 m .42499 .54909 L .40363 .54643 L .643 .215 .214 r
F
.41908 .54835 m .4198 .54918 L .40363 .54643 L F
.4089 .54579 m .41016 .54556 L .40976 .54547 L .462 0 .036 r
F
.41016 .54556 m .40363 .54643 L .39983 .54578 L .643 .215 .214 r
F
.43058 .55449 m .42547 .55141 L .43605 .54464 L .745 .291 .174 r
F
.39851 .54745 m .37592 .55105 L .40387 .54671 L .124 .673 .727 r
F
.40175 .54668 m .42192 .5498 L .42691 .5584 L .643 .215 .214 r
F
.42192 .5498 m .42524 .55032 L .42639 .55586 L F
.42192 .5498 m .42639 .55586 L .42691 .5584 L F
.44111 .57265 m .43094 .56205 L .45077 .57835 L .679 .139 0 r
F
.43094 .56205 m .42896 .55936 L .45077 .57835 L F
.42896 .55936 m .42639 .55586 L .43237 .56138 L F
.42896 .55936 m .43237 .56138 L .45077 .57835 L F
.42918 .55701 m .43058 .55449 L .44822 .56514 L .745 .291 .174 r
F
.44822 .56514 m .43058 .55449 L .43232 .55136 L F
.44822 .56514 m .43232 .55136 L .44177 .55428 L F
.42499 .54909 m .42519 .5501 L .4198 .54918 L .643 .215 .214 r
F
.42499 .54909 m .4198 .54918 L .41908 .54835 L F
.40363 .54643 m .42519 .5501 L .40175 .54668 L F
.42519 .5501 m .42524 .55032 L .40175 .54668 L F
.42609 .55442 m .4145 .5449 L .41466 .54489 L .745 .291 .174 r
F
.45734 .5805 m .45058 .57488 L .45055 .57484 L F
.45734 .5805 m .4383 .56461 L .45251 .57236 L F
.45348 .57995 m .47069 .59647 L .45542 .58417 L .797 .547 .561 r
F
.45309 .57911 m .4548 .58073 L .45348 .57995 L F
.4548 .58073 m .47059 .5957 L .45348 .57995 L F
.45077 .57835 m .4145 .5449 L .45734 .5805 L .745 .291 .174 r
F
.45281 .5785 m .45363 .57929 L .45309 .57911 L .797 .547 .561 r
F
.45363 .57929 m .47059 .5957 L .45309 .57911 L F
.45962 .59333 m .47012 .60302 L .47261 .61833 L F
.45962 .59333 m .47387 .62076 L .47038 .61678 L F
.42612 .55455 m .4145 .5449 L .42609 .55442 L .745 .291 .174 r
F
.45055 .57484 m .42612 .55455 L .42609 .55442 L F
.45058 .57488 m .42612 .55455 L .45055 .57484 L F
.42691 .5584 m .43942 .55252 L .44813 .56829 L .643 .215 .214 r
F
.42547 .55141 m .4241 .54478 L .43605 .54464 L .745 .291 .174 r
F
.42918 .55701 m .42609 .55442 L .43058 .55449 L F
.42609 .55442 m .42547 .55141 L .43058 .55449 L F
.42524 .55032 m .43942 .55252 L .42691 .5584 L .643 .215 .214 r
F
.42691 .5584 m .42896 .55936 L .40189 .54476 L F
.42896 .55936 m .4192 .55357 L .40189 .54476 L F
.43094 .56205 m .4145 .5449 L .42639 .55586 L .679 .139 0 r
F
.42758 .55854 m .41842 .55223 L .4145 .5449 L F
.40052 .5434 m .40324 .54408 L .4018 .5441 L .749 .348 .291 r
F
.40052 .5434 m .4018 .5441 L .40136 .54404 L F
.39695 .54069 m .4021 .54347 L .40052 .5434 L F
.4021 .54347 m .40324 .54408 L .40052 .5434 L F
.40052 .5434 m .40136 .54404 L .40386 .54316 L F
.40525 .54317 m .40386 .54316 L .4018 .5441 L .164 .683 .886 r
F
.39695 .54069 m .40052 .5434 L .40386 .54316 L .749 .348 .291 r
F
.40386 .54316 m .39406 .54314 L .40136 .54404 L .164 .683 .886 r
F
.40386 .54316 m .40136 .54404 L .4018 .5441 L F
.40447 .54295 m .40386 .54316 L .40493 .54309 L .749 .348 .291 r
F
.39695 .54069 m .40386 .54316 L .40447 .54295 L F
.40525 .54317 m .4018 .5441 L .40701 .54406 L .164 .683 .886 r
F
.4018 .5441 m .40124 .54408 L .39923 .54479 L F
.42079 .55451 m .4205 .55423 L .4192 .55357 L .643 .215 .214 r
F
.42896 .55936 m .4205 .55423 L .42079 .55451 L F
.40649 .54408 m .40525 .54317 L .41842 .55223 L .679 .139 0 r
F
.41851 .55232 m .41842 .55223 L .42758 .55854 L F
.40649 .54408 m .41842 .55223 L .41851 .55232 L F
.40189 .54476 m .42359 .5558 L .40324 .54408 L .643 .215 .214 r
F
.42359 .5558 m .41851 .55232 L .40324 .54408 L F
.40324 .54408 m .41851 .55232 L .40143 .5441 L .749 .348 .291 r
F
.42359 .5558 m .44813 .56829 L .41851 .55232 L .643 .215 .214 r
F
.41851 .55232 m .41993 .55368 L .40143 .5441 L .749 .348 .291 r
F
.42896 .55936 m .44813 .56829 L .4205 .55423 L .643 .215 .214 r
F
.39983 .54578 m .40363 .54643 L .40175 .54668 L F
.39983 .54578 m .42691 .5584 L .40189 .54476 L F
.40143 .5441 m .41993 .55368 L .44218 .57505 L .749 .348 .291 r
F
.42919 .56022 m .40649 .54408 L .42758 .55854 L .679 .139 0 r
F
.43094 .56205 m .42317 .55634 L .42919 .56022 L F
.42317 .55634 m .40649 .54408 L .42919 .56022 L F
.37722 .54445 m .38531 .54366 L .37309 .54387 L .317 .806 .849 r
F
.39406 .54314 m .35702 .54305 L .4018 .5441 L .164 .683 .886 r
F
.40136 .54404 m .4018 .5441 L .40143 .5441 L .749 .348 .291 r
F
.40136 .54404 m .4099 .55053 L .40386 .54316 L F
.4099 .55053 m .42878 .56487 L .40915 .54777 L F
.4099 .55053 m .40915 .54777 L .40386 .54316 L F
.40978 .54546 m .40976 .54547 L .4145 .5449 L .164 .683 .886 r
F
.40976 .54547 m .41111 .54542 L .4145 .5449 L F
.41232 .54449 m .40978 .54546 L .4145 .5449 L F
.40525 .54317 m .40978 .54546 L .41232 .54449 L F
.41842 .55223 m .40525 .54317 L .40988 .54403 L .679 .139 0 r
F
.4377 .56984 m .40525 .54317 L .43094 .56205 L F
.40603 .54325 m .40782 .54288 L .40587 .5431 L 0 .222 .744 r
F
.4086 .54575 m .40814 .54405 L .40603 .54325 L F
.40814 .54405 m .40782 .54288 L .40603 .54325 L F
.36504 .54273 m .405 .54317 L .40502 .54316 L .264 .671 .967 r
F
.4055 .54311 m .36504 .54273 L .40502 .54316 L F
.35272 .54246 m .38811 .54032 L .39695 .54069 L .024 0 0 r
F
.34383 .54296 m .34336 .54263 L .33928 .54301 L .264 .671 .967 r
F
.34336 .54263 m .33915 .5427 L .33928 .54301 L F
.34336 .54263 m .38811 .54032 L .35272 .54246 L .024 0 0 r
F
.3459 .54302 m .34336 .54263 L .34349 .54272 L .317 .806 .849 r
F
.36599 .54555 m .37309 .54387 L .3459 .54302 L F
.36599 .54555 m .37722 .54445 L .37309 .54387 L F
.39923 .54479 m .35702 .54305 L .37768 .55058 L .164 .683 .886 r
F
.34383 .54296 m .33928 .54301 L .3459 .54302 L .264 .671 .967 r
F
.3459 .54302 m .33928 .54301 L .36275 .54514 L .164 .683 .886 r
F
.35527 .54616 m .33928 .54301 L .34967 .54529 L F
.36599 .54555 m .34293 .54265 L .32526 .54356 L .317 .806 .849 r
F
.35345 .54286 m .33725 .53835 L .34383 .54296 L .264 .671 .967 r
F
.35272 .54246 m .39695 .54069 L .33779 .53429 L .024 0 0 r
F
.34254 .53503 m .39695 .54069 L .40493 .54309 L .269 0 0 r
F
.39083 .54246 m .34601 .53879 L .35345 .54286 L .264 .671 .967 r
F
.34601 .53879 m .33725 .53835 L .35345 .54286 L F
.36401 .5397 m .33533 .53391 L .33725 .53835 L F
.37727 .54037 m .35144 .5364 L .36401 .5397 L F
.35144 .5364 m .33533 .53391 L .36401 .5397 L F
.3947 .54222 m .40075 .5429 L .39923 .54283 L .269 0 0 r
F
.35272 .54246 m .33817 .5345 L .33221 .53369 L .024 0 0 r
F
.33814 .53449 m .33779 .53429 L .33221 .53369 L F
.33221 .53369 m .40075 .5429 L .3947 .54222 L .269 0 0 r
F
.33221 .53369 m .40493 .54309 L .40075 .5429 L F
.33779 .53429 m .39695 .54069 L .34254 .53503 L F
.39627 .5427 m .36504 .54273 L .4055 .54311 L .264 .671 .967 r
F
.39083 .54246 m .37513 .54263 L .39627 .5427 L F
.37513 .54263 m .36504 .54273 L .39627 .5427 L F
.33221 .53369 m .3508 .53623 L .35144 .5364 L .269 0 0 r
F
.40459 .54311 m .40895 .54703 L .40493 .54309 L .749 .348 .291 r
F
.40895 .54703 m .40885 .54666 L .40493 .54309 L F
.41123 .54858 m .40525 .54317 L .44111 .57265 L .679 .139 0 r
F
.40895 .54703 m .42878 .56487 L .40885 .54666 L .749 .348 .291 r
F
.40401 .54329 m .42878 .56487 L .40459 .54311 L F
.45491 .58217 m .46682 .60881 L .45906 .58916 L .797 .547 .561 r
F
.46682 .60881 m .46618 .60653 L .45906 .58916 L F
.45348 .57995 m .47038 .61678 L .45491 .58217 L F
.47038 .61678 m .47036 .61609 L .45906 .58916 L F
.47038 .61678 m .47387 .62076 L .47453 .62582 L F
.47344 .62343 m .47209 .62011 L .45906 .58916 L F
.4626 .59133 m .45637 .58443 L .46247 .58915 L .679 .139 0 r
F
.46269 .59285 m .46016 .59031 L .4626 .59133 L F
.46016 .59031 m .45637 .58443 L .4626 .59133 L F
.44903 .5809 m .41123 .54858 L .44111 .57265 L F
.41252 .54972 m .41123 .54858 L .44903 .5809 L F
.42878 .56487 m .44218 .57505 L .41205 .54932 L .749 .348 .291 r
F
.40883 .54662 m .40525 .54317 L .41205 .54932 L 0 .222 .744 r
F
.41061 .54811 m .41205 .54932 L .41036 .54788 L .749 .348 .291 r
F
.42878 .56487 m .41205 .54932 L .41061 .54811 L F
.45858 .58105 m .47059 .5957 L .45281 .5785 L .797 .547 .561 r
F
.46247 .58915 m .45491 .58217 L .45734 .5805 L .745 .291 .174 r
F
.45309 .57911 m .45348 .57995 L .45491 .58217 L .797 .547 .561 r
F
.45491 .58217 m .45077 .57835 L .45309 .57911 L .745 .291 .174 r
F
.45491 .58217 m .45309 .57911 L .45734 .5805 L F
.44111 .57265 m .45077 .57835 L .45491 .58217 L .679 .139 0 r
F
.45637 .58443 m .45491 .58217 L .46247 .58915 L F
.45491 .58217 m .45906 .58916 L .45839 .58757 L .797 .547 .561 r
F
.44111 .57265 m .45491 .58217 L .45637 .58443 L .679 .139 0 r
F
.45309 .57911 m .45491 .58217 L .45674 .58364 L .797 .547 .561 r
F
.45491 .58217 m .45839 .58757 L .45674 .58364 L F
.45674 .58364 m .45934 .58963 L .45807 .58602 L F
.45934 .58963 m .46403 .60042 L .46008 .59088 L F
.45934 .58963 m .46008 .59088 L .45807 .58602 L F
.46532 .60346 m .4645 .6005 L .46247 .58915 L .787 .521 0 r
F
.46532 .60346 m .46277 .59063 L .46736 .60847 L F
.46403 .60042 m .46495 .60253 L .45807 .58602 L .797 .547 .561 r
F
.46277 .59063 m .46286 .59065 L .4674 .60858 L .787 .521 0 r
F
.46277 .59063 m .4674 .60858 L .46736 .60847 L F
.47261 .61833 m .47174 .60452 L .47387 .62076 L .797 .547 .561 r
F
.47012 .60302 m .47174 .60452 L .47261 .61833 L F
.47564 .6233 m .46323 .58877 L .4714 .59647 L .957 .664 .437 r
F
.47312 .61968 m .46323 .58877 L .47564 .6233 L F
.46896 .61235 m .46323 .58877 L .47696 .63169 L F
.47696 .63169 m .47312 .61968 L .47564 .6233 L F
.4714 .59647 m .4727 .59777 L .47932 .62451 L F
.48498 .62897 m .47601 .60352 L .47647 .60202 L .859 .611 .562 r
F
.48498 .62897 m .47647 .60202 L .48261 .60897 L F
.475 .60006 m .47647 .60202 L .47362 .59868 L .722 .458 .527 r
F
.475 .60006 m .47362 .59868 L .45858 .58105 L F
.47647 .60202 m .467 .59132 L .45858 .58105 L F
.485 .62963 m .46969 .58559 L .48498 .62897 L .859 .611 .562 r
F
.48544 .64925 m .47932 .62451 L .485 .62963 L F
.47932 .62451 m .46969 .58559 L .485 .62963 L F
.485 .62963 m .49631 .64568 L .48617 .64817 L .803 .643 .683 r
F
.48664 .63111 m .49631 .64568 L .485 .62963 L F
.46486 .57518 m .48096 .58731 L .48074 .58805 L .722 .458 .527 r
F
.46774 .57692 m .48096 .58731 L .46486 .57518 L F
.4433 .55771 m .48074 .58805 L .44958 .5661 L F
.46305 .57323 m .48031 .58182 L .48096 .58731 L F
.48498 .62897 m .47961 .58361 L .48436 .60121 L .859 .611 .562 r
F
.48388 .61193 m .485 .62963 L .48446 .64744 L .803 .643 .683 r
F
.485 .62963 m .48541 .63616 L .4852 .63863 L F
.485 .62963 m .4852 .63863 L .48446 .64744 L F
.48436 .60121 m .47961 .58361 L .48391 .5954 L .859 .611 .562 r
F
.49631 .64568 m .48707 .60225 L .49978 .64483 L .784 .572 .613 r
F
.48707 .60225 m .49234 .61744 L .49978 .64483 L F
.49885 .64375 m .51067 .66074 L .50819 .66359 L .803 .643 .683 r
F
.50576 .6518 m .51067 .66074 L .49885 .64375 L F
.48664 .63111 m .48498 .62897 L .48436 .60121 L .859 .611 .562 r
F
.48391 .5954 m .48707 .60225 L .49631 .64568 L F
.49569 .64475 m .49631 .64568 L .49955 .66092 L F
.48391 .5954 m .49631 .64568 L .49569 .64475 L F
.48486 .62743 m .50819 .66359 L .48493 .62854 L .803 .643 .683 r
F
.49885 .64375 m .50819 .66359 L .48486 .62743 L F
.49955 .66092 m .49978 .64483 L .50936 .65953 L .784 .572 .613 r
F
.49978 .64483 m .49987 .63914 L .50576 .6518 L F
.49978 .64483 m .50576 .6518 L .50936 .65953 L F
.48388 .61193 m .49885 .64375 L .48486 .62743 L .803 .643 .683 r
F
.49753 .64093 m .50576 .6518 L .49885 .64375 L F
.48388 .61193 m .50202 .64498 L .49753 .64093 L F
.50202 .64498 m .50576 .6518 L .49753 .64093 L F
.48917 .66433 m .48507 .6297 L .48664 .63111 L .859 .611 .562 r
F
.48507 .6297 m .48498 .62897 L .48664 .63111 L F
.48238 .6558 m .48274 .64713 L .48545 .65439 L .957 .664 .437 r
F
.48546 .65601 m .4875 .67973 L .48546 .65859 L .803 .643 .683 r
F
.48546 .65859 m .48545 .65439 L .48782 .66071 L .957 .664 .437 r
F
.48238 .6558 m .48545 .65439 L .48546 .65859 L F
.47696 .63169 m .48536 .65165 L .48917 .66433 L F
.48541 .63616 m .48546 .65859 L .48446 .64744 L .803 .643 .683 r
F
.48917 .66433 m .48544 .64925 L .48498 .62897 L .859 .611 .562 r
F
.48493 .62854 m .48664 .63111 L .485 .62963 L .803 .643 .683 r
F
.47453 .62582 m .48388 .61193 L .48446 .64744 L .797 .547 .561 r
F
.47601 .60352 m .46969 .58559 L .4803 .58947 L .859 .611 .562 r
F
.47059 .5957 m .48388 .61193 L .47453 .62582 L .797 .547 .561 r
F
.46896 .61235 m .46851 .61074 L .46865 .61105 L .957 .664 .437 r
F
.46851 .61074 m .46247 .58915 L .46865 .61105 L F
.46865 .61105 m .46247 .58915 L .46323 .58877 L F
.4674 .60858 m .46247 .58915 L .46896 .61235 L F
.46495 .60253 m .48446 .64744 L .46112 .5931 L .797 .547 .561 r
F
.46495 .60253 m .46112 .5931 L .45807 .58602 L F
.47402 .6247 m .48446 .64744 L .45674 .58364 L F
.46005 .59126 m .46413 .59975 L .46243 .59809 L .872 .635 .576 r
F
.46413 .59975 m .4645 .6005 L .46243 .59809 L F
.46243 .59809 m .4645 .6005 L .46614 .60877 L F
.45965 .5901 m .46614 .60877 L .46299 .60472 L F
.46682 .60881 m .47038 .61678 L .46618 .60653 L .797 .547 .561 r
F
.47038 .61678 m .47344 .62343 L .47036 .61609 L F
.47344 .62343 m .47402 .6247 L .47209 .62011 L F
.4805 .65411 m .46896 .61235 L .47696 .63169 L .957 .664 .437 r
F
.47857 .65184 m .46896 .61235 L .4805 .65411 L F
.46736 .60847 m .4674 .60858 L .46855 .61311 L .787 .521 0 r
F
.45965 .5901 m .46026 .5914 L .46005 .59126 L .872 .635 .576 r
F
.46026 .5914 m .4645 .6005 L .46005 .59126 L F
.47989 .67136 m .48211 .68644 L .47529 .70058 L .874 .745 .717 r
F
.48228 .6562 m .48214 .68086 L .47989 .67136 L F
.48214 .68086 m .48211 .68644 L .47989 .67136 L F
.48203 .65719 m .47529 .70058 L .47461 .68703 L F
.48228 .6562 m .48211 .6573 L .48203 .65719 L F
.48211 .6573 m .47529 .70058 L .48203 .65719 L F
.4777 .65062 m .46668 .61028 L .47748 .64831 L .787 .521 0 r
F
.47461 .68703 m .47529 .70058 L .46695 .71784 L .874 .745 .717 r
F
.46695 .71784 m .48211 .68644 L .46199 .73779 L F
.48198 .66537 m .46199 .73779 L .48191 .66703 L F
.48199 .66408 m .46199 .73779 L .48198 .66537 L F
.48228 .6562 m .46199 .73779 L .48204 .66389 L F
.48382 .65802 m .48211 .68644 L .48228 .6562 L F
.48304 .67024 m .48198 .66587 L .48204 .66389 L .957 .664 .437 r
F
.48446 .64744 m .48382 .65802 L .48228 .6562 L .874 .745 .717 r
F
.48238 .6558 m .48228 .6562 L .48204 .66389 L F
.4875 .67973 m .48743 .6792 L .48546 .65859 L .803 .643 .683 r
F
.47361 .74583 m .51016 .66133 L .51063 .66126 L .872 .767 .743 r
F
.47361 .74583 m .51063 .66126 L .50351 .68194 L F
.47361 .74583 m .49052 .705 L .49066 .7064 L F
.49488 .65427 m .50094 .66585 L .48857 .68612 L .803 .643 .683 r
F
.50094 .66585 m .50292 .66964 L .49362 .68032 L F
.50094 .66585 m .49362 .68032 L .48857 .68612 L F
.48857 .68612 m .4888 .68985 L .48785 .68024 L F
.4888 .68985 m .49362 .68032 L .4894 .69415 L .935 .84 .726 r
F
.50721 .66472 m .49955 .66092 L .50936 .65953 L .872 .767 .743 r
F
.4825 .72437 m .49465 .67913 L .50721 .66472 L F
.49465 .67913 m .49955 .66092 L .50721 .66472 L F
.51016 .66133 m .51055 .66088 L .51063 .66126 L F
.49066 .7064 m .50936 .65953 L .51048 .66057 L F
.49052 .705 m .50936 .65953 L .49066 .7064 L F
.51055 .66088 m .51067 .66074 L .51078 .66084 L F
.48021 .72421 m .49955 .66092 L .4825 .72437 L F
.51067 .66074 m .51073 .66087 L .48857 .68612 L .803 .643 .683 r
F
.48843 .68713 m .49955 .66092 L .49362 .68032 L .935 .84 .726 r
F
.48843 .68713 m .49362 .68032 L .4888 .68985 L F
.48046 .72014 m .48362 .72444 L .47717 .72401 L .839 .839 .846 r
F
.47917 .72166 m .476 .72537 L .46471 .74096 L F
.46672 .73829 m .46471 .74096 L .46415 .74173 L F
.47917 .72166 m .46471 .74096 L .46672 .73829 L F
.46672 .73829 m .48733 .67839 L .48843 .68713 L .935 .84 .726 r
F
.46672 .73829 m .48305 .6845 L .48733 .67839 L F
.48743 .6792 m .48706 .67621 L .48546 .65859 L .803 .643 .683 r
F
.48815 .68203 m .48785 .68024 L .4873 .67462 L F
.48815 .68203 m .4873 .67462 L .48743 .67511 L F
.48305 .6845 m .49348 .66291 L .49955 .66092 L .935 .84 .726 r
F
.48765 .68146 m .48731 .679 L .48706 .67621 L .803 .643 .683 r
F
.48765 .68146 m .48706 .67621 L .48743 .6792 L F
.48706 .67621 m .48917 .66433 L .49348 .66291 L .935 .84 .726 r
F
.47984 .69225 m .48211 .68644 L .46471 .74096 L .964 .935 .627 r
F
.48638 .67119 m .46471 .74096 L .46459 .74112 L F
.46471 .74096 m .48211 .68644 L .46672 .73829 L .935 .84 .726 r
F
.48211 .68644 m .48305 .6845 L .46672 .73829 L F
.46672 .73829 m .47653 .71519 L .47543 .72665 L F
.47653 .71519 m .48021 .72421 L .47361 .74583 L F
.48211 .68644 m .49001 .70894 L .46199 .73779 L .874 .745 .717 r
F
.48688 .67428 m .48706 .67621 L .48211 .68644 L F
.48706 .67621 m .49001 .70894 L .48211 .68644 L F
.48211 .68644 m .48917 .66433 L .48305 .6845 L .935 .84 .726 r
F
.48305 .6845 m .48662 .67275 L .48706 .67621 L F
.48662 .67275 m .48917 .66433 L .48706 .67621 L F
.48304 .67024 m .48204 .66389 L .48917 .66433 L .957 .664 .437 r
F
.48204 .66389 m .4805 .65411 L .48236 .6563 L F
.48204 .66389 m .48236 .6563 L .48917 .66433 L F
.48139 .67922 m .48304 .67024 L .48499 .66926 L .964 .935 .627 r
F
.46564 .60813 m .46614 .60877 L .47386 .64774 L .872 .635 .576 r
F
.46902 .7135 m .48074 .6773 L .48139 .67922 L .964 .935 .627 r
F
.46912 .71292 m .48074 .6773 L .46902 .7135 L F
.47883 .67964 m .47048 .70829 L .47716 .68642 L .874 .745 .717 r
F
.47807 .68089 m .47048 .70829 L .47883 .67964 L F
.4796 .67834 m .48043 .67638 L .47773 .68487 L 0 0 0 r
F
.48043 .67638 m .48061 .67693 L .47773 .68487 L F
.48043 .67638 m .48304 .67024 L .48061 .67693 L F
.4768 .68762 m .48242 .67197 L .46812 .71602 L .964 .935 .627 r
F
.48242 .67197 m .48304 .67024 L .48247 .67198 L F
.48242 .67197 m .48247 .67198 L .46812 .71602 L F
.46812 .71602 m .46912 .71292 L .46902 .7135 L F
.48194 .67079 m .48197 .66603 L .48304 .67024 L .787 .521 0 r
F
.45626 .75069 m .45429 .75412 L .37678 .80217 L .799 .946 .92 r
F
.45806 .74953 m .45649 .75143 L .45626 .75069 L F
.45649 .75143 m .45429 .75412 L .45626 .75069 L F
.47917 .72166 m .45736 .7508 L .45926 .74875 L .839 .839 .846 r
F
.45835 .74973 m .45429 .75412 L .45806 .74953 L .799 .946 .92 r
F
.45799 .74948 m .44188 .75992 L .44295 .75812 L F
.45805 .74953 m .3746 .80351 L .45799 .74948 L F
.45805 .74953 m .37678 .80217 L .37671 .80216 L F
.45806 .74953 m .37678 .80217 L .45805 .74953 L F
.45945 .7468 m .4588 .74912 L .45835 .74973 L .964 .935 .627 r
F
.45805 .74953 m .37461 .80351 L .3746 .80351 L .799 .946 .92 r
F
.45805 .74953 m .37461 .80351 L .45805 .74953 L F
.45799 .74949 m .45835 .74973 L .45641 .75241 L .964 .935 .627 r
F
.40997 .77708 m .3746 .80351 L .36272 .80423 L .799 .946 .92 r
F
.44295 .75812 m .39749 .78831 L .40997 .77708 L F
.39749 .78831 m .3746 .80351 L .40997 .77708 L F
.44188 .75992 m .3746 .80351 L .44295 .75812 L F
.45776 .74974 m .36983 .80015 L .3925 .79132 L F
.45776 .74974 m .3925 .79132 L .41713 .77639 L F
.37647 .80104 m .38534 .79566 L .37786 .8014 L 0 0 0 r
F
.38534 .79566 m .40757 .78218 L .38526 .79662 L F
.38534 .79566 m .38526 .79662 L .37786 .8014 L F
.36321 .80395 m .36366 .80394 L .36372 .80392 L .799 .946 .92 r
F
.3746 .80351 m .37429 .80371 L .36272 .80423 L F
.36198 .80466 m .37429 .80371 L .35549 .80839 L F
.36419 .80414 m .37421 .80492 L .36499 .8041 L .342 0 0 r
F
.36321 .80395 m .37421 .80492 L .36419 .80414 L .407 0 0 r
F
.36258 .80382 m .36375 .80393 L .36321 .80395 L F
.3746 .80351 m .37461 .80351 L .37429 .80371 L .799 .946 .92 r
F
.36499 .8041 m .37421 .80492 L .38406 .80294 L .342 0 0 r
F
.36375 .80393 m .37421 .80492 L .36321 .80395 L .407 0 0 r
F
.36429 .80416 m .36544 .80439 L .36198 .80466 L .799 .946 .92 r
F
.36712 .80425 m .36787 .80625 L .37421 .80492 L .407 0 0 r
F
.36375 .80393 m .3647 .80446 L .36712 .80425 L F
.3647 .80446 m .36787 .80625 L .36712 .80425 L F
.36272 .80423 m .36401 .80475 L .3661 .80386 L .799 .946 .92 r
F
.36366 .80394 m .3661 .80386 L .37253 .80112 L F
.36272 .80423 m .3661 .80386 L .36366 .80394 L F
.36983 .80015 m .37081 .80015 L .37202 .79929 L F
.38137 .80039 m .44168 .76149 L .44232 .76111 L .486 .876 .693 r
F
.44055 .76275 m .44232 .76111 L .45493 .7536 L F
.38137 .80039 m .44232 .76111 L .44055 .76275 L F
.45799 .74948 m .36983 .80015 L .45776 .74974 L .799 .946 .92 r
F
.45945 .7468 m .46459 .74112 L .4588 .74912 L .964 .935 .627 r
F
.49001 .70894 m .48362 .72444 L .48046 .72014 L .839 .839 .846 r
F
.49001 .70894 m .47917 .72166 L .45926 .74875 L F
.46242 .73733 m .49001 .70894 L .45926 .74875 L .874 .745 .717 r
F
.45739 .74907 m .48638 .67119 L .47974 .6925 L .964 .935 .627 r
F
.45739 .74907 m .47974 .6925 L .4577 .74873 L F
.46812 .71602 m .48549 .66788 L .48638 .67119 L F
.45561 .74782 m .48638 .67119 L .45739 .74907 L F
.38137 .80039 m .45493 .7536 L .45445 .75399 L .486 .876 .693 r
F
.45801 .74945 m .45835 .74973 L .45799 .74949 L .964 .935 .627 r
F
.45877 .74862 m .45835 .74973 L .45801 .74945 L F
.45586 .75183 m .41713 .77639 L .4532 .75424 L .799 .946 .92 r
F
.45776 .74974 m .41713 .77639 L .45586 .75183 L F
.41713 .77639 m .44084 .76202 L .4532 .75424 L F
.42541 .77065 m .45005 .75597 L .43013 .76851 L 0 0 0 r
F
.45005 .75597 m .45039 .75584 L .37786 .8014 L F
.44168 .76149 m .4532 .75424 L .45406 .75375 L .486 .876 .693 r
F
.45495 .75331 m .45406 .75375 L .45641 .75241 L F
.44168 .76149 m .45406 .75375 L .45495 .75331 L F
.40757 .78218 m .43013 .76851 L .37786 .8014 L 0 0 0 r
F
.44168 .76149 m .45641 .75241 L .45493 .7536 L .486 .876 .693 r
F
.45556 .74685 m .45369 .7538 L .4532 .75424 L .936 .882 .757 r
F
.44168 .76149 m .45055 .75577 L .4532 .75424 L .486 .876 .693 r
F
.37786 .8014 m .43267 .76697 L .37914 .80174 L 0 0 0 r
F
.43267 .76697 m .44012 .76245 L .37914 .80174 L F
.45039 .75584 m .45051 .75579 L .37914 .80174 L F
.38137 .80039 m .45704 .75235 L .44211 .76198 L .486 .876 .693 r
F
.45556 .74685 m .45242 .75469 L .44774 .75689 L .936 .882 .757 r
F
.38127 .80037 m .45051 .75579 L .38137 .80039 L .486 .876 .693 r
F
.45051 .75579 m .45055 .75577 L .38137 .80039 L F
.4532 .75424 m .44084 .76202 L .45226 .75509 L .799 .946 .92 r
F
.45242 .75469 m .45226 .75509 L .45051 .75579 L .936 .882 .757 r
F
.45242 .75469 m .45051 .75579 L .44774 .75689 L F
.45051 .75579 m .45241 .75457 L .45055 .75577 L .486 .876 .693 r
F
.45226 .75509 m .3971 .78953 L .4272 .77781 L .799 .946 .92 r
F
.44084 .76202 m .3971 .78953 L .45226 .75509 L F
.43267 .76697 m .45039 .75584 L .44012 .76245 L 0 0 0 r
F
.4532 .75424 m .45241 .75457 L .45431 .75354 L .486 .876 .693 r
F
.45055 .75577 m .45241 .75457 L .4532 .75424 L F
.45242 .75469 m .4532 .75424 L .45226 .75509 L .936 .882 .757 r
F
.45556 .74685 m .4532 .75424 L .45242 .75469 L F
.4107 .7806 m .3971 .78953 L .41617 .77753 L .799 .946 .92 r
F
.4107 .7806 m .41617 .77753 L .44084 .76202 L F
.41713 .77639 m .4107 .7806 L .44084 .76202 L F
.42541 .77065 m .43013 .76851 L .40757 .78218 L 0 0 0 r
F
.38548 .79405 m .38534 .79566 L .4272 .77781 L .799 .946 .92 r
F
.36795 .80123 m .36349 .80379 L .37253 .80112 L F
.36349 .80379 m .36372 .80392 L .37253 .80112 L F
.36983 .80015 m .36795 .80123 L .37477 .80017 L F
.36795 .80123 m .37253 .80112 L .37477 .80017 L F
.38534 .79566 m .3647 .80446 L .36497 .80427 L .571 .935 .92 r
F
.38534 .79566 m .36497 .80427 L .38544 .79444 L F
.37502 .80065 m .42387 .77156 L .40757 .78218 L 0 0 0 r
F
.42387 .77156 m .42541 .77065 L .42432 .77135 L F
.42387 .77156 m .42432 .77135 L .40757 .78218 L F
.42387 .77156 m .43376 .76765 L .45002 .756 L F
.41713 .77639 m .3925 .79132 L .3971 .78953 L .799 .946 .92 r
F
.38544 .79444 m .41737 .77674 L .42387 .77156 L 0 0 0 r
F
.42224 .77286 m .43376 .76765 L .42387 .77156 L F
.41737 .77674 m .43054 .76944 L .42224 .77286 L F
.43054 .76944 m .43376 .76765 L .42224 .77286 L F
.42387 .77156 m .45002 .756 L .45003 .75599 L F
.43632 .76144 m .43848 .76058 L .43536 .76535 L .936 .882 .757 r
F
.37502 .80065 m .40757 .78218 L .37647 .80104 L 0 0 0 r
F
.38974 .79238 m .43376 .76765 L .38544 .79444 L F
.39258 .79102 m .43345 .76787 L .38989 .79231 L F
.39163 .79198 m .38534 .79566 L .38544 .79444 L .571 .935 .92 r
F
.4272 .77781 m .38544 .79444 L .40986 .78272 L F
.43345 .76787 m .43376 .76765 L .37502 .80065 L 0 0 0 r
F
.3963 .78724 m .40324 .78355 L .39258 .79102 L .308 0 .029 r
F
.40324 .78355 m .41389 .77868 L .39258 .79102 L F
.43061 .76901 m .43253 .76824 L .39258 .79102 L F
.43253 .76824 m .43345 .76787 L .43108 .76921 L F
.43253 .76824 m .43108 .76921 L .39258 .79102 L F
.43323 .76699 m .43392 .76754 L .43226 .76873 L .936 .882 .757 r
F
.43323 .76699 m .43253 .76824 L .43357 .76701 L F
.43253 .76824 m .43226 .76873 L .43273 .7681 L F
.43253 .76824 m .43273 .7681 L .43357 .76701 L F
.40324 .78355 m .43061 .76901 L .41389 .77868 L .308 0 .029 r
F
.40324 .78355 m .42268 .77513 L .43061 .76901 L F
.3963 .78724 m .40272 .7843 L .40324 .78355 L F
.40272 .7843 m .42268 .77513 L .40324 .78355 L F
.43226 .76873 m .43345 .76787 L .4272 .77781 L .936 .882 .757 r
F
.43345 .76787 m .43379 .76774 L .4272 .77781 L F
.45487 .73554 m .44169 .76467 L .4272 .77781 L F
.42925 .77413 m .4272 .77781 L .4301 .77379 L F
.42925 .77413 m .4301 .77379 L .4344 .76785 L F
.43226 .76873 m .42925 .77413 L .4344 .76785 L F
.4272 .77781 m .38994 .7937 L .39163 .79198 L .571 .935 .92 r
F
.4272 .77781 m .42145 .77944 L .41175 .78924 L F
.4272 .77781 m .41175 .78924 L .41461 .78831 L F
.42145 .77944 m .4091 .78451 L .40356 .79753 L F
.38544 .79444 m .36497 .80427 L .37991 .79373 L F
.36272 .80423 m .36429 .80416 L .36198 .80466 L .799 .946 .92 r
F
.36272 .80423 m .35549 .80839 L .36401 .80475 L F
.3647 .80446 m .35549 .80839 L .36133 .80476 L .571 .935 .92 r
F
.36349 .80379 m .36321 .80395 L .36372 .80392 L .799 .946 .92 r
F
.36321 .80395 m .36272 .80423 L .36366 .80394 L F
.27935 .796 m .35774 .80507 L .36375 .80393 L .407 0 0 r
F
.35276 .80551 m .35549 .80839 L .34043 .80843 L .571 .935 .92 r
F
.33968 .8071 m .34043 .80843 L .32842 .80846 L F
.35276 .80551 m .34043 .80843 L .33968 .8071 L F
.36133 .80476 m .35606 .80804 L .35276 .80551 L F
.27935 .796 m .36439 .80698 L .36787 .80625 L .407 0 0 r
F
.27158 .79527 m .28 .79633 L .27935 .796 L F
.28 .79633 m .36439 .80698 L .27935 .796 L F
.22745 .75197 m .27158 .79527 L .23111 .75412 L .742 .238 0 r
F
.20364 .72861 m .21009 .73493 L .21527 .73941 L F
.21009 .73493 m .22745 .75197 L .21527 .73941 L F
.21099 .73487 m .31163 .7942 L .2125 .73353 L .861 .43 .188 r
F
.21099 .73487 m .30524 .79687 L .31163 .7942 L F
.19057 .63127 m .21099 .73487 L .2125 .73353 L .933 .726 .246 r
F
.19057 .63127 m .20292 .72478 L .20364 .72861 L .734 .525 0 r
F
.26481 .78832 m .27158 .79527 L .26413 .78796 L .677 .176 0 r
F
.20292 .72478 m .24429 .76726 L .20364 .72861 L F
.24429 .76726 m .26481 .78832 L .24142 .76549 L F
.24429 .76726 m .24142 .76549 L .20364 .72861 L F
.26481 .78832 m .26413 .78796 L .20364 .72861 L F
.21966 .74197 m .26608 .79204 L .27158 .79527 L F
.27045 .79461 m .35227 .80514 L .27158 .79527 L .469 0 0 r
F
.29686 .79672 m .35227 .80514 L .27045 .79461 L F
.35276 .80551 m .32842 .80846 L .33158 .80738 L .571 .935 .92 r
F
.31894 .80849 m .32721 .80847 L .31712 .809 L F
.32721 .80847 m .35549 .80839 L .32724 .80884 L F
.32721 .80847 m .32724 .80884 L .31712 .809 L F
.26608 .79204 m .29686 .79672 L .27045 .79461 L .469 0 0 r
F
.2742 .79328 m .28235 .79516 L .28079 .79428 L F
.26608 .79204 m .27514 .79378 L .2742 .79328 L F
.27514 .79378 m .28235 .79516 L .2742 .79328 L F
.21558 .73827 m .26608 .79204 L .21966 .74197 L .677 .176 0 r
F
.20292 .72478 m .21558 .73827 L .21966 .74197 L F
.2125 .73353 m .31734 .7904 L .21382 .73134 L .869 .456 .238 r
F
.2125 .73353 m .31163 .7942 L .31734 .7904 L F
.19057 .63127 m .2125 .73353 L .21382 .73134 L .933 .727 .246 r
F
.24362 .76657 m .25809 .78298 L .24857 .77294 L .585 .101 0 r
F
.25809 .78298 m .26608 .79204 L .25698 .78235 L F
.25809 .78298 m .25698 .78235 L .20292 .72478 L F
.24362 .76657 m .26156 .78774 L .26608 .79204 L F
.20267 .72012 m .24362 .76657 L .20292 .72478 L F
.24362 .76657 m .24857 .77294 L .20292 .72478 L F
.21785 .73733 m .26156 .78774 L .24362 .76657 L F
.21382 .73134 m .32209 .7854 L .21489 .72829 L .875 .48 .282 r
F
.21382 .73134 m .31734 .7904 L .32209 .7854 L F
.19057 .63127 m .21382 .73134 L .21489 .72829 L .928 .72 .235 r
F
.21208 .72596 m .25834 .78223 L .26156 .78774 L 0 0 .528 r
F
.20301 .71463 m .20839 .72121 L .21208 .72596 L F
.20839 .72121 m .25834 .78223 L .21208 .72596 L F
.28079 .79428 m .28822 .79628 L .28676 .79519 L .469 0 0 r
F
.28235 .79516 m .28822 .79628 L .28079 .79428 L F
.35606 .80804 m .35549 .80839 L .35276 .80551 L .571 .935 .92 r
F
.32429 .80697 m .34861 .80552 L .31894 .80849 L F
.35227 .80514 m .35276 .80551 L .27158 .79527 L .469 0 0 r
F
.35774 .80507 m .3647 .80446 L .36375 .80393 L .407 0 0 r
F
.34861 .80552 m .36133 .80476 L .35134 .80564 L .571 .935 .92 r
F
.34861 .80552 m .35134 .80564 L .31894 .80849 L F
.28676 .79519 m .33977 .80596 L .35227 .80514 L .469 0 0 r
F
.38587 .78952 m .36172 .80452 L .35647 .80486 L .571 .935 .92 r
F
.35647 .80486 m .36133 .80476 L .32429 .80697 L F
.36172 .80452 m .36137 .80474 L .35647 .80486 L F
.36137 .80474 m .36133 .80476 L .35647 .80486 L F
.30523 .79953 m .35518 .80909 L .2975 .79737 L .469 0 0 r
F
.30523 .79953 m .2975 .79737 L .28676 .79519 L F
.28822 .79628 m .30523 .79953 L .28676 .79519 L F
.33867 .80532 m .33906 .806 L .3035 .7992 L .517 0 0 r
F
.30836 .79978 m .3035 .7992 L .26608 .79204 L F
.33867 .80532 m .3035 .7992 L .30836 .79978 L F
.26156 .78774 m .32086 .80126 L .26608 .79204 L F
.27114 .79036 m .29529 .79696 L .26985 .78963 L F
.32086 .80126 m .30836 .79978 L .26608 .79204 L F
.29529 .79696 m .32698 .80562 L .26985 .78963 L F
.32925 .80557 m .35647 .80486 L .32429 .80697 L .571 .935 .92 r
F
.32086 .80126 m .33867 .80532 L .30836 .79978 L .517 0 0 r
F
.26985 .78963 m .3273 .80562 L .33867 .80532 L F
.38587 .78952 m .35647 .80486 L .32925 .80557 L .571 .935 .92 r
F
.33748 .80323 m .32925 .80557 L .3456 .80419 L F
.32925 .80557 m .32703 .8062 L .33128 .80661 L F
.33977 .80596 m .35518 .80909 L .35227 .80514 L .469 0 0 r
F
.33867 .80532 m .33984 .80615 L .33906 .806 L .517 0 0 r
F
.33867 .80532 m .34033 .8065 L .3431 .80633 L F
.32703 .8062 m .33045 .80675 L .33128 .80661 L .571 .935 .92 r
F
.32925 .80557 m .34666 .81101 L .33867 .80532 L .517 0 0 r
F
.33158 .80738 m .32842 .80846 L .31894 .80849 L .571 .935 .92 r
F
.33128 .80661 m .31712 .809 L .33207 .80702 L F
.3273 .80562 m .33177 .80686 L .32925 .80557 L .517 0 0 r
F
.33177 .80686 m .34666 .81101 L .32925 .80557 L F
.33413 .80613 m .33128 .80661 L .33494 .80664 L .571 .935 .92 r
F
.33207 .80702 m .34666 .81101 L .33177 .80686 L .517 0 0 r
F
.33128 .80661 m .33207 .80702 L .33494 .80664 L .571 .935 .92 r
F
.32925 .80557 m .33128 .80661 L .3456 .80419 L F
.32698 .80562 m .3273 .80562 L .26985 .78963 L .517 0 0 r
F
.3269 .80457 m .33343 .80669 L .32698 .80562 L .539 0 0 r
F
.35995 .80177 m .3456 .80419 L .3554 .80392 L .571 .935 .92 r
F
.3456 .80419 m .33413 .80613 L .34895 .80459 L F
.3456 .80419 m .34895 .80459 L .3554 .80392 L F
.33748 .80323 m .3456 .80419 L .35995 .80177 L F
.33413 .80613 m .33494 .80664 L .3554 .80392 L F
.3647 .80446 m .36133 .80476 L .38587 .78952 L F
.35885 .80188 m .33494 .80664 L .34986 .80275 L .181 .715 .778 r
F
.36535 .80274 m .37395 .79893 L .36661 .8029 L .502 .096 .203 r
F
.36541 .80273 m .36858 .80172 L .37007 .80067 L F
.35227 .80514 m .36439 .80698 L .35276 .80551 L .469 0 0 r
F
.35227 .80514 m .35518 .80909 L .36439 .80698 L F
.35774 .80507 m .36787 .80625 L .3647 .80446 L .407 0 0 r
F
.38874 .79286 m .38544 .79444 L .38547 .7942 L .571 .935 .92 r
F
.38874 .79286 m .38547 .7942 L .38587 .78952 L F
.3963 .78724 m .42561 .77558 L .4296 .77195 L .308 0 .029 r
F
.43345 .76787 m .43392 .76754 L .43379 .76774 L .936 .882 .757 r
F
.44645 .75855 m .45226 .75509 L .44169 .76467 L F
.4435 .76067 m .44645 .75855 L .44169 .76467 L F
.43345 .76787 m .44418 .7618 L .43376 .76765 L 0 0 0 r
F
.43323 .76699 m .43536 .76535 L .43392 .76754 L .936 .882 .757 r
F
.45005 .75597 m .45226 .75509 L .44645 .75855 L F
.43376 .76765 m .44418 .7618 L .45005 .75597 L 0 0 0 r
F
.43253 .76824 m .44418 .7618 L .43345 .76787 L .308 0 .029 r
F
.43431 .76704 m .44418 .7618 L .43253 .76824 L F
.44271 .76258 m .43973 .7673 L .44418 .7618 L F
.43431 .76704 m .43936 .76728 L .44271 .76258 L F
.43936 .76728 m .43973 .7673 L .44271 .76258 L F
.43226 .76873 m .4344 .76785 L .43562 .76617 L .936 .882 .757 r
F
.43496 .76707 m .42816 .77649 L .42411 .77707 L .846 .987 .712 r
F
.42145 .77944 m .40986 .78272 L .4091 .78451 L .571 .935 .92 r
F
.43496 .76707 m .41132 .78885 L .41096 .78891 L .846 .987 .712 r
F
.43528 .77182 m .43655 .77123 L .3963 .78724 L .308 0 .029 r
F
.40986 .78272 m .38874 .79286 L .38705 .7909 L .571 .935 .92 r
F
.40232 .78486 m .38705 .7909 L .38587 .78952 L F
.40986 .78272 m .38705 .7909 L .40232 .78486 L F
.38544 .79444 m .37991 .79373 L .3857 .79143 L F
.35518 .80909 m .3963 .78724 L .36439 .80698 L .308 0 .029 r
F
.37569 .80058 m .39258 .79102 L .37502 .80065 L 0 0 0 r
F
.39258 .79102 m .38989 .79231 L .37502 .80065 L F
.37502 .80065 m .38974 .79238 L .38544 .79444 L F
.36439 .80698 m .37502 .80065 L .37421 .80492 L F
.37671 .80216 m .37678 .80217 L .37461 .80351 L .799 .946 .92 r
F
.37502 .80065 m .37914 .80174 L .37421 .80492 L 0 0 0 r
F
.36439 .80698 m .37569 .80058 L .37502 .80065 L F
.3963 .78724 m .39258 .79102 L .36439 .80698 L .308 0 .029 r
F
.38994 .7937 m .38534 .79566 L .39163 .79198 L .571 .935 .92 r
F
.40986 .78272 m .40232 .78486 L .39606 .79372 L F
.35518 .80909 m .3999 .78828 L .3963 .78724 L .308 0 .029 r
F
.40986 .78272 m .39606 .79372 L .40356 .79753 L .571 .935 .92 r
F
.40079 .78701 m .43528 .77182 L .40232 .78486 L .308 0 .029 r
F
.40441 .78618 m .43528 .77182 L .40079 .78701 L F
.3999 .78828 m .40441 .78618 L .40079 .78701 L F
.3999 .78828 m .40232 .78486 L .3963 .78724 L F
.3967 .78959 m .3999 .78828 L .39667 .78978 L .502 .096 .203 r
F
.3967 .78959 m .39667 .78978 L .35518 .80909 L F
.37395 .79893 m .3967 .78959 L .35518 .80909 L F
.39606 .79372 m .3967 .78959 L .39572 .79398 L .571 .935 .92 r
F
.3967 .78959 m .39722 .78631 L .39657 .78965 L F
.3967 .78959 m .39657 .78965 L .39572 .79398 L F
.40232 .78486 m .39722 .78631 L .39606 .79372 L F
.39722 .78631 m .38804 .7905 L .39572 .79398 L F
.3857 .79143 m .37991 .79373 L .38587 .78952 L F
.38587 .78952 m .37321 .7955 L .40356 .79753 L F
.37421 .80492 m .38127 .80037 L .38137 .80039 L .486 .876 .693 r
F
.38406 .80294 m .38466 .80297 L .38414 .80295 L .342 0 0 r
F
.38406 .80294 m .37421 .80492 L .38466 .80297 L F
.38421 .80294 m .38532 .80286 L .39578 .80107 L .292 0 0 r
F
.37421 .80492 m .38137 .80039 L .38466 .80297 L .486 .876 .693 r
F
.38137 .80039 m .38792 .80071 L .38466 .80297 L F
.37321 .7955 m .37449 .80139 L .40356 .79753 L .571 .935 .92 r
F
.38971 .79246 m .42299 .77723 L .3999 .78828 L .502 .096 .203 r
F
.37395 .79893 m .40109 .78692 L .38971 .79246 L F
.40109 .78692 m .42299 .77723 L .38971 .79246 L F
.43632 .76144 m .43536 .76535 L .43323 .76699 L .936 .882 .757 r
F
.43273 .7681 m .43562 .76617 L .44949 .74698 L F
.44402 .75953 m .44705 .75778 L .44645 .75855 L F
.44402 .75953 m .44645 .75855 L .4435 .76067 L F
.45487 .73554 m .44705 .75778 L .44402 .75953 L F
.44072 .76524 m .44949 .74698 L .44418 .7618 L .283 .063 .393 r
F
.45487 .73554 m .45556 .74685 L .44705 .75778 L .936 .882 .757 r
F
.45556 .74685 m .48638 .67119 L .45561 .74782 L .964 .935 .627 r
F
.46199 .73779 m .45926 .74875 L .47807 .68089 L .874 .745 .717 r
F
.46199 .73779 m .47807 .68089 L .47794 .68111 L F
.45652 .74326 m .48304 .67024 L .45566 .74646 L .964 .935 .627 r
F
.4641 .71157 m .4623 .71912 L .45446 .72887 L .936 .882 .757 r
F
.45556 .74685 m .4768 .68762 L .46812 .71602 L .964 .935 .627 r
F
.45526 .74758 m .45566 .74646 L .45556 .74685 L F
.45566 .74646 m .4768 .68762 L .45556 .74685 L F
.4623 .71912 m .45652 .74326 L .45487 .73554 L .936 .882 .757 r
F
.45652 .74326 m .45558 .74719 L .45556 .74685 L F
.45652 .74326 m .45556 .74685 L .45487 .73554 L F
.4623 .71912 m .45487 .73554 L .45446 .72887 L F
.44588 .7578 m .4623 .71912 L .45241 .75457 L 0 0 0 r
F
.48191 .66707 m .47716 .68642 L .48173 .67128 L .874 .745 .717 r
F
.4623 .71912 m .4796 .67834 L .45667 .74263 L 0 0 0 r
F
.4623 .71912 m .45667 .74263 L .45241 .75457 L F
.4796 .67834 m .47773 .68487 L .4778 .68431 L F
.48173 .67128 m .4796 .67834 L .48172 .67151 L .874 .745 .717 r
F
.4796 .67834 m .47716 .68642 L .47967 .67824 L F
.4796 .67834 m .47967 .67824 L .48172 .67151 L F
.4796 .67834 m .47716 .68642 L .45241 .75457 L 0 0 0 r
F
.4796 .67834 m .48136 .67541 L .48304 .67024 L F
.48074 .6773 m .48304 .67024 L .48139 .67922 L .964 .935 .627 r
F
.48136 .67541 m .45926 .74875 L .48064 .68189 L .874 .745 .717 r
F
.48183 .67116 m .47987 .6779 L .48136 .67541 L F
.47987 .6779 m .45926 .74875 L .48136 .67541 L F
.4778 .68431 m .47773 .68487 L .47716 .68642 L 0 0 0 r
F
.47048 .70829 m .45926 .74875 L .48183 .67116 L .874 .745 .717 r
F
.46967 .70281 m .47972 .67955 L .46943 .70334 L 0 0 0 r
F
.47972 .67955 m .48057 .6776 L .47972 .67956 L F
.48057 .6776 m .48057 .67758 L .47972 .67956 L F
.4623 .71912 m .48067 .6773 L .4796 .67834 L F
.48047 .67787 m .48136 .67541 L .48087 .67981 L .872 .635 .576 r
F
.48067 .6773 m .48192 .67448 L .48136 .67541 L 0 0 0 r
F
.48067 .6773 m .48136 .67541 L .4796 .67834 L F
.47794 .68111 m .47807 .68089 L .48195 .66693 L .874 .745 .717 r
F
.48195 .6669 m .48195 .66693 L .48253 .66483 L F
.47794 .68111 m .48195 .66693 L .48195 .6669 L F
.4805 .65411 m .48782 .66071 L .48917 .66433 L .957 .664 .437 r
F
.48238 .6558 m .48204 .66389 L .48253 .66483 L .874 .745 .717 r
F
.48204 .66389 m .48191 .66703 L .48195 .6669 L F
.48204 .66389 m .48195 .6669 L .48253 .66483 L F
.48198 .66587 m .47748 .64831 L .47721 .64627 L .957 .664 .437 r
F
.48304 .67024 m .48197 .66603 L .48198 .66587 L F
.48197 .66603 m .47748 .64831 L .48198 .66587 L F
.48191 .66707 m .47807 .68089 L .47883 .67964 L .874 .745 .717 r
F
.48253 .66483 m .48191 .66707 L .48183 .67116 L F
.48191 .66707 m .48172 .67151 L .48183 .67116 L F
.47117 .63281 m .48195 .67008 L .48136 .67541 L .872 .635 .576 r
F
.46943 .70334 m .48057 .67758 L .4623 .71912 L 0 0 0 r
F
.48057 .67758 m .48192 .67448 L .48067 .6773 L F
.48057 .67758 m .48067 .6773 L .4623 .71912 L F
.48006 .679 m .48087 .67981 L .48064 .68189 L .872 .635 .576 r
F
.48047 .67787 m .48087 .67981 L .48006 .679 L F
.48001 .67915 m .48005 .67902 L .48064 .68189 L F
.48005 .67902 m .48006 .679 L .48064 .68189 L F
.48001 .67915 m .48064 .68189 L .4802 .67887 L F
.48152 .67539 m .48051 .67976 L .48192 .67448 L 0 0 0 r
F
.47972 .67955 m .47972 .67956 L .46943 .70334 L F
.48064 .68189 m .45558 .74719 L .4623 .71912 L .936 .882 .757 r
F
.48064 .68189 m .4623 .71912 L .47265 .69622 L F
.45314 .74106 m .46704 .70995 L .47265 .69622 L 0 0 0 r
F
.46967 .70281 m .47265 .69622 L .47503 .69041 L F
.45314 .74106 m .47265 .69622 L .46967 .70281 L F
.47265 .69622 m .4623 .71912 L .4641 .71157 L .936 .882 .757 r
F
.45556 .74685 m .45586 .75183 L .45369 .7538 L F
.45241 .75457 m .45739 .74907 L .45693 .75065 L .964 .935 .627 r
F
.45241 .75457 m .45693 .75065 L .45431 .75354 L F
.45241 .75457 m .45526 .74758 L .45739 .74907 L F
.48064 .68189 m .45586 .75183 L .45558 .74719 L .936 .882 .757 r
F
.45739 .74907 m .45799 .74949 L .45641 .75241 L .964 .935 .627 r
F
.45926 .74875 m .45835 .74973 L .45806 .74953 L .799 .946 .92 r
F
.45926 .74875 m .45776 .74974 L .45586 .75183 L F
.45926 .74875 m .45805 .74953 L .45805 .74953 L F
.45926 .74875 m .45806 .74953 L .45805 .74953 L F
.45926 .74875 m .45805 .74953 L .45799 .74948 L F
.45926 .74875 m .45799 .74948 L .45776 .74974 L F
.45945 .7468 m .45877 .74862 L .45801 .74945 L .964 .935 .627 r
F
.45739 .74907 m .45945 .7468 L .45799 .74949 L F
.48064 .68189 m .45926 .74875 L .45586 .75183 L .936 .882 .757 r
F
.48064 .68189 m .47265 .69622 L .47412 .7129 L F
.47516 .69424 m .48064 .68189 L .47392 .69939 L .958 .74 .565 r
F
.44593 .75775 m .46967 .70281 L .44588 .7578 L 0 0 0 r
F
.46967 .70281 m .46943 .70334 L .44588 .7578 L F
.44588 .7578 m .46943 .70334 L .4623 .71912 L F
.45003 .75599 m .45002 .756 L .45005 .75597 L F
.44774 .75689 m .45005 .75597 L .44645 .75855 L .936 .882 .757 r
F
.45039 .75584 m .45241 .75457 L .45051 .75579 L 0 0 0 r
F
.45005 .75597 m .45241 .75457 L .45039 .75584 L F
.45005 .75597 m .44418 .7618 L .45241 .75457 L F
.44418 .7618 m .44588 .7578 L .45241 .75457 L F
.44418 .7618 m .45401 .73962 L .45314 .74106 L F
.4802 .67887 m .48064 .68189 L .48033 .68259 L .958 .74 .565 r
F
.47785 .68606 m .48033 .68259 L .47516 .69424 L F
.4802 .67887 m .48033 .68259 L .47785 .68606 L F
.4802 .67887 m .47516 .69424 L .4759 .69116 L F
.47265 .69622 m .45877 .73015 L .47412 .7129 L .936 .882 .757 r
F
.45401 .73962 m .46613 .71224 L .45314 .74106 L 0 0 0 r
F
.46613 .71224 m .48051 .67976 L .46525 .71394 L F
.46613 .71224 m .46525 .71394 L .45314 .74106 L F
.43273 .7681 m .44949 .74698 L .45056 .74475 L .936 .882 .757 r
F
.43226 .76873 m .43562 .76617 L .43273 .7681 L F
.44949 .74698 m .4657 .71321 L .45045 .74765 L .283 .063 .393 r
F
.45446 .72887 m .45487 .73554 L .43848 .76058 L .936 .882 .757 r
F
.45446 .72887 m .43848 .76058 L .43632 .76144 L F
.44535 .74522 m .43323 .76699 L .45078 .74429 L F
.45412 .73733 m .45078 .74429 L .46083 .73129 L F
.44535 .74522 m .45078 .74429 L .45412 .73733 L F
.43323 .76699 m .43357 .76701 L .46083 .73129 L F
.44901 .74664 m .43496 .76707 L .44419 .75243 L .846 .987 .712 r
F
.44853 .7463 m .44419 .75243 L .4482 .74607 L F
.44901 .74664 m .44419 .75243 L .44853 .7463 L F
.47265 .69622 m .44535 .74522 L .45877 .73015 L .936 .882 .757 r
F
.44535 .74522 m .46083 .73129 L .47412 .7129 L F
.4489 .74656 m .46468 .71297 L .4657 .71321 L .283 .063 .393 r
F
.44853 .7463 m .46991 .70183 L .4489 .74656 L F
.45056 .74475 m .44949 .74698 L .46083 .73129 L .936 .882 .757 r
F
.45594 .73806 m .44949 .74698 L .45813 .73337 L .846 .987 .712 r
F
.44949 .74698 m .43496 .76707 L .44901 .74664 L F
.43061 .76901 m .43431 .76704 L .43253 .76824 L .308 0 .029 r
F
.43061 .76901 m .43973 .7673 L .43431 .76704 L F
.42268 .77513 m .43973 .7673 L .43061 .76901 L F
.43825 .7677 m .4489 .74656 L .44072 .76524 L .283 .063 .393 r
F
.4489 .74656 m .4657 .71321 L .44949 .74698 L F
.4489 .74656 m .44949 .74698 L .44072 .76524 L F
.42582 .77461 m .42395 .77709 L .42299 .77723 L .846 .987 .712 r
F
.4482 .74607 m .42395 .77709 L .44761 .74566 L F
.4482 .74607 m .43496 .76707 L .42395 .77709 L F
.43555 .77167 m .43655 .77123 L .43573 .77161 L .502 .096 .203 r
F
.42299 .77723 m .43345 .77267 L .42395 .77709 L F
.42299 .77723 m .43646 .77136 L .43555 .77167 L F
.42299 .77723 m .42395 .77709 L .3999 .78828 L F
.40109 .78692 m .42283 .77738 L .42299 .77723 L F
.4012 .78692 m .42283 .77738 L .40109 .78692 L F
.42283 .77738 m .43646 .77136 L .42299 .77723 L F
.44761 .74566 m .42582 .77461 L .42193 .77738 L .846 .987 .712 r
F
.42582 .77461 m .42299 .77723 L .42193 .77738 L F
.37396 .79895 m .41138 .78797 L .42283 .77738 L .502 .096 .203 r
F
.42193 .77738 m .42395 .77709 L .41718 .78325 L .846 .987 .712 r
F
.3431 .80633 m .34666 .81101 L .35518 .80909 L .517 0 0 r
F
.34666 .81101 m .36535 .80274 L .35518 .80909 L .502 .096 .203 r
F
.36535 .80274 m .36661 .8029 L .35518 .80909 L F
.34666 .81101 m .4012 .78692 L .40109 .78692 L F
.36858 .80172 m .3936 .79378 L .37007 .80067 L F
.3936 .79378 m .39354 .79356 L .37007 .80067 L F
.4111 .78823 m .41138 .78797 L .37007 .80067 L F
.37007 .80067 m .37407 .79944 L .37396 .79895 L F
.41202 .78738 m .41718 .78325 L .41006 .78973 L .846 .987 .712 r
F
.42411 .77707 m .4272 .77781 L .41132 .78885 L F
.41096 .78891 m .41132 .78885 L .41006 .78973 L F
.41461 .78831 m .41175 .78924 L .40356 .79753 L .571 .935 .92 r
F
.41006 .78973 m .4272 .77781 L .40356 .79753 L .846 .987 .712 r
F
.41202 .78738 m .41071 .78895 L .41468 .7875 L F
.41071 .78895 m .40356 .79753 L .41468 .7875 L F
.39606 .79372 m .39572 .79398 L .39583 .79403 L .571 .935 .92 r
F
.39606 .79372 m .39583 .79403 L .40356 .79753 L F
.41468 .7875 m .42874 .78264 L .41516 .78695 L .502 .096 .203 r
F
.4111 .78823 m .42874 .78264 L .41138 .78797 L F
.43825 .7677 m .44853 .7463 L .4489 .74656 L .283 .063 .393 r
F
.44853 .7463 m .46098 .72801 L .4617 .72616 L F
.46468 .71297 m .46991 .70183 L .46816 .70656 L F
.46468 .71297 m .46816 .70656 L .4657 .71321 L F
.46704 .70995 m .48051 .67976 L .47503 .69041 L 0 0 0 r
F
.46991 .70183 m .47677 .68756 L .46619 .71208 L .283 .063 .393 r
F
.46991 .70183 m .46619 .71208 L .4657 .71321 L F
.47677 .68756 m .47754 .68649 L .4657 .71321 L F
.46362 .71492 m .4617 .72616 L .47677 .68756 L F
.44853 .7463 m .4617 .72616 L .46362 .71492 L F
.45895 .73161 m .46098 .72801 L .44853 .7463 L F
.46098 .72801 m .47152 .70937 L .47366 .70047 L F
.47187 .70112 m .47366 .70047 L .4759 .69116 L F
.46098 .72801 m .47366 .70047 L .47187 .70112 L F
.47365 .70011 m .48064 .68189 L .47366 .70047 L .958 .74 .565 r
F
.47366 .70047 m .48064 .68189 L .47412 .7129 L F
.47366 .70047 m .47412 .7129 L .47513 .69994 L F
.46098 .72801 m .4759 .69116 L .47677 .68756 L .283 .063 .393 r
F
.47503 .69041 m .47857 .68355 L .481 .6766 L 0 0 0 r
F
.47033 .62992 m .48047 .67787 L .48006 .679 L .872 .635 .576 r
F
.46467 .60138 m .48446 .64744 L .4645 .6005 L .797 .547 .561 r
F
.4645 .6005 m .46785 .61677 L .46766 .61647 L .872 .635 .576 r
F
.46299 .60472 m .46564 .60813 L .48005 .67902 L F
.46299 .60472 m .48005 .67902 L .48001 .67915 L F
.46564 .60813 m .47386 .64774 L .48006 .679 L F
.46564 .60813 m .48006 .679 L .48005 .67902 L F
.47905 .67493 m .48001 .67915 L .47933 .6728 L F
.48001 .67915 m .4802 .67887 L .47933 .6728 L F
.4726 .64672 m .47905 .67493 L .47874 .67014 L F
.47117 .63281 m .48047 .67787 L .47033 .62992 L F
.47117 .63281 m .48136 .67541 L .48047 .67787 L F
.47905 .67493 m .47933 .6728 L .47856 .66747 L F
.47186 .64639 m .4802 .67887 L .47614 .69047 L .958 .74 .565 r
F
.4726 .64672 m .47874 .67014 L .47713 .6625 L .872 .635 .576 r
F
.4726 .64672 m .47856 .66747 L .47239 .64256 L F
.46766 .61647 m .47117 .63281 L .47033 .62992 L F
.46785 .61677 m .47117 .63281 L .46766 .61647 L F
.4784 .65781 m .47524 .64688 L .4777 .65062 L .787 .521 0 r
F
.4819 .66992 m .48187 .66978 L .4819 .6699 L F
.48187 .66978 m .47748 .64831 L .4819 .6699 L F
.4819 .6699 m .47748 .64831 L .48197 .66603 L F
.47983 .66277 m .47748 .64831 L .4819 .66992 L F
.48136 .67541 m .48192 .67448 L .48254 .67213 L 0 0 0 r
F
.48136 .67541 m .48254 .67213 L .48304 .67024 L F
.4818 .6749 m .48197 .66603 L .48192 .67448 L .787 .521 0 r
F
.48204 .66389 m .48199 .66408 L .48198 .66537 L .874 .745 .717 r
F
.48204 .66389 m .47857 .65184 L .4805 .65411 L .957 .664 .437 r
F
.48198 .66587 m .47857 .65184 L .48204 .66389 L F
.47342 .64413 m .46668 .61028 L .4777 .65062 L .787 .521 0 r
F
.47117 .63281 m .4645 .6005 L .46532 .60346 L F
.46668 .61028 m .46532 .60346 L .46855 .61311 L F
.46532 .60346 m .46736 .60847 L .46855 .61311 L F
.46668 .61028 m .46855 .61311 L .47748 .64831 L F
.481 .6766 m .48051 .67976 L .48152 .67539 L 0 0 0 r
F
.47857 .68355 m .48051 .67976 L .481 .6766 L F
.48057 .6776 m .48192 .67448 L .48057 .67758 L F
.48051 .67976 m .47748 .64831 L .4818 .6749 L .787 .521 0 r
F
.4805 .65411 m .48274 .64713 L .48238 .6558 L .957 .664 .437 r
F
.48446 .64744 m .48238 .6558 L .48253 .66483 L .874 .745 .717 r
F
.47721 .64627 m .4674 .60858 L .46896 .61235 L .957 .664 .437 r
F
.47748 .64831 m .4674 .60858 L .47721 .64627 L F
.4645 .6005 m .48446 .64744 L .48195 .67008 L .872 .635 .576 r
F
.4645 .6005 m .48195 .67008 L .47117 .63281 L F
.46016 .59031 m .4645 .6005 L .45965 .5901 L F
.45974 .59021 m .4726 .64672 L .47207 .63838 L F
.45965 .5901 m .4726 .64672 L .45974 .59021 L F
.46 .59054 m .45308 .58189 L .45637 .58443 L .679 .139 0 r
F
.46125 .5921 m .47207 .63838 L .46316 .59588 L .872 .635 .576 r
F
.45974 .59021 m .47207 .63838 L .46125 .5921 L F
.4569 .58982 m .45827 .59054 L .46316 .59588 L .83 .438 .308 r
F
.45827 .59054 m .46125 .5921 L .46202 .59363 L F
.45827 .59054 m .46202 .59363 L .46316 .59588 L F
.45354 .58665 m .41123 .54858 L .45664 .58885 L .679 .139 0 r
F
.45404 .58707 m .46316 .59588 L .4507 .58432 L .83 .438 .308 r
F
.45235 .58581 m .4507 .58432 L .45354 .58665 L .679 .139 0 r
F
.4507 .58432 m .41123 .54858 L .45354 .58665 L F
.40493 .54309 m .40885 .54666 L .40528 .54319 L .749 .348 .291 r
F
.40885 .54666 m .42878 .56487 L .40878 .54642 L F
.40883 .54662 m .40587 .5431 L .40525 .54317 L 0 .222 .744 r
F
.40885 .54666 m .40878 .54642 L .40528 .54319 L .749 .348 .291 r
F
.40957 .54732 m .40878 .54642 L .40883 .54662 L 0 .222 .744 r
F
.40878 .54642 m .40587 .5431 L .40883 .54662 L F
.43733 .57403 m .40883 .54662 L .45053 .58418 L F
.4507 .58432 m .46316 .59588 L .4375 .57421 L .83 .438 .308 r
F
.4507 .58432 m .4375 .57421 L .43733 .57403 L F
.40883 .54662 m .41205 .54932 L .45603 .58914 L 0 .222 .744 r
F
.46 .59054 m .45637 .58443 L .46158 .59251 L .679 .139 0 r
F
.46284 .59531 m .44111 .57265 L .45308 .58189 L F
.46284 .59531 m .45308 .58189 L .46 .59054 L F
.45807 .58602 m .45945 .58923 L .45916 .58796 L .797 .547 .561 r
F
.4086 .54575 m .40587 .5431 L .40878 .54642 L 0 .222 .744 r
F
.45734 .5805 m .44822 .56514 L .46929 .58578 L .745 .291 .174 r
F
.44813 .56829 m .45858 .58105 L .45281 .5785 L .797 .547 .561 r
F
.44813 .56829 m .45309 .57911 L .45674 .58364 L F
.44218 .57505 m .44813 .56829 L .45916 .58796 L .749 .348 .291 r
F
.44111 .57265 m .4377 .56984 L .43094 .56205 L .679 .139 0 r
F
.41993 .55368 m .44813 .56829 L .44218 .57505 L .749 .348 .291 r
F
.41036 .54788 m .43159 .56532 L .40867 .54601 L F
.43159 .56532 m .43139 .56488 L .40867 .54601 L F
.40878 .54642 m .40867 .54601 L .40528 .54319 L F
.41036 .54788 m .40867 .54601 L .40878 .54642 L F
.44218 .57505 m .45916 .58796 L .41036 .54788 L F
.45664 .58885 m .41252 .54972 L .44903 .5809 L .679 .139 0 r
F
.41851 .55232 m .44813 .56829 L .41993 .55368 L .749 .348 .291 r
F
.41842 .55223 m .40988 .54403 L .4145 .5449 L .679 .139 0 r
F
.40528 .54319 m .45916 .58796 L .41016 .54466 L .749 .348 .291 r
F
.42308 .56032 m .4086 .54575 L .40957 .54732 L 0 .222 .744 r
F
.43733 .57403 m .42287 .5598 L .42308 .56032 L F
.42287 .5598 m .4086 .54575 L .42308 .56032 L F
.43581 .57242 m .4086 .54575 L .43733 .57403 L F
.43159 .56532 m .45916 .58796 L .43139 .56488 L .749 .348 .291 r
F
.43361 .57007 m .4086 .54575 L .43366 .57012 L 0 .222 .744 r
F
.42241 .55797 m .45314 .5862 L .43733 .57403 L .83 .438 .308 r
F
.42241 .55797 m .43733 .57403 L .43022 .56646 L F
.42607 .56004 m .45314 .5862 L .42241 .55797 L F
.46123 .59424 m .46316 .59588 L .46371 .59945 L F
.46364 .5998 m .46371 .59945 L .4654 .60755 L .07 .081 .562 r
F
.46364 .5998 m .46371 .59945 L .46383 .60025 L .83 .438 .308 r
F
.46123 .59424 m .46371 .59945 L .46364 .5998 L F
.46473 .60597 m .46364 .5998 L .4654 .60755 L .07 .081 .562 r
F
.46364 .5998 m .46284 .59531 L .46371 .59945 L F
.46772 .61626 m .46592 .60905 L .4645 .6005 L .787 .521 0 r
F
.47342 .64413 m .46641 .61135 L .46772 .61626 L F
.46641 .61135 m .46592 .60905 L .46772 .61626 L F
.46592 .60905 m .46302 .59522 L .4645 .6005 L F
.47342 .64413 m .4645 .6005 L .47117 .63281 L F
.46504 .60522 m .46278 .59437 L .46523 .60582 L F
.47221 .63905 m .46592 .60905 L .47342 .64413 L F
.4645 .6005 m .4631 .59551 L .46277 .59213 L F
.4645 .6005 m .46277 .59213 L .46247 .58915 L F
.46316 .59588 m .47207 .63838 L .47029 .61002 L .872 .635 .576 r
F
.46592 .60905 m .46278 .59437 L .46302 .59522 L .787 .521 0 r
F
.47099 .63391 m .46504 .60522 L .46592 .60905 L F
.47239 .64256 m .47605 .65732 L .47221 .63905 L .872 .635 .576 r
F
.4726 .64672 m .47101 .61503 L .47029 .61002 L F
.47231 .64026 m .46544 .60775 L .46504 .60522 L .787 .521 0 r
F
.47641 .65999 m .47194 .63871 L .47231 .64026 L F
.47194 .63871 m .46544 .60775 L .47231 .64026 L F
.46544 .60775 m .46469 .60417 L .46479 .60448 L F
.46544 .60775 m .46479 .60448 L .46504 .60522 L F
.47941 .67334 m .4802 .67887 L .47765 .66631 L .958 .74 .565 r
F
.4779 .66663 m .47765 .66631 L .47593 .65787 L F
.47941 .67334 m .47765 .66631 L .4779 .66663 L F
.47713 .6625 m .47874 .67014 L .47856 .66747 L .872 .635 .576 r
F
.4779 .66663 m .47605 .65732 L .47856 .66747 L .787 .521 0 r
F
.47593 .65787 m .46469 .60417 L .47609 .65856 L F
.47609 .65856 m .46544 .60775 L .47641 .65999 L F
.47872 .66768 m .47342 .64413 L .47902 .66805 L F
.47902 .66805 m .47342 .64413 L .47524 .64688 L F
.47982 .67254 m .47524 .64688 L .4784 .65781 L F
.47605 .65732 m .47221 .63905 L .47342 .64413 L F
.47605 .65732 m .47342 .64413 L .47982 .67254 L F
.47221 .63905 m .47856 .66747 L .47101 .61503 L .872 .635 .576 r
F
.47605 .65732 m .47856 .66747 L .47221 .63905 L F
.47888 .67155 m .47099 .63391 L .47221 .63905 L .787 .521 0 r
F
.47888 .67155 m .47221 .63905 L .47605 .65732 L F
.47868 .67093 m .47099 .63391 L .47888 .67155 L F
.47807 .66403 m .47856 .66747 L .47593 .65787 L .958 .74 .565 r
F
.47856 .66747 m .47941 .67334 L .4779 .66663 L F
.47856 .66747 m .4779 .66663 L .47593 .65787 L F
.47982 .67254 m .47872 .66768 L .47902 .66805 L .787 .521 0 r
F
.48051 .67976 m .4779 .66663 L .47982 .67254 L F
.4779 .66663 m .47856 .66747 L .47982 .67254 L F
.47882 .67167 m .47593 .65787 L .47886 .67177 L F
.47593 .65787 m .47609 .65856 L .47886 .67177 L F
.47593 .65787 m .4802 .67887 L .47161 .6454 L .958 .74 .565 r
F
.46504 .60522 m .46284 .59531 L .46283 .59459 L .787 .521 0 r
F
.46473 .60597 m .46496 .60588 L .46364 .5998 L .07 .081 .562 r
F
.46469 .60417 m .46284 .59531 L .46504 .60522 L .787 .521 0 r
F
.46496 .60588 m .46608 .60543 L .46383 .60025 L .07 .081 .562 r
F
.46496 .60588 m .46383 .60025 L .46364 .5998 L F
.4375 .57421 m .4642 .60264 L .46433 .60354 L .83 .438 .308 r
F
.46429 .60349 m .46433 .60354 L .46429 .60348 L F
.4375 .57421 m .46123 .59424 L .4642 .60264 L F
.45252 .58836 m .43733 .57403 L .45603 .58914 L 0 .222 .744 r
F
.44079 .57736 m .43733 .57403 L .45252 .58836 L F
.43684 .57365 m .4375 .57421 L .46433 .60354 L .83 .438 .308 r
F
.44751 .58525 m .46429 .60349 L .4583 .59541 L F
.43733 .57403 m .45053 .58418 L .45603 .58914 L 0 .222 .744 r
F
.46284 .59531 m .46 .59054 L .46278 .59437 L .679 .139 0 r
F
.46 .59054 m .46158 .59251 L .46278 .59437 L F
.45916 .58796 m .46016 .59031 L .45972 .59013 L .872 .635 .576 r
F
.45916 .58796 m .45974 .59021 L .46125 .5921 L F
.45916 .58796 m .45972 .59013 L .45965 .5901 L F
.45916 .58796 m .45965 .5901 L .45974 .59021 L F
.41016 .54466 m .45916 .58796 L .46125 .5921 L .83 .438 .308 r
F
.45827 .59054 m .45354 .58665 L .45664 .58885 L .679 .139 0 r
F
.41016 .54466 m .46125 .5921 L .4569 .58982 L .83 .438 .308 r
F
.44565 .58237 m .4583 .59541 L .45431 .59004 L F
.46429 .60349 m .46429 .60348 L .45833 .59545 L F
.45831 .59543 m .45833 .59545 L .45433 .59006 L F
.46429 .60349 m .45833 .59545 L .45831 .59543 L F
.46429 .60349 m .45433 .59006 L .45431 .59004 L F
.46123 .59424 m .46383 .60025 L .4642 .60264 L F
.46284 .59541 m .45312 .58892 L .46284 .59531 L 0 .222 .744 r
F
.46288 .59808 m .45723 .59278 L .46284 .59541 L F
.45723 .59278 m .45312 .58892 L .46284 .59541 L F
.47029 .61002 m .47807 .66403 L .47593 .65787 L .958 .74 .565 r
F
.47099 .63391 m .46592 .60905 L .47221 .63905 L .787 .521 0 r
F
.47031 .63747 m .46653 .61436 L .47574 .65733 L .07 .081 .562 r
F
.46473 .60597 m .4654 .60755 L .47882 .67167 L F
.47029 .61002 m .47593 .65787 L .47131 .63728 L .958 .74 .565 r
F
.47029 .61002 m .47131 .63728 L .47492 .63548 L F
.47337 .61698 m .47492 .63548 L .48037 .63278 L F
.47029 .61002 m .47492 .63548 L .47337 .61698 L F
.46504 .60522 m .46523 .60582 L .46592 .60905 L .787 .521 0 r
F
.46798 .61887 m .46841 .61082 L .46608 .60543 L .07 .081 .562 r
F
.47031 .63747 m .46473 .60597 L .46653 .61436 L F
.47031 .63747 m .46608 .60543 L .46473 .60597 L F
.47183 .64603 m .47031 .63747 L .47574 .65733 L F
.47183 .64603 m .47112 .64104 L .47031 .63747 L F
.47112 .64104 m .46608 .60543 L .47031 .63747 L F
.47183 .64603 m .47024 .62963 L .46798 .61887 L F
.47131 .63728 m .47593 .65787 L .47161 .6454 L .958 .74 .565 r
F
.47131 .63728 m .47151 .64276 L .47263 .64393 L F
.47151 .64276 m .47199 .64485 L .47263 .64393 L F
.47057 .62578 m .46863 .61044 L .47009 .62667 L .07 .081 .562 r
F
.46863 .61044 m .46829 .60953 L .47183 .64603 L F
.46722 .60672 m .47029 .61002 L .46909 .61165 L .897 .5 .256 r
F
.46608 .60543 m .46316 .59588 L .47029 .61002 L .83 .438 .308 r
F
.46433 .60354 m .46383 .60025 L .46608 .60543 L F
.46383 .60025 m .46316 .59588 L .46608 .60543 L F
.46608 .60543 m .47029 .61002 L .46663 .60521 L F
.46608 .60543 m .46629 .60535 L .46364 .5998 L .07 .081 .562 r
F
.46829 .60953 m .46481 .60037 L .46364 .5998 L F
.46159 .59859 m .46663 .60521 L .46153 .59846 L .83 .438 .308 r
F
.46663 .60521 m .47029 .61002 L .46665 .60521 L F
.46663 .60521 m .46665 .60521 L .46153 .59846 L F
.46841 .61082 m .46829 .60953 L .46629 .60535 L .07 .081 .562 r
F
.46841 .61082 m .46629 .60535 L .46608 .60543 L F
.46665 .60521 m .47029 .61002 L .46722 .60672 L .897 .5 .256 r
F
.46829 .60953 m .46752 .60167 L .46481 .60037 L .07 .081 .562 r
F
.46409 .60261 m .46378 .60147 L .45712 .59273 L .83 .438 .308 r
F
.45314 .5862 m .45404 .58707 L .4507 .58432 L F
.45312 .58892 m .45603 .58914 L .46284 .59531 L 0 .222 .744 r
F
.45214 .58828 m .45252 .58836 L .45312 .58892 L F
.45252 .58836 m .45603 .58914 L .45312 .58892 L F
.46409 .60261 m .45712 .59273 L .457 .59256 L .83 .438 .308 r
F
.45546 .59112 m .457 .59256 L .42574 .55153 L F
.46409 .60261 m .457 .59256 L .45546 .59112 L F
.46433 .60354 m .46409 .60261 L .42574 .55153 L F
.42574 .55153 m .46159 .59859 L .42607 .55168 L F
.46159 .59859 m .46153 .59846 L .42607 .55168 L F
.45723 .59278 m .46255 .5998 L .45642 .5924 L .897 .5 .256 r
F
.46289 .59862 m .45214 .58828 L .45312 .58892 L 0 .222 .744 r
F
.44491 .58122 m .45431 .59004 L .42574 .55153 L .83 .438 .308 r
F
.44565 .58237 m .45431 .59004 L .44491 .58122 L F
.43022 .56646 m .44079 .57736 L .42574 .55153 L F
.44079 .57736 m .44565 .58237 L .44491 .58122 L F
.44079 .57736 m .44491 .58122 L .42574 .55153 L F
.45214 .58828 m .44079 .57736 L .45252 .58836 L 0 .222 .744 r
F
.45273 .58867 m .43562 .57203 L .45258 .58857 L F
.45273 .58867 m .45258 .58857 L .45606 .59196 L F
.45582 .59168 m .45273 .58867 L .45606 .59196 L F
.46289 .59862 m .45312 .58892 L .46288 .59808 L F
.43917 .56925 m .45723 .59278 L .45642 .5924 L .897 .5 .256 r
F
.44 .57005 m .45723 .59278 L .43917 .56925 L F
.43562 .57203 m .43626 .57269 L .4561 .59201 L 0 .222 .744 r
F
.43562 .57203 m .4561 .59201 L .45606 .59196 L F
.44751 .58525 m .4583 .59541 L .44565 .58237 L .83 .438 .308 r
F
.44911 .58514 m .43554 .57195 L .44912 .58516 L 0 .222 .744 r
F
.43554 .57195 m .43556 .57196 L .44912 .58516 L F
.45431 .59004 m .45433 .59006 L .42574 .55153 L .83 .438 .308 r
F
.43492 .56488 m .45642 .5924 L .44031 .57294 L .897 .5 .256 r
F
.42607 .55168 m .43785 .56748 L .43492 .56488 L F
.43785 .56748 m .45642 .5924 L .43492 .56488 L F
.41016 .54466 m .42607 .56004 L .42241 .55797 L .83 .438 .308 r
F
.42609 .55442 m .41657 .54648 L .42547 .55141 L .745 .291 .174 r
F
.41016 .54466 m .43022 .56646 L .42574 .55153 L .83 .438 .308 r
F
.39122 .54302 m .39406 .54314 L .40386 .54316 L .264 .671 .967 r
F
.36504 .54273 m .40386 .54316 L .40398 .54316 L F
.3508 .53623 m .40814 .54405 L .35144 .5364 L .269 0 0 r
F
.40926 .54435 m .409 .54275 L .40782 .54288 L 0 .222 .744 r
F
.4095 .54456 m .40814 .54405 L .41016 .54466 L .269 0 0 r
F
.40951 .54461 m .40947 .54447 L .40926 .54435 L 0 .222 .744 r
F
.40947 .54447 m .409 .54275 L .40926 .54435 L F
.41873 .54942 m .41016 .54466 L .42607 .55168 L .403 0 0 r
F
.42276 .55952 m .40782 .54288 L .4086 .54575 L 0 .222 .744 r
F
.45178 .58774 m .42182 .55717 L .42276 .55952 L F
.42182 .55717 m .40782 .54288 L .42276 .55952 L F
.42497 .55134 m .42488 .55115 L .41824 .54819 L .403 0 0 r
F
.4095 .54456 m .41016 .54466 L .40947 .54447 L .269 0 0 r
F
.40947 .54447 m .41016 .54466 L .41873 .54942 L .403 0 0 r
F
.35144 .5364 m .40814 .54405 L .4095 .54456 L .269 0 0 r
F
.35144 .5364 m .39627 .5427 L .33469 .53199 L F
.39627 .5427 m .39758 .54271 L .33469 .53199 L F
.39738 .54267 m .39758 .54271 L .39746 .54267 L F
.39738 .54267 m .39746 .54267 L .34312 .52622 L F
.33469 .53199 m .39738 .54267 L .34312 .52622 L F
.39758 .54271 m .40011 .54272 L .34312 .52622 L F
.40661 .54299 m .39627 .5427 L .4055 .54311 L .264 .671 .967 r
F
.40886 .54275 m .40314 .54273 L .40661 .54299 L F
.40314 .54273 m .39627 .5427 L .40661 .54299 L F
.40364 .54374 m .40342 .5436 L .40275 .54348 L .269 0 0 r
F
.40398 .54316 m .40386 .54316 L .405 .54317 L .264 .671 .967 r
F
.40386 .54316 m .40401 .54329 L .40459 .54311 L .749 .348 .291 r
F
.39923 .54283 m .40493 .54309 L .40814 .54405 L .269 0 0 r
F
.40342 .5436 m .40127 .54221 L .40275 .54348 L F
.40275 .54348 m .40127 .54221 L .34312 .52622 L F
.40108 .54257 m .39083 .54246 L .39627 .5427 L .264 .671 .967 r
F
.39858 .54238 m .39083 .54246 L .40108 .54257 L F
.39627 .5427 m .40364 .54374 L .39758 .54271 L .269 0 0 r
F
.40364 .54374 m .4095 .54456 L .40127 .54221 L F
.35447 .52953 m .40251 .54268 L .39858 .54238 L .403 0 0 r
F
.35621 .52985 m .40251 .54268 L .35447 .52953 L F
.34312 .52622 m .39858 .54238 L .37275 .53531 L F
.34312 .52622 m .40314 .54273 L .40251 .54268 L F
.4095 .54456 m .40947 .54447 L .40127 .54221 L .269 0 0 r
F
.4062 .5423 m .39442 .54124 L .39858 .54238 L .264 .671 .967 r
F
.41373 .54222 m .4049 .54177 L .4062 .5423 L F
.4049 .54177 m .39442 .54124 L .4062 .5423 L F
.40918 .54271 m .39627 .5427 L .40886 .54275 L F
.41373 .54222 m .40698 .5424 L .40918 .54271 L F
.40698 .5424 m .39627 .5427 L .40918 .54271 L F
.39858 .54238 m .37727 .54037 L .39083 .54246 L F
.39758 .54271 m .40364 .54374 L .40011 .54272 L .269 0 0 r
F
.45178 .58774 m .4106 .54444 L .40951 .54461 L 0 .222 .744 r
F
.4106 .54444 m .409 .54275 L .40905 .54295 L F
.4106 .54444 m .40905 .54295 L .40951 .54461 L F
.46909 .61165 m .47029 .61002 L .47337 .61698 L .897 .5 .256 r
F
.47886 .67177 m .47609 .65856 L .47641 .65999 L .787 .521 0 r
F
.47131 .63728 m .47263 .64393 L .48037 .63278 L .958 .74 .565 r
F
.47634 .67146 m .47183 .64603 L .47882 .67167 L .07 .081 .562 r
F
.47183 .64603 m .47574 .65733 L .47882 .67167 L F
.47634 .67146 m .47422 .65469 L .47183 .64603 L F
.47199 .64485 m .47454 .65609 L .48037 .63278 L .958 .74 .565 r
F
.47454 .65609 m .47657 .66504 L .47772 .65526 L F
.47454 .65609 m .47772 .65526 L .48037 .63278 L F
.47446 .65659 m .47193 .61913 L .46863 .61044 L .07 .081 .562 r
F
.46909 .61165 m .47337 .61698 L .4726 .62089 L .897 .5 .256 r
F
.4749 .65375 m .47239 .62267 L .47446 .65659 L .07 .081 .562 r
F
.47239 .62267 m .47108 .6065 L .47219 .62298 L F
.47239 .62267 m .47219 .62298 L .47446 .65659 L F
.46863 .61044 m .47108 .6065 L .46752 .60167 L F
.47193 .61913 m .47108 .6065 L .46863 .61044 L F
.47024 .62963 m .46841 .61082 L .46798 .61887 L F
.47284 .62154 m .47337 .61698 L .48037 .63278 L .897 .5 .256 r
F
.47255 .62111 m .4726 .62089 L .47284 .62154 L F
.4726 .62089 m .47337 .61698 L .47284 .62154 L F
.47707 .66725 m .47587 .66195 L .47634 .67146 L .07 .081 .562 r
F
.47492 .64292 m .47392 .63883 L .47634 .67146 L F
.4726 .62089 m .47215 .6197 L .47634 .67146 L F
.47634 .67146 m .4749 .65375 L .47446 .65659 L F
.47161 .6454 m .47186 .64639 L .47356 .69784 L .958 .74 .565 r
F
.47186 .64639 m .47614 .69047 L .47356 .69784 L F
.47336 .69232 m .47446 .68929 L .47686 .66632 L F
.47657 .66504 m .47686 .66632 L .48037 .63278 L F
.47336 .69232 m .47686 .66632 L .47657 .66504 L F
.47412 .7129 m .44826 .74599 L .45332 .73861 L .846 .987 .712 r
F
.47412 .7129 m .45594 .73806 L .45813 .73337 L F
.47513 .69994 m .47412 .7129 L .47227 .71282 L .981 .833 .437 r
F
.47152 .70937 m .47729 .69916 L .47366 .70047 L .283 .063 .393 r
F
.47169 .70867 m .47342 .70569 L .47164 .70887 L .527 .3 .513 r
F
.47169 .70867 m .47164 .70887 L .45895 .73161 L F
.47366 .70047 m .4754 .69873 L .47677 .68756 L .283 .063 .393 r
F
.47729 .69916 m .4803 .69383 L .47366 .70047 L F
.4759 .69116 m .47516 .69424 L .47356 .69784 L .958 .74 .565 r
F
.47356 .69784 m .47516 .69424 L .47365 .70011 L F
.47516 .69424 m .47392 .69939 L .47365 .70011 L F
.47737 .67728 m .47634 .67146 L .47884 .67644 L .07 .081 .562 r
F
.47634 .67146 m .47882 .67167 L .48051 .67976 L F
.47737 .67728 m .47749 .67093 L .47634 .67146 L F
.47686 .66632 m .47752 .66926 L .48037 .63278 L .958 .74 .565 r
F
.48037 .63278 m .47763 .66792 L .47763 .66393 L .981 .833 .437 r
F
.47763 .66792 m .47752 .66926 L .47755 .6678 L F
.47763 .66792 m .47755 .6678 L .47763 .66393 L F
.47733 .66573 m .47492 .64292 L .47587 .66195 L .07 .081 .562 r
F
.47733 .66573 m .47587 .66195 L .47707 .66725 L F
.47492 .64292 m .4726 .62089 L .47392 .63883 L F
.47242 .62178 m .47733 .66576 L .47732 .66579 L .437 .333 .639 r
F
.47242 .62178 m .47255 .62111 L .47733 .66576 L F
.47752 .66926 m .47733 .66573 L .47707 .66725 L .07 .081 .562 r
F
.47242 .62178 m .47755 .66779 L .47753 .66777 L .437 .333 .639 r
F
.47787 .67076 m .47707 .66725 L .47634 .67146 L .07 .081 .562 r
F
.47356 .69784 m .47561 .69388 L .47752 .66926 L .958 .74 .565 r
F
.47356 .69784 m .47752 .66926 L .47686 .66632 L F
.47255 .62111 m .4727 .62181 L .47755 .6678 L .437 .333 .639 r
F
.47787 .67076 m .47755 .6678 L .47752 .66926 L .07 .081 .562 r
F
.47755 .66779 m .47755 .6678 L .47787 .67076 L .437 .333 .639 r
F
.47255 .62111 m .47755 .6678 L .47755 .66779 L F
.47732 .66742 m .47688 .67757 L .47641 .67784 L .981 .833 .437 r
F
.47743 .6676 m .47688 .67757 L .47732 .66742 L F
.47356 .69784 m .47366 .70047 L .47561 .69388 L .958 .74 .565 r
F
.47366 .70047 m .47513 .69994 L .47561 .69388 L F
.47423 .70162 m .47402 .70495 L .47342 .70569 L .981 .833 .437 r
F
.4769 .66674 m .47402 .70495 L .47648 .66606 L F
.47755 .6678 m .47733 .66573 L .47752 .66926 L .07 .081 .562 r
F
.47161 .6454 m .47584 .67123 L .47657 .66504 L .958 .74 .565 r
F
.47422 .65469 m .47167 .64345 L .47183 .64603 L .07 .081 .562 r
F
.47161 .6454 m .47657 .66504 L .47199 .64485 L .958 .74 .565 r
F
.47629 .66575 m .47242 .62178 L .47516 .64642 L .437 .333 .639 r
F
.47648 .66606 m .47516 .64642 L .47753 .66777 L F
.47629 .66575 m .47516 .64642 L .47648 .66606 L F
.47732 .66579 m .47733 .66576 L .47755 .66779 L F
.47763 .66393 m .47733 .66728 L .47781 .6547 L .981 .833 .437 r
F
.47733 .66728 m .47402 .70495 L .47781 .6547 L F
.47781 .6547 m .4769 .66674 L .47648 .66606 L F
.47763 .66393 m .47743 .6676 L .47732 .66742 L F
.48037 .63278 m .47763 .66393 L .47781 .6547 L F
.47752 .66926 m .47688 .67757 L .47763 .66393 L F
.48192 .67448 m .48194 .67079 L .48304 .67024 L .787 .521 0 r
F
.4818 .6749 m .47983 .66277 L .4819 .66992 L F
.47781 .6547 m .47648 .66606 L .48254 .67474 L .981 .833 .437 r
F
.47781 .6547 m .48254 .67474 L .48257 .67418 L F
.47648 .66606 m .47423 .70162 L .47311 .70607 L F
.47337 .69267 m .47356 .69784 L .47436 .69023 L .958 .74 .565 r
F
.47337 .69267 m .47436 .69023 L .47446 .68929 L F
.47336 .69232 m .47337 .69267 L .47446 .68929 L F
.47581 .67175 m .47311 .70607 L .47158 .70796 L .981 .833 .437 r
F
.47648 .66606 m .47311 .70607 L .47581 .67175 L F
.47641 .67784 m .47547 .69415 L .47487 .69531 L F
.47547 .69415 m .47513 .69994 L .47487 .69531 L F
.47487 .69531 m .47513 .69994 L .47402 .70495 L F
.47688 .67757 m .47513 .69994 L .47641 .67784 L F
.4754 .69873 m .4803 .69383 L .47757 .68899 L .283 .063 .393 r
F
.4754 .69873 m .47757 .68899 L .47677 .68756 L F
.47677 .68756 m .48051 .67976 L .47754 .68649 L F
.48638 .67119 m .48211 .68644 L .47984 .69225 L .964 .935 .627 r
F
.47677 .68756 m .4803 .69383 L .48051 .67976 L .283 .063 .393 r
F
.47701 .67398 m .47158 .70796 L .47803 .6891 L .981 .833 .437 r
F
.47648 .66606 m .47581 .67175 L .47701 .67398 L F
.47581 .67175 m .47158 .70796 L .47701 .67398 L F
.47342 .70569 m .4803 .69383 L .47402 .70495 L .527 .3 .513 r
F
.47342 .70569 m .47402 .70495 L .45895 .73161 L F
.46074 .72777 m .47169 .70867 L .46092 .72806 L F
.45949 .73046 m .46092 .72806 L .45895 .73161 L F
.46074 .72777 m .46092 .72806 L .45949 .73046 L F
.47412 .7129 m .41718 .78325 L .44115 .75245 L .846 .987 .712 r
F
.45912 .74132 m .45903 .74145 L .45901 .74198 L F
.45655 .73585 m .45716 .73478 L .45813 .73337 L F
.44949 .74698 m .45716 .73478 L .45655 .73585 L F
.44949 .74698 m .44901 .74664 L .45716 .73478 L F
.45813 .73337 m .44901 .74664 L .4482 .74607 L F
.45198 .74394 m .45895 .73161 L .45798 .73298 L .283 .063 .393 r
F
.45198 .74394 m .45798 .73298 L .44853 .7463 L F
.44418 .7618 m .44593 .75775 L .44588 .7578 L 0 0 0 r
F
.44949 .74698 m .45045 .74765 L .44418 .7618 L .283 .063 .393 r
F
.4296 .77195 m .43655 .77123 L .43973 .7673 L .308 0 .029 r
F
.43655 .77123 m .43825 .7677 L .44418 .7618 L .283 .063 .393 r
F
.43655 .77123 m .45198 .74394 L .44853 .7463 L F
.45332 .73861 m .4482 .74607 L .44761 .74566 L .846 .987 .712 r
F
.44826 .74599 m .4482 .74607 L .45332 .73861 L F
.45949 .73046 m .44711 .7453 L .45131 .74413 L F
.42816 .77649 m .4272 .77781 L .42411 .77707 L F
.42283 .77738 m .42874 .78264 L .43646 .77136 L .502 .096 .203 r
F
.41898 .78094 m .41718 .78325 L .41202 .78738 L .846 .987 .712 r
F
.41138 .78797 m .42874 .78264 L .42283 .77738 L .502 .096 .203 r
F
.41605 .78684 m .42028 .78544 L .41513 .78728 L .613 .221 .277 r
F
.42028 .78544 m .42874 .78264 L .41468 .7875 L F
.42561 .77558 m .43655 .77123 L .4296 .77195 L .308 0 .029 r
F
.4379 .76655 m .41468 .7875 L .43065 .77646 L 0 0 0 r
F
.37449 .80139 m .41468 .7875 L .36541 .80273 L .502 .096 .203 r
F
.41468 .7875 m .41516 .78695 L .36541 .80273 L F
.41202 .78738 m .41468 .7875 L .43203 .77185 L .846 .987 .712 r
F
.42028 .78544 m .41468 .7875 L .41024 .78903 L .613 .221 .277 r
F
.41605 .78684 m .42022 .79542 L .42874 .78264 L F
.41666 .78613 m .41468 .7875 L .41605 .78684 L 0 0 0 r
F
.40866 .78929 m .41605 .78684 L .41024 .78903 L .613 .221 .277 r
F
.41605 .78684 m .41513 .78728 L .41024 .78903 L F
.40623 .79834 m .42022 .79542 L .41605 .78684 L F
.40684 .79902 m .40754 .79902 L .40689 .79901 L .275 0 0 r
F
.39763 .79991 m .40868 .79822 L .40754 .79902 L .786 .975 .912 r
F
.40737 .79796 m .42022 .79542 L .40623 .79834 L .685 .288 .29 r
F
.40737 .79796 m .41104 .8086 L .42022 .79542 L F
.4095 .79533 m .41468 .7875 L .40576 .7985 L 0 0 0 r
F
.40482 .80109 m .41104 .8086 L .40737 .79796 L .685 .288 .29 r
F
.40215 .80662 m .41104 .8086 L .40482 .80109 L F
.40095 .80913 m .39465 .81219 L .39687 .8176 L .363 0 .14 r
F
.40203 .80687 m .39854 .80939 L .40095 .80913 L F
.39854 .80939 m .39465 .81219 L .40095 .80913 L F
.4006 .80628 m .39465 .81219 L .40203 .80687 L 0 0 0 r
F
.39817 .80927 m .40676 .80882 L .4006 .80628 L .685 .288 .29 r
F
.40676 .80882 m .41104 .8086 L .4006 .80628 L F
.40335 .80886 m .41104 .8086 L .40095 .80913 L .736 .315 .248 r
F
.47174 .76773 m .59526 .70965 L .60678 .69801 L .224 0 0 r
F
.46474 .77634 m .59526 .70965 L .47174 .76773 L 0 0 0 r
F
.45531 .78341 m .57952 .71964 L .46474 .77634 L .473 .887 .771 r
F
.46474 .77634 m .53559 .74134 L .59526 .70965 L 0 0 0 r
F
.53559 .74134 m .57952 .71964 L .59131 .71216 L F
.53559 .74134 m .59131 .71216 L .59526 .70965 L F
.44421 .78901 m .56108 .72766 L .46274 .7795 L .674 .97 .917 r
F
.45402 .78406 m .46274 .7795 L .45531 .78341 L F
.44421 .78901 m .46274 .7795 L .45402 .78406 L F
.43216 .7933 m .54146 .73365 L .44421 .78901 L .749 .96 .938 r
F
.43216 .7933 m .52201 .73787 L .54146 .73365 L F
.41977 .79653 m .52201 .73787 L .43216 .7933 L .78 .948 .93 r
F
.4532 .75424 m .45431 .75354 L .45591 .75268 L .486 .876 .693 r
F
.4532 .75424 m .45591 .75268 L .45641 .75241 L F
.45431 .75354 m .45693 .75065 L .45641 .75241 L .964 .935 .627 r
F
.45445 .75399 m .45493 .7536 L .45704 .75235 L .486 .876 .693 r
F
.45493 .7536 m .45641 .75241 L .46201 .74939 L F
.45835 .74973 m .4588 .74912 L .45858 .74989 L .964 .935 .627 r
F
.48819 .74557 m .48713 .74528 L .48875 .72479 L .803 .728 .781 r
F
.48828 .73079 m .48629 .75591 L .48362 .72444 L .839 .839 .846 r
F
.45402 .76435 m .47361 .74583 L .48753 .74323 L .786 .975 .912 r
F
.47019 .7547 m .4838 .7472 L .47251 .75371 L .839 .839 .846 r
F
.45402 .76435 m .48513 .74474 L .47251 .75371 L .786 .975 .912 r
F
.41104 .8086 m .41889 .80024 L .42022 .79542 L .726 .492 .572 r
F
.46672 .74721 m .45486 .76036 L .46446 .76192 L 0 0 0 r
F
.41889 .80024 m .43306 .78453 L .42022 .79542 L .726 .492 .572 r
F
.43306 .78453 m .45268 .76277 L .44005 .77547 L F
.43306 .78453 m .44005 .77547 L .42022 .79542 L F
.42022 .79542 m .44005 .77547 L .4318 .77955 L .647 .417 .556 r
F
.46726 .76413 m .47276 .76405 L .47385 .75891 L .726 .492 .572 r
F
.46651 .76856 m .47276 .76405 L .46726 .76413 L F
.45531 .78341 m .56108 .72766 L .57952 .71964 L .473 .887 .771 r
F
.44421 .78901 m .54146 .73365 L .56108 .72766 L .674 .97 .917 r
F
.47021 .74657 m .46446 .76192 L .46452 .76901 L .275 .088 .437 r
F
.46651 .76856 m .46452 .76901 L .4646 .77994 L F
.47021 .74657 m .46452 .76901 L .46651 .76856 L F
.46741 .76835 m .47276 .76405 L .46651 .76856 L .789 .547 .571 r
F
.48513 .74474 m .4853 .74478 L .47251 .75371 L .786 .975 .912 r
F
.47361 .74583 m .48362 .72444 L .48421 .74385 L .872 .767 .743 r
F
.48556 .74735 m .48562 .74808 L .4854 .74744 L .839 .839 .846 r
F
.48819 .74557 m .48875 .72479 L .4893 .7232 L .803 .728 .781 r
F
.47251 .75371 m .48753 .74323 L .50186 .74112 L .792 .953 .922 r
F
.47361 .74583 m .48021 .72421 L .4825 .72437 L .872 .767 .743 r
F
.4679 .73949 m .448 .75924 L .45486 .76036 L 0 0 0 r
F
.4679 .73949 m .45486 .76036 L .46672 .74721 L F
.43533 .77429 m .44497 .76118 L .44625 .75902 L .647 .417 .556 r
F
.45241 .75457 m .45511 .74712 L .45526 .74758 L .964 .935 .627 r
F
.4679 .73949 m .44625 .75902 L .44455 .76189 L 0 0 0 r
F
.43877 .76536 m .44408 .75622 L .44302 .75956 L .527 .3 .513 r
F
.44711 .7453 m .4434 .75534 L .45131 .74413 L .846 .987 .712 r
F
.4434 .75534 m .44145 .76062 L .44408 .75622 L F
.4434 .75534 m .44408 .75622 L .45131 .74413 L F
.44408 .75622 m .46133 .72651 L .45481 .73827 L .527 .3 .513 r
F
.44408 .75622 m .45481 .73827 L .44302 .75956 L F
.43877 .76536 m .44302 .75956 L .43655 .77123 L F
.46133 .72651 m .45895 .73161 L .43655 .77123 L F
.43877 .76536 m .44489 .75727 L .44408 .75622 L F
.43555 .77167 m .43646 .77136 L .43655 .77123 L .502 .096 .203 r
F
.43011 .78028 m .43877 .76536 L .43655 .77123 L .527 .3 .513 r
F
.43011 .78028 m .44079 .76365 L .43877 .76536 L F
.44079 .76365 m .44489 .75727 L .43877 .76536 L F
.4318 .77955 m .44389 .76299 L .43533 .77429 L .647 .417 .556 r
F
.4598 .74753 m .44439 .76215 L .448 .75924 L 0 0 0 r
F
.44439 .76215 m .44389 .76299 L .448 .75924 L F
.44389 .76299 m .44497 .76118 L .43533 .77429 L .647 .417 .556 r
F
.42509 .78812 m .44625 .75902 L .42874 .78264 L F
.42022 .79542 m .44625 .75902 L .42509 .78812 L F
.45511 .74712 m .45652 .74326 L .45526 .74758 L .964 .935 .627 r
F
.45652 .74326 m .45566 .74646 L .45526 .74758 L F
.45526 .74758 m .45556 .74685 L .45561 .74782 L F
.45131 .74413 m .44408 .75622 L .4679 .73949 L .846 .987 .712 r
F
.42874 .78264 m .43011 .78028 L .43655 .77123 L .527 .3 .513 r
F
.43011 .78028 m .44612 .75885 L .44489 .75727 L F
.44408 .75622 m .44145 .76062 L .44518 .75764 L .846 .987 .712 r
F
.44408 .75622 m .44518 .75764 L .4679 .73949 L F
.45911 .73952 m .45661 .74265 L .45901 .74198 L F
.45949 .73046 m .45661 .74265 L .45911 .73952 L F
.45949 .73046 m .45131 .74413 L .45661 .74265 L F
.46135 .72822 m .45949 .73046 L .45903 .74145 L F
.46135 .72822 m .45903 .74145 L .45912 .74132 L F
.47412 .7129 m .46135 .72822 L .4679 .73949 L F
.47156 .71598 m .47402 .70495 L .47157 .71596 L .981 .833 .437 r
F
.47156 .71598 m .47157 .71596 L .46963 .72471 L F
.46965 .72456 m .47156 .71598 L .46963 .72471 L F
.46135 .72822 m .45901 .74198 L .4679 .73949 L .846 .987 .712 r
F
.44489 .75727 m .46916 .72699 L .46965 .72456 L .527 .3 .513 r
F
.46626 .72401 m .46965 .72456 L .47134 .7161 L F
.44489 .75727 m .46965 .72456 L .46626 .72401 L F
.47342 .70569 m .47402 .70495 L .46965 .72456 L .981 .833 .437 r
F
.46133 .72651 m .46308 .72349 L .46074 .72777 L .527 .3 .513 r
F
.46308 .72349 m .47169 .70867 L .46074 .72777 L F
.47227 .71282 m .47412 .7129 L .46963 .72471 L .981 .833 .437 r
F
.44408 .75622 m .4741 .7114 L .46133 .72651 L .527 .3 .513 r
F
.4741 .7114 m .48036 .70205 L .47442 .70969 L F
.4741 .7114 m .47442 .70969 L .46133 .72651 L F
.46535 .75807 m .46683 .7473 L .46446 .76192 L 0 0 .088 r
F
.46683 .7473 m .46672 .74721 L .46446 .76192 L F
.4704 .74543 m .47218 .75239 L .47858 .73672 L .726 .492 .572 r
F
.47218 .75239 m .47385 .75891 L .47406 .75794 L F
.47218 .75239 m .47406 .75794 L .47858 .73672 L F
.46741 .76323 m .47385 .75891 L .4704 .74543 L F
.41104 .8086 m .45626 .77283 L .43032 .78808 L F
.46446 .76192 m .45486 .77164 L .45824 .77453 L .363 0 .14 r
F
.46452 .76901 m .45824 .77453 L .4646 .77994 L F
.46446 .76192 m .45824 .77453 L .46452 .76901 L F
.40204 .82101 m .44198 .78884 L .41104 .8086 L .789 .547 .571 r
F
.44198 .78884 m .45599 .77651 L .41104 .8086 L F
.45626 .77283 m .45486 .77164 L .43032 .78808 L .726 .492 .572 r
F
.40204 .82101 m .46233 .79285 L .46455 .78673 L .789 .547 .571 r
F
.46461 .78094 m .4622 .784 L .46538 .78769 L .61 .236 .308 r
F
.46567 .7869 m .46538 .78769 L .46592 .78832 L F
.46461 .78094 m .46538 .78769 L .46567 .7869 L F
.47677 .79588 m .47138 .80955 L .47944 .79433 L .692 .491 .61 r
F
.45833 .80691 m .4645 .79009 L .46233 .79285 L .875 .71 .674 r
F
.46233 .79285 m .4645 .79009 L .46381 .78966 L .789 .613 .662 r
F
.46645 .79131 m .46347 .79098 L .46745 .79695 L .61 .236 .308 r
F
.46592 .78832 m .46437 .79001 L .46645 .79131 L F
.46437 .79001 m .46347 .79098 L .46645 .79131 L F
.46233 .79285 m .46381 .78966 L .46455 .78673 L .789 .613 .662 r
F
.40204 .82101 m .46455 .78673 L .46447 .78664 L .789 .547 .571 r
F
.45824 .77453 m .44244 .78879 L .4646 .77994 L .363 0 .14 r
F
.44244 .78879 m .45405 .78763 L .4646 .77994 L F
.40204 .82101 m .46461 .78656 L .45543 .78749 L .789 .547 .571 r
F
.42285 .80425 m .45543 .78749 L .44198 .78884 L F
.40204 .82101 m .45543 .78749 L .42285 .80425 L F
.43259 .80992 m .44887 .82071 L .46233 .79285 L .846 .586 .546 r
F
.43073 .81158 m .40056 .82661 L .40193 .82816 L .61 .236 .308 r
F
.41225 .82803 m .40193 .82816 L .40639 .83323 L F
.43073 .81158 m .40193 .82816 L .41225 .82803 L F
.42517 .82786 m .44887 .82071 L .41225 .82803 L .902 .603 .47 r
F
.427 .82784 m .4287 .82728 L .42517 .82786 L F
.4287 .82728 m .44887 .82071 L .42517 .82786 L F
.41225 .82803 m .44887 .82071 L .43259 .80992 L .846 .586 .546 r
F
.48296 .76873 m .46745 .79695 L .46839 .79996 L .692 .491 .61 r
F
.47911 .77328 m .46745 .79695 L .48296 .76873 L F
.46939 .78364 m .46567 .7869 L .46645 .79131 L .543 .335 .549 r
F
.47677 .79588 m .47602 .79625 L .47138 .80955 L .692 .491 .61 r
F
.47602 .79625 m .46839 .79996 L .47106 .80849 L F
.47602 .79625 m .47106 .80849 L .47138 .80955 L F
.51063 .66126 m .48905 .72833 L .50351 .68194 L .803 .728 .781 r
F
.50351 .68194 m .51145 .66498 L .48421 .74385 L .872 .767 .743 r
F
.51145 .66498 m .51279 .66211 L .5112 .66665 L F
.51145 .66498 m .5112 .66665 L .48421 .74385 L F
.51279 .66211 m .51334 .66194 L .51065 .6704 L F
.51105 .6677 m .51065 .6704 L .48753 .74323 L F
.51279 .66211 m .51065 .6704 L .51105 .6677 L F
.50749 .73482 m .53464 .68954 L .53531 .68963 L .804 .719 .77 r
F
.5135 .65404 m .50072 .58018 L .51644 .63592 L .732 .552 .648 r
F
.51997 .68204 m .52304 .67625 L .50915 .72285 L .829 .73 .755 r
F
.52304 .67625 m .52649 .6763 L .50619 .73399 L F
.52304 .67625 m .50619 .73399 L .50915 .72285 L F
.53364 .67986 m .53586 .68971 L .52798 .67633 L .743 .634 .739 r
F
.53116 .67638 m .52798 .67633 L .51316 .65116 L F
.53364 .67986 m .52798 .67633 L .53116 .67638 L F
.50794 .73392 m .52677 .67676 L .53461 .68954 L .804 .719 .77 r
F
.53586 .68971 m .53461 .68954 L .51316 .65116 L .743 .634 .739 r
F
.50619 .73399 m .52649 .6763 L .50794 .73392 L .804 .719 .77 r
F
.52649 .6763 m .52677 .67676 L .50794 .73392 L F
.53461 .68954 m .53269 .68927 L .5238 .67192 L .743 .634 .739 r
F
.53461 .68954 m .5238 .67192 L .51316 .65116 L F
.52002 .61933 m .53364 .67986 L .51316 .65116 L F
.52649 .6763 m .53333 .65684 L .52677 .67676 L .804 .719 .77 r
F
.50559 .74054 m .53586 .68971 L .52201 .73787 L F
.53586 .68971 m .55358 .65995 L .54122 .69047 L F
.53586 .68971 m .54122 .69047 L .52201 .73787 L F
.51259 .66253 m .5108 .66072 L .51279 .66211 L .872 .767 .743 r
F
.52212 .66865 m .53269 .68927 L .51105 .6609 L .743 .634 .739 r
F
.50794 .73392 m .53461 .68954 L .50749 .73482 L .804 .719 .77 r
F
.53461 .68954 m .53464 .68954 L .50749 .73482 L F
.54669 .66684 m .55208 .66146 L .55113 .66407 L .743 .634 .739 r
F
.54122 .69047 m .55358 .65995 L .54767 .69951 L .794 .728 .79 r
F
.54456 .67511 m .55113 .66407 L .53816 .69994 L .743 .634 .739 r
F
.54669 .66684 m .55113 .66407 L .54456 .67511 L F
.52152 .67623 m .53045 .68895 L .52121 .67739 L .803 .728 .781 r
F
.50454 .74071 m .55358 .65995 L .50559 .74054 L .804 .719 .77 r
F
.50749 .73482 m .55358 .65995 L .50454 .74071 L F
.53045 .68895 m .53816 .69994 L .53023 .68939 L .803 .728 .781 r
F
.53045 .68895 m .53023 .68939 L .52121 .67739 L F
.50378 .74084 m .50749 .73482 L .50454 .74071 L .804 .719 .77 r
F
.53269 .68927 m .53816 .69994 L .53054 .68896 L .743 .634 .739 r
F
.53269 .68927 m .53054 .68896 L .51105 .6609 L F
.55611 .63022 m .55208 .66146 L .54669 .66684 L F
.53461 .68954 m .53333 .65684 L .55608 .65379 L .804 .719 .77 r
F
.52677 .67676 m .53333 .65684 L .53461 .68954 L F
.53461 .68954 m .53816 .69994 L .53269 .68927 L .743 .634 .739 r
F
.53586 .68971 m .53653 .69267 L .53461 .68954 L F
.53653 .69267 m .53816 .69994 L .53461 .68954 L F
.51145 .66498 m .52089 .70805 L .50454 .73405 L .803 .728 .781 r
F
.50129 .73418 m .50454 .73405 L .50033 .74076 L F
.51145 .66498 m .50454 .73405 L .50129 .73418 L F
.52089 .70805 m .50943 .73094 L .50033 .74076 L F
.50378 .74084 m .50619 .73399 L .50794 .73392 L .804 .719 .77 r
F
.50915 .72285 m .50619 .73399 L .50378 .74084 L .829 .73 .755 r
F
.51182 .66242 m .52152 .67623 L .51152 .6645 L .803 .728 .781 r
F
.52152 .67623 m .52121 .67739 L .51152 .6645 L F
.5174 .69174 m .53816 .69994 L .52276 .71656 L F
.51152 .6645 m .52121 .67739 L .5174 .69174 L F
.52121 .67739 m .53816 .69994 L .5174 .69174 L F
.51073 .66087 m .52276 .71656 L .51065 .66135 L F
.48753 .74323 m .51997 .68204 L .50378 .74084 L .829 .73 .755 r
F
.51997 .68204 m .50915 .72285 L .50378 .74084 L F
.52304 .67625 m .53333 .65684 L .52649 .6763 L F
.53461 .68954 m .55608 .65379 L .53464 .68954 L .804 .719 .77 r
F
.53531 .68963 m .55608 .65379 L .55358 .65995 L F
.53464 .68954 m .55608 .65379 L .53531 .68963 L F
.51105 .6609 m .53054 .68896 L .51098 .66122 L .743 .634 .739 r
F
.53054 .68896 m .53816 .69994 L .53045 .68895 L F
.53054 .68896 m .53045 .68895 L .51098 .66122 L F
.51073 .66087 m .51182 .66242 L .51152 .6645 L .803 .728 .781 r
F
.52089 .70805 m .52276 .71656 L .50943 .73094 L F
.50378 .74084 m .50794 .73392 L .50749 .73482 L .804 .719 .77 r
F
.50114 .74243 m .50378 .74084 L .50268 .74157 L .792 .953 .922 r
F
.49104 .75921 m .49368 .78034 L .50779 .73478 L .875 .71 .674 r
F
.47602 .79625 m .49368 .78034 L .49104 .75921 L F
.48589 .78921 m .49368 .78034 L .47987 .79278 L .953 .819 .675 r
F
.52042 .71698 m .50673 .74774 L .53049 .72409 L .808 .634 .665 r
F
.49368 .78034 m .50373 .75737 L .50779 .73478 L .812 .687 .726 r
F
.50373 .75737 m .50437 .7559 L .50457 .75467 L F
.50373 .75737 m .50457 .75467 L .50779 .73478 L F
.50437 .7559 m .51378 .72337 L .50779 .73478 L F
.51674 .71229 m .51384 .72311 L .52042 .71698 L .692 .491 .61 r
F
.51384 .72311 m .51087 .73425 L .5167 .72371 L F
.51384 .72311 m .5167 .72371 L .52042 .71698 L F
.50779 .73478 m .51384 .72311 L .50918 .72214 L .719 .599 .722 r
F
.51378 .72337 m .51384 .72311 L .50779 .73478 L .812 .687 .726 r
F
.52042 .71698 m .51046 .73579 L .50673 .74774 L .808 .634 .665 r
F
.50673 .74774 m .50471 .75472 L .53049 .72409 L F
.5024 .75746 m .51541 .74714 L .53049 .72409 L F
.51261 .61783 m .51202 .60415 L .51817 .6172 L .732 .552 .648 r
F
.51138 .61797 m .51202 .60415 L .51261 .61783 L F
.51138 .61797 m .50072 .58018 L .51202 .60415 L F
.50052 .59398 m .51793 .61004 L .49841 .59384 L .65 .463 .618 r
F
.5013 .59447 m .51793 .61004 L .50052 .59398 L F
.49841 .59384 m .51793 .61004 L .49861 .5948 L .732 .556 .654 r
F
.50717 .56576 m .50811 .56538 L .50718 .5877 L .65 .463 .618 r
F
.51185 .60379 m .50072 .58018 L .51455 .59581 L .732 .552 .648 r
F
.51244 .60206 m .51793 .61004 L .50079 .594 L .65 .463 .618 r
F
.51244 .60206 m .50079 .594 L .50314 .59416 L F
.51644 .63592 m .51138 .61797 L .51817 .6172 L .732 .552 .648 r
F
.50038 .60346 m .51793 .61004 L .51505 .63038 L .732 .556 .654 r
F
.49861 .5948 m .51793 .61004 L .50038 .60346 L F
.51418 .65317 m .52212 .66865 L .51217 .65572 L .743 .634 .739 r
F
.51433 .65882 m .51644 .63592 L .53333 .65684 L .732 .552 .648 r
F
.51644 .63592 m .51817 .6172 L .51965 .62107 L F
.51644 .63592 m .51965 .62107 L .53333 .65684 L F
.51817 .6172 m .52681 .62715 L .53333 .65684 L F
.51793 .61004 m .52002 .61933 L .51077 .6607 L .743 .634 .739 r
F
.51793 .61004 m .51077 .6607 L .51076 .66069 L F
.51077 .6607 m .51098 .66122 L .51073 .66087 L F
.52002 .61933 m .51105 .6609 L .51077 .6607 L F
.51105 .6609 m .51098 .66122 L .51077 .6607 L F
.5107 .66077 m .51067 .66074 L .50576 .6518 L .732 .556 .654 r
F
.51076 .66069 m .50936 .65953 L .51179 .65918 L .872 .767 .743 r
F
.5107 .66077 m .51013 .66025 L .51076 .66069 L F
.51013 .66025 m .50936 .65953 L .51076 .66069 L F
.5108 .66072 m .51179 .65918 L .51433 .65882 L F
.48753 .74323 m .51065 .6704 L .51997 .68204 L .829 .73 .755 r
F
.51243 .6606 m .51407 .66301 L .51225 .66173 L .743 .634 .739 r
F
.51279 .66211 m .51433 .65882 L .51334 .66194 L .872 .767 .743 r
F
.51386 .66177 m .52212 .66865 L .51407 .66301 L .743 .634 .739 r
F
.51624 .66101 m .52212 .66865 L .51386 .66177 L F
.52304 .67625 m .51433 .65882 L .53333 .65684 L .829 .73 .755 r
F
.51334 .66194 m .51433 .65882 L .52304 .67625 L F
.50038 .60346 m .51505 .63038 L .51131 .65682 L .732 .556 .654 r
F
.51316 .65116 m .51418 .65317 L .51217 .65572 L .743 .634 .739 r
F
.51433 .65882 m .5135 .65404 L .51644 .63592 L .732 .552 .648 r
F
.50936 .65953 m .50933 .65932 L .51433 .65882 L .784 .572 .613 r
F
.50933 .65932 m .5135 .65404 L .51433 .65882 L F
.51279 .66211 m .5108 .66072 L .51433 .65882 L .872 .767 .743 r
F
.52889 .61543 m .52914 .61597 L .51793 .61004 L .666 .547 .71 r
F
.51619 .5798 m .53996 .62086 L .51793 .61004 L F
.51793 .61004 m .52914 .61597 L .52279 .61668 L .743 .634 .739 r
F
.51793 .61004 m .55002 .65387 L .52002 .61933 L F
.50437 .7559 m .50619 .75174 L .51378 .72337 L .812 .687 .726 r
F
.51208 .70636 m .50911 .7139 L .51087 .73425 L .692 .491 .61 r
F
.50779 .73478 m .50918 .72214 L .50899 .71014 L .719 .599 .722 r
F
.50885 .70562 m .50899 .71014 L .5089 .70432 L F
.50779 .73478 m .50899 .71014 L .50885 .70562 L F
.50918 .72214 m .50912 .71526 L .50907 .71248 L F
.50899 .71014 m .50907 .71248 L .5089 .70432 L F
.50918 .72214 m .50907 .71248 L .50899 .71014 L F
.51208 .70636 m .50907 .71248 L .50907 .7128 L .692 .491 .61 r
F
.51208 .70636 m .50907 .7128 L .50911 .7139 L F
.50911 .7139 m .50932 .73705 L .51087 .73425 L F
.50996 .70239 m .50907 .71248 L .51208 .70636 L .543 .335 .549 r
F
.50882 .70025 m .5089 .70432 L .50996 .70239 L F
.5089 .70432 m .50907 .71248 L .50996 .70239 L F
.50518 .71109 m .50779 .73478 L .5089 .70432 L .789 .613 .662 r
F
.4734 .78013 m .47911 .77328 L .47302 .78046 L .875 .71 .674 r
F
.48513 .74474 m .48753 .74323 L .4853 .74478 L .786 .975 .912 r
F
.48421 .74385 m .48861 .73124 L .48753 .74323 L .872 .767 .743 r
F
.48861 .73124 m .49048 .73377 L .48753 .74323 L F
.48861 .73124 m .5112 .66665 L .49048 .73377 L F
.5112 .66665 m .51105 .6677 L .49048 .73377 L F
.48875 .72479 m .48828 .73079 L .48362 .72444 L .839 .839 .846 r
F
.48362 .72444 m .48828 .73079 L .48421 .74385 L .872 .767 .743 r
F
.47276 .76405 m .50199 .70579 L .49993 .70516 L .701 .531 .655 r
F
.50452 .6922 m .49539 .7125 L .49777 .70866 L .543 .335 .549 r
F
.4893 .7232 m .48875 .72479 L .49001 .70894 L .803 .728 .781 r
F
.49001 .70894 m .48875 .72479 L .48362 .72444 L .839 .839 .846 r
F
.50351 .68194 m .48905 .72833 L .4893 .7232 L .803 .728 .781 r
F
.51063 .66126 m .4893 .7232 L .49001 .70894 L F
.47276 .76405 m .49722 .71104 L .4789 .73914 L .701 .531 .655 r
F
.49722 .71104 m .49993 .70516 L .49539 .7125 L F
.49722 .71104 m .49539 .7125 L .4789 .73914 L F
.4888 .68985 m .49001 .70894 L .48765 .68146 L .803 .643 .683 r
F
.4888 .68985 m .51073 .66087 L .49001 .70894 L F
.49357 .68042 m .51073 .66087 L .4888 .68985 L F
.48765 .68146 m .49001 .70894 L .48731 .679 L F
.51073 .66087 m .51063 .66126 L .49001 .70894 L .803 .728 .781 r
F
.46634 .7818 m .49349 .72455 L .47276 .76405 L .789 .613 .662 r
F
.50572 .69755 m .50227 .70587 L .50772 .70647 L .543 .335 .549 r
F
.50227 .70587 m .48458 .74853 L .50721 .70739 L F
.50227 .70587 m .50721 .70739 L .50772 .70647 L F
.49157 .72879 m .48458 .74853 L .50572 .69755 L F
.50648 .69587 m .50907 .71248 L .50882 .70025 L F
.50572 .69755 m .50907 .71248 L .50648 .69587 L F
.48857 .68612 m .48785 .68024 L .48815 .68203 L .803 .643 .683 r
F
.48843 .68713 m .48733 .67839 L .49955 .66092 L .935 .84 .726 r
F
.50351 .68194 m .51063 .66126 L .51145 .66498 L .872 .767 .743 r
F
.49955 .66092 m .49631 .64568 L .49978 .64483 L .784 .572 .613 r
F
.48917 .66433 m .48664 .63111 L .49955 .66092 L .859 .611 .562 r
F
.48664 .63111 m .49569 .64475 L .49955 .66092 L F
.50181 .68097 m .49706 .67482 L .50452 .6922 L .175 .215 .665 r
F
.49693 .66608 m .50939 .69103 L .5 .65363 L .701 .531 .655 r
F
.49823 .67002 m .50939 .69103 L .49693 .66608 L F
.49693 .66608 m .49706 .67482 L .50181 .68097 L .175 .215 .665 r
F
.49693 .66608 m .5 .65363 L .49653 .66712 L .701 .531 .655 r
F
.46767 .748 m .46958 .74603 L .46751 .74786 L .726 .492 .572 r
F
.46958 .74603 m .46868 .74668 L .46751 .74786 L F
.46963 .72471 m .47412 .7129 L .47143 .7244 L .981 .833 .437 r
F
.46926 .72789 m .47143 .7244 L .4679 .73949 L F
.46963 .72471 m .47143 .7244 L .46926 .72789 L F
.45735 .74961 m .44455 .76189 L .4598 .74753 L 0 0 0 r
F
.44625 .75902 m .44616 .75891 L .43011 .78028 L .527 .3 .513 r
F
.44518 .75764 m .44625 .75902 L .4679 .73949 L .846 .987 .712 r
F
.45967 .74092 m .45944 .74103 L .43011 .78028 L .527 .3 .513 r
F
.44115 .75245 m .41898 .78094 L .41202 .78738 L .846 .987 .712 r
F
.42014 .77764 m .43203 .77185 L .44625 .75902 L F
.42014 .77764 m .44625 .75902 L .44518 .75764 L F
.43057 .78017 m .44625 .75902 L .43011 .78028 L .527 .3 .513 r
F
.44625 .75902 m .45967 .74092 L .44616 .75891 L F
.46965 .72456 m .46926 .72789 L .47157 .72487 L .981 .833 .437 r
F
.46926 .72789 m .4679 .73949 L .47157 .72487 L F
.46652 .753 m .47157 .72487 L .46535 .75807 L 0 0 .088 r
F
.47201 .72446 m .47157 .72487 L .46652 .753 L F
.46683 .7473 m .4679 .73949 L .46672 .74721 L F
.47157 .72487 m .4679 .73949 L .46535 .75807 L F
.4679 .73949 m .45735 .74961 L .4598 .74753 L 0 0 0 r
F
.45676 .74536 m .46817 .74084 L .46939 .73806 L .647 .417 .556 r
F
.47201 .72446 m .46939 .73806 L .48044 .71292 L F
.45676 .74536 m .46939 .73806 L .47201 .72446 L F
.46817 .74084 m .47858 .73672 L .47903 .73094 L F
.46817 .74084 m .47903 .73094 L .48044 .71292 L F
.44455 .76189 m .44439 .76215 L .4598 .74753 L 0 0 0 r
F
.46117 .74881 m .47858 .73672 L .45676 .74536 L .647 .417 .556 r
F
.46997 .74588 m .46652 .753 L .47021 .74657 L 0 0 .088 r
F
.46767 .748 m .46652 .753 L .46997 .74588 L F
.46652 .753 m .46751 .75377 L .47021 .74657 L F
.46785 .74814 m .46741 .76323 L .4704 .74543 L .726 .492 .572 r
F
.448 .75924 m .45774 .76659 L .46446 .76192 L 0 0 0 r
F
.45128 .76171 m .47858 .73672 L .44712 .75857 L .647 .417 .556 r
F
.44005 .77547 m .47858 .73672 L .4318 .77955 L F
.46889 .7427 m .47201 .72446 L .46652 .753 L 0 0 .088 r
F
.46652 .753 m .46446 .76192 L .46751 .75377 L F
.40054 .82326 m .46233 .79285 L .40204 .82101 L .846 .586 .546 r
F
.40278 .82305 m .46233 .79285 L .40054 .82326 L F
.4042 .82292 m .40336 .823 L .40065 .82651 L .363 0 .14 r
F
.40065 .82651 m .40295 .82304 L .40056 .82661 L F
.40295 .82304 m .40292 .82304 L .40056 .82661 L F
.40793 .82095 m .46233 .79285 L .40278 .82305 L .846 .586 .546 r
F
.40793 .82095 m .40278 .82305 L .40332 .823 L F
.45599 .77651 m .45824 .77453 L .41104 .8086 L .789 .547 .571 r
F
.41104 .8086 m .46651 .76856 L .46726 .76413 L .726 .492 .572 r
F
.42266 .79321 m .42266 .79322 L .40292 .82304 L .363 0 .14 r
F
.40292 .82304 m .40292 .82304 L .40056 .82661 L F
.42266 .79321 m .40292 .82304 L .40292 .82304 L F
.40407 .82294 m .40793 .82095 L .40332 .823 L .846 .586 .546 r
F
.46158 .76484 m .43273 .78496 L .40336 .823 L .363 0 .14 r
F
.4318 .77955 m .45128 .76171 L .44712 .75857 L .647 .417 .556 r
F
.42022 .79542 m .4318 .77955 L .43533 .77429 L F
.4006 .80628 m .40215 .80662 L .40482 .80109 L .685 .288 .29 r
F
.42874 .78264 m .43057 .78017 L .43011 .78028 L .527 .3 .513 r
F
.448 .75924 m .4006 .80628 L .43499 .78239 L 0 0 0 r
F
.45268 .76277 m .43499 .78239 L .45774 .76659 L F
.448 .75924 m .43499 .78239 L .45268 .76277 L F
.45785 .76668 m .43306 .78453 L .46158 .76484 L .363 0 .14 r
F
.41889 .80024 m .43032 .78808 L .43306 .78453 L .726 .492 .572 r
F
.43306 .78453 m .42417 .79093 L .43273 .78496 L .363 0 .14 r
F
.43306 .78453 m .43273 .78496 L .46158 .76484 L F
.4006 .80628 m .40203 .80687 L .46446 .76192 L 0 0 0 r
F
.43306 .78453 m .46785 .74814 L .45268 .76277 L .726 .492 .572 r
F
.43032 .78808 m .46785 .74814 L .43306 .78453 L F
.43273 .78496 m .42417 .79093 L .40295 .82304 L .363 0 .14 r
F
.40336 .823 m .40295 .82304 L .40065 .82651 L F
.43273 .78496 m .40295 .82304 L .40336 .823 L F
.41026 .8199 m .40056 .82661 L .44682 .80356 L .61 .236 .308 r
F
.4042 .82292 m .40056 .82661 L .4052 .82242 L .363 0 .14 r
F
.46607 .78591 m .46542 .78371 L .46567 .7869 L .543 .335 .549 r
F
.46542 .78371 m .46461 .78094 L .46519 .7842 L F
.46542 .78371 m .46519 .7842 L .46567 .7869 L F
.46669 .77632 m .46461 .78094 L .46542 .78371 L F
.46634 .7818 m .46542 .78371 L .46607 .78591 L F
.46669 .77632 m .46542 .78371 L .46634 .7818 L F
.49157 .72879 m .49349 .72455 L .46634 .7818 L .789 .613 .662 r
F
.46461 .78094 m .45543 .78749 L .4622 .784 L .61 .236 .308 r
F
.45626 .77283 m .47385 .75891 L .45486 .77164 L .726 .492 .572 r
F
.46639 .77513 m .47021 .74657 L .46461 .78094 L .275 .088 .437 r
F
.47079 .74606 m .47021 .74657 L .46639 .77513 L F
.46592 .77329 m .46735 .77898 L .47276 .76405 L .789 .547 .571 r
F
.44198 .78884 m .44244 .78879 L .45824 .77453 L .363 0 .14 r
F
.4528 .79832 m .46233 .79285 L .40407 .82294 L .846 .586 .546 r
F
.40261 .82307 m .40081 .82323 L .4006 .82607 L .363 0 .14 r
F
.42417 .79093 m .4006 .82607 L .40056 .82661 L F
.40203 .80687 m .39687 .8176 L .39816 .82076 L F
.40041 .81654 m .39816 .82076 L .39971 .82075 L F
.40203 .80687 m .40034 .81294 L .40041 .81654 L F
.40034 .81294 m .39816 .82076 L .40041 .81654 L F
.40001 .82075 m .40204 .82101 L .40335 .80886 L .736 .315 .248 r
F
.40049 .82074 m .40204 .82101 L .40001 .82075 L .764 .294 .128 r
F
.40049 .82074 m .40054 .82326 L .40204 .82101 L F
.40136 .81595 m .39926 .82343 L .40056 .82661 L .363 0 .14 r
F
.40203 .80687 m .39926 .82343 L .40136 .81595 L F
.40335 .80886 m .40204 .82101 L .41104 .8086 L .736 .315 .248 r
F
.42417 .79093 m .40203 .80687 L .40081 .82323 L .363 0 .14 r
F
.39837 .80903 m .40335 .80886 L .39828 .80914 L .736 .315 .248 r
F
.40982 .79713 m .40576 .7985 L .39672 .80964 L 0 0 0 r
F
.39739 .80947 m .39672 .80964 L .39465 .81219 L F
.40982 .79713 m .39672 .80964 L .39739 .80947 L F
.42402 .78304 m .40576 .7985 L .40982 .79713 L F
.41661 .78657 m .41468 .7875 L .4095 .79533 L F
.41468 .7875 m .40356 .79753 L .39767 .80722 L F
.41468 .7875 m .39767 .80722 L .3961 .80979 L F
.39672 .80964 m .3961 .80979 L .39465 .81219 L F
.41468 .7875 m .3961 .80979 L .39672 .80964 L F
.40335 .80886 m .40095 .80913 L .39817 .80927 L .736 .315 .248 r
F
.32703 .8062 m .31712 .809 L .33045 .80675 L .571 .935 .92 r
F
.33207 .80702 m .31712 .809 L .31702 .80881 L .181 .715 .778 r
F
.32207 .80764 m .31702 .80881 L .31657 .80798 L F
.33207 .80702 m .31702 .80881 L .32207 .80764 L F
.26156 .78774 m .27114 .79036 L .26985 .78963 L .517 0 0 r
F
.25834 .78223 m .3269 .80457 L .26156 .78774 L .539 0 0 r
F
.3269 .80457 m .32698 .80562 L .26156 .78774 L F
.28006 .78931 m .32536 .80699 L .3294 .80684 L F
.28006 .78931 m .32244 .80437 L .3269 .80457 L F
.25834 .78223 m .28428 .79191 L .28006 .78931 L F
.28428 .79191 m .32477 .80701 L .28006 .78931 L F
.33207 .80702 m .31657 .80798 L .31622 .80733 L .181 .715 .778 r
F
.33207 .80702 m .31622 .80733 L .32914 .80685 L F
.32477 .80701 m .33909 .81235 L .32536 .80699 L .539 0 0 r
F
.32477 .80701 m .32536 .80699 L .28006 .78931 L F
.32637 .80665 m .32477 .80701 L .31738 .80426 L .52 0 0 r
F
.32107 .80474 m .31738 .80426 L .25834 .78223 L F
.32637 .80665 m .31738 .80426 L .32107 .80474 L F
.25682 .77571 m .31912 .80342 L .25834 .78223 L F
.31912 .80342 m .32192 .80505 L .25834 .78223 L F
.31912 .80342 m .32637 .80665 L .32192 .80505 L F
.25675 .77541 m .25947 .77663 L .25682 .77571 L F
.25947 .77663 m .32637 .80665 L .25682 .77571 L F
.25675 .77541 m .32044 .80653 L .32637 .80665 L F
.26585 .77567 m .27596 .78275 L .26791 .77702 L .836 .368 .065 r
F
.25718 .76715 m .30346 .79493 L .25675 .77541 L .434 0 0 r
F
.30346 .79493 m .32215 .80615 L .26235 .77804 L F
.30346 .79493 m .26235 .77804 L .25675 .77541 L F
.33343 .80669 m .33266 .80688 L .32698 .80562 L .539 0 0 r
F
.33494 .80664 m .33207 .80702 L .33343 .80669 L .181 .715 .778 r
F
.32698 .80562 m .33207 .80702 L .3273 .80562 L .517 0 0 r
F
.33207 .80702 m .33177 .80686 L .3273 .80562 L F
.33676 .80778 m .33207 .80702 L .32698 .80562 L .539 0 0 r
F
.3269 .80457 m .33184 .80675 L .33343 .80669 L F
.33343 .80669 m .33207 .80702 L .32914 .80685 L .181 .715 .778 r
F
.33676 .80778 m .34666 .81101 L .33207 .80702 L .539 0 0 r
F
.32244 .80437 m .34296 .81166 L .3269 .80457 L F
.34986 .80275 m .33343 .80669 L .32288 .80634 L .181 .715 .778 r
F
.32215 .80615 m .32044 .80653 L .31794 .8053 L .434 0 0 r
F
.32134 .80577 m .31794 .8053 L .25675 .77541 L F
.32215 .80615 m .31794 .8053 L .32134 .80577 L F
.3294 .80684 m .33909 .81235 L .34296 .81166 L .539 0 0 r
F
.37321 .7955 m .3554 .80392 L .37449 .80139 L .571 .935 .92 r
F
.37292 .80051 m .36428 .8026 L .35885 .80188 L .181 .715 .778 r
F
.37363 .8009 m .38464 .79725 L .37449 .80139 L .613 .221 .277 r
F
.3742 .80123 m .36428 .8026 L .37292 .80051 L .181 .715 .778 r
F
.34666 .81101 m .37449 .80139 L .36541 .80273 L .502 .096 .203 r
F
.38464 .79725 m .39175 .79528 L .37449 .80139 L .613 .221 .277 r
F
.40866 .78929 m .41024 .78903 L .37449 .80139 L F
.37449 .80139 m .33494 .80664 L .39499 .79836 L .181 .715 .778 r
F
.33343 .80669 m .33676 .80778 L .33266 .80688 L .539 0 0 r
F
.33343 .80669 m .34296 .81166 L .33676 .80778 L F
.33184 .80675 m .34296 .81166 L .33343 .80669 L F
.34033 .8065 m .34666 .81101 L .3431 .80633 L .517 0 0 r
F
.33676 .80778 m .34296 .81166 L .34666 .81101 L .539 0 0 r
F
.33909 .81235 m .37363 .8009 L .37449 .80139 L .613 .221 .277 r
F
.39499 .79836 m .3742 .80123 L .37363 .8009 L .181 .715 .778 r
F
.39499 .79836 m .37363 .8009 L .38614 .79922 L F
.40356 .79753 m .37449 .80139 L .39499 .79836 L F
.38466 .80297 m .38891 .80024 L .39578 .80107 L .721 .988 .872 r
F
.38891 .80024 m .39781 .79963 L .39578 .80107 L F
.39499 .79836 m .38614 .79922 L .38987 .80181 L .181 .715 .778 r
F
.39573 .8008 m .38987 .80181 L .39767 .80722 L F
.39499 .79836 m .38987 .80181 L .39573 .8008 L F
.38987 .80181 m .3921 .80704 L .39767 .80722 L F
.38421 .80294 m .38466 .80297 L .38532 .80286 L .292 0 0 r
F
.38466 .80297 m .38792 .80071 L .38816 .80072 L .721 .988 .872 r
F
.38614 .79922 m .38832 .80208 L .38987 .80181 L .181 .715 .778 r
F
.38832 .80208 m .3921 .80704 L .38987 .80181 L F
.34296 .81166 m .37449 .80139 L .34666 .81101 L .613 .221 .277 r
F
.33909 .81235 m .37449 .80139 L .34296 .81166 L F
.33915 .81233 m .33958 .81224 L .36448 .80643 L F
.33958 .81224 m .38831 .80207 L .36448 .80643 L F
.38831 .80207 m .38814 .80184 L .36448 .80643 L F
.40356 .79753 m .39499 .79836 L .39573 .8008 L .181 .715 .778 r
F
.40226 .79967 m .39573 .8008 L .39767 .80722 L F
.40356 .79753 m .39573 .8008 L .40226 .79967 L F
.36448 .80643 m .40623 .79834 L .40798 .79629 L .613 .221 .277 r
F
.38831 .80207 m .40623 .79834 L .38814 .80184 L F
.38832 .80208 m .40623 .79834 L .38831 .80207 L F
.40737 .79796 m .40623 .79834 L .38832 .80208 L .685 .288 .29 r
F
.33919 .81233 m .38832 .80208 L .33915 .81233 L .613 .221 .277 r
F
.38832 .80208 m .38831 .80207 L .33915 .81233 L F
.38561 .80254 m .38832 .80208 L .33909 .81235 L .685 .288 .29 r
F
.33915 .81233 m .38754 .80106 L .37363 .8009 L .613 .221 .277 r
F
.38754 .80106 m .40798 .79629 L .38614 .79922 L F
.38754 .80106 m .38614 .79922 L .37363 .8009 L F
.32914 .80685 m .31694 .80731 L .32024 .80657 L .181 .715 .778 r
F
.32914 .80685 m .31574 .80643 L .32495 .80662 L F
.32536 .80699 m .33909 .81235 L .3294 .80684 L .539 0 0 r
F
.33343 .80669 m .32914 .80685 L .31556 .80609 L .181 .715 .778 r
F
.32637 .80665 m .33909 .81235 L .32477 .80701 L .52 0 0 r
F
.32637 .80665 m .33298 .81265 L .33909 .81235 L F
.33909 .81235 m .33919 .81233 L .33915 .81233 L .613 .221 .277 r
F
.33298 .81265 m .37406 .80454 L .33909 .81235 L .685 .288 .29 r
F
.37406 .80454 m .38189 .80319 L .33909 .81235 L F
.38189 .80319 m .38561 .80254 L .33909 .81235 L F
.39767 .80722 m .39218 .80714 L .39526 .81118 L .181 .715 .778 r
F
.35415 .80847 m .38131 .81014 L .37406 .80454 L .685 .288 .29 r
F
.33298 .81265 m .37472 .81049 L .35415 .80847 L F
.37472 .81049 m .38131 .81014 L .35415 .80847 L F
.37817 .81022 m .38131 .81014 L .37472 .81049 L .736 .315 .248 r
F
.37374 .81046 m .37472 .81049 L .33298 .81265 L F
.37817 .81022 m .37472 .81049 L .37374 .81046 L F
.39218 .80714 m .35109 .80658 L .38459 .81007 L .181 .715 .778 r
F
.39424 .80984 m .38459 .81007 L .39526 .81118 L F
.39218 .80714 m .38459 .81007 L .39424 .80984 L F
.38459 .81007 m .38068 .80966 L .38131 .81014 L F
.38464 .79725 m .40866 .78929 L .39175 .79528 L .613 .221 .277 r
F
.37363 .8009 m .40798 .79629 L .41605 .78684 L F
.38614 .79922 m .37363 .8009 L .37292 .80051 L .181 .715 .778 r
F
.38614 .79922 m .36932 .80086 L .3921 .80704 L F
.27024 .77499 m .31963 .8055 L .32019 .80564 L .434 0 0 r
F
.30346 .79493 m .32019 .80564 L .32215 .80615 L F
.27024 .77499 m .32019 .80564 L .30346 .79493 L F
.34986 .80275 m .32918 .8055 L .32773 .80491 L .181 .715 .778 r
F
.32564 .80597 m .32288 .80634 L .32019 .80564 L F
.32773 .80491 m .32019 .80564 L .33114 .80631 L F
.32019 .80564 m .32288 .80634 L .31556 .80609 L F
.32019 .80564 m .31556 .80609 L .32101 .80617 L F
.32495 .80662 m .31574 .80643 L .31556 .80609 L F
.32044 .80653 m .33298 .81265 L .32637 .80665 L .52 0 0 r
F
.32215 .80615 m .33298 .81265 L .32044 .80653 L .434 0 0 r
F
.32215 .80615 m .32918 .81139 L .33298 .81265 L F
.32158 .806 m .32918 .81139 L .32215 .80615 L F
.32163 .80656 m .32918 .81139 L .32158 .806 L F
.32164 .80673 m .32906 .81132 L .32163 .80656 L F
.32906 .81132 m .32918 .81139 L .32163 .80656 L F
.37302 .81044 m .37374 .81046 L .33298 .81265 L .736 .315 .248 r
F
.32918 .81139 m .36448 .81019 L .33298 .81265 L F
.36932 .80086 m .37663 .80652 L .3921 .80704 L .181 .715 .778 r
F
.36428 .8026 m .33494 .80664 L .35885 .80188 L F
.33494 .80664 m .33343 .80669 L .34986 .80275 L F
.32773 .80491 m .33114 .80631 L .39218 .80714 L F
.32773 .80491 m .39218 .80714 L .3921 .80704 L F
.38131 .81014 m .39817 .80927 L .37406 .80454 L .685 .288 .29 r
F
.37124 .81038 m .35326 .809 L .36955 .81034 L .149 0 0 r
F
.36955 .81034 m .35326 .809 L .35846 .80969 L F
.36448 .81019 m .35846 .80969 L .36164 .81011 L F
.36955 .81034 m .35846 .80969 L .36448 .81019 L F
.3579 .8107 m .37302 .81044 L .33298 .81265 L .736 .315 .248 r
F
.36448 .81019 m .37124 .81038 L .3579 .8107 L F
.37124 .81038 m .37302 .81044 L .3579 .8107 L F
.35109 .80658 m .34475 .80834 L .37124 .81038 L .181 .715 .778 r
F
.3776 .81023 m .37817 .81022 L .37374 .81046 L .736 .315 .248 r
F
.35109 .80658 m .37124 .81038 L .37916 .8102 L .181 .715 .778 r
F
.38131 .81014 m .35803 .8073 L .37963 .81018 L F
.38068 .80966 m .35803 .8073 L .38131 .81014 L F
.37601 .81027 m .37374 .81046 L .37302 .81044 L .736 .315 .248 r
F
.35803 .8073 m .35746 .8074 L .37916 .8102 L .181 .715 .778 r
F
.35803 .8073 m .37916 .8102 L .37963 .81018 L F
.39481 .80923 m .3776 .81023 L .37601 .81027 L .736 .315 .248 r
F
.3776 .81023 m .37374 .81046 L .37601 .81027 L F
.37963 .81018 m .37916 .8102 L .39465 .81219 L .181 .715 .778 r
F
.37916 .8102 m .37124 .81038 L .39465 .81219 L F
.32918 .81139 m .39442 .81848 L .38868 .81261 L .736 .315 .248 r
F
.39465 .81219 m .38825 .81217 L .39613 .82023 L .149 0 0 r
F
.39465 .81219 m .39613 .82023 L .39816 .82076 L F
.32918 .81139 m .40001 .82075 L .40046 .81914 L .736 .315 .248 r
F
.37684 .81657 m .37959 .81705 L .32918 .81139 L .764 .294 .128 r
F
.37959 .81705 m .38416 .81831 L .32918 .81139 L F
.32918 .81139 m .39509 .81274 L .36448 .81019 L .736 .315 .248 r
F
.32883 .80853 m .37684 .81657 L .32918 .81139 L .764 .294 .128 r
F
.33433 .80907 m .37684 .81657 L .32883 .80853 L F
.32341 .80698 m .32164 .80669 L .3228 .80692 L .149 0 0 r
F
.35412 .80989 m .3228 .8068 L .32341 .80698 L F
.3228 .8068 m .32164 .80669 L .32341 .80698 L F
.3236 .80703 m .32883 .80853 L .32918 .81139 L 0 .243 .707 r
F
.32024 .80657 m .31622 .80733 L .31574 .80643 L .181 .715 .778 r
F
.31694 .80731 m .31622 .80733 L .32024 .80657 L F
.32164 .80669 m .31556 .80609 L .32168 .8072 L .149 0 0 r
F
.32123 .8063 m .31556 .80609 L .32163 .80656 L .181 .715 .778 r
F
.32163 .80656 m .31556 .80609 L .32164 .80669 L .149 0 0 r
F
.32019 .80564 m .32163 .80656 L .32158 .806 L .434 0 0 r
F
.34605 .80651 m .32101 .80617 L .34841 .80732 L .181 .715 .778 r
F
.32101 .80617 m .31556 .80609 L .32123 .8063 L F
.32101 .80617 m .32123 .8063 L .34841 .80732 L F
.31963 .8055 m .32164 .80673 L .32163 .80656 L .434 0 0 r
F
.31963 .8055 m .32163 .80656 L .32019 .80564 L F
.26459 .77171 m .32918 .81139 L .27024 .77499 L F
.3236 .80703 m .32918 .81139 L .32164 .80676 L 0 .243 .707 r
F
.33963 .80928 m .3228 .80692 L .33326 .80901 L .149 0 0 r
F
.35412 .80989 m .3228 .80692 L .33963 .80928 L F
.33433 .80907 m .33574 .80957 L .33708 .80956 L .764 .294 .128 r
F
.33304 .809 m .33574 .80957 L .33433 .80907 L F
.39304 .81943 m .39564 .8201 L .32918 .81139 L F
.39816 .82076 m .39613 .82023 L .39926 .82343 L .149 0 0 r
F
.40049 .82074 m .40001 .82075 L .39613 .82023 L .764 .294 .128 r
F
.39564 .8201 m .39613 .82023 L .32918 .81139 L F
.38825 .81217 m .38551 .81217 L .39613 .82023 L .149 0 0 r
F
.38551 .81217 m .36503 .81211 L .39304 .81943 L F
.38551 .81217 m .39304 .81943 L .39613 .82023 L F
.40049 .82074 m .39613 .82023 L .39564 .8201 L .764 .294 .128 r
F
.37959 .81705 m .39304 .81943 L .38416 .81831 L F
.33744 .80962 m .396 .82228 L .39304 .81943 L F
.33574 .80957 m .37571 .81801 L .33708 .80956 L F
.37571 .81801 m .39603 .82231 L .37494 .81775 L F
.37571 .81801 m .37494 .81775 L .33708 .80956 L F
.39603 .82231 m .396 .82228 L .33708 .80956 L F
.35412 .80989 m .33326 .80901 L .34191 .80953 L .149 0 0 r
F
.39613 .82023 m .39339 .81976 L .39926 .82343 L F
.3374 .80963 m .396 .82228 L .33744 .80962 L .764 .294 .128 r
F
.396 .82228 m .396 .82228 L .33744 .80962 L F
.39339 .81976 m .39657 .82283 L .39926 .82343 L .149 0 0 r
F
.39926 .82343 m .39923 .82342 L .40056 .82661 L F
.39923 .82342 m .39657 .82283 L .39916 .82528 L F
.39923 .82342 m .39916 .82528 L .40056 .82661 L F
.39915 .82548 m .39915 .82548 L .39901 .82555 L .846 .586 .546 r
F
.32164 .80669 m .32168 .8072 L .33089 .80887 L .149 0 0 r
F
.33227 .80895 m .39506 .83146 L .39916 .82532 L .764 .294 .128 r
F
.33098 .80887 m .39506 .83146 L .33227 .80895 L F
.32164 .80669 m .33083 .80885 L .33326 .80901 L .149 0 0 r
F
.33083 .80885 m .33089 .80887 L .33098 .80887 L F
.33083 .80885 m .33098 .80887 L .33326 .80901 L F
.32877 .80809 m .33433 .80907 L .32883 .80853 L .764 .294 .128 r
F
.32877 .80809 m .333 .80913 L .33469 .80934 L F
.333 .80913 m .39916 .82532 L .33469 .80934 L F
.33469 .80934 m .39916 .82532 L .39603 .82231 L F
.35038 .81134 m .37197 .82106 L .33098 .80887 L .718 .185 0 r
F
.37197 .82106 m .39506 .83146 L .37575 .82465 L F
.37197 .82106 m .37575 .82465 L .33098 .80887 L F
.35708 .81367 m .39506 .83146 L .35038 .81134 L F
.35708 .81367 m .39282 .83898 L .39506 .83146 L F
.35274 .81164 m .35708 .81367 L .35038 .81134 L F
.35274 .81164 m .35485 .81308 L .35708 .81367 L F
.35485 .81308 m .39282 .83898 L .35708 .81367 L F
.39506 .83146 m .40119 .82794 L .39872 .82598 L .846 .586 .546 r
F
.40056 .82661 m .40053 .827 L .40297 .8297 L .356 0 0 r
F
.40056 .82661 m .40297 .8297 L .40193 .82816 L F
.39506 .83146 m .40307 .82986 L .40119 .82794 L .846 .586 .546 r
F
.39282 .83898 m .40407 .83531 L .39506 .83146 L .902 .603 .47 r
F
.40407 .83531 m .40627 .83459 L .40158 .83328 L F
.40407 .83531 m .40158 .83328 L .39506 .83146 L F
.48064 .80638 m .47788 .81044 L .47554 .81784 L .808 .634 .665 r
F
.47788 .81044 m .4744 .81558 L .4754 .81758 L F
.47788 .81044 m .4754 .81758 L .47554 .81784 L F
.48483 .79042 m .47788 .81044 L .49368 .78034 L .953 .819 .675 r
F
.48913 .78728 m .47138 .80955 L .4744 .81558 L .808 .634 .665 r
F
.52201 .73787 m .58171 .64862 L .54146 .73365 L .794 .728 .79 r
F
.54146 .73365 m .60896 .64054 L .56108 .72766 L .799 .757 .815 r
F
.54146 .73365 m .58171 .64862 L .60896 .64054 L F
.54362 .72827 m .53589 .74128 L .56122 .73085 L .92 .85 .758 r
F
.53589 .74128 m .52741 .76848 L .56122 .73085 L F
.56122 .73085 m .53073 .77631 L .58444 .73387 L .897 .854 .792 r
F
.52862 .77794 m .53053 .777 L .53073 .77631 L .814 .762 .804 r
F
.52982 .77766 m .48868 .82073 L .50222 .81881 L .897 .854 .792 r
F
.52676 .7805 m .48868 .82073 L .52982 .77766 L F
.49964 .80284 m .52982 .77766 L .51305 .78558 L .88 .959 .848 r
F
.52982 .77766 m .52862 .77794 L .51305 .78558 L F
.56122 .73085 m .53401 .76457 L .53073 .77631 L .897 .854 .792 r
F
.53073 .77631 m .58092 .73751 L .58444 .73387 L F
.51305 .78558 m .52862 .77794 L .58086 .73679 L .814 .762 .804 r
F
.51305 .78558 m .58086 .73679 L .52741 .76848 L F
.49922 .80298 m .48868 .82073 L .50443 .80122 L .92 .85 .758 r
F
.51305 .78558 m .52741 .76848 L .53956 .72949 L .814 .762 .804 r
F
.53963 .727 m .5365 .732 L .53977 .729 L .896 .772 .717 r
F
.53963 .727 m .53977 .729 L .53984 .72889 L F
.54012 .72716 m .53984 .72894 L .54135 .72755 L F
.53963 .727 m .53984 .72894 L .54012 .72716 L F
.49024 .80604 m .51305 .78558 L .53985 .72887 L .92 .842 .75 r
F
.53956 .72949 m .53865 .73573 L .53985 .72887 L .814 .762 .804 r
F
.53865 .73573 m .53887 .73528 L .53985 .72887 L F
.54362 .72827 m .53887 .73528 L .53589 .74128 L .92 .85 .758 r
F
.52741 .76848 m .53521 .75919 L .53956 .72949 L .814 .762 .804 r
F
.5365 .732 m .49011 .8061 L .54135 .72755 L .896 .772 .717 r
F
.49011 .8061 m .4806 .8213 L .49058 .80589 L F
.50381 .79405 m .51305 .78558 L .50343 .79421 L .793 .955 .624 r
F
.51046 .78864 m .51305 .78558 L .49122 .80561 L F
.51554 .77551 m .50475 .79368 L .52741 .76848 L .92 .85 .758 r
F
.50695 .7928 m .49964 .80284 L .51305 .78558 L .793 .955 .624 r
F
.50475 .79368 m .49922 .80298 L .50783 .79245 L .92 .85 .758 r
F
.50475 .79368 m .4806 .8213 L .48868 .82073 L F
.49177 .80513 m .4806 .8213 L .50475 .79368 L F
.49122 .80561 m .50381 .79405 L .49024 .80604 L .793 .955 .624 r
F
.50381 .79405 m .50343 .79421 L .49024 .80604 L F
.53887 .73528 m .49122 .80561 L .53589 .74128 L .92 .85 .758 r
F
.49122 .80561 m .4806 .8213 L .49177 .80513 L F
.49122 .80561 m .49177 .80513 L .53589 .74128 L F
.54135 .72755 m .4806 .8213 L .54362 .72827 L .896 .772 .717 r
F
.51033 .76337 m .4806 .8213 L .53963 .727 L F
.49368 .78034 m .53307 .73514 L .50033 .76515 L .812 .687 .726 r
F
.48811 .79096 m .51438 .75659 L .49368 .78034 L .92 .842 .75 r
F
.47855 .80917 m .50661 .76799 L .48811 .79096 L F
.50661 .76799 m .51438 .75659 L .48811 .79096 L F
.48064 .80638 m .51438 .75659 L .47855 .80917 L F
.51033 .76337 m .47554 .81784 L .4806 .8213 L .896 .772 .717 r
F
.49466 .78665 m .47554 .81784 L .51033 .76337 L F
.50033 .76515 m .51763 .7487 L .50437 .7559 L .812 .687 .726 r
F
.51763 .7487 m .51835 .74481 L .50437 .7559 L F
.53049 .72409 m .51835 .74481 L .5175 .74941 L .896 .772 .717 r
F
.53049 .72409 m .5175 .74941 L .53963 .727 L F
.48814 .79634 m .47554 .81784 L .49466 .78665 L F
.48064 .80638 m .47554 .81784 L .48814 .79634 L .808 .634 .665 r
F
.54113 .72617 m .53963 .727 L .54081 .72738 L .722 .627 .751 r
F
.54121 .72585 m .54109 .72594 L .54113 .72617 L F
.54109 .72594 m .53963 .727 L .54113 .72617 L F
.53586 .68971 m .54456 .67511 L .53816 .69994 L .743 .634 .739 r
F
.53018 .69166 m .53049 .72409 L .53508 .6852 L .683 .581 .735 r
F
.53018 .69166 m .52042 .71698 L .53049 .72409 L F
.53018 .69166 m .54484 .66341 L .53014 .69171 L .812 .687 .726 r
F
.52279 .61668 m .55611 .63022 L .55002 .65387 L .743 .634 .739 r
F
.53333 .65684 m .52957 .63033 L .53822 .62386 L .699 .548 .679 r
F
.52914 .61597 m .55611 .63022 L .52279 .61668 L .743 .634 .739 r
F
.55611 .63022 m .55835 .6413 L .55531 .64742 L F
.5541 .64576 m .55531 .64742 L .55339 .65127 L F
.55611 .63022 m .55531 .64742 L .5541 .64576 L F
.53333 .65684 m .53822 .62386 L .55608 .65379 L .699 .548 .679 r
F
.51786 .63848 m .52012 .70773 L .5238 .67581 L .609 .514 .722 r
F
.52012 .70773 m .52042 .71698 L .52131 .70619 L F
.52012 .70773 m .52131 .70619 L .5238 .67581 L F
.51575 .65346 m .51977 .70818 L .51786 .63848 L F
.51977 .70818 m .52042 .71698 L .52012 .70773 L F
.51977 .70818 m .52012 .70773 L .51786 .63848 L F
.52131 .70619 m .52042 .71698 L .53012 .69182 L .683 .581 .735 r
F
.53011 .69179 m .53012 .69182 L .53018 .69166 L F
.52131 .70619 m .53012 .69182 L .53011 .69179 L F
.5238 .67581 m .52131 .70619 L .53011 .69179 L F
.51455 .66215 m .51208 .70636 L .51674 .71229 L .609 .514 .722 r
F
.51977 .70818 m .51674 .71229 L .52042 .71698 L F
.5091 .69879 m .52171 .60882 L .50939 .69103 L .719 .599 .722 r
F
.50904 .69852 m .50648 .69587 L .50882 .70025 L .47 .41 .709 r
F
.50886 .69778 m .50648 .69587 L .50904 .69852 L F
.51015 .69343 m .50882 .70025 L .51208 .70636 L F
.50839 .69579 m .5091 .69879 L .50939 .69103 L .789 .613 .662 r
F
.50987 .69485 m .52171 .60882 L .5091 .69879 L .719 .599 .722 r
F
.50901 .70123 m .51336 .67034 L .50902 .70102 L F
.51015 .69343 m .51208 .70636 L .51203 .68045 L .47 .41 .709 r
F
.50896 .70279 m .51137 .68502 L .50901 .70123 L .719 .599 .722 r
F
.51137 .68502 m .51336 .67034 L .50901 .70123 L F
.51336 .67034 m .52171 .60882 L .50902 .70102 L F
.5072 .6549 m .5072 .63969 L .50936 .65953 L .784 .572 .613 r
F
.49987 .63914 m .5072 .63969 L .5072 .6549 L F
.49344 .59072 m .49861 .5948 L .50038 .60346 L .732 .556 .654 r
F
.5072 .63969 m .50651 .6334 L .5072 .63674 L .784 .572 .613 r
F
.5107 .66077 m .51076 .66069 L .5108 .66072 L .872 .767 .743 r
F
.51076 .66069 m .51077 .6607 L .51073 .66087 L .743 .634 .739 r
F
.51071 .66076 m .51071 .66075 L .51073 .66087 L .732 .556 .654 r
F
.50912 .65572 m .5072 .63969 L .50833 .64226 L .784 .572 .613 r
F
.50933 .65932 m .50892 .65548 L .50912 .65572 L F
.50892 .65548 m .5072 .63969 L .50912 .65572 L F
.51016 .66133 m .51048 .66057 L .51055 .66088 L .872 .767 .743 r
F
.50933 .65932 m .50833 .64226 L .51131 .65682 L .784 .572 .613 r
F
.5107 .66077 m .51071 .66076 L .51073 .66087 L .732 .556 .654 r
F
.49987 .63914 m .48871 .58205 L .50038 .60346 L .784 .572 .613 r
F
.49987 .63914 m .50576 .6518 L .50168 .64437 L .732 .556 .654 r
F
.51055 .66088 m .51048 .66057 L .51067 .66074 L .872 .767 .743 r
F
.5107 .66077 m .51073 .66087 L .51067 .66074 L .732 .556 .654 r
F
.51244 .60206 m .5147 .59537 L .51793 .61004 L .65 .463 .618 r
F
.50939 .69103 m .52171 .60882 L .51723 .60442 L .627 .537 .734 r
F
.51076 .66069 m .51179 .65918 L .5108 .66072 L .872 .767 .743 r
F
.50939 .69103 m .51723 .60442 L .51379 .60988 L .627 .537 .734 r
F
.51187 .60086 m .51237 .61215 L .51267 .61167 L .609 .514 .722 r
F
.49584 .66888 m .49706 .67482 L .49693 .66608 L .175 .215 .665 r
F
.50381 .68483 m .50939 .69103 L .49668 .66711 L .701 .531 .655 r
F
.50682 .6923 m .5075 .69197 L .50381 .68483 L F
.5075 .69197 m .50939 .69103 L .50381 .68483 L F
.48247 .67464 m .48245 .67505 L .4828 .67512 L .981 .833 .437 r
F
.47648 .66606 m .48245 .67505 L .48247 .67464 L F
.47899 .6864 m .47737 .67728 L .48051 .67976 L .07 .081 .562 r
F
.47737 .67728 m .47884 .67644 L .48051 .67976 L F
.4803 .69383 m .47899 .6864 L .48051 .67976 L F
.4803 .69383 m .47787 .67076 L .47749 .67093 L F
.4803 .69383 m .47749 .67093 L .47737 .67728 L F
.4791 .69104 m .47629 .66575 L .47787 .67076 L .437 .333 .639 r
F
.4788 .69435 m .47701 .67398 L .4791 .69104 L F
.47701 .67398 m .47629 .66575 L .47672 .66962 L F
.47701 .67398 m .47672 .66962 L .4791 .69104 L F
.47158 .70796 m .47378 .70394 L .4781 .69015 L .981 .833 .437 r
F
.47548 .70965 m .48044 .71292 L .48036 .70205 L .527 .3 .513 r
F
.47134 .7161 m .48044 .71292 L .47548 .70965 L F
.44489 .75727 m .48036 .70205 L .44408 .75622 L F
.47342 .70569 m .47952 .70249 L .47896 .69614 L F
.47952 .70249 m .48036 .70205 L .47896 .69614 L F
.47896 .69614 m .48036 .70205 L .4803 .69383 L F
.472 .7128 m .48036 .70205 L .47342 .70569 L F
.48044 .71292 m .4788 .69435 L .4791 .69104 L .437 .333 .639 r
F
.48035 .70051 m .47787 .67076 L .4803 .69383 L F
.48044 .71292 m .47787 .67076 L .48035 .70051 L F
.48044 .71292 m .48023 .68945 L .4788 .69435 L F
.4944 .66188 m .49584 .66888 L .49653 .66712 L .175 .215 .665 r
F
.46958 .74603 m .47858 .73672 L .46868 .74668 L .726 .492 .572 r
F
.46997 .74588 m .47858 .73672 L .46767 .748 L F
.478 .73717 m .47072 .7452 L .47692 .74069 L .275 .088 .437 r
F
.47444 .72113 m .48044 .71292 L .47344 .72243 L .647 .417 .556 r
F
.45967 .74092 m .48044 .71292 L .45944 .74103 L .527 .3 .513 r
F
.46916 .72699 m .48044 .71292 L .47134 .7161 L F
.44612 .75885 m .48044 .71292 L .44489 .75727 L F
.46434 .73478 m .48044 .71292 L .45967 .74092 L .647 .417 .556 r
F
.44844 .75646 m .48044 .71292 L .44524 .76073 L F
.48004 .71392 m .47991 .71425 L .48037 .70878 L .598 .448 .65 r
F
.48044 .71292 m .48201 .68331 L .48014 .67982 L .437 .333 .639 r
F
.48037 .70878 m .48085 .69776 L .48201 .68331 L .598 .448 .65 r
F
.47984 .71515 m .48085 .69776 L .48037 .70878 L F
.48155 .68759 m .47856 .69704 L .47808 .70234 L 0 0 .088 r
F
.48186 .68471 m .47856 .69704 L .48155 .68759 L F
.48149 .68807 m .47808 .70234 L .47938 .69725 L F
.48085 .69776 m .48149 .68807 L .48201 .68331 L .598 .448 .65 r
F
.47914 .72955 m .48201 .68331 L .48044 .71292 L F
.47858 .73672 m .48037 .70878 L .47914 .72955 L F
.48037 .70878 m .48201 .68331 L .48058 .70626 L F
.48037 .70878 m .48058 .70626 L .47914 .72955 L F
.47858 .73672 m .47984 .71515 L .47991 .71425 L F
.47858 .73672 m .47991 .71425 L .48004 .71392 L F
.47882 .73258 m .48193 .71163 L .47989 .71432 L F
.47882 .73258 m .4876 .70012 L .48205 .71087 L F
.4876 .70012 m .48761 .70008 L .48759 .70012 L F
.4851 .69925 m .48669 .6998 L .49003 .69175 L 0 0 .088 r
F
.49126 .68667 m .49003 .69175 L .49706 .67482 L F
.4851 .69925 m .49003 .69175 L .49126 .68667 L F
.48305 .72234 m .48476 .71505 L .48798 .70025 L .701 .531 .655 r
F
.48476 .71505 m .48844 .69847 L .48798 .70025 L F
.48127 .72807 m .48798 .70025 L .47858 .73672 L F
.48305 .72234 m .48798 .70025 L .48127 .72807 L F
.47975 .73217 m .48844 .69847 L .47882 .73258 L .598 .448 .65 r
F
.49706 .67482 m .48878 .69693 L .49185 .69186 L .275 .088 .437 r
F
.48878 .69693 m .48759 .70012 L .48844 .69847 L F
.48878 .69693 m .48844 .69847 L .49185 .69186 L F
.48844 .69847 m .48765 .70205 L .49185 .69186 L F
.48844 .69847 m .48761 .70008 L .47882 .73258 L .598 .448 .65 r
F
.47923 .72247 m .47909 .72406 L .49185 .69186 L .275 .088 .437 r
F
.49185 .69186 m .47909 .72406 L .47829 .73364 L F
.47858 .73672 m .47975 .73217 L .47882 .73258 L .598 .448 .65 r
F
.48236 .72289 m .47829 .73364 L .478 .73717 L .275 .088 .437 r
F
.49185 .69186 m .47829 .73364 L .48236 .72289 L F
.50768 .69443 m .50648 .69587 L .50911 .69798 L .47 .41 .709 r
F
.5058 .68976 m .50452 .6922 L .50648 .69587 L F
.50939 .69103 m .51379 .60988 L .5039 .65234 L .627 .537 .734 r
F
.51379 .60988 m .51389 .60811 L .51332 .61064 L F
.51379 .60988 m .51332 .61064 L .5039 .65234 L F
.51187 .60086 m .5119 .61289 L .51237 .61215 L .609 .514 .722 r
F
.51187 .60086 m .51267 .61167 L .5133 .60982 L F
.51389 .60811 m .50389 .65172 L .5039 .65234 L .627 .537 .734 r
F
.50939 .69103 m .5039 .65234 L .50424 .66826 L F
.50798 .69408 m .50839 .69579 L .50939 .69103 L .789 .613 .662 r
F
.50768 .69443 m .50939 .69103 L .50682 .6923 L .701 .531 .655 r
F
.50798 .69408 m .50768 .69443 L .50862 .69678 L .47 .41 .709 r
F
.50421 .70224 m .50939 .69103 L .49965 .71181 L .789 .613 .662 r
F
.50794 .69413 m .50939 .69103 L .50789 .69418 L F
.49349 .72455 m .50939 .69103 L .50199 .70579 L F
.50939 .69103 m .50548 .67375 L .5 .65363 L .627 .537 .734 r
F
.50548 .67375 m .504 .66742 L .5 .65363 L F
.48048 .58326 m .49987 .63914 L .48274 .60235 L .732 .556 .654 r
F
.48274 .60235 m .49987 .63914 L .48388 .61193 L F
.49987 .63914 m .50168 .64437 L .48388 .61193 L F
.504 .66742 m .49285 .62035 L .5 .65363 L .627 .537 .734 r
F
.50424 .66826 m .50088 .65412 L .504 .66742 L F
.50088 .65412 m .49285 .62035 L .504 .66742 L F
.49987 .63914 m .48302 .58293 L .48971 .58716 L .784 .572 .613 r
F
.48031 .58182 m .49987 .63914 L .48048 .58326 L .732 .556 .654 r
F
.48707 .60225 m .48296 .58294 L .49234 .61744 L .784 .572 .613 r
F
.49961 .63839 m .49995 .63932 L .49987 .63914 L .732 .556 .654 r
F
.49234 .61744 m .48296 .58294 L .49987 .63914 L .784 .572 .613 r
F
.48494 .58613 m .49163 .61469 L .49495 .59206 L .175 .215 .665 r
F
.49163 .61469 m .49918 .64688 L .49684 .61657 L F
.49163 .61469 m .49684 .61657 L .49495 .59206 L F
.5 .65363 m .48532 .61242 L .48542 .61355 L .511 .482 .761 r
F
.48261 .60897 m .47647 .60202 L .4803 .58947 L .859 .611 .562 r
F
.47647 .60202 m .48096 .58731 L .48388 .61193 L .722 .458 .527 r
F
.4803 .58947 m .46969 .58559 L .47961 .58361 L .859 .611 .562 r
F
.46738 .57339 m .48031 .58182 L .46305 .57323 L .722 .458 .527 r
F
.46969 .58559 m .46738 .57339 L .48225 .58308 L .68 .316 .35 r
F
.478 .58202 m .48611 .62152 L .48532 .61242 L .175 .215 .665 r
F
.4788 .69435 m .48014 .67982 L .47701 .67398 L .437 .333 .639 r
F
.48023 .68945 m .48014 .67982 L .4788 .69435 L F
.47803 .6891 m .4781 .69015 L .4828 .67512 L .981 .833 .437 r
F
.47629 .66575 m .47753 .66777 L .47787 .67076 L .437 .333 .639 r
F
.47753 .66777 m .47755 .66779 L .47787 .67076 L F
.48051 .67976 m .47868 .67093 L .47888 .67155 L .787 .521 0 r
F
.48051 .67976 m .47882 .67167 L .47886 .67177 L F
.47648 .66606 m .47701 .67398 L .48245 .67505 L .981 .833 .437 r
F
.47701 .67398 m .48079 .68103 L .4828 .67512 L F
.48446 .64744 m .48546 .65859 L .48387 .65715 L .874 .745 .717 r
F
.48545 .65194 m .48544 .64925 L .48917 .66433 L .957 .664 .437 r
F
.48037 .63278 m .47781 .6547 L .48918 .65476 L .981 .833 .437 r
F
.48499 .66926 m .48304 .67024 L .48549 .66788 L .964 .935 .627 r
F
.47781 .6547 m .4828 .67512 L .48918 .65476 L .981 .833 .437 r
F
.48197 .64002 m .48037 .63278 L .4845 .6431 L .888 .491 .049 r
F
.48197 .64002 m .4845 .6431 L .48417 .64452 L F
.48408 .64433 m .48417 .64452 L .48412 .64345 L F
.48408 .64433 m .48412 .64345 L .48399 .64035 L F
.48197 .64002 m .48408 .64433 L .48399 .64035 L F
.48417 .64452 m .48426 .64116 L .48399 .64035 L F
.48417 .64452 m .4845 .6431 L .48918 .65476 L F
.4881 .65255 m .4884 .65247 L .48429 .6404 L F
.48429 .6404 m .48504 .62616 L .48384 .63928 L .437 .333 .639 r
F
.48429 .6404 m .48384 .63928 L .48375 .64031 L F
.49148 .65892 m .48918 .65476 L .49706 .67482 L 0 0 .413 r
F
.49025 .65568 m .48918 .65476 L .49148 .65892 L F
.49019 .65553 m .49069 .65273 L .49006 .65518 L .598 .448 .65 r
F
.48429 .6404 m .48918 .65476 L .49025 .65568 L 0 0 .413 r
F
.48429 .6404 m .49025 .65568 L .48831 .65056 L F
.49025 .65567 m .49272 .66017 L .49069 .65273 L .598 .448 .65 r
F
.49148 .65892 m .49706 .67482 L .4944 .66188 L 0 0 .413 r
F
.49562 .66985 m .49653 .66712 L .49025 .65567 L .598 .448 .65 r
F
.49025 .65567 m .49069 .65273 L .49019 .65553 L F
.4726 .62089 m .47108 .6065 L .47215 .6197 L .07 .081 .562 r
F
.45192 .59029 m .46909 .61165 L .47255 .62111 L .897 .5 .256 r
F
.46909 .61165 m .4726 .62089 L .47255 .62111 L F
.47094 .6187 m .47255 .62111 L .47178 .61914 L F
.47255 .62111 m .47108 .6065 L .4726 .62089 L .437 .333 .639 r
F
.47253 .62123 m .47248 .62075 L .47255 .62111 L F
.47248 .62075 m .47108 .6065 L .47255 .62111 L F
.47227 .62002 m .47108 .6065 L .47253 .62123 L F
.47221 .61937 m .48509 .62536 L .47108 .6065 L F
.48504 .62616 m .48509 .62536 L .47221 .61937 L F
.47236 .61945 m .47372 .6199 L .47143 .61547 L .897 .5 .256 r
F
.47284 .62154 m .47361 .62011 L .47236 .61945 L F
.47361 .62011 m .47372 .6199 L .47236 .61945 L F
.46863 .61044 m .46752 .60167 L .46829 .60953 L .07 .081 .562 r
F
.46364 .5998 m .46752 .60167 L .46284 .59531 L F
.48156 .62125 m .47636 .61498 L .47108 .6065 L .315 .407 .797 r
F
.47636 .61498 m .46265 .59846 L .47108 .6065 L F
.46285 .5985 m .45579 .59163 L .46285 .59851 L 0 .222 .744 r
F
.45579 .59163 m .4558 .59165 L .46285 .59851 L F
.45606 .59196 m .4561 .59201 L .46289 .59862 L F
.46285 .59851 m .45582 .59168 L .46289 .59862 L F
.45582 .59168 m .45606 .59196 L .46289 .59862 L F
.46284 .59531 m .45235 .58581 L .45354 .58665 L .679 .139 0 r
F
.47108 .6065 m .46289 .59862 L .46284 .59531 L 0 .222 .744 r
F
.44911 .58514 m .44912 .58516 L .46996 .60543 L F
.46289 .59862 m .44394 .58017 L .44462 .58105 L F
.47108 .6065 m .44606 .57846 L .45178 .58774 L F
.46265 .59846 m .44921 .58225 L .46371 .59833 L .315 .407 .797 r
F
.4354 .56561 m .44031 .57294 L .44058 .57185 L .897 .5 .256 r
F
.44031 .57294 m .45481 .58685 L .44327 .56091 L F
.41873 .54942 m .42497 .55134 L .41831 .54836 L .403 0 0 r
F
.44447 .57668 m .42003 .54929 L .45178 .58774 L 0 .222 .744 r
F
.42003 .54929 m .41923 .54879 L .45178 .58774 L F
.42609 .55662 m .41977 .54926 L .42961 .56002 L .315 .407 .797 r
F
.40943 .54465 m .41002 .54476 L .40989 .54485 L .403 0 0 r
F
.40943 .54465 m .40989 .54485 L .40805 .54615 L F
.39484 .54209 m .40943 .54465 L .40805 .54615 L F
.40251 .54268 m .41002 .54476 L .39484 .54209 L F
.40698 .5424 m .39858 .54238 L .40108 .54257 L .264 .671 .967 r
F
.41373 .54222 m .4062 .5423 L .40698 .5424 L F
.4062 .5423 m .39858 .54238 L .40698 .5424 L F
.40251 .54268 m .40947 .54447 L .41002 .54476 L .403 0 0 r
F
.40314 .54273 m .40947 .54447 L .40251 .54268 L F
.43562 .57203 m .4086 .54575 L .43626 .57269 L 0 .222 .744 r
F
.43403 .57052 m .4086 .54575 L .43581 .57242 L F
.4086 .54575 m .40878 .54642 L .40957 .54732 L F
.45178 .58774 m .41923 .54879 L .409 .54275 L F
.42497 .55134 m .41824 .54819 L .41831 .54836 L .403 0 0 r
F
.41871 .54848 m .42607 .55168 L .41919 .54877 L .434 0 0 r
F
.41923 .54879 m .40924 .54272 L .409 .54275 L 0 .222 .744 r
F
.40989 .54485 m .41002 .54476 L .41128 .54543 L .403 0 0 r
F
.40989 .54485 m .41128 .54543 L .41873 .54942 L F
.40805 .54615 m .40989 .54485 L .41873 .54942 L F
.41373 .54222 m .3861 .53641 L .33533 .53391 L .264 .671 .967 r
F
.3861 .53641 m .33458 .53219 L .33533 .53391 L F
.34312 .52622 m .35621 .52985 L .35447 .52953 L .403 0 0 r
F
.34312 .52622 m .35304 .52926 L .35707 .52114 L F
.39442 .54124 m .37727 .54037 L .39858 .54238 L .264 .671 .967 r
F
.41373 .54222 m .33533 .53391 L .37727 .54037 L F
.37275 .53531 m .39858 .54238 L .39484 .54209 L .403 0 0 r
F
.35304 .52926 m .39353 .54169 L .38295 .53573 L F
.35304 .52926 m .38295 .53573 L .35707 .52114 L F
.39704 .53877 m .39036 .53733 L .39744 .53881 L .379 .639 .957 r
F
.4087 .54278 m .40502 .54316 L .40525 .54317 L .264 .671 .967 r
F
.40924 .54272 m .40502 .54316 L .4087 .54278 L F
.41373 .54222 m .40918 .54271 L .40924 .54272 L F
.40918 .54271 m .40502 .54316 L .40924 .54272 L F
.39353 .54169 m .41873 .54942 L .39415 .53815 L .403 0 0 r
F
.39353 .54169 m .39415 .53815 L .38295 .53573 L F
.3954 .53872 m .39613 .53901 L .39437 .53819 L F
.41734 .51563 m .41122 .51661 L .43127 .51744 L .12 .646 .876 r
F
.3723 .5129 m .40592 .51084 L .36361 .5084 L .483 .612 .904 r
F
.40592 .51084 m .43261 .50921 L .4113 .50896 L F
.40592 .51084 m .4113 .50896 L .36361 .5084 L F
.37647 .51506 m .38805 .51385 L .3723 .5129 L F
.38805 .51385 m .39581 .51304 L .3723 .5129 L F
.46064 .51895 m .45188 .51883 L .47137 .52043 L .182 .659 .931 r
F
.43861 .51591 m .44131 .51629 L .43261 .50921 L .571 .605 .848 r
F
.44131 .51629 m .45878 .5187 L .45228 .51634 L F
.44131 .51629 m .45228 .51634 L .43261 .50921 L F
.40087 .51252 m .43261 .50921 L .39241 .51167 L .483 .612 .904 r
F
.44161 .51701 m .43833 .51714 L .45188 .51883 L .15 .652 .908 r
F
.43833 .51714 m .43127 .51744 L .43753 .51786 L F
.43833 .51714 m .43753 .51786 L .45188 .51883 L F
.43893 .51627 m .45188 .51883 L .44131 .51629 L F
.439 .51654 m .43854 .51601 L .43876 .51676 L .571 .605 .848 r
F
.43854 .51601 m .43261 .50921 L .43837 .51628 L F
.43854 .51601 m .43837 .51628 L .43876 .51676 L F
.44014 .51356 m .44335 .51678 L .46579 .51903 L .182 .659 .931 r
F
.43893 .51627 m .43261 .50921 L .439 .51654 L .571 .605 .848 r
F
.41961 .5151 m .43127 .51744 L .44161 .51701 L .15 .652 .908 r
F
.39312 .51533 m .41122 .51661 L .39595 .51433 L .111 .652 .846 r
F
.39595 .51433 m .41122 .51661 L .41734 .51563 L .12 .646 .876 r
F
.417 .51571 m .43261 .50921 L .37647 .51506 L .483 .612 .904 r
F
.41734 .51563 m .43127 .51744 L .41961 .5151 L .12 .646 .876 r
F
.43819 .51605 m .43457 .51162 L .417 .51571 L .483 .612 .904 r
F
.43457 .51162 m .43261 .50921 L .417 .51571 L F
.39581 .51304 m .40087 .51252 L .38508 .51212 L F
.40087 .51252 m .39241 .51167 L .38508 .51212 L F
.36179 .51542 m .36361 .5084 L .3533 .51544 L .379 .639 .957 r
F
.37281 .51317 m .3642 .5087 L .36163 .51604 L F
.3642 .5087 m .36361 .5084 L .36163 .51604 L F
.33806 .52631 m .33497 .52566 L .33658 .52712 L .264 .671 .967 r
F
.33658 .52712 m .34028 .52661 L .33806 .52631 L .338 .815 .885 r
F
.33752 .52623 m .33141 .52491 L .33806 .52631 L .379 .639 .957 r
F
.36056 .5191 m .35724 .52108 L .37374 .51801 L .217 .737 .848 r
F
.34323 .52233 m .36361 .5084 L .33255 .52433 L .379 .639 .957 r
F
.34635 .52266 m .34687 .51984 L .33877 .52538 L F
.34653 .52172 m .35724 .52108 L .36056 .5191 L .217 .737 .848 r
F
.34629 .52299 m .35724 .52108 L .34653 .52172 L .338 .815 .885 r
F
.37281 .51317 m .34687 .51984 L .34635 .52266 L .379 .639 .957 r
F
.37281 .51317 m .33877 .52538 L .33967 .52544 L F
.33627 .52728 m .33141 .52491 L .33317 .52896 L .264 .671 .967 r
F
.33497 .52566 m .33141 .52491 L .33734 .5278 L F
.3343 .52743 m .33658 .52712 L .33967 .52544 L .338 .815 .885 r
F
.33734 .5278 m .34312 .52622 L .33658 .52712 L .485 .894 .927 r
F
.33734 .5278 m .33469 .53199 L .34312 .52622 L F
.3861 .53641 m .33826 .52635 L .33458 .53219 L .264 .671 .967 r
F
.33826 .52635 m .33457 .53218 L .33458 .53219 L F
.34281 .52738 m .33752 .52623 L .34569 .52791 L .379 .639 .957 r
F
.33752 .52623 m .33806 .52631 L .34569 .52791 L F
.33806 .52631 m .34312 .52622 L .3432 .52353 L .338 .815 .885 r
F
.34028 .52661 m .34312 .52622 L .33806 .52631 L F
.37635 .51667 m .37374 .51801 L .38107 .51747 L .14 .68 .834 r
F
.37955 .51667 m .38107 .51747 L .39193 .51667 L F
.37635 .51667 m .38107 .51747 L .37955 .51667 L F
.4267 .54407 m .43497 .54338 L .43327 .54413 L .462 0 .036 r
F
.43371 .54346 m .43259 .54358 L .43528 .54334 L .124 .673 .727 r
F
.43259 .54358 m .43436 .54343 L .43528 .54334 L F
.43436 .54343 m .43463 .54341 L .43528 .54334 L F
.43605 .54464 m .41466 .54489 L .43528 .54334 L .745 .291 .174 r
F
.43638 .54276 m .47436 .5738 L .43903 .55129 L .627 .339 .461 r
F
.47621 .57687 m .46666 .54985 L .48215 .58129 L .68 .316 .35 r
F
.46648 .56072 m .46666 .54985 L .47621 .57687 L F
.45088 .54498 m .47892 .5703 L .47991 .57848 L .627 .339 .461 r
F
.46636 .56803 m .46648 .56072 L .47621 .57687 L .68 .316 .35 r
F
.46429 .55709 m .47644 .54978 L .47892 .5703 L .627 .339 .461 r
F
.46636 .56803 m .46429 .55709 L .46648 .56072 L .68 .316 .35 r
F
.46651 .5688 m .43736 .54287 L .45026 .54442 L F
.46651 .5688 m .45026 .54442 L .46429 .55709 L F
.46651 .5688 m .4357 .54325 L .43736 .54287 L F
.37374 .51801 m .40321 .53607 L .41522 .53517 L 0 .218 .637 r
F
.37374 .51801 m .41522 .53517 L .38107 .51747 L F
.36101 .5178 m .37374 .51801 L .37635 .51667 L .14 .68 .834 r
F
.36056 .5191 m .37374 .51801 L .36101 .5178 L .217 .737 .848 r
F
.33826 .52635 m .33806 .52631 L .33734 .5278 L .264 .671 .967 r
F
.33806 .52631 m .33658 .52712 L .33734 .5278 L F
.34629 .52299 m .34312 .52622 L .35724 .52108 L .338 .815 .885 r
F
.34318 .52414 m .34312 .52622 L .34629 .52299 L F
.34281 .52738 m .34569 .52791 L .38597 .5364 L .379 .639 .957 r
F
.38597 .5364 m .34569 .52791 L .3861 .53641 L F
.38829 .53688 m .3861 .53641 L .39758 .53882 L F
.38597 .5364 m .3861 .53641 L .38829 .53688 L F
.41873 .54942 m .41831 .54836 L .39666 .53869 L .403 0 0 r
F
.34281 .52738 m .39758 .53882 L .39744 .53881 L .379 .639 .957 r
F
.39437 .53819 m .39666 .53869 L .35724 .52108 L .403 0 0 r
F
.41873 .54942 m .39666 .53869 L .39437 .53819 L F
.39132 .53683 m .39144 .53684 L .35724 .52108 L F
.35707 .52114 m .3954 .53872 L .35724 .52108 L F
.41831 .54836 m .41824 .54819 L .35724 .52108 L F
.39299 .53697 m .39704 .53877 L .382 .53254 L .434 0 0 r
F
.3954 .53872 m .39437 .53819 L .39422 .53816 L .403 0 0 r
F
.3954 .53872 m .39144 .53684 L .39132 .53683 L F
.39506 .53859 m .39036 .53733 L .39704 .53877 L .379 .639 .957 r
F
.39704 .53877 m .39659 .53873 L .382 .53254 L .434 0 0 r
F
.39422 .53816 m .39437 .53819 L .39144 .53684 L .403 0 0 r
F
.4044 .54204 m .40364 .54194 L .382 .53254 L .434 0 0 r
F
.38295 .53573 m .39415 .53815 L .35707 .52114 L .403 0 0 r
F
.382 .53254 m .39616 .53869 L .39506 .53859 L .434 0 0 r
F
.35724 .52108 m .39299 .53697 L .382 .53254 L F
.35724 .52108 m .39506 .53859 L .37374 .51801 L F
.39704 .53877 m .4044 .54204 L .39659 .53873 L F
.42547 .55141 m .41466 .54489 L .4241 .54478 L .745 .291 .174 r
F
.4044 .54204 m .42607 .55168 L .40364 .54194 L .434 0 0 r
F
.41588 .54812 m .41873 .54942 L .41586 .5481 L .403 0 0 r
F
.41588 .54812 m .41586 .5481 L .39613 .53901 L F
.3954 .53872 m .41588 .54812 L .39613 .53901 L F
.40267 .5418 m .42607 .55168 L .40171 .54167 L .434 0 0 r
F
.40364 .54194 m .41871 .54848 L .40267 .5418 L F
.41871 .54848 m .41919 .54877 L .40267 .5418 L F
.39616 .53869 m .40364 .54194 L .39506 .53859 L F
.40364 .54194 m .40267 .5418 L .39506 .53859 L F
.41977 .54926 m .42003 .54929 L .42961 .56002 L .315 .407 .797 r
F
.42609 .55662 m .42961 .56002 L .44606 .57846 L F
.44921 .58225 m .44606 .57846 L .47108 .6065 L F
.44606 .57846 m .44447 .57668 L .44493 .57738 L 0 .222 .744 r
F
.44606 .57846 m .44493 .57738 L .45178 .58774 L F
.45579 .59163 m .44911 .58514 L .4558 .59165 L F
.43361 .57007 m .43366 .57012 L .44912 .58516 L F
.44031 .57294 m .45642 .5924 L .45192 .59029 L .897 .5 .256 r
F
.46433 .60354 m .46608 .60543 L .46378 .60147 L .83 .438 .308 r
F
.46608 .60543 m .46663 .60521 L .46378 .60147 L F
.45642 .5924 m .46665 .60521 L .45192 .59029 L .897 .5 .256 r
F
.46255 .5998 m .46665 .60521 L .45642 .5924 L F
.46665 .60521 m .46722 .60672 L .45192 .59029 L F
.45192 .59029 m .46722 .60672 L .46909 .61165 L F
.46284 .59531 m .45354 .58665 L .45827 .59054 L .679 .139 0 r
F
.44031 .57294 m .46508 .60995 L .45481 .58685 L .897 .5 .256 r
F
.42609 .55662 m .44606 .57846 L .44921 .58225 L .315 .407 .797 r
F
.45481 .58685 m .45848 .59037 L .44327 .56091 L .897 .5 .256 r
F
.46022 .59552 m .46208 .59734 L .45848 .59037 L F
.46222 .59793 m .46208 .59734 L .46022 .59552 L F
.46508 .60995 m .45848 .59037 L .45481 .58685 L F
.47248 .62072 m .47143 .61547 L .46208 .59734 L F
.46508 .60995 m .47094 .6187 L .46208 .59734 L F
.47094 .6187 m .47178 .61914 L .46208 .59734 L F
.46508 .60995 m .46222 .59793 L .46022 .59552 L F
.47284 .62154 m .47143 .61547 L .47248 .62072 L F
.47284 .62154 m .48037 .63278 L .47372 .6199 L F
.47242 .62178 m .47227 .62002 L .47253 .62123 L .437 .333 .639 r
F
.47391 .62027 m .48037 .63278 L .48197 .64002 L .888 .491 .049 r
F
.47255 .62111 m .4726 .62089 L .4727 .62181 L .437 .333 .639 r
F
.47255 .62111 m .47284 .62154 L .47248 .62072 L .897 .5 .256 r
F
.47255 .62111 m .47248 .62072 L .47178 .61914 L F
.47629 .66575 m .47891 .63251 L .47221 .61937 L .437 .333 .639 r
F
.47891 .63251 m .47963 .6233 L .47391 .62027 L F
.47891 .63251 m .47391 .62027 L .47221 .61937 L F
.47369 .61996 m .47391 .62027 L .47413 .6208 L .888 .491 .049 r
F
.46262 .59846 m .47391 .62027 L .47369 .61996 L F
.46265 .59846 m .47391 .62027 L .46262 .59846 L F
.46265 .59846 m .42609 .55662 L .44921 .58225 L .315 .407 .797 r
F
.46206 .59853 m .42609 .55662 L .46265 .59846 L F
.44327 .56091 m .47413 .6208 L .45808 .59118 L .888 .491 .049 r
F
.48156 .62125 m .46206 .59853 L .46265 .59846 L .315 .407 .797 r
F
.47997 .6612 m .48504 .62616 L .47963 .6233 L .437 .333 .639 r
F
.47701 .67398 m .47963 .6233 L .47629 .66575 L F
.48014 .67982 m .47978 .63967 L .47701 .67398 L F
.47978 .63967 m .47963 .6233 L .4788 .6395 L F
.47978 .63967 m .4788 .6395 L .47701 .67398 L F
.46996 .60542 m .46285 .5985 L .46996 .60543 L 0 .222 .744 r
F
.46285 .5985 m .46285 .59851 L .46996 .60543 L F
.46996 .60543 m .46285 .59851 L .46289 .59862 L F
.47108 .6065 m .46996 .60542 L .46996 .60543 L F
.46265 .59846 m .46371 .59833 L .47108 .6065 L .315 .407 .797 r
F
.48509 .62536 m .48156 .62125 L .47108 .6065 L F
.47684 .61575 m .46745 .598 L .46945 .60714 L F
.48193 .66018 m .48504 .62616 L .47997 .6612 L .437 .333 .639 r
F
.4783 .61346 m .47035 .59952 L .47684 .61575 L .315 .407 .797 r
F
.4433 .55771 m .46774 .57692 L .46486 .57518 L .722 .458 .527 r
F
.46247 .58915 m .45734 .5805 L .46929 .58578 L .745 .291 .174 r
F
.47647 .60202 m .48388 .61193 L .467 .59132 L .722 .458 .527 r
F
.4714 .59647 m .46323 .58877 L .46969 .58559 L .957 .664 .437 r
F
.44822 .56514 m .45931 .57295 L .46969 .58559 L .745 .291 .174 r
F
.46969 .58559 m .45952 .5731 L .46738 .57339 L .68 .316 .35 r
F
.4433 .55771 m .46738 .57339 L .46305 .57323 L .722 .458 .527 r
F
.47006 .59898 m .47035 .59952 L .46075 .57135 L .888 .491 .049 r
F
.47021 .59942 m .47035 .59952 L .47006 .59898 L F
.48695 .6399 m .5 .65363 L .48509 .62536 L .598 .448 .65 r
F
.5 .65363 m .49574 .646 L .48509 .62536 L .511 .482 .761 r
F
.44743 .56318 m .45118 .56548 L .44894 .56196 L 0 .218 .637 r
F
.45118 .56548 m .46075 .57135 L .44894 .56196 L F
.44327 .56091 m .46265 .59846 L .46262 .59846 L .888 .491 .049 r
F
.43942 .55252 m .44958 .5661 L .44813 .56829 L .722 .458 .527 r
F
.44958 .5661 m .45858 .58105 L .44813 .56829 L F
.44327 .56091 m .45808 .59118 L .46075 .57135 L .888 .491 .049 r
F
.46278 .59437 m .46135 .59215 L .46269 .59285 L .679 .139 0 r
F
.46135 .59215 m .46016 .59031 L .46269 .59285 L F
.4631 .59551 m .46278 .59437 L .46269 .59285 L .787 .521 0 r
F
.4631 .59551 m .46269 .59285 L .46247 .58915 L F
.46277 .59063 m .46247 .58915 L .46286 .59065 L F
.45808 .59118 m .46845 .59823 L .46075 .57135 L .888 .491 .049 r
F
.47035 .59952 m .46708 .59729 L .47301 .60851 L .315 .407 .797 r
F
.47035 .59952 m .47301 .60851 L .47684 .61575 L F
.48436 .63776 m .48509 .62536 L .48435 .63825 L .598 .448 .65 r
F
.48435 .63825 m .48509 .62536 L .48429 .6404 L F
.48439 .63722 m .48695 .6399 L .48509 .62536 L F
.48509 .62536 m .4783 .61346 L .47684 .61575 L .315 .407 .797 r
F
.49574 .646 m .48329 .62372 L .47035 .59952 L .511 .482 .761 r
F
.48329 .62372 m .47153 .60207 L .47035 .59952 L F
.49574 .646 m .47035 .59952 L .48509 .62536 L F
.4714 .59647 m .46969 .58559 L .4727 .59777 L .957 .664 .437 r
F
.46075 .57135 m .47153 .60207 L .478 .58202 L 0 0 .413 r
F
.48399 .64035 m .48429 .6404 L .47035 .59952 L .888 .491 .049 r
F
.48276 .63593 m .48429 .6404 L .48424 .63983 L 0 0 .413 r
F
.46133 .72651 m .472 .7128 L .47342 .70569 L .527 .3 .513 r
F
.47312 .70606 m .47342 .70569 L .47241 .71073 L .981 .833 .437 r
F
.47312 .70606 m .47241 .71073 L .46965 .72456 L F
.47158 .70796 m .47312 .70606 L .46965 .72456 L F
.47423 .70162 m .47342 .70569 L .47311 .70607 L F
.48638 .67119 m .48549 .66788 L .48917 .66433 L .964 .935 .627 r
F
.47102 .71276 m .47669 .70448 L .48918 .65476 L .981 .833 .437 r
F
.48201 .68331 m .48429 .6404 L .48014 .67982 L .437 .333 .639 r
F
.48394 .64527 m .48425 .63995 L .48383 .64899 L .598 .448 .65 r
F
.48425 .63995 m .48435 .63825 L .48426 .64007 L F
.48425 .63995 m .48426 .64007 L .48383 .64899 L F
.48426 .64116 m .48429 .6404 L .48399 .64035 L .888 .491 .049 r
F
.48426 .64007 m .48429 .6404 L .48383 .64899 L .598 .448 .65 r
F
.48435 .63825 m .48429 .6404 L .48426 .64007 L F
.48436 .63776 m .48435 .63825 L .48425 .63995 L F
.48436 .63776 m .48425 .63995 L .48424 .63987 L F
.48424 .63983 m .48436 .63776 L .48424 .63987 L F
.48424 .63983 m .49069 .65273 L .48439 .63722 L F
.48424 .63983 m .48429 .6404 L .48831 .65056 L 0 0 .413 r
F
.48424 .63987 m .48425 .63995 L .48393 .64555 L .598 .448 .65 r
F
.4839 .64569 m .48424 .63983 L .48393 .64555 L F
.48429 .6404 m .48345 .64364 L .48384 .64461 L .437 .333 .639 r
F
.48424 .63983 m .48424 .63987 L .48393 .64555 L .598 .448 .65 r
F
.4881 .65255 m .48429 .6404 L .48426 .64116 L .888 .491 .049 r
F
.48155 .68759 m .47808 .70234 L .48149 .68807 L 0 0 .088 r
F
.48201 .68331 m .47856 .69704 L .48485 .67352 L F
.4875 .67973 m .48765 .68146 L .48743 .6792 L .803 .643 .683 r
F
.48638 .67119 m .48658 .67245 L .48211 .68644 L .964 .935 .627 r
F
.48843 .68713 m .48765 .68146 L .4875 .67973 L .803 .643 .683 r
F
.48638 .67119 m .48917 .66433 L .48658 .67245 L .964 .935 .627 r
F
.48918 .65476 m .47938 .69725 L .49706 .67482 L 0 0 .088 r
F
.48205 .71087 m .48581 .69949 L .48384 .69881 L .598 .448 .65 r
F
.47938 .69725 m .4851 .69925 L .49706 .67482 L 0 0 .088 r
F
.48193 .71163 m .48384 .69881 L .47989 .71432 L .598 .448 .65 r
F
.48384 .69881 m .49025 .65567 L .4827 .69841 L F
.48384 .69881 m .4827 .69841 L .47989 .71432 L F
.4876 .70012 m .48759 .70012 L .48205 .71087 L F
.46889 .7427 m .47021 .74657 L .48759 .70012 L 0 0 .088 r
F
.48669 .6998 m .48759 .70012 L .49706 .67482 L F
.48761 .70008 m .49653 .66712 L .48205 .71087 L .598 .448 .65 r
F
.46889 .7427 m .48759 .70012 L .48669 .6998 L 0 0 .088 r
F
.49025 .65567 m .49019 .65553 L .47989 .71432 L .598 .448 .65 r
F
.48085 .69776 m .48134 .68954 L .48149 .68807 L F
.47989 .71432 m .49019 .65553 L .48134 .68954 L F
.47201 .72446 m .47444 .72113 L .4719 .72456 L .647 .417 .556 r
F
.47444 .72113 m .47344 .72243 L .46828 .72946 L F
.47938 .69725 m .4734 .72316 L .4851 .69925 L 0 0 .088 r
F
.48384 .69881 m .49562 .66985 L .49025 .65567 L .598 .448 .65 r
F
.48581 .69949 m .49562 .66985 L .48384 .69881 L F
.48134 .68954 m .4839 .64569 L .48149 .68807 L F
.4839 .64569 m .48393 .64555 L .48149 .68807 L F
.48429 .6404 m .48375 .64031 L .48345 .64364 L .437 .333 .639 r
F
.48417 .64452 m .4881 .65255 L .48426 .64116 L .888 .491 .049 r
F
.48149 .68807 m .48394 .64527 L .48284 .66772 L .598 .448 .65 r
F
.48394 .64527 m .48383 .64899 L .48284 .66772 L F
.48485 .67352 m .48155 .68759 L .48149 .68807 L 0 0 .088 r
F
.48149 .68807 m .48284 .66772 L .48201 .68331 L .598 .448 .65 r
F
.48485 .67352 m .48186 .68471 L .48155 .68759 L 0 0 .088 r
F
.48918 .65476 m .48201 .68331 L .48485 .67352 L F
.48257 .67418 m .48254 .67474 L .4828 .67512 L .981 .833 .437 r
F
.4881 .65255 m .48918 .65476 L .4884 .65247 L .888 .491 .049 r
F
.48134 .68954 m .49006 .65518 L .48424 .63983 L .598 .448 .65 r
F
.49006 .65518 m .49069 .65273 L .48424 .63983 L F
.48423 .63977 m .48831 .65056 L .49038 .65579 L 0 0 .413 r
F
.48276 .63593 m .48424 .63983 L .48423 .63977 L F
.48424 .63983 m .48831 .65056 L .48423 .63977 L F
.49653 .66712 m .5 .65363 L .48439 .63722 L .598 .448 .65 r
F
.48452 .62598 m .49038 .65579 L .48576 .62827 L 0 0 .413 r
F
.47153 .60207 m .48002 .62627 L .48329 .62372 L F
.48454 .62595 m .48464 .62267 L .48329 .62372 L .511 .482 .761 r
F
.5 .65363 m .48783 .62018 L .48454 .62595 L F
.48329 .62372 m .4848 .62254 L .478 .58202 L 0 0 .413 r
F
.48783 .62018 m .48464 .62267 L .48454 .62595 L .511 .482 .761 r
F
.49038 .65579 m .49089 .65553 L .478 .58202 L 0 0 .413 r
F
.49272 .66017 m .4944 .66188 L .49069 .65273 L .598 .448 .65 r
F
.49148 .65892 m .4944 .66188 L .478 .58202 L 0 0 .413 r
F
.48783 .62018 m .48496 .61229 L .48464 .62267 L .511 .482 .761 r
F
.47153 .60207 m .48329 .62372 L .478 .58202 L 0 0 .413 r
F
.48329 .62372 m .48576 .62827 L .4848 .62254 L F
.48329 .62372 m .47314 .60555 L .47153 .60207 L .511 .482 .761 r
F
.48329 .62372 m .48496 .61229 L .47488 .60867 L F
.48464 .62267 m .48496 .61229 L .48329 .62372 L F
.48329 .62372 m .48408 .63783 L .48452 .62598 L 0 0 .413 r
F
.48002 .62627 m .48408 .63783 L .48329 .62372 L F
.48408 .63783 m .49038 .65579 L .48452 .62598 L F
.47062 .60009 m .48276 .63593 L .48423 .63977 L F
.47059 .60002 m .48276 .63593 L .47062 .60009 L F
.47035 .59952 m .48276 .63593 L .46993 .5981 L F
.4617 .59858 m .47413 .6208 L .48197 .64002 L .888 .491 .049 r
F
.47824 .63239 m .47921 .62616 L .47006 .59898 L F
.46713 .59362 m .47006 .59898 L .46075 .57135 L F
.47824 .63239 m .47006 .59898 L .46713 .59362 L F
.44743 .56318 m .44327 .56091 L .45216 .56622 L 0 .218 .637 r
F
.44743 .56318 m .45216 .56622 L .45118 .56548 L F
.44894 .56196 m .44856 .56227 L .46708 .59729 L .315 .407 .797 r
F
.48399 .64035 m .47035 .59952 L .47021 .59942 L .888 .491 .049 r
F
.46075 .57135 m .48423 .63977 L .48415 .63869 L 0 0 .413 r
F
.48002 .62627 m .48415 .63869 L .48408 .63783 L F
.46075 .57135 m .48415 .63869 L .48002 .62627 L F
.5 .65363 m .49163 .61469 L .48532 .61242 L .511 .482 .761 r
F
.49918 .64688 m .50088 .65412 L .49495 .59206 L .175 .215 .665 r
F
.50548 .67375 m .50424 .66826 L .504 .66742 L .627 .537 .734 r
F
.49495 .59206 m .50443 .67748 L .50389 .65172 L .47 .41 .709 r
F
.49495 .59206 m .50381 .68483 L .50463 .68686 L F
.49495 .59206 m .50463 .68686 L .50443 .67748 L F
.47962 .52788 m .50192 .55612 L .47867 .52864 L .523 .324 .553 r
F
.51093 .55837 m .5152 .56256 L .50466 .55908 L F
.49648 .56585 m .48967 .54288 L .50018 .55424 L .543 .31 .512 r
F
.50326 .55757 m .50466 .55908 L .4986 .55708 L .523 .324 .553 r
F
.51093 .55837 m .50466 .55908 L .50326 .55757 L F
.50018 .55424 m .48541 .52851 L .50551 .53752 L .543 .31 .512 r
F
.48967 .54288 m .48541 .52851 L .50018 .55424 L F
.49541 .55603 m .49921 .55728 L .49361 .55617 L .65 .463 .618 r
F
.49921 .55728 m .50466 .55908 L .49361 .55617 L F
.48413 .55691 m .48468 .54484 L .48415 .55693 L .608 .314 .444 r
F
.48468 .54484 m .4847 .54483 L .48416 .55694 L F
.48413 .55691 m .48474 .55739 L .4815 .55712 L .65 .463 .618 r
F
.48061 .58033 m .4845 .58229 L .48074 .5807 L .732 .556 .654 r
F
.47621 .57687 m .48215 .58129 L .48022 .58048 L .68 .316 .35 r
F
.47991 .57848 m .48267 .58077 L .48061 .58033 L .732 .556 .654 r
F
.48267 .58077 m .4845 .58229 L .48061 .58033 L F
.48415 .55693 m .48416 .55694 L .48311 .58086 L .608 .314 .444 r
F
.48311 .58086 m .48311 .58086 L .48302 .58293 L F
.48415 .55693 m .48311 .58086 L .48311 .58086 L F
.48468 .54484 m .48416 .55694 L .48415 .55693 L F
.49361 .55617 m .50466 .55908 L .48474 .55739 L .65 .463 .618 r
F
.49361 .55617 m .48474 .55739 L .48413 .55691 L F
.48297 .58265 m .48413 .55691 L .48302 .58293 L .608 .314 .444 r
F
.48413 .55691 m .48415 .55693 L .48302 .58293 L F
.48474 .55739 m .49678 .56688 L .49169 .57193 L .65 .463 .618 r
F
.48302 .58293 m .48416 .55694 L .50072 .58018 L .608 .314 .444 r
F
.48971 .58716 m .48302 .58293 L .48871 .58205 L .784 .572 .613 r
F
.48306 .58085 m .48285 .58046 L .48413 .55691 L .608 .314 .444 r
F
.48285 .58046 m .4815 .55712 L .48413 .55691 L F
.47436 .5738 m .47093 .56812 L .47991 .57848 L .627 .339 .461 r
F
.48045 .58145 m .46651 .5688 L .48065 .58095 L .68 .316 .35 r
F
.46738 .57339 m .46651 .5688 L .48225 .58308 L F
.48074 .5807 m .48175 .58149 L .48115 .58178 L .732 .556 .654 r
F
.46651 .5688 m .46896 .57036 L .48296 .58294 L .68 .316 .35 r
F
.43903 .55129 m .47115 .57265 L .43942 .55252 L .627 .339 .461 r
F
.47115 .57265 m .47226 .57357 L .43942 .55252 L F
.43942 .55252 m .47991 .57848 L .48031 .58182 L .722 .458 .527 r
F
.43942 .55252 m .48031 .58182 L .4433 .55771 L F
.47436 .5738 m .47991 .57848 L .43903 .55129 L .627 .339 .461 r
F
.46651 .5688 m .46636 .56803 L .46896 .57036 L .68 .316 .35 r
F
.46084 .56804 m .48197 .56977 L .45696 .55681 L .511 .482 .761 r
F
.48391 .5954 m .47961 .58361 L .48296 .58294 L .859 .611 .562 r
F
.48391 .5954 m .48296 .58294 L .48707 .60225 L F
.47991 .57848 m .48074 .5807 L .48031 .58182 L .732 .556 .654 r
F
.47523 .57698 m .478 .58202 L .48494 .58613 L .182 .455 .88 r
F
.46875 .57295 m .478 .58202 L .47523 .57698 L F
.48286 .58067 m .48288 .58094 L .47991 .57848 L .65 .463 .618 r
F
.47936 .57393 m .48265 .57701 L .47991 .57848 L F
.48265 .57701 m .48286 .58067 L .47991 .57848 L F
.47115 .57265 m .47991 .57848 L .47226 .57357 L .627 .339 .461 r
F
.46875 .57295 m .48197 .56977 L .46084 .56804 L .511 .482 .761 r
F
.48011 .58 m .48091 .57562 L .46875 .57295 L F
.48091 .57562 m .48197 .56977 L .46875 .57295 L F
.46497 .57212 m .478 .58202 L .46875 .57295 L 0 .344 .809 r
F
.48479 .58291 m .48494 .58613 L .4848 .58292 L .182 .455 .88 r
F
.47314 .60555 m .45045 .56493 L .47035 .59952 L .511 .482 .761 r
F
.44894 .56196 m .44141 .54876 L .44816 .56151 L .315 .407 .797 r
F
.44894 .56196 m .44816 .56151 L .44856 .56227 L F
.4477 .56001 m .44141 .54876 L .44785 .56004 L .511 .482 .761 r
F
.44845 .56119 m .4485 .5612 L .44894 .56196 L F
.40171 .54167 m .41958 .54901 L .41632 .54843 L .434 0 0 r
F
.42607 .55168 m .44 .57005 L .43917 .56925 L .897 .5 .256 r
F
.42607 .55168 m .4354 .56561 L .44327 .56091 L F
.4354 .56561 m .44058 .57185 L .44327 .56091 L F
.42711 .55781 m .43163 .55552 L .41977 .54926 L .315 .407 .797 r
F
.41632 .54843 m .41916 .54893 L .426 .55291 L .434 0 0 r
F
.41916 .54893 m .41958 .54901 L .42141 .55012 L F
.41916 .54893 m .42141 .55012 L .426 .55291 L F
.41657 .54648 m .41466 .54489 L .41808 .54695 L .745 .291 .174 r
F
.41657 .54648 m .41808 .54695 L .42547 .55141 L F
.41923 .54879 m .41373 .54222 L .40924 .54272 L 0 .222 .744 r
F
.42003 .54929 m .41373 .54222 L .41923 .54879 L F
.41977 .54926 m .41373 .54222 L .42003 .54929 L .315 .407 .797 r
F
.41958 .54901 m .42034 .54932 L .42009 .54929 L .434 0 0 r
F
.41958 .54901 m .42602 .55255 L .42141 .55012 L F
.43232 .55136 m .43942 .55252 L .42781 .54996 L .462 0 .036 r
F
.42781 .54996 m .43942 .55252 L .42499 .54909 L F
.42499 .54909 m .43942 .55252 L .42519 .5501 L .643 .215 .214 r
F
.41977 .54926 m .44141 .54876 L .41373 .54222 L .315 .407 .797 r
F
.41795 .54341 m .40443 .54065 L .40774 .54108 L .379 .639 .957 r
F
.4207 .54404 m .41868 .54362 L .41795 .54341 L F
.41868 .54362 m .40443 .54065 L .41795 .54341 L F
.39506 .53859 m .40267 .5418 L .40171 .54167 L .434 0 0 r
F
.39506 .53859 m .41632 .54843 L .40588 .54097 L F
.40443 .54065 m .39407 .5385 L .39814 .53927 L .379 .639 .957 r
F
.40443 .54065 m .39814 .53927 L .40774 .54108 L F
.42497 .55134 m .42607 .55168 L .42488 .55115 L .403 0 0 r
F
.42009 .54929 m .42607 .55168 L .42602 .55255 L .434 0 0 r
F
.42034 .54932 m .42607 .55168 L .42009 .54929 L F
.42141 .55012 m .42602 .55255 L .426 .55291 L F
.426 .55291 m .42607 .55168 L .44327 .56091 L F
.43163 .55552 m .44327 .56091 L .43323 .55471 L F
.43323 .55471 m .44327 .56091 L .44743 .56318 L 0 .218 .637 r
F
.42519 .5501 m .43942 .55252 L .42524 .55032 L .643 .215 .214 r
F
.44545 .56281 m .44141 .54876 L .41977 .54926 L .315 .407 .797 r
F
.41632 .54843 m .43163 .55552 L .41212 .54235 L .434 0 0 r
F
.41632 .54843 m .41212 .54235 L .40856 .54156 L F
.43163 .55552 m .43323 .55471 L .41378 .54271 L F
.43163 .55552 m .41378 .54271 L .41212 .54235 L F
.46708 .59729 m .44141 .54876 L .4525 .58739 L .315 .407 .797 r
F
.41466 .5431 m .43323 .55471 L .44743 .56318 L 0 .218 .637 r
F
.42523 .54525 m .41405 .54283 L .41382 .54273 L .379 .639 .957 r
F
.42486 .54516 m .40443 .54065 L .4207 .54404 L F
.41405 .54283 m .43323 .55471 L .41466 .5431 L 0 .218 .637 r
F
.41378 .54271 m .42181 .54767 L .41405 .54283 L F
.42181 .54767 m .43323 .55471 L .41405 .54283 L F
.44141 .54876 m .42523 .54525 L .4207 .54404 L .379 .639 .957 r
F
.44141 .54876 m .4207 .54404 L .42161 .54408 L F
.4207 .54404 m .40774 .54108 L .41772 .54324 L F
.4207 .54404 m .41772 .54324 L .42161 .54408 L F
.44141 .54876 m .41702 .53611 L .42894 .54606 L F
.42891 .54605 m .41522 .53517 L .42523 .54525 L F
.48197 .56977 m .45894 .55783 L .43818 .54707 L .483 .612 .904 r
F
.45894 .55783 m .45103 .55373 L .44698 .55163 L F
.45894 .55783 m .44698 .55163 L .43818 .54707 L F
.39193 .51667 m .41862 .53693 L .41122 .51661 L 0 .344 .809 r
F
.4357 .54325 m .43844 .54176 L .43736 .54287 L 0 0 0 r
F
.43528 .54334 m .43594 .54301 L .4357 .54325 L F
.43594 .54301 m .43844 .54176 L .4357 .54325 L F
.43605 .54464 m .43528 .54334 L .43614 .5444 L .745 .291 .174 r
F
.43599 .5415 m .43703 .54238 L .43638 .54276 L .627 .339 .461 r
F
.43528 .54334 m .43497 .54338 L .43695 .54251 L 0 0 0 r
F
.43671 .5442 m .43528 .54334 L .4357 .54325 L .68 .316 .35 r
F
.43634 .54433 m .43528 .54334 L .43671 .5442 L F
.41862 .53693 m .44327 .5497 L .41122 .51661 L 0 .344 .809 r
F
.43818 .54707 m .42669 .54111 L .41857 .53691 L .483 .612 .904 r
F
.4477 .56001 m .44894 .56196 L .44842 .56127 L .511 .482 .761 r
F
.44835 .56118 m .45883 .56246 L .4477 .56001 L F
.46122 .56965 m .45883 .56246 L .44835 .56118 L F
.4477 .56001 m .45696 .55681 L .44141 .54876 L F
.45883 .56246 m .45696 .55681 L .4477 .56001 L F
.46497 .57212 m .46075 .57135 L .478 .58202 L 0 .344 .809 r
F
.46005 .56888 m .46075 .57135 L .46497 .57212 L F
.48296 .58294 m .48297 .58265 L .48302 .58293 L .608 .314 .444 r
F
.48296 .58294 m .48215 .58129 L .48306 .58085 L F
.48022 .58048 m .48215 .58129 L .48296 .58294 L .68 .316 .35 r
F
.48225 .58308 m .48045 .58145 L .48296 .58294 L F
.48045 .58145 m .48065 .58095 L .48296 .58294 L F
.47523 .57698 m .48494 .58613 L .48479 .58291 L .182 .455 .88 r
F
.478 .58202 m .48532 .61242 L .48828 .61349 L .175 .215 .665 r
F
.50088 .65412 m .49163 .61469 L .49285 .62035 L .627 .537 .734 r
F
.478 .58202 m .49918 .64688 L .48494 .58613 L .175 .215 .665 r
F
.47488 .60867 m .48011 .58 L .46084 .56804 L .511 .482 .761 r
F
.47488 .60867 m .45696 .55681 L .47314 .60555 L F
.47454 .56592 m .43672 .54632 L .44141 .54876 L .483 .612 .904 r
F
.43672 .54632 m .41857 .53691 L .42803 .54182 L F
.43672 .54632 m .42803 .54182 L .44141 .54876 L F
.48197 .56977 m .43105 .54338 L .47454 .56592 L F
.43105 .54338 m .41857 .53691 L .42913 .54239 L F
.43105 .54338 m .42913 .54239 L .47454 .56592 L F
.44628 .53746 m .43824 .54197 L .43844 .54176 L .455 .123 .313 r
F
.43695 .54251 m .43674 .54255 L .44961 .53616 L 0 0 0 r
F
.43674 .54255 m .44396 .53837 L .44961 .53616 L F
.43844 .54176 m .45864 .53163 L .43736 .54287 L F
.44072 .53519 m .44628 .53746 L .43599 .5415 L .455 .123 .313 r
F
.44628 .53746 m .43811 .54194 L .43599 .5415 L F
.41122 .51661 m .44729 .54911 L .43127 .51744 L .182 .455 .88 r
F
.45864 .53163 m .46432 .53047 L .46058 .53753 L 0 0 0 r
F
.46432 .53047 m .46506 .53116 L .46058 .53753 L F
.46206 .53566 m .46539 .53146 L .46449 .53375 L F
.44577 .53517 m .478 .53501 L .44667 .53628 L .455 .123 .313 r
F
.44577 .53517 m .44667 .53628 L .44368 .5364 L F
.44072 .53519 m .44577 .53517 L .44368 .5364 L F
.45088 .54498 m .45778 .54627 L .46429 .55709 L .627 .339 .461 r
F
.46081 .5457 m .47644 .54978 L .45026 .54442 L .455 .123 .313 r
F
.44368 .5364 m .44856 .53657 L .44628 .53746 L F
.46904 .52923 m .46785 .5296 L .46804 .52947 L 0 0 0 r
F
.46904 .52923 m .46804 .52947 L .47206 .52643 L F
.46922 .52917 m .46904 .52923 L .47206 .52643 L F
.46904 .52923 m .46909 .52921 L .46042 .53127 L F
.46432 .53047 m .46785 .5296 L .46042 .53127 L F
.46785 .5296 m .46904 .52923 L .46042 .53127 L F
.46042 .53127 m .46909 .52921 L .46628 .52963 L F
.46406 .53022 m .46396 .53014 L .46569 .52976 L F
.46396 .53014 m .46369 .52989 L .46569 .52976 L F
.46569 .52976 m .46369 .52989 L .46882 .52887 L F
.44387 .53465 m .46628 .52963 L .44072 .53519 L F
.4534 .53301 m .45864 .53163 L .44387 .53465 L F
.45864 .53163 m .46628 .52963 L .44387 .53465 L F
.44072 .53519 m .46628 .52963 L .45222 .53514 L .455 .123 .313 r
F
.44729 .54911 m .45305 .54409 L .43127 .51744 L .182 .455 .88 r
F
.45778 .54627 m .47644 .54978 L .46429 .55709 L .627 .339 .461 r
F
.48197 .56977 m .45772 .54002 L .4536 .54361 L .483 .612 .904 r
F
.43811 .54194 m .43824 .54197 L .43795 .54201 L .627 .339 .461 r
F
.43599 .5415 m .43811 .54194 L .43703 .54238 L F
.41122 .51661 m .44698 .55163 L .45003 .55321 L .182 .455 .88 r
F
.43844 .54176 m .43824 .54197 L .43811 .54194 L .455 .123 .313 r
F
.41122 .51661 m .45003 .55321 L .45103 .55373 L .182 .455 .88 r
F
.45566 .55613 m .44729 .54911 L .45103 .55373 L .483 .612 .904 r
F
.44729 .54911 m .45103 .55373 L .45427 .5554 L .182 .455 .88 r
F
.41122 .51661 m .45103 .55373 L .44729 .54911 L F
.45566 .55613 m .4536 .54361 L .44729 .54911 L .483 .612 .904 r
F
.46497 .57212 m .46875 .57295 L .44698 .55163 L 0 .344 .809 r
F
.44327 .5497 m .44698 .55163 L .41122 .51661 L F
.46497 .57212 m .44698 .55163 L .44327 .5497 L F
.45103 .55373 m .42669 .54111 L .43419 .545 L .483 .612 .904 r
F
.44698 .55163 m .43419 .545 L .43818 .54707 L F
.45103 .55373 m .43419 .545 L .44698 .55163 L F
.45103 .55373 m .44729 .54911 L .44536 .55079 L F
.48197 .56977 m .4536 .54361 L .45566 .55613 L F
.43127 .51744 m .4536 .54361 L .45299 .53992 L .368 .521 .878 r
F
.48453 .58106 m .48446 .58075 L .4848 .58289 L .627 .537 .734 r
F
.48446 .58075 m .48197 .56977 L .48463 .58212 L F
.48446 .58075 m .48463 .58212 L .4848 .58292 L F
.4848 .58291 m .48463 .58212 L .47975 .582 L .511 .482 .761 r
F
.48463 .58212 m .48197 .56977 L .48009 .58013 L F
.48463 .58212 m .48009 .58013 L .47975 .582 L F
.48446 .58075 m .48706 .58256 L .48197 .56977 L .627 .537 .734 r
F
.48225 .57971 m .48431 .5796 L .4536 .54361 L .182 .455 .88 r
F
.48479 .58291 m .48452 .58106 L .48225 .57971 L F
.48452 .58106 m .48431 .5796 L .48225 .57971 L F
.50052 .59398 m .48871 .58205 L .50072 .58018 L .784 .572 .613 r
F
.49244 .58888 m .48871 .58205 L .50052 .59398 L F
.50052 .59398 m .50072 .58018 L .50224 .5941 L F
.50224 .5941 m .50072 .58018 L .50314 .59416 L F
.48706 .58256 m .51425 .60149 L .50708 .59444 L .627 .537 .734 r
F
.48706 .58256 m .50708 .59444 L .48197 .56977 L F
.48661 .5823 m .48756 .58341 L .4873 .58279 L .368 .521 .878 r
F
.51187 .60086 m .5133 .60982 L .51582 .60249 L .609 .514 .722 r
F
.439 .51654 m .45188 .51883 L .43893 .51627 L .15 .652 .908 r
F
.45305 .54409 m .4536 .54361 L .43127 .51744 L .182 .455 .88 r
F
.46449 .53375 m .47206 .52643 L .47043 .52907 L 0 0 0 r
F
.46432 .53047 m .46575 .53018 L .46506 .53116 L F
.46539 .53146 m .46663 .53053 L .46449 .53375 L F
.46449 .53375 m .46785 .5296 L .46922 .52917 L F
.45222 .53514 m .46953 .52912 L .46279 .53509 L .455 .123 .313 r
F
.46909 .52921 m .47104 .5286 L .46628 .52963 L 0 0 0 r
F
.46628 .52963 m .47104 .5286 L .45222 .53514 L .455 .123 .313 r
F
.45772 .54002 m .45655 .53858 L .44536 .55079 L .483 .612 .904 r
F
.43127 .51744 m .45299 .53992 L .4527 .53439 L .368 .521 .878 r
F
.43753 .51786 m .4527 .53439 L .45188 .51883 L F
.43127 .51744 m .4527 .53439 L .43753 .51786 L F
.5145 .60173 m .45928 .54155 L .48197 .56977 L .571 .605 .848 r
F
.52009 .60187 m .51982 .60414 L .52832 .60766 L .476 .562 .863 r
F
.52796 .60712 m .52832 .60766 L .52937 .60809 L F
.50468 .59102 m .52832 .60766 L .52796 .60712 L F
.46058 .53753 m .47886 .52848 L .47325 .53293 L 0 0 0 r
F
.51455 .59581 m .50072 .58018 L .51159 .5783 L .732 .552 .648 r
F
.5136 .58993 m .50468 .59102 L .52937 .60809 L .476 .562 .863 r
F
.47785 .52714 m .47789 .52709 L .47885 .5269 L 0 0 0 r
F
.47785 .52714 m .47885 .5269 L .47746 .52723 L F
.47116 .52845 m .48606 .52728 L .48554 .52827 L F
.47116 .52845 m .48554 .52827 L .48129 .5285 L F
.47096 .52862 m .47107 .5286 L .47104 .5286 L F
.47746 .52723 m .47885 .5269 L .47096 .52862 L F
.47209 .52838 m .47785 .52714 L .47732 .52797 L F
.47104 .5286 m .47885 .5269 L .47507 .52883 L .455 .123 .313 r
F
.47043 .52907 m .47507 .52883 L .46279 .53509 L F
.47104 .5286 m .47507 .52883 L .47043 .52907 L F
.48129 .5285 m .48554 .52827 L .48541 .52851 L 0 0 0 r
F
.46058 .53753 m .47043 .52907 L .47854 .52864 L F
.46953 .52912 m .47043 .52907 L .46279 .53509 L .455 .123 .313 r
F
.48474 .55739 m .50048 .55873 L .49678 .56688 L .65 .463 .618 r
F
.48416 .55694 m .49678 .56688 L .50072 .58018 L .608 .314 .444 r
F
.47644 .54978 m .49541 .55603 L .4815 .55712 L .65 .463 .618 r
F
.46672 .54581 m .47773 .53759 L .46934 .54688 L .455 .123 .313 r
F
.46685 .53755 m .47773 .53759 L .46672 .54581 L F
.46058 .53753 m .46449 .53375 L .47043 .52907 L 0 0 0 r
F
.48443 .55026 m .47219 .54372 L .47773 .53759 L .608 .314 .444 r
F
.47845 .53074 m .50192 .55612 L .49348 .55402 L .523 .324 .553 r
F
.47845 .53074 m .49348 .55402 L .47773 .53759 L F
.48468 .54484 m .47773 .53759 L .48539 .52911 L .608 .314 .444 r
F
.48443 .55026 m .47773 .53759 L .48468 .54484 L F
.46468 .54583 m .46058 .53753 L .48443 .55026 L F
.47773 .53759 m .49348 .55402 L .47644 .54978 L .523 .324 .553 r
F
.46934 .54688 m .47773 .53759 L .47644 .54978 L .455 .123 .313 r
F
.48539 .52911 m .46058 .53753 L .48541 .52851 L .608 .314 .444 r
F
.47219 .54372 m .46058 .53753 L .48539 .52911 L F
.46058 .53753 m .46206 .53566 L .46449 .53375 L 0 0 0 r
F
.50072 .58018 m .50289 .56083 L .52104 .57666 L .543 .31 .512 r
F
.50072 .58018 m .49678 .56688 L .50037 .56333 L F
.51093 .55837 m .4986 .55708 L .47644 .54978 L .523 .324 .553 r
F
.45188 .51883 m .50397 .59005 L .5136 .58993 L .476 .562 .863 r
F
.50397 .59005 m .50468 .59102 L .5136 .58993 L F
.52256 .60528 m .52263 .60922 L .52937 .60809 L .609 .514 .722 r
F
.54484 .66341 m .54225 .65213 L .52171 .60882 L .651 .623 .809 r
F
.54225 .65213 m .54025 .64342 L .5297 .62267 L F
.54025 .64342 m .52999 .62318 L .5297 .62267 L F
.54225 .65213 m .5297 .62267 L .52171 .60882 L F
.53011 .69179 m .54484 .66341 L .52912 .68929 L .719 .599 .722 r
F
.52044 .62023 m .54484 .66341 L .52171 .60882 L F
.52275 .65842 m .54484 .66341 L .52044 .62023 L F
.52171 .60882 m .52035 .6073 L .51568 .60289 L .571 .605 .848 r
F
.5145 .60173 m .51187 .60086 L .51481 .60208 L .476 .562 .863 r
F
.51379 .60988 m .51723 .60442 L .5145 .60173 L .627 .537 .734 r
F
.51424 .60159 m .5145 .60173 L .51425 .60149 L F
.51379 .60988 m .5145 .60173 L .51424 .60159 L F
.50468 .59102 m .45928 .54155 L .5145 .60173 L .571 .605 .848 r
F
.51107 .59976 m .51187 .60086 L .5145 .60173 L .476 .562 .863 r
F
.51053 .59944 m .51425 .60149 L .48706 .58256 L .627 .537 .734 r
F
.45655 .53858 m .44383 .54337 L .44536 .55079 L .483 .612 .904 r
F
.51047 .59941 m .51187 .60086 L .51107 .59976 L .368 .521 .878 r
F
.51414 .60204 m .48706 .58256 L .48661 .5823 L .627 .537 .734 r
F
.46189 .53566 m .46206 .53566 L .46058 .53753 L 0 0 0 r
F
.45299 .53992 m .46422 .53569 L .45188 .51883 L .368 .521 .878 r
F
.45655 .53858 m .43819 .51605 L .44383 .54337 L .483 .612 .904 r
F
.41522 .53517 m .41701 .5361 L .41191 .53184 L 0 .344 .809 r
F
.42669 .54111 m .41631 .53574 L .41857 .53691 L .483 .612 .904 r
F
.41631 .53574 m .41522 .53517 L .44141 .54876 L F
.42928 .54634 m .42996 .54652 L .41739 .53629 L 0 .344 .809 r
F
.41701 .5361 m .41739 .53629 L .41191 .53184 L F
.42928 .54634 m .41739 .53629 L .41701 .5361 L F
.38107 .51747 m .41522 .53517 L .39193 .51667 L 0 .218 .637 r
F
.39407 .5385 m .34281 .52738 L .39036 .53733 L .379 .639 .957 r
F
.36767 .53277 m .37281 .51317 L .33752 .52623 L F
.37575 .51779 m .37281 .51317 L .37191 .51658 L F
.42523 .54525 m .41382 .54273 L .42486 .54516 L F
.39744 .53881 m .39758 .53882 L .41373 .54222 L F
.40774 .54108 m .39744 .53881 L .41373 .54222 L F
.39814 .53927 m .39704 .53877 L .40774 .54108 L F
.39704 .53877 m .39744 .53881 L .40774 .54108 L F
.40588 .54097 m .40084 .53473 L .37374 .51801 L .434 0 0 r
F
.41632 .54843 m .40856 .54156 L .40588 .54097 L F
.42161 .54408 m .40774 .54108 L .41373 .54222 L .379 .639 .957 r
F
.40856 .54156 m .40084 .53473 L .40588 .54097 L .434 0 0 r
F
.39407 .5385 m .39506 .53859 L .39814 .53927 L .379 .639 .957 r
F
.39506 .53859 m .39704 .53877 L .39814 .53927 L F
.41382 .54273 m .40443 .54065 L .41378 .54271 L F
.41382 .54273 m .41378 .54271 L .42486 .54516 L F
.37374 .51801 m .41378 .54271 L .41405 .54283 L 0 .218 .637 r
F
.37374 .51801 m .41405 .54283 L .40321 .53607 L F
.39506 .53859 m .40588 .54097 L .37374 .51801 L .434 0 0 r
F
.37527 .51867 m .37191 .51658 L .36767 .53277 L .379 .639 .957 r
F
.37575 .51779 m .37191 .51658 L .37527 .51867 L F
.42523 .54525 m .40321 .53607 L .41405 .54283 L F
.40321 .53607 m .41405 .54283 L .41466 .5431 L 0 .218 .637 r
F
.37635 .51667 m .37955 .51667 L .37705 .51537 L .14 .68 .834 r
F
.37955 .51667 m .39193 .51667 L .37705 .51537 L F
.37864 .51619 m .37464 .51412 L .37915 .51646 L .483 .612 .904 r
F
.37464 .51412 m .36361 .5084 L .37705 .51537 L F
.37447 .51401 m .37705 .51537 L .39301 .51532 L .111 .652 .846 r
F
.37464 .51412 m .37705 .51537 L .37679 .51523 L .483 .612 .904 r
F
.41212 .54235 m .41378 .54271 L .40084 .53473 L .434 0 0 r
F
.40856 .54156 m .41212 .54235 L .40084 .53473 L F
.41522 .53517 m .37705 .51537 L .38812 .53721 L .379 .639 .957 r
F
.37705 .51537 m .37281 .51317 L .37422 .51538 L F
.37705 .51537 m .37422 .51538 L .38812 .53721 L F
.30513 .50911 m .37705 .51537 L .37447 .51401 L .111 .652 .846 r
F
.37679 .51523 m .37705 .51537 L .37915 .51646 L .483 .612 .904 r
F
.36163 .51604 m .36179 .51542 L .34849 .51873 L .379 .639 .957 r
F
.36179 .51542 m .3533 .51544 L .34849 .51873 L F
.36163 .51604 m .34849 .51873 L .35227 .51845 L F
.29252 .51668 m .37635 .51667 L .30513 .50911 L .14 .68 .834 r
F
.37635 .51667 m .37705 .51537 L .30513 .50911 L F
.38812 .53721 m .37575 .51779 L .36767 .53277 L .379 .639 .957 r
F
.37864 .51619 m .37915 .51646 L .41522 .53517 L .483 .612 .904 r
F
.39193 .51667 m .41522 .53517 L .41191 .53184 L 0 .344 .809 r
F
.37864 .51619 m .41522 .53517 L .41631 .53574 L .483 .612 .904 r
F
.41191 .53184 m .42996 .54652 L .43196 .54706 L 0 .344 .809 r
F
.39312 .51533 m .39193 .51667 L .41122 .51661 L .111 .652 .846 r
F
.393 .51533 m .39193 .51667 L .39312 .51533 L F
.37705 .51537 m .39193 .51667 L .39301 .51532 L F
.44536 .55079 m .43819 .51605 L .37647 .51506 L .483 .612 .904 r
F
.33363 .49787 m .41961 .5151 L .43876 .51676 L .15 .652 .908 r
F
.439 .51654 m .43876 .51676 L .44161 .51701 L F
.33363 .49787 m .43876 .51676 L .439 .51654 L F
.4391 .51646 m .43876 .51676 L .45655 .53858 L .571 .605 .848 r
F
.45928 .54155 m .45655 .53858 L .48197 .56977 L F
.45655 .53858 m .50326 .58947 L .46422 .53569 L .368 .521 .878 r
F
.4391 .51646 m .45655 .53858 L .45928 .54155 L .571 .605 .848 r
F
.45299 .53992 m .51047 .59941 L .50326 .58947 L .368 .521 .878 r
F
.45299 .53992 m .50326 .58947 L .45655 .53858 L F
.51422 .60162 m .51425 .60149 L .51053 .59944 L .627 .537 .734 r
F
.51047 .59941 m .51107 .59976 L .46422 .53569 L .368 .521 .878 r
F
.51414 .60204 m .51422 .60162 L .51053 .59944 L .627 .537 .734 r
F
.51389 .60811 m .51424 .60159 L .51137 .61547 L F
.51424 .60159 m .51425 .60149 L .51423 .60158 L F
.51424 .60159 m .51423 .60158 L .51137 .61547 L F
.50468 .59102 m .51107 .59976 L .5145 .60173 L .476 .562 .863 r
F
.52044 .62023 m .52096 .61561 L .51744 .64149 L .719 .599 .722 r
F
.51744 .64149 m .52096 .61561 L .51575 .65346 L F
.52096 .61561 m .52171 .60882 L .51336 .67034 L F
.51575 .65346 m .51336 .67034 L .50896 .70279 L F
.52096 .61561 m .51336 .67034 L .51575 .65346 L F
.51389 .60811 m .51137 .61547 L .50389 .65172 L .627 .537 .734 r
F
.5133 .60982 m .51786 .63848 L .51582 .60249 L .609 .514 .722 r
F
.51786 .63848 m .5238 .67581 L .51892 .631 L F
.51786 .63848 m .51892 .631 L .51582 .60249 L F
.51588 .60308 m .51892 .631 L .51962 .60661 L F
.51892 .631 m .5238 .67581 L .52044 .62023 L F
.51892 .631 m .52044 .62023 L .51962 .60661 L F
.51267 .61167 m .51674 .71229 L .51977 .70818 L F
.51237 .61215 m .51674 .71229 L .51267 .61167 L F
.51203 .68045 m .51208 .70636 L .51455 .66215 L F
.5089 .70432 m .51744 .64149 L .50896 .70279 L .719 .599 .722 r
F
.51744 .64149 m .51575 .65346 L .50896 .70279 L F
.52912 .68929 m .54484 .66341 L .51638 .65698 L F
.53024 .69158 m .53031 .69146 L .53018 .69166 L .812 .687 .726 r
F
.53031 .69146 m .54484 .66341 L .53018 .69166 L F
.53508 .6852 m .53049 .72409 L .5356 .69229 L .683 .581 .735 r
F
.53562 .68448 m .54484 .66341 L .53024 .69158 L .812 .687 .726 r
F
.53996 .62086 m .54065 .62205 L .52914 .61597 L .666 .547 .71 r
F
.53996 .62086 m .52914 .61597 L .52889 .61543 L F
.53893 .61908 m .52193 .57651 L .54605 .571 L .699 .548 .679 r
F
.53313 .60905 m .52193 .57651 L .53893 .61908 L F
.52937 .60809 m .53057 .62433 L .53577 .61003 L .683 .581 .735 r
F
.53057 .62433 m .5356 .69229 L .53572 .63448 L F
.53057 .62433 m .53572 .63448 L .53577 .61003 L F
.56021 .63081 m .54065 .62205 L .53996 .62086 L .666 .547 .71 r
F
.53893 .61908 m .54605 .571 L .55196 .61979 L .699 .548 .679 r
F
.53822 .62386 m .55531 .64742 L .55608 .65379 L F
.53577 .61003 m .53572 .63448 L .5482 .6138 L .683 .581 .735 r
F
.56026 .63082 m .54605 .571 L .57268 .56248 L .684 .561 .71 r
F
.55538 .62434 m .54605 .571 L .56026 .63082 L F
.55611 .63022 m .5622 .63344 L .55871 .6431 L .743 .634 .739 r
F
.56026 .63082 m .57268 .56248 L .58015 .63368 L .684 .561 .71 r
F
.56049 .63085 m .5618 .62248 L .5622 .63344 L .666 .547 .71 r
F
.56021 .63081 m .5622 .63344 L .55611 .63022 L F
.5482 .6138 m .54697 .64468 L .56918 .61842 L .722 .627 .751 r
F
.54484 .66341 m .55274 .65001 L .54465 .64574 L .651 .623 .809 r
F
.56186 .62707 m .565 .63638 L .56918 .61842 L .722 .627 .751 r
F
.54697 .64468 m .55922 .63904 L .56186 .62707 L F
.55922 .63904 m .565 .63638 L .56186 .62707 L F
.54184 .7178 m .54452 .70566 L .54484 .66341 L .728 .669 .792 r
F
.54767 .69951 m .55358 .65995 L .58171 .64862 L .794 .728 .79 r
F
.55608 .65379 m .55531 .64742 L .55835 .6413 L .684 .561 .71 r
F
.55358 .65995 m .55608 .65379 L .56069 .65286 L .794 .728 .79 r
F
.55358 .65995 m .56069 .65286 L .58171 .64862 L F
.55608 .65379 m .55835 .6413 L .55842 .64163 L .684 .561 .71 r
F
.54452 .70566 m .55922 .63904 L .55274 .65001 L .728 .669 .792 r
F
.54452 .70566 m .55274 .65001 L .54484 .66341 L F
.54112 .72619 m .54311 .72427 L .54142 .72557 L .814 .762 .804 r
F
.54452 .70566 m .54172 .72463 L .54233 .72447 L .722 .627 .751 r
F
.54142 .72557 m .54311 .72427 L .54172 .72463 L .728 .669 .792 r
F
.54452 .70566 m .54226 .72509 L .5438 .7236 L .722 .627 .751 r
F
.56108 .72766 m .63613 .62927 L .57952 .71964 L .819 .811 .843 r
F
.56108 .72766 m .60896 .64054 L .63613 .62927 L F
.56294 .70663 m .54979 .72136 L .56174 .72347 L .735 .656 .771 r
F
.5445 .72254 m .54678 .72083 L .54541 .72058 L .728 .669 .792 r
F
.54473 .72347 m .5462 .72211 L .54403 .72357 L .814 .762 .804 r
F
.54473 .72347 m .54362 .72827 L .54979 .72136 L .735 .656 .771 r
F
.54746 .72095 m .54979 .72136 L .56294 .70663 L F
.54473 .72347 m .54979 .72136 L .54746 .72095 L F
.55274 .65001 m .55922 .63904 L .54697 .64468 L .651 .623 .809 r
F
.55274 .65001 m .54373 .64168 L .54025 .64342 L F
.54697 .64468 m .5438 .7236 L .565 .63638 L .722 .627 .751 r
F
.5438 .7236 m .54391 .72359 L .565 .63638 L F
.54378 .7241 m .54541 .72058 L .565 .63638 L F
.54311 .72427 m .54746 .72095 L .54172 .72463 L .728 .669 .792 r
F
.54746 .72095 m .54678 .72083 L .54172 .72463 L F
.55958 .71314 m .55138 .71795 L .54746 .72095 L .814 .762 .804 r
F
.5462 .72211 m .54746 .72095 L .54403 .72357 L F
.55958 .71314 m .54746 .72095 L .5462 .72211 L F
.54172 .72463 m .5445 .72254 L .54512 .72053 L .728 .669 .792 r
F
.56759 .64085 m .54541 .72058 L .56294 .70663 L .735 .656 .771 r
F
.56918 .61842 m .565 .63638 L .56759 .64085 L F
.565 .63638 m .54541 .72058 L .56759 .64085 L F
.58171 .64862 m .57268 .56248 L .60109 .54985 L .688 .59 .741 r
F
.56695 .70606 m .60288 .67861 L .56711 .70553 L .728 .669 .792 r
F
.58171 .64862 m .60109 .54985 L .60896 .64054 L .688 .59 .741 r
F
.56918 .61842 m .56294 .70663 L .59192 .62257 L .735 .656 .771 r
F
.56294 .70663 m .56174 .72347 L .56695 .70606 L F
.56294 .70663 m .56695 .70606 L .59192 .62257 L F
.57952 .71964 m .6612 .61515 L .59526 .70965 L .852 .894 .866 r
F
.57952 .71964 m .63613 .62927 L .6612 .61515 L F
.58773 .69093 m .56122 .73085 L .58444 .73387 L .731 .671 .792 r
F
.56857 .70583 m .58739 .69096 L .56695 .70606 L .814 .762 .804 r
F
.57588 .70014 m .58739 .69096 L .56857 .70583 L F
.58739 .69096 m .60288 .67861 L .58663 .69103 L F
.58739 .69096 m .58663 .69103 L .56695 .70606 L F
.58783 .6896 m .60288 .67861 L .59185 .63705 L .728 .669 .792 r
F
.58783 .6896 m .59185 .63705 L .58896 .62618 L F
.54541 .72058 m .54746 .72095 L .56294 .70663 L .735 .656 .771 r
F
.54541 .72058 m .58783 .6896 L .58896 .62618 L .728 .669 .792 r
F
.54678 .72083 m .60288 .67861 L .54541 .72058 L F
.56857 .70583 m .56122 .73085 L .58773 .69093 L .731 .671 .792 r
F
.58773 .69093 m .58444 .73387 L .58557 .73049 L F
.59291 .69048 m .58776 .71856 L .60288 .67861 L .814 .762 .804 r
F
.59291 .69048 m .58557 .73049 L .59909 .68995 L .731 .671 .792 r
F
.58773 .69093 m .58557 .73049 L .59291 .69048 L F
.52741 .76848 m .53401 .76457 L .56122 .73085 L .92 .85 .758 r
F
.52741 .76848 m .58086 .73679 L .58776 .71856 L .814 .762 .804 r
F
.56831 .70587 m .56122 .73085 L .56857 .70583 L .735 .656 .771 r
F
.56174 .72347 m .56122 .73085 L .59192 .62257 L F
.56174 .72347 m .54362 .72827 L .56122 .73085 L F
.54979 .72136 m .54362 .72827 L .56174 .72347 L F
.54378 .7241 m .54362 .72827 L .54473 .72347 L .722 .627 .751 r
F
.54403 .72357 m .54473 .72347 L .54541 .72058 L F
.54378 .7241 m .54473 .72347 L .54403 .72357 L F
.49011 .8061 m .49058 .80589 L .54135 .72755 L .896 .772 .717 r
F
.49024 .80604 m .53985 .72887 L .54112 .72619 L .92 .842 .75 r
F
.54119 .72592 m .54112 .72619 L .54142 .72557 L F
.49024 .80604 m .54112 .72619 L .54119 .72592 L F
.54379 .72398 m .54121 .72585 L .54362 .72827 L .722 .627 .751 r
F
.54121 .72585 m .54081 .72738 L .54362 .72827 L F
.53521 .75919 m .56793 .72023 L .53985 .72887 L .814 .762 .804 r
F
.56793 .72023 m .58157 .70399 L .55018 .72271 L F
.56793 .72023 m .55018 .72271 L .53985 .72887 L F
.58157 .70399 m .60288 .67861 L .56879 .7058 L F
.58157 .70399 m .56879 .7058 L .53985 .72887 L F
.59192 .62257 m .56831 .70587 L .59294 .62276 L .735 .656 .771 r
F
.56831 .70587 m .56857 .70583 L .59294 .62276 L F
.58157 .70399 m .58776 .71856 L .59291 .69048 L .814 .762 .804 r
F
.52741 .76848 m .57383 .73008 L .58157 .70399 L F
.57383 .73008 m .58776 .71856 L .58157 .70399 L F
.59294 .62276 m .56857 .70583 L .58773 .69093 L .731 .671 .792 r
F
.56879 .7058 m .57588 .70014 L .56857 .70583 L .814 .762 .804 r
F
.60896 .64054 m .6301 .53254 L .63613 .62927 L .712 .634 .768 r
F
.60896 .64054 m .60109 .54985 L .6301 .53254 L F
.59294 .62276 m .58773 .69093 L .61981 .62787 L .731 .671 .792 r
F
.58773 .69093 m .59909 .68995 L .61981 .62787 L F
.55958 .71314 m .56879 .7058 L .55138 .71795 L .814 .762 .804 r
F
.56879 .7058 m .56695 .70606 L .55138 .71795 L F
.54746 .72095 m .56695 .70606 L .54678 .72083 L .728 .669 .792 r
F
.56695 .70606 m .56711 .70553 L .54678 .72083 L F
.52193 .57651 m .52297 .56391 L .54605 .571 L .494 .321 .575 r
F
.53283 .57165 m .5482 .6138 L .56918 .61842 L .568 .612 .856 r
F
.51969 .56197 m .52023 .55025 L .52307 .5627 L .494 .321 .575 r
F
.54469 .56615 m .53527 .53254 L .54567 .56618 L .474 .357 .64 r
F
.52326 .56352 m .54567 .56618 L .5328 .56572 L .666 .547 .71 r
F
.52326 .56352 m .5328 .56572 L .52297 .56391 L F
.52297 .56391 m .53002 .56521 L .54605 .571 L .494 .321 .575 r
F
.5152 .56256 m .52326 .56352 L .52194 .56533 L .666 .547 .71 r
F
.51969 .56197 m .51305 .51877 L .52023 .55025 L .494 .321 .575 r
F
.53195 .54155 m .54567 .56618 L .5152 .56256 L .55 .438 .679 r
F
.52156 .56188 m .5482 .6138 L .53283 .57165 L .568 .612 .856 r
F
.52182 .56883 m .5482 .6138 L .52156 .56188 L F
.52008 .59652 m .51159 .5783 L .52193 .57651 L .732 .552 .648 r
F
.52008 .59652 m .52193 .57651 L .52441 .594 L F
.52193 .57651 m .5199 .56813 L .52051 .56729 L .494 .321 .575 r
F
.51447 .52501 m .5213 .55491 L .5152 .56256 L .55 .438 .679 r
F
.51077 .56519 m .51816 .56757 L .52193 .57651 L .543 .31 .512 r
F
.5152 .56256 m .51862 .56772 L .51575 .57205 L .666 .547 .71 r
F
.52104 .57666 m .51616 .57142 L .52193 .57651 L .543 .31 .512 r
F
.51616 .57142 m .51647 .57097 L .52193 .57651 L F
.52058 .57955 m .52937 .60809 L .5482 .6138 L .538 .59 .855 r
F
.52074 .5961 m .52937 .60809 L .52086 .59488 L .476 .562 .863 r
F
.52056 .59794 m .52612 .60434 L .52074 .5961 L F
.52612 .60434 m .52937 .60809 L .52074 .5961 L F
.47507 .52883 m .47885 .5269 L .47867 .52864 L .455 .123 .313 r
F
.47325 .53293 m .47867 .52864 L .48541 .52851 L 0 0 0 r
F
.47867 .52864 m .47886 .52848 L .48129 .5285 L F
.47867 .52864 m .48129 .5285 L .48541 .52851 L F
.47885 .5269 m .47962 .52788 L .47867 .52864 L .523 .324 .553 r
F
.50048 .55873 m .50466 .55908 L .50289 .56083 L .65 .463 .618 r
F
.50048 .55873 m .50289 .56083 L .49678 .56688 L F
.48468 .54484 m .48541 .52851 L .4847 .54483 L .608 .314 .444 r
F
.4847 .54483 m .48541 .52851 L .48967 .54288 L F
.47116 .52845 m .47952 .52453 L .47785 .52714 L 0 0 0 r
F
.47789 .52709 m .48117 .52366 L .47885 .5269 L F
.4798 .52409 m .48117 .52366 L .47789 .52709 L F
.47116 .52845 m .48413 .51732 L .47952 .52453 L F
.47885 .5269 m .47975 .52778 L .47962 .52788 L .523 .324 .553 r
F
.48541 .52851 m .48621 .52727 L .48623 .52725 L 0 0 0 r
F
.51142 .52213 m .51447 .52501 L .5152 .56256 L .55 .438 .679 r
F
.47885 .5269 m .48447 .52607 L .47943 .52747 L .523 .324 .553 r
F
.50551 .53752 m .49859 .52217 L .50669 .52701 L .543 .31 .512 r
F
.50326 .55757 m .50551 .53752 L .51444 .55873 L F
.51093 .55837 m .51142 .52213 L .5152 .56256 L .523 .324 .553 r
F
.50613 .5229 m .51142 .52213 L .51093 .55837 L F
.50811 .56538 m .5152 .56256 L .51575 .57205 L .65 .463 .618 r
F
.50326 .55757 m .50018 .55424 L .50551 .53752 L .543 .31 .512 r
F
.52074 .5961 m .51645 .53961 L .47379 .52414 L .571 .605 .848 r
F
.46953 .52912 m .47104 .5286 L .47043 .52907 L .455 .123 .313 r
F
.46315 .52938 m .47179 .52664 L .46369 .52989 L 0 0 0 r
F
.47179 .52664 m .47093 .52728 L .46369 .52989 L F
.46369 .52989 m .47093 .52728 L .46882 .52887 L F
.45188 .51883 m .52056 .59794 L .47302 .52057 L .476 .562 .863 r
F
.52085 .59502 m .52001 .58447 L .52074 .5961 L .651 .623 .809 r
F
.5189 .57044 m .51645 .53961 L .51882 .57086 L F
.52037 .56827 m .51645 .53961 L .52087 .5953 L F
.52058 .57955 m .5482 .6138 L .52182 .56883 L .538 .59 .855 r
F
.52156 .56188 m .51645 .53961 L .52236 .58279 L .651 .623 .809 r
F
.53666 .51403 m .5428 .51206 L .51447 .52501 L .55 .438 .679 r
F
.51447 .52501 m .53195 .54155 L .5213 .55491 L F
.52307 .5627 m .5267 .51896 L .54372 .56269 L .494 .321 .575 r
F
.5328 .56572 m .54567 .56618 L .54522 .56801 L .666 .547 .71 r
F
.52307 .5627 m .51305 .51877 L .52694 .51598 L .494 .321 .575 r
F
.54605 .571 m .54522 .56801 L .54567 .56618 L .474 .357 .64 r
F
.54605 .571 m .54567 .56618 L .54609 .56694 L F
.54605 .571 m .54675 .4919 L .57268 .56248 L F
.51928 .55193 m .58209 .60029 L .51645 .53961 L .651 .623 .809 r
F
.54189 .57328 m .58209 .60029 L .51928 .55193 L F
.55744 .59742 m .58209 .60029 L .52095 .55921 L F
.57615 .60999 m .56918 .61842 L .58819 .61807 L .577 .626 .864 r
F
.5765 .60977 m .58819 .61807 L .58689 .6165 L F
.55744 .59742 m .57615 .60999 L .5765 .60977 L F
.57615 .60999 m .58819 .61807 L .5765 .60977 L F
.58928 .61805 m .58819 .61807 L .59294 .62276 L F
.58819 .61807 m .56918 .61842 L .59192 .62257 L F
.58819 .61807 m .59192 .62257 L .59294 .62276 L F
.57976 .60789 m .58616 .61562 L .58209 .60029 L .728 .669 .792 r
F
.57966 .60778 m .57986 .60716 L .57964 .60779 L F
.57986 .60716 m .58209 .60029 L .57984 .60717 L F
.57986 .60716 m .57984 .60717 L .57964 .60779 L F
.57964 .60779 m .57984 .60717 L .5765 .60977 L F
.57984 .60717 m .58209 .60029 L .57794 .60733 L F
.57984 .60717 m .57794 .60733 L .5765 .60977 L F
.58928 .61805 m .59145 .62009 L .58398 .60681 L .577 .626 .864 r
F
.57966 .60778 m .57976 .60789 L .58209 .60029 L .728 .669 .792 r
F
.57429 .60834 m .58209 .60029 L .55744 .59742 L .651 .623 .809 r
F
.57659 .60961 m .58209 .60029 L .57467 .60794 L F
.58313 .60688 m .58398 .60681 L .53989 .52837 L .577 .626 .864 r
F
.58928 .61805 m .58398 .60681 L .58313 .60688 L F
.5267 .51896 m .53527 .53254 L .54372 .56269 L .494 .321 .575 r
F
.53527 .53254 m .53547 .532 L .54567 .56618 L .474 .357 .64 r
F
.51704 .52514 m .58076 .60709 L .53989 .52837 L .577 .626 .864 r
F
.58076 .60709 m .58928 .61805 L .58313 .60688 L F
.58076 .60709 m .58313 .60688 L .53989 .52837 L F
.55744 .59742 m .5675 .61543 L .57615 .60999 L F
.5675 .61543 m .56918 .61842 L .57615 .60999 L F
.53283 .57165 m .56918 .61842 L .55744 .59742 L .568 .612 .856 r
F
.56347 .63184 m .57372 .61447 L .55829 .62482 L .651 .623 .809 r
F
.57372 .61447 m .57659 .60961 L .5724 .61309 L F
.57372 .61447 m .5724 .61309 L .55829 .62482 L F
.52095 .55921 m .54189 .57328 L .51928 .55193 L F
.52137 .55691 m .53283 .57165 L .52467 .53879 L .568 .612 .856 r
F
.53283 .57165 m .55744 .59742 L .52467 .53879 L F
.57659 .60961 m .57467 .60794 L .55829 .62482 L .651 .623 .809 r
F
.54609 .56694 m .54567 .56618 L .54611 .56439 L .474 .357 .64 r
F
.51704 .52514 m .55744 .59742 L .58928 .61805 L .577 .626 .864 r
F
.5445 .72254 m .58896 .62618 L .58616 .61562 L .728 .669 .792 r
F
.5445 .72254 m .58616 .61562 L .57976 .60789 L F
.54172 .72463 m .57966 .60778 L .542 .72272 L F
.57966 .60778 m .57964 .60779 L .542 .72272 L F
.5439 .71693 m .57964 .60779 L .56291 .63279 L F
.57964 .60779 m .5765 .60977 L .56291 .63279 L F
.58689 .6165 m .58819 .61807 L .58928 .61805 L .577 .626 .864 r
F
.54316 .72019 m .54512 .72053 L .57976 .60789 L .728 .669 .792 r
F
.54316 .72019 m .57976 .60789 L .57966 .60778 L F
.57105 .61167 m .57429 .60834 L .55744 .59742 L .651 .623 .809 r
F
.58928 .61805 m .59294 .62276 L .59145 .62009 L .577 .626 .864 r
F
.54142 .72557 m .54172 .72463 L .542 .72272 L .728 .669 .792 r
F
.54142 .72557 m .55922 .63904 L .54184 .7178 L F
.54484 .66341 m .54465 .64574 L .54115 .64735 L .651 .623 .809 r
F
.53562 .68448 m .54142 .72557 L .54484 .66341 L .812 .687 .726 r
F
.5356 .69197 m .54142 .72557 L .53562 .68448 L F
.54107 .72585 m .54142 .72557 L .53468 .68663 L F
.54121 .72585 m .54119 .72592 L .54142 .72557 L .92 .842 .75 r
F
.54121 .72585 m .54142 .72557 L .54109 .72594 L F
.54641 .64416 m .53963 .727 L .54158 .72559 L .722 .627 .751 r
F
.5482 .6138 m .54594 .64373 L .54641 .64416 L F
.54594 .64373 m .53963 .727 L .54641 .64416 L F
.54697 .64468 m .54158 .72559 L .54452 .70566 L F
.5482 .6138 m .54641 .64416 L .54697 .64468 L F
.54641 .64416 m .54158 .72559 L .54697 .64468 L F
.5482 .6138 m .54373 .64168 L .54594 .64373 L F
.53572 .63448 m .54025 .64342 L .5482 .6138 L .683 .581 .735 r
F
.54115 .64735 m .54465 .64574 L .54025 .64342 L .651 .623 .809 r
F
.54025 .64342 m .54223 .64733 L .54319 .64195 L .683 .581 .735 r
F
.54025 .64342 m .54319 .64195 L .5482 .6138 L F
.53562 .68448 m .53719 .68241 L .5482 .6138 L F
.56261 .63227 m .55829 .62482 L .54278 .64081 L .651 .623 .809 r
F
.54373 .64168 m .54278 .64081 L .54025 .64342 L F
.56261 .63227 m .54278 .64081 L .54373 .64168 L F
.53881 .63714 m .57105 .61167 L .52095 .55921 L F
.54025 .64342 m .54278 .64081 L .53881 .63714 L F
.54278 .64081 m .57105 .61167 L .53881 .63714 L F
.51142 .52213 m .53666 .51403 L .51447 .52501 L .55 .438 .679 r
F
.48777 .52516 m .50691 .49794 L .49859 .52217 L 0 0 0 r
F
.50105 .52364 m .50613 .5229 L .50669 .52701 L .523 .324 .553 r
F
.49473 .52263 m .52137 .55691 L .51704 .52514 L .568 .612 .856 r
F
.52137 .55691 m .52467 .53879 L .51704 .52514 L F
.52001 .58447 m .5189 .57044 L .51992 .58527 L .651 .623 .809 r
F
.5189 .57044 m .51882 .57086 L .51992 .58527 L F
.52001 .58447 m .51992 .58527 L .52074 .5961 L F
.47302 .52057 m .52058 .57955 L .49473 .52263 L .538 .59 .855 r
F
.52086 .59488 m .52937 .60809 L .52058 .57955 L F
.52236 .58279 m .52037 .56827 L .52087 .5953 L .651 .623 .809 r
F
.52058 .57955 m .52182 .56883 L .49473 .52263 L .538 .59 .855 r
F
.52056 .59794 m .52086 .59488 L .47302 .52057 L .476 .562 .863 r
F
.52075 .59628 m .52074 .5961 L .47245 .52365 L .571 .605 .848 r
F
.52074 .5961 m .47379 .52414 L .47245 .52365 L F
.52087 .5953 m .52085 .59502 L .52075 .59628 L .651 .623 .809 r
F
.52085 .59502 m .52074 .5961 L .52075 .59628 L F
.47302 .52057 m .52086 .59488 L .52058 .57955 L .538 .59 .855 r
F
.52372 .57133 m .52156 .56188 L .52236 .58279 L .651 .623 .809 r
F
.49473 .52263 m .51381 .55516 L .52156 .56188 L .568 .612 .856 r
F
.52137 .55691 m .52156 .56188 L .53283 .57165 L F
.49473 .52263 m .52156 .56188 L .52137 .55691 L F
.51381 .55516 m .52182 .56883 L .52156 .56188 L F
.52937 .60809 m .52951 .62223 L .53057 .62433 L .683 .581 .735 r
F
.52937 .60809 m .52842 .61968 L .52951 .62223 L F
.52263 .60922 m .52842 .61968 L .52937 .60809 L .609 .514 .722 r
F
.53932 .63937 m .52372 .57133 L .52267 .59088 L .651 .623 .809 r
F
.52999 .62318 m .52177 .60767 L .52171 .60882 L F
.52596 .61524 m .52177 .60767 L .52999 .62318 L F
.52177 .60767 m .52159 .60735 L .52171 .60882 L F
.51946 .604 m .51966 .60726 L .52153 .60735 L .609 .514 .722 r
F
.51982 .60414 m .52213 .60832 L .52256 .60528 L F
.51946 .604 m .52213 .60832 L .51982 .60414 L F
.50468 .59102 m .51481 .60208 L .51982 .60414 L .476 .562 .863 r
F
.50468 .59102 m .51982 .60414 L .52009 .60187 L F
.51582 .60249 m .51588 .60308 L .51946 .604 L .609 .514 .722 r
F
.51588 .60308 m .51962 .60661 L .51946 .604 L F
.44335 .51678 m .45188 .51883 L .46064 .51895 L .182 .659 .931 r
F
.44889 .51733 m .46064 .51895 L .46579 .51903 L F
.44335 .51678 m .46064 .51895 L .44889 .51733 L F
.52065 .60731 m .52075 .59628 L .45878 .5187 L .571 .605 .848 r
F
.52171 .60882 m .52159 .60735 L .52065 .60731 L F
.52159 .60735 m .52075 .59628 L .52065 .60731 L F
.43876 .51567 m .44335 .51678 L .44014 .51356 L .182 .659 .931 r
F
.52171 .60882 m .45878 .5187 L .43861 .51591 L .571 .605 .848 r
F
.52153 .60735 m .52044 .62023 L .52213 .60832 L .609 .514 .722 r
F
.51966 .60726 m .52044 .62023 L .52153 .60735 L F
.52372 .57133 m .52075 .59628 L .52159 .60735 L .651 .623 .809 r
F
.52372 .57133 m .52159 .60735 L .52177 .60767 L F
.52044 .62023 m .5238 .67581 L .52256 .60528 L .609 .514 .722 r
F
.52341 .61 m .52267 .59088 L .5218 .60704 L .651 .623 .809 r
F
.53932 .63937 m .52267 .59088 L .52341 .61 L F
.56347 .63184 m .55829 .62482 L .56261 .63227 L F
.54172 .72463 m .54512 .72053 L .54316 .72019 L .728 .669 .792 r
F
.54541 .72058 m .54473 .72347 L .54746 .72095 L .735 .656 .771 r
F
.542 .72272 m .5439 .71693 L .55922 .63904 L .728 .669 .792 r
F
.5439 .71693 m .56291 .63279 L .55922 .63904 L F
.54697 .64468 m .56347 .63184 L .54373 .64168 L .651 .623 .809 r
F
.55922 .63904 m .56347 .63184 L .54697 .64468 L F
.54703 .72315 m .55958 .71314 L .5462 .72211 L .814 .762 .804 r
F
.54703 .72315 m .5462 .72211 L .54473 .72347 L F
.60678 .69801 m .69652 .58265 L .6127 .68522 L .669 .902 .562 r
F
.6127 .68522 m .69652 .58265 L .70283 .56733 L 0 0 0 r
F
.60678 .69801 m .68204 .59912 L .69652 .58265 L .669 .902 .562 r
F
.59526 .70965 m .68204 .59912 L .60678 .69801 L .865 .987 .838 r
F
.59526 .70965 m .6612 .61515 L .68204 .59912 L F
.61697 .67946 m .58444 .73387 L .61365 .73979 L .711 .673 .811 r
F
.61981 .62787 m .59909 .68995 L .61697 .67946 L F
.59909 .68995 m .58444 .73387 L .61697 .67946 L F
.5438 .7236 m .54226 .72509 L .54379 .72398 L .722 .627 .751 r
F
.53985 .72887 m .54703 .72315 L .54311 .72427 L .814 .762 .804 r
F
.5438 .7236 m .54378 .7241 L .54391 .72359 L .722 .627 .751 r
F
.54703 .72315 m .54403 .72357 L .54311 .72427 L .814 .762 .804 r
F
.54233 .72447 m .54158 .72559 L .54226 .72509 L .722 .627 .751 r
F
.54172 .72463 m .54158 .72559 L .54233 .72447 L F
.53985 .72887 m .54311 .72427 L .54112 .72619 L .814 .762 .804 r
F
.54594 .64373 m .53049 .72409 L .53963 .727 L .722 .627 .751 r
F
.54373 .64168 m .53049 .72409 L .54594 .64373 L F
.54025 .64342 m .53562 .68448 L .54223 .64733 L .683 .581 .735 r
F
.53572 .63448 m .53569 .64569 L .54025 .64342 L F
.53569 .64569 m .53562 .68448 L .54025 .64342 L F
.53932 .63937 m .52596 .61524 L .52999 .62318 L .651 .623 .809 r
F
.52596 .61524 m .5218 .60704 L .52177 .60767 L F
.53932 .63937 m .5218 .60704 L .52596 .61524 L F
.51087 .73425 m .51046 .73579 L .52042 .71698 L .692 .491 .61 r
F
.50619 .75174 m .53562 .68448 L .51378 .72337 L .812 .687 .726 r
F
.53562 .68448 m .53024 .69158 L .51378 .72337 L F
.53562 .68448 m .5356 .69229 L .53719 .68241 L .683 .581 .735 r
F
.53057 .62433 m .53018 .69166 L .53508 .6852 L F
.52951 .62223 m .53018 .69166 L .53057 .62433 L F
.54025 .64342 m .53932 .63937 L .52999 .62318 L .651 .623 .809 r
F
.52951 .62223 m .5238 .67581 L .53018 .69166 L .683 .581 .735 r
F
.52842 .61968 m .5238 .67581 L .52951 .62223 L F
.52263 .60922 m .5238 .67581 L .52842 .61968 L .609 .514 .722 r
F
.52075 .59628 m .47245 .52365 L .45878 .5187 L .571 .605 .848 r
F
.51462 .60185 m .50468 .59102 L .5145 .60173 L F
.51568 .60289 m .4391 .51646 L .45928 .54155 L F
.51568 .60289 m .45928 .54155 L .51462 .60185 L F
.52035 .6073 m .4391 .51646 L .51568 .60289 L F
.48661 .5823 m .48706 .58256 L .48446 .58075 L .627 .537 .734 r
F
.4848 .58291 m .48453 .58106 L .48479 .58291 L .182 .455 .88 r
F
.48453 .58106 m .48431 .5796 L .48452 .58106 L F
.48453 .58106 m .48452 .58106 L .48479 .58291 L F
.49244 .58888 m .49841 .59384 L .49291 .58975 L .732 .556 .654 r
F
.50052 .59398 m .49841 .59384 L .49244 .58888 L .65 .463 .618 r
F
.48756 .58341 m .49495 .59206 L .49062 .58475 L .368 .521 .878 r
F
.48756 .58341 m .49062 .58475 L .48167 .5696 L F
.4848 .58292 m .49495 .59206 L .48661 .5823 L .182 .455 .88 r
F
.48453 .58106 m .48661 .5823 L .48446 .58075 L .627 .537 .734 r
F
.48453 .58106 m .48661 .5823 L .48431 .5796 L .182 .455 .88 r
F
.4848 .58292 m .48661 .5823 L .48453 .58106 L F
.50079 .594 m .5013 .59447 L .50052 .59398 L .65 .463 .618 r
F
.48325 .57124 m .49495 .59206 L .51187 .60086 L .368 .521 .878 r
F
.48342 .57256 m .49495 .59206 L .48325 .57124 L F
.4848 .58292 m .48494 .58613 L .49495 .59206 L .182 .455 .88 r
F
.49495 .59206 m .50389 .65172 L .51187 .60086 L .47 .41 .709 r
F
.50389 .65172 m .51162 .61422 L .51187 .60086 L F
.51015 .69343 m .51203 .68045 L .51187 .60086 L F
.50227 .65956 m .51414 .60204 L .48661 .5823 L .627 .537 .734 r
F
.50227 .65956 m .48661 .5823 L .48453 .58106 L F
.47112 .56413 m .48661 .5823 L .48167 .5696 L .368 .521 .878 r
F
.48661 .5823 m .4873 .58279 L .48167 .5696 L F
.4848 .58292 m .4536 .54361 L .45305 .54409 L .182 .455 .88 r
F
.44729 .54911 m .4848 .58292 L .45305 .54409 L F
.49163 .61469 m .4848 .58291 L .47488 .60867 L .511 .482 .761 r
F
.4848 .58292 m .4848 .58291 L .48479 .58291 L .182 .455 .88 r
F
.4848 .58291 m .47975 .582 L .47488 .60867 L .511 .482 .761 r
F
.45299 .53992 m .47112 .56413 L .48167 .5696 L .368 .521 .878 r
F
.4536 .54361 m .47112 .56413 L .45299 .53992 L F
.48477 .58213 m .48453 .58106 L .4848 .58292 L .627 .537 .734 r
F
.48453 .58106 m .4848 .58289 L .4848 .58292 L F
.48167 .5696 m .48342 .57256 L .48325 .57124 L .368 .521 .878 r
F
.45003 .55321 m .46875 .57295 L .47523 .57698 L .182 .455 .88 r
F
.44698 .55163 m .46875 .57295 L .45003 .55321 L F
.41862 .53693 m .46497 .57212 L .44327 .5497 L 0 .344 .809 r
F
.45427 .5554 m .47523 .57698 L .48479 .58291 L .182 .455 .88 r
F
.45003 .55321 m .47523 .57698 L .45427 .5554 L F
.42669 .54111 m .37864 .51619 L .41631 .53574 L .483 .612 .904 r
F
.41522 .53517 m .42928 .54634 L .41701 .5361 L 0 .344 .809 r
F
.42928 .54634 m .44894 .56196 L .42996 .54652 L F
.42523 .54525 m .41522 .53517 L .40321 .53607 L .379 .639 .957 r
F
.41382 .54273 m .39407 .5385 L .40443 .54065 L F
.41405 .54283 m .39407 .5385 L .41382 .54273 L F
.39407 .5385 m .39273 .53808 L .39506 .53859 L F
.39273 .53808 m .39036 .53733 L .39506 .53859 L F
.41405 .54283 m .40321 .53607 L .38812 .53721 L F
.4525 .58739 m .44545 .56281 L .43163 .55552 L .315 .407 .797 r
F
.4525 .58739 m .43163 .55552 L .42711 .55781 L F
.43196 .54706 m .44894 .56196 L .44542 .55728 L 0 .344 .809 r
F
.42996 .54652 m .44894 .56196 L .43196 .54706 L F
.44743 .56318 m .44894 .56196 L .44602 .55964 L 0 .218 .637 r
F
.4506 .56507 m .44894 .56196 L .44999 .564 L .315 .407 .797 r
F
.47035 .59952 m .45077 .56518 L .4506 .56507 L F
.45077 .56518 m .44894 .56196 L .4506 .56507 L F
.44842 .56127 m .44894 .56196 L .47035 .59952 L .511 .482 .761 r
F
.44542 .55728 m .44894 .56196 L .45987 .56825 L 0 .344 .809 r
F
.44894 .56196 m .46075 .57135 L .45987 .56825 L F
.45045 .56493 m .44838 .5612 L .45058 .56503 L .511 .482 .761 r
F
.45045 .56493 m .4477 .56001 L .44838 .5612 L F
.45045 .56493 m .45058 .56503 L .47035 .59952 L F
.45118 .56548 m .45216 .56622 L .46075 .57135 L 0 .218 .637 r
F
.46993 .5981 m .47059 .60002 L .47062 .60009 L 0 0 .413 r
F
.46075 .57135 m .47035 .59952 L .46993 .5981 L F
.47314 .60555 m .46122 .56965 L .44835 .56118 L .511 .482 .761 r
F
.45987 .56825 m .46005 .56888 L .46497 .57212 L 0 .344 .809 r
F
.44245 .55886 m .44602 .55964 L .41522 .53517 L 0 .218 .637 r
F
.44743 .56318 m .44602 .55964 L .44245 .55886 L F
.50424 .66826 m .48477 .58213 L .49163 .61469 L .627 .537 .734 r
F
.48477 .58213 m .4848 .58292 L .49163 .61469 L F
.50424 .66826 m .49163 .61469 L .50088 .65412 L F
.50506 .67172 m .50648 .69587 L .50985 .69185 L .47 .41 .709 r
F
.50443 .67748 m .50648 .69587 L .50389 .65172 L F
.50181 .68097 m .50452 .6922 L .50381 .68483 L .175 .215 .665 r
F
.50381 .68483 m .50452 .6922 L .5058 .68976 L .47 .41 .709 r
F
.50452 .6922 m .50572 .69755 L .50648 .69587 L .543 .335 .549 r
F
.49706 .67482 m .48476 .71505 L .50452 .6922 L .275 .088 .437 r
F
.48476 .71505 m .48319 .72175 L .50452 .6922 L F
.48236 .72289 m .49539 .7125 L .50452 .6922 L F
.49349 .72455 m .50199 .70579 L .47276 .76405 L .789 .613 .662 r
F
.4989 .70682 m .46567 .7869 L .46939 .78364 L .543 .335 .549 r
F
.50452 .6922 m .49777 .70866 L .4989 .70682 L F
.49777 .70866 m .46567 .7869 L .4989 .70682 L F
.50452 .6922 m .49993 .70516 L .50572 .69755 L F
.49993 .70516 m .49157 .72879 L .50199 .70579 L F
.49993 .70516 m .50199 .70579 L .50572 .69755 L F
.46945 .78359 m .46645 .79131 L .46988 .78321 L F
.4989 .70682 m .46939 .78364 L .49993 .70516 L F
.46939 .78364 m .46645 .79131 L .46945 .78359 L F
.46939 .78364 m .46945 .78359 L .49993 .70516 L F
.49104 .75921 m .50779 .73478 L .47073 .78247 L .875 .71 .674 r
F
.4734 .78013 m .46645 .79131 L .46745 .79695 L .543 .335 .549 r
F
.49104 .75921 m .47073 .78247 L .47302 .78046 L .875 .71 .674 r
F
.47073 .78247 m .50779 .73478 L .46988 .78321 L F
.48562 .74808 m .48629 .75591 L .48422 .74868 L .839 .839 .846 r
F
.49465 .74579 m .4966 .74479 L .4962 .74521 L .803 .728 .781 r
F
.48783 .74992 m .4962 .74521 L .48629 .75591 L F
.47089 .78082 m .50779 .73478 L .50421 .70224 L .789 .613 .662 r
F
.49993 .70516 m .46945 .78359 L .48458 .74853 L .543 .335 .549 r
F
.46945 .78359 m .46988 .78321 L .48458 .74853 L F
.45543 .78749 m .46461 .78656 L .4663 .78189 L .789 .547 .571 r
F
.4622 .784 m .45974 .78713 L .46592 .78832 L .61 .236 .308 r
F
.45974 .78713 m .46437 .79001 L .46592 .78832 L F
.4645 .79009 m .50779 .73478 L .46381 .78966 L .789 .613 .662 r
F
.48458 .74853 m .46988 .78321 L .4734 .78013 L .543 .335 .549 r
F
.46988 .78321 m .46645 .79131 L .4734 .78013 L F
.47302 .78046 m .47073 .78247 L .46422 .79085 L .875 .71 .674 r
F
.46422 .79085 m .47073 .78247 L .4645 .79009 L F
.47073 .78247 m .46988 .78321 L .4645 .79009 L F
.50452 .6922 m .4989 .70682 L .49993 .70516 L .543 .335 .549 r
F
.50199 .70579 m .50768 .69443 L .50624 .69496 L .701 .531 .655 r
F
.50009 .7049 m .50624 .69496 L .49081 .70059 L F
.50199 .70579 m .50624 .69496 L .50009 .7049 L F
.48818 .70155 m .50682 .6923 L .50381 .68483 L F
.49602 .66977 m .50381 .68483 L .49668 .66711 L F
.48818 .70155 m .50381 .68483 L .49602 .66977 L F
.48828 .61349 m .50181 .68097 L .49918 .64688 L .175 .215 .665 r
F
.48532 .61242 m .50181 .68097 L .48828 .61349 L F
.46942 .59888 m .45065 .5653 L .46708 .59729 L .315 .407 .797 r
F
.40321 .53607 m .44743 .56318 L .41522 .53517 L 0 .218 .637 r
F
.46206 .59853 m .45808 .59118 L .4525 .58739 L .315 .407 .797 r
F
.45808 .59118 m .46206 .59853 L .4617 .59858 L .888 .491 .049 r
F
.46206 .59853 m .47413 .6208 L .4617 .59858 L F
.28143 .52561 m .34653 .52172 L .36056 .5191 L .217 .737 .848 r
F
.33752 .52623 m .34323 .52233 L .33141 .52491 L .379 .639 .957 r
F
.34323 .52233 m .33255 .52433 L .33141 .52491 L F
.27217 .53591 m .3343 .52743 L .3432 .52353 L .338 .815 .885 r
F
.33967 .52544 m .33877 .52538 L .33752 .52623 L .379 .639 .957 r
F
.3343 .52743 m .33967 .52544 L .3432 .52353 L .338 .815 .885 r
F
.31894 .50286 m .41734 .51563 L .33363 .49787 L .12 .646 .876 r
F
.41734 .51563 m .41961 .5151 L .33363 .49787 L F
.3489 .49409 m .43876 .51567 L .44014 .51356 L .182 .659 .931 r
F
.43744 .51627 m .439 .51654 L .43893 .51627 L .15 .652 .908 r
F
.4391 .51646 m .43893 .51627 L .439 .51654 L .571 .605 .848 r
F
.33363 .49787 m .43744 .51627 L .3489 .49409 L .15 .652 .908 r
F
.43744 .51627 m .44131 .51629 L .3489 .49409 L F
.46579 .51903 m .46064 .51895 L .47302 .52057 L .182 .659 .931 r
F
.46064 .51895 m .47137 .52043 L .47302 .52057 L F
.39581 .51304 m .38508 .51212 L .3723 .5129 L .483 .612 .904 r
F
.30513 .50911 m .39312 .51533 L .31894 .50286 L .111 .652 .846 r
F
.39312 .51533 m .39595 .51433 L .31894 .50286 L F
.31894 .50286 m .39595 .51433 L .41734 .51563 L .12 .646 .876 r
F
.39301 .51532 m .393 .51533 L .39312 .51533 L .111 .652 .846 r
F
.35227 .51845 m .34849 .51873 L .34687 .51984 L .379 .639 .957 r
F
.29252 .51668 m .36101 .5178 L .37635 .51667 L .14 .68 .834 r
F
.28143 .52561 m .36056 .5191 L .29252 .51668 L .217 .737 .848 r
F
.36056 .5191 m .36101 .5178 L .29252 .51668 L F
.27217 .53591 m .34629 .52299 L .28143 .52561 L .338 .815 .885 r
F
.34629 .52299 m .34653 .52172 L .28143 .52561 L F
.3432 .52353 m .34318 .52414 L .34629 .52299 L F
.33734 .5278 m .33627 .52728 L .33457 .53218 L .264 .671 .967 r
F
.33627 .52728 m .33317 .52896 L .33457 .53218 L F
.26503 .54756 m .33734 .5278 L .27217 .53591 L .485 .894 .927 r
F
.33734 .5278 m .33658 .52712 L .27217 .53591 L F
.26503 .54756 m .33221 .53369 L .33469 .53199 L F
.26503 .54756 m .33469 .53199 L .33734 .5278 L F
.46283 .59459 m .46284 .59531 L .46278 .59437 L .787 .521 0 r
F
.46945 .60714 m .46708 .59729 L .45808 .59118 L .315 .407 .797 r
F
.46945 .60714 m .45808 .59118 L .46206 .59853 L F
.46745 .598 m .46708 .59729 L .46945 .60714 L F
.48014 .67982 m .48193 .66018 L .47997 .6612 L .437 .333 .639 r
F
.49038 .65579 m .49148 .65892 L .49089 .65553 L 0 0 .413 r
F
.48408 .63783 m .48423 .63977 L .49038 .65579 L F
.49272 .66017 m .49653 .66712 L .4944 .66188 L .598 .448 .65 r
F
.48831 .65056 m .49025 .65568 L .49038 .65579 L 0 0 .413 r
F
.49019 .65553 m .49006 .65518 L .48134 .68954 L .598 .448 .65 r
F
.49038 .65579 m .49025 .65568 L .49148 .65892 L 0 0 .413 r
F
.48384 .64461 m .48345 .64364 L .48014 .67982 L .437 .333 .639 r
F
.47824 .63239 m .48197 .64002 L .47921 .62616 L .888 .491 .049 r
F
.48197 .64002 m .48399 .64035 L .47921 .62616 L F
.48532 .61242 m .49247 .65248 L .50181 .68097 L .175 .215 .665 r
F
.48611 .62152 m .49247 .65248 L .48532 .61242 L F
.48542 .61355 m .48532 .61242 L .48496 .61229 L .511 .482 .761 r
F
.50181 .68097 m .50381 .68483 L .50088 .65412 L .175 .215 .665 r
F
.50181 .68097 m .50088 .65412 L .49918 .64688 L F
.50389 .65172 m .50506 .67172 L .5099 .69179 L .47 .41 .709 r
F
.50506 .67172 m .50985 .69185 L .5099 .69179 L F
.5039 .65234 m .50389 .65172 L .50227 .65956 L .627 .537 .734 r
F
.51237 .61215 m .51203 .68045 L .51455 .66215 L .609 .514 .722 r
F
.5119 .61289 m .51203 .68045 L .51237 .61215 L F
.49021 .70217 m .49081 .70059 L .48818 .70155 L .701 .531 .655 r
F
.50199 .70579 m .49081 .70059 L .49021 .70217 L F
.48476 .71505 m .49693 .66608 L .49068 .68979 L F
.48305 .72234 m .48395 .71871 L .48476 .71505 L F
.48395 .71871 m .49693 .66608 L .48476 .71505 L F
.48844 .69847 m .49653 .66712 L .48761 .70008 L .598 .448 .65 r
F
.48759 .70012 m .47923 .72247 L .48765 .70205 L .275 .088 .437 r
F
.48759 .70012 m .48765 .70205 L .48844 .69847 L F
.48476 .71505 m .49068 .68979 L .48844 .69847 L .701 .531 .655 r
F
.47923 .72247 m .47072 .7452 L .47909 .72406 L .275 .088 .437 r
F
.44524 .76073 m .46434 .73478 L .44625 .75902 L .647 .417 .556 r
F
.46434 .73478 m .45967 .74092 L .44625 .75902 L F
.47909 .72406 m .47072 .7452 L .478 .73717 L .275 .088 .437 r
F
.47994 .71167 m .48147 .7124 L .48669 .6998 L 0 0 .088 r
F
.4734 .72316 m .47974 .71471 L .47994 .71167 L F
.47974 .71471 m .48147 .7124 L .47994 .71167 L F
.4734 .72316 m .48669 .6998 L .4851 .69925 L F
.47938 .69725 m .47808 .70234 L .47801 .70318 L F
.47158 .70796 m .4781 .69015 L .47803 .6891 L .981 .833 .437 r
F
.50443 .67748 m .50463 .68686 L .5058 .68976 L .47 .41 .709 r
F
.50424 .66826 m .5039 .65234 L .50227 .65956 L .627 .537 .734 r
F
.5133 .60982 m .51575 .65346 L .51786 .63848 L .609 .514 .722 r
F
.51267 .61167 m .51575 .65346 L .5133 .60982 L F
.50389 .65172 m .51015 .69343 L .51162 .61422 L .47 .41 .709 r
F
.5099 .69179 m .50882 .70025 L .51015 .69343 L F
.50518 .71109 m .5089 .70432 L .5091 .69879 L .789 .613 .662 r
F
.50518 .71109 m .5091 .69879 L .50839 .69579 L F
.5099 .69179 m .50798 .69408 L .50911 .69798 L .47 .41 .709 r
F
.50798 .69408 m .50862 .69678 L .50911 .69798 L F
.50911 .69798 m .50886 .69778 L .50904 .69852 L F
.50421 .70224 m .50518 .71109 L .50839 .69579 L .789 .613 .662 r
F
.50421 .70224 m .50839 .69579 L .50798 .69408 L F
.50768 .69443 m .50682 .6923 L .48818 .70155 L .701 .531 .655 r
F
.50902 .70102 m .50987 .69485 L .5091 .69879 L .719 .599 .722 r
F
.51208 .70636 m .51087 .73425 L .51674 .71229 L .692 .491 .61 r
F
.51384 .72311 m .53011 .69179 L .50918 .72214 L .719 .599 .722 r
F
.53011 .69179 m .52912 .68929 L .50918 .72214 L F
.52606 .69966 m .52593 .69984 L .52533 .70099 L .812 .687 .726 r
F
.52544 .70085 m .52533 .70099 L .51386 .72309 L F
.52606 .69966 m .52533 .70099 L .52544 .70085 L F
.51378 .72337 m .52545 .70083 L .51386 .72309 L F
.52545 .70083 m .52606 .69966 L .52544 .70085 L F
.52545 .70083 m .52544 .70085 L .51386 .72309 L F
.50925 .72155 m .52044 .62023 L .5089 .70432 L .719 .599 .722 r
F
.52044 .62023 m .51744 .64149 L .5089 .70432 L F
.51638 .65698 m .52275 .65842 L .52044 .62023 L F
.50918 .72214 m .52912 .68929 L .51638 .65698 L F
.5238 .67581 m .53011 .69179 L .53018 .69166 L .683 .581 .735 r
F
.52606 .69966 m .53024 .69158 L .52593 .69984 L .812 .687 .726 r
F
.53024 .69158 m .53014 .69171 L .52593 .69984 L F
.53468 .68663 m .5356 .69197 L .53562 .68448 L F
.5175 .74941 m .53307 .73514 L .53963 .727 L .896 .772 .717 r
F
.5175 .74941 m .51763 .7487 L .50033 .76515 L .812 .687 .726 r
F
.48913 .78728 m .49575 .78335 L .53049 .72409 L .808 .634 .665 r
F
.50437 .7559 m .54107 .72585 L .53468 .68663 L .812 .687 .726 r
F
.44998 .86024 m .46494 .84253 L .47238 .82223 L .793 .955 .624 r
F
.46985 .83858 m .47324 .83682 L .48307 .82417 L F
.44998 .86024 m .46509 .84503 L .46936 .83924 L F
.44998 .86024 m .46936 .83924 L .46884 .83968 L F
.46509 .84503 m .47324 .83682 L .46985 .83858 L F
.4806 .8213 m .47024 .83805 L .48328 .8239 L 0 0 0 r
F
.4837 .82108 m .48328 .8239 L .48603 .82092 L F
.4806 .8213 m .48328 .8239 L .4837 .82108 L F
.47324 .83682 m .48286 .82678 L .48328 .8239 L .88 .959 .848 r
F
.48603 .82092 m .4831 .82511 L .48868 .82073 L 0 0 0 r
F
.48868 .82073 m .47906 .83219 L .50222 .81881 L .171 0 .048 r
F
.50242 .82583 m .49808 .82911 L .50246 .8258 L .059 0 0 r
F
.49808 .82911 m .45352 .86272 L .4981 .82909 L F
.49808 .82911 m .4981 .82909 L .50246 .8258 L F
.51117 .81924 m .45358 .86362 L .52273 .81979 L 0 0 0 r
F
.45358 .86362 m .44376 .87119 L .45475 .86404 L F
.45358 .86362 m .45475 .86404 L .52273 .81979 L F
.4831 .84058 m .45386 .86333 L .51117 .81924 L F
.45386 .86333 m .44376 .87119 L .45405 .86326 L F
.45386 .86333 m .45405 .86326 L .51117 .81924 L F
.45333 .86354 m .45286 .86371 L .45352 .86272 L .602 .166 .184 r
F
.45333 .86354 m .45352 .86272 L .45304 .86343 L F
.45304 .86343 m .45352 .86272 L .50242 .82583 L .059 0 0 r
F
.45304 .86343 m .50242 .82583 L .50221 .82603 L F
.50493 .82398 m .50804 .82159 L .5077 .82188 L F
.45304 .86343 m .50503 .82388 L .50493 .82398 L F
.50503 .82388 m .50804 .82159 L .50493 .82398 L F
.44975 .86116 m .46482 .84555 L .44998 .86024 L 0 0 0 r
F
.46482 .84555 m .47324 .83682 L .46509 .84503 L F
.46482 .84555 m .46509 .84503 L .44998 .86024 L F
.48727 .8322 m .44376 .87119 L .50737 .82169 L F
.50674 .82134 m .50737 .82169 L .51056 .81921 L F
.48727 .8322 m .50737 .82169 L .50674 .82134 L F
.48223 .91889 m .382 .91584 L .35889 .96686 L .789 .867 .907 r
F
.46719 .88476 m .382 .91584 L .48223 .91889 L .614 .953 .914 r
F
.4576 .88826 m .41469 .89284 L .382 .91584 L F
.45446 .88661 m .40234 .89416 L .4576 .88826 L F
.44376 .87119 m .43739 .87762 L .45371 .87034 L .603 .144 .136 r
F
.45371 .87034 m .42511 .8836 L .46719 .88476 L .105 0 0 r
F
.42511 .8836 m .40234 .89416 L .41451 .89239 L F
.42511 .8836 m .41451 .89239 L .46719 .88476 L F
.41469 .89284 m .40234 .89416 L .38605 .91152 L .614 .953 .914 r
F
.41469 .89284 m .38605 .91152 L .382 .91584 L F
.43985 .88027 m .41762 .89771 L .43967 .87685 L .105 0 0 r
F
.44906 .87387 m .43395 .88532 L .45077 .87171 L F
.43395 .88532 m .41762 .89771 L .43361 .88516 L F
.43395 .88532 m .43361 .88516 L .45077 .87171 L F
.45077 .87171 m .43985 .88027 L .43967 .87685 L F
.43967 .87685 m .41762 .89771 L .40234 .89416 L F
.45371 .87034 m .44906 .87387 L .45077 .87171 L F
.43868 .87704 m .44136 .87971 L .45371 .87034 L .603 .144 .136 r
F
.43739 .87762 m .43793 .87791 L .43868 .87704 L F
.43793 .87791 m .44136 .87971 L .43868 .87704 L F
.41762 .89771 m .4169 .89805 L .40234 .89416 L .105 0 0 r
F
.43739 .87762 m .4171 .8981 L .44136 .87971 L .603 .144 .136 r
F
.44376 .87119 m .43396 .90412 L .4189 .89628 L F
.4379 .888 m .43648 .88868 L .43848 .88563 L .602 .166 .184 r
F
.43693 .89196 m .43648 .88868 L .4379 .888 L F
.48223 .91889 m .35889 .96686 L .4992 .97237 L .789 .867 .907 r
F
.47633 .96509 m .45315 .95204 L .42827 .90119 L .67 .241 .222 r
F
.4441 .92249 m .43352 .90816 L .43438 .9095 L F
.44034 .91768 m .43438 .9095 L .43647 .91273 L F
.4441 .92249 m .43438 .9095 L .44034 .91768 L F
.44409 .92222 m .43352 .90816 L .4441 .92249 L F
.44088 .89321 m .44586 .93854 L .43414 .92307 L .727 .29 .212 r
F
.44411 .92287 m .44435 .92503 L .4441 .92249 L .571 .188 .277 r
F
.44435 .92503 m .44459 .92692 L .4441 .92249 L F
.44435 .92503 m .44586 .93854 L .44459 .92692 L F
.44435 .92503 m .4609 .94594 L .44586 .93854 L F
.44411 .92287 m .44774 .92785 L .44435 .92503 L F
.44774 .92785 m .4609 .94594 L .44435 .92503 L F
.44412 .92314 m .44454 .92336 L .44061 .91856 L .67 .241 .222 r
F
.47633 .96509 m .44454 .92336 L .44412 .92314 L F
.47633 .96509 m .44932 .92918 L .44454 .92336 L F
.44932 .92918 m .44409 .92222 L .4441 .92249 L F
.44932 .92918 m .43647 .91273 L .44061 .91856 L F
.48695 .9605 m .47633 .96509 L .46393 .94893 L .417 .229 .516 r
F
.461 .93889 m .46393 .94893 L .44774 .92785 L F
.48695 .9605 m .46393 .94893 L .461 .93889 L F
.43352 .90816 m .43304 .9079 L .43647 .91273 L .67 .241 .222 r
F
.43352 .90816 m .42827 .90119 L .43304 .9079 L F
.43647 .91272 m .42827 .90119 L .42829 .90116 L .602 .166 .184 r
F
.43647 .91273 m .42827 .90119 L .43647 .91272 L F
.4379 .888 m .43396 .90412 L .43928 .88626 L .727 .29 .212 r
F
.43897 .90672 m .42829 .90116 L .43648 .88868 L .602 .166 .184 r
F
.43699 .88916 m .43396 .90412 L .4379 .888 L .727 .29 .212 r
F
.44061 .91856 m .43693 .89196 L .43941 .88812 L .602 .166 .184 r
F
.44024 .89001 m .43941 .88812 L .4402 .8869 L F
.44061 .91856 m .43941 .88812 L .44024 .89001 L F
.43693 .89196 m .4379 .888 L .4391 .88742 L F
.43941 .88812 m .4391 .88742 L .4402 .8869 L F
.43693 .89196 m .4391 .88742 L .43941 .88812 L F
.45777 .93019 m .45773 .93075 L .45369 .9207 L .239 .058 .423 r
F
.45133 .91876 m .46455 .94773 L .4609 .94594 L .571 .188 .277 r
F
.44223 .91129 m .4402 .8869 L .44263 .90952 L .602 .166 .184 r
F
.44049 .90986 m .4402 .8869 L .44223 .91129 L F
.43937 .87951 m .43699 .88916 L .43879 .88438 L .727 .29 .212 r
F
.4405 .87737 m .43879 .88438 L .44376 .87119 L F
.43937 .87951 m .43879 .88438 L .4405 .87737 L F
.43699 .88916 m .43928 .88626 L .44376 .87119 L F
.47073 .85788 m .4456 .8701 L .45371 .87034 L .704 .98 .791 r
F
.4576 .86294 m .4456 .8701 L .47073 .85788 L F
.4456 .8701 m .44463 .87112 L .45371 .87034 L F
.45868 .86148 m .45475 .86404 L .49104 .843 L F
.45475 .86404 m .44584 .86983 L .4576 .86294 L F
.44584 .86983 m .4456 .8701 L .4576 .86294 L F
.45475 .86404 m .4576 .86294 L .49104 .843 L F
.44858 .88289 m .44274 .88568 L .45134 .86802 L .602 .166 .184 r
F
.44274 .88568 m .4379 .888 L .45134 .86802 L F
.45134 .86802 m .4379 .888 L .45183 .86539 L F
.44858 .88289 m .45183 .86539 L .45258 .86496 L F
.44265 .90973 m .44329 .91538 L .44088 .89321 L .571 .188 .277 r
F
.444 .92184 m .44401 .92191 L .44088 .89321 L F
.44401 .92191 m .4441 .92249 L .44088 .89321 L F
.44411 .92287 m .4441 .92255 L .44401 .92191 L F
.4441 .92255 m .4441 .92249 L .44401 .92191 L F
.44287 .91182 m .444 .92184 L .44329 .91538 L F
.45369 .9207 m .46455 .94773 L .45133 .91876 L F
.44299 .90791 m .44159 .89986 L .44751 .88766 L .602 .166 .184 r
F
.44263 .90952 m .44235 .90691 L .44299 .90791 L F
.44235 .90691 m .44159 .89986 L .44299 .90791 L F
.44156 .89958 m .4402 .8869 L .44225 .88592 L F
.44228 .91133 m .45286 .86371 L .45333 .86354 L F
.44061 .91856 m .44223 .91129 L .44228 .91133 L F
.44223 .91129 m .45286 .86371 L .44228 .91133 L F
.44287 .91182 m .44329 .91538 L .44265 .90973 L .571 .188 .277 r
F
.444 .92184 m .44411 .92287 L .44401 .92191 L F
.44287 .91182 m .4609 .94594 L .44411 .92287 L F
.44172 .89631 m .4434 .89614 L .44195 .89175 L .602 .166 .184 r
F
.4379 .888 m .43848 .88563 L .45286 .86371 L F
.43937 .87951 m .4406 .89065 L .43835 .88484 L .727 .29 .212 r
F
.44061 .91856 m .42829 .90116 L .43897 .90672 L .602 .166 .184 r
F
.43835 .88484 m .44088 .89321 L .43371 .9092 L .727 .29 .212 r
F
.4406 .89065 m .44088 .89321 L .43835 .88484 L F
.44088 .89321 m .43414 .92307 L .42996 .91756 L F
.44061 .91856 m .44049 .90986 L .44223 .91129 L .602 .166 .184 r
F
.44061 .91856 m .44265 .90973 L .44154 .89996 L F
.44026 .88796 m .44287 .91182 L .44021 .8872 L .571 .188 .277 r
F
.4403 .88882 m .44138 .8985 L .44026 .88796 L F
.44138 .8985 m .44287 .91182 L .44026 .88796 L F
.44184 .89935 m .4434 .89614 L .44172 .89631 L .602 .166 .184 r
F
.44287 .91182 m .44088 .89321 L .44021 .8872 L .571 .188 .277 r
F
.44138 .8985 m .44172 .89631 L .44201 .90412 L F
.44265 .90973 m .4448 .90042 L .44184 .89935 L .602 .166 .184 r
F
.4448 .90042 m .44797 .88672 L .4434 .89614 L F
.4448 .90042 m .4434 .89614 L .44184 .89935 L F
.44195 .89175 m .44797 .88672 L .44226 .88559 L F
.4434 .89614 m .44797 .88672 L .44195 .89175 L F
.44773 .88667 m .44274 .88568 L .44858 .88289 L F
.44797 .88672 m .45062 .87525 L .44226 .88559 L F
.45062 .87525 m .45306 .86469 L .44803 .87443 L F
.45062 .87525 m .44803 .87443 L .44226 .88559 L F
.45306 .86469 m .45333 .86354 L .45268 .86484 L F
.45306 .86469 m .45268 .86484 L .44788 .87439 L F
.44803 .87443 m .44788 .87439 L .44226 .88559 L F
.45306 .86469 m .44788 .87439 L .44803 .87443 L F
.44226 .88559 m .45268 .86484 L .44557 .87483 L F
.44729 .87186 m .43937 .87951 L .44727 .87175 L 0 0 0 r
F
.43947 .87939 m .43967 .87923 L .44547 .87363 L .171 0 .048 r
F
.43947 .87939 m .44547 .87363 L .44545 .87362 L F
.44584 .86983 m .44376 .87119 L .4456 .8701 L .704 .98 .791 r
F
.4456 .8701 m .44376 .87119 L .44463 .87112 L F
.44681 .86846 m .43937 .87951 L .44376 .87119 L 0 0 0 r
F
.45268 .86484 m .45333 .86354 L .45234 .86497 L .602 .166 .184 r
F
.44727 .87175 m .43937 .87951 L .44681 .86846 L 0 0 0 r
F
.44487 .87344 m .43947 .87939 L .44545 .87362 L .171 0 .048 r
F
.44244 .88203 m .44557 .87483 L .44318 .87821 L .602 .166 .184 r
F
.44226 .88559 m .44557 .87483 L .44244 .88203 L F
.44284 .88911 m .44233 .89243 L .44247 .88519 L .234 0 .201 r
F
.44266 .88482 m .44247 .88519 L .44254 .8819 L F
.44284 .88911 m .44247 .88519 L .44266 .88482 L F
.4427 .88474 m .44254 .8819 L .4426 .8818 L F
.44284 .88911 m .44266 .88482 L .4427 .88474 L F
.44266 .88482 m .44254 .8819 L .4427 .88474 L F
.4426 .8818 m .44254 .8819 L .44256 .88054 L F
.44244 .88203 m .44318 .87821 L .44252 .88055 L .602 .166 .184 r
F
.44266 .88171 m .44256 .88054 L .44263 .88052 L .234 0 .201 r
F
.44273 .88468 m .4426 .8818 L .44266 .88171 L F
.4427 .88474 m .4426 .8818 L .44273 .88468 L F
.4426 .8818 m .44256 .88054 L .44266 .88171 L F
.45268 .86484 m .45234 .86497 L .44618 .87385 L .602 .166 .184 r
F
.45268 .86484 m .44618 .87385 L .44625 .87387 L F
.45268 .86484 m .44319 .87817 L .44318 .87821 L F
.45258 .86496 m .45183 .86539 L .45286 .86371 L F
.44455 .87334 m .43947 .87939 L .44487 .87344 L .171 0 .048 r
F
.43947 .87939 m .43937 .87951 L .43967 .87923 L F
.45333 .86354 m .45304 .86343 L .44933 .86931 L .602 .166 .184 r
F
.44008 .88684 m .4403 .88882 L .43937 .87951 L .571 .188 .277 r
F
.4403 .88882 m .44021 .8872 L .43937 .87951 L F
.44116 .88537 m .44008 .88684 L .44213 .88065 L .171 0 .048 r
F
.44286 .87933 m .44232 .88007 L .44279 .87864 L F
.44289 .87922 m .44279 .87864 L .44455 .87334 L F
.44286 .87933 m .44279 .87864 L .44289 .87922 L F
.44252 .88055 m .44232 .88007 L .44286 .87933 L F
.44233 .89243 m .44195 .89175 L .44252 .88055 L .234 0 .201 r
F
.44252 .88055 m .44318 .87821 L .44259 .87903 L .602 .166 .184 r
F
.44256 .88054 m .44252 .88055 L .44259 .87903 L .234 0 .201 r
F
.44233 .89243 m .44252 .88055 L .44256 .88054 L F
.44294 .87821 m .44213 .88065 L .43947 .87939 L .171 0 .048 r
F
.4478 .9024 m .45927 .93343 L .44255 .89283 L .239 .058 .423 r
F
.44326 .90609 m .45133 .91876 L .44342 .91226 L .571 .188 .277 r
F
.44326 .90609 m .44342 .91226 L .44287 .91182 L F
.44265 .90973 m .44184 .89935 L .44201 .90412 L .602 .166 .184 r
F
.44201 .90412 m .44326 .90609 L .44287 .91182 L .571 .188 .277 r
F
.44233 .89243 m .44172 .89631 L .44195 .89175 L .234 0 .201 r
F
.44172 .89631 m .45133 .91876 L .44201 .90412 L .571 .188 .277 r
F
.44153 .89094 m .44224 .89298 L .44172 .89631 L F
.44224 .89298 m .45133 .91876 L .44172 .89631 L F
.45133 .91876 m .4609 .94594 L .44287 .91182 L F
.45778 .92999 m .45369 .9207 L .44233 .89243 L .239 .058 .423 r
F
.45778 .92999 m .44233 .89243 L .4424 .89257 L F
.44021 .88717 m .45369 .9207 L .44022 .88723 L .571 .188 .277 r
F
.44022 .88723 m .45369 .9207 L .45133 .91876 L F
.44359 .91908 m .44172 .89631 L .44233 .89243 L .234 0 .201 r
F
.44295 .89357 m .44233 .89243 L .44284 .88911 L F
.45778 .92999 m .4424 .89257 L .44251 .89277 L .239 .058 .423 r
F
.45927 .93343 m .45812 .93081 L .44324 .89455 L F
.44324 .89452 m .44324 .89455 L .44008 .88684 L F
.45927 .93343 m .44324 .89455 L .44324 .89452 L F
.4424 .89257 m .4415 .89038 L .44251 .89277 L F
.4424 .89257 m .44233 .89243 L .4415 .89038 L F
.49104 .843 m .4576 .86294 L .47073 .85788 L .704 .98 .791 r
F
.5133 .8267 m .45868 .86148 L .49104 .843 L F
.52273 .81979 m .50675 .83019 L .5133 .8267 L F
.50675 .83019 m .45868 .86148 L .5133 .8267 L F
.44535 .87664 m .45304 .86343 L .47687 .84531 L .059 0 0 r
F
.51158 .81876 m .51089 .81888 L .51117 .81924 L .857 .826 .816 r
F
.51089 .81888 m .50942 .81916 L .51056 .81921 L F
.51089 .81888 m .51056 .81921 L .51117 .81924 L F
.55431 .76812 m .50222 .81881 L .50942 .81916 L F
.52982 .77766 m .50222 .81881 L .54555 .77404 L .897 .854 .792 r
F
.511 .79739 m .56506 .76086 L .53053 .777 L .88 .959 .848 r
F
.56506 .76086 m .56934 .75796 L .56299 .76108 L F
.56506 .76086 m .56299 .76108 L .53053 .777 L F
.56779 .76057 m .5593 .77026 L .57364 .75585 L F
.56582 .76078 m .55688 .77301 L .56779 .76057 L .857 .826 .816 r
F
.51108 .81869 m .51273 .818 L .54067 .78949 L .88 .959 .848 r
F
.51203 .81867 m .51117 .81924 L .51281 .81799 L .059 0 0 r
F
.51203 .81867 m .51287 .81794 L .51089 .81888 L F
.53073 .77631 m .56299 .76108 L .58045 .73787 L .814 .762 .804 r
F
.53053 .777 m .56299 .76108 L .53073 .77631 L F
.56299 .76108 m .57754 .74348 L .58045 .73787 L F
.57754 .74348 m .57991 .73928 L .58045 .73787 L F
.51089 .81888 m .51287 .81794 L .51108 .81869 L .88 .959 .848 r
F
.5077 .82188 m .50804 .82159 L .51281 .81799 L .059 0 0 r
F
.51281 .81799 m .50242 .82583 L .51287 .81794 L F
.50242 .82583 m .50246 .8258 L .51287 .81794 L F
.51273 .818 m .51287 .81794 L .5129 .8179 L .88 .959 .848 r
F
.51273 .818 m .5129 .8179 L .54191 .78827 L F
.51273 .818 m .54191 .78827 L .54067 .78949 L F
.55379 .77654 m .51117 .81924 L .53393 .8042 L .857 .826 .816 r
F
.57754 .74348 m .57364 .75585 L .57899 .74173 L .814 .762 .804 r
F
.56299 .76108 m .56934 .75796 L .57754 .74348 L F
.56934 .75796 m .57364 .75585 L .57754 .74348 L F
.57754 .74348 m .5147 .81513 L .55379 .77654 L .857 .826 .816 r
F
.58444 .73387 m .58014 .73888 L .57754 .74348 L F
.58014 .73888 m .5147 .81513 L .57754 .74348 L F
.5147 .81513 m .51117 .81924 L .55379 .77654 L F
.55742 .7724 m .55725 .7726 L .57364 .75585 L .88 .959 .848 r
F
.5593 .77026 m .55742 .7724 L .57364 .75585 L F
.5658 .76078 m .57364 .75585 L .56934 .75796 L F
.58021 .73876 m .50942 .81916 L .51089 .81888 L .857 .826 .816 r
F
.58033 .73853 m .50942 .81916 L .58021 .73876 L F
.58444 .73387 m .51089 .81888 L .5147 .81513 L F
.54555 .77404 m .50222 .81881 L .55431 .76812 L F
.53393 .8042 m .51117 .81924 L .52273 .81979 L F
.46386 .86054 m .47687 .84531 L .51117 .81924 L .059 0 0 r
F
.46386 .86054 m .51117 .81924 L .51203 .81867 L F
.44535 .87664 m .47687 .84531 L .46386 .86054 L F
.44392 .87788 m .44568 .87509 L .44535 .87664 L F
.44568 .87509 m .45304 .86343 L .44535 .87664 L F
.44933 .86931 m .45304 .86343 L .44259 .87903 L .602 .166 .184 r
F
.44625 .87387 m .44618 .87385 L .44319 .87817 L F
.4432 .87812 m .45304 .86343 L .44392 .87788 L .059 0 0 r
F
.47717 .84125 m .44727 .87175 L .44681 .86846 L 0 0 0 r
F
.47233 .84713 m .44727 .87175 L .47717 .84125 L F
.50221 .82603 m .50242 .82583 L .50804 .82159 L .059 0 0 r
F
.51056 .81921 m .4831 .84058 L .51117 .81924 L 0 0 0 r
F
.50222 .81881 m .48727 .8322 L .51056 .81921 L F
.44392 .87788 m .51203 .81867 L .50006 .82427 L .059 0 0 r
F
.48765 .83299 m .50006 .82427 L .49287 .82763 L F
.44392 .87788 m .50006 .82427 L .48765 .83299 L F
.49008 .82969 m .47233 .84713 L .47717 .84125 L 0 0 0 r
F
.44392 .87788 m .49287 .82763 L .44715 .87345 L .059 0 0 r
F
.51203 .81867 m .51089 .81888 L .49318 .82732 L F
.4944 .8261 m .49348 .82702 L .49008 .82969 L 0 0 0 r
F
.51203 .81867 m .49318 .82732 L .49287 .82763 L .059 0 0 r
F
.49631 .82451 m .49472 .82605 L .49348 .82702 L 0 0 0 r
F
.49631 .82451 m .49348 .82702 L .4944 .8261 L F
.49472 .82605 m .48884 .8309 L .49008 .82969 L F
.47324 .83682 m .4742 .83637 L .47892 .83225 L .88 .959 .848 r
F
.50222 .81881 m .49631 .82451 L .49008 .82969 L 0 0 0 r
F
.4742 .83637 m .49607 .82594 L .47906 .83219 L .88 .959 .848 r
F
.4742 .83637 m .47906 .83219 L .47892 .83225 L F
.48868 .82073 m .48251 .82911 L .48025 .83117 L .171 0 .048 r
F
.48868 .82073 m .48025 .83117 L .47906 .83219 L F
.49607 .82594 m .50106 .82357 L .49305 .82671 L .88 .959 .848 r
F
.49607 .82594 m .49305 .82671 L .47906 .83219 L F
.47906 .83219 m .47906 .83219 L .47892 .83225 L F
.49607 .82594 m .47906 .83219 L .47906 .83219 L F
.47699 .83506 m .47702 .83502 L .4742 .83637 L .059 0 0 r
F
.49318 .82732 m .4701 .84983 L .48884 .8309 L 0 0 0 r
F
.49472 .82605 m .48723 .83329 L .49318 .82732 L F
.48723 .83329 m .4701 .84983 L .49318 .82732 L F
.49287 .82763 m .47702 .83502 L .47699 .83506 L .059 0 0 r
F
.49287 .82763 m .49318 .82732 L .47702 .83502 L F
.44729 .87186 m .44727 .87175 L .49008 .82969 L 0 0 0 r
F
.4651 .84883 m .49287 .82763 L .4742 .83637 L .059 0 0 r
F
.4701 .84983 m .44729 .87186 L .47209 .84742 L 0 0 0 r
F
.4701 .84983 m .47209 .84742 L .48884 .8309 L F
.47595 .84121 m .4745 .84558 L .48723 .83329 L .171 0 .048 r
F
.48723 .83329 m .49287 .82763 L .4651 .84883 L .059 0 0 r
F
.47232 .84022 m .4651 .84883 L .47702 .83799 L .171 0 .048 r
F
.4651 .84883 m .45349 .86268 L .4706 .84497 L F
.45349 .86268 m .44769 .86992 L .4706 .84497 L F
.45349 .86268 m .44455 .87334 L .44769 .86992 L F
.4651 .84883 m .4706 .84497 L .47702 .83799 L F
.44455 .87334 m .44487 .87344 L .47082 .84481 L F
.4706 .84497 m .47082 .84481 L .47702 .83799 L F
.44455 .87334 m .47082 .84481 L .4706 .84497 L F
.46422 .84946 m .4742 .83637 L .47324 .83682 L .059 0 0 r
F
.44545 .87362 m .44547 .87363 L .4745 .84558 L .171 0 .048 r
F
.47702 .83799 m .44487 .87344 L .4745 .84558 L F
.44487 .87344 m .44545 .87362 L .4745 .84558 L F
.45617 .86441 m .48723 .83329 L .46933 .84587 L .059 0 0 r
F
.45617 .86441 m .46933 .84587 L .4651 .84883 L F
.44715 .87345 m .45617 .86441 L .4651 .84883 L F
.47885 .83244 m .47232 .84022 L .47702 .83799 L .171 0 .048 r
F
.47885 .83244 m .44524 .87982 L .44489 .87655 L F
.4651 .84883 m .44489 .87655 L .44455 .87334 L F
.47885 .83244 m .44489 .87655 L .4651 .84883 L F
.44524 .87982 m .44252 .88055 L .44455 .87334 L F
.44392 .87788 m .4651 .84883 L .46422 .84946 L .059 0 0 r
F
.4651 .84883 m .4742 .83637 L .46422 .84946 L F
.44318 .87821 m .44319 .87817 L .44259 .87903 L .602 .166 .184 r
F
.44259 .87903 m .4432 .87812 L .44392 .87788 L .059 0 0 r
F
.44259 .87903 m .44392 .87788 L .46422 .84946 L F
.44259 .87903 m .46422 .84946 L .46391 .84967 L F
.47885 .83244 m .47595 .84121 L .50222 .81881 L .171 0 .048 r
F
.47595 .84121 m .48723 .83329 L .50222 .81881 L F
.47906 .83219 m .47974 .83192 L .50222 .81881 L F
.56757 .76059 m .57364 .75585 L .5658 .76078 L .88 .959 .848 r
F
.57754 .74348 m .56506 .76086 L .58534 .73405 L .857 .826 .816 r
F
.56506 .76086 m .52273 .81979 L .56582 .76078 L F
.5658 .76078 m .56934 .75796 L .56506 .76086 L .88 .959 .848 r
F
.56506 .76086 m .56582 .76078 L .58534 .73405 L .857 .826 .816 r
F
.4831 .82511 m .48251 .82911 L .48868 .82073 L 0 0 0 r
F
.50443 .80122 m .52982 .77766 L .49964 .80284 L .88 .959 .848 r
F
.52982 .77766 m .53053 .777 L .52862 .77794 L F
.52862 .77794 m .58045 .73787 L .58086 .73679 L .814 .762 .804 r
F
.53401 .76457 m .50443 .80122 L .53073 .77631 L .897 .854 .792 r
F
.50443 .80122 m .48868 .82073 L .52676 .7805 L F
.50443 .80122 m .52676 .7805 L .53073 .77631 L F
.48286 .82678 m .5658 .76078 L .511 .79739 L .88 .959 .848 r
F
.5658 .76078 m .56506 .76086 L .511 .79739 L F
.47971 .83163 m .51108 .81869 L .5593 .77026 L F
.47892 .83225 m .47907 .83218 L .47971 .83163 L F
.47907 .83218 m .51108 .81869 L .47971 .83163 L F
.49472 .82605 m .49572 .82522 L .47892 .83225 L F
.51089 .81888 m .51108 .81869 L .47892 .83225 L F
.47892 .83225 m .5593 .77026 L .56779 .76057 L F
.47906 .83219 m .47885 .83244 L .47974 .83192 L .171 0 .048 r
F
.48025 .83117 m .44524 .87982 L .47885 .83244 L F
.47892 .83225 m .48247 .82938 L .4796 .83019 L .88 .959 .848 r
F
.48228 .82943 m .44524 .87982 L .48025 .83117 L .171 0 .048 r
F
.44648 .87765 m .44758 .87663 L .46557 .85217 L 0 0 0 r
F
.44648 .87765 m .46557 .85217 L .46529 .85231 L F
.46094 .85663 m .44866 .87068 L .46391 .84967 L F
.45252 .86816 m .44866 .87068 L .46094 .85663 L F
.46391 .84967 m .46422 .84946 L .47324 .83682 L .059 0 0 r
F
.46592 .84981 m .46391 .84967 L .47096 .84088 L 0 0 0 r
F
.44479 .87922 m .44648 .87765 L .44741 .87632 L F
.44756 .87536 m .44741 .87632 L .46515 .85087 L F
.44479 .87922 m .44741 .87632 L .44756 .87536 L F
.44479 .87922 m .46515 .85087 L .45546 .86413 L F
.44672 .87609 m .44479 .87922 L .45546 .86413 L F
.44387 .88249 m .44284 .88911 L .44263 .88052 L .234 0 .201 r
F
.44616 .88868 m .44284 .88911 L .44387 .88249 L F
.45007 .89925 m .44478 .89182 L .44616 .88868 L F
.44478 .89182 m .44284 .88911 L .44616 .88868 L F
.46094 .85663 m .46391 .84967 L .46592 .84981 L 0 0 0 r
F
.44743 .89644 m .44284 .88911 L .45007 .89925 L .234 0 .201 r
F
.44923 .90251 m .44284 .88911 L .45134 .90269 L F
.44387 .88249 m .44263 .88052 L .4431 .88039 L F
.44387 .88248 m .44326 .88083 L .44342 .88229 L F
.44326 .88083 m .4431 .88039 L .44321 .88106 L F
.44326 .88083 m .44321 .88106 L .44342 .88229 L F
.44524 .87982 m .44116 .88537 L .44146 .88429 L .171 0 .048 r
F
.44365 .88024 m .44146 .88429 L .44252 .88055 L F
.44524 .87982 m .44146 .88429 L .44365 .88024 L F
.44263 .88052 m .44256 .88054 L .44259 .87903 L .234 0 .201 r
F
.443 .8821 m .44259 .87903 L .44249 .88188 L F
.44318 .88218 m .44309 .88169 L .443 .8821 L F
.44309 .88169 m .44259 .87903 L .443 .8821 L F
.44116 .88537 m .44213 .88065 L .44252 .88055 L .171 0 .048 r
F
.443 .8821 m .44008 .88684 L .44329 .88223 L 0 0 0 r
F
.4431 .88039 m .44263 .88052 L .44259 .87903 L .234 0 .201 r
F
.44111 .88536 m .44116 .88537 L .44342 .88229 L 0 0 0 r
F
.44111 .88536 m .44342 .88229 L .4434 .88228 L F
.44342 .88229 m .44502 .89208 L .44516 .89232 L .234 0 .201 r
F
.44341 .88228 m .44502 .89208 L .44342 .88229 L F
.44329 .88223 m .44111 .88536 L .4434 .88227 L 0 0 0 r
F
.44111 .88536 m .4434 .88228 L .4434 .88227 L F
.44341 .88228 m .44318 .88218 L .44502 .89208 L .234 0 .201 r
F
.45134 .90269 m .44743 .89644 L .45007 .89925 L F
.4487 .90247 m .45727 .91263 L .4626 .93053 L .239 .058 .423 r
F
.4487 .90247 m .4619 .9291 L .46046 .93007 L F
.4619 .9291 m .4626 .93053 L .46152 .9303 L F
.4619 .9291 m .46152 .9303 L .46046 .93007 L F
.61854 .88105 m .48223 .91889 L .4992 .97237 L .746 .711 .819 r
F
.50297 .95356 m .46101 .93187 L .46152 .9303 L .417 .229 .516 r
F
.44923 .90251 m .44295 .89357 L .44284 .88911 L .234 0 .201 r
F
.4487 .90247 m .4611 .93159 L .4478 .9024 L .239 .058 .423 r
F
.45994 .93523 m .461 .93889 L .45773 .93075 L F
.50297 .95356 m .48695 .9605 L .45951 .93656 L .417 .229 .516 r
F
.50297 .95356 m .45951 .93656 L .46101 .93187 L F
.45951 .93656 m .44774 .92785 L .44412 .92314 L F
.48695 .9605 m .45924 .93742 L .45951 .93656 L F
.45924 .93742 m .44774 .92785 L .45951 .93656 L F
.4478 .9024 m .46098 .93196 L .45927 .93343 L .239 .058 .423 r
F
.46098 .93196 m .46714 .94577 L .4601 .93473 L F
.46098 .93196 m .4601 .93473 L .45927 .93343 L F
.4611 .93159 m .46714 .94577 L .46098 .93196 L F
.4611 .93159 m .46098 .93196 L .4478 .9024 L F
.45927 .93343 m .46714 .94577 L .46455 .94773 L F
.45812 .93081 m .45778 .93003 L .45778 .92999 L F
.45994 .93523 m .45773 .93075 L .45777 .93019 L F
.45994 .93523 m .45369 .9207 L .45812 .93081 L F
.45927 .93343 m .45994 .93523 L .45812 .93081 L F
.46101 .93187 m .45951 .93656 L .44412 .92314 L .417 .229 .516 r
F
.47529 .93376 m .46152 .9303 L .47426 .93303 L F
.50297 .95356 m .4761 .93848 L .47529 .93376 L F
.4761 .93848 m .46152 .9303 L .47529 .93376 L F
.58272 .84836 m .48223 .91889 L .61854 .88105 L .792 .82 .874 r
F
.58272 .84836 m .46719 .88476 L .48223 .91889 L F
.45134 .90269 m .44387 .88248 L .4454 .89273 L .234 0 .201 r
F
.44349 .88385 m .44318 .88218 L .44286 .8852 L F
.4478 .9024 m .44295 .89357 L .44923 .90251 L F
.44284 .88911 m .4427 .88474 L .44273 .88468 L F
.44231 .88755 m .4487 .90247 L .4478 .9024 L .239 .058 .423 r
F
.4421 .88697 m .44243 .88774 L .44231 .88755 L F
.44243 .88774 m .4487 .90247 L .44231 .88755 L F
.44349 .88385 m .44286 .8852 L .44256 .88797 L .234 0 .201 r
F
.44243 .88774 m .44256 .88797 L .44255 .88804 L .239 .058 .423 r
F
.44256 .88797 m .45134 .90269 L .44255 .88804 L F
.44255 .88804 m .45134 .90269 L .4487 .90247 L F
.44202 .88728 m .44501 .8951 L .44137 .88996 L F
.44501 .8951 m .44418 .89539 L .44137 .88996 L F
.44208 .88705 m .44223 .88745 L .44202 .88728 L F
.44223 .88745 m .4478 .9024 L .44202 .88728 L F
.44289 .88268 m .44237 .88529 L .44034 .88685 L 0 0 0 r
F
.44237 .88529 m .44204 .88696 L .44159 .88693 L F
.44237 .88529 m .44159 .88693 L .44034 .88685 L F
.44231 .88755 m .4478 .9024 L .44223 .88745 L .239 .058 .423 r
F
.44229 .8875 m .44223 .88745 L .44208 .88705 L F
.44231 .88755 m .44223 .88745 L .44229 .8875 L F
.44501 .8951 m .4478 .9024 L .44418 .89539 L F
.4478 .9024 m .44255 .89283 L .44137 .88996 L F
.44649 .89999 m .44349 .88385 L .44213 .89204 L .234 0 .201 r
F
.44528 .87973 m .44524 .87982 L .44758 .87663 L 0 0 0 r
F
.44648 .87765 m .44599 .87835 L .44758 .87663 L F
.44599 .87835 m .44528 .87973 L .44758 .87663 L F
.48251 .82911 m .48228 .82943 L .48025 .83117 L .171 0 .048 r
F
.47906 .83219 m .48025 .83117 L .47885 .83244 L F
.46667 .84929 m .44648 .87765 L .46848 .84802 L 0 0 0 r
F
.4796 .83019 m .48247 .82938 L .48286 .82678 L .88 .959 .848 r
F
.47324 .83682 m .47892 .83225 L .4796 .83019 L F
.46515 .85087 m .44648 .87765 L .48049 .82988 L 0 0 0 r
F
.55008 .8284 m .45371 .87034 L .46719 .88476 L .823 .941 .903 r
F
.52273 .81979 m .45371 .87034 L .55008 .8284 L .704 .98 .791 r
F
.44639 .88448 m .44778 .87464 L .45737 .865 L 0 0 0 r
F
.4451 .88676 m .4457 .88406 L .44639 .88448 L F
.4457 .88406 m .44778 .87464 L .44639 .88448 L F
.44778 .87464 m .45024 .87128 L .45737 .865 L F
.44811 .87316 m .44956 .87009 L .45737 .865 L F
.44453 .88652 m .44789 .87361 L .4451 .88676 L F
.44789 .87361 m .44866 .87068 L .44811 .87316 L F
.44789 .87361 m .44811 .87316 L .4451 .88676 L F
.4434 .88788 m .4439 .88625 L .44392 .88812 L F
.44387 .88248 m .44342 .88229 L .44649 .89999 L .234 0 .201 r
F
.4439 .88625 m .44752 .87441 L .44453 .88652 L 0 0 0 r
F
.44752 .87441 m .44866 .87068 L .44789 .87361 L F
.44752 .87441 m .44789 .87361 L .44453 .88652 L F
.44321 .88106 m .44341 .88228 L .44342 .88229 L .234 0 .201 r
F
.4431 .88039 m .44318 .88218 L .44341 .88228 L F
.44506 .87902 m .44389 .88099 L .44599 .87835 L 0 0 0 r
F
.44479 .87922 m .44389 .88099 L .44506 .87902 L F
.44479 .87922 m .443 .8821 L .44389 .88099 L F
.44289 .88268 m .44291 .88258 L .44643 .87671 L F
.44289 .88268 m .44643 .87671 L .44636 .87686 L F
.44318 .88218 m .44229 .88751 L .44263 .88733 L .234 0 .201 r
F
.44289 .88268 m .44034 .88685 L .44291 .88258 L 0 0 0 r
F
.44111 .88536 m .44008 .88684 L .44116 .88537 L F
.443 .8821 m .44034 .88685 L .441 .88534 L F
.44291 .88258 m .44034 .88685 L .443 .8821 L F
.44318 .88218 m .44249 .88188 L .44229 .88751 L .234 0 .201 r
F
.44599 .87835 m .44329 .88223 L .44528 .87973 L 0 0 0 r
F
.44329 .88223 m .4434 .88227 L .44528 .87973 L F
.4434 .88227 m .44524 .87982 L .44528 .87973 L F
.4434 .88228 m .44524 .87982 L .4434 .88227 L F
.4431 .88039 m .44259 .87903 L .44318 .88218 L .234 0 .201 r
F
.443 .8821 m .44329 .88223 L .44599 .87835 L 0 0 0 r
F
.4434 .88228 m .44342 .88229 L .44524 .87982 L F
.44479 .87922 m .44599 .87835 L .44624 .87787 L F
.44607 .87746 m .44237 .88529 L .44289 .88268 L F
.44607 .87746 m .44289 .88268 L .44636 .87686 L F
.44349 .88385 m .44256 .88797 L .44275 .88828 L .234 0 .201 r
F
.4431 .88039 m .44321 .88108 L .44321 .88106 L F
.44321 .88108 m .44341 .88228 L .44321 .88106 L F
.44752 .87441 m .44259 .87903 L .44866 .87068 L 0 0 0 r
F
.44624 .87787 m .44599 .87835 L .44648 .87765 L F
.44375 .88673 m .44325 .88342 L .44752 .87441 L F
.44672 .87609 m .44291 .88258 L .443 .8821 L F
.44643 .87671 m .44291 .88258 L .44672 .87609 L F
.44325 .88342 m .44259 .87903 L .44752 .87441 L F
.44778 .87464 m .44811 .87316 L .45024 .87128 L F
.4607 .85347 m .44672 .87609 L .46526 .85028 L F
.44672 .87609 m .45546 .86413 L .46526 .85028 L F
.44934 .87185 m .44643 .87671 L .44672 .87609 L F
.44636 .87686 m .44643 .87671 L .44934 .87185 L F
.44779 .88991 m .44973 .89294 L .44467 .88898 L 0 0 .542 r
F
.44425 .88827 m .44467 .88898 L .44307 .88773 L F
.44779 .88991 m .44467 .88898 L .44425 .88827 L F
.44419 .88638 m .44453 .88652 L .44413 .88807 L 0 0 0 r
F
.44263 .88733 m .44229 .88751 L .44213 .89204 L .234 0 .201 r
F
.44973 .89294 m .4446 .89047 L .44243 .88743 L 0 0 .542 r
F
.44229 .88751 m .44237 .88529 L .44375 .88673 L 0 0 0 r
F
.44307 .88773 m .44243 .88743 L .4421 .88697 L 0 0 .542 r
F
.44973 .89294 m .44243 .88743 L .44307 .88773 L F
.44419 .88638 m .44413 .88807 L .4441 .8882 L 0 0 0 r
F
.444 .88816 m .4441 .8882 L .44393 .88884 L F
.44419 .88638 m .4441 .8882 L .444 .88816 L F
.4439 .88625 m .44419 .88638 L .44393 .88884 L F
.44393 .88884 m .44453 .88652 L .4451 .88676 L F
.44425 .88827 m .44687 .88362 L .44353 .88706 L F
.44237 .88529 m .44325 .88342 L .44375 .88673 L F
.44736 .87546 m .44204 .88696 L .44237 .88529 L F
.44771 .87479 m .44728 .87571 L .44736 .87546 L F
.44728 .87571 m .44204 .88696 L .44736 .87546 L F
.44771 .87479 m .44237 .88529 L .44607 .87746 L F
.44237 .88529 m .44259 .87903 L .44325 .88342 L F
.44771 .87479 m .4421 .88697 L .44204 .88696 L F
.44794 .87645 m .4421 .88697 L .44771 .87479 L F
.44549 .87996 m .44193 .88621 L .44316 .88477 L .999 .845 .541 r
F
.4455 .87984 m .44193 .88621 L .44549 .87996 L F
.44468 .88068 m .44193 .88621 L .44579 .87932 L F
.44252 .88055 m .44213 .88065 L .44232 .88007 L .171 0 .048 r
F
.43947 .87939 m .44213 .88065 L .43937 .87951 L F
.44455 .87334 m .44294 .87821 L .43947 .87939 L F
.44213 .88065 m .44008 .88684 L .43955 .88135 L F
.44213 .88065 m .43955 .88135 L .43937 .87951 L F
.44337 .88102 m .44012 .87792 L .44155 .88447 L .999 .845 .541 r
F
.44811 .87316 m .44866 .87068 L .44956 .87009 L 0 0 0 r
F
.44714 .86642 m .44586 .87692 L .44975 .86116 L .847 .753 .239 r
F
.44719 .86607 m .44975 .86116 L .44985 .8605 L F
.44697 .86781 m .44135 .8761 L .44596 .87614 L .999 .845 .541 r
F
.44135 .8761 m .44103 .87658 L .4416 .87653 L F
.44135 .8761 m .4416 .87653 L .44596 .87614 L F
.48913 .78728 m .47949 .80581 L .48064 .80638 L .808 .634 .665 r
F
.47949 .80581 m .4744 .81558 L .47788 .81044 L F
.47788 .81044 m .48064 .80638 L .47855 .80917 L .92 .842 .75 r
F
.47949 .80581 m .47788 .81044 L .48064 .80638 L .808 .634 .665 r
F
.43641 .84551 m .45651 .82264 L .44887 .82071 L .953 .819 .675 r
F
.47106 .80849 m .45803 .81975 L .47138 .80955 L .761 .416 .4 r
F
.46839 .79996 m .46525 .80595 L .47106 .80849 L F
.46525 .80595 m .45803 .81975 L .47106 .80849 L F
.44887 .82071 m .46525 .80595 L .46293 .80494 L .875 .71 .674 r
F
.44887 .82071 m .46293 .80494 L .45878 .80625 L F
.46745 .79695 m .45931 .80422 L .45878 .80625 L .761 .416 .4 r
F
.45651 .82264 m .46405 .80824 L .44887 .82071 L .953 .819 .675 r
F
.48054 .79354 m .47138 .80955 L .48913 .78728 L .808 .634 .665 r
F
.47969 .79416 m .48589 .78921 L .47602 .79625 L .953 .819 .675 r
F
.48483 .79042 m .48589 .78921 L .47969 .79416 L F
.48589 .78921 m .47987 .79278 L .47602 .79625 L F
.47969 .79416 m .47602 .79625 L .47944 .79433 L F
.51046 .73579 m .47944 .79433 L .50673 .74774 L .808 .634 .665 r
F
.47944 .79433 m .47138 .80955 L .48054 .79354 L F
.47944 .79433 m .48054 .79354 L .50673 .74774 L F
.47944 .79433 m .47602 .79625 L .47677 .79588 L .953 .819 .675 r
F
.48341 .79203 m .47969 .79416 L .47944 .79433 L F
.48244 .79313 m .48158 .79355 L .44887 .82071 L F
.48341 .79203 m .4758 .79645 L .44887 .82071 L F
.46293 .80494 m .45878 .80625 L .45584 .8175 L .761 .416 .4 r
F
.46745 .79695 m .45878 .80625 L .46293 .80494 L F
.46396 .80539 m .45195 .82439 L .45803 .81975 L F
.46745 .79695 m .46293 .80494 L .46396 .80539 L F
.46293 .80494 m .45195 .82439 L .46396 .80539 L F
.46745 .79695 m .45803 .81975 L .46839 .79996 L F
.46293 .80494 m .47602 .79625 L .46043 .80385 L .875 .71 .674 r
F
.46525 .80595 m .46822 .80328 L .46293 .80494 L F
.46822 .80328 m .47602 .79625 L .46293 .80494 L F
.45878 .80625 m .46293 .80494 L .46043 .80385 L F
.4734 .78013 m .46745 .79695 L .47911 .77328 L .543 .335 .549 r
F
.48296 .76873 m .46839 .79996 L .49141 .75877 L .692 .491 .61 r
F
.44887 .82071 m .45833 .80691 L .4618 .79473 L .875 .71 .674 r
F
.46224 .79305 m .4618 .79473 L .46233 .79285 L F
.44887 .82071 m .4618 .79473 L .46224 .79305 L F
.4287 .82728 m .43641 .84551 L .44887 .82071 L .902 .603 .47 r
F
.41638 .84226 m .41605 .84217 L .41542 .84349 L .61 .236 .308 r
F
.42996 .84509 m .43641 .84551 L .42068 .84315 L .933 .558 .257 r
F
.42702 .83061 m .43641 .84551 L .4287 .82728 L .902 .603 .47 r
F
.42524 .831 m .43073 .81158 L .41605 .84217 L .61 .236 .308 r
F
.42524 .831 m .41605 .84217 L .41638 .84226 L F
.42297 .83863 m .41542 .84349 L .41859 .8473 L .761 .416 .4 r
F
.42498 .83304 m .41542 .84349 L .42472 .83517 L .61 .236 .308 r
F
.39848 .84305 m .41409 .84406 L .39282 .83898 L .933 .558 .257 r
F
.41374 .84163 m .41378 .84189 L .41542 .84349 L .356 0 0 r
F
.40407 .83531 m .40914 .83745 L .40627 .83459 L .902 .603 .47 r
F
.39282 .83898 m .41335 .84205 L .40407 .83531 L F
.40627 .83459 m .40351 .8305 L .39506 .83146 L F
.40351 .8305 m .40307 .82986 L .39506 .83146 L F
.40053 .827 m .40486 .83318 L .40621 .8345 L .356 0 0 r
F
.40308 .82986 m .40621 .8345 L .41378 .84189 L F
.40053 .827 m .40621 .8345 L .40308 .82986 L F
.40053 .827 m .41378 .84189 L .41374 .84163 L F
.43811 .8079 m .43073 .81158 L .42524 .831 L .61 .236 .308 r
F
.40193 .82816 m .40297 .8297 L .40352 .83031 L .356 0 0 r
F
.40193 .82816 m .40352 .83031 L .40639 .83323 L F
.43073 .81158 m .40639 .83323 L .41542 .84349 L .61 .236 .308 r
F
.427 .82784 m .41225 .82803 L .40307 .82986 L .902 .603 .47 r
F
.40639 .83323 m .40352 .83031 L .41374 .84163 L .356 0 0 r
F
.41373 .84157 m .41374 .84163 L .41542 .84349 L F
.40639 .83323 m .41374 .84163 L .41373 .84157 L F
.40486 .83318 m .41479 .8431 L .41542 .84349 L F
.43258 .86012 m .47124 .82309 L .43641 .84551 L .989 .892 .598 r
F
.43557 .86467 m .44998 .86024 L .45116 .84455 L F
.44555 .86605 m .43689 .86485 L .44012 .87792 L .892 .593 .474 r
F
.4352 .86515 m .43075 .86191 L .43375 .86703 L F
.43654 .86343 m .43395 .86275 L .4352 .86515 L F
.43395 .86275 m .43075 .86191 L .4352 .86515 L F
.44555 .86605 m .44998 .86024 L .43557 .86467 L .847 .753 .239 r
F
.45116 .84455 m .44998 .86024 L .47124 .82309 L .989 .892 .598 r
F
.43633 .85697 m .47124 .82309 L .43258 .86012 L F
.43516 .85818 m .43075 .86191 L .44565 .86582 L .892 .593 .474 r
F
.458 .83882 m .43516 .85818 L .44565 .86582 L F
.43133 .86117 m .43075 .86191 L .458 .83882 L F
.43772 .8583 m .44944 .84599 L .43241 .86078 L .989 .892 .598 r
F
.44944 .84599 m .47124 .82309 L .43628 .85702 L F
.44944 .84599 m .43628 .85702 L .43241 .86078 L F
.43873 .85783 m .44338 .85286 L .43772 .8583 L F
.44338 .85286 m .47124 .82309 L .43772 .8583 L F
.43641 .84551 m .47124 .82309 L .47405 .81773 L .953 .819 .675 r
F
.47138 .80955 m .4673 .81849 L .47405 .81773 L .892 .593 .474 r
F
.4744 .81558 m .47405 .81773 L .4754 .81758 L F
.47138 .80955 m .47405 .81773 L .4744 .81558 L F
.47124 .82309 m .47375 .8196 L .47383 .81916 L .92 .842 .75 r
F
.43641 .84551 m .47405 .81773 L .47201 .81796 L .953 .819 .675 r
F
.43641 .84551 m .47525 .81545 L .46923 .81776 L F
.47405 .81773 m .47405 .81776 L .4754 .81758 L .892 .593 .474 r
F
.47124 .82309 m .47383 .81916 L .47384 .81909 L .92 .842 .75 r
F
.47138 .80955 m .46322 .82006 L .4673 .81849 L .892 .593 .474 r
F
.45195 .82439 m .46322 .82006 L .47138 .80955 L .761 .416 .4 r
F
.45648 .82267 m .47788 .81044 L .48483 .79042 L .953 .819 .675 r
F
.43641 .84551 m .46927 .81772 L .45648 .82267 L F
.46927 .81772 m .47788 .81044 L .45648 .82267 L F
.43214 .85905 m .42476 .844 L .43065 .8616 L .761 .416 .4 r
F
.42996 .84509 m .43241 .85978 L .43641 .84551 L .933 .558 .257 r
F
.43219 .85936 m .43241 .85978 L .42996 .84509 L F
.43241 .85978 m .43258 .86012 L .43641 .84551 L F
.43917 .84701 m .42996 .84509 L .43214 .85905 L .761 .416 .4 r
F
.42996 .84509 m .42476 .844 L .43214 .85905 L F
.43219 .85937 m .43065 .8616 L .43103 .86142 L F
.43214 .85905 m .43065 .8616 L .43219 .85937 L F
.43219 .85937 m .43103 .86142 L .43237 .8597 L F
.43241 .85978 m .43258 .86012 L .43258 .86012 L .933 .558 .257 r
F
.43258 .86012 m .43633 .85697 L .43258 .86012 L .989 .892 .598 r
F
.43628 .85702 m .43633 .85697 L .43258 .86012 L F
.4673 .81849 m .43133 .86117 L .458 .83882 L .892 .593 .474 r
F
.46322 .82006 m .43133 .86117 L .4673 .81849 L F
.43103 .86142 m .43133 .86117 L .43241 .85978 L .761 .416 .4 r
F
.43237 .8597 m .43241 .85978 L .46322 .82006 L F
.43103 .86142 m .43241 .85978 L .43237 .8597 L F
.41335 .84205 m .41381 .84212 L .40407 .83531 L .902 .603 .47 r
F
.41381 .84212 m .40961 .83792 L .40407 .83531 L F
.427 .82784 m .42702 .83061 L .4287 .82728 L F
.42619 .82929 m .42702 .83061 L .427 .82784 L F
.42367 .8436 m .43641 .84551 L .42702 .83061 L F
.42472 .83517 m .42702 .83061 L .42557 .8283 L F
.42367 .8436 m .42702 .83061 L .42472 .83517 L F
.43462 .82631 m .42472 .83517 L .44469 .82467 L .761 .416 .4 r
F
.42472 .83517 m .41542 .84349 L .42297 .83863 L F
.4528 .79832 m .40407 .82294 L .4042 .82292 L .846 .586 .546 r
F
.43259 .80992 m .4528 .79832 L .40946 .82026 L F
.45974 .78713 m .42524 .831 L .46437 .79001 L .61 .236 .308 r
F
.42524 .831 m .41542 .84349 L .42498 .83304 L F
.42524 .831 m .42498 .83304 L .46437 .79001 L F
.40627 .83459 m .42367 .8436 L .42557 .8283 L .902 .603 .47 r
F
.42472 .83517 m .42297 .83863 L .44469 .82467 L .761 .416 .4 r
F
.42068 .84315 m .42102 .84248 L .40407 .83531 L .902 .603 .47 r
F
.40486 .83318 m .40036 .83396 L .40956 .83987 L .356 0 0 r
F
.40036 .83396 m .40095 .83456 L .40956 .83987 L F
.40053 .827 m .40042 .82874 L .40486 .83318 L F
.41389 .84267 m .41387 .84253 L .39282 .83898 L .933 .558 .257 r
F
.41387 .84253 m .41381 .84212 L .41335 .84205 L F
.41387 .84253 m .41335 .84205 L .39282 .83898 L F
.42068 .84315 m .42367 .8436 L .42102 .84248 L .902 .603 .47 r
F
.40914 .83745 m .42367 .8436 L .40627 .83459 L F
.42297 .83863 m .41859 .8473 L .43075 .86191 L .761 .416 .4 r
F
.42935 .85395 m .43241 .85978 L .42938 .85397 L .933 .558 .257 r
F
.42388 .85202 m .43241 .85978 L .42935 .85395 L F
.41542 .84349 m .4209 .84792 L .43075 .86191 L .45 0 0 r
F
.4209 .84792 m .4306 .8613 L .43075 .86191 L F
.39848 .84305 m .42789 .85755 L .42388 .85202 L .933 .558 .257 r
F
.42789 .85755 m .43241 .85978 L .42388 .85202 L F
.42789 .85755 m .43258 .86012 L .43241 .85978 L F
.39848 .84305 m .42813 .85789 L .42789 .85755 L F
.42813 .85789 m .43258 .86012 L .42789 .85755 L F
.43103 .86142 m .43075 .86191 L .43133 .86117 L .761 .416 .4 r
F
.43103 .86142 m .43065 .8616 L .43075 .86191 L F
.4306 .8613 m .43119 .8621 L .43075 .86191 L .45 0 0 r
F
.43654 .86343 m .43375 .86703 L .44012 .87792 L .892 .593 .474 r
F
.43209 .86419 m .43301 .86517 L .43334 .86576 L 0 .006 .567 r
F
.43375 .86703 m .43334 .86576 L .44012 .87792 L F
.43209 .86419 m .43334 .86576 L .43375 .86703 L F
.43288 .86408 m .43557 .86467 L .45116 .84455 L .989 .892 .598 r
F
.43283 .86413 m .43292 .86415 L .43288 .86408 L F
.43292 .86415 m .43557 .86467 L .43288 .86408 L F
.4291 .85905 m .43182 .86303 L .43241 .86078 L .933 .558 .257 r
F
.43228 .85997 m .43241 .86078 L .43258 .86012 L F
.39848 .84305 m .43241 .86078 L .43228 .85997 L F
.43241 .86078 m .43628 .85702 L .43258 .86012 L .989 .892 .598 r
F
.43182 .86303 m .43873 .85783 L .43241 .86078 L F
.43182 .86303 m .43873 .85783 L .43182 .86303 L F
.43282 .86415 m .43873 .85783 L .43182 .86303 L F
.43284 .86415 m .43557 .86467 L .43283 .86413 L F
.43322 .86539 m .43342 .86533 L .43282 .86415 L F
.43342 .86533 m .43557 .86467 L .43284 .86415 L F
.43342 .86533 m .43284 .86415 L .43282 .86415 L F
.44555 .86605 m .44086 .8763 L .44708 .86611 L .892 .593 .474 r
F
.44086 .8763 m .44012 .87792 L .44097 .87647 L F
.44086 .8763 m .44097 .87647 L .44708 .86611 L F
.43107 .86222 m .432 .86311 L .4317 .8629 L 0 .006 .567 r
F
.44708 .86611 m .44012 .87792 L .44842 .86567 L .999 .845 .541 r
F
.4427 .87546 m .4428 .87525 L .43389 .8661 L .847 .753 .239 r
F
.4428 .87525 m .4471 .86626 L .43416 .86611 L F
.4428 .87525 m .43416 .86611 L .43389 .8661 L F
.4471 .86626 m .43557 .86467 L .43322 .86539 L F
.44596 .87614 m .44103 .87658 L .44337 .88102 L .999 .845 .541 r
F
.44103 .87658 m .44012 .87792 L .44337 .88102 L F
.43311 .86527 m .4427 .87546 L .44058 .87826 L 0 .006 .567 r
F
.45087 .8696 m .44607 .87746 L .44934 .87185 L 0 0 0 r
F
.44607 .87746 m .44636 .87686 L .44934 .87185 L F
.44807 .87385 m .44155 .88447 L .44468 .88068 L .999 .845 .541 r
F
.47096 .84088 m .46391 .84967 L .47324 .83682 L 0 0 0 r
F
.46478 .85061 m .47079 .84096 L .44975 .86116 L F
.47079 .84096 m .46794 .84232 L .44975 .86116 L F
.44465 .8786 m .44155 .88447 L .44807 .87385 L .999 .845 .541 r
F
.45737 .865 m .45252 .86816 L .46094 .85663 L 0 0 0 r
F
.45459 .86526 m .44373 .88413 L .45574 .86242 L F
.44373 .88413 m .44377 .88396 L .45574 .86242 L F
.45713 .86036 m .45574 .86242 L .4607 .85347 L F
.45459 .86526 m .45574 .86242 L .45713 .86036 L F
.4607 .85347 m .45087 .8696 L .44934 .87185 L F
.4607 .85347 m .44794 .87645 L .44771 .87479 L F
.4562 .86214 m .46113 .85569 L .45903 .8567 L F
.46113 .85569 m .46478 .85061 L .4607 .85347 L F
.45903 .8567 m .4607 .85347 L .44975 .86116 L F
.46113 .85569 m .4607 .85347 L .45903 .8567 L F
.448 .87689 m .44798 .87674 L .45459 .86526 L F
.448 .87689 m .45459 .86526 L .45403 .86634 L F
.45275 .8688 m .448 .87689 L .45403 .86634 L F
.45737 .865 m .46094 .85663 L .46592 .84981 L F
.46592 .84981 m .47324 .83682 L .46526 .85028 L F
.45546 .86413 m .46515 .85087 L .48603 .82092 L F
.45624 .86538 m .46526 .85028 L .44631 .87511 L F
.45403 .86634 m .45459 .86526 L .46142 .85339 L F
.46238 .85237 m .45275 .8688 L .46142 .85339 L F
.45275 .8688 m .45403 .86634 L .46142 .85339 L F
.44631 .87511 m .4562 .86214 L .44975 .86116 L F
.4562 .86214 m .45903 .8567 L .44975 .86116 L F
.46113 .85569 m .46526 .85028 L .46478 .85061 L F
.44921 .87227 m .44468 .88068 L .44579 .87932 L .999 .845 .541 r
F
.44807 .87385 m .44468 .88068 L .44921 .87227 L F
.44921 .87227 m .44316 .88477 L .45206 .86948 L F
.44579 .87932 m .4455 .87984 L .44549 .87996 L F
.448 .87689 m .4421 .88697 L .44798 .87674 L 0 0 0 r
F
.47079 .84096 m .47324 .83682 L .46794 .84232 L F
.48248 .82477 m .48307 .82417 L .48328 .8239 L .793 .955 .624 r
F
.4806 .8213 m .47284 .83453 L .47024 .83805 L 0 0 0 r
F
.44998 .86024 m .48307 .82417 L .46786 .83957 L .793 .955 .624 r
F
.47024 .83805 m .4607 .85347 L .48603 .82092 L 0 0 0 r
F
.46526 .85028 m .46639 .84838 L .46478 .85061 L F
.46639 .84838 m .47079 .84096 L .46478 .85061 L F
.4607 .85347 m .46526 .85028 L .48603 .82092 L F
.47284 .83453 m .46238 .85237 L .47024 .83805 L F
.46238 .85237 m .46142 .85339 L .47024 .83805 L F
.46142 .85339 m .45459 .86526 L .45994 .85495 L F
.44316 .88477 m .44366 .88427 L .47185 .83553 L .999 .845 .541 r
F
.47174 .83565 m .47185 .83553 L .48023 .82105 L F
.44316 .88477 m .47185 .83553 L .47174 .83565 L F
.44998 .86024 m .46786 .83957 L .46494 .84253 L .793 .955 .624 r
F
.47024 .83805 m .46142 .85339 L .4607 .85347 L 0 0 0 r
F
.46142 .85339 m .45994 .85495 L .4607 .85347 L F
.46494 .84253 m .47435 .82075 L .47238 .82223 L .793 .955 .624 r
F
.47124 .82309 m .47453 .82014 L .4736 .81982 L .92 .842 .75 r
F
.47453 .82014 m .47467 .82002 L .4745 .81998 L F
.47453 .82014 m .4745 .81998 L .4736 .81982 L F
.47435 .82075 m .47467 .82002 L .47124 .82309 L .793 .955 .624 r
F
.4745 .81998 m .44921 .87227 L .45804 .85849 L .999 .845 .541 r
F
.47314 .82355 m .45804 .85849 L .46245 .85161 L F
.4745 .81998 m .45804 .85849 L .47314 .82355 L F
.47554 .81784 m .4745 .81998 L .48023 .82105 L F
.499 .80221 m .49024 .80604 L .47467 .82002 L .793 .955 .624 r
F
.4745 .81998 m .46245 .85161 L .47621 .8203 L .999 .845 .541 r
F
.499 .80221 m .47467 .82002 L .47435 .82075 L .793 .955 .624 r
F
.4745 .81998 m .45654 .85006 L .4623 .8452 L .999 .845 .541 r
F
.47554 .81784 m .47444 .81969 L .4745 .81998 L F
.47467 .82002 m .47495 .81976 L .4736 .81982 L .92 .842 .75 r
F
.47495 .81976 m .47385 .81961 L .4736 .81982 L F
.47107 .82339 m .47238 .82223 L .47124 .82309 L .793 .955 .624 r
F
.44998 .86024 m .47238 .82223 L .47107 .82339 L F
.458 .83882 m .46915 .8281 L .47439 .81968 L .892 .593 .474 r
F
.47403 .81964 m .47439 .81968 L .47554 .81784 L F
.47124 .82309 m .47376 .8196 L .47375 .8196 L .92 .842 .75 r
F
.47405 .81773 m .51438 .75659 L .47788 .81044 L F
.47124 .82309 m .47384 .81909 L .47405 .81773 L F
.4672 .81869 m .47375 .8196 L .47376 .81959 L .892 .593 .474 r
F
.47405 .81776 m .47376 .81959 L .4754 .81758 L F
.4672 .81869 m .47376 .81959 L .47405 .81776 L F
.47384 .81909 m .51438 .75659 L .47405 .81773 L .92 .842 .75 r
F
.47368 .82006 m .47439 .81968 L .47403 .81964 L .892 .593 .474 r
F
.458 .83882 m .47359 .82061 L .47368 .82006 L F
.47359 .82061 m .47439 .81968 L .47368 .82006 L F
.47375 .8196 m .54119 .72592 L .54121 .72585 L .92 .842 .75 r
F
.47376 .8196 m .54119 .72592 L .47375 .8196 L F
.44682 .8661 m .44998 .86024 L .44555 .86605 L .847 .753 .239 r
F
.44719 .86607 m .44998 .86024 L .44676 .86621 L F
.44714 .86642 m .44975 .86116 L .44719 .86607 L F
.44985 .8605 m .44975 .86116 L .44998 .86024 L F
.44555 .86605 m .44708 .86611 L .47554 .81784 L .892 .593 .474 r
F
.47495 .81976 m .49024 .80604 L .47385 .81961 L .92 .842 .75 r
F
.4754 .81758 m .47375 .8196 L .47554 .81784 L .892 .593 .474 r
F
.4736 .81982 m .47385 .81961 L .47376 .8196 L .92 .842 .75 r
F
.47375 .8196 m .458 .83882 L .47403 .81964 L .892 .593 .474 r
F
.47375 .8196 m .47403 .81964 L .47554 .81784 L F
.47444 .81969 m .45654 .85006 L .4745 .81998 L .999 .845 .541 r
F
.46884 .83968 m .46936 .83924 L .46985 .83858 L .793 .955 .624 r
F
.47621 .8203 m .46245 .85161 L .48023 .82105 L .999 .845 .541 r
F
.48023 .82105 m .47185 .83553 L .4806 .8213 L F
.47185 .83553 m .47268 .83469 L .4806 .8213 L F
.45648 .86211 m .45593 .86337 L .4806 .8213 L F
.50212 .79944 m .49922 .80298 L .5006 .80152 L .92 .85 .758 r
F
.49922 .80298 m .50443 .80122 L .52524 .77543 L F
.46494 .84253 m .49964 .80284 L .50695 .7928 L .793 .955 .624 r
F
.46786 .83957 m .49964 .80284 L .46494 .84253 L F
.45648 .86211 m .4421 .88697 L .45593 .86337 L .999 .845 .541 r
F
.44341 .88685 m .45624 .86538 L .44631 .87511 L 0 0 0 r
F
.4623 .8452 m .44807 .87385 L .44921 .87227 L .999 .845 .541 r
F
.44921 .87227 m .45206 .86948 L .46245 .85161 L F
.44327 .8883 m .4423 .88751 L .44375 .88673 L 0 0 0 r
F
.44687 .88362 m .46592 .84981 L .44349 .88698 L F
.44341 .88685 m .44408 .88799 L .44344 .88766 L 0 0 .542 r
F
.44353 .88706 m .44349 .88698 L .4433 .88729 L 0 0 0 r
F
.44687 .88362 m .44349 .88698 L .44353 .88706 L F
.44316 .88477 m .44193 .88621 L .4421 .88697 L .999 .845 .541 r
F
.44373 .88413 m .4421 .88697 L .44377 .88396 L 0 0 0 r
F
.44316 .88477 m .4421 .88697 L .44366 .88427 L .999 .845 .541 r
F
.44253 .88537 m .44344 .88766 L .4421 .88697 L 0 0 .542 r
F
.44468 .88068 m .44155 .88447 L .44193 .88621 L .999 .845 .541 r
F
.44324 .88279 m .44341 .88685 L .44253 .88537 L 0 0 .542 r
F
.44341 .88685 m .44344 .88766 L .44253 .88537 L F
.4433 .88729 m .44348 .88698 L .44341 .88685 L 0 0 0 r
F
.44348 .88698 m .46526 .85028 L .44341 .88685 L F
.44339 .88138 m .44335 .8854 L .44372 .88415 L .847 .753 .239 r
F
.44339 .88138 m .44372 .88415 L .44442 .88179 L F
.44403 .88023 m .44442 .88179 L .44586 .87692 L F
.44339 .88138 m .44442 .88179 L .44403 .88023 L F
.4623 .8452 m .44465 .8786 L .44807 .87385 L .999 .845 .541 r
F
.44348 .87382 m .44343 .87782 L .44586 .87692 L .847 .753 .239 r
F
.44343 .87782 m .44403 .88023 L .44586 .87692 L F
.44335 .8854 m .4434 .88675 L .44383 .88506 L F
.44372 .88415 m .44383 .88506 L .44586 .87692 L F
.44335 .8854 m .44383 .88506 L .44372 .88415 L F
.44333 .88705 m .44344 .88673 L .44383 .88513 L F
.44383 .88506 m .44383 .88513 L .44586 .87692 L F
.44333 .88705 m .44383 .88513 L .44383 .88506 L F
.44343 .87782 m .44339 .88138 L .44403 .88023 L F
.46592 .84981 m .46526 .85028 L .4433 .88729 L 0 0 0 r
F
.44331 .88066 m .44331 .8807 L .44012 .87792 L 0 .006 .567 r
F
.4427 .87546 m .44326 .88026 L .44058 .87826 L F
.44012 .87792 m .44324 .88279 L .4421 .88697 L 0 0 .542 r
F
.44329 .88141 m .44333 .88718 L .44339 .88138 L .847 .753 .239 r
F
.44309 .88691 m .44333 .88718 L .44329 .88141 L F
.51359 .90923 m .4801 .91677 L .47338 .9068 L .334 .327 .702 r
F
.47431 .8985 m .47324 .90679 L .46846 .89691 L F
.51359 .90923 m .47324 .90679 L .47431 .8985 L F
.46643 .89931 m .46674 .89696 L .47292 .90612 L 0 .006 .567 r
F
.46058 .89318 m .4663 .89669 L .46643 .89931 L F
.4663 .89669 m .46674 .89696 L .46643 .89931 L F
.44324 .88279 m .46855 .90314 L .47079 .92585 L 0 0 .542 r
F
.46855 .90314 m .47323 .9069 L .47172 .91866 L F
.46855 .90314 m .47172 .91866 L .47079 .92585 L F
.47444 .93168 m .47491 .93283 L .45347 .90286 L F
.45347 .90286 m .47491 .93283 L .4487 .90247 L .239 .058 .423 r
F
.47504 .93316 m .47431 .93135 L .47172 .91866 L .334 .327 .702 r
F
.51359 .90923 m .50297 .95356 L .47529 .93376 L F
.47504 .93316 m .47529 .93376 L .47472 .93336 L F
.51359 .90923 m .47529 .93376 L .47504 .93316 L F
.47491 .93283 m .47444 .93297 L .4487 .90247 L .239 .058 .423 r
F
.47079 .92585 m .47431 .93135 L .47103 .92699 L 0 0 .542 r
F
.47431 .93135 m .47444 .93168 L .47103 .92699 L F
.51359 .90923 m .47623 .93242 L .47172 .91866 L .334 .327 .702 r
F
.47623 .93242 m .47504 .93316 L .47496 .93281 L F
.47623 .93242 m .47496 .93281 L .47172 .91866 L F
.47338 .9068 m .47827 .91718 L .47324 .90679 L F
.4801 .91677 m .47827 .91718 L .47338 .9068 L F
.4427 .87546 m .44339 .88138 L .44343 .87782 L .847 .753 .239 r
F
.4428 .87525 m .44343 .87782 L .44348 .87382 L F
.4427 .87546 m .44343 .87782 L .4428 .87525 L F
.4471 .86626 m .43322 .86539 L .43389 .8661 L F
.4327 .86387 m .44227 .87312 L .43279 .86404 L 0 .006 .567 r
F
.46846 .89691 m .46858 .89968 L .46635 .89633 L .334 .327 .702 r
F
.44348 .87382 m .44586 .87692 L .44709 .86685 L .847 .753 .239 r
F
.44697 .86678 m .44709 .86685 L .44714 .86642 L F
.44348 .87382 m .44709 .86685 L .44697 .86678 L F
.42889 .85437 m .43408 .86342 L .43202 .86248 L .45 0 0 r
F
.42889 .85437 m .43202 .86248 L .43042 .85954 L F
.42889 .85437 m .43119 .8621 L .4306 .8613 L F
.43075 .86191 m .43107 .86222 L .4317 .8629 L 0 .006 .567 r
F
.43075 .86191 m .4317 .8629 L .43301 .86517 L F
.4317 .8629 m .43181 .86301 L .43182 .86303 L F
.4317 .8629 m .43182 .86303 L .43301 .86517 L F
.43075 .86191 m .43301 .86517 L .43209 .86419 L F
.43181 .86301 m .44058 .87826 L .44012 .87792 L F
.43075 .86191 m .43119 .8621 L .43164 .86276 L F
.39848 .84305 m .43182 .86303 L .4291 .85905 L .933 .558 .257 r
F
.39848 .84305 m .42938 .85397 L .41564 .84416 L F
.4209 .84792 m .42889 .85437 L .4306 .8613 L .45 0 0 r
F
.43917 .84701 m .43214 .85905 L .43219 .85937 L .761 .416 .4 r
F
.42457 .84474 m .43219 .85936 L .42996 .84509 L .933 .558 .257 r
F
.45195 .82439 m .43219 .85937 L .46322 .82006 L .761 .416 .4 r
F
.43219 .85937 m .43237 .8597 L .46322 .82006 L F
.44565 .86582 m .43654 .86343 L .43689 .86485 L .892 .593 .474 r
F
.44565 .86582 m .43689 .86485 L .44555 .86605 L F
.44687 .86674 m .44714 .86642 L .44719 .86607 L .847 .753 .239 r
F
.44348 .87382 m .44697 .86678 L .44687 .86674 L F
.44697 .86678 m .44714 .86642 L .44687 .86674 L F
.4623 .8452 m .44697 .86781 L .44596 .87614 L .999 .845 .541 r
F
.42889 .85437 m .44319 .86593 L .43408 .86342 L .45 0 0 r
F
.42926 .85502 m .42942 .8553 L .43888 .86269 L F
.41564 .84416 m .42942 .8553 L .42926 .85502 L F
.41564 .84416 m .41831 .84662 L .42942 .8553 L F
.41564 .84416 m .43888 .86269 L .43924 .86287 L F
.4209 .84792 m .41564 .84416 L .43924 .86287 L F
.4209 .84792 m .43924 .86287 L .43968 .86309 L F
.44227 .87312 m .44229 .8732 L .43279 .86404 L 0 .006 .567 r
F
.43182 .86303 m .43182 .86303 L .43182 .86303 L .989 .892 .598 r
F
.43282 .86415 m .43284 .86415 L .43283 .86413 L F
.43182 .86303 m .43182 .86303 L .43182 .86303 L .933 .558 .257 r
F
.43181 .86301 m .44263 .87489 L .43311 .86527 L 0 .006 .567 r
F
.44263 .87489 m .4427 .87546 L .43311 .86527 L F
.43181 .86301 m .44256 .87428 L .44263 .87489 L F
.43279 .86404 m .44229 .8732 L .44256 .87428 L F
.432 .86311 m .44225 .87305 L .43214 .86333 L F
.44225 .87305 m .44227 .87312 L .43214 .86333 L F
.43389 .8661 m .43322 .86539 L .43102 .86607 L .847 .753 .239 r
F
.432 .86311 m .43214 .86333 L .4317 .8629 L 0 .006 .567 r
F
.4317 .8629 m .4327 .86387 L .43279 .86404 L F
.43102 .86607 m .43282 .86415 L .43182 .86303 L .989 .892 .598 r
F
.43042 .85954 m .43202 .86248 L .43119 .8621 L .45 0 0 r
F
.43263 .86373 m .43408 .86342 L .43593 .86692 L 0 .006 .567 r
F
.43164 .86276 m .43223 .86292 L .43263 .86373 L F
.43223 .86292 m .43408 .86342 L .43263 .86373 L F
.43102 .86607 m .43322 .86539 L .43282 .86415 L .989 .892 .598 r
F
.44012 .87792 m .44331 .8807 L .44324 .88279 L 0 0 .542 r
F
.46058 .89318 m .45535 .89101 L .44012 .87792 L 0 .006 .567 r
F
.43396 .90412 m .42996 .91756 L .4189 .89628 L .603 .144 .136 r
F
.43336 .90381 m .43243 .90757 L .43396 .90412 L .727 .29 .212 r
F
.43699 .88916 m .43336 .90381 L .43396 .90412 L F
.43243 .90757 m .42996 .91756 L .43287 .90781 L F
.43243 .90757 m .43287 .90781 L .43396 .90412 L F
.43937 .87951 m .43371 .9092 L .43243 .90757 L F
.4393 .88256 m .4427 .87546 L .43102 .86607 L .847 .753 .239 r
F
.4427 .87546 m .43389 .8661 L .43102 .86607 L F
.39848 .84305 m .43102 .86607 L .43182 .86303 L .933 .558 .257 r
F
.39848 .84305 m .43182 .86303 L .43182 .86303 L F
.43119 .8621 m .43408 .86342 L .43164 .86276 L 0 .006 .567 r
F
.41409 .84406 m .41564 .84416 L .41389 .84267 L .933 .558 .257 r
F
.41931 .84663 m .41523 .84379 L .4209 .84792 L .45 0 0 r
F
.41523 .84379 m .41564 .84416 L .4209 .84792 L F
.41409 .84406 m .41389 .84267 L .39282 .83898 L .933 .558 .257 r
F
.41627 .84417 m .41344 .84235 L .41931 .84663 L .45 0 0 r
F
.41564 .84416 m .41404 .84269 L .41389 .84267 L .933 .558 .257 r
F
.41344 .84235 m .41005 .84018 L .41931 .84663 L .45 0 0 r
F
.40486 .83318 m .40956 .83987 L .41387 .84253 L .356 0 0 r
F
.41381 .84212 m .41387 .84253 L .41479 .8431 L F
.40486 .83318 m .41387 .84253 L .41381 .84212 L F
.41542 .84349 m .41479 .8431 L .41627 .84417 L .45 0 0 r
F
.41479 .8431 m .41387 .84253 L .41627 .84417 L F
.41404 .84269 m .41387 .84253 L .41389 .84267 L .933 .558 .257 r
F
.41387 .84253 m .41005 .84018 L .41423 .84286 L .45 0 0 r
F
.41387 .84253 m .41423 .84286 L .41627 .84417 L F
.42642 .84486 m .41381 .84212 L .41387 .84253 L .933 .558 .257 r
F
.42642 .84486 m .41387 .84253 L .41404 .84269 L F
.41564 .84416 m .42642 .84486 L .41404 .84269 L F
.41523 .84379 m .41007 .84019 L .41564 .84416 L .45 0 0 r
F
.41564 .84416 m .41005 .84018 L .41831 .84662 L F
.41564 .84416 m .42938 .85397 L .42457 .84474 L .933 .558 .257 r
F
.41007 .84019 m .41005 .84018 L .41976 .8471 L .45 0 0 r
F
.41976 .8471 m .41976 .8471 L .4209 .84792 L F
.41007 .84019 m .41976 .8471 L .41976 .8471 L F
.41304 .84364 m .43102 .86607 L .39848 .84305 L .661 .246 0 r
F
.41005 .84018 m .41118 .84225 L .42324 .85091 L .45 0 0 r
F
.40449 .83722 m .41304 .84364 L .40969 .84351 L .036 .354 .828 r
F
.41118 .84225 m .41124 .84236 L .41304 .84364 L .45 0 0 r
F
.41118 .84225 m .41304 .84364 L .42324 .85091 L F
.40119 .82794 m .40053 .827 L .39872 .82598 L .846 .586 .546 r
F
.40053 .827 m .36832 .81759 L .40041 .82876 L .356 0 0 r
F
.40041 .82876 m .3703 .81906 L .3774 .82263 L F
.39916 .82532 m .39913 .82621 L .40046 .82658 L .149 0 0 r
F
.40056 .82661 m .39915 .82622 L .40053 .827 L .356 0 0 r
F
.40056 .82661 m .40046 .82658 L .40056 .82661 L F
.35008 .81167 m .39282 .83898 L .35274 .81164 L .718 .185 0 r
F
.35963 .81158 m .3518 .8108 L .34959 .81167 L .149 0 0 r
F
.34191 .80953 m .33326 .80901 L .33485 .80933 L F
.34819 .81169 m .39282 .83898 L .35008 .81167 L .718 .185 0 r
F
.3532 .81336 m .39282 .83898 L .34819 .81169 L 0 .082 .565 r
F
.3532 .81336 m .34819 .81169 L .3492 .81182 L F
.33708 .80956 m .3374 .80963 L .33744 .80962 L .764 .294 .128 r
F
.35412 .80989 m .33485 .80933 L .3436 .81107 L .149 0 0 r
F
.34921 .81183 m .3436 .81107 L .34859 .81207 L F
.35412 .80989 m .3436 .81107 L .34921 .81183 L F
.36503 .81211 m .35963 .81158 L .35042 .81199 L F
.36503 .81211 m .35042 .81199 L .35107 .81208 L F
.35963 .81158 m .34959 .81167 L .34921 .81183 L F
.39339 .81976 m .35204 .81266 L .39657 .82283 L F
.35204 .81266 m .35252 .81295 L .39657 .82283 L F
.40046 .82658 m .3532 .81336 L .40056 .82661 L .356 0 0 r
F
.3532 .81336 m .34859 .81207 L .3532 .81336 L F
.3532 .81336 m .3532 .81336 L .40056 .82661 L F
.39916 .82528 m .40046 .82658 L .40056 .82661 L .149 0 0 r
F
.39657 .82283 m .39916 .82532 L .39916 .82528 L F
.39916 .82532 m .40046 .82658 L .39916 .82528 L F
.4646 .77994 m .40883 .82058 L .46461 .78094 L .363 0 .14 r
F
.40883 .82058 m .40056 .82661 L .40946 .82026 L F
.40883 .82058 m .40946 .82026 L .46461 .78094 L F
.40946 .82026 m .40056 .82661 L .41026 .8199 L .61 .236 .308 r
F
.44244 .78879 m .40056 .82661 L .45405 .78763 L .363 0 .14 r
F
.41102 .8223 m .4042 .82292 L .39915 .82548 L .846 .586 .546 r
F
.39915 .82551 m .39915 .82548 L .39901 .82555 L F
.41102 .8223 m .39915 .82548 L .39915 .82551 L F
.40169 .82766 m .41102 .8223 L .39914 .82585 L F
.39913 .82621 m .39914 .82585 L .39872 .82598 L F
.40169 .82766 m .39914 .82585 L .39913 .82621 L F
.39657 .82283 m .35252 .81295 L .39913 .82621 L .149 0 0 r
F
.35252 .81295 m .3532 .81336 L .39913 .82621 L F
.37267 .82082 m .38687 .83362 L .3532 .81336 L 0 .082 .565 r
F
.38687 .83362 m .39282 .83898 L .3532 .81336 L F
.37267 .82082 m .39848 .84305 L .39282 .83898 L F
.37586 .82317 m .39848 .84305 L .37267 .82082 L F
.39915 .82622 m .36832 .81759 L .40053 .827 L .356 0 0 r
F
.38921 .82869 m .40969 .84351 L .39848 .84305 L .036 .354 .828 r
F
.3958 .83171 m .40969 .84351 L .38921 .82869 L F
.40095 .83456 m .40969 .84351 L .3958 .83171 L F
.3703 .81906 m .38921 .82869 L .39036 .82914 L .356 0 0 r
F
.39533 .8295 m .3774 .82263 L .39203 .82998 L F
.40041 .82876 m .3774 .82263 L .39533 .8295 L F
.36832 .81759 m .34859 .81207 L .40041 .82876 L F
.36503 .81211 m .35107 .81208 L .39613 .82023 L .149 0 0 r
F
.3532 .81336 m .3492 .81182 L .35107 .81208 L 0 .082 .565 r
F
.35107 .81208 m .34859 .81207 L .35204 .81266 L .149 0 0 r
F
.35107 .81208 m .35204 .81266 L .39613 .82023 L F
.38921 .82869 m .39848 .84305 L .37651 .82365 L .036 .354 .828 r
F
.3703 .81906 m .37367 .82155 L .38921 .82869 L .356 0 0 r
F
.37367 .82155 m .37752 .8244 L .39203 .82998 L F
.37706 .81214 m .35412 .80989 L .3518 .8108 L .149 0 0 r
F
.37706 .81214 m .3518 .8108 L .36503 .81211 L F
.36932 .80086 m .32773 .80491 L .37663 .80652 L .181 .715 .778 r
F
.35803 .8073 m .35109 .80658 L .35746 .8074 L F
.35326 .809 m .3341 .80752 L .37706 .81214 L .149 0 0 r
F
.3341 .80752 m .34425 .80892 L .37706 .81214 L F
.34646 .80069 m .33748 .80323 L .35995 .80177 L .571 .935 .92 r
F
.38587 .78952 m .34646 .80069 L .35995 .80177 L F
.35027 .80049 m .37651 .82365 L .35312 .80319 L 0 .082 .565 r
F
.37651 .82365 m .39848 .84305 L .37586 .82317 L F
.37651 .82365 m .37586 .82317 L .35312 .80319 L F
.37267 .82082 m .34859 .81207 L .37752 .8244 L .356 0 0 r
F
.3703 .81906 m .3564 .81458 L .37267 .82082 L F
.3564 .81458 m .34859 .81207 L .37267 .82082 L F
.37267 .82082 m .3532 .81336 L .35496 .8126 L 0 .082 .565 r
F
.3532 .81336 m .35107 .81208 L .35496 .8126 L F
.40737 .79796 m .38832 .80208 L .38561 .80254 L .685 .288 .29 r
F
.3921 .80704 m .39218 .80714 L .39767 .80722 L .181 .715 .778 r
F
.37406 .80454 m .39366 .80066 L .38189 .80319 L .685 .288 .29 r
F
.39366 .80066 m .39719 .8001 L .38561 .80254 L F
.39366 .80066 m .38561 .80254 L .38189 .80319 L F
.39366 .80066 m .40737 .79796 L .39719 .8001 L F
.37406 .80454 m .39817 .80927 L .40737 .79796 L F
.36448 .81019 m .39837 .80903 L .37302 .81044 L .736 .315 .248 r
F
.39481 .80923 m .39675 .80922 L .37817 .81022 L F
.39481 .80923 m .37817 .81022 L .3776 .81023 L F
.38276 .81127 m .37124 .81038 L .39205 .81218 L .149 0 0 r
F
.37124 .81038 m .36955 .81034 L .39205 .81218 L F
.39205 .81218 m .36955 .81034 L .37706 .81214 L F
.36955 .81034 m .36164 .81011 L .37706 .81214 L F
.39465 .81219 m .38276 .81127 L .39205 .81218 L F
.39881 .80911 m .39817 .80927 L .38131 .81014 L .736 .315 .248 r
F
.39881 .80911 m .38131 .81014 L .37817 .81022 L F
.39526 .81118 m .38459 .81007 L .39465 .81219 L .181 .715 .778 r
F
.38459 .81007 m .37963 .81018 L .39465 .81219 L F
.36448 .81019 m .39509 .81274 L .39215 .80925 L .736 .315 .248 r
F
.36 .78342 m .38921 .82869 L .34311 .79417 L .036 .354 .828 r
F
.38921 .82869 m .37651 .82365 L .34311 .79417 L F
.39036 .82914 m .38921 .82869 L .39203 .82998 L .356 0 0 r
F
.39203 .82998 m .37752 .8244 L .40006 .83402 L F
.40041 .82876 m .39203 .82998 L .40008 .83368 L F
.39927 .8333 m .3958 .83171 L .38553 .82298 L .036 .354 .828 r
F
.40095 .83456 m .3958 .83171 L .39927 .8333 L F
.35042 .81199 m .34921 .81183 L .34859 .81207 L .149 0 0 r
F
.35963 .81158 m .34921 .81183 L .35042 .81199 L F
.34841 .80732 m .32123 .8063 L .34475 .80834 L .181 .715 .778 r
F
.32123 .8063 m .32163 .80656 L .34475 .80834 L F
.3341 .80752 m .32163 .80656 L .34425 .80892 L .149 0 0 r
F
.32163 .80656 m .32164 .80669 L .34425 .80892 L F
.33301 .80241 m .35274 .81164 L .34664 .81074 L .718 .185 0 r
F
.32019 .80564 m .32101 .80617 L .33114 .80631 L .181 .715 .778 r
F
.33301 .80241 m .34664 .81074 L .32877 .80809 L .718 .185 0 r
F
.33326 .80901 m .33089 .80887 L .34859 .81207 L .149 0 0 r
F
.32877 .80809 m .33098 .80887 L .33227 .80895 L .764 .294 .128 r
F
.32877 .80809 m .33304 .809 L .33433 .80907 L F
.35274 .81164 m .33098 .80887 L .32877 .80809 L .718 .185 0 r
F
.33854 .80579 m .34819 .81169 L .34263 .80691 L F
.34819 .81169 m .35008 .81167 L .34263 .80691 L F
.34263 .80691 m .35008 .81167 L .35274 .81164 L F
.33301 .80241 m .33854 .80579 L .34263 .80691 L F
.35496 .8126 m .34709 .81101 L .33301 .80241 L 0 .082 .565 r
F
.3492 .81182 m .34709 .81101 L .35496 .8126 L F
.35109 .80658 m .34605 .80651 L .34841 .80732 L .181 .715 .778 r
F
.34311 .79417 m .36506 .81395 L .34172 .80645 L 0 .082 .565 r
F
.36506 .81395 m .37267 .82082 L .35496 .8126 L F
.36506 .81395 m .35496 .8126 L .34172 .80645 L F
.35107 .81208 m .35042 .81199 L .34859 .81207 L .149 0 0 r
F
.3492 .81182 m .34819 .81169 L .34709 .81101 L 0 .082 .565 r
F
.35204 .81266 m .34859 .81207 L .35252 .81295 L .149 0 0 r
F
.35252 .81295 m .34859 .81207 L .3532 .81336 L F
.33386 .80172 m .34172 .80645 L .33301 .80241 L 0 .082 .565 r
F
.34311 .79417 m .34172 .80645 L .33386 .80172 L F
.37754 .8106 m .40095 .83456 L .38553 .82298 L .036 .354 .828 r
F
.40008 .83368 m .39203 .82998 L .40006 .83402 L .356 0 0 r
F
.38553 .82298 m .3958 .83171 L .38921 .82869 L .036 .354 .828 r
F
.41005 .84018 m .40095 .83456 L .41118 .84225 L .45 0 0 r
F
.40042 .82874 m .40008 .83368 L .40486 .83318 L .356 0 0 r
F
.40008 .83368 m .40006 .83402 L .40036 .83396 L F
.40008 .83368 m .40036 .83396 L .40486 .83318 L F
.36 .78342 m .40969 .84351 L .37754 .8106 L .036 .354 .828 r
F
.41118 .84225 m .40006 .83402 L .41124 .84236 L .45 0 0 r
F
.40095 .83456 m .40006 .83402 L .41118 .84225 L F
.41381 .84212 m .42068 .84315 L .40961 .83792 L .902 .603 .47 r
F
.41698 .84645 m .43102 .86607 L .41304 .84364 L .661 .246 0 r
F
.41698 .84645 m .4393 .88256 L .43102 .86607 L F
.41669 .84638 m .4393 .88256 L .41698 .84645 L F
.43223 .85784 m .4393 .88256 L .41669 .84638 L .041 .256 .754 r
F
.41005 .84018 m .42717 .85412 L .44031 .86381 L .45 0 0 r
F
.44319 .86593 m .44472 .86825 L .43408 .86342 L F
.44319 .86593 m .44424 .86678 L .44472 .86825 L F
.43968 .86309 m .43924 .86287 L .44229 .86528 L F
.46719 .88476 m .45446 .88661 L .4576 .88826 L .614 .953 .914 r
F
.45903 .87808 m .4645 .89171 L .44585 .86876 L .041 .256 .754 r
F
.44456 .86702 m .44585 .86876 L .44424 .86678 L F
.45903 .87808 m .44585 .86876 L .44456 .86702 L F
.43593 .86692 m .46638 .89643 L .46638 .89643 L 0 .006 .567 r
F
.44227 .87312 m .46611 .89617 L .44229 .8732 L F
.46611 .89617 m .46639 .89644 L .46611 .89617 L F
.46611 .89617 m .46611 .89617 L .44229 .8732 L F
.46639 .89644 m .46639 .89644 L .44229 .8732 L F
.4652 .89978 m .47324 .90679 L .46506 .90024 L 0 0 .542 r
F
.4652 .89978 m .46506 .90024 L .44324 .88279 L F
.44331 .8807 m .4652 .89978 L .44324 .88279 L F
.47324 .90679 m .47323 .9069 L .44324 .88279 L F
.44256 .87428 m .46647 .89654 L .46058 .89318 L 0 .006 .567 r
F
.43593 .86692 m .44624 .86928 L .46632 .89635 L F
.43593 .86692 m .46632 .89635 L .46615 .8962 L F
.43968 .86309 m .44229 .86528 L .44424 .86678 L .45 0 0 r
F
.44424 .86678 m .44585 .86876 L .44472 .86825 L F
.4393 .88256 m .44309 .88691 L .44329 .88141 L .847 .753 .239 r
F
.4393 .88256 m .44339 .88138 L .4427 .87546 L F
.44263 .87489 m .45654 .89017 L .4427 .87546 L 0 .006 .567 r
F
.45535 .89101 m .45495 .89084 L .44331 .8807 L F
.45535 .89101 m .44331 .8807 L .44331 .88066 L F
.44263 .87489 m .46058 .89318 L .45654 .89017 L F
.44256 .87428 m .46058 .89318 L .44263 .87489 L F
.46858 .89968 m .46635 .89638 L .46635 .89633 L .334 .327 .702 r
F
.44229 .8732 m .46726 .89728 L .44256 .87428 L 0 .006 .567 r
F
.44324 .88279 m .44779 .88991 L .44408 .88799 L 0 0 .542 r
F
.44324 .88279 m .44408 .88799 L .44341 .88685 L F
.44225 .87305 m .46726 .89728 L .44227 .87312 L 0 .006 .567 r
F
.4427 .87546 m .45654 .89017 L .44326 .88026 L F
.43408 .86342 m .44585 .86876 L .43593 .86692 L F
.4645 .89171 m .46399 .89321 L .44585 .86876 L .041 .256 .754 r
F
.44585 .86876 m .44777 .86963 L .44624 .86928 L 0 .006 .567 r
F
.44585 .86876 m .44624 .86928 L .43593 .86692 L F
.4645 .89171 m .46635 .89633 L .46399 .89321 L .041 .256 .754 r
F
.44585 .86876 m .46399 .89321 L .44163 .86357 L F
.4415 .86468 m .46399 .89321 L .4393 .88256 L F
.4438 .86644 m .46399 .89321 L .4415 .86468 L F
.4415 .86468 m .4393 .88256 L .43223 .85784 L F
.44229 .86528 m .44031 .86381 L .44777 .86963 L .45 0 0 r
F
.4419 .86498 m .4415 .86468 L .44229 .86528 L F
.4415 .86468 m .44031 .86381 L .44229 .86528 L F
.44163 .86357 m .4438 .86644 L .4415 .86468 L .041 .256 .754 r
F
.46399 .89321 m .46635 .89633 L .46628 .89629 L F
.46647 .89654 m .46681 .897 L .46058 .89318 L 0 .006 .567 r
F
.46058 .89318 m .47292 .90612 L .45535 .89101 L F
.46399 .89321 m .46628 .89629 L .4393 .88256 L .041 .256 .754 r
F
.46647 .89654 m .46726 .89728 L .46681 .897 L 0 .006 .567 r
F
.47292 .90612 m .47324 .90679 L .45495 .89084 L F
.47292 .90612 m .45495 .89084 L .45535 .89101 L F
.46164 .91156 m .47079 .92585 L .45347 .90286 L 0 0 .542 r
F
.47079 .92585 m .47103 .92699 L .45347 .90286 L F
.45824 .92141 m .4478 .9024 L .44923 .90251 L .234 0 .201 r
F
.45727 .91263 m .47444 .93297 L .47019 .93429 L .239 .058 .423 r
F
.47827 .91718 m .47172 .91866 L .47324 .90679 L .334 .327 .702 r
F
.47431 .93135 m .47511 .90842 L .47819 .93742 L 0 0 .542 r
F
.47079 .92585 m .4721 .92056 L .47431 .93135 L F
.4721 .92056 m .47511 .90842 L .47431 .93135 L F
.47323 .9069 m .47511 .90842 L .47079 .92585 L F
.45727 .91263 m .47397 .94061 L .46714 .94577 L .239 .058 .423 r
F
.47172 .91866 m .47463 .93291 L .45836 .92166 L .334 .327 .702 r
F
.47463 .93291 m .47472 .93336 L .47426 .93303 L F
.47463 .93291 m .47426 .93303 L .45836 .92166 L F
.47019 .93429 m .47819 .93742 L .47397 .94061 L .239 .058 .423 r
F
.47444 .93297 m .47819 .93742 L .47019 .93429 L F
.45836 .92166 m .44923 .90251 L .45134 .90269 L .234 0 .201 r
F
.45833 .92156 m .45134 .90269 L .4457 .89475 L F
.45134 .90269 m .4454 .89273 L .4457 .89475 L F
.44516 .89232 m .44502 .89208 L .44649 .89999 L F
.44232 .88749 m .45347 .90286 L .45134 .90269 L .239 .058 .423 r
F
.44232 .88749 m .45134 .90269 L .44243 .88774 L F
.44243 .88743 m .45347 .90286 L .44232 .88749 L F
.44973 .89294 m .45207 .8966 L .4446 .89047 L 0 0 .542 r
F
.45207 .8966 m .46164 .91156 L .44983 .89694 L F
.45207 .8966 m .44983 .89694 L .4446 .89047 L F
.46346 .89486 m .44986 .89341 L .45624 .89118 L 0 0 .446 r
F
.46628 .89629 m .46061 .8953 L .46346 .89486 L F
.46061 .8953 m .44986 .89341 L .46346 .89486 L F
.46164 .91156 m .45347 .90286 L .4446 .89047 L 0 0 .542 r
F
.44251 .89277 m .4415 .89038 L .44139 .89002 L .239 .058 .423 r
F
.45836 .92166 m .44295 .89357 L .45824 .92141 L .234 0 .201 r
F
.45836 .92166 m .45833 .92156 L .44649 .89999 L F
.45833 .92156 m .4457 .89475 L .44649 .89999 L F
.46629 .89632 m .45836 .92166 L .44213 .89204 L 0 0 .446 r
F
.46635 .89633 m .46634 .89636 L .46629 .89632 L F
.46615 .8962 m .46632 .89635 L .46638 .89643 L 0 .006 .567 r
F
.46635 .89638 m .46634 .89636 L .46635 .89633 L .334 .327 .702 r
F
.46635 .89633 m .46629 .89632 L .46628 .89629 L 0 0 .446 r
F
.458 .83882 m .44555 .86605 L .46915 .8281 L .892 .593 .474 r
F
.45654 .85006 m .44708 .86611 L .4623 .8452 L .999 .845 .541 r
F
.44708 .86611 m .44842 .86567 L .4623 .8452 L F
.48049 .82988 m .46667 .84929 L .48228 .82943 L 0 0 0 r
F
.46667 .84929 m .46848 .84802 L .48228 .82943 L F
.47963 .8301 m .46515 .85087 L .48049 .82988 L F
.46529 .85231 m .46557 .85217 L .48228 .82943 L F
.46786 .83957 m .48248 .82477 L .49964 .80284 L .793 .955 .624 r
F
.47185 .83553 m .45648 .86211 L .47268 .83469 L .999 .845 .541 r
F
.46494 .84253 m .499 .80221 L .47435 .82075 L .793 .955 .624 r
F
.55008 .8284 m .46719 .88476 L .58272 .84836 L .823 .941 .903 r
F
.48648 .83719 m .46635 .89633 L .44435 .8415 L .402 .463 .809 r
F
.48648 .83719 m .51359 .90923 L .46635 .89633 L F
.46639 .89643 m .44777 .86963 L .46726 .89728 L 0 .006 .567 r
F
.44624 .86928 m .44777 .86963 L .46639 .89643 L F
.46634 .89636 m .45836 .92166 L .46629 .89632 L 0 0 .446 r
F
.46638 .89643 m .46638 .89643 L .46639 .89643 L 0 .006 .567 r
F
.46937 .91918 m .46526 .89979 L .46634 .89636 L .334 .327 .702 r
F
.46937 .91918 m .46634 .89636 L .46635 .89638 L F
.44424 .86678 m .44777 .86963 L .44585 .86876 L .45 0 0 r
F
.44424 .86678 m .44229 .86528 L .44777 .86963 L F
.44676 .86621 m .44682 .8661 L .44555 .86605 L .847 .753 .239 r
F
.4471 .86626 m .44719 .86607 L .44676 .86621 L F
.44435 .8415 m .45903 .87808 L .44163 .86357 L .041 .256 .754 r
F
.45903 .87808 m .44424 .86678 L .44163 .86357 L F
.45584 .8175 m .42476 .844 L .43917 .84701 L .761 .416 .4 r
F
.42642 .84486 m .42996 .84509 L .41864 .84284 L .933 .558 .257 r
F
.42996 .84509 m .42068 .84315 L .41864 .84284 L F
.44163 .86357 m .4415 .86468 L .42791 .84275 L .041 .256 .754 r
F
.43924 .86287 m .43888 .86269 L .44031 .86381 L .45 0 0 r
F
.43924 .86287 m .44031 .86381 L .4419 .86498 L F
.4415 .86468 m .43223 .85784 L .42791 .84275 L .041 .256 .754 r
F
.44031 .86381 m .42923 .85579 L .44777 .86963 L .45 0 0 r
F
.42717 .85412 m .42923 .85579 L .44031 .86381 L F
.42642 .84486 m .41864 .84284 L .41381 .84212 L .933 .558 .257 r
F
.45584 .8175 m .42297 .83863 L .42476 .844 L .761 .416 .4 r
F
.42791 .84275 m .43223 .85784 L .41502 .84372 L .041 .256 .754 r
F
.42324 .85091 m .41124 .84236 L .42923 .85579 L .45 0 0 r
F
.41502 .84372 m .41698 .84645 L .41304 .84364 L .661 .246 0 r
F
.41502 .84372 m .41669 .84638 L .41698 .84645 L F
.43223 .85784 m .41669 .84638 L .41502 .84372 L .041 .256 .754 r
F
.40627 .83459 m .427 .82784 L .40351 .8305 L .902 .603 .47 r
F
.39872 .82598 m .39914 .82585 L .39901 .82555 L .846 .586 .546 r
F
.37407 .79944 m .41138 .78797 L .37396 .79895 L .502 .096 .203 r
F
.36 .78342 m .41502 .84372 L .41304 .84364 L .036 .354 .828 r
F
.36 .78342 m .41304 .84364 L .40449 .83722 L F
.44435 .8415 m .44163 .86357 L .42791 .84275 L .041 .256 .754 r
F
.46858 .89968 m .46937 .91918 L .46635 .89638 L .334 .327 .702 r
F
.46639 .89644 m .46726 .89728 L .46639 .89644 L 0 .006 .567 r
F
.47324 .90679 m .46937 .91918 L .46846 .89691 L .334 .327 .702 r
F
.47172 .91866 m .46937 .91918 L .47324 .90679 L F
.47324 .90679 m .47511 .90842 L .47323 .9069 L 0 0 .542 r
F
.47491 .93283 m .47819 .93742 L .47444 .93297 L .239 .058 .423 r
F
.47504 .93316 m .47472 .93336 L .47431 .93135 L .334 .327 .702 r
F
.47431 .93135 m .47508 .93255 L .47444 .93168 L 0 0 .542 r
F
.47508 .93255 m .47519 .93323 L .47491 .93283 L F
.47508 .93255 m .47491 .93283 L .47444 .93168 L F
.46629 .89632 m .44986 .89341 L .46628 .89629 L 0 0 .446 r
F
.47292 .90612 m .46726 .89728 L .47511 .90842 L 0 .006 .567 r
F
.46674 .89696 m .46726 .89728 L .47292 .90612 L F
.40036 .83396 m .40006 .83402 L .40095 .83456 L .356 0 0 r
F
.47384 .81909 m .51665 .75399 L .50066 .77774 L .92 .842 .75 r
F
.47383 .81916 m .51665 .75399 L .47384 .81909 L F
.4673 .81849 m .4672 .81869 L .47405 .81776 L .892 .593 .474 r
F
.4673 .81849 m .47405 .81776 L .47405 .81773 L F
.4672 .81869 m .458 .83882 L .47375 .8196 L F
.47376 .8196 m .49024 .80604 L .54119 .72592 L .92 .842 .75 r
F
.47385 .81961 m .49024 .80604 L .47376 .8196 L F
.47383 .81916 m .54121 .72585 L .51665 .75399 L F
.47375 .8196 m .54121 .72585 L .47383 .81916 L F
.47201 .81796 m .47405 .81773 L .47525 .81545 L .953 .819 .675 r
F
.427 .82784 m .40307 .82986 L .40351 .8305 L .902 .603 .47 r
F
.44682 .80356 m .43811 .8079 L .42524 .831 L .61 .236 .308 r
F
.42557 .8283 m .42619 .82929 L .427 .82784 L .902 .603 .47 r
F
.46347 .79098 m .42498 .83304 L .46036 .80328 L .61 .236 .308 r
F
.42498 .83304 m .42472 .83517 L .46036 .80328 L F
.46347 .79098 m .46036 .80328 L .46745 .79695 L F
.45833 .80691 m .48163 .77293 L .46422 .79085 L .875 .71 .674 r
F
.45878 .80625 m .43462 .82631 L .45584 .8175 L .761 .416 .4 r
F
.45931 .80422 m .45611 .80709 L .45878 .80625 L F
.45611 .80709 m .43462 .82631 L .45878 .80625 L F
.49141 .75877 m .46839 .79996 L .47677 .79588 L .692 .491 .61 r
F
.46043 .80385 m .47602 .79625 L .49104 .75921 L .875 .71 .674 r
F
.45651 .82264 m .48244 .79313 L .46405 .80824 L .953 .819 .675 r
F
.46923 .81776 m .47525 .81545 L .47788 .81044 L F
.44335 .8854 m .44333 .88705 L .4434 .88675 L .847 .753 .239 r
F
.44333 .88705 m .44333 .88718 L .44344 .88673 L F
.44779 .88991 m .44307 .88773 L .4421 .88697 L 0 0 .542 r
F
.44327 .8883 m .4434 .88788 L .44393 .88884 L 0 0 0 r
F
.4434 .88788 m .44392 .88812 L .44393 .88884 L F
.44213 .89204 m .44327 .8883 L .44393 .88884 L F
.44213 .89204 m .44425 .88827 L .4433 .88729 L F
.44425 .88827 m .44353 .88706 L .4433 .88729 L F
.44213 .89204 m .44229 .88751 L .4423 .88751 L F
.44275 .88828 m .44256 .88797 L .44213 .89204 L .234 0 .201 r
F
.44213 .89204 m .4423 .88751 L .44327 .8883 L 0 0 0 r
F
.4421 .88697 m .44243 .88743 L .44232 .88749 L .239 .058 .423 r
F
.4421 .88697 m .44231 .88755 L .44208 .88705 L F
.441 .88534 m .44034 .88685 L .44008 .88684 L 0 0 0 r
F
.4421 .88697 m .44137 .88996 L .44034 .88685 L .239 .058 .423 r
F
.4393 .88256 m .44213 .89204 L .44333 .88718 L .847 .753 .239 r
F
.45624 .89118 m .44213 .89204 L .4393 .88256 L 0 0 .446 r
F
.44986 .89341 m .44213 .89204 L .45624 .89118 L F
.47292 .90612 m .47511 .90842 L .47324 .90679 L 0 .006 .567 r
F
.46937 .91918 m .45836 .92166 L .46526 .89979 L .334 .327 .702 r
F
.47508 .93255 m .47819 .93742 L .47519 .93323 L 0 0 .542 r
F
.45778 .93003 m .45369 .9207 L .45778 .92999 L .239 .058 .423 r
F
.46152 .9303 m .44412 .92314 L .44377 .92034 L .417 .229 .516 r
F
.46046 .93007 m .4626 .93053 L .46714 .94577 L .239 .058 .423 r
F
.46101 .93187 m .44412 .92314 L .46152 .9303 L .417 .229 .516 r
F
.47426 .93303 m .45791 .92827 L .45838 .92168 L F
.46152 .9303 m .45791 .92827 L .47426 .93303 L F
.50106 .82357 m .51089 .81888 L .49572 .82522 L .88 .959 .848 r
F
.50106 .82357 m .49572 .82522 L .49472 .82605 L F
.50062 .81265 m .56757 .76059 L .5658 .76078 L F
.48286 .82678 m .49862 .81447 L .50062 .81265 L F
.49862 .81447 m .56757 .76059 L .50062 .81265 L F
.48247 .82938 m .57364 .75585 L .48286 .82678 L F
.56873 .7595 m .59308 .75789 L .61365 .73979 L .857 .826 .816 r
F
.56582 .76078 m .56779 .76057 L .56873 .7595 L F
.56779 .76057 m .59308 .75789 L .56873 .7595 L F
.54067 .78949 m .54191 .78827 L .55725 .7726 L .88 .959 .848 r
F
.54067 .78949 m .55725 .7726 L .55742 .7724 L F
.58444 .73387 m .57754 .74348 L .58534 .73405 L .857 .826 .816 r
F
.57754 .74348 m .57899 .74173 L .57991 .73928 L .814 .762 .804 r
F
.58444 .73387 m .58033 .73853 L .58021 .73876 L .857 .826 .816 r
F
.5147 .81513 m .51089 .81888 L .51158 .81876 L F
.51108 .81869 m .54067 .78949 L .55742 .7724 L .88 .959 .848 r
F
.51108 .81869 m .55742 .7724 L .5593 .77026 L F
.58534 .73405 m .56582 .76078 L .56873 .7595 L .857 .826 .816 r
F
.59018 .73503 m .56873 .7595 L .61365 .73979 L F
.58534 .73405 m .56873 .7595 L .59018 .73503 L F
.56779 .76057 m .52273 .81979 L .59308 .75789 L F
.55688 .77301 m .52273 .81979 L .56779 .76057 L F
.58444 .73387 m .54555 .77404 L .55431 .76812 L F
.44359 .91908 m .44233 .89243 L .44295 .89357 L .234 0 .201 r
F
.45836 .92166 m .44359 .91908 L .44295 .89357 L F
.44034 .88685 m .44137 .88996 L .44008 .88684 L .239 .058 .423 r
F
.44201 .90412 m .44184 .89935 L .44154 .89996 L .602 .166 .184 r
F
.44154 .89996 m .44184 .89935 L .44172 .89631 L F
.44359 .91908 m .44154 .89996 L .44172 .89631 L .234 0 .201 r
F
.44008 .88684 m .44153 .89094 L .44172 .89631 L .571 .188 .277 r
F
.44008 .88684 m .44172 .89631 L .44138 .8985 L F
.44359 .91908 m .44061 .91856 L .44154 .89996 L .234 0 .201 r
F
.44139 .89002 m .4415 .89038 L .44008 .88684 L .239 .058 .423 r
F
.45791 .92827 m .44377 .92034 L .45838 .92168 L .417 .229 .516 r
F
.44377 .92034 m .44061 .91856 L .44359 .91908 L F
.44377 .92034 m .44359 .91908 L .45838 .92168 L F
.45838 .92168 m .44359 .91908 L .45836 .92166 L F
.44359 .91908 m .44061 .91856 L .44359 .91908 L F
.44359 .91908 m .44359 .91908 L .45836 .92166 L F
.44008 .88684 m .44021 .88717 L .44022 .88723 L .571 .188 .277 r
F
.45994 .93523 m .46455 .94773 L .461 .93889 L .239 .058 .423 r
F
.44377 .92034 m .44412 .92314 L .44061 .91856 L .417 .229 .516 r
F
.43243 .90757 m .43371 .9092 L .42996 .91756 L .727 .29 .212 r
F
.44061 .91856 m .43647 .91273 L .43647 .91272 L .602 .166 .184 r
F
.4189 .89628 m .42996 .91756 L .4171 .8981 L .603 .144 .136 r
F
.41762 .89771 m .4171 .8981 L .4169 .89805 L .105 0 0 r
F
.4831 .82511 m .47963 .8301 L .48251 .82911 L 0 0 0 r
F
.47963 .8301 m .48228 .82943 L .48251 .82911 L F
.48328 .8239 m .53053 .777 L .49182 .81291 L .88 .959 .848 r
F
.48286 .82678 m .53053 .777 L .48328 .8239 L F
.48248 .82477 m .48328 .8239 L .49964 .80284 L .793 .955 .624 r
F
.54121 .72585 m .54109 .72594 L .51665 .75399 L .92 .842 .75 r
F
.50066 .77774 m .51665 .75399 L .51438 .75659 L F
.5175 .74941 m .51033 .76337 L .53307 .73514 L .896 .772 .717 r
F
.53307 .73514 m .53878 .7286 L .51763 .7487 L .812 .687 .726 r
F
.53307 .73514 m .51763 .7487 L .5175 .74941 L F
.51835 .74481 m .48814 .79634 L .5175 .74941 L .896 .772 .717 r
F
.48814 .79634 m .49466 .78665 L .5175 .74941 L F
.5175 .74941 m .49466 .78665 L .51033 .76337 L F
.51763 .7487 m .53878 .7286 L .51835 .74481 L .812 .687 .726 r
F
.499 .80221 m .51046 .78864 L .49122 .80561 L .793 .955 .624 r
F
.50475 .79368 m .50783 .79245 L .52741 .76848 L .92 .85 .758 r
F
.53589 .74128 m .49177 .80513 L .50475 .79368 L F
.53984 .72889 m .53977 .729 L .53984 .72894 L .896 .772 .717 r
F
.53865 .73573 m .53521 .75919 L .53887 .73528 L .814 .762 .804 r
F
.52741 .76848 m .50212 .79944 L .52524 .77543 L .92 .85 .758 r
F
.50212 .79944 m .5006 .80152 L .52524 .77543 L F
.53589 .74128 m .51554 .77551 L .52741 .76848 L F
.49182 .81291 m .50443 .80122 L .49964 .80284 L .88 .959 .848 r
F
.53073 .77631 m .52982 .77766 L .58092 .73751 L .897 .854 .792 r
F
.52982 .77766 m .54555 .77404 L .58092 .73751 L F
.53073 .77631 m .52676 .7805 L .52982 .77766 L F
.52741 .76848 m .52524 .77543 L .53401 .76457 L .92 .85 .758 r
F
.48913 .78728 m .48064 .80638 L .49575 .78335 L .808 .634 .665 r
F
.48064 .80638 m .48814 .79634 L .49575 .78335 L F
.50673 .74774 m .48054 .79354 L .48913 .78728 L F
.48341 .79203 m .48483 .79042 L .47969 .79416 L .953 .819 .675 r
F
.40119 .82794 m .41225 .82803 L .43259 .80992 L .846 .586 .546 r
F
.40307 .82986 m .41225 .82803 L .40119 .82794 L F
.40119 .82794 m .40169 .82766 L .40053 .827 L F
.39914 .82585 m .39915 .82551 L .39901 .82555 L F
.39657 .82283 m .39913 .82621 L .39916 .82532 L .149 0 0 r
F
.39914 .82585 m .41102 .8223 L .39915 .82551 L .846 .586 .546 r
F
.35312 .80319 m .37586 .82317 L .37267 .82082 L 0 .082 .565 r
F
.34311 .79417 m .35027 .80049 L .35312 .80319 L F
.39971 .82075 m .39816 .82076 L .39926 .82343 L .363 0 .14 r
F
.39603 .82231 m .39916 .82532 L .40054 .82326 L .764 .294 .128 r
F
.4042 .82292 m .40407 .82294 L .39915 .82548 L .846 .586 .546 r
F
.4042 .82292 m .39915 .82548 L .39915 .82548 L F
.396 .82228 m .40054 .82326 L .396 .82228 L .764 .294 .128 r
F
.39304 .81943 m .40049 .82074 L .39564 .8201 L F
.39304 .81943 m .40054 .82326 L .40049 .82074 L F
.396 .82228 m .40054 .82326 L .39304 .81943 L F
.39603 .82231 m .40054 .82326 L .396 .82228 L F
.26001 .75739 m .32877 .80809 L .32883 .80853 L 0 .243 .707 r
F
.26001 .75739 m .32883 .80853 L .3236 .80703 L F
.26001 .75739 m .3236 .80703 L .25718 .76715 L F
.25718 .76715 m .26459 .77171 L .27024 .77499 L .434 0 0 r
F
.3236 .80703 m .32164 .80676 L .25718 .76715 L 0 .243 .707 r
F
.38868 .81261 m .40046 .81914 L .39509 .81274 L .736 .315 .248 r
F
.39442 .81848 m .40046 .81914 L .38868 .81261 L F
.40335 .80886 m .39817 .80927 L .39881 .80911 L F
.39837 .80903 m .39828 .80914 L .39675 .80922 L F
.39837 .80903 m .39675 .80922 L .39481 .80923 L F
.39215 .80925 m .40046 .81914 L .40335 .80886 L F
.42417 .79093 m .40081 .82323 L .40261 .82307 L .363 0 .14 r
F
.47021 .74657 m .4646 .77994 L .46461 .78094 L .275 .088 .437 r
F
.44198 .78884 m .45543 .78749 L .46697 .77188 L .789 .547 .571 r
F
.46718 .76854 m .46697 .77188 L .47276 .76405 L F
.44198 .78884 m .46697 .77188 L .46718 .76854 L F
.47692 .74069 m .47079 .74606 L .46639 .77513 L .275 .088 .437 r
F
.46561 .78022 m .4663 .78189 L .46735 .77898 L .789 .547 .571 r
F
.45543 .78749 m .46528 .78242 L .46561 .78022 L F
.46528 .78242 m .4663 .78189 L .46561 .78022 L F
.46639 .77513 m .46461 .78094 L .46669 .77632 L .275 .088 .437 r
F
.45543 .78749 m .46735 .77898 L .46592 .77329 L .789 .547 .571 r
F
.47276 .76405 m .4789 .73914 L .47858 .73672 L .701 .531 .655 r
F
.4789 .73914 m .48305 .72234 L .48168 .72673 L F
.4789 .73914 m .48168 .72673 L .47858 .73672 L F
.4789 .73914 m .49993 .70516 L .48818 .70155 L F
.48236 .72289 m .46639 .77513 L .49539 .7125 L .275 .088 .437 r
F
.46639 .77513 m .46669 .77632 L .49539 .7125 L F
.47125 .77328 m .46669 .77632 L .46607 .78591 L .543 .335 .549 r
F
.49777 .70866 m .47427 .75981 L .47125 .77328 L F
.47427 .75981 m .46669 .77632 L .47125 .77328 L F
.46381 .78966 m .50421 .70224 L .46455 .78673 L .789 .613 .662 r
F
.50421 .70224 m .49965 .71181 L .46455 .78673 L F
.45543 .78749 m .40946 .82026 L .4622 .784 L .61 .236 .308 r
F
.40946 .82026 m .41026 .8199 L .4622 .784 L F
.41102 .8223 m .43259 .80992 L .4042 .82292 L .846 .586 .546 r
F
.43259 .80992 m .40946 .82026 L .4042 .82292 L F
.40332 .823 m .40278 .82305 L .3996 .82467 L F
.39901 .82555 m .40407 .82294 L .3996 .82467 L F
.40407 .82294 m .40332 .823 L .3996 .82467 L F
.40295 .82304 m .42266 .79321 L .40292 .82304 L .363 0 .14 r
F
.46158 .76484 m .40336 .823 L .4042 .82292 L F
.3996 .82467 m .40278 .82305 L .40054 .82326 L .846 .586 .546 r
F
.46446 .76192 m .45785 .76668 L .46158 .76484 L .363 0 .14 r
F
.43032 .78808 m .46459 .76512 L .46785 .74814 L .726 .492 .572 r
F
.46459 .76512 m .46741 .76323 L .46785 .74814 L F
.4734 .72316 m .47248 .72402 L .46889 .7427 L 0 0 .088 r
F
.47248 .72402 m .47201 .72446 L .46889 .7427 L F
.47801 .70318 m .47157 .72487 L .4734 .72316 L F
.46778 .73025 m .47201 .72446 L .46828 .72946 L .647 .417 .556 r
F
.47201 .72446 m .4719 .72456 L .46828 .72946 L F
.44455 .76189 m .43371 .77227 L .44439 .76215 L 0 0 0 r
F
.44389 .76299 m .46778 .73025 L .44497 .76118 L .647 .417 .556 r
F
.46778 .73025 m .46828 .72946 L .44497 .76118 L F
.47856 .69704 m .47157 .72487 L .47801 .70318 L 0 0 .088 r
F
.49247 .65248 m .4944 .66188 L .49693 .66608 L .175 .215 .665 r
F
.4944 .66188 m .49653 .66712 L .49693 .66608 L F
.49693 .66608 m .49653 .66712 L .49068 .68979 L .701 .531 .655 r
F
.49668 .66711 m .49823 .67002 L .49693 .66608 L F
.49965 .71181 m .50794 .69413 L .49349 .72455 L .789 .613 .662 r
F
.50794 .69413 m .50789 .69418 L .49349 .72455 L F
.49965 .71181 m .49349 .72455 L .49157 .72879 L F
.48476 .71505 m .48236 .72289 L .48319 .72175 L .275 .088 .437 r
F
.49539 .7125 m .46669 .77632 L .49777 .70866 L .543 .335 .549 r
F
.46455 .78673 m .49965 .71181 L .46634 .7818 L .789 .613 .662 r
F
.46381 .78966 m .47089 .78082 L .48458 .74853 L F
.47354 .7686 m .48458 .74853 L .50421 .70224 L F
.46381 .78966 m .48458 .74853 L .47354 .7686 L F
.50772 .70647 m .4734 .78013 L .50907 .71248 L .543 .335 .549 r
F
.48458 .74853 m .4734 .78013 L .50772 .70647 L F
.4734 .78013 m .47911 .77328 L .50907 .71248 L F
.48163 .77293 m .49104 .75921 L .47911 .77328 L .875 .71 .674 r
F
.48163 .77293 m .47911 .77328 L .4734 .78013 L F
.50907 .7128 m .47911 .77328 L .48296 .76873 L .692 .491 .61 r
F
.50907 .71248 m .47911 .77328 L .50907 .7128 L F
.50911 .7139 m .48296 .76873 L .49141 .75877 L F
.50907 .7128 m .48296 .76873 L .50911 .7139 L F
.50911 .7139 m .47677 .79588 L .50932 .73705 L F
.50918 .72214 m .50925 .72155 L .50912 .71526 L .719 .599 .722 r
F
.47677 .79588 m .47944 .79433 L .51046 .73579 L .692 .491 .61 r
F
.47677 .79588 m .51046 .73579 L .51087 .73425 L F
.51378 .72337 m .51386 .72309 L .51384 .72311 L .812 .687 .726 r
F
.50673 .74774 m .5024 .75746 L .50471 .75472 L .808 .634 .665 r
F
.53878 .7286 m .54142 .72557 L .50437 .7559 L .812 .687 .726 r
F
.5024 .75746 m .48913 .78728 L .51541 .74714 L .808 .634 .665 r
F
.47677 .79588 m .47602 .79625 L .4758 .79645 L .953 .819 .675 r
F
.48163 .77293 m .47302 .78046 L .46422 .79085 L .875 .71 .674 r
F
.43462 .82631 m .44469 .82467 L .45584 .8175 L .761 .416 .4 r
F
.4622 .784 m .41026 .8199 L .44682 .80356 L .61 .236 .308 r
F
.41046 .81659 m .4042 .82292 L .44244 .78879 L .363 0 .14 r
F
.4042 .82292 m .4052 .82242 L .44244 .78879 L F
.41046 .81659 m .44244 .78879 L .44198 .78884 L F
.48244 .79313 m .48341 .79203 L .48158 .79355 L .953 .819 .675 r
F
.46447 .78664 m .46455 .78673 L .46461 .78656 L .789 .547 .571 r
F
.45486 .77164 m .41046 .81659 L .45824 .77453 L .363 0 .14 r
F
.46741 .76835 m .46651 .76856 L .45824 .77453 L .789 .547 .571 r
F
.46741 .76835 m .45824 .77453 L .45599 .77651 L F
.44198 .78884 m .46741 .76835 L .45599 .77651 L F
.47072 .7452 m .47021 .74657 L .47692 .74069 L .275 .088 .437 r
F
.46785 .74814 m .46997 .74588 L .46767 .748 L .726 .492 .572 r
F
.46889 .7427 m .46767 .748 L .46997 .74588 L 0 0 .088 r
F
.46785 .74814 m .46751 .74786 L .45268 .76277 L .726 .492 .572 r
F
.47102 .71276 m .46965 .72456 L .47669 .70448 L .981 .833 .437 r
F
.46965 .72456 m .47157 .72487 L .47669 .70448 L F
.44439 .76215 m .43371 .77227 L .44389 .76299 L 0 0 0 r
F
.44711 .7453 m .43674 .76438 L .44145 .76062 L .846 .987 .712 r
F
.4734 .72316 m .46889 .7427 L .48147 .7124 L 0 0 .088 r
F
.44497 .76118 m .44844 .75646 L .44524 .76073 L .647 .417 .556 r
F
.44455 .76189 m .4379 .76655 L .43371 .77227 L 0 0 0 r
F
.44625 .75902 m .4379 .76655 L .44455 .76189 L F
.448 .75924 m .43371 .77227 L .43065 .77646 L F
.44712 .75857 m .46117 .74881 L .45676 .74536 L .647 .417 .556 r
F
.42266 .79321 m .42417 .79093 L .42266 .79322 L .363 0 .14 r
F
.42402 .78304 m .41661 .78657 L .4095 .79533 L 0 0 0 r
F
.43065 .77646 m .41666 .78613 L .42402 .78304 L F
.41666 .78613 m .41605 .78684 L .42402 .78304 L F
.47701 .67398 m .47803 .6891 L .48079 .68103 L .981 .833 .437 r
F
.47158 .70796 m .47102 .71276 L .47378 .70394 L F
.45808 .59118 m .47824 .63239 L .46845 .59823 L .888 .491 .049 r
F
.47422 .65469 m .47057 .62578 L .47167 .64345 L .07 .081 .562 r
F
.47057 .62578 m .47009 .62667 L .47183 .64603 L F
.47151 .64276 m .47161 .6454 L .47199 .64485 L .958 .74 .565 r
F
.43554 .57195 m .43361 .57007 L .43556 .57196 L 0 .222 .744 r
F
.44394 .58017 m .43403 .57052 L .44462 .58105 L F
.43403 .57052 m .43581 .57242 L .44462 .58105 L F
.43022 .56646 m .43733 .57403 L .43684 .57365 L .83 .438 .308 r
F
.44079 .57736 m .43581 .57242 L .43733 .57403 L 0 .222 .744 r
F
.43947 .57599 m .43581 .57242 L .44079 .57736 L F
.43733 .57403 m .4375 .57421 L .43684 .57365 L .83 .438 .308 r
F
.43022 .56646 m .44751 .58525 L .44565 .58237 L F
.44462 .58105 m .43947 .57599 L .44079 .57736 L 0 .222 .744 r
F
.47161 .6454 m .47336 .69232 L .47584 .67123 L .958 .74 .565 r
F
.3936 .79378 m .4111 .78823 L .39354 .79356 L .502 .096 .203 r
F
.42014 .77764 m .41202 .78738 L .43203 .77185 L .846 .987 .712 r
F
.44711 .7453 m .42014 .77764 L .43674 .76438 L F
.39722 .78631 m .38587 .78952 L .38804 .7905 L .571 .935 .92 r
F
.33221 .53369 m .33779 .53429 L .34254 .53503 L .269 0 0 r
F
.33221 .53369 m .35144 .5364 L .33469 .53199 L F
.37727 .54037 m .34601 .53879 L .39083 .54246 L .264 .671 .967 r
F
.34349 .54272 m .34336 .54263 L .34293 .54265 L .317 .806 .849 r
F
.32526 .54356 m .34336 .54263 L .35272 .54246 L .024 0 0 r
F
.34336 .54263 m .33725 .53835 L .33915 .5427 L .264 .671 .967 r
F
.32526 .54356 m .35272 .54246 L .33221 .53369 L .024 0 0 r
F
.40124 .54408 m .35702 .54305 L .39923 .54479 L .164 .683 .886 r
F
.36504 .54273 m .36747 .54308 L .39406 .54314 L .264 .671 .967 r
F
.36504 .54273 m .39406 .54314 L .39122 .54302 L F
.39923 .54479 m .38657 .54819 L .3894 .54786 L .164 .683 .886 r
F
.38657 .54819 m .3962 .54759 L .39736 .54702 L F
.3962 .54759 m .39761 .54751 L .39736 .54702 L F
.38657 .54819 m .37768 .55058 L .39761 .54751 L F
.39471 .54839 m .38824 .5494 L .39183 .54891 L .124 .673 .727 r
F
.38824 .5494 m .38659 .54965 L .39232 .54887 L F
.36504 .54273 m .34383 .54296 L .36747 .54308 L .264 .671 .967 r
F
.34383 .54296 m .3459 .54302 L .36747 .54308 L F
.35702 .54305 m .3459 .54302 L .36275 .54514 L .164 .683 .886 r
F
.3229 .55573 m .36599 .54555 L .32526 .54356 L .317 .806 .849 r
F
.20267 .72012 m .21436 .73354 L .21785 .73733 L .585 .101 0 r
F
.21436 .73354 m .26156 .78774 L .21785 .73733 L F
.3229 .55573 m .36474 .54764 L .36599 .54555 L .317 .806 .849 r
F
.32548 .56989 m .37323 .54896 L .3229 .55573 L .615 .938 .956 r
F
.37323 .54896 m .36474 .54764 L .3229 .55573 L F
.37039 .5502 m .3759 .54993 L .37323 .54896 L F
.37768 .55058 m .37592 .55105 L .37859 .55063 L .164 .683 .886 r
F
.36565 .55228 m .37859 .55063 L .37039 .5502 L .615 .938 .956 r
F
.32548 .56989 m .38979 .55037 L .38907 .54929 L F
.38685 .54962 m .38659 .54965 L .38677 .54963 L .124 .673 .727 r
F
.32548 .56989 m .38907 .54929 L .36565 .55228 L .615 .938 .956 r
F
.50722 .52231 m .50772 .51778 L .50863 .52153 L .543 .31 .512 r
F
.51059 .52157 m .51098 .52036 L .51142 .52213 L .21 0 .352 r
F
.51098 .52036 m .51108 .52021 L .51142 .52213 L F
.53419 .5123 m .5428 .51206 L .53666 .51403 L .285 .208 .591 r
F
.54658 .51196 m .52778 .50586 L .54675 .4919 L .474 .357 .64 r
F
.52962 .51243 m .52778 .50586 L .54658 .51196 L F
.5082 .51974 m .50772 .51778 L .52694 .51598 L .494 .321 .575 r
F
.51184 .51901 m .53666 .51403 L .51142 .52213 L .285 .208 .591 r
F
.51611 .48954 m .51973 .48342 L .51809 .48811 L 0 0 0 r
F
.51595 .48853 m .51768 .48993 L .5146 .49852 L .285 .208 .591 r
F
.50723 .49893 m .51595 .48853 L .51239 .51497 L .21 0 .352 r
F
.50772 .51778 m .52114 .48088 L .52778 .50586 L 0 0 0 r
F
.53041 .46983 m .53298 .46576 L .52801 .49832 L .285 .208 .591 r
F
.52114 .48088 m .52888 .48806 L .52778 .50586 L 0 0 0 r
F
.52778 .50586 m .52888 .48806 L .53059 .46953 L 0 0 .006 r
F
.52888 .48806 m .53047 .46912 L .53059 .46953 L F
.53011 .46795 m .53098 .45384 L .53059 .46953 L F
.53557 .43101 m .53331 .43438 L .53257 .41465 L 0 0 .337 r
F
.53381 .45844 m .5357 .4321 L .53456 .4462 L .716 .629 .065 r
F
.55234 .479 m .56369 .42803 L .53381 .45844 L .917 .885 .786 r
F
.56369 .42803 m .53625 .42532 L .53381 .45844 L .95 .803 .662 r
F
.54675 .4919 m .53489 .44118 L .53557 .43101 L 0 0 .337 r
F
.53489 .44118 m .53331 .43438 L .53557 .43101 L F
.53366 .45976 m .53456 .4462 L .53298 .46576 L .716 .629 .065 r
F
.53381 .45844 m .53456 .4462 L .53366 .45976 L F
.51809 .48811 m .51973 .48342 L .51975 .48453 L 0 0 0 r
F
.51809 .48811 m .51975 .48453 L .51942 .48538 L F
.51973 .48342 m .52118 .47986 L .51975 .48471 L F
.51975 .48471 m .52118 .47986 L .52423 .47238 L F
.51595 .48853 m .52059 .48232 L .51768 .48993 L .285 .208 .591 r
F
.51942 .48538 m .51975 .48453 L .51975 .48471 L 0 0 0 r
F
.52138 .47938 m .52059 .48232 L .51595 .48853 L .716 .629 .065 r
F
.49859 .52217 m .50691 .49794 L .50772 .51778 L 0 0 0 r
F
.50772 .51778 m .51062 .50948 L .51975 .48471 L F
.51062 .50948 m .51924 .48575 L .51975 .48471 L F
.50691 .49794 m .50874 .50362 L .50772 .51778 L F
.34498 .60251 m .42178 .57092 L .40207 .55975 L .808 .85 .881 r
F
0 g
.41316 .57036 m
.43281 .56968 L
s
.40343 .59446 m
.41949 .60638 L
s
.36069 .61998 m .42178 .57092 L .34498 .60251 L .807 .772 .821 r
F
0 g
.38101 .57784 m
.40343 .59446 L
s
.39423 .57102 m
.41316 .57036 L
s
.39227 .57109 m
.39423 .57102 L
s
.53692 .48168 m
.54348 .47789 L
s
.54411 .47752 m
.55136 .47333 L
s
.55136 .47333 m
.57613 .45898 L
s
.57613 .45898 m
.57756 .45816 L
s
.57756 .45816 m
.58041 .45651 L
s
.58785 .44718 m
.59173 .43973 L
s
.58775 .45258 m
.58868 .45212 L
s
.53723 .48291 m
.54373 .47895 L
s
.54439 .47855 m
.54474 .47834 L
s
.54431 .47859 m
.54439 .47855 L
s
.54474 .47834 m
.56965 .46317 L
s
.56965 .46317 m
.57627 .45914 L
s
.27159 .63797 m .36069 .61998 L .34498 .60251 L .856 .772 .768 r
F
.27929 .65441 m .36069 .61998 L .27159 .63797 L .846 .718 .723 r
F
0 g
.35406 .64134 m
.35415 .64135 L
s
.35415 .64135 m
.38888 .64416 L
s
.38888 .64416 m
.46028 .64994 L
s
.46028 .64994 m
.47181 .65087 L
s
.68624 .54515 m .71703 .42158 L .7004 .42403 L .275 .239 .636 r
F
.69962 .55456 m .71703 .42158 L .68624 .54515 L 0 0 .335 r
F
0 g
.69896 .50992 m
.69927 .50998 L
s
.67246 .50442 m
.69896 .50992 L
s
.64099 .66183 m
.64297 .66034 L
s
.62674 .67256 m
.62699 .67237 L
s
.62634 .67286 m
.62674 .67256 L
s
.62739 .67207 m
.64099 .66183 L
s
.62699 .67237 m
.62739 .67207 L
s
.64297 .66034 m
.64316 .66019 L
s
.6444 .65926 m
.65278 .65295 L
s
.64316 .66019 m
.6444 .65926 L
s
.30638 .644 m
.3088 .64372 L
s
.65278 .65295 m
.65286 .65039 L
s
.65286 .65039 m
.65291 .6491 L
s
.65291 .6491 m
.65317 .64158 L
s
.65317 .64158 m
.65321 .64034 L
s
.65321 .64034 m
.65328 .63823 L
s
.66129 .6064 m
.66131 .60637 L
s
.66131 .60637 m
.66151 .60608 L
s
.63913 .65783 m
.6446 .65588 L
s
.6384 .65809 m
.63913 .65783 L
s
.63761 .65838 m
.6384 .65809 L
s
.64883 .65436 m
.65278 .65295 L
s
.64706 .65499 m
.64883 .65436 L
s
.64474 .65583 m
.64706 .65499 L
s
.6446 .65588 m
.64474 .65583 L
s
.67656 .57927 m
.6766 .57921 L
s
.7004 .42403 m .65781 .33192 L .67266 .43358 L .384 .446 .801 r
F
.67266 .43358 m .65781 .33192 L .63291 .36204 L .602 .583 .804 r
F
0 g
.67182 .46036 m
.6799 .42321 L
s
.34723 .74043 m
.38192 .75 L
s
.38192 .75 m
.38322 .75035 L
s
.38322 .75035 m
.38325 .75036 L
s
.33116 .75562 m
.37042 .75832 L
s
.59936 .39544 m .55357 .38378 L .56369 .42803 L .82 .702 .735 r
F
0 g
.5926 .45019 m
.67702 .40862 L
s
.58868 .45212 m
.5926 .45019 L
s
.58694 .48689 m
.67778 .41035 L
s
.57814 .4943 m
.58694 .48689 L
s
.59936 .39544 m .57603 .33825 L .55357 .38378 L .82 .702 .735 r
F
0 g
.59173 .43973 m
.60063 .42266 L
s
.63291 .36204 m .57603 .33825 L .59936 .39544 L .72 .645 .774 r
F
.34498 .60251 m .40207 .55975 L .33298 .58565 L .808 .85 .881 r
F
.26518 .6215 m .34498 .60251 L .33298 .58565 L .858 .827 .816 r
F
.27159 .63797 m .34498 .60251 L .26518 .6215 L .856 .772 .768 r
F
0 g
.31718 .60645 m
.32756 .62209 L
s
.53331 .46712 m
.5354 .46448 L
s
.5354 .46448 m
.53922 .45967 L
s
.54053 .45801 m
.55793 .43605 L
s
.57837 .41025 m
.58341 .40388 L
s
.58341 .40388 m
.58391 .40324 L
s
.58709 .3872 m
.58818 .36687 L
s
.59008 .39562 m
.59013 .39555 L
s
.58928 .39659 m
.59008 .39562 L
s
.49946 .50243 m
.50483 .4961 L
s
.50483 .4961 m
.52256 .47524 L
s
.52256 .47524 m
.52268 .4751 L
s
.53352 .46234 m
.53665 .45866 L
s
.53334 .46255 m
.53352 .46234 L
s
.53665 .45866 m
.53848 .4565 L
s
.57246 .41651 m
.57961 .4081 L
s
.57961 .4081 m
.58064 .40688 L
s
.69962 .55456 m .72232 .42764 L .71703 .42158 L 0 0 .335 r
F
.70283 .56733 m .72232 .42764 L .69962 .55456 L .88 .814 .334 r
F
0 g
.6322 .56628 m
.70466 .52073 L
s
.6766 .57921 m
.70319 .53506 L
s
.56369 .42803 m .55357 .38378 L .53625 .42532 L .95 .803 .662 r
F
0 g
.55784 .43372 m
.57246 .41651 L
s
.53994 .45479 m
.55784 .43372 L
s
.55793 .43605 m
.57837 .41025 L
s
.33298 .58565 m .40207 .55975 L .38979 .55037 L .764 .922 .941 r
F
0 g
.39188 .5634 m
.39835 .56056 L
s
.39835 .56056 m
.40243 .55876 L
s
.52489 .50046 m
.52677 .49968 L
s
.5147 .47534 m
.53098 .45384 L
s
.50661 .48603 m
.5147 .47534 L
s
.49163 .50583 m
.50661 .48603 L
s
.48686 .51213 m
.49163 .50583 L
s
.47321 .52059 m
.47442 .52027 L
s
.63291 .36204 m .59281 .2914 L .57603 .33825 L .72 .645 .774 r
F
0 g
.60063 .42266 m
.60248 .41911 L
s
.65781 .33192 m .59281 .2914 L .63291 .36204 L .603 .603 .825 r
F
.21266 .68526 m .31246 .71583 L .30487 .7015 L .916 .639 .5 r
F
.21392 .69345 m .31246 .71583 L .21266 .68526 L .909 .613 .472 r
F
.21392 .69345 m .31883 .72923 L .31246 .71583 L F
0 g
.50659 .49642 m
.52232 .47602 L
s
.21125 .67654 m .30487 .7015 L .29648 .68638 L .924 .669 .532 r
F
.21266 .68526 m .30487 .7015 L .21125 .67654 L .916 .639 .5 r
F
0 g
.30331 .68871 m
.3358 .68787 L
s
.29725 .68887 m
.30331 .68871 L
s
.29032 .68905 m
.29725 .68887 L
s
.21494 .70105 m .31883 .72923 L .21392 .69345 L .902 .59 .446 r
F
0 g
.29787 .6958 m
.29984 .69635 L
s
.28961 .69348 m
.29205 .69417 L
s
.29205 .69417 m
.29787 .6958 L
s
.21494 .70105 m .32367 .74159 L .31883 .72923 L .902 .59 .446 r
F
0 g
.49408 .50694 m
.49461 .50656 L
s
.49193 .50843 m
.49408 .50694 L
s
.49034 .50955 m
.49193 .50843 L
s
.48723 .51172 m
.49034 .50955 L
s
.48684 .51199 m
.48723 .51172 L
s
.48358 .51427 m
.48684 .51199 L
s
.48348 .51434 m
.48358 .51427 L
s
.21125 .67654 m .29648 .68638 L .20979 .66739 L .924 .669 .532 r
F
.20979 .66739 m .29648 .68638 L .28778 .67062 L .933 .703 .567 r
F
.7004 .42403 m .67087 .31028 L .65781 .33192 L .384 .446 .801 r
F
.71703 .42158 m .67087 .31028 L .7004 .42403 L 0 0 .552 r
F
.21566 .708 m .32367 .74159 L .21494 .70105 L .896 .571 .423 r
F
.21566 .708 m .3268 .75283 L .32367 .74159 L F
0 g
.31273 .72541 m
.35893 .72672 L
s
.65638 .64504 m
.66051 .636 L
s
.66051 .636 m
.66362 .62918 L
s
.66624 .62344 m
.66887 .61768 L
s
.66887 .61768 m
.66932 .61669 L
s
.66544 .6252 m
.66624 .62344 L
s
.66362 .62918 m
.66544 .6252 L
s
.65631 .64519 m
.65638 .64504 L
s
.65278 .65295 m
.65631 .64519 L
s
.64964 .64554 m
.64983 .64598 L
s
.6504 .64733 m
.65196 .65102 L
s
.64983 .64598 m
.6504 .64733 L
s
.64858 .64303 m
.64956 .64536 L
s
.64857 .64301 m
.64858 .64303 L
s
.64956 .64536 m
.64964 .64554 L
s
.65196 .65102 m
.65197 .65106 L
s
.65197 .65106 m
.65278 .65295 L
s
.62396 .67268 m
.62448 .67233 L
s
.62111 .67464 m
.62396 .67268 L
s
.61708 .67739 m
.62111 .67464 L
s
.62448 .67233 m
.63552 .66476 L
s
.63552 .66476 m
.63676 .66392 L
s
.63676 .66392 m
.6387 .66259 L
s
.6387 .66259 m
.64428 .65877 L
s
.64428 .65877 m
.64941 .65525 L
s
.64941 .65525 m
.64948 .6552 L
s
.64948 .6552 m
.65278 .65295 L
s
.52049 .48015 m
.52093 .47898 L
s
.53496 .4422 m
.53507 .44192 L
s
.53676 .43749 m
.54116 .42594 L
s
.54135 .42546 m
.54281 .42163 L
s
.53095 .45272 m
.53107 .45241 L
s
.52093 .47898 m
.53095 .45272 L
s
.53107 .45241 m
.53119 .4521 L
s
.53213 .44963 m
.53486 .44246 L
s
.54281 .42163 m
.56066 .37483 L
s
.56066 .37483 m
.56525 .36278 L
s
.51887 .4844 m
.52049 .48015 L
s
.53867 .4479 m
.54176 .43824 L
s
.54176 .43824 m
.5547 .39765 L
s
.5547 .39765 m
.5551 .39639 L
s
.5551 .39639 m
.56446 .36702 L
s
.56446 .36702 m
.56745 .35766 L
s
.56895 .35259 m
.56975 .34911 L
s
.55357 .38378 m
.57603 .33825 L
s
.20839 .65787 m .28778 .67062 L .27929 .65441 L .94 .74 .605 r
F
.20979 .66739 m .28778 .67062 L .20839 .65787 L .933 .703 .567 r
F
0 g
.28274 .65713 m
.35508 .67893 L
s
.33298 .58565 m .38979 .55037 L .32548 .56989 L .764 .922 .941 r
F
0 g
.34081 .58232 m
.35257 .57844 L
s
.33127 .56026 m
.33209 .56049 L
s
.3437 .5637 m
.34875 .5651 L
s
.36224 .54788 m
.36387 .55155 L
s
.36462 .55326 m
.36955 .56439 L
s
.36955 .56439 m
.37092 .56747 L
s
.26054 .60528 m .33298 .58565 L .32548 .56989 L .847 .882 .866 r
F
.26518 .6215 m .33298 .58565 L .26054 .60528 L .858 .827 .816 r
F
0 g
.32021 .59494 m
.41503 .61001 L
s
.32401 .58786 m
.34081 .58232 L
s
.21603 .71423 m .3268 .75283 L .21566 .708 L .891 .553 .4 r
F
0 g
.31173 .72538 m
.31273 .72541 L
s
.21603 .71423 m .32814 .76286 L .3268 .75283 L .891 .553 .4 r
F
0 g
.30812 .72528 m
.30831 .72529 L
s
.30831 .72529 m
.31173 .72538 L
s
.29984 .69635 m
.37475 .71734 L
s
.30718 .72939 m
.3098 .73011 L
s
.3098 .73011 m
.31034 .73026 L
s
.31034 .73026 m
.34723 .74043 L
s
.70283 .56733 m .71728 .44197 L .72232 .42764 L .88 .814 .334 r
F
0 g
.70858 .5261 m
.71123 .52171 L
s
.70978 .51751 m
.7121 .51605 L
s
.71051 .51231 m
.71276 .51278 L
s
.69652 .58265 m .71728 .44197 L .70283 .56733 L .974 .901 .684 r
F
0 g
.71427 .51309 m
.71618 .51349 L
s
.71276 .51278 m
.71427 .51309 L
s
.71383 .51497 m
.71618 .51349 L
s
.7121 .51605 m
.71383 .51497 L
s
.71324 .51836 m
.71618 .51349 L
s
.71123 .52171 m
.71324 .51836 L
s
.71618 .49303 m
.71618 .49145 L
s
.71618 .51349 m
.71618 .49393 L
s
.71618 .49393 m
.71618 .49303 L
s
.71347 .50887 m
.71398 .50974 L
s
.71212 .50656 m
.71347 .50887 L
s
.71146 .50545 m
.71212 .50656 L
s
.71398 .50974 m
.71416 .51004 L
s
.71416 .51004 m
.71618 .51349 L
s
.70962 .52804 m
.71399 .51835 L
s
.71399 .51835 m
.71418 .51792 L
s
.71418 .51792 m
.71618 .51349 L
s
.01 w
.71618 .51349 Mdot
.71618 .51349 Mdot
.71618 .51349 Mdot
.71618 .51349 Mdot
.71618 .51349 Mdot
.71618 .51349 Mdot
.5 Mabswid
.52232 .47602 m
.53098 .45384 L
s
.53625 .42532 m
.55357 .38378 L
s
.20718 .64809 m .27929 .65441 L .27159 .63797 L .946 .78 .644 r
F
.20839 .65787 m .27929 .65441 L .20718 .64809 L .94 .74 .605 r
F
0 g
.27374 .64777 m
.30638 .644 L
s
.26887 .65295 m
.28274 .65713 L
s
.26862 .65287 m
.26887 .65295 L
s
.21602 .71971 m .32814 .76286 L .21603 .71423 L .887 .536 .376 r
F
.21602 .71971 m .32771 .77165 L .32814 .76286 L F
0 g
.31652 .75461 m
.31675 .75463 L
s
.31675 .75463 m
.33116 .75562 L
s
.51009 .49343 m
.51082 .49278 L
s
.50921 .4942 m
.51009 .49343 L
s
.51618 .48801 m
.51667 .48757 L
s
.51667 .48757 m
.51688 .48739 L
s
.51523 .48886 m
.51618 .48801 L
s
.51082 .49278 m
.51523 .48886 L
s
.49678 .51138 m
.49712 .50918 L
s
.4874 .51558 m
.49717 .50504 L
s
.48198 .52142 m
.4874 .51558 L
s
.32788 .76165 m
.3747 .77467 L
s
.25158 .69858 m
.25386 .70011 L
s
.25386 .70011 m
.25513 .70097 L
s
.25513 .70097 m
.25565 .70132 L
s
.25565 .70132 m
.26007 .7043 L
s
.21583 .69145 m
.2228 .69457 L
s
.2228 .69457 m
.23316 .69919 L
s
.23316 .69919 m
.24234 .70329 L
s
.24234 .70329 m
.24257 .70339 L
s
.24257 .70339 m
.24258 .7034 L
s
.65781 .33192 m .59684 .25012 L .59281 .2914 L .603 .603 .825 r
F
0 g
.57603 .33825 m
.59281 .2914 L
s
.67087 .31028 m .59684 .25012 L .65781 .33192 L .301 .502 .887 r
F
0 g
.59013 .39555 m
.65488 .31648 L
s
.60248 .41911 m
.65553 .31738 L
s
.24562 .67087 m
.24921 .67313 L
s
.24921 .67313 m
.25197 .67486 L
s
.22097 .67202 m
.23099 .67524 L
s
.23099 .67524 m
.23287 .67584 L
s
.23287 .67584 m
.23816 .67754 L
s
.68204 .59912 m .70361 .46267 L .69652 .58265 L .896 .83 .774 r
F
0 g
.66151 .60608 m
.68654 .57063 L
s
.69652 .58265 m .70361 .46267 L .71728 .44197 L .974 .901 .684 r
F
0 g
.70944 .52844 m
.70962 .52804 L
s
.70362 .54134 m
.70513 .53801 L
s
.70513 .53801 m
.70944 .52844 L
s
.71619 .47993 m
.71619 .47159 L
s
.71618 .49145 m
.71619 .47993 L
s
.21563 .72441 m .32771 .77165 L .21602 .71971 L .883 .519 .349 r
F
.21563 .72441 m .32563 .77916 L .32771 .77165 L F
0 g
.315 .75807 m
.32788 .76165 L
s
.31498 .75806 m
.315 .75807 L
s
.71703 .42158 m .67237 .30147 L .67087 .31028 L 0 0 .552 r
F
.72232 .42764 m .67237 .30147 L .71703 .42158 L .973 .664 .313 r
F
.20627 .63815 m .27159 .63797 L .26518 .6215 L .949 .823 .685 r
F
.20718 .64809 m .27159 .63797 L .20627 .63815 L .946 .78 .644 r
F
0 g
.27049 .64814 m
.27374 .64777 L
s
.53403 .45369 m
.53507 .45364 L
s
.53507 .45364 m
.53778 .45351 L
s
.53181 .4538 m
.53395 .45369 L
s
.52961 .4688 m
.53098 .45384 L
s
.01 w
.53098 .45384 Mdot
.53098 .45384 Mdot
.53098 .45384 Mdot
.5 Mabswid
.53456 .4462 m
.53495 .4414 L
s
.53572 .43183 m
.53625 .42532 L
s
.24837 .71749 m
.24963 .7184 L
s
.24963 .7184 m
.25317 .72096 L
s
.25317 .72096 m
.25595 .72297 L
s
.25595 .72297 m
.2567 .72351 L
s
.23562 .71936 m
.23656 .71987 L
s
.23656 .71987 m
.24044 .72199 L
s
.24044 .72199 m
.24426 .72407 L
s
.25803 .58954 m .32548 .56989 L .3229 .55573 L .811 .929 .911 r
F
.26054 .60528 m .32548 .56989 L .25803 .58954 L .847 .882 .866 r
F
0 g
.30642 .5811 m
.30646 .58135 L
s
.29207 .58713 m
.29237 .58723 L
s
.27979 .60017 m
.28286 .5994 L
s
.51823 .48789 m
.51825 .48847 L
s
.5048 .52376 m
.50709 .51735 L
s
.50709 .51735 m
.50823 .51414 L
s
.50823 .51414 m
.50987 .50953 L
s
.50987 .50953 m
.5105 .50777 L
s
.5105 .50777 m
.51797 .4868 L
s
.21489 .72829 m .32563 .77916 L .21563 .72441 L .88 .5 .318 r
F
0 g
.24697 .72555 m
.24738 .72577 L
s
.24426 .72407 m
.24697 .72555 L
s
.21489 .72829 m .32209 .7854 L .32563 .77916 L .88 .5 .318 r
F
0 g
.3138 .77565 m
.31433 .7757 L
s
.31433 .7757 m
.31626 .7759 L
s
.31626 .7759 m
.36227 .78068 L
s
.24202 .64111 m
.24453 .64246 L
s
.20577 .62815 m .26518 .6215 L .26054 .60528 L .948 .866 .724 r
F
.20627 .63815 m .26518 .6215 L .20577 .62815 L .949 .823 .685 r
F
0 g
.36966 .54849 m
.37384 .54776 L
s
.36678 .54899 m
.36966 .54849 L
s
.68204 .59912 m .68324 .48676 L .70361 .46267 L .896 .83 .774 r
F
0 g
.69727 .55544 m
.70061 .54803 L
s
.70061 .54803 m
.70362 .54134 L
s
.69247 .56223 m
.693 .56148 L
s
.6938 .56035 m
.6968 .55609 L
s
.693 .56148 m
.6938 .56035 L
s
.6968 .55609 m
.69727 .55544 L
s
.68898 .5736 m
.68934 .57281 L
s
.6876 .57663 m
.68898 .5736 L
s
.68934 .57281 m
.69659 .55693 L
s
.69659 .55693 m
.69727 .55544 L
s
.67479 .6047 m
.68215 .58857 L
s
.6612 .61515 m .68324 .48676 L .68204 .59912 L .818 .755 .794 r
F
.67087 .31028 m .58741 .22224 L .59684 .25012 L .301 .502 .887 r
F
0 g
.59281 .2914 m
.59684 .25012 L
s
.48638 .52184 m
.49323 .51808 L
s
.49972 .51452 m
.51135 .50814 L
s
.49323 .51808 m
.49972 .51452 L
s
.51135 .50814 m
.52323 .50162 L
s
.52323 .50162 m
.52677 .49968 L
s
.67237 .30147 m .58741 .22224 L .67087 .31028 L .748 .231 0 r
F
0 g
.56975 .34911 m
.59426 .24243 L
s
.58818 .36687 m
.59483 .24308 L
s
.52778 .50586 m .53331 .43438 L .54675 .4919 L 0 0 .006 r
F
0 g
.52677 .49968 m
.52808 .48541 L
s
.53098 .45384 m
.53104 .43615 L
s
.53098 .45384 m
.53331 .43438 L
s
.72232 .42764 m .66503 .30732 L .67237 .30147 L .973 .664 .313 r
F
0 g
.68653 .40477 m
.70938 .40048 L
s
.71728 .44197 m .66503 .30732 L .72232 .42764 L .924 .715 .602 r
F
0 g
.71287 .39982 m
.7162 .39919 L
s
.71141 .40009 m
.71188 .40001 L
s
.71223 .39994 m
.71287 .39982 L
s
.71188 .40001 m
.71223 .39994 L
s
.71465 .40219 m
.7162 .39919 L
s
.71349 .40443 m
.71465 .40219 L
s
.7162 .40567 m
.7162 .39919 L
s
.7162 .41508 m
.7162 .41502 L
s
.71619 .44362 m
.71619 .43917 L
s
.7162 .41502 m
.7162 .41097 L
s
.7162 .41097 m
.7162 .40567 L
s
.66589 .49621 m
.70732 .41631 L
s
.71295 .40547 m
.71349 .40443 L
s
.71285 .40566 m
.71295 .40547 L
s
.6612 .61515 m .65809 .51095 L .68324 .48676 L .818 .755 .794 r
F
.63613 .62927 m .65809 .51095 L .6612 .61515 L .756 .689 .788 r
F
0 g
.52877 .51783 m
.52908 .51404 L
s
.52908 .51404 m
.53032 .49866 L
s
.53032 .49866 m
.53089 .49161 L
s
.52806 .5267 m
.52877 .51783 L
s
.32664 .78224 m
.35125 .78899 L
s
.31258 .77838 m
.32664 .78224 L
s
.31121 .778 m
.31258 .77838 L
s
.31119 .778 m
.31121 .778 L
s
.24754 .73558 m
.24793 .7359 L
s
.24793 .7359 m
.2482 .73611 L
s
.2482 .73611 m
.24928 .73696 L
s
.24928 .73696 m
.24948 .73712 L
s
.2248 .72776 m
.22663 .72895 L
s
.22663 .72895 m
.23116 .73189 L
s
.23116 .73189 m
.2353 .73457 L
s
.2353 .73457 m
.2393 .73716 L
s
.2393 .73716 m
.24312 .73963 L
s
.24312 .73963 m
.24438 .74045 L
s
.21856 .72372 m
.2248 .72776 L
s
.25803 .58954 m .3229 .55573 L .25788 .57454 L .811 .929 .911 r
F
0 g
.28935 .58613 m
.29207 .58713 L
s
.25788 .57454 m .3229 .55573 L .32526 .54356 L .741 .955 .944 r
F
0 g
.30187 .55212 m
.30219 .55417 L
s
.31714 .55635 m
.33127 .56026 L
s
.3167 .55623 m
.31714 .55635 L
s
.30187 .55212 m
.30485 .55295 L
s
.30431 .56768 m
.30642 .5811 L
s
.20579 .6182 m .26054 .60528 L .25803 .58954 L .94 .909 .761 r
F
.20577 .62815 m .26054 .60528 L .20579 .6182 L .948 .866 .724 r
F
0 g
.25572 .60618 m
.27979 .60017 L
s
.25571 .60619 m
.25572 .60618 L
s
.25611 .61201 m
.32613 .63564 L
s
.25384 .61125 m
.25611 .61201 L
s
.69698 .5536 m
.69727 .55544 L
s
.69257 .52563 m
.69698 .5536 L
s
.6916 .51951 m
.69257 .52563 L
s
.6897 .50743 m
.6916 .51951 L
s
.69675 .55522 m
.69727 .55544 L
s
.68941 .55208 m
.69675 .55522 L
s
.68735 .55121 m
.68941 .55208 L
s
.68505 .55022 m
.68735 .55121 L
s
.69663 .55588 m
.69727 .55544 L
s
.68625 .56302 m
.69663 .55588 L
s
.68227 .56577 m
.68625 .56302 L
s
.67143 .57323 m
.68227 .56577 L
s
.66995 .57425 m
.67143 .57323 L
s
.01 w
.69727 .55544 Mdot
.69727 .55544 Mdot
.69727 .55544 Mdot
.69727 .55544 Mdot
.69727 .55544 Mdot
.69727 .55544 Mdot
.5 Mabswid
.52677 .49968 m
.52837 .49801 L
s
.53046 .49582 m
.53425 .49185 L
s
.52677 .49968 m
.52817 .5 L
s
.52677 .49968 m
.52761 .50285 L
s
.01 w
.52677 .49968 Mdot
.52677 .49968 Mdot
.52677 .49968 Mdot
.52677 .49968 Mdot
.52677 .49968 Mdot
.52677 .49968 Mdot
.5 Mabswid
.30619 .7886 m
.34378 .79374 L
s
.30515 .78846 m
.30619 .7886 L
s
.30202 .78803 m
.30515 .78846 L
s
.30166 .78798 m
.30202 .78803 L
s
.63613 .62927 m .6301 .53254 L .65809 .51095 L .756 .689 .788 r
F
0 g
.63086 .60118 m
.63786 .59635 L
s
.63786 .59635 m
.64305 .59278 L
s
.64305 .59278 m
.66268 .57926 L
s
.62581 .61792 m
.63086 .60118 L
s
.63086 .60118 m
.63255 .60517 L
s
.70997 .38877 m
.7162 .39919 L
s
.71167 .39781 m
.71383 .39847 L
s
.71383 .39847 m
.7162 .39919 L
s
.71379 .40298 m
.71497 .40112 L
s
.71497 .40112 m
.7162 .39919 L
s
.01 w
.7162 .39919 Mdot
.7162 .39919 Mdot
.7162 .39919 Mdot
.7162 .39919 Mdot
.7162 .39919 Mdot
.7162 .39919 Mdot
.5 Mabswid
.31821 .54935 m
.33336 .54677 L
s
.30187 .55212 m
.30943 .55084 L
s
.5655 .47414 m .53257 .41465 L .53026 .39097 L 0 .149 .673 r
F
0 g
.53968 .45341 m
.54025 .45339 L
s
.54025 .45339 m
.55365 .45273 L
s
.53104 .43615 m
.53115 .39949 L
s
.54675 .4919 m .53257 .41465 L .5655 .47414 L 0 0 .337 r
F
0 g
.53257 .41465 m
.53331 .43438 L
s
.55637 .4526 m
.5576 .45254 L
s
.53998 .48585 m
.54323 .48244 L
s
.53425 .49185 m
.53998 .48585 L
s
.54323 .48244 m
.54478 .48082 L
s
.20641 .60839 m .25803 .58954 L .25788 .57454 L .922 .949 .794 r
F
.20579 .6182 m .25803 .58954 L .20641 .60839 L .94 .909 .761 r
F
0 g
.22162 .61459 m
.22163 .61459 L
s
.67237 .30147 m .5693 .21309 L .58741 .22224 L .748 .231 0 r
F
0 g
.59045 .23122 m
.59684 .25012 L
s
.71728 .44197 m .65226 .32663 L .66503 .30732 L .924 .715 .602 r
F
0 g
.67216 .36193 m
.68236 .39993 L
s
.70361 .46267 m .65226 .32663 L .71728 .44197 L .846 .698 .698 r
F
0 g
.70478 .38007 m
.70997 .38877 L
s
.70444 .39561 m
.71167 .39781 L
s
.70336 .39528 m
.70444 .39561 L
s
.70919 .4102 m
.71379 .40298 L
s
.7079 .41221 m
.70919 .4102 L
s
.57268 .56248 m .54675 .4919 L .5655 .47414 L .493 .42 .702 r
F
0 g
.54478 .48082 m
.55079 .47453 L
s
.55079 .47453 m
.56083 .46402 L
s
.56835 .50922 m
.57818 .51147 L
s
.62598 .57894 m
.63086 .60118 L
s
.62458 .59793 m
.63086 .60118 L
s
.58837 .61461 m
.59067 .61389 L
s
.6116 .60727 m
.61916 .60488 L
s
.61916 .60488 m
.63086 .60118 L
s
.59067 .61389 m
.6116 .60727 L
s
.66503 .30732 m .5693 .21309 L .67237 .30147 L .834 .525 .466 r
F
.26022 .56048 m .32526 .54356 L .33221 .53369 L .629 .945 .951 r
F
.25788 .57454 m .32526 .54356 L .26022 .56048 L .741 .955 .944 r
F
0 g
.28985 .54813 m
.29173 .54875 L
s
.55185 .54965 m
.56181 .54472 L
s
.53115 .39949 m
.53132 .39943 L
s
.53109 .39856 m
.53115 .39949 L
s
.53115 .39949 m
.53163 .4001 L
s
.01 w
.53115 .39949 Mdot
.53115 .39949 Mdot
.53115 .39949 Mdot
.68324 .48676 m .63678 .35561 L .70361 .46267 L .775 .67 .747 r
F
.70361 .46267 m .63678 .35561 L .65226 .32663 L .846 .698 .698 r
F
0 g
.5 Mabswid
.67993 .33848 m
.70478 .38007 L
s
.68724 .44462 m
.68788 .44361 L
s
.67987 .33838 m
.67993 .33848 L
s
.31114 .79261 m
.32995 .79763 L
s
.30585 .79119 m
.31114 .79261 L
s
.32995 .79763 m
.33049 .79778 L
s
.22335 .73058 m
.22498 .73202 L
s
.22498 .73202 m
.23192 .73818 L
s
.23192 .73818 m
.23849 .744 L
s
.23849 .744 m
.23919 .74462 L
s
.21656 .73225 m
.21802 .73338 L
s
.21892 .73407 m
.21937 .73442 L
s
.23186 .74411 m
.23647 .74768 L
s
.23647 .74768 m
.23893 .74958 L
s
.23893 .74958 m
.23982 .75027 L
s
.21937 .73442 m
.23071 .74321 L
s
.23071 .74321 m
.23186 .74411 L
s
.20641 .60839 m .25788 .57454 L .20769 .59884 L .922 .949 .794 r
F
.20769 .59884 m .25788 .57454 L .26022 .56048 L .889 .981 .817 r
F
0 g
.25314 .57291 m
.28935 .58613 L
s
.25537 .5673 m
.27269 .56164 L
s
.57268 .56248 m .5655 .47414 L .60109 .54985 L .493 .42 .702 r
F
0 g
.5701 .54062 m
.571 .54018 L
s
.56181 .54472 m
.5701 .54062 L
s
.5655 .47414 m .53026 .39097 L .58416 .45099 L 0 .149 .673 r
F
.60109 .54985 m .5655 .47414 L .58416 .45099 L .548 .497 .751 r
F
0 g
.57205 .45184 m
.57249 .45182 L
s
.56816 .45635 m
.57249 .45182 L
s
.58416 .45099 m .53026 .39097 L .52724 .36101 L .35 .439 .812 r
F
0 g
.56912 .44755 m
.57249 .45182 L
s
.53026 .39097 m
.53257 .41465 L
s
.52102 1.03998 m .34706 1.13644 L .55116 1.11243 L .766 .637 .719 r
F
.52102 1.03998 m .34296 1.04384 L .34706 1.13644 L F
.69295 .97561 m .52102 1.03998 L .55116 1.11243 L .658 .534 .702 r
F
.4992 .97237 m .34296 1.04384 L .52102 1.03998 L .788 .736 .804 r
F
.65574 .92493 m .52102 1.03998 L .69295 .97561 L .702 .619 .761 r
F
.65574 .92493 m .4992 .97237 L .52102 1.03998 L F
.60109 .54985 m .58416 .45099 L .6301 .53254 L .548 .497 .751 r
F
0 g
.571 .54018 m
.59607 .52777 L
s
.62582 .52494 m
.63491 .52882 L
s
.68324 .48676 m .62001 .38909 L .63678 .35561 L .775 .67 .747 r
F
0 g
.68365 .45025 m
.68724 .44462 L
s
.65809 .51095 m .62001 .38909 L .68324 .48676 L .702 .63 .773 r
F
0 g
.68127 .45398 m
.68358 .45036 L
s
.68358 .45036 m
.68365 .45025 L
s
.68127 .45398 m
.68277 .46348 L
s
.68287 .46409 m
.68379 .46996 L
s
.68277 .46348 m
.68284 .46391 L
s
.68284 .46391 m
.68287 .46409 L
s
.68252 .4561 m
.68291 .45677 L
s
.68127 .45398 m
.68248 .45605 L
s
.68248 .45605 m
.68252 .4561 L
s
.68291 .45677 m
.68369 .45811 L
s
.6301 .53254 m .60242 .4221 L .65809 .51095 L .624 .572 .775 r
F
.6301 .53254 m .58416 .45099 L .60242 .4221 L F
0 g
.60154 .52507 m
.61292 .51944 L
s
.61006 .51878 m
.61292 .51944 L
s
.61292 .51944 m
.61522 .52988 L
s
.61292 .51944 m
.6157 .52062 L
s
.65809 .51095 m .60242 .4221 L .62001 .38909 L .702 .63 .773 r
F
.19057 .63127 m .21266 .68526 L .21125 .67654 L .866 .626 .093 r
F
.19057 .63127 m .21392 .69345 L .21266 .68526 L .861 .618 .083 r
F
.69295 .97561 m .55116 1.11243 L .72848 1.02657 L .658 .534 .702 r
F
.55116 1.11243 m .38037 1.22797 L .5904 1.17769 L .734 .547 .64 r
F
.55116 1.11243 m .34706 1.13644 L .38037 1.22797 L F
.72848 1.02657 m .55116 1.11243 L .5904 1.17769 L .603 .442 .637 r
F
.19057 .63127 m .21494 .70105 L .21392 .69345 L .863 .62 .086 r
F
0 g
.57249 .45182 m
.57518 .45632 L
s
.60509 .50634 m
.61292 .51944 L
s
.67612 .45891 m
.68127 .45398 L
s
.67142 .46341 m
.67612 .45891 L
s
.61292 .51944 m
.6207 .51199 L
s
.66685 .46779 m
.67142 .46341 L
s
.66677 .46787 m
.66685 .46779 L
s
.01 w
.61292 .51944 Mdot
.61292 .51944 Mdot
.61292 .51944 Mdot
.61292 .51944 Mdot
.61292 .51944 Mdot
.61292 .51944 Mdot
.66503 .30732 m .54969 .22352 L .5693 .21309 L .834 .525 .466 r
F
0 g
.5 Mabswid
.5693 .21309 m
.58741 .22224 L
s
.65535 .30029 m
.65776 .31171 L
s
.65462 .2968 m
.65463 .29686 L
s
.65568 .30053 m
.65968 .31542 L
s
.19057 .63127 m .21125 .67654 L .20979 .66739 L .875 .643 .116 r
F
.19057 .63127 m .21566 .708 L .21494 .70105 L .87 .632 .101 r
F
0 g
.21444 .66992 m
.21506 .67012 L
s
.21506 .67012 m
.22097 .67202 L
s
.57249 .45182 m
.57444 .44804 L
s
.67604 .45387 m
.68127 .45398 L
s
.67291 .45381 m
.67604 .45387 L
s
.67279 .45381 m
.67291 .45381 L
s
.67226 .4538 m
.67279 .45381 L
s
.57249 .45182 m
.57348 .45184 L
s
.01 w
.57249 .45182 Mdot
.57249 .45182 Mdot
.57249 .45182 Mdot
.57249 .45182 Mdot
.57249 .45182 Mdot
.57249 .45182 Mdot
.5 Mabswid
.56687 1.18333 m
.56811 1.18624 L
s
.4078 .893 m
.40903 .8946 L
s
.44959 .94726 m
.45292 .95158 L
s
.43247 .92503 m
.43529 .92869 L
s
.43529 .92869 m
.44959 .94726 L
s
.41033 .89629 m
.43247 .92503 L
s
.50409 .99156 m
.51713 .98821 L
s
.19057 .63127 m .20979 .66739 L .20839 .65787 L .887 .669 .15 r
F
.26022 .56048 m .33221 .53369 L .26503 .54756 L .629 .945 .951 r
F
0 g
.27911 .54456 m
.27962 .54473 L
s
.19057 .63127 m .21603 .71423 L .21566 .708 L .881 .649 .126 r
F
0 g
.21563 .69384 m
.24837 .71749 L
s
.2127 .69006 m
.2128 .6901 L
s
.21308 .69023 m
.21404 .69065 L
s
.2128 .6901 m
.21308 .69023 L
s
.2127 .69006 m
.2127 .69006 L
s
.21232 .66924 m
.21444 .66992 L
s
.2123 .67211 m
.21432 .67347 L
s
.21394 .69262 m
.21563 .69384 L
s
.21404 .69065 m
.21583 .69145 L
s
.21432 .67347 m
.21489 .67385 L
s
.21489 .67385 m
.25158 .69858 L
s
.66503 .43286 m
.68127 .45398 L
s
.65511 .41996 m
.66503 .43286 L
s
.63847 .39833 m
.65511 .41996 L
s
.63778 .39743 m
.63847 .39833 L
s
.01 w
.68127 .45398 Mdot
.68127 .45398 Mdot
.68127 .45398 Mdot
.68127 .45398 Mdot
.68127 .45398 Mdot
.68127 .45398 Mdot
.65226 .32663 m .54969 .22352 L .66503 .30732 L .778 .57 .618 r
F
0 g
.5 Mabswid
.6544 .29574 m
.65759 .30108 L
s
.65864 .30284 m
.65867 .3029 L
s
.65759 .30108 m
.65864 .30284 L
s
.6544 .29574 m
.65512 .29845 L
s
.65512 .29845 m
.65526 .29897 L
s
.65526 .29897 m
.65531 .29914 L
s
.6544 .29574 m
.65459 .29668 L
s
.65459 .29668 m
.65462 .2968 L
s
.19057 .63127 m .20839 .65787 L .20718 .64809 L .899 .701 .192 r
F
.19057 .63127 m .21602 .71971 L .21603 .71423 L .895 .67 .156 r
F
0 g
.21569 .7085 m
.23562 .71936 L
s
.21102 .64444 m
.21177 .64452 L
s
.20942 .66831 m
.20949 .66833 L
s
.20928 .66826 m
.20942 .66831 L
s
.20949 .66833 m
.21008 .66852 L
s
.21103 .66882 m
.21232 .66924 L
s
.21008 .66852 m
.21103 .66882 L
s
.20942 .67017 m
.20954 .67025 L
s
.20961 .6703 m
.21023 .67072 L
s
.21114 .67133 m
.2123 .67211 L
s
.21023 .67072 m
.21114 .67133 L
s
.20954 .67025 m
.20961 .6703 L
s
.21197 .64973 m
.24562 .67087 L
s
.21195 .64971 m
.21197 .64973 L
s
.21179 .64452 m
.22964 .6465 L
s
.21177 .64452 m
.21179 .64452 L
s
.21291 .69188 m
.21315 .69205 L
s
.21361 .69238 m
.21394 .69262 L
s
.21315 .69205 m
.21361 .69238 L
s
.21285 .69183 m
.21291 .69188 L
s
.21284 .69183 m
.21285 .69183 L
s
.31951 .79871 m
.32078 .79894 L
s
.3149 .79787 m
.31951 .79871 L
s
.32078 .79894 m
.32131 .79904 L
s
.4992 .97237 m .35889 .96686 L .34296 1.04384 L .788 .736 .804 r
F
0 g
.47777 .96447 m
.48499 .98888 L
s
.45337 .95217 m
.48471 .99285 L
s
.49194 1.00735 m
.56135 1.17036 L
s
.4511 .99435 m
.45115 .99435 L
s
.35215 .99 m
.35408 .99009 L
s
.61854 .88105 m .4992 .97237 L .65574 .92493 L .746 .711 .819 r
F
.58416 .45099 m .52724 .36101 L .60242 .4221 L .35 .439 .812 r
F
.20966 .58965 m .26022 .56048 L .26503 .54756 L .835 .999 .825 r
F
.20769 .59884 m .26022 .56048 L .20966 .58965 L .889 .981 .817 r
F
0 g
.6458 .29683 m
.6544 .29574 L
s
.6442 .29703 m
.6458 .29683 L
s
.65085 .30237 m
.6544 .29574 L
s
.64972 .30449 m
.65085 .30237 L
s
.01 w
.6544 .29574 Mdot
.6544 .29574 Mdot
.6544 .29574 Mdot
.6544 .29574 Mdot
.6544 .29574 Mdot
.6544 .29574 Mdot
.5 Mabswid
.58383 .93625 m
.62558 .95414 L
s
.51221 .90557 m
.58383 .93625 L
s
.62257 .94369 m
.62295 .94414 L
s
.55684 .86559 m
.55742 .86627 L
s
.55272 .8607 m
.55684 .86559 L
s
.19057 .63127 m .20718 .64809 L .20627 .63815 L .907 .736 .238 r
F
.19057 .63127 m .21563 .72441 L .21602 .71971 L .908 .69 .186 r
F
0 g
.20819 .64413 m
.20874 .64419 L
s
.20846 .64752 m
.20895 .64783 L
s
.20874 .64419 m
.21077 .64441 L
s
.20895 .64783 m
.21097 .6491 L
s
.21462 .70792 m
.21468 .70795 L
s
.21468 .70795 m
.21471 .70797 L
s
.21491 .70808 m
.21569 .7085 L
s
.21471 .70797 m
.21491 .70808 L
s
.20901 .70487 m
.2106 .70573 L
s
.20909 .70517 m
.21082 .70654 L
s
.21123 .64926 m
.21195 .64971 L
s
.21097 .6491 m
.21123 .64926 L
s
.21077 .64441 m
.21102 .64444 L
s
.21463 .70955 m
.21463 .70955 L
s
.21481 .70969 m
.21547 .71022 L
s
.21463 .70955 m
.21481 .70969 L
s
.21547 .71022 m
.24754 .73558 L
s
.60242 .4221 m .52724 .36101 L .52513 .32501 L .559 .555 .806 r
F
0 g
.52724 .36101 m
.53026 .39097 L
s
.20707 .69261 m
.20763 .69934 L
s
.19057 .63127 m .20627 .63815 L .20577 .62815 L .91 .77 .282 r
F
.19057 .63127 m .21489 .72829 L .21563 .72441 L .92 .707 .214 r
F
0 g
.21433 .72098 m
.21856 .72372 L
s
.21421 .72091 m
.21433 .72098 L
s
.21413 .72085 m
.21418 .72088 L
s
.21418 .72088 m
.21421 .72091 L
s
.21403 .72232 m
.22335 .73058 L
s
.21394 .72224 m
.214 .7223 L
s
.214 .7223 m
.21403 .72232 L
s
.2139 .72221 m
.21394 .72224 L
s
.20603 .64599 m
.20694 .64657 L
s
.20694 .64657 m
.20846 .64752 L
s
.2061 .64389 m
.20668 .64396 L
s
.20668 .64396 m
.20819 .64413 L
s
.21137 .72823 m
.21144 .72828 L
s
.21168 .72846 m
.21656 .73225 L
s
.21144 .72828 m
.21168 .72846 L
s
.72606 .79405 m .65574 .92493 L .76428 .82487 L .642 .603 .795 r
F
.72606 .79405 m .61854 .88105 L .65574 .92493 L F
.76428 .82487 m .65574 .92493 L .69295 .97561 L .576 .523 .759 r
F
0 g
.65246 .94532 m
.69155 .91749 L
s
.60242 .4221 m .52513 .32501 L .62001 .38909 L .559 .555 .806 r
F
.65226 .32663 m .53459 .24998 L .54969 .22352 L .778 .57 .618 r
F
0 g
.54969 .22352 m
.6544 .29574 L
s
.54969 .22352 m
.5693 .21309 L
s
.01 w
.54969 .22352 Mdot
.54969 .22352 Mdot
.54969 .22352 Mdot
.63678 .35561 m .53459 .24998 L .65226 .32663 L .727 .586 .697 r
F
.79805 .85877 m .69295 .97561 L .72848 1.02657 L .496 .427 .709 r
F
.76428 .82487 m .69295 .97561 L .79805 .85877 L .576 .523 .759 r
F
0 g
.5 Mabswid
.69155 .91749 m
.69316 .91634 L
s
.19057 .63127 m .20577 .62815 L .20579 .6182 L .904 .799 .32 r
F
.21233 .58089 m .26503 .54756 L .27217 .53591 L .754 .993 .811 r
F
0 g
.26693 .54051 m
.27546 .54335 L
s
.20966 .58965 m .26503 .54756 L .21233 .58089 L .835 .999 .825 r
F
0 g
.25583 .54819 m
.25592 .548 L
s
.22046 .58659 m
.22128 .58607 L
s
.22128 .58607 m
.2214 .58599 L
s
.35783 .99517 m
.55849 1.1775 L
s
.35215 .99 m
.35379 .99149 L
s
.56531 1.1837 m
.56811 1.18624 L
s
.68645 .76898 m .61854 .88105 L .72606 .79405 L .701 .674 .821 r
F
.68645 .76898 m .58272 .84836 L .61854 .88105 L F
0 g
.55742 .86627 m
.62257 .94369 L
s
.34296 1.04384 m
.34706 1.13644 L
s
.62001 .38909 m .52513 .32501 L .52667 .28611 L .665 .587 .757 r
F
0 g
.54766 .30927 m
.58711 .30427 L
s
.52509 .31213 m
.52594 .30905 L
s
.52513 .32501 m
.52724 .36101 L
s
.52533 .3156 m
.52544 .31721 L
s
.52509 .31213 m
.52531 .31529 L
s
.52531 .31529 m
.52533 .3156 L
s
.72848 1.02657 m .5904 1.17769 L .75924 1.07026 L .603 .442 .637 r
F
.5904 1.17769 m .44196 1.29786 L .634 1.22302 L .679 .435 .546 r
F
0 g
.56811 1.18624 m
.57442 1.18278 L
s
.55539 1.18907 m
.56811 1.18624 L
s
.5904 1.17769 m .38037 1.22797 L .44196 1.29786 L .679 .435 .546 r
F
0 g
.34706 1.13644 m
.38037 1.22797 L
s
.75924 1.07026 m .5904 1.17769 L .634 1.22302 L .511 .309 .542 r
F
0 g
.57926 1.18012 m
.63442 1.14985 L
s
.49458 .99913 m
.7075 1.08982 L
s
.64608 .97526 m
.71177 1.07418 L
s
.30444 .79954 m
.30578 .79993 L
s
.25632 .78662 m
.25778 .78694 L
s
.25778 .78694 m
.25843 .78708 L
s
.25843 .78708 m
.26068 .78757 L
s
.26068 .78757 m
.2616 .78778 L
s
.21104 .72929 m
.21929 .7376 L
s
.21096 .72921 m
.21104 .72929 L
s
.21929 .7376 m
.22731 .74568 L
s
.22731 .74568 m
.22849 .74688 L
s
.20225 .72494 m
.2031 .72574 L
s
.62001 .38909 m .52667 .28611 L .63678 .35561 L .665 .587 .757 r
F
0 g
.61511 .36865 m
.61553 .36849 L
s
.61137 .37002 m
.61511 .36865 L
s
.61553 .36849 m
.61566 .36824 L
s
.61553 .36849 m
.61598 .36908 L
s
.61598 .36908 m
.62226 .37724 L
s
.61488 .36975 m
.61553 .36849 L
s
.61198 .37537 m
.61488 .36975 L
s
.61553 .36849 m
.61573 .36855 L
s
.61573 .36855 m
.61933 .36965 L
s
.53147 .28914 m
.54062 .2562 L
s
.61566 .36824 m
.61898 .36204 L
s
.62603 .34883 m
.62752 .34604 L
s
.40809 .54616 m
.41857 .5526 L
s
.3383 .5258 m
.33957 .52599 L
s
.63678 .35561 m .52667 .28611 L .53459 .24998 L .727 .586 .697 r
F
0 g
.52513 .32501 m
.52667 .28611 L
s
.52509 .31213 m
.52816 .31174 L
s
.53459 .24998 m
.54969 .22352 L
s
.57707 .34452 m
.61163 .36606 L
s
.52509 .31213 m
.57707 .34452 L
s
.61163 .36606 m
.61553 .36849 L
s
.01 w
.52509 .31213 Mdot
.52509 .31213 Mdot
.52509 .31213 Mdot
.19057 .63127 m .20579 .6182 L .20641 .60839 L .887 .822 .348 r
F
0 g
.5 Mabswid
.20483 .62108 m
.2051 .62122 L
s
.2051 .62122 m
.20616 .62179 L
s
.20508 .61864 m
.22162 .61459 L
s
.20618 .6218 m
.24202 .64111 L
s
.20616 .62179 m
.20618 .6218 L
s
.01 w
.61553 .36849 Mdot
.61553 .36849 Mdot
.61553 .36849 Mdot
.61553 .36849 Mdot
.61553 .36849 Mdot
.61553 .36849 Mdot
.5 Mabswid
.34296 1.04384 m
.35889 .96686 L
s
.52667 .28611 m
.53459 .24998 L
s
.29965 .51777 m
.30068 .51802 L
s
.28764 .53181 m
.28842 .53163 L
s
.19057 .63127 m .20641 .60839 L .20769 .59884 L .857 .834 .362 r
F
.64819 .75098 m .58272 .84836 L .68645 .76898 L .757 .736 .833 r
F
.64819 .75098 m .55008 .8284 L .58272 .84836 L F
.82402 .89209 m .72848 1.02657 L .75924 1.07026 L .376 .293 .634 r
F
.79805 .85877 m .72848 1.02657 L .82402 .89209 L .496 .427 .709 r
F
.21233 .58089 m .27217 .53591 L .21569 .57267 L .754 .993 .811 r
F
0 g
.22525 .57374 m
.22593 .57363 L
s
.22593 .57363 m
.22849 .57321 L
s
.21569 .57267 m .27217 .53591 L .28143 .52561 L .644 .957 .768 r
F
0 g
.2602 .53828 m
.26261 .53908 L
s
.25857 .54197 m
.2602 .53828 L
s
.26992 .53599 m
.27856 .53395 L
s
.2602 .53828 m
.26546 .53704 L
s
.27856 .53395 m
.28764 .53181 L
s
.35311 .9981 m
.38037 1.22797 L
s
.35215 .99 m
.35286 .99599 L
s
.01 w
.38037 1.22797 Mdot
.38037 1.22797 Mdot
.38037 1.22797 Mdot
.5 Mabswid
.20225 .72494 m
.2029 .72466 L
s
.40646 .89534 m
.4078 .893 L
s
.3921 .92037 m
.40646 .89534 L
s
.36312 .97088 m
.3921 .92037 L
s
.35436 .98615 m
.36312 .97088 L
s
.35424 .98637 m
.35436 .98615 L
s
.35215 .99 m
.35424 .98637 L
s
.01 w
.35215 .99 Mdot
.35215 .99 Mdot
.35215 .99 Mdot
.19057 .63127 m .20769 .59884 L .20966 .58965 L .812 .831 .359 r
F
0 g
.5 Mabswid
.20747 .5971 m
.2342 .60508 L
s
.20818 .59438 m
.22046 .58659 L
s
.50227 .86505 m
.50244 .865 L
s
.50244 .865 m
.52464 .85823 L
s
.49751 .8665 m
.50227 .86505 L
s
.43614 .88557 m
.43801 .88499 L
s
.49756 .86665 m
.51852 .86019 L
s
.51852 .86019 m
.5342 .85536 L
s
.5342 .85536 m
.53677 .85457 L
s
.53677 .85457 m
.54111 .85323 L
s
.49676 .83761 m
.5015 .839 L
s
.51555 .84315 m
.51697 .84356 L
s
.51697 .84356 m
.53711 .8495 L
s
.5015 .839 m
.51555 .84315 L
s
.55651 .85324 m
.72879 .87345 L
s
.72879 .87345 m
.72915 .87349 L
s
.55517 .85308 m
.55651 .85324 L
s
.55322 .85285 m
.55517 .85308 L
s
.61056 .81298 m
.61947 .80765 L
s
.56052 .84286 m
.60575 .81585 L
s
.60575 .81585 m
.61056 .81298 L
s
.31712 .809 m
.32509 .80887 L
s
.25724 .53994 m
.2602 .53828 L
s
.31712 .809 m
.32566 .80923 L
s
.25806 .7871 m
.25818 .78713 L
s
.25818 .78713 m
.26091 .78789 L
s
.26091 .78789 m
.26206 .78821 L
s
.30072 .79894 m
.30697 .80068 L
s
.30697 .80068 m
.3102 .80158 L
s
.25632 .78662 m
.25806 .7871 L
s
.19057 .63127 m .20966 .58965 L .21233 .58089 L .749 .811 .336 r
F
0 g
.20504 .59638 m
.20587 .59585 L
s
.20504 .59638 m
.20557 .59654 L
s
.20475 .59844 m
.20504 .59638 L
s
.35889 .96686 m
.382 .91584 L
s
.67442 .81636 m
.71663 .84966 L
s
.67107 .81372 m
.67442 .81636 L
s
.71663 .84966 m
.7173 .85019 L
s
.6589 .80411 m
.67107 .81372 L
s
.50216 .82934 m
.5069 .82812 L
s
.49993 .82991 m
.50216 .82934 L
s
.49875 .83021 m
.49993 .82991 L
s
.65456 .79069 m
.65539 .79052 L
s
.61365 .73979 m .55008 .8284 L .64819 .75098 L .81 .786 .831 r
F
0 g
.62056 .78505 m
.62708 .78714 L
s
.62888 .79673 m
.63473 .79523 L
s
.62208 .79848 m
.62888 .79673 L
s
.61365 .73979 m .52273 .81979 L .55008 .8284 L .81 .786 .831 r
F
0 g
.54276 .81889 m
.59794 .80469 L
s
.59794 .80469 m
.62208 .79848 L
s
.58565 .77384 m
.59675 .77741 L
s
.5069 .82812 m
.54276 .81889 L
s
.21969 .56506 m .28143 .52561 L .29252 .51668 L .508 .886 .695 r
F
.21569 .57267 m .28143 .52561 L .21969 .56506 L .644 .957 .768 r
F
0 g
.26963 .52968 m
.27231 .52724 L
s
.26405 .53477 m
.26963 .52968 L
s
.26073 .5378 m
.26405 .53477 L
s
.25101 .54345 m
.25724 .53994 L
s
.22665 .56455 m
.22812 .56341 L
s
.01 w
.20504 .59638 Mdot
.20504 .59638 Mdot
.20504 .59638 Mdot
.20504 .59638 Mdot
.20504 .59638 Mdot
.19057 .63127 m .21233 .58089 L .21569 .57267 L .668 .769 .29 r
F
0 g
.5 Mabswid
.48229 .63456 m
.48255 .6369 L
s
.48255 .6369 m
.48375 .64819 L
s
.44688 .56032 m
.45172 .5672 L
s
.24421 .7728 m
.25632 .78662 L
s
.22767 .75394 m
.24421 .7728 L
s
.22065 .74592 m
.22767 .75394 L
s
.20225 .72494 m
.20314 .72596 L
s
.19953 .72064 m
.20225 .72494 L
s
.01 w
.20225 .72494 Mdot
.20225 .72494 Mdot
.20225 .72494 Mdot
.20225 .72494 Mdot
.20225 .72494 Mdot
.5 Mabswid
.47251 .71923 m
.47365 .71658 L
s
.46894 .72747 m
.47251 .71923 L
s
.46796 .72974 m
.46894 .72747 L
s
.28345 .7966 m
.29101 .79939 L
s
.27943 .79513 m
.28345 .7966 L
s
.26186 .78866 m
.26294 .78905 L
s
.29475 .80077 m
.31473 .80812 L
s
.31473 .80812 m
.31712 .809 L
s
.29101 .79939 m
.29475 .80077 L
s
.25632 .78662 m
.25853 .78743 L
s
.25853 .78743 m
.26186 .78866 L
s
.24665 .77726 m
.25293 .78333 L
s
.25293 .78333 m
.25345 .78383 L
s
.25345 .78383 m
.25632 .78662 L
s
.22136 .746 m
.22834 .7541 L
s
.23591 .7629 m
.24139 .76927 L
s
.22834 .7541 m
.23591 .7629 L
s
.24139 .76927 m
.25632 .78662 L
s
.20269 .7243 m
.20288 .72453 L
s
.2024 .72397 m
.20269 .7243 L
s
.20189 .72337 m
.2024 .72397 L
s
.20185 .72333 m
.20189 .72337 L
s
.20151 .72293 m
.20185 .72333 L
s
.2015 .72292 m
.20151 .72293 L
s
.19953 .72064 m
.2015 .72292 L
s
.01 w
.25632 .78662 Mdot
.25632 .78662 Mdot
.25632 .78662 Mdot
.25632 .78662 Mdot
.25632 .78662 Mdot
.25632 .78662 Mdot
.5 Mabswid
.41394 .5032 m
.41671 .50856 L
s
.71336 .65848 m .68645 .76898 L .72606 .79405 L .553 .583 .839 r
F
.68122 .64493 m .68645 .76898 L .71336 .65848 L .625 .632 .838 r
F
.68122 .64493 m .64819 .75098 L .68645 .76898 L F
0 g
.68317 .73305 m
.68647 .72796 L
s
.65631 .77446 m
.66795 .75652 L
s
.64952 .63493 m .64819 .75098 L .68122 .64493 L .676 .661 .828 r
F
0 g
.66795 .75652 m
.68317 .73305 L
s
.64952 .63493 m .61365 .73979 L .64819 .75098 L .676 .661 .828 r
F
.634 1.22302 m .5174 1.32674 L .67083 1.23792 L .547 .222 .368 r
F
.634 1.22302 m .44196 1.29786 L .5174 1.32674 L F
0 g
.38037 1.22797 m
.44196 1.29786 L
s
.7799 1.09958 m .634 1.22302 L .67083 1.23792 L .277 .01 .317 r
F
.75924 1.07026 m .634 1.22302 L .7799 1.09958 L .511 .309 .542 r
F
.82402 .89209 m .75924 1.07026 L .83845 .92094 L .376 .293 .634 r
F
.83845 .92094 m .75924 1.07026 L .7799 1.09958 L .137 .043 .476 r
F
0 g
.64465 .95885 m
.80214 .97194 L
s
.76923 .90128 m
.80419 .94721 L
s
.74125 1.08132 m
.7804 1.03071 L
s
.5582 .71507 m
.5599 .67625 L
s
.55798 .72015 m
.5582 .71507 L
s
.44034 .88956 m
.44115 .88877 L
s
.44028 .88961 m
.44034 .88956 L
s
.43491 .89479 m
.43798 .89183 L
s
.43798 .89183 m
.44028 .88961 L
s
.43296 .89667 m
.43491 .89479 L
s
.42828 .90118 m
.43296 .89667 L
s
.48866 .84298 m
.50792 .82441 L
s
.50792 .82441 m
.5168 .81585 L
s
.5168 .81585 m
.52535 .80762 L
s
.52535 .80762 m
.52653 .80647 L
s
.52653 .80647 m
.52863 .80445 L
s
.52863 .80445 m
.54397 .78967 L
s
.54397 .78967 m
.55267 .78128 L
s
.74389 .67558 m .72606 .79405 L .76428 .82487 L .452 .508 .826 r
F
.71336 .65848 m .72606 .79405 L .74389 .67558 L .553 .583 .839 r
F
.21969 .56506 m .29252 .51668 L .22426 .55813 L .508 .886 .695 r
F
.22426 .55813 m .29252 .51668 L .30513 .50911 L 0 0 0 r
F
0 g
.29231 .51597 m
.29333 .51622 L
s
.29338 .51623 m
.29965 .51777 L
s
.27231 .52724 m
.27575 .52411 L
s
.29089 .51562 m
.29231 .51597 L
s
.58045 .73787 m
.58605 .72307 L
s
.58605 .72307 m
.58776 .71856 L
s
.57899 .74173 m
.57991 .73928 L
s
.5428 .78736 m
.55725 .7726 L
s
.54191 .78827 m
.5428 .78736 L
s
.19057 .63127 m .21569 .57267 L .21969 .56506 L 0 0 0 r
F
0 g
.21668 .57237 m
.22665 .56455 L
s
.2122 .57588 m
.21447 .5755 L
s
.21447 .5755 m
.21451 .5755 L
s
.21514 .57539 m
.22525 .57374 L
s
.2122 .57588 m
.21531 .57344 L
s
.21531 .57344 m
.21574 .5731 L
s
.21637 .57261 m
.21668 .57237 L
s
.21006 .58199 m
.2122 .57588 L
s
.20725 .59005 m
.21006 .58199 L
s
.20504 .59638 m
.20725 .59005 L
s
.61981 .62787 m .61365 .73979 L .64952 .63493 L .711 .673 .811 r
F
0 g
.48153 .82377 m
.49258 .81544 L
s
.49258 .81544 m
.51074 .80174 L
s
.51074 .80174 m
.52343 .79217 L
s
.52343 .79217 m
.52866 .78822 L
s
.52866 .78822 m
.53818 .78104 L
s
.58207 .7554 m
.63135 .7342 L
s
.63135 .7342 m
.66308 .72055 L
s
.66308 .72055 m
.67821 .71404 L
s
.67821 .71404 m
.68432 .71141 L
s
.68432 .71141 m
.68825 .70972 L
s
.57605 .75799 m
.58207 .7554 L
s
.56709 .76184 m
.57605 .75799 L
s
.56598 .76232 m
.56709 .76184 L
s
.57875 .73315 m
.5944 .70762 L
s
.57329 .74207 m
.57875 .73315 L
s
.5944 .70762 m
.59613 .7048 L
s
.57137 .7452 m
.57329 .74207 L
s
.41759 .7844 m
.42042 .78232 L
s
.4128 .78792 m
.41759 .7844 L
s
.41899 .50905 m
.43261 .50921 L
s
.39889 .50476 m
.41394 .5032 L
s
.32251 .51164 m
.32314 .51159 L
s
.32314 .51159 m
.32865 .51115 L
s
.01 w
.2122 .57588 Mdot
.2122 .57588 Mdot
.2122 .57588 Mdot
.2122 .57588 Mdot
.2122 .57588 Mdot
.5 Mabswid
.50466 .70231 m
.50906 .6768 L
s
.50412 .70545 m
.50466 .70231 L
s
.50378 .70739 m
.50412 .70545 L
s
.50286 .71275 m
.50378 .70739 L
s
.52327 .61986 m
.52699 .60945 L
s
.52165 .62441 m
.52327 .61986 L
s
.4996 .59851 m
.50479 .61394 L
s
.49751 .59229 m
.4996 .59851 L
s
.49446 .58325 m
.49751 .59229 L
s
.49428 .5827 m
.49446 .58325 L
s
.49423 .58255 m
.49428 .5827 L
s
.49422 .58252 m
.49423 .58255 L
s
.74389 .67558 m .76428 .82487 L .77033 .69564 L .452 .508 .826 r
F
.77033 .69564 m .76428 .82487 L .79805 .85877 L .305 .392 .788 r
F
0 g
.76913 .76759 m
.7692 .76758 L
s
.65539 .79052 m
.76913 .76759 L
s
.4078 .893 m
.41513 .89091 L
s
.43614 .88557 m
.4374 .88516 L
s
.49492 .76359 m
.49764 .75627 L
s
.50063 .74821 m
.50244 .74334 L
s
.49764 .75627 m
.50063 .74821 L
s
.50244 .74334 m
.50975 .72361 L
s
.50975 .72361 m
.51199 .71758 L
s
.48455 .79156 m
.49492 .76359 L
s
.48021 .80324 m
.48455 .79156 L
s
.47492 .81751 m
.47857 .80767 L
s
.47857 .80767 m
.48021 .80324 L
s
.47408 .81976 m
.47421 .81941 L
s
.19057 .63127 m .21969 .56506 L .22426 .55813 L 0 0 0 r
F
0 g
.46537 .78804 m
.46609 .78691 L
s
.46118 .79462 m
.46537 .78804 L
s
.4608 .79522 m
.46118 .79462 L
s
.46609 .78691 m
.46854 .78306 L
s
.46854 .78306 m
.47612 .77117 L
s
.47612 .77117 m
.47663 .77037 L
s
.51476 .71486 m
.52621 .70005 L
s
.47895 .81575 m
.48039 .81362 L
s
.48039 .81362 m
.4861 .80521 L
s
.4861 .80521 m
.4888 .80123 L
s
.47333 .82403 m
.47895 .81575 L
s
.47294 .82461 m
.47333 .82403 L
s
.57626 .70853 m
.58396 .70186 L
s
.58396 .70186 m
.59602 .69143 L
s
.59602 .69143 m
.59786 .68984 L
s
.53303 .74594 m
.5513 .73013 L
s
.5513 .73013 m
.5675 .71611 L
s
.5675 .71611 m
.57626 .70853 L
s
.52968 .74884 m
.53303 .74594 L
s
.52966 .74886 m
.52968 .74884 L
s
.52797 .73091 m
.53844 .7038 L
s
.53844 .7038 m
.54409 .68917 L
s
.31712 .809 m
.3241 .80831 L
s
.22426 .55813 m .30513 .50911 L .22932 .55193 L 0 0 0 r
F
.22932 .55193 m .30513 .50911 L .31894 .50286 L F
0 g
.2996 .51345 m
.32251 .51164 L
s
.2863 .51449 m
.2971 .51364 L
s
.2863 .51449 m
.29089 .51562 L
s
.28552 .5152 m
.2863 .51449 L
s
.27577 .52409 m
.28552 .5152 L
s
.27575 .52411 m
.27577 .52409 L
s
.23123 .55459 m
.23323 .55347 L
s
.23323 .55347 m
.23494 .5525 L
s
.57233 .63542 m
.57318 .63409 L
s
.52667 .70591 m
.53395 .67385 L
s
.5171 .74798 m
.52667 .70591 L
s
.53395 .67385 m
.53435 .67211 L
s
.53435 .67211 m
.53666 .66193 L
s
.51583 .75359 m
.5171 .74798 L
s
.47623 .83824 m
.48157 .83124 L
s
.43991 .88591 m
.43993 .88589 L
s
.43993 .88589 m
.44019 .88555 L
s
.43584 .89126 m
.43627 .8907 L
s
.43627 .8907 m
.43991 .88591 L
s
.43507 .89226 m
.43584 .89126 L
s
.43228 .89593 m
.43507 .89226 L
s
.42828 .90118 m
.43228 .89593 L
s
.48157 .83124 m
.48805 .82274 L
s
.48805 .82274 m
.49012 .82001 L
s
.49012 .82001 m
.49307 .81614 L
s
.49307 .81614 m
.49387 .81509 L
s
.49387 .81509 m
.49887 .80853 L
s
.44047 .9141 m
.44237 .91075 L
s
.44036 .9143 m
.44047 .9141 L
s
.43933 .9161 m
.44036 .9143 L
s
.43883 .91699 m
.43912 .91647 L
s
.48405 .83744 m
.49107 .82509 L
s
.49107 .82509 m
.49667 .81524 L
s
.49667 .81524 m
.49803 .81285 L
s
.49803 .81285 m
.50126 .80717 L
s
.21165 .73529 m
.21578 .74028 L
s
.20257 .7243 m
.20291 .72471 L
s
.2022 .72386 m
.20257 .7243 L
s
.20197 .72358 m
.2022 .72386 L
s
.20151 .72302 m
.20197 .72358 L
s
.20148 .72298 m
.20151 .72302 L
s
.20118 .72263 m
.20148 .72298 L
s
.20117 .72262 m
.20118 .72263 L
s
.19953 .72064 m
.20117 .72262 L
s
.19912 .71522 m
.19914 .71548 L
s
.19914 .71548 m
.19924 .71671 L
s
.19924 .71671 m
.19924 .71674 L
s
.19924 .71674 m
.19929 .7174 L
s
.19929 .7174 m
.19929 .71741 L
s
.19929 .71741 m
.19953 .72064 L
s
.01 w
.19953 .72064 Mdot
.19953 .72064 Mdot
.19953 .72064 Mdot
.19953 .72064 Mdot
.19953 .72064 Mdot
.5 Mabswid
.382 .91584 m
.40234 .89416 L
s
.2492 .5407 m
.2863 .51449 L
s
.01 w
.2863 .51449 Mdot
.2863 .51449 Mdot
.2863 .51449 Mdot
.2863 .51449 Mdot
.2863 .51449 Mdot
.2863 .51449 Mdot
.5 Mabswid
.46109 .81209 m
.46859 .79562 L
s
.46009 .8143 m
.46109 .81209 L
s
.45838 .81804 m
.46009 .8143 L
s
.46859 .79562 m
.46976 .79303 L
s
.46043 .78392 m
.46701 .77822 L
s
.45791 .7861 m
.46043 .78392 L
s
.46701 .77822 m
.46898 .77651 L
s
.62624 .66271 m
.63038 .65828 L
s
.62468 .66438 m
.62624 .66271 L
s
.61892 .67054 m
.62468 .66438 L
s
.61145 .6447 m
.6117 .64815 L
s
.19057 .63127 m .22426 .55813 L .22932 .55193 L 0 0 0 r
F
0 g
.22528 .55794 m
.22587 .55761 L
s
.22679 .55709 m
.23123 .55459 L
s
.21781 .56712 m
.22033 .56319 L
s
.2122 .57588 m
.21781 .56712 L
s
.43098 .51606 m
.43241 .51714 L
s
.43082 .51595 m
.43098 .51606 L
s
.43241 .51714 m
.45065 .5309 L
s
.42994 .51528 m
.43082 .51595 L
s
.41394 .5032 m
.42274 .50984 L
s
.43841 .88314 m
.43916 .88234 L
s
.43818 .88338 m
.43841 .88314 L
s
.43614 .88557 m
.43818 .88338 L
s
.78999 .71749 m .79805 .85877 L .82402 .89209 L .064 .199 .695 r
F
.77033 .69564 m .79805 .85877 L .78999 .71749 L .305 .392 .788 r
F
0 g
.7587 .85256 m
.77594 .80667 L
s
.77594 .80667 m
.77618 .80602 L
s
.31556 .80609 m
.31567 .8063 L
s
.31567 .8063 m
.31574 .80643 L
s
.31574 .80643 m
.31622 .80733 L
s
.31622 .80733 m
.31692 .80862 L
s
.31692 .80862 m
.31712 .809 L
s
.34333 .818 m
.37795 .82989 L
s
.34271 .81779 m
.34333 .818 L
s
.33335 .81457 m
.34271 .81779 L
s
.33195 .81409 m
.33335 .81457 L
s
.32133 .81045 m
.33195 .81409 L
s
.31712 .809 m
.32133 .81045 L
s
.3774 .82368 m
.38223 .82486 L
s
.36536 .82075 m
.37375 .8228 L
s
.36514 .8207 m
.36536 .82075 L
s
.35725 .81878 m
.36145 .8198 L
s
.35359 .81788 m
.35725 .81878 L
s
.35077 .8172 m
.35359 .81788 L
s
.34435 .81563 m
.35077 .8172 L
s
.33829 .81416 m
.34435 .81563 L
s
.33414 .81315 m
.33829 .81416 L
s
.33287 .81284 m
.33414 .81315 L
s
.33122 .81244 m
.33287 .81284 L
s
.31901 .80946 m
.33122 .81244 L
s
.31712 .809 m
.31901 .80946 L
s
.01 w
.31712 .809 Mdot
.31712 .809 Mdot
.31712 .809 Mdot
.5 Mabswid
.34115 .81366 m
.3487 .81512 L
s
.33751 .81295 m
.34115 .81366 L
s
.32836 .81118 m
.32905 .81131 L
s
.33701 .81285 m
.33751 .81295 L
s
.33537 .81254 m
.33701 .81285 L
s
.31712 .809 m
.32836 .81118 L
s
.30455 .80171 m
.30552 .80227 L
s
.30552 .80227 m
.30955 .80461 L
s
.30955 .80461 m
.31016 .80496 L
s
.31016 .80496 m
.31277 .80648 L
s
.31277 .80648 m
.31609 .8084 L
s
.31609 .8084 m
.31618 .80845 L
s
.31618 .80845 m
.31712 .809 L
s
.28461 .79404 m
.30156 .80184 L
s
.30156 .80184 m
.31467 .80787 L
s
.31467 .80787 m
.31712 .809 L
s
.01 w
.31712 .809 Mdot
.31712 .809 Mdot
.31712 .809 Mdot
.31712 .809 Mdot
.31712 .809 Mdot
.31712 .809 Mdot
.22932 .55193 m .31894 .50286 L .23475 .54651 L 0 0 0 r
F
0 g
.5 Mabswid
.24299 .54508 m
.24704 .54222 L
s
.19057 .63127 m .22932 .55193 L .23475 .54651 L 0 0 .033 r
F
0 g
.23114 .55345 m
.24299 .54508 L
s
.22033 .56319 m
.22279 .55934 L
s
.22279 .55934 m
.22528 .55794 L
s
.22558 .55738 m
.22722 .55622 L
s
.22279 .55934 m
.22558 .55738 L
s
.70639 .697 m
.70658 .6967 L
s
.69462 .66916 m
.69629 .67677 L
s
.23475 .54651 m .31894 .50286 L .33363 .49787 L 0 0 0 r
F
0 g
.2863 .51449 m
.2966 .50987 L
s
.26524 .5283 m
.2863 .51449 L
s
.01 w
.22279 .55934 Mdot
.22279 .55934 Mdot
.22279 .55934 Mdot
.22279 .55934 Mdot
.22279 .55934 Mdot
.19057 .63127 m .20267 .72012 L .20292 .72478 L 0 0 .15 r
F
0 g
.5 Mabswid
.199 .71357 m
.19912 .71522 L
s
.19895 .71295 m
.199 .71357 L
s
.53989 .52837 m .59294 .62276 L .61981 .62787 L .564 .633 .878 r
F
0 g
.58652 .61696 m
.58985 .62951 L
s
.58616 .61562 m
.58652 .61696 L
s
.57318 .63409 m
.57917 .62476 L
s
.5599 .67625 m
.56203 .62744 L
s
.20301 .71463 m .26156 .78774 L .20267 .72012 L 0 0 .528 r
F
0 g
.24528 .77594 m
.25093 .77854 L
s
.25093 .77854 m
.2553 .78055 L
s
.25796 .78178 m
.25826 .78191 L
s
.22596 .75258 m
.24528 .77594 L
s
.21578 .74028 m
.22596 .75258 L
s
.24528 .77594 m
.24665 .77726 L
s
.25436 .77988 m
.25675 .78093 L
s
.24528 .77594 m
.25436 .77988 L
s
.29663 .79826 m
.30455 .80171 L
s
.27459 .78868 m
.29663 .79826 L
s
.26568 .78481 m
.27459 .78868 L
s
.25755 .78127 m
.25818 .78155 L
s
.21808 .73781 m
.24528 .77594 L
s
.01 w
.24528 .77594 Mdot
.24528 .77594 Mdot
.24528 .77594 Mdot
.24528 .77594 Mdot
.24528 .77594 Mdot
.24528 .77594 Mdot
.23475 .54651 m .33363 .49787 L .24045 .54193 L 0 0 0 r
F
.19057 .63127 m .23475 .54651 L .24045 .54193 L 0 0 .113 r
F
.19057 .63127 m .27625 .56787 L .27266 .57617 L .022 0 .223 r
F
.19057 .63127 m .27882 .56031 L .27625 .56787 L .027 0 .231 r
F
.19057 .63127 m .28033 .55356 L .27882 .56031 L .037 0 .247 r
F
.19057 .63127 m .28074 .54769 L .28033 .55356 L .051 0 .267 r
F
.19057 .63127 m .28006 .54274 L .28074 .54769 L .067 0 .288 r
F
0 g
.5 Mabswid
.22279 .55934 m
.2248 .55751 L
s
.19057 .63127 m .27835 .53875 L .28006 .54274 L .082 0 .308 r
F
.19057 .63127 m .27568 .53573 L .27835 .53875 L .095 0 .323 r
F
.19057 .63127 m .27215 .5337 L .27568 .53573 L .103 0 .332 r
F
.19057 .63127 m .26789 .53267 L .27215 .5337 L .105 0 .334 r
F
.19057 .63127 m .26302 .53262 L .26789 .53267 L .097 0 .326 r
F
.24045 .54193 m .33363 .49787 L .3489 .49409 L .031 0 0 r
F
.24045 .54193 m .3489 .49409 L .24626 .53822 L F
.3489 .49409 m .47302 .52057 L .36447 .4915 L .182 .659 .931 r
F
.26773 .52974 m .3489 .49409 L .36447 .4915 L .126 0 0 r
F
.24626 .53822 m .25812 .53313 L .26773 .52974 L F
.25812 .53313 m .3489 .49409 L .26773 .52974 L F
.24626 .53822 m .36447 .4915 L .25206 .53542 L F
.25206 .53542 m .34401 .50285 L .2577 .53354 L .205 0 0 r
F
.36447 .4915 m .47302 .52057 L .49473 .52263 L .198 .66 .942 r
F
.36447 .4915 m .49473 .52263 L .38004 .49009 L F
.34401 .50285 m .38004 .49009 L .35722 .49819 L .205 0 0 r
F
.34401 .50285 m .35722 .49819 L .2577 .53354 L F
.19057 .63127 m .2577 .53354 L .26302 .53262 L .079 0 .308 r
F
0 g
.25854 .53269 m
.26524 .5283 L
s
.2578 .53318 m
.25854 .53269 L
s
.19057 .63127 m .25206 .53542 L .2577 .53354 L .048 0 .278 r
F
0 g
.2248 .55751 m
.22631 .55614 L
s
.19057 .63127 m .24626 .53822 L .25206 .53542 L .003 0 .236 r
F
.19057 .63127 m .24045 .54193 L .24626 .53822 L 0 0 .181 r
F
0 g
.23966 .54507 m
.23985 .54494 L
s
.22767 .5549 m
.22866 .554 L
s
.22866 .554 m
.2295 .55323 L
s
.22631 .55614 m
.22767 .5549 L
s
.2295 .55323 m
.22968 .55307 L
s
.23075 .5521 m
.23088 .55198 L
s
.23088 .55198 m
.23543 .54784 L
s
.23017 .55262 m
.23075 .5521 L
s
.22968 .55307 m
.23017 .55262 L
s
.23825 .54599 m
.23877 .54565 L
s
.23794 .54619 m
.23825 .54599 L
s
.23745 .54651 m
.2375 .54648 L
s
.23543 .54784 m
.23745 .54651 L
s
.2375 .54648 m
.23772 .54633 L
s
.23772 .54633 m
.23794 .54619 L
s
.23877 .54565 m
.23891 .54556 L
s
.23951 .54516 m
.23966 .54507 L
s
.23891 .54556 m
.23951 .54516 L
s
.19057 .63127 m .20301 .71463 L .20267 .72012 L 0 0 .24 r
F
.19057 .63127 m .204 .70835 L .20301 .71463 L 0 0 .318 r
F
0 g
.19878 .71076 m
.19895 .71295 L
s
.20133 .71432 m
.20202 .71529 L
s
.20017 .71271 m
.20117 .7141 L
s
.20117 .7141 m
.20133 .71432 L
s
.1988 .71078 m
.20017 .71271 L
s
.19878 .71076 m
.1988 .71078 L
s
.19057 .63127 m .20571 .7013 L .204 .70835 L 0 0 .38 r
F
.19057 .63127 m .20818 .69352 L .20571 .7013 L 0 0 .423 r
F
.19057 .63127 m .21144 .68508 L .20818 .69352 L 0 0 .447 r
F
.19057 .63127 m .21547 .67604 L .21144 .68508 L 0 0 .455 r
F
.19057 .63127 m .22022 .6665 L .21547 .67604 L 0 0 .449 r
F
.19057 .63127 m .22561 .65653 L .22022 .6665 L .021 0 .434 r
F
.19057 .63127 m .23152 .64626 L .22561 .65653 L .044 0 .409 r
F
.19057 .63127 m .23781 .63581 L .23152 .64626 L .056 0 .38 r
F
.19057 .63127 m .24429 .62529 L .23781 .63581 L .058 0 .346 r
F
.19057 .63127 m .25077 .61483 L .24429 .62529 L .054 0 .312 r
F
.19057 .63127 m .25704 .60457 L .25077 .61483 L .046 0 .281 r
F
.19057 .63127 m .2629 .59463 L .25704 .60457 L .036 0 .254 r
F
.19057 .63127 m .26817 .58512 L .2629 .59463 L .028 0 .234 r
F
.19057 .63127 m .27266 .57617 L .26817 .58512 L .023 0 .224 r
F
0 g
.19057 .63127 m
.2122 .57588 L
s
.19057 .63127 m
.20504 .59638 L
s
.19057 .63127 m
.20225 .72494 L
s
.19057 .63127 m
.19953 .72064 L
s
.19057 .63127 m
.22279 .55934 L
s
.19057 .63127 m
.2645 .56234 L
s
.19057 .63127 m
.26441 .54938 L
s
.25646 .54514 m
.25844 .54255 L
s
.19057 .63127 m
.25646 .54514 L
s
.24455 .54755 m
.24807 .54209 L
s
.19057 .63127 m
.24455 .54755 L
s
.19057 .63127 m
.23543 .54784 L
s
.19057 .63127 m
.19878 .71076 L
s
.19057 .63127 m
.20142 .69563 L
s
.19057 .63127 m
.20832 .67591 L
s
.19057 .63127 m
.21936 .65275 L
s
.19057 .63127 m
.23313 .62782 L
s
.01 w
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.19057 .63127 Mdot
.56302 .53268 m .61981 .62787 L .64952 .63493 L .528 .63 .895 r
F
.53989 .52837 m .61981 .62787 L .56302 .53268 L .564 .633 .878 r
F
0 g
.5 Mabswid
.56338 .59662 m
.5634 .59604 L
s
.56344 .59507 m
.56356 .59243 L
s
.5634 .59604 m
.56344 .59507 L
s
.56203 .62744 m
.56338 .59662 L
s
.42097 .82831 m
.42347 .82666 L
s
.44231 .90736 m
.44362 .90374 L
s
.44362 .90374 m
.44475 .90061 L
s
.44475 .90061 m
.44558 .89833 L
s
.44026 .91304 m
.44231 .90736 L
s
.43988 .91408 m
.44026 .91304 L
s
.43917 .91604 m
.43988 .91408 L
s
.43883 .91699 m
.43905 .91637 L
s
.45454 .9231 m
.45467 .92235 L
s
.46883 .839 m
.46895 .83833 L
s
.41683 .84295 m
.42054 .83525 L
s
.39591 .81476 m
.40554 .81269 L
s
.39487 .81499 m
.39591 .81476 L
s
.46677 .5216 m
.47049 .52295 L
s
.46274 .52013 m
.46677 .5216 L
s
.45878 .5187 m
.46274 .52013 L
s
.47049 .52295 m
.47379 .52414 L
s
.19878 .71076 m
.20159 .7137 L
s
.20159 .7137 m
.20225 .7144 L
s
.2062 .71854 m
.20944 .72193 L
s
.2 .70378 m
.20142 .69563 L
s
.19878 .71076 m
.2 .70378 L
s
.01 w
.19878 .71076 Mdot
.19878 .71076 Mdot
.19878 .71076 Mdot
.19878 .71076 Mdot
.19878 .71076 Mdot
.5 Mabswid
.42703 .50342 m
.44144 .50366 L
s
.31981 .49944 m
.3323 .49994 L
s
.3323 .49994 m
.33382 .5 L
s
.34442 .50042 m
.34916 .50061 L
s
.34916 .50061 m
.35021 .50066 L
s
.35028 .50066 m
.35861 .50099 L
s
.34212 .50033 m
.34442 .50042 L
s
.35861 .50099 m
.36797 .50137 L
s
.36797 .50137 m
.36895 .50141 L
s
.53655 .55463 m
.53693 .55588 L
s
.49968 .53238 m
.51344 .54476 L
s
.51344 .54476 m
.51612 .54718 L
s
.43648 .88868 m
.43748 .88715 L
s
.42829 .90116 m
.43648 .88868 L
s
.7799 1.09958 m .67083 1.23792 L .78333 1.10948 L .277 .01 .317 r
F
.83743 .942 m .7799 1.09958 L .78333 1.10948 L 0 0 0 r
F
.83845 .92094 m .7799 1.09958 L .83743 .942 L .137 .043 .476 r
F
0 g
.30169 .50758 m
.31056 .5036 L
s
.2966 .50987 m
.30169 .50758 L
s
.31056 .5036 m
.31981 .49944 L
s
.31981 .49944 m
.32604 .50071 L
s
.32604 .50071 m
.32637 .50078 L
s
.32637 .50078 m
.32784 .50108 L
s
.336 .50275 m
.33892 .50335 L
s
.58591 .53848 m .64952 .63493 L .68122 .64493 L .46 .61 .912 r
F
.56302 .53268 m .64952 .63493 L .58591 .53848 L .528 .63 .895 r
F
0 g
.60886 .60841 m
.61145 .6447 L
s
.60882 .60781 m
.60886 .60841 L
s
.59328 .6028 m
.59619 .59828 L
s
.57917 .62476 m
.59328 .6028 L
s
.78999 .71749 m .82402 .89209 L .80346 .76068 L .064 .199 .695 r
F
.80017 .73965 m .82402 .89209 L .83845 .92094 L 0 0 .448 r
F
.79844 .76062 m .83509 .90748 L .83743 .942 L .856 .6 .063 r
F
.83509 .90748 m .83845 .92094 L .83836 .92269 L F
.83509 .90748 m .83836 .92269 L .83743 .942 L F
.79783 .73456 m .80346 .76068 L .80017 .73965 L .064 .199 .695 r
F
.78999 .71749 m .80346 .76068 L .79783 .73456 L F
.204 .70835 m .25834 .78223 L .20301 .71463 L 0 .08 .631 r
F
0 g
.24507 .77434 m
.24528 .77594 L
s
.204 .70835 m .25675 .77541 L .25834 .78223 L 0 .08 .631 r
F
0 g
.24434 .76885 m
.24507 .77434 L
s
.23543 .54784 m
.23848 .54609 L
s
.23848 .54609 m
.23856 .54604 L
s
.23856 .54604 m
.23888 .54586 L
s
.23888 .54586 m
.2392 .54567 L
s
.2392 .54567 m
.23962 .54543 L
s
.23962 .54543 m
.2404 .54498 L
s
.2404 .54498 m
.24049 .54494 L
s
.24049 .54494 m
.24119 .54453 L
s
.24119 .54453 m
.24142 .5444 L
s
.2615 .53288 m
.26347 .53175 L
s
.26347 .53175 m
.26467 .53106 L
s
.26519 .53077 m
.26533 .53069 L
s
.27716 .5239 m
.31981 .49944 L
s
.26994 .52804 m
.27716 .5239 L
s
.23543 .54784 m
.24807 .54209 L
s
.01 w
.23543 .54784 Mdot
.23543 .54784 Mdot
.23543 .54784 Mdot
.23543 .54784 Mdot
.23543 .54784 Mdot
.58591 .53848 m .68122 .64493 L .60778 .54611 L .46 .61 .912 r
F
0 g
.5 Mabswid
.59619 .59828 m
.59748 .59627 L
s
.60778 .54611 m .68122 .64493 L .71336 .65848 L .34 .56 .918 r
F
.67083 1.23792 m .5174 1.32674 L .58102 1.30335 L 0 0 0 r
F
.67083 1.23792 m .58102 1.30335 L .68599 1.21767 L F
0 g
.66319 1.23958 m
.67171 1.23993 L
s
.38037 1.22797 m
.65934 1.23942 L
s
.57226 1.18839 m
.66376 1.23581 L
s
.44196 1.29786 m
.5174 1.32674 L
s
.38037 1.22797 m
.55436 1.31292 L
s
.55463 1.31305 m
.56292 1.3171 L
s
.78333 1.10948 m .67083 1.23792 L .68599 1.21767 L .58 .856 .522 r
F
0 g
.66876 1.2384 m
.67171 1.23993 L
s
.66655 1.23726 m
.66876 1.2384 L
s
.24807 .54209 m
.25389 .53863 L
s
.25389 .53863 m
.25393 .53861 L
s
.25393 .53861 m
.25405 .53854 L
s
.25405 .53854 m
.25424 .53842 L
s
.25424 .53842 m
.25425 .53842 L
s
.28262 .52155 m
.31981 .49944 L
s
.01 w
.31981 .49944 Mdot
.31981 .49944 Mdot
.31981 .49944 Mdot
.31981 .49944 Mdot
.31981 .49944 Mdot
.31981 .49944 Mdot
.5 Mabswid
.40234 .89416 m
.4171 .8981 L
s
.38612 .49164 m .49473 .52263 L .51704 .52514 L .185 .65 .938 r
F
.38576 .49171 m .49473 .52263 L .38612 .49164 L F
.38004 .49009 m .51704 .52514 L .39534 .48988 L F
.2577 .53354 m .39437 .49019 L .26302 .53262 L .272 0 0 r
F
.39437 .49019 m .39534 .48988 L .39441 .49018 L F
.39437 .49019 m .39441 .49018 L .26302 .53262 L F
.38004 .49009 m .38576 .49171 L .38612 .49164 L .185 .65 .938 r
F
0 g
.47278 .51784 m
.47923 .5375 L
s
.47264 .51741 m
.47265 .51745 L
s
.47272 .51765 m
.47278 .51784 L
s
.47265 .51745 m
.47272 .51765 L
s
.47811 .51296 m
.47959 .51429 L
s
.48394 .51821 m
.48415 .5184 L
s
.48433 .51855 m
.48453 .51874 L
s
.48415 .5184 m
.48433 .51855 L
s
.48453 .51874 m
.49968 .53238 L
s
.38659 .49842 m
.38699 .49849 L
s
.20571 .7013 m .25675 .77541 L .204 .70835 L 0 .166 .705 r
F
0 g
.21157 .72416 m
.21841 .73134 L
s
.24352 .76275 m
.24388 .7654 L
s
.24388 .7654 m
.24434 .76885 L
s
.5987 .56935 m
.5988 .5695 L
s
.5988 .5695 m
.599 .56979 L
s
.599 .56979 m
.60033 .57175 L
s
.57501 .55475 m
.57578 .5554 L
s
.57578 .5554 m
.57634 .55586 L
s
.62753 .5558 m .71336 .65848 L .74389 .67558 L .134 .453 .884 r
F
.60778 .54611 m .71336 .65848 L .62753 .5558 L .34 .56 .918 r
F
0 g
.68651 .63208 m
.688 .6389 L
s
.688 .6389 m
.69462 .66916 L
s
.63038 .65828 m
.6658 .62039 L
s
.37004 .82566 m
.37029 .8251 L
s
.37029 .8251 m
.37045 .82474 L
s
.37045 .82474 m
.37051 .82461 L
s
.30616 .80213 m
.31015 .80319 L
s
.31015 .80319 m
.31961 .8057 L
s
.30455 .80171 m
.30616 .80213 L
s
.20142 .69563 m
.20402 .69948 L
s
.20402 .69948 m
.20439 .70003 L
s
.20142 .69563 m
.20476 .69772 L
s
.20476 .69772 m
.20481 .69775 L
s
.20347 .68978 m
.206 .68253 L
s
.20142 .69563 m
.20347 .68978 L
s
.20608 .6823 m
.20832 .67591 L
s
.206 .68253 m
.20608 .6823 L
s
.01 w
.20142 .69563 Mdot
.20142 .69563 Mdot
.20142 .69563 Mdot
.20142 .69563 Mdot
.20142 .69563 Mdot
.25206 .53542 m .36447 .4915 L .38004 .49009 L .205 0 0 r
F
0 g
.5 Mabswid
.37908 .4971 m
.38659 .49842 L
s
.26399 .53263 m
.26517 .53193 L
s
.26789 .53031 m
.2695 .52935 L
s
.27338 .52704 m
.28262 .52155 L
s
.27096 .52848 m
.27338 .52704 L
s
.26995 .52908 m
.27096 .52848 L
s
.31981 .49944 m
.33992 .4958 L
s
.37162 .4958 m
.37489 .49637 L
s
.37512 .49641 m
.37908 .4971 L
s
.39534 .48988 m .51704 .52514 L .53989 .52837 L .132 .621 .914 r
F
0 g
.44745 .50376 m
.46827 .5041 L
s
.46827 .5041 m
.47648 .51149 L
s
.46827 .5041 m
.47014 .5098 L
s
.20571 .7013 m .25718 .76715 L .25675 .77541 L 0 .166 .705 r
F
0 g
.4534 .91535 m
.45363 .91692 L
s
.45285 .9116 m
.4534 .91535 L
s
.45439 .92209 m
.45454 .9231 L
s
.46596 .90795 m
.4661 .90831 L
s
.4078 .893 m
.41009 .89575 L
s
.44413 .93647 m
.44586 .93854 L
s
.44381 .93609 m
.44413 .93647 L
s
.43253 .92259 m
.43283 .92295 L
s
.41724 .9043 m
.43253 .92259 L
s
.43283 .92295 m
.44381 .93609 L
s
.41061 .89637 m
.41724 .9043 L
s
.01 w
.4078 .893 Mdot
.4078 .893 Mdot
.4078 .893 Mdot
.20818 .69352 m .25718 .76715 L .20571 .7013 L .004 .235 .744 r
F
0 g
.5 Mabswid
.23233 .74593 m
.24273 .75683 L
s
.21841 .73134 m
.23233 .74593 L
s
.24273 .75683 m
.24306 .75929 L
s
.24306 .75929 m
.24352 .76275 L
s
.23248 .74164 m
.24273 .75683 L
s
.22387 .7289 m
.23248 .74164 L
s
.21436 .71481 m
.22387 .7289 L
s
.43724 .50104 m
.46827 .5041 L
s
.01 w
.46827 .5041 Mdot
.46827 .5041 Mdot
.46827 .5041 Mdot
.46827 .5041 Mdot
.46827 .5041 Mdot
.46827 .5041 Mdot
.5 Mabswid
.24807 .54209 m
.25535 .53876 L
s
.25535 .53876 m
.2554 .53874 L
s
.2554 .53874 m
.25552 .53868 L
s
.25552 .53868 m
.25568 .53861 L
s
.24807 .54209 m
.25844 .54255 L
s
.01 w
.24807 .54209 Mdot
.24807 .54209 Mdot
.24807 .54209 Mdot
.24807 .54209 Mdot
.24807 .54209 Mdot
.2577 .53354 m .38004 .49009 L .39534 .48988 L .272 0 0 r
F
0 g
.5 Mabswid
.26841 .53279 m
.28268 .52627 L
s
.28719 .52421 m
.2979 .51931 L
s
.36502 .49464 m
.36533 .4947 L
s
.36533 .4947 m
.36584 .49479 L
s
.64388 .56759 m .74389 .67558 L .77033 .69564 L 0 .24 .739 r
F
.62753 .5558 m .74389 .67558 L .65037 .57459 L .134 .453 .884 r
F
.65541 .58135 m .75599 .68138 L .78999 .71749 L .58 .075 0 r
F
.75599 .68138 m .77033 .69564 L .77269 .69826 L F
.75599 .68138 m .77269 .69826 L .78999 .71749 L F
.64234 .56648 m .65037 .57459 L .64388 .56759 L .134 .453 .884 r
F
.62753 .5558 m .65037 .57459 L .64234 .56648 L F
0 g
.6805 .60467 m
.6805 .60466 L
s
.6805 .60466 m
.68051 .60468 L
s
.66785 .6182 m
.66943 .6165 L
s
.6658 .62039 m
.66785 .6182 L
s
.68048 .60465 m
.6805 .60466 L
s
.43614 .88557 m
.43674 .8888 L
s
.43674 .8888 m
.43688 .88959 L
s
.4403 .88892 m
.44036 .88896 L
s
.43742 .8866 m
.43793 .88701 L
s
.43992 .88861 m
.4403 .88892 L
s
.43793 .88701 m
.43992 .88861 L
s
.4371 .88634 m
.43742 .8866 L
s
.43614 .88557 m
.4371 .88634 L
s
.4407 .88924 m
.44148 .88986 L
s
.4761 .9177 m
.47864 .91975 L
s
.44036 .88896 m
.4407 .88924 L
s
.43979 .88656 m
.44055 .88676 L
s
.4369 .88578 m
.43979 .88656 L
s
.43643 .88565 m
.4369 .88578 L
s
.43614 .88557 m
.43643 .88565 L
s
.01 w
.43614 .88557 Mdot
.43614 .88557 Mdot
.43614 .88557 Mdot
.43614 .88557 Mdot
.43614 .88557 Mdot
.43614 .88557 Mdot
.80017 .73965 m .83845 .92094 L .79844 .76062 L 0 0 .448 r
F
0 g
.5 Mabswid
.81241 .7976 m
.81333 .79919 L
s
.81333 .79919 m
.81422 .80073 L
s
.81422 .80073 m
.8166 .80487 L
s
.82589 .94412 m
.82813 .89871 L
s
.82891 .88291 m
.82964 .8681 L
s
.8206 .8367 m
.82141 .83625 L
s
.757 .872 m
.81541 .83958 L
s
.82026 .83689 m
.8206 .8367 L
s
.39534 .48988 m .53989 .52837 L .41002 .49095 L .132 .621 .914 r
F
.41002 .49095 m .53989 .52837 L .56302 .53268 L .028 .56 .855 r
F
0 g
.45172 .50233 m
.46827 .5041 L
s
.41553 .4989 m
.41574 .49892 L
s
.32752 .81011 m
.33435 .8126 L
s
.32509 .80922 m
.32752 .81011 L
s
.36758 .82476 m
.37004 .82566 L
s
.36388 .8234 m
.36758 .82476 L
s
.3477 .81748 m
.36388 .8234 L
s
.33912 .81435 m
.3477 .81748 L
s
.33435 .8126 m
.33912 .81435 L
s
.31562 .80576 m
.31853 .80682 L
s
.31853 .80682 m
.32509 .80922 L
s
.30759 .80282 m
.31562 .80576 L
s
.30455 .80171 m
.30759 .80282 L
s
.3063 .7977 m
.30833 .79309 L
s
.30455 .80171 m
.3063 .7977 L
s
.28781 .78956 m
.30455 .80171 L
s
.26911 .77598 m
.28781 .78956 L
s
.24273 .75683 m
.24779 .7605 L
s
.24779 .7605 m
.25222 .76372 L
s
.01 w
.30455 .80171 Mdot
.30455 .80171 Mdot
.30455 .80171 Mdot
.30455 .80171 Mdot
.30455 .80171 Mdot
.30455 .80171 Mdot
.5 Mabswid
.26528 .7648 m
.26747 .76557 L
s
.01 w
.24273 .75683 Mdot
.24273 .75683 Mdot
.24273 .75683 Mdot
.24273 .75683 Mdot
.24273 .75683 Mdot
.24273 .75683 Mdot
.20818 .69352 m .26001 .75739 L .25718 .76715 L .004 .235 .744 r
F
0 g
.5 Mabswid
.25276 .76038 m
.25442 .76096 L
s
.21144 .68508 m .26001 .75739 L .20818 .69352 L .132 .285 .755 r
F
0 g
.24273 .75683 m
.25276 .76038 L
s
.34658 .8117 m
.34859 .81207 L
s
.34161 .8108 m
.34658 .8117 L
s
.33089 .80887 m
.34161 .8108 L
s
.33077 .80884 m
.33089 .80887 L
s
.32927 .80857 m
.33077 .80884 L
s
.32168 .8072 m
.32848 .80843 L
s
.31556 .80609 m
.32168 .8072 L
s
.26302 .53262 m .41002 .49095 L .26789 .53267 L .328 0 .03 r
F
0 g
.39114 .49649 m
.41553 .4989 L
s
.26302 .53262 m .39534 .48988 L .41002 .49095 L .328 0 .03 r
F
0 g
.30402 .51651 m
.35551 .49298 L
s
.2979 .51931 m
.30402 .51651 L
s
.36848 .49426 m
.37025 .49443 L
s
.37025 .49443 m
.37208 .49461 L
s
.35551 .49298 m
.36848 .49426 L
s
.35551 .49298 m
.3638 .49443 L
s
.3638 .49443 m
.36502 .49464 L
s
.33992 .4958 m
.35551 .49298 L
s
.25844 .54255 m
.26648 .53845 L
s
.30102 .52081 m
.35551 .49298 L
s
.01 w
.35551 .49298 Mdot
.35551 .49298 Mdot
.35551 .49298 Mdot
.35551 .49298 Mdot
.35551 .49298 Mdot
.35551 .49298 Mdot
.5 Mabswid
.20832 .67591 m
.21079 .67876 L
s
.21079 .67876 m
.21122 .67926 L
s
.20832 .67591 m
.21308 .66592 L
s
.21308 .66592 m
.21936 .65275 L
s
.01 w
.20832 .67591 Mdot
.20832 .67591 Mdot
.20832 .67591 Mdot
.20832 .67591 Mdot
.20832 .67591 Mdot
.5 Mabswid
.38223 .82486 m
.38484 .82651 L
s
.42836 .86993 m
.44012 .8853 L
s
.42605 .86691 m
.42836 .86993 L
s
.42383 .86402 m
.42605 .86691 L
s
.41878 .85741 m
.42383 .86402 L
s
.42373 .49337 m .56302 .53268 L .58591 .53848 L 0 .448 .735 r
F
.41002 .49095 m .56302 .53268 L .42373 .49337 L .028 .56 .855 r
F
0 g
.5386 .52422 m
.53919 .52471 L
s
.54141 .52657 m
.57501 .55475 L
s
.53919 .52471 m
.54057 .52587 L
s
.52692 .52323 m
.53655 .55463 L
s
.21144 .68508 m .26556 .74608 L .26001 .75739 L .132 .285 .755 r
F
0 g
.24605 .74833 m
.24662 .74685 L
s
.24273 .75683 m
.24605 .74833 L
s
.21547 .67604 m .26556 .74608 L .21144 .68508 L .233 .318 .746 r
F
0 g
.21149 .67657 m
.21236 .67675 L
s
.20832 .67591 m
.21149 .67657 L
s
.21122 .67926 m
.21166 .67976 L
s
.6805 .60466 m
.68093 .60497 L
s
.68047 .60465 m
.6805 .60466 L
s
.63979 .57642 m
.64177 .57779 L
s
.68046 .60463 m
.6805 .60466 L
s
.01 w
.6805 .60466 Mdot
.6805 .60466 Mdot
.6805 .60466 Mdot
.6805 .60466 Mdot
.6805 .60466 Mdot
.6805 .60466 Mdot
.78333 1.10948 m .68599 1.21767 L .76282 1.09862 L .58 .856 .522 r
F
0 g
.5 Mabswid
.73063 1.10179 m
.74753 1.12232 L
s
.57278 1.18497 m
.73566 1.1407 L
s
.81765 .95326 m .78333 1.10948 L .76282 1.09862 L .961 .944 .685 r
F
0 g
.81636 .95913 m
.81974 .96527 L
s
.83743 .942 m .78333 1.10948 L .81765 .95326 L 0 0 0 r
F
0 g
.62377 1.27393 m
.67171 1.23993 L
s
.59776 1.29239 m
.62377 1.27393 L
s
.56292 1.3171 m
.59776 1.29239 L
s
.67002 1.23665 m
.67171 1.23993 L
s
.6687 1.2341 m
.67002 1.23665 L
s
.67064 1.23595 m
.67171 1.23993 L
s
.6699 1.23315 m
.67064 1.23595 L
s
.67171 1.23993 m
.69272 1.21422 L
s
.71695 1.18458 m
.73141 1.16689 L
s
.69272 1.21422 m
.71695 1.18458 L
s
.01 w
.67171 1.23993 Mdot
.67171 1.23993 Mdot
.67171 1.23993 Mdot
.67171 1.23993 Mdot
.67171 1.23993 Mdot
.67171 1.23993 Mdot
.26789 .53267 m .42373 .49337 L .27215 .5337 L .375 0 .092 r
F
.26789 .53267 m .41002 .49095 L .42373 .49337 L F
0 g
.5 Mabswid
.29347 .52466 m
.30102 .52081 L
s
.27385 .53468 m
.2797 .53169 L
s
.64388 .56759 m .77033 .69564 L .65541 .58135 L 0 .24 .739 r
F
0 g
.75505 .68214 m
.77781 .73139 L
s
.66344 .59546 m
.66397 .59575 L
s
.68093 .60497 m
.68687 .60921 L
s
.68977 .61128 m
.69599 .61572 L
s
.68687 .60921 m
.68977 .61128 L
s
.56292 1.3171 m
.56366 1.30973 L
s
.56285 1.31011 m
.56292 1.3171 L
s
.01 w
.56292 1.3171 Mdot
.56292 1.3171 Mdot
.56292 1.3171 Mdot
.5 Mabswid
.25844 .54255 m
.26753 .53925 L
s
.25844 .54255 m
.26441 .54938 L
s
.01 w
.25844 .54255 Mdot
.25844 .54255 Mdot
.25844 .54255 Mdot
.25844 .54255 Mdot
.25844 .54255 Mdot
.5 Mabswid
.42106 .9041 m
.42996 .91756 L
s
.4171 .8981 m
.42106 .9041 L
s
.44676 .93898 m
.45062 .94687 L
s
.43708 .91437 m
.43883 .91699 L
s
.27215 .5337 m .43605 .49723 L .27568 .53573 L .414 .004 .148 r
F
0 g
.27605 .53615 m
.28018 .53465 L
s
.42622 .49959 m
.4367 .50072 L
s
.27215 .5337 m .42373 .49337 L .43605 .49723 L .414 .004 .148 r
F
0 g
.31187 .52313 m
.31195 .5231 L
s
.40086 .49688 m
.40119 .49691 L
s
.38572 .49532 m
.38789 .49549 L
s
.35551 .49298 m
.38572 .49532 L
s
.39917 .49669 m
.40042 .49683 L
s
.40042 .49683 m
.40086 .49688 L
s
.38789 .49549 m
.39694 .49646 L
s
.39694 .49646 m
.39917 .49669 L
s
.21547 .67604 m .27409 .73327 L .26556 .74608 L .233 .318 .746 r
F
0 g
.24662 .74685 m
.24941 .7397 L
s
.24986 .73855 m
.25046 .737 L
s
.24941 .7397 m
.24986 .73855 L
s
.22437 .70996 m
.22968 .71327 L
s
.22022 .6665 m .27409 .73327 L .21547 .67604 L .312 .337 .726 r
F
0 g
.22968 .71327 m
.23396 .71594 L
s
.43605 .49723 m .58591 .53848 L .60778 .54611 L .324 0 0 r
F
0 g
.46827 .5041 m
.48182 .50589 L
s
.526 .5202 m
.52654 .52197 L
s
.53834 .524 m
.5386 .52422 L
s
.42373 .49337 m .58591 .53848 L .43605 .49723 L 0 .448 .735 r
F
0 g
.5233 .51138 m
.53834 .524 L
s
.5233 .51138 m
.526 .5202 L
s
.48182 .50589 m
.5233 .51138 L
s
.44817 .88845 m
.45542 .89648 L
s
.45542 .89648 m
.46192 .90368 L
s
.46547 .90761 m
.4661 .90831 L
s
.42226 .85973 m
.43127 .86972 L
s
.45832 .86874 m
.45883 .86895 L
s
.37004 .82566 m
.37895 .83065 L
s
.37895 .83065 m
.39178 .83784 L
s
.49692 .51057 m
.5233 .51138 L
s
.46951 .50507 m
.47124 .50527 L
s
.46388 .50441 m
.46951 .50507 L
s
.46306 .50431 m
.46388 .50441 L
s
.47124 .50527 m
.5233 .51138 L
s
.01 w
.5233 .51138 Mdot
.5233 .51138 Mdot
.5233 .51138 Mdot
.5233 .51138 Mdot
.5233 .51138 Mdot
.5233 .51138 Mdot
.26556 .74608 m .32877 .80809 L .26001 .75739 L 0 .351 .825 r
F
.26556 .74608 m .33301 .80241 L .32877 .80809 L F
0 g
.5 Mabswid
.26747 .76557 m
.27283 .76747 L
s
.27283 .76747 m
.27475 .76815 L
s
.47608 .91749 m
.47864 .91975 L
s
.39933 .84282 m
.4001 .84362 L
s
.38223 .82486 m
.3846 .82735 L
s
.38472 .82747 m
.39933 .84282 L
s
.4001 .84362 m
.40024 .84377 L
s
.40024 .84377 m
.41942 .8639 L
s
.41942 .8639 m
.42447 .86921 L
s
.42447 .86921 m
.44026 .88579 L
s
.27568 .53573 m .44651 .50262 L .27835 .53875 L .445 .052 .198 r
F
0 g
.31195 .5231 m
.31233 .52296 L
s
.27568 .53573 m .43605 .49723 L .44651 .50262 L .445 .052 .198 r
F
0 g
.32415 .51866 m
.33233 .51569 L
s
.31233 .52296 m
.32415 .51866 L
s
.44587 .50229 m
.4594 .50388 L
s
.40733 .49777 m
.4074 .49778 L
s
.38789 .49549 m
.40548 .49755 L
s
.40548 .49755 m
.40733 .49777 L
s
.21936 .65275 m
.22232 .65458 L
s
.22232 .65458 m
.2237 .65543 L
s
.2237 .65543 m
.22373 .65545 L
s
.21936 .65275 m
.22239 .65262 L
s
.22239 .65262 m
.22414 .65254 L
s
.22414 .65254 m
.22448 .65253 L
s
.23012 .63328 m
.23313 .62782 L
s
.21936 .65275 m
.2245 .64344 L
s
.2245 .64344 m
.23012 .63328 L
s
.01 w
.21936 .65275 Mdot
.21936 .65275 Mdot
.21936 .65275 Mdot
.21936 .65275 Mdot
.21936 .65275 Mdot
.22022 .6665 m .28569 .71904 L .27409 .73327 L .312 .337 .726 r
F
0 g
.5 Mabswid
.25046 .737 m
.25268 .73131 L
s
.25291 .73073 m
.25384 .72834 L
s
.25268 .73131 m
.25291 .73073 L
s
.24733 .72429 m
.25384 .72834 L
s
.2457 .72327 m
.24733 .72429 L
s
.22561 .65653 m .28569 .71904 L .22022 .6665 L .372 .346 .7 r
F
0 g
.23396 .71594 m
.2457 .72327 L
s
.22549 .69569 m
.23504 .70669 L
s
.23688 .70881 m
.23989 .71228 L
s
.23504 .70669 m
.23688 .70881 L
s
.26441 .54938 m
.27446 .54653 L
s
.26441 .54938 m
.2645 .56234 L
s
.26441 .54938 m
.27392 .54523 L
s
.27999 .54258 m
.2989 .53433 L
s
.01 w
.26441 .54938 Mdot
.26441 .54938 Mdot
.26441 .54938 Mdot
.26441 .54938 Mdot
.26441 .54938 Mdot
.66073 .5968 m .78999 .71749 L .80017 .73965 L .824 .35 0 r
F
0 g
.5 Mabswid
.70658 .6967 m
.72675 .66444 L
s
.65541 .58135 m .78999 .71749 L .66073 .5968 L .58 .075 0 r
F
0 g
.75141 .67427 m
.75421 .68034 L
s
.74961 .67038 m
.75063 .67257 L
s
.75063 .67257 m
.75141 .67427 L
s
.69599 .61572 m
.71084 .62632 L
s
.71084 .62632 m
.71137 .6267 L
s
.71497 .62927 m
.72176 .63412 L
s
.71137 .6267 m
.71497 .62927 L
s
.72176 .63412 m
.73832 .64594 L
s
.73816 .64618 m
.73832 .64594 L
s
.73206 .65594 m
.73254 .65517 L
s
.7315 .65685 m
.73206 .65594 L
s
.73254 .65517 m
.73312 .65425 L
s
.73355 .65356 m
.73816 .64618 L
s
.73312 .65425 m
.73355 .65356 L
s
.73832 .64594 m
.74961 .67038 L
s
.68599 1.21767 m .60578 1.23111 L .66734 1.16627 L .837 .928 .891 r
F
0 g
.66662 1.22091 m
.66938 1.23122 L
s
.66227 1.22164 m
.66786 1.23247 L
s
.68599 1.21767 m .58102 1.30335 L .60578 1.23111 L .837 .928 .891 r
F
0 g
.5174 1.32674 m
.58102 1.30335 L
s
.76282 1.09862 m .68599 1.21767 L .66734 1.16627 L .863 .887 .852 r
F
0 g
.73141 1.16689 m
.75772 1.1347 L
s
.75117 1.13648 m
.75772 1.1347 L
s
.75585 1.13243 m
.75772 1.1347 L
s
.78301 .77918 m .83743 .942 L .81765 .95326 L .997 .779 .484 r
F
0 g
.82964 .8681 m
.83029 .85497 L
s
.79844 .76062 m .83743 .942 L .78301 .77918 L .856 .6 .063 r
F
0 g
.8166 .80487 m
.82554 .82036 L
s
.8278 .82427 m
.83149 .83066 L
s
.82554 .82036 m
.8278 .82427 L
s
.83067 .84724 m
.83149 .83066 L
s
.83029 .85497 m
.83067 .84724 L
s
.82141 .83625 m
.82618 .8336 L
s
.82802 .83258 m
.83149 .83066 L
s
.82618 .8336 m
.82802 .83258 L
s
.27835 .53875 m .45463 .50959 L .28006 .54274 L .47 .093 .242 r
F
.27835 .53875 m .44651 .50262 L .45463 .50959 L F
0 g
.3366 .51414 m
.38789 .49549 L
s
.33233 .51569 m
.3366 .51414 L
s
.42781 .50845 m
.42789 .50845 L
s
.32975 .52086 m
.38789 .49549 L
s
.31771 .52612 m
.31914 .52549 L
s
.32527 .52282 m
.32975 .52086 L
s
.31914 .52549 m
.32527 .52282 L
s
.31498 .52731 m
.31771 .52612 L
s
.42646 .50841 m
.42688 .50842 L
s
.42688 .50842 m
.42781 .50845 L
s
.41988 .50821 m
.42646 .50841 L
s
.41059 .50792 m
.41988 .50821 L
s
.75077 1.12969 m
.75772 1.1347 L
s
.75243 1.12766 m
.75772 1.1347 L
s
.75772 1.1347 m
.76611 1.10632 L
s
.01 w
.75772 1.1347 Mdot
.75772 1.1347 Mdot
.75772 1.1347 Mdot
.75772 1.1347 Mdot
.75772 1.1347 Mdot
.75772 1.1347 Mdot
.43605 .49723 m .60778 .54611 L .44651 .50262 L .324 0 0 r
F
.44651 .50262 m .60778 .54611 L .62753 .5558 L .498 0 0 r
F
0 g
.5 Mabswid
.59721 .54689 m
.63979 .57642 L
s
.57813 .53894 m
.5783 .53919 L
s
.58011 .54187 m
.5987 .56935 L
s
.57769 .53828 m
.57813 .53894 L
s
.57662 .5367 m
.57769 .53828 L
s
.5233 .51138 m
.55203 .5219 L
s
.48373 .51017 m
.48525 .51022 L
s
.48321 .51015 m
.48373 .51017 L
s
.48525 .51022 m
.4868 .51026 L
s
.4868 .51026 m
.48796 .5103 L
s
.49308 .51046 m
.49692 .51057 L
s
.48796 .5103 m
.49308 .51046 L
s
.22561 .65653 m .30024 .70357 L .28569 .71904 L .372 .346 .7 r
F
0 g
.23989 .71228 m
.25384 .72834 L
s
.23152 .64626 m .30024 .70357 L .22561 .65653 L .418 .347 .67 r
F
0 g
.43883 .91699 m
.44013 .91889 L
s
.43883 .91699 m
.43957 .91779 L
s
.43957 .91779 m
.44101 .91933 L
s
.44101 .91933 m
.44145 .9198 L
s
.44356 .91883 m
.44391 .91896 L
s
.44587 .91973 m
.45454 .9231 L
s
.44016 .91751 m
.44356 .91883 L
s
.43968 .91732 m
.44016 .91751 L
s
.4394 .91721 m
.43968 .91732 L
s
.43883 .91699 m
.4394 .91721 L
s
.01 w
.43883 .91699 Mdot
.43883 .91699 Mdot
.43883 .91699 Mdot
.43883 .91699 Mdot
.43883 .91699 Mdot
.43883 .91699 Mdot
.5 Mabswid
.38789 .49549 m
.41059 .50792 L
s
.01 w
.38789 .49549 Mdot
.38789 .49549 Mdot
.38789 .49549 Mdot
.38789 .49549 Mdot
.38789 .49549 Mdot
.38789 .49549 Mdot
.28006 .54274 m .45992 .51817 L .28074 .54769 L .488 .128 .281 r
F
.28006 .54274 m .45463 .50959 L .45992 .51817 L F
0 g
.5 Mabswid
.23313 .62782 m
.23532 .62831 L
s
.23532 .62831 m
.23537 .62832 L
s
.23537 .62832 m
.23592 .62845 L
s
.23592 .62845 m
.23597 .62846 L
s
.23597 .62846 m
.23696 .62868 L
s
.23696 .62868 m
.23716 .62873 L
s
.23716 .62873 m
.23809 .62894 L
s
.23809 .62894 m
.23898 .62914 L
s
.23898 .62914 m
.23902 .62915 L
s
.23902 .62915 m
.23934 .62922 L
s
.23313 .62782 m
.23583 .62734 L
s
.23583 .62734 m
.23589 .62733 L
s
.23589 .62733 m
.23654 .62722 L
s
.23654 .62722 m
.2366 .62721 L
s
.2366 .62721 m
.23773 .62701 L
s
.23773 .62701 m
.23801 .62696 L
s
.23801 .62696 m
.23894 .62679 L
s
.23894 .62679 m
.2398 .62664 L
s
.2398 .62664 m
.23989 .62662 L
s
.01 w
.23313 .62782 Mdot
.23313 .62782 Mdot
.23313 .62782 Mdot
.23313 .62782 Mdot
.23313 .62782 Mdot
.23152 .64626 m .31742 .68709 L .30024 .70357 L .418 .347 .67 r
F
0 g
.5 Mabswid
.2682 .68832 m
.2816 .6911 L
s
.26305 .68726 m
.2682 .68832 L
s
.23781 .63581 m .31742 .68709 L .23152 .64626 L .453 .342 .638 r
F
0 g
.26228 .6871 m
.26305 .68726 L
s
.2645 .56234 m
.27472 .56023 L
s
.25836 .58069 m
.2645 .56234 L
s
.2645 .56234 m
.27472 .55854 L
s
.01 w
.2645 .56234 Mdot
.2645 .56234 Mdot
.2645 .56234 Mdot
.2645 .56234 Mdot
.2645 .56234 Mdot
.5 Mabswid
.42996 .91756 m
.43931 .92989 L
s
.43931 .92989 m
.44586 .93854 L
s
.27409 .73327 m .33301 .80241 L .26556 .74608 L .182 .423 .857 r
F
0 g
.27475 .76815 m
.29226 .77433 L
s
.30847 .79277 m
.31153 .78578 L
s
.25384 .72834 m
.25765 .73177 L
s
.25765 .73177 m
.25835 .7324 L
s
.25835 .7324 m
.26372 .73722 L
s
.25384 .72834 m
.26039 .7295 L
s
.26039 .7295 m
.2612 .72965 L
s
.2612 .72965 m
.26492 .73031 L
s
.25384 .72834 m
.26289 .7162 L
s
.26925 .70767 m
.27262 .70315 L
s
.26873 .70836 m
.26925 .70767 L
s
.26371 .71509 m
.26873 .70836 L
s
.26289 .7162 m
.26371 .71509 L
s
.27583 .69884 m
.27999 .69326 L
s
.27262 .70315 m
.27583 .69884 L
s
.27999 .69326 m
.2816 .6911 L
s
.01 w
.25384 .72834 Mdot
.25384 .72834 Mdot
.25384 .72834 Mdot
.25384 .72834 Mdot
.25384 .72834 Mdot
.25384 .72834 Mdot
.5 Mabswid
.81484 .84058 m
.82582 .83403 L
s
.813 .84167 m
.81484 .84058 L
s
.82582 .83403 m
.83149 .83066 L
s
.81596 .80719 m
.82046 .81399 L
s
.80927 .79707 m
.81596 .80719 L
s
.80661 .79305 m
.80927 .79707 L
s
.82046 .81399 m
.83149 .83066 L
s
.818 .82338 m
.82338 .82629 L
s
.81331 .82085 m
.818 .82338 L
s
.8121 .8202 m
.81331 .82085 L
s
.82338 .82629 m
.83149 .83066 L
s
.01 w
.83149 .83066 Mdot
.83149 .83066 Mdot
.83149 .83066 Mdot
.83149 .83066 Mdot
.83149 .83066 Mdot
.83149 .83066 Mdot
.28074 .54769 m .46194 .52834 L .28033 .55356 L .502 .157 .315 r
F
0 g
.5 Mabswid
.27963 .55671 m
.29267 .55185 L
s
.28074 .54769 m .45992 .51817 L .46194 .52834 L .502 .157 .315 r
F
0 g
.3456 .52636 m
.35892 .52258 L
s
.32563 .53202 m
.32664 .53173 L
s
.32278 .53283 m
.32563 .53202 L
s
.32986 .53082 m
.33144 .53037 L
s
.32664 .53173 m
.32986 .53082 L
s
.37821 .51999 m
.41059 .50792 L
s
.35892 .52258 m
.41059 .50792 L
s
.23781 .63581 m .33666 .66987 L .31742 .68709 L .453 .342 .638 r
F
0 g
.24971 .67145 m
.25566 .67512 L
s
.25666 .67573 m
.2816 .6911 L
s
.25566 .67512 m
.25666 .67573 L
s
.25926 .68647 m
.25959 .68654 L
s
.25959 .68654 m
.26228 .6871 L
s
.24429 .62529 m .33666 .66987 L .23781 .63581 L .479 .333 .604 r
F
0 g
.24647 .66946 m
.24649 .66947 L
s
.23313 .62782 m
.24711 .60311 L
s
.19057 .63127 m
.24711 .60311 L
s
.19057 .63127 m
.25836 .58069 L
s
.41251 .84637 m
.4185 .84929 L
s
.40442 .84242 m
.41105 .84565 L
s
.41105 .84565 m
.41251 .84637 L
s
.39101 .83588 m
.40442 .84242 L
s
.38546 .83317 m
.38972 .83525 L
s
.37004 .82566 m
.38546 .83317 L
s
.38972 .83525 m
.39101 .83588 L
s
.42474 .85233 m
.44029 .85991 L
s
.42401 .85197 m
.42432 .85212 L
s
.44029 .85991 m
.45288 .86605 L
s
.457 .86806 m
.45883 .86895 L
s
.37004 .82566 m
.37627 .82387 L
s
.34212 .80406 m
.3532 .81263 L
s
.3532 .81263 m
.35636 .81507 L
s
.35724 .81575 m
.37004 .82566 L
s
.01 w
.37004 .82566 Mdot
.37004 .82566 Mdot
.37004 .82566 Mdot
.37004 .82566 Mdot
.37004 .82566 Mdot
.37004 .82566 Mdot
.27409 .73327 m .34311 .79417 L .33301 .80241 L .182 .423 .857 r
F
0 g
.5 Mabswid
.31329 .78177 m
.33041 .79501 L
s
.28045 .75226 m
.31329 .78177 L
s
.31153 .78578 m
.31319 .782 L
s
.31319 .782 m
.31329 .78177 L
s
.29226 .77433 m
.31301 .78167 L
s
.31301 .78167 m
.31329 .78177 L
s
.24711 .60311 m
.2546 .60317 L
s
.2546 .60317 m
.25463 .60317 L
s
.25463 .60317 m
.2549 .60317 L
s
.2549 .60317 m
.255 .60317 L
s
.255 .60317 m
.25512 .60317 L
s
.24711 .60311 m
.25529 .60103 L
s
.25529 .60103 m
.25532 .60102 L
s
.25532 .60102 m
.25556 .60096 L
s
.25556 .60096 m
.25569 .60093 L
s
.25569 .60093 m
.2557 .60093 L
s
.24711 .60311 m
.25836 .58069 L
s
.01 w
.24711 .60311 Mdot
.24711 .60311 Mdot
.24711 .60311 Mdot
.24711 .60311 Mdot
.24711 .60311 Mdot
.5 Mabswid
.25836 .58069 m
.26821 .57759 L
s
.26821 .57759 m
.26821 .57759 L
s
.25836 .58069 m
.26785 .57957 L
s
.26785 .57957 m
.26785 .57957 L
s
.01 w
.25836 .58069 Mdot
.25836 .58069 Mdot
.25836 .58069 Mdot
.25836 .58069 Mdot
.25836 .58069 Mdot
.45463 .50959 m .62753 .5558 L .64388 .56759 L .618 .079 0 r
F
0 g
.5 Mabswid
.59412 .54475 m
.59531 .54557 L
s
.44651 .50262 m .62753 .5558 L .45463 .50959 L .498 0 0 r
F
0 g
.59375 .54449 m
.59412 .54475 L
s
.59114 .54268 m
.59375 .54449 L
s
.57501 .53433 m
.57662 .5367 L
s
.5714 .52899 m
.57501 .53433 L
s
.58145 .53596 m
.5869 .53974 L
s
.5869 .53974 m
.59114 .54268 L
s
.5714 .52899 m
.58145 .53596 L
s
.55203 .5219 m
.5714 .52899 L
s
.36601 .81949 m
.37752 .8244 L
s
.34859 .81207 m
.36601 .81949 L
s
.37752 .8244 m
.40006 .83402 L
s
.28033 .55356 m .46034 .54004 L .27882 .56031 L .512 .183 .346 r
F
.28033 .55356 m .46194 .52834 L .46034 .54004 L F
0 g
.33276 .53692 m
.33303 .53681 L
s
.33303 .53681 m
.33304 .53681 L
s
.33304 .53681 m
.33356 .53662 L
s
.33356 .53662 m
.33425 .53636 L
s
.33447 .53628 m
.33772 .53507 L
s
.33425 .53636 m
.33447 .53628 L
s
.33772 .53507 m
.33776 .53505 L
s
.34139 .5337 m
.35235 .52962 L
s
.33776 .53505 m
.34139 .5337 L
s
.35235 .52962 m
.37821 .51999 L
s
.38331 .53782 m
.41678 .53091 L
s
.33458 .52948 m
.3456 .52636 L
s
.33144 .53037 m
.33458 .52948 L
s
.24429 .62529 m .35716 .65222 L .33666 .66987 L .479 .333 .604 r
F
0 g
.24649 .66947 m
.24971 .67145 L
s
.25077 .61483 m .35716 .65222 L .24429 .62529 L .498 .32 .57 r
F
0 g
.01 w
.73832 .64594 Mdot
.73832 .64594 Mdot
.73832 .64594 Mdot
.73832 .64594 Mdot
.73832 .64594 Mdot
.73832 .64594 Mdot
.27882 .56031 m .45492 .55317 L .27625 .56787 L .519 .205 .375 r
F
.27882 .56031 m .46034 .54004 L .45492 .55317 L F
0 g
.5 Mabswid
.3491 .55218 m
.35901 .54906 L
s
.35901 .54906 m
.3617 .54822 L
s
.3617 .54822 m
.3812 .54209 L
s
.3812 .54209 m
.41678 .53091 L
s
.32971 .54888 m
.33374 .54805 L
s
.32802 .54923 m
.32971 .54888 L
s
.33374 .54805 m
.33702 .54737 L
s
.33702 .54737 m
.33975 .54681 L
s
.33975 .54681 m
.36359 .54189 L
s
.36359 .54189 m
.38331 .53782 L
s
.66073 .5968 m .80017 .73965 L .65864 .61355 L .824 .35 0 r
F
.65864 .61355 m .80017 .73965 L .79844 .76062 L .9 .502 .249 r
F
0 g
.76207 .72236 m
.78563 .75388 L
s
.73911 .65467 m
.74046 .66951 L
s
.73832 .64594 m
.73911 .65467 L
s
.71264 .63863 m
.72461 .64204 L
s
.71108 .63819 m
.71264 .63863 L
s
.71037 .63798 m
.71108 .63819 L
s
.706 .63674 m
.71037 .63798 L
s
.72461 .64204 m
.72487 .64211 L
s
.72487 .64211 m
.73832 .64594 L
s
.70352 .62469 m
.71093 .62922 L
s
.69015 .61653 m
.70352 .62469 L
s
.68967 .61623 m
.69015 .61653 L
s
.71093 .62922 m
.72205 .63601 L
s
.72205 .63601 m
.73832 .64594 L
s
.25077 .61483 m .37799 .63443 L .35716 .65222 L .498 .32 .57 r
F
0 g
.27589 .63749 m
.28819 .64027 L
s
.29615 .64207 m
.32294 .64813 L
s
.28819 .64027 m
.29615 .64207 L
s
.29677 .6493 m
.30025 .64914 L
s
.3082 .64879 m
.32294 .64813 L
s
.30025 .64914 m
.3082 .64879 L
s
.25704 .60457 m .37799 .63443 L .25077 .61483 L .511 .304 .535 r
F
.27625 .56787 m .44566 .5676 L .27266 .57617 L .523 .227 .405 r
F
0 g
.27265 .5762 m
.27274 .57617 L
s
.27625 .56787 m .45492 .55317 L .44566 .5676 L .523 .227 .405 r
F
0 g
.34302 .55409 m
.34538 .55335 L
s
.34538 .55335 m
.3491 .55218 L
s
.01 w
.31329 .78177 Mdot
.31329 .78177 Mdot
.31329 .78177 Mdot
.31329 .78177 Mdot
.31329 .78177 Mdot
.31329 .78177 Mdot
.25704 .60457 m .39817 .61681 L .37799 .63443 L .511 .304 .535 r
F
.2629 .59463 m .39817 .61681 L .25704 .60457 L .519 .286 .5 r
F
.27266 .57617 m .43278 .58315 L .26817 .58512 L .525 .247 .435 r
F
.27266 .57617 m .44566 .5676 L .43278 .58315 L F
0 g
.5 Mabswid
.34467 .5783 m
.34942 .57709 L
s
.34942 .57709 m
.35446 .57581 L
s
.35446 .57581 m
.40187 .56375 L
s
.31647 .57383 m
.33084 .57213 L
s
.33084 .57213 m
.40187 .56375 L
s
.41678 .53091 m
.42919 .53076 L
s
.42919 .53076 m
.42985 .53075 L
s
.42985 .53075 m
.43375 .5307 L
s
.43375 .5307 m
.43709 .53066 L
s
.43709 .53066 m
.43784 .53065 L
s
.43784 .53065 m
.43791 .53065 L
s
.41059 .50792 m
.42999 .51047 L
s
.42999 .51047 m
.43279 .51083 L
s
.43279 .51083 m
.43305 .51086 L
s
.43305 .51086 m
.43363 .51094 L
s
.50499 .52029 m
.5714 .52899 L
s
.49942 .51956 m
.50499 .52029 L
s
.49782 .51935 m
.49942 .51956 L
s
.01 w
.5714 .52899 Mdot
.5714 .52899 Mdot
.5714 .52899 Mdot
.5714 .52899 Mdot
.5714 .52899 Mdot
.5714 .52899 Mdot
.5 Mabswid
.45454 .9231 m
.45857 .92775 L
s
.45857 .92775 m
.46218 .93192 L
s
.45454 .9231 m
.45814 .92554 L
s
.45814 .92554 m
.45839 .92571 L
s
.45687 .92013 m
.45821 .91841 L
s
.45578 .92152 m
.4566 .92047 L
s
.4566 .92047 m
.45687 .92013 L
s
.45454 .9231 m
.45578 .92152 L
s
.45821 .91841 m
.45987 .91629 L
s
.46197 .9136 m
.4661 .90831 L
s
.01 w
.45454 .9231 Mdot
.45454 .9231 Mdot
.45454 .9231 Mdot
.45454 .9231 Mdot
.45454 .9231 Mdot
.45454 .9231 Mdot
.2629 .59463 m .41672 .59963 L .39817 .61681 L .519 .286 .5 r
F
0 g
.5 Mabswid
.30894 .60361 m
.36748 .60409 L
s
.3027 .60356 m
.30894 .60361 L
s
.33232 .6103 m
.36748 .60409 L
s
.32246 .61204 m
.33232 .6103 L
s
.26817 .58512 m .41672 .59963 L .2629 .59463 L .524 .267 .467 r
F
.26817 .58512 m .43278 .58315 L .41672 .59963 L F
.76282 1.09862 m .66734 1.16627 L .71578 1.07023 L .863 .887 .852 r
F
.77769 .95461 m .76282 1.09862 L .71578 1.07023 L .871 .813 .79 r
F
.81765 .95326 m .76282 1.09862 L .77769 .95461 L .961 .944 .685 r
F
0 g
.78208 1.05235 m
.79021 1.02488 L
s
.77583 1.07349 m
.78208 1.05235 L
s
.79021 1.02488 m
.79246 1.01727 L
s
.79267 1.01061 m
.79376 1.00913 L
s
.79246 1.01727 m
.7956 1.00662 L
s
.79619 1.00595 m
.79791 1.00399 L
s
.7956 1.00662 m
.79619 1.00595 L
s
.79791 1.00399 m
.79811 1.00377 L
s
.79376 1.00913 m
.79523 1.00713 L
s
.79523 1.00713 m
.7956 1.00662 L
s
.28569 .71904 m .34311 .79417 L .27409 .73327 L .334 .46 .839 r
F
0 g
.31329 .78177 m
.32067 .77588 L
s
.31329 .78177 m
.33313 .78706 L
s
.45176 .93516 m
.47261 .92321 L
s
.47261 .92321 m
.47611 .9212 L
s
.47645 .92101 m
.47864 .91975 L
s
.44586 .93854 m
.45176 .93516 L
s
.01 w
.44586 .93854 Mdot
.44586 .93854 Mdot
.44586 .93854 Mdot
.5 Mabswid
.4609 .94594 m
.46455 .94773 L
s
.44586 .93854 m
.4609 .94594 L
s
.45992 .51817 m .64388 .56759 L .65541 .58135 L .686 .204 .102 r
F
.45463 .50959 m .64388 .56759 L .45992 .51817 L .618 .079 0 r
F
0 g
.53231 .52947 m
.5714 .52899 L
s
.52149 .52961 m
.53231 .52947 L
s
.52017 .52963 m
.52105 .52961 L
s
.52011 .52963 m
.52017 .52963 L
s
.52105 .52961 m
.52149 .52961 L
s
.41059 .50792 m
.41678 .53091 L
s
.01 w
.41059 .50792 Mdot
.41059 .50792 Mdot
.41059 .50792 Mdot
.41059 .50792 Mdot
.41059 .50792 Mdot
.41059 .50792 Mdot
.75326 .79467 m .81765 .95326 L .77769 .95461 L .928 .761 .655 r
F
.78301 .77918 m .81765 .95326 L .75326 .79467 L .997 .779 .484 r
F
0 g
.5 Mabswid
.80417 .84694 m
.813 .84167 L
s
.45266 .89417 m
.46587 .90718 L
s
.43445 .87625 m
.45266 .89417 L
s
.46587 .90718 m
.4759 .91706 L
s
.42201 .86401 m
.43445 .87625 L
s
.47604 .91719 m
.47864 .91975 L
s
.39737 .83976 m
.42201 .86401 L
s
.39413 .83657 m
.39737 .83976 L
s
.38223 .82486 m
.3852 .82778 L
s
.3852 .82778 m
.39413 .83657 L
s
.01 w
.38223 .82486 Mdot
.38223 .82486 Mdot
.38223 .82486 Mdot
.28569 .71904 m .36 .78342 L .34311 .79417 L .334 .46 .839 r
F
0 g
.5 Mabswid
.46455 .94773 m
.47819 .93742 L
s
.54183 1.02526 m .45315 .95204 L .47633 .96509 L .665 .421 .541 r
F
.54183 1.02526 m .51565 1.02944 L .45315 .95204 L F
0 g
.45062 .94687 m
.45315 .95204 L
s
.51565 1.02944 m
.54895 1.07817 L
s
.48155 .96283 m
.52725 1.01187 L
s
.45315 .95204 m
.47158 .97487 L
s
.789 1.00491 m
.7956 1.00662 L
s
.78236 1.00318 m
.789 1.00491 L
s
.79061 1.00314 m
.7956 1.00662 L
s
.78464 .99898 m
.79061 1.00314 L
s
.79271 .99277 m
.7956 1.00662 L
s
.78877 .97395 m
.79271 .99277 L
s
.01 w
.7956 1.00662 Mdot
.7956 1.00662 Mdot
.7956 1.00662 Mdot
.7956 1.00662 Mdot
.7956 1.00662 Mdot
.7956 1.00662 Mdot
.30024 .70357 m .36 .78342 L .28569 .71904 L .44 .479 .804 r
F
.65864 .61355 m .79844 .76062 L .64833 .63119 L .9 .502 .249 r
F
.64833 .63119 m .79844 .76062 L .78301 .77918 L .895 .57 .424 r
F
0 g
.5 Mabswid
.74995 .70614 m
.75074 .7072 L
s
.74617 .70109 m
.74995 .70614 L
s
.75005 .70751 m
.76433 .72911 L
s
.76433 .72911 m
.76812 .73484 L
s
.74046 .66951 m
.7406 .67108 L
s
.7406 .67108 m
.74061 .67116 L
s
.45992 .51817 m .65541 .58135 L .46194 .52834 L .686 .204 .102 r
F
0 g
.6185 .57124 m
.65954 .59336 L
s
.46194 .52834 m .65541 .58135 L .66073 .5968 L .719 .292 .232 r
F
0 g
.65413 .59453 m
.66053 .59844 L
s
.62399 .57613 m
.62726 .57812 L
s
.61205 .56776 m
.61221 .56785 L
s
.60744 .56527 m
.61164 .56754 L
s
.61164 .56754 m
.61205 .56776 L
s
.62284 .57543 m
.62399 .57613 L
s
.5714 .52899 m
.58864 .54961 L
s
.46166 .53036 m
.46759 .53028 L
s
.4166 .84636 m
.44777 .86963 L
s
.41165 .84267 m
.4166 .84636 L
s
.41124 .84236 m
.41165 .84267 L
s
.40006 .83402 m
.41124 .84236 L
s
.2816 .6911 m
.29241 .69903 L
s
.29241 .69903 m
.2932 .69961 L
s
.2932 .69961 m
.29321 .69962 L
s
.2816 .6911 m
.29113 .69168 L
s
.29113 .69168 m
.29123 .69168 L
s
.29123 .69168 m
.29316 .6918 L
s
.28357 .68905 m
.29194 .68035 L
s
.2816 .6911 m
.28357 .68905 L
s
.29194 .68035 m
.29227 .68001 L
s
.30405 .66776 m
.30457 .66722 L
s
.29227 .68001 m
.30405 .66776 L
s
.30457 .66722 m
.31151 .66002 L
s
.31421 .65721 m
.32294 .64813 L
s
.31151 .66002 m
.31421 .65721 L
s
.01 w
.2816 .6911 Mdot
.2816 .6911 Mdot
.2816 .6911 Mdot
.2816 .6911 Mdot
.2816 .6911 Mdot
.2816 .6911 Mdot
.5 Mabswid
.4661 .90831 m
.47303 .91405 L
s
.47597 .91649 m
.48024 .92002 L
s
.4661 .90831 m
.46925 .90938 L
s
.51023 .92323 m
.51701 .92552 L
s
.46378 .89577 m
.46486 .9016 L
s
.46351 .89428 m
.46378 .89577 L
s
.46486 .9016 m
.4661 .90831 L
s
.46298 .89145 m
.46351 .89428 L
s
.46188 .88547 m
.46292 .89113 L
s
.45883 .86895 m
.46139 .88283 L
s
.01 w
.4661 .90831 Mdot
.4661 .90831 Mdot
.4661 .90831 Mdot
.4661 .90831 Mdot
.4661 .90831 Mdot
.4661 .90831 Mdot
.66734 1.16627 m .57908 1.13003 L .61418 1.09653 L .795 .716 .777 r
F
0 g
.5 Mabswid
.62463 1.14874 m
.64554 1.18923 L
s
.65013 1.1592 m
.65538 1.17887 L
s
.66734 1.16627 m .60578 1.23111 L .57908 1.13003 L .795 .716 .777 r
F
0 g
.56368 1.3096 m
.58101 1.13734 L
s
.58102 1.30335 m
.60578 1.23111 L
s
.71578 1.07023 m .66734 1.16627 L .61418 1.09653 L .769 .706 .793 r
F
0 g
.47718 .92787 m
.47819 .93742 L
s
.47511 .90842 m
.47718 .92787 L
s
.38405 .77041 m .41502 .84372 L .36 .78342 L .336 .476 .852 r
F
0 g
.36171 .79467 m
.36988 .79685 L
s
.38405 .77041 m .44435 .8415 L .41502 .84372 L .336 .476 .852 r
F
.57062 .99058 m .47633 .96509 L .50297 .95356 L .57 .446 .672 r
F
.57062 .99058 m .54183 1.02526 L .47633 .96509 L F
0 g
.54244 1.02454 m
.55903 1.04368 L
s
.01 w
.47864 .91975 Mdot
.47864 .91975 Mdot
.47864 .91975 Mdot
.30024 .70357 m .38405 .77041 L .36 .78342 L .44 .479 .804 r
F
.31742 .68709 m .38405 .77041 L .30024 .70357 L .514 .488 .765 r
F
0 g
.5 Mabswid
.33035 .74189 m
.34396 .7443 L
s
.32621 .72384 m
.32735 .72468 L
s
.46145 .88904 m
.47191 .90388 L
s
.46023 .88731 m
.46145 .88904 L
s
.47191 .90388 m
.47511 .90842 L
s
.44777 .86963 m
.46023 .88731 L
s
.41678 .53091 m
.44091 .53477 L
s
.44091 .53477 m
.44169 .53489 L
s
.46063 .53791 m
.51487 .54656 L
s
.40187 .56375 m
.41678 .53091 L
s
.01 w
.41678 .53091 Mdot
.41678 .53091 Mdot
.41678 .53091 Mdot
.41678 .53091 Mdot
.41678 .53091 Mdot
.41678 .53091 Mdot
.46034 .54004 m .66073 .5968 L .65864 .61355 L .733 .352 .33 r
F
.46194 .52834 m .66073 .5968 L .46034 .54004 L .719 .292 .232 r
F
0 g
.5 Mabswid
.59706 .55968 m
.60744 .56527 L
s
.59706 .55968 m
.62191 .57486 L
s
.62191 .57486 m
.62284 .57543 L
s
.58864 .54961 m
.59706 .55968 L
s
.51828 .54711 m
.59706 .55968 L
s
.51724 .54694 m
.51828 .54711 L
s
.40187 .56375 m
.42438 .56328 L
s
.53661 .56094 m
.59706 .55968 L
s
.01 w
.59706 .55968 Mdot
.59706 .55968 Mdot
.59706 .55968 Mdot
.59706 .55968 Mdot
.59706 .55968 Mdot
.59706 .55968 Mdot
.71578 1.07023 m .61418 1.09653 L .64729 1.03145 L .769 .706 .793 r
F
.7196 .94786 m .71578 1.07023 L .64729 1.03145 L .763 .695 .788 r
F
.77769 .95461 m .71578 1.07023 L .7196 .94786 L .871 .813 .79 r
F
.57742 .92257 m .50297 .95356 L .51359 .90923 L .543 .499 .757 r
F
.57742 .92257 m .57062 .99058 L .50297 .95356 L F
.62953 .64933 m .78301 .77918 L .75326 .79467 L .863 .597 .535 r
F
0 g
.5 Mabswid
.74061 .67116 m
.74148 .68075 L
s
.64833 .63119 m .78301 .77918 L .62953 .64933 L .895 .57 .424 r
F
0 g
.74335 .69731 m
.74535 .69999 L
s
.74535 .69999 m
.74617 .70109 L
s
.74294 .69676 m
.74335 .69731 L
s
.74294 .69676 m
.74376 .69801 L
s
.74376 .69801 m
.75005 .70751 L
s
.7423 .68979 m
.74294 .69676 L
s
.74148 .68075 m
.7423 .68979 L
s
.45883 .86895 m
.47648 .87874 L
s
.50888 .89673 m
.52376 .90499 L
s
.52376 .90499 m
.54217 .9152 L
s
.45883 .86895 m
.46406 .86915 L
s
.44945 .85415 m
.45883 .86895 L
s
.44097 .84075 m
.44935 .85398 L
s
.01 w
.45883 .86895 Mdot
.45883 .86895 Mdot
.45883 .86895 Mdot
.45883 .86895 Mdot
.45883 .86895 Mdot
.45883 .86895 Mdot
.71019 .80706 m .77769 .95461 L .7196 .94786 L .838 .71 .722 r
F
.75326 .79467 m .77769 .95461 L .71019 .80706 L .928 .761 .655 r
F
0 g
.5 Mabswid
.77315 .86543 m
.77482 .86444 L
s
.77482 .86444 m
.78592 .85782 L
s
.76686 .86918 m
.77315 .86543 L
s
.76942 .87383 m
.76993 .87476 L
s
.76993 .87476 m
.77092 .87656 L
s
.76686 .86918 m
.76942 .87383 L
s
.77396 .90312 m
.77488 .90751 L
s
.77488 .90751 m
.77743 .9197 L
s
.76686 .86918 m
.77396 .90312 L
s
.31742 .68709 m .41483 .75554 L .38405 .77041 L .514 .488 .765 r
F
0 g
.32735 .72468 m
.3305 .72699 L
s
.34396 .7443 m
.34569 .74461 L
s
.33666 .66987 m .41483 .75554 L .31742 .68709 L .57 .491 .727 r
F
0 g
.35358 .74966 m
.35732 .74667 L
s
.35238 .75061 m
.35292 .75018 L
s
.35292 .75018 m
.35358 .74966 L
s
.348 .7541 m
.35238 .75061 L
s
.34569 .74461 m
.35732 .74667 L
s
.3305 .72699 m
.35732 .74667 L
s
.46034 .54004 m .65864 .61355 L .45492 .55317 L .733 .352 .33 r
F
0 g
.44876 .56277 m
.48478 .56202 L
s
.7284 .70587 m
.74294 .69676 L
s
.72223 .70974 m
.7284 .70587 L
s
.71213 .71606 m
.72223 .70974 L
s
.70713 .67551 m
.74294 .69676 L
s
.70529 .67442 m
.70713 .67551 L
s
.69898 .67068 m
.70529 .67442 L
s
.6848 .66226 m
.69898 .67068 L
s
.7209 .6921 m
.74294 .69676 L
s
.71469 .69078 m
.7209 .6921 L
s
.7144 .69072 m
.71469 .69078 L
s
.70557 .68885 m
.7144 .69072 L
s
.01 w
.74294 .69676 Mdot
.74294 .69676 Mdot
.74294 .69676 Mdot
.74294 .69676 Mdot
.74294 .69676 Mdot
.74294 .69676 Mdot
.5 Mabswid
.32294 .64813 m
.32903 .65095 L
s
.32903 .65095 m
.33464 .65355 L
s
.33464 .65355 m
.33994 .656 L
s
.32294 .64813 m
.32725 .64817 L
s
.32725 .64817 m
.33237 .64822 L
s
.33237 .64822 m
.33633 .64826 L
s
.33633 .64826 m
.33846 .64829 L
s
.32294 .64813 m
.32712 .64399 L
s
.32712 .64399 m
.33541 .6358 L
s
.33541 .6358 m
.34088 .6304 L
s
.34124 .63003 m
.36266 .60886 L
s
.34088 .6304 m
.34124 .63003 L
s
.36266 .60886 m
.36306 .60846 L
s
.36306 .60846 m
.36748 .60409 L
s
.01 w
.32294 .64813 Mdot
.32294 .64813 Mdot
.32294 .64813 Mdot
.32294 .64813 Mdot
.32294 .64813 Mdot
.32294 .64813 Mdot
.5 Mabswid
.35732 .74667 m
.37259 .7618 L
s
.37259 .7618 m
.37312 .76233 L
s
.37312 .76233 m
.37402 .76322 L
s
.35732 .74667 m
.36455 .74803 L
s
.35732 .74667 m
.36217 .74381 L
s
.01 w
.35732 .74667 Mdot
.35732 .74667 Mdot
.35732 .74667 Mdot
.35732 .74667 Mdot
.35732 .74667 Mdot
.35732 .74667 Mdot
.41483 .75554 m .44435 .8415 L .38405 .77041 L .496 .526 .818 r
F
.41483 .75554 m .48648 .83719 L .44435 .8415 L F
0 g
.5 Mabswid
.42006 .81129 m
.42197 .81074 L
s
.40445 .80607 m
.41589 .80912 L
s
.38576 .80108 m
.40445 .80607 L
s
.41589 .80912 m
.42002 .81022 L
s
.42002 .81022 m
.42197 .81074 L
s
.43418 .83002 m
.43792 .83593 L
s
.43792 .83593 m
.44097 .84075 L
s
.42831 .82075 m
.43418 .83002 L
s
.42197 .81074 m
.42831 .82075 L
s
.40219 .79113 m
.42197 .81074 L
s
.40187 .56375 m
.42552 .56871 L
s
.42552 .56871 m
.42632 .56887 L
s
.37024 .60085 m
.37803 .59171 L
s
.37803 .59171 m
.39399 .573 L
s
.39399 .573 m
.40187 .56375 L
s
.36748 .60409 m
.37024 .60085 L
s
.01 w
.40187 .56375 Mdot
.40187 .56375 Mdot
.40187 .56375 Mdot
.40187 .56375 Mdot
.40187 .56375 Mdot
.40187 .56375 Mdot
.61418 1.09653 m .51565 1.02944 L .54183 1.02526 L .724 .573 .684 r
F
0 g
.5 Mabswid
.56063 1.11036 m
.56285 1.31011 L
s
.61418 1.09653 m .57908 1.13003 L .51565 1.02944 L .724 .573 .684 r
F
0 g
.56055 1.10324 m
.56063 1.11036 L
s
.47158 .97487 m
.51565 1.02944 L
s
.57908 1.13003 m
.60578 1.23111 L
s
.64729 1.03145 m .61418 1.09653 L .54183 1.02526 L .677 .58 .739 r
F
0 g
.57952 1.06733 m
.58716 1.07615 L
s
.58716 1.07615 m
.58988 1.08142 L
s
.58644 1.08335 m
.58716 1.07615 L
s
.58085 1.06938 m
.58716 1.07615 L
s
.55438 1.0861 m
.56046 1.09502 L
s
.55341 1.08469 m
.56046 1.09502 L
s
.56046 1.09502 m
.56055 1.10324 L
s
.6163 1.03271 m
.61773 1.03804 L
s
.6163 1.03271 m
.6202 1.03552 L
s
.45492 .55317 m .65864 .61355 L .64833 .63119 L .735 .395 .406 r
F
.64729 1.03145 m .54183 1.02526 L .57062 .99058 L .677 .58 .739 r
F
0 g
.51565 1.02944 m
.57908 1.13003 L
s
.60984 1.02833 m
.6163 1.03271 L
s
.60778 1.02565 m
.6163 1.03271 L
s
.33666 .66987 m .45107 .73927 L .41483 .75554 L .57 .491 .727 r
F
0 g
.37139 .74931 m
.37187 .7494 L
s
.36455 .74803 m
.37139 .74931 L
s
.35716 .65222 m .45107 .73927 L .33666 .66987 L .613 .491 .689 r
F
0 g
.36217 .74381 m
.37124 .73846 L
s
.37124 .73846 m
.37277 .73756 L
s
.45492 .55317 m .64833 .63119 L .44566 .5676 L .735 .395 .406 r
F
0 g
.59195 .57453 m
.59706 .55968 L
s
.56046 1.09502 m
.58716 1.07615 L
s
.58716 1.07615 m
.6163 1.03271 L
s
.01 w
.58716 1.07615 Mdot
.58716 1.07615 Mdot
.58716 1.07615 Mdot
.58716 1.07615 Mdot
.58716 1.07615 Mdot
.58716 1.07615 Mdot
.5 Mabswid
.42197 .81074 m
.4383 .8164 L
s
.42197 .81074 m
.433 .80791 L
s
.01 w
.42197 .81074 Mdot
.42197 .81074 Mdot
.42197 .81074 Mdot
.42197 .81074 Mdot
.42197 .81074 Mdot
.42197 .81074 Mdot
.5 Mabswid
.36748 .60409 m
.38048 .60795 L
s
.38048 .60795 m
.38337 .6088 L
s
.38337 .6088 m
.38783 .61013 L
s
.38783 .61013 m
.38858 .61035 L
s
.36748 .60409 m
.37911 .60395 L
s
.37911 .60395 m
.38789 .60385 L
s
.01 w
.36748 .60409 Mdot
.36748 .60409 Mdot
.36748 .60409 Mdot
.36748 .60409 Mdot
.36748 .60409 Mdot
.36748 .60409 Mdot
.53911 .83151 m .51359 .90923 L .48648 .83719 L .567 .551 .796 r
F
0 g
.5 Mabswid
.48131 .8313 m
.4955 .83622 L
s
.53911 .83151 m .57742 .92257 L .51359 .90923 L .567 .551 .796 r
F
0 g
.01 w
.56046 1.09502 Mdot
.56046 1.09502 Mdot
.56046 1.09502 Mdot
.6163 1.03271 Mdot
.6163 1.03271 Mdot
.6163 1.03271 Mdot
.6163 1.03271 Mdot
.6163 1.03271 Mdot
.6163 1.03271 Mdot
.64961 .93612 m .64729 1.03145 L .57062 .99058 L .664 .601 .775 r
F
0 g
.5 Mabswid
.64832 .98918 m
.66484 1.01116 L
s
.7196 .94786 m .64729 1.03145 L .64961 .93612 L .763 .695 .788 r
F
.64961 .93612 m .57062 .99058 L .57742 .92257 L .664 .601 .775 r
F
0 g
.62887 .96332 m
.63327 .96446 L
s
.62258 .96119 m
.62887 .96332 L
s
.6193 .95801 m
.62887 .96332 L
s
.62887 .96332 m
.63182 .96723 L
s
.6163 1.03271 m
.62887 .96332 L
s
.75612 .86954 m
.76686 .86918 L
s
.75421 .8696 m
.75612 .86954 L
s
.74433 .86993 m
.75421 .8696 L
s
.74361 .86995 m
.74433 .86993 L
s
.75651 .86517 m
.76686 .86918 L
s
.75483 .86451 m
.75651 .86517 L
s
.74877 .86216 m
.75483 .86451 L
s
.74725 .86158 m
.74877 .86216 L
s
.75381 .85235 m
.76686 .86918 L
s
.75194 .84993 m
.75381 .85235 L
s
.74264 .83794 m
.75194 .84993 L
s
.73978 .83424 m
.74264 .83794 L
s
.01 w
.76686 .86918 Mdot
.76686 .86918 Mdot
.76686 .86918 Mdot
.76686 .86918 Mdot
.76686 .86918 Mdot
.76686 .86918 Mdot
.44566 .5676 m .62953 .64933 L .43278 .58315 L .728 .426 .468 r
F
.44566 .5676 m .64833 .63119 L .62953 .64933 L F
0 g
.5 Mabswid
.58545 .59342 m
.59195 .57453 L
s
.59904 .6063 m
.60263 .60732 L
s
.60263 .60732 m
.60576 .60821 L
s
.60576 .60821 m
.60618 .60833 L
s
.49963 .58423 m
.52165 .58885 L
s
.52165 .58885 m
.52632 .58983 L
s
.41247 .60357 m
.49083 .60268 L
s
.35716 .65222 m .49067 .72204 L .45107 .73927 L .613 .491 .689 r
F
.37799 .63443 m .49067 .72204 L .35716 .65222 L .648 .486 .651 r
F
.60273 .66768 m .75326 .79467 L .71019 .80706 L .82 .604 .61 r
F
0 g
.73283 .77743 m
.74348 .78318 L
s
.62953 .64933 m .75326 .79467 L .60273 .66768 L .863 .597 .535 r
F
0 g
.68265 .75036 m
.68569 .752 L
s
.69967 .72387 m
.70569 .72009 L
s
.70569 .72009 m
.71213 .71606 L
s
.6827 .7345 m
.69967 .72387 L
s
.69241 .77315 m
.69684 .77886 L
s
.43278 .58315 m .60273 .66768 L .41672 .59963 L .716 .449 .521 r
F
.43278 .58315 m .62953 .64933 L .60273 .66768 L F
0 g
.59029 .60381 m
.59904 .6063 L
s
.609 .61728 m
.61337 .61987 L
s
.53061 .60222 m
.53953 .60212 L
s
.61337 .61987 m
.61599 .62142 L
s
.37799 .63443 m .53099 .70421 L .49067 .72204 L .648 .486 .651 r
F
0 g
.41833 .71069 m
.41926 .71014 L
s
.41639 .71184 m
.41833 .71069 L
s
.39817 .61681 m .53099 .70421 L .37799 .63443 L .676 .478 .611 r
F
0 g
.41926 .71014 m
.4227 .70812 L
s
.65678 .81684 m .7196 .94786 L .64961 .93612 L .755 .659 .755 r
F
.71019 .80706 m .7196 .94786 L .65678 .81684 L .838 .71 .722 r
F
.41672 .59963 m .5692 .68603 L .39817 .61681 L .699 .466 .568 r
F
.41672 .59963 m .60273 .66768 L .5692 .68603 L F
0 g
.52632 .58983 m
.58263 .60163 L
s
.54533 .60205 m
.58263 .60163 L
s
.53953 .60212 m
.54533 .60205 L
s
.58263 .60163 m
.59221 .60731 L
s
.59221 .60731 m
.59627 .60972 L
s
.59627 .60972 m
.609 .61728 L
s
.58263 .60163 m
.58849 .60329 L
s
.58849 .60329 m
.59029 .60381 L
s
.58263 .60163 m
.58511 .59442 L
s
.58511 .59442 m
.58545 .59342 L
s
.39817 .61681 m .5692 .68603 L .53099 .70421 L .676 .478 .611 r
F
0 g
.52265 .65014 m
.527 .65106 L
s
.527 .65106 m
.53543 .65284 L
s
.50028 .64991 m
.51308 .65004 L
s
.48811 .64979 m
.49329 .64984 L
s
.49329 .64984 m
.50028 .64991 L
s
.51308 .65004 m
.52265 .65014 L
s
.48085 .64972 m
.48811 .64979 L
s
.45855 .63111 m
.47002 .63452 L
s
.47463 .63588 m
.49856 .64298 L
s
.47002 .63452 m
.47095 .63479 L
s
.47095 .63479 m
.47463 .63588 L
s
.49856 .64298 m
.50573 .64511 L
s
.50573 .64511 m
.52265 .65014 L
s
.53543 .65284 m
.53635 .65303 L
s
.53635 .65303 m
.5426 .65436 L
s
.5426 .65436 m
.54723 .65534 L
s
.4006 .68412 m
.40486 .68609 L
s
.39196 .68011 m
.4006 .68412 L
s
.43211 .70257 m
.43576 .70041 L
s
.4227 .70812 m
.43211 .70257 L
s
.42513 .69548 m
.43576 .70041 L
s
.41468 .69064 m
.42513 .69548 L
s
.40486 .68609 m
.41468 .69064 L
s
.43038 .70009 m
.43576 .70041 L
s
.42426 .69972 m
.43038 .70009 L
s
.41305 .69904 m
.41804 .69934 L
s
.41804 .69934 m
.41826 .69936 L
s
.41826 .69936 m
.42426 .69972 L
s
.54015 .63598 m
.5531 .62551 L
s
.5531 .62551 m
.5616 .61864 L
s
.5616 .61864 m
.58263 .60163 L
s
.52265 .65014 m
.5271 .64654 L
s
.5271 .64654 m
.53662 .63884 L
s
.53662 .63884 m
.54015 .63598 L
s
.01 w
.58263 .60163 Mdot
.58263 .60163 Mdot
.58263 .60163 Mdot
.58263 .60163 Mdot
.58263 .60163 Mdot
.58263 .60163 Mdot
.45107 .73927 m .48648 .83719 L .41483 .75554 L .594 .554 .78 r
F
0 g
.62887 .96332 Mdot
.62887 .96332 Mdot
.62887 .96332 Mdot
.62887 .96332 Mdot
.62887 .96332 Mdot
.62887 .96332 Mdot
.45107 .73927 m .53911 .83151 L .48648 .83719 L .594 .554 .78 r
F
.5978 .82479 m .57742 .92257 L .53911 .83151 L .671 .608 .777 r
F
.5978 .82479 m .64961 .93612 L .57742 .92257 L F
0 g
.5 Mabswid
.59423 .87044 m
.59477 .87062 L
s
.65678 .81684 m .64961 .93612 L .5978 .82479 L .755 .659 .755 r
F
0 g
.60604 .87453 m
.61198 .87867 L
s
.60604 .87453 m
.61317 .87429 L
s
.60604 .87453 m
.62887 .96332 L
s
.59477 .87062 m
.60604 .87453 L
s
.59834 .87424 m
.60604 .87453 L
s
.5977 .87421 m
.59834 .87424 L
s
.5692 .68603 m .71019 .80706 L .65678 .81684 L .772 .599 .664 r
F
0 g
.68103 .74949 m
.68265 .75036 L
s
.60273 .66768 m .71019 .80706 L .5692 .68603 L .82 .604 .61 r
F
0 g
.66907 .74304 m
.67895 .74837 L
s
.67895 .74837 m
.68103 .74949 L
s
.66907 .74304 m
.68175 .73509 L
s
.68175 .73509 m
.6827 .7345 L
s
.66907 .74304 m
.69012 .77019 L
s
.69012 .77019 m
.69241 .77315 L
s
.43576 .70041 m
.44161 .70497 L
s
.44161 .70497 m
.44552 .70802 L
s
.44552 .70802 m
.44603 .70842 L
s
.44603 .70842 m
.46258 .72133 L
s
.43576 .70041 m
.4388 .70097 L
s
.4388 .70097 m
.44144 .70145 L
s
.44144 .70145 m
.4448 .70206 L
s
.4448 .70206 m
.45357 .70367 L
s
.64894 .73936 m
.66907 .74304 L
s
.64061 .73784 m
.64894 .73936 L
s
.63837 .73743 m
.64061 .73784 L
s
.43576 .70041 m
.43866 .69874 L
s
.43866 .69874 m
.44153 .69708 L
s
.44153 .69708 m
.45955 .68665 L
s
.45955 .68665 m
.46273 .68481 L
s
.51571 .65415 m
.52265 .65014 L
s
.47706 .67652 m
.49704 .66495 L
s
.46778 .68189 m
.47706 .67652 L
s
.49848 .66412 m
.51571 .65415 L
s
.49704 .66495 m
.49848 .66412 L
s
.46273 .68481 m
.46778 .68189 L
s
.01 w
.43576 .70041 Mdot
.43576 .70041 Mdot
.43576 .70041 Mdot
.43576 .70041 Mdot
.43576 .70041 Mdot
.43576 .70041 Mdot
.49067 .72204 m .53911 .83151 L .45107 .73927 L .664 .574 .744 r
F
0 g
.5 Mabswid
.50923 .71383 m
.59877 .7302 L
s
.57825 .83577 m
.60604 .87453 L
s
.01 w
.60604 .87453 Mdot
.60604 .87453 Mdot
.60604 .87453 Mdot
.60604 .87453 Mdot
.60604 .87453 Mdot
.60604 .87453 Mdot
.49067 .72204 m .5978 .82479 L .53911 .83151 L .664 .574 .744 r
F
0 g
.5 Mabswid
.57375 .8295 m
.57825 .83577 L
s
.52169 .77756 m
.5249 .77816 L
s
.52573 .78413 m
.52851 .78342 L
s
.5608 .7893 m
.63828 .81933 L
s
.50542 .75474 m
.50576 .755 L
s
.65055 .7484 m
.66907 .74304 L
s
.63183 .75383 m
.65055 .7484 L
s
.63611 .72213 m
.66907 .74304 L
s
.52265 .65014 m
.52947 .65446 L
s
.52947 .65446 m
.54568 .66475 L
s
.54568 .66475 m
.55099 .66812 L
s
.55099 .66812 m
.55316 .66949 L
s
.6201 .71197 m
.63611 .72213 L
s
.01 w
.66907 .74304 Mdot
.66907 .74304 Mdot
.66907 .74304 Mdot
.66907 .74304 Mdot
.66907 .74304 Mdot
.66907 .74304 Mdot
.52265 .65014 Mdot
.52265 .65014 Mdot
.52265 .65014 Mdot
.52265 .65014 Mdot
.52265 .65014 Mdot
.52265 .65014 Mdot
.53099 .70421 m .65678 .81684 L .5978 .82479 L .721 .589 .707 r
F
.5692 .68603 m .65678 .81684 L .53099 .70421 L .772 .599 .664 r
F
.53099 .70421 m .5978 .82479 L .49067 .72204 L .721 .589 .707 r
F
0 g
.5 Mabswid
.55361 .77649 m
.5558 .77585 L
s
.54501 .77898 m
.55361 .77649 L
s
.53882 .78078 m
.54501 .77898 L
s
.51503 .76223 m
.53882 .78078 L
s
.50576 .755 m
.51503 .76223 L
s
.53882 .78078 m
.54453 .78299 L
s
.54453 .78299 m
.54981 .78504 L
s
.54981 .78504 m
.55113 .78555 L
s
.53073 .78285 m
.53882 .78078 L
s
.52851 .78342 m
.53073 .78285 L
s
.52785 .77871 m
.53882 .78078 L
s
.5249 .77816 m
.52785 .77871 L
s
.53882 .78078 m
.55348 .80122 L
s
.55348 .80122 m
.55955 .80969 L
s
.55955 .80969 m
.57168 .8266 L
s
.01 w
.53882 .78078 Mdot
.53882 .78078 Mdot
.53882 .78078 Mdot
.53882 .78078 Mdot
.53882 .78078 Mdot
.53882 .78078 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ImageSize->{196.625, 285.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003400017B000`400?l00000o`00003oa03oool0
0<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03o
ool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00
a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?oo
o`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo0034
0?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00KP3oool3000005<0
oooo001/0?ooo`8000000`3EQWL00`000000oooo0?ooo`1@0?ooo`00J`3oool2000000D0eHIg00<0
00000?ooo`3oool0C`3oool006/0oooo00<000000<NAWP0000001@3EQWL00`000000oooo0?ooo`1>
0?ooo`00JP3oool010000000ai6N0<NAWP37TIh2000000@0eHIg00<0_c/00?ooo`3oool0C@3oool0
06T0oooo00<000000<NAWP37TIh01037TIh00`000000eHIg0=F6M`020=F6M`030;lk003oool0oooo
04`0oooo001Y0?ooo`0300000037TIh0ai6N00D0ai6N0P0000030=F6M`030;lk003oool0oooo04/0
oooo001X0?ooo`0300000037TIh0ai6N00L0ai6N00<0eHIg0000003EQWL00`3EQWM<0?ooo`00J03o
ool2000000X0ai6N0P0000030=F6Md/0oooo001X0?ooo`80000000<0^YJb0<NAWP37TIh02037TIh0
0`3EQWL000000=F6M`020=F6MdX0oooo001X0?ooo`030000002jU[80^YJb0080^YJb2P37TIh20000
0080eHIg00<0_c/00?ooo`3oool0AP3oool006L0oooo00<000000;ZF/P2jU[80102jU[8:0<NAWP05
0=F6M`000000eHIg0=F6M`2o>`00A`3oool006L0oooo00<000000;ZF/P2jU[801P2jU[8:0<NAWP80
00000P3EQWM60?ooo`00I`3oool00`000000^YJb0;ZF/P070;ZF/PX0ai6N00@0eHIg0000003EQWL0
eHIgA@3oool006L0oooo00<000000;ZF/P2jU[802@2jU[8:0<NAWP80000000<0eHIg0?ooo`3oool0
@P3oool006L0oooo00<000000:ZF`@2jU[802`2jU[890<NAWP030=F6M`000000eHIg04<0oooo001W
0?ooo`030000002ZU/40ZYK100`0^YJb2037TIh3000000030=F6M`3oool0oooo0400oooo001W0?oo
o`030000002ZU/40ZYK10080ZYK1302jU[870<NAWP<0000000<0eHIg0?ooo`3oool0?`3oool006L0
oooo00<000000:ZF`@2ZU/400`2ZU/450;ZF/P030000002jU[80^YJb00@0^YJb1P37TIh010000000
ai6N0<NAWP3EQWM10?ooo`00IP3oool2000000L0ZYK1302jU[870<NAWP80nJU@@03oool006H0oooo
00@000000:ZF`@00000000001P2ZU/4<0;ZF/PH0ai6N00<0k;NJ0?VYD03oool0?`3oool006H0oooo
00D000000:ZF`@2ZU/40ZYK1000000070:ZF`@`0^YJb0`37TIh20>bgVP030?VYD03oool0oooo03h0
oooo001V0?ooo`030000002ZU/40ZYK10080ZYK10P0000060:ZF`@`0^YJb00<0ai6N0>bgVP3/]iX0
0P3/]iX00`3iZE00oooo0?ooo`0m0?ooo`00IP3oool00`000000Shk>0:ZF`@040:ZF`@8000001P2Z
U/4:0;ZF/PD0k;NJ00<0nJU@0?ooo`3oool0?@3oool006H0oooo00<0000008n>cP2?S/h01P2ZU/40
0`000000ZYK10:ZF`@040:ZF`@T0^YJb00<0f;:b0>bgVP3/]iX00`3/]iX00`000000oooo0?ooo`0l
0?ooo`00IP3oool00`000000Shk>08n>cP0208n>cPD0ZYK10P0000060:ZF`@H0^YJb0P3H/[850>bg
VP030000003oool0oooo03`0oooo001W0?ooo`030000002?S/h0Shk>00<0Shk>1@2ZU/400`000000
ZYK10:ZF`@040:ZF`@030;ZF/P000000^YJb0080^YJb0`3H/[840>bgVP030?VYD0000000oooo03`0
oooo001W0?ooo`030000002?S/h0Shk>00@0Shk>1@2ZU/42000000H0ZYK10P2jU[850=Rb/P@0k;NJ
00<000000?ooo`3oool0>`3oool006L0oooo00<0000008n>cP2?S/h01P2?S/h50:ZF`@030000002Z
U/40ZYK100@0ZYK100<0^YJb0=Rb/P3H/[800`3H/[840>bgVP030?VYD0000000oooo03/0oooo001W
0?ooo`030000002?S/h0Shk>00L0Shk>1@2ZU/4010000000ZYK10:ZF`@0000020:ZF`@L0f;:b00D0
00000>bgVP3/]iX0k;NJ0000000l0?ooo`00I`3oool00`000000FG3?08n>cP0908n>cP@0ZYK10`00
00020:ZF`@030<J[_`3H/[80f;:b00@0f;:b00H000000>bgVP3/]iX0k;NJ0?VYD000000k0?ooo`00
I`3oool00`000000FG3?05U`c`0:08n>cP<0ZYK10P0000020:ZF`@<0aZ^o1P3H/[840>bgVP030000
003oool0oooo03T0oooo001W0?ooo`040000001IL<l0FG3?05U`c`/0Shk>00D0ZYK10000002ZU/40
00000:ZF`@030<J[_`H0f;:b00H000000>bgVP3/]iX0k;NJ0?VYD000000j0?ooo`00I`3oool00`00
0000FG3?05U`c`0205U`c``0Shk>0P2ZU/450<J[_`H0f;:b103/]iX00`000000oooo0?ooo`0h0?oo
o`00I`3oool00`000000FG3?05U`c`0305U`c``0Shk>00<0ZYK10<J[_`36Zkl00`36Zkl70=Rb/P<0
k;NJ00<0nJU@0000003oool0>03oool006L0oooo00<0000005U`c`1IL<l0101IL<l;08n>cPL0aZ^o
1P3H/[830>bgVP<00000>03oool006L0oooo00<0000005U`c`1IL<l01P1IL<l908n>cP040;>Qa@36
Zkl0aZ^o000000@0aZ^o1P3H/[830>bgVP<00000=`3oool006L0oooo00<00000000V[01IL<l01`1I
L<l708n>cP<0/j750P36Zkl010000000aZ^o0<J[_`36Zkl60=Rb/P<0k;NJ00<0nJU@000000000000
=`3oool006L0oooo0P0000000`009Z`0FG3?05U`c`0605U`c`H0Shk>0`2cXLD30<J[_`0400000036
Zkl0aZ^o0<J[_`H0f;:b0P3/]iX00`000000oooo0000000g0?ooo`00I`3oool20000008002J/201I
L<l408n>cPD0/j750`36Zkl010000000aZ^o0<J[_`36Zkl50=Rb/P80k;NJ00<000000?VYD0000000
=`3oool006L0oooo0P000003000V[0P0FG3?0P2?S/h60;>Qa@@0aZ^o00<000000<J[_`36Zkl01P3H
/[800`3/]iX000000>bgVP0h0?ooo`00I`3oool2000000@002J/201IL<l00`2?S/h0/j750;>Qa@05
0;>Qa@<0aZ^o00@000000<J[_`36Zkl0aZ^o1@3H/[800`3/]iX000000>bgVP0h0?ooo`00I`3oool2
000000D002J/1`1IL<l90;>Qa@<0aZ^o00<000000<J[_`36Zkl01P3H/[830>bgVSL0oooo001W0?oo
o`80000000<0001F000V[0009Z`00`009Z`605U`c`0309nBaP2cXLD0/j7500H0/j751036Zkl00`00
0000aZ^o0<J[_`060=Rb/P80k;NJ=`3oool006L0oooo0P0000000`0005H002J/000V[004000V[0@0
FG3?0`2OT/H80;>Qa@<0aZ^o00@000000<J[_`36Zkl0aZ^o1@3H/[800`3/]iX000000?ooo`0f0?oo
o`00I`3oool200000080001F1P009Z`205U`c`@0Wi;62@2cXLD30<J[_`0400000036Zkl0aZ^o0000
00D0f;:b00<000000?ooo`3oool0=@3oool006L0oooo0P0000020000EP@002J/0P0000000`009Z`0
FG3?09nBaP0409nBaPP0/j751036Zkl2000000030<J[_`3H/[80f;:b00<0f;:b00<0hM1E0?ooo`3o
ool0=@3oool006L0oooo00<0000000000@0005H00P0005H3000V[080000000<002J/09nBaP2OT/H0
1@2OT/H80;>Qa@80aZ^o0`0000000`36Zkl0f;:b0=Rb/P030=Rb/SP0oooo001W0?ooo`0300000000
0040001F0080001F1P009Z`00`2<Ol00Wi;609nBaP0409nBaPT0/j750P36Zkl200000080aZ^o0`3H
/[800`3iiZl0oooo0?ooo`0f0?ooo`00IP3oool20000000300000@0005H0001F0080001F10009Z`2
08ao`0L0Wi;6202cXLD2000000030<J[_`000000aZ^o0080aZ^o00<0f;:b0?WV[`3iiZl0>03oool0
06D0oooo0`0000001@000040001F0000EP0005H0000000<002J/102<Ol0709nBaPL0/j7500@00000
0<J[_`36Zkl000000`36Zkl30?WV[`030000003oool0oooo03D0oooo001T0?ooo`080000003oool0
000004PeU`000040j^;90000EP0000020000EP03000V[02<Ol00S7o000@0S7o01P2OT/H80;>Qa@D0
aZ^o00D0iMC60?WV[`3iiZl0hM1E0000000g0?ooo`00I03oool3000000<0000100@000000000EP00
05H0OV^c1`2<Ol0709nBaPP0/j750`36Zkl20>GDaP80nNJ_00<0hM1E0000003oool0=P3oool006<0
oooo0`0000001018=IL0000000000@0000020000EP<0OV^c1`2<Ol0609nBaPT0/j7500@0aZ^o0>GD
aP3Ue<H0iMC60P3iiZl00`3Qd5D000000?ooo`0f0?ooo`00H`3oool60000000300000@0005H0OV^c
00<0OV^c1`2<Ol0709nBaPP0/j75103Ue<H20?WV[`030?ooo`000000oooo03H0oooo00100?oooa00
00000P1O01L00`07SmX0oooo0?ooo`0=0?ooo`H000000P00004607i[/`L0S7o01`2OT/H60;>Qa@03
0=71b`3Ue<H0iMC60080iMC60P3iiZl00`3oool000000?ooo`0f0?ooo`00?@3oool700000080=000
00D0A@00000000000000000005<01`0205l05`<000000`1Y0BD4074=<P0405800000000000000000
00H0oooo00<000000?ooo`0e05X0100000000`000040NE^S07UKX`0507i[/`L0S7o01`2OT/H50;>Q
a@80dL7;103Ue<H20?WV[`030?ooo`000000oooo03H0oooo000k0?ooo`<0000000D01`0000000000
0000000003@0000204D000<00000101O01L206T19@H0000000<0L@db07PG?@1h5cd00`1o00000`1B
000000000000000;000000<0NE^S1P1nJk<508ao`0030000002<Ol00Wi;600H0Wi;60`2cXLD30=71
b`040>GDaP000000iMC60>GDaP80nNJ_0P00000g0?ooo`00>@3oool60000000303@000150000A@00
00<000000`1O01L306T19@H000000P1h5cd2000000<0N1Lm1@1o00000`1B00000000000000080000
00@0NE^S1@1nJk<508ao`0040000002<Ol00Wi;6000000H0Wi;600<0/j750=71b`3A`L/00P3A`L/0
103Ue<H000000>GDaP3Ue<H20?WV[`800000=`3oool003L0oooo0`00000010070000000000000015
000205<01`<00000101Y0BD00`1a3C80000000000002000000@0N1Lm00<0000007PG?@1h5cd00P1h
5cd407`PA`80WQ@01P1o0000101B000007:l0000001nDY<60000000307UKX`1nJk<0OV^c00@0OV^c
1@2<Ol02000000H0Wi;600<0`K390=71b`3A`L/00`3A`L/20>GDaP030000003Ue<H0nNJ_00<00000
=`3oool003@0oooo100000000`0P000000000000000205<01`@000000P1Y0BD2074=<PD000001@1h
5cd207`PA`030000001l84L0O2170080O2170`20:5030:ld6P<0WQ@00P1o00080000000408a`[@1i
Fj<00000000000D0OV^c102<Ol030000000308ao`02OT/H0Wi;60080Wi;60P31/<T50=71b`80iMC6
00D000000>GDaP3iiZl0hM1E0000000h0?ooo`00<`3oool50000000305<01`000000G`0G0080J@4U
0P000003074=<PH000000P1h5cd607`PA`03080XD0000000P2Q@00L0P2Q@1@2_=1X309hD00@0O`00
2@00000307i[/`0608ao`000000000000000002<Ol0000000P2<Ol0309nBaP<0`K391@3A`L/20>GD
aP040000003Ue<H0nNJ_000003T0oooo000b0?ooo`<0000000<0D`070000001Y0BD00`1Y0BD2074=
<P80N1Lm1P00000507`PA`@0P2Q@2000000408<^F0<0^4Xk1P2_=1X209hD00h000001@2<Ol001@00
0000S7o008ao`02OT/H0000000<0`K391@3A`L/20>GDaP040000003iiZl0nNJ_000003T0oooo000a
0?ooo`@0000000<0J@4U0000001a3C801P1h5cd307`PA`8000000P1l84L4080XD0H000000P23;UP0
10000000PbiH08<^F023;UP2000000<0PbiH1P2hBS/70:ld6P<0WQ@0101o000205800080000000<0
OV^c08ao`02<Ol001@2<Ol000`2fX/@0`K390<6`b@030<6`b@D0dL7;0P3Ue<H00`000000nNJ_0000
000j0?ooo`00;`3oool60000000401P0DP1h5cd0N1Lm07PG?@H0O2171P20:507000000@0PbiH00<0
000008<^F023;UP01`23;UP80;Q:>`030000002hBS/0[c@J00D0[c@J102N500307l000<000001@2<
Ol020;JRa0D0`K391@3A`L/30>GDaP800000>P3oool002h0oooo0`0000000`0D04h0000001X0E@02
000000<0O2171`20:508000000P0PbiH00<0000008<^F023;UP00`23;UP408@dG`<0^eYD202hBS/4
000000D0[c@J102N50001@000000O`00000000000000S7o000@0]Z;41@31/<T50=71b`<0iMC60P00
000j0?ooo`00;03oool40000000601@0CP0H05<000000000000H0580501>0P20:502000000H0PbiH
00<0000008<^F023;UP00P00000808<^F080Q3AO00<0000008@dG`24=5l01`24=5l70;]JE0T0^4Xk
1@0000030:ld6P80WQ@000D0000009hD001o0000000007l000030;JRa0D0`K391@3A`L/00`3Ue<H0
000000000002000003X0oooo000[0?ooo`@0000000@0301701@0CP0000006P1D0`00000>08<^F0/0
Q3AO00<0000008@dG`24=5l01P25>VL30;aUI`T0^eYD2P2hBS/6000000030:ld6P2N5000WQ@00080
WQ@000<0O`000;JRa031/<T01031/<T50=71b`80iMC60P0000000`3Qd5D0oooo0?ooo`0h0?ooo`00
:`3oool01`000000000L000000000000501>0000000J05@01000000508<^F0`0Q3AO1025>VL90000
00<0QCYW00<000000;aUI`2lIFL0102lIFL00`000000^eYD0;]JE0060;]JE0030;Q:>`0000000000
00`000000`2_=1X309hD00@0`K391@3A`L/0103Ue<H0000000000000000k0?ooo`00:P3oool40000
000301@0CP0000006P1E00<0000000<02@0o00H0>`24=5l01@24=5l808DjI`T0000000<0QCYW0000
0025>VL00P25>VL2000000<0QCYW2P2lIFL:0;]JE0T0^4Xk00@000000:ld6P0000000000102_=1X0
0`2N50008W?R0<6`b@020<6`b@<0dL7;0P0000000`3Ue<H000000?WV[`0k0?ooo`00:P3oool01@00
0000000L0000000003`0601C00<0000000@02@0o0000000603/01@0i1`25>VL7000000<0QCYW0`00
000308DjI`0300000025>VL0QSm_00L0QSm_0`2jKGL;0;aUI`X0^eYD102hBS/00`000000^4Xk0;Q:
>`020;Q:>`800000102_=1X00`0RLn80`K390<6`b@020=71b`060000003A`L/0iMC60000003Ue<H0
nNJ_>`3oool002T0oooo100000001@0D04h000000000000000002@0o00@000002025>VL508HoK`@0
00001@26?fl00`000000QSm_08HoK`0708HoK`L0^Veg2`2lIFL:0;]JE0030;Q:>`000000^4Xk00@0
^4Xk0P0000001@2hBS/0[c@J0:ld6P2_=1X0`K39008000000`3A`L/0103Ue<H000000>GDaP3iiZlk
0?ooo`00:@3oool010000000000L0000000D04h30000000300T0?`000000000000801@0i5P26?fl0
0`000000QSm_08HoK`0708HoK`/0^Veg00<0_6EW0000000000000P0000060;aUI`P0^eYD00<00000
0;]JE02kFU@02@2hBS/00`2_=1X0`K390=71b`030=71b`<0iMC6?03oool002P0oooo1`0000001009
03l0000000D0>@00000200D0>@l0QSm_1P26A7L00`000000QTAg08I4M`0708I4M`<0]g:5302jKGL2
0;aUI`@000001P2lIFL30;]JE0030000002kFU@0^eYD00@0^eYD1`2hBS/00`000000dL7;0=71b`02
0=71b`030000003Ue<H0iMC603`0oooo000X0?ooo`H0000000H02@0o0000000503T0000000D0>@07
03/E08I4M`0300000026A7L0QTAg00L0QTAg1`2gLXD<0;Y]M`<0_6EW100000050;aUI`030000002k
FU@0^eYD00P0^eYD0P2hBS/3000000<0dL7;00<000000>GDaP2[iXl0?03oool002L0oooo0`000000
0`0<04L0000000000002000000801@0i0P00000@08A9O`H0QTAg00<0000008I4M`26A7L01P26A7L;
0;MbQ@`0^Veg102lIFL300000080_6EW00<000000;aUI`2lIFL02`2kFU@00`2hBS/0000009@C0002
0=71b`030>GDaP2[iXl0oooo03`0oooo000W0?ooo`H000000P0503T4000000P0Q4Uo4@00000408A9
O`030000002bMi40/WNA00d0]g:500<000000;Y]M`2jKGL0102jKGL>000000@0_6EW202kFU@20=9I
000309@C00000000000003h0oooo000W0?ooo`D0000000<01@0i0000000000000P0000000`0;04L0
PTf8089=R004089=R0P0Q4Uo1000000208A9O`8000000P24BGl3000000<0Q4Uo1P2bMi4=0;MbQ@`0
^Veg00@000000;aUI`2lIFL0_6EW100000050;aUI`D0^eYD0`3BF@000`2D4`00oooo0000000m0?oo
o`009`3oool6000000802@1100<0000000/0A`0;04L03@22CHP00`000000PTf808A9O`0308A9O`03
00000024BGl0Q4Uo00L0Q4Uo2@2bMi4>0;MbQ@P0^Veg00@000000;Y]M`2jKGL0^Veg102lIFL00`00
0000_6EW0;aUI`060;aUI`030;]JE03BF@00dUT000<0dUT000<0U1<0000000000000?03oool002H0
oooo1@00000200T0@@0400/0A`0000002`1700d0C`@0Oe6A3`22CHP00`000000PTf8089=R003089=
R0@0Q4Uo3@2bMi4>0;MbQ@@0^Veg00<000000;Y]M`2jKGL01@2jKGL20;aUI`030000002lIFL0_6EW
00H0_6EW0P3VP3l40=9I00@00000>P3oool002H0oooo1000000300/0A`0300d0C`000000000000/0
Oe6A2022CHP00`000000PTf8089=R006089=R0<0[GZL3`2bMi4=0;MbQ@8000002`2jKGL00`000000
_6EW0;aUI`050;aUI`<0iX0o103BF@00102D4`00oooo00000000000i0?ooo`009P3oool200000003
00/0A`000000000000@000000`1jEIX?07mAT@03089=R0000000PTf800L0PTf81`2]NY`>0;9gT@X0
]g:500<000000;MbQ@2gLXD00P2gLXD<0;Y]M`@0_6EW1@3VP3l40=9I000309@C003oool0oooo0080
0000=`3oool002@0oooo1@00000400h0F0030000000>05P0NUFJ00H0NUFJ2`1oDI400`000000Oe6A
07mAT@0307mAT@<0PTf82`2]NY`40;9gT@D000001@2bMi460;MbQ@030000002gLXD0]g:500H0]g:5
302jKGL00`2lIFL0iX0o0>J0?`040>J0?`@0dUT000@0U1<00?ooo`3oool0oooo0P00000e0?ooo`00
9@3oool00`0000001@1_0000000400h0H@040000000>0640LeNS07=GX`D0NUFJ1000000707mAT@03
0000001oDI40Oe6A00H0Oe6A0P2UO:H<0:ejW0L0/WNA0`0000040;9gT@<0]g:500<000000;MbQ@2g
LXD02P2gLXD90;Y]M`80iI5/1P3VP3l40=9I00<000000P3oool00`000000oooo0?ooo`0b0?ooo`00
9@3oool20000000500D0K`0000002`1X00h0H@0000000P0>064507=GX`H0NUFJ1000000207mAT@03
0000001oDI40Oe6A00H0Oe6A1@2UO:H=0:ejW0L0/WNA100000030;9gT@030000002gLXD0]g:500d0
]g:51@2jKGL40>FAK0H0iX0o103BF@000`2D4`00oooo00000003000003<0oooo000U0?ooo`800000
00H0001b00D0K`0000002`1X0000000;06P907=GX`@0NUFJ2@00000407mAT@P0YGbV3@2]NY`20;9g
T@X000000P2bMi4A0;MbQ@030;Y]M`3UTF`0iI5/00@0iI5/1P3VP3l40=9I000309@C003oool0oooo
00800000<`3oool002D0oooo0P0000020000LP0400D0K`000000000000000080JeR[2P1cEj<507YE
VP030000001jEIX0NUFJ0080000000<0NUFJ07mAT@1oDI40302UO:H=0:ejW0@0/WNA0`0000000`2b
Mi40000000000003000000030;9gT@2gLXD0]g:500/0]g:50`3LV8P60>FAK0H0iX0o103BF@000`2D
4`00oooo0000000200000380oooo000U0?ooo`<000000P0007800`0000001@1_00/0J00506]HZ`T0
LeNS00<0NUFJ0000000000001P1jEIX309am/0d0YGbV3P2]NY`00`000000/WNA0;9gT@040;9gT@03
0000002bMi40/WNA00@0/WNA2@2gLXD50=bHR0H0iI5/1`3VP3l40=9I00<00000<P3oool002D0oooo
0`0000001000078000000000LP0506l205mH/`H0JeR[201cEj<00`000000LeNS07YEVP0407YEVPH0
W7f`3@2UO:H:0:ejW08000000P2]NY`60;9gT@030000002bMi40/WNA00D0/WNA1@2gLXD80=bHR0H0
iI5/0`0000040>J0?`80dUT000@000000=9I000000000000<P3oool002D0oooo0`0000000`0007@0
00000000LP0204mF^@80GeRc00<0JeR[0000000000001@1[F:/407=GX`030000001cEj<0LeNS00<0
LeNS00<0NUFJ09am/02LOK001`2LOK0=0:ElYPH0[GZL0P0000070:ejW0@0/WNA0P0000080;9gT@03
0;MbQ@3LV8P0g9R800P0g9R81`3UTF`00`3VP3l000000>J0?`030>J0?`060=9I00000000dUT00000
003oool00000<@3oool002H0oooo00D000000000LP00000000000000LP0304mF^@<0GeRc00<0JeR[
0000000000001@1[F:/00`1cEj<0000007=GX`0507=GX`80TGfj2P2LOK0=0:ElYP80[GZL0P00000;
0:ejW0/0/WNA0`3AVY`:0=bHR0L0iI5/00@0iX0o00000000000000000P3VP3l20=9I00030000003B
F@0000000340oooo000V0?ooo`040000000007800000000000D0CeJi0`1OF;<206]HZ`8000000`1[
F:/00`000000JeR[07=GX`0407=GX`@0TGfj202LOK020000000309am/02UO:H0YGbV00X0YGbV00<0
00000:ejW02]NY`03P2]NY`60;9gT@H0dIZL2P3LV8P70>FAK0<0iX0o0P0000001P3VP3l0dUT00=9I
00000000dUT000000300oooo000V0?ooo`<0000000<0001d03]A_P1?E[T0101?E[T205mH/`800000
0P1[F:/00`000000JeR[0000000506]HZ`0307=GX`2AOKX0TGfj00D0TGfj202LOK03000000L0YGbV
0`0000030:ElYQ40[GZL00<0/WNA0=6JW03AVY`01`3AVY`;0=bHR0H0iI5/103VP3l010000000iX0o
0=9I000000020=9I0300oooo000V0?ooo`80000000@0001b03]A_P0kDKh0>e6n1@1?E[T205mH/`L0
0000101[F:/208=l``P0TGfj2@2LOK02000000@0YGbV00<000000:ElYP2UO:H01`2UO:H=0:ejW0<0
aIVY2@3AVY`;0=bHR0D0iI5/200000030=9I02l0oooo000V0?ooo`80000000D0001b0258`@0kDKh0
>e6n0000000504mF^@@0GeRc00<0000006]HZ`000000101[F:/408=l``P0TGfj2P2LOK0200000003
0:ElYP000000YGbV00/0YGbV2@2]NY`60<FIZ@T0dIZL2`3LV8P70>FAK0<0iX0o0P0000040=9I02h0
oooo000V0?ooo`8000000`0QB<400`0kDKh0000003]A_P0504mF^@80GeRc00D0000005mH/`1OF;<0
GeRc0000000206]HZ`H0Pgc32@2AOKX509am/0P000003@2UO:H50:ejW0T0aIVY2P3AVY`:0=bHR0L0
iI5/00D0iX0o00000000000000000>J0?`040=9I02d0oooo000V0?ooo`80000000L00Cbn0258`@0Q
B<408DS103]A_P000000>e6n00D0CeJi00<0GeRc0000001OF;<00`1OF;<00`1[F:/0Pgc308=l``07
08=l``T0TGfj1P2LOK020000000409am/0000000W7f`000000h0YGbV00<0[GZL0<FIZ@35VJT02P35
VJT:0=6JW0X0g9R81P3UTF`01@000000iX0o0>J0?`3VP3l000000080iX0o0`3BF@0/0?ooo`009P3o
ool200000008000Z]001?;h08DS10000000QB<40>e6n0000000kDKh404mF^@030000001OF;<0GeRc
00<0GeRc0P1`N/d908=l``T0TGfj0`2LOK02000000@0W7f`0P00000209am/0/0YGbV0`2hU[@<0<FI
Z@@0dIZL0P0000040=6JW0X0g9R80`3UTF`200000080iI5/0P3VP3l010000000iX0o0>J0?`3VP3l3
0=9I02/0oooo000V0?ooo`0600000000:[@002Zd00000001?;h08DS10`00000203]A_P80CeJi00<0
000004mF^@1?E[T00`1OF;<4071jc@T0Pgc32P2AOKX909am/0040000002LOK00W7f`09am/0H0YGbV
1`2hU[@<0<FIZ@D0dIZL00<000000=6JW03AVY`00P3AVY`:0=bHR0030>FAK0000000iI5/00D0iI5/
00<0iX0o0000003VP3l00P3VP3l30=9I02X0oooo000V0?ooo`06000000005:4002Zd00000000:[@0
0Cbn0P0QB<401P0kDKh0000003]A_P0kDKh0CeJi000000<0CeJi00<0GeRc071jc@1`N/d0101`N/d:
08=l``X0TGfj202LOK000`000000W7f`09am/00209am/0030:ElYP2hU[@0^9Jd00T0^9Jd3035VJT5
0=6JW08000000`3AVY`80=bHR080000000<0g9R80>FAK03UTF`01@3UTF`00`3VP3l0000000000002
0>J0?`80dUT0:P3oool002L0oooo00@00000000DX@00000000000P01?;h20258`@0403]A_P000000
>e6n000000@0CeJi0P1EMMH6071jc@<000001`23O<<:095m^P/0W7f`0`2YT[h;0;RF]0`0aIVY1P3A
VY`00`000000dIZL0=6JW0020=6JW0@0g9R80P0000040=bHR0L0iI5/0P0000030>J0?`80dUT0:@3o
ool002L0oooo00<0[Bd00000Q`005:400P0000001@01?;h08DS10258`@0QB<40>e6n00<000000`1?
E[T305EeePL0L7[=00<0Pgc300000023O<<01`23O<<:095m^PL0W7f`1P2YT[h;0;RF]0P0aIVY00<0
00000<FIZ@35VJT00P35VJT50=6JW08000000`3AVY`20=bHR0030000003LV8P0g9R800D0g9R81`3U
TF`2000000<0iX0o00<0dUT00?ooo`3oool09`3oool002P0oooo00<0kKPk0000Q`005:400P000000
1001?;h08DS10258`@00000203]A_P030000000kDKh0CeJi00D0EGGF1`1`N/d00`23O<<0000008=l
``0308=l``0400000023O<<0Pgc308=l``/0TGfj102LOK080:VB_P/0^9Jd3@35VJT00`3AVY`00000
000000030=6JW0030000003AVY`0dIZL008000002@3LV8P70>FAK0030000003VP3l0iX0o0080iX0o
00<043:a0?ooo`3oool09P3oool002T0oooo00<0d5@0000000005:400P0000001001?;h08DS10000
000QB<4303]A_P80;VcK1@1EMMH4071jc@<0000000@0L7[=00000023O<<0Pgc30P00000408=l``/0
TGfj00<0W7f`0:VB_P2YT[h02@2YT[h;0;RF]0d0aIVY0P3AVY`600000080dIZL2P3LV8P80>FAK0@0
iX0o:03oool002/0oooo00H00000000DX@00000002Zd004l_P0000020258`@0303]A_P0^K=/0;VcK
0080;VcK1P1EMMH5071jc@D000001`23O<<8095m^P0309R=a`2YT[h0ZI:n00/0ZI:n302hU[@<0<FI
Z@080=6JW000000000000000003AVY`000000=6JW00000020=6JW0X0g9R8203UTF`30>J0?bP0oooo
000[0?ooo`80000000@002Zd00000001?;h000000P0QB<42001Id`0402i/f`000000000002i/f`H0
EGGF1@1`N/d30000000308=l``000000Pgc300H0Pgc3102AOKX509R=a`d0ZI:n302hU[@:0<FIZ@80
00001@3AVY`010000000dIZL0000000000020=6JW0X0g9R81`3UTF`20>J0?`03010b/@3oool0oooo
02D0oooo000/0?ooo`03000000005:4002Zd0080000000<00Cbn0258`@00FM<00P00FM<202i/f`03
0000000^K=/0EGGF00D0EGGF101`N/d010000000L7[=071jc@00000908=l``03095m^P2HSLL0V8g7
00H0V8g7202YT[h2000000<0ZI:n302hU[@80<FIZ@0400000035VJT0aIVY0<FIZ@D0dIZL00<00000
0=6JW03AVY`00`3AVY`:0=bHR0L0iI5/00<0iX0o0000LP3oool09P3oool002d0oooo00<00000000D
X@0000000P000002000n]0<005WC0P0^K=/00`000000;VcK02i/f`0505EeePL0L7[=0P00000608=l
``0307j6d@2HSLL0V8g700P0V8g72@2YT[h200000080ZI:n302hU[@<0<FIZ@D0dIZL00<000000=6J
W03AVY`00`3AVY`:0=bHR0L0iI5/00<0001b0?ooo`3oool09@3oool002d0oooo0`000002000Z]003
000n]000000000000080000000@005WC02i/f`0^K=/000000P0^K=/605EeePL0L7[=1023O<<407j6
d@X0V8g72P2YT[h00`000000ZI:n0:VB_P0<0;RF]0`0aIVY1@3AVY`00`000000dIZL0=6JW0030=6J
W0X0g9R81P3UTF`00`000780oooo0?ooo`0U0?ooo`00;P3oool200000004000DX@00:[@0K`0006l0
00<003jd0P0000000`00FM<0;VcK0000000202i/f`H0EGGF1`1`N/d00`23O<<0OXKA07j6d@0507j6
d@X0V8g72P2YT[h00`000000ZI:n0:VB_P0<0;RF]0d0aIVY103AVY`00`000000dIZL0=6JW0030=6J
W0X0g9R81@3UTF`00`000780oooo0?ooo`0U0?ooo`00;`3oool200000003000DX@1_0000K`000080
00000P00?[@00`00FM<00000000000020000000302i/f`000000;VcK00D0EGGF1@1`N/d00`1FNMX0
OXKA07j6d@0707j6d@X0V8g7202YT[h3000000040:VB_P0000000000000000X0^9Jd3@35VJT40=6J
W0030000003AVY`0dIZL00@0dIZL0P0000070=bHR0<0iI5/0P3KVA0W0?ooo`00<@3oool200000004
08D0001_0000K`000000008003jd0`00FM<40000000302i/f`1EMMH0EGGF00<0EGGF00<0L7[=05Ii
fP1FNMX00`1FNMX907j6d@X0V8g71`2YT[h5000000030:VB_P2hU[@0^9Jd00X0^9Jd3@35VJT;0=6J
W0030=bHR0000000g9R800H0g9R800D0iI5/0=^I403KVA00fiT@0000LP0V0?ooo`00<@3oool70000
00<003jd00D005WC00000000FM<0000002i/f`02000000<0EGGF00<02E[C05IifP1FNMX01@1FNMX9
07j6d@X0V8g72@2YT[h010000000ZI:n0000002YT[h=0;RF]0`0aIVY2`3AVY`70=bHR0030?o7N`3K
VA00fiT@0080fiT@00<0001b0?ooo`3oool0903oool003@0oooo0P2400001@290000000000000000
000003jd008000000P00FM<01@000000;VcK02i/f`0^K=/0EGGF00<02E[C1`1FNMX00`000000OXKA
07j6d@0607j6d@X0V8g72@2YT[h010000000ZI:n0:VB_P2YT[h=0;RF]0`0aIVY2`3AVY`40=bHR0<0
olMk103KVA000`000000oooo0?ooo`0T0?ooo`00=03oool207P000H0000000D003jd00000000FM<0
05WC0000000202i/f`03000DT009F]<02E[C00<000001P1FNMX00`000000OXKA07j6d@0607j6d@X0
V8g72@2YT[h010000000ZI:n0:VB_P2YT[h=0;RF]0`0aIVY2`3AVY`00`3LV8P0olMk0?o7N`040?o7
N`@0fiT@0P00000T0?ooo`00>@3oool500000004000n]000FM<005WC02i/f`80000000<001B@00UJ
d`09F]<00P09F]<205IifP<0000000<0EWWJ07j6d@0000001`1nQ]4;09R=a`T0ZI:n00@000000:VB
_P2YT[h0ZI:n3@2hU[@<0<FIZ@P0dIZL0P3]`ZL70?o7N`@0fiT@0P00000T0?ooo`00?03oool40000
0006001Id`00000001B@000DT000000001B@1009F]<405IifP@0000000<0OXKA000000000000101n
Q]4;09R=a`T0ZI:n00@000000:VB_P2YT[h0ZI:n3@2hU[@<0<FIZ@80dIZL203]`ZL60?o7N`@0fiT@
00<0001b0000003oool08`3oool003d0oooo2P00000400UJd`H0EWWJ00@0OXKA0000000000000000
1@1nQ]4;09R=a`P0ZI:n00<000000:VB_P2YT[h00P2YT[h=0;RF]0T0aIVY0P3F]KP:0>g2Y`L0olMk
0`3KVA000`00078000000000000S0?ooo`00@`3oool6000000<02E[C1P1FNMX010000000OXKA07j6
d@00000507j6d@/0V8g7202YT[h00`000000ZI:n0:VB_P020:VB_Pd0^9Jd0`35VJT80=Je^0T0kL:W
1`3oag/40=^I40030?ooo`000000oooo0280oooo00160?ooo`D000000P09F]<505IifP0307j6d@00
0000OXKA00L0OXKA2`2HSLL70:VB_P030000002YT[h0ZI:n00<0ZI:n1P2hU[@60<6X`@/0e[Fh2P3]
`ZL60?o7N`<0fiT@1000000R0?ooo`00A`3oool7000000D0EWWJ00<0OXKA0000001nQ]401`1nQ]4;
09R=a`L0ZI:n0P0000030:^KaPd0`JS12`3F]KP90>g2Y`L0olMk0`3KVA000`000780oooo0000000R
0?ooo`00BP3oool30000000300UJd`000000EWWJ00@0EWWJ00<0000007j6d@1nQ]401`1nQ]4;09R=
a`<0ZI:n102[VlH00`000000Zi_60:^KaP020:^KaP`0`JS12`3F]KP40>g2Y`030000003]`ZL0kL:W
00<0kL:W1P3oag/30=^I40040000LP3oool0000000000240oooo001<0?ooo`@000001@1FNMX00`00
0000OXKA07j6d@0707j6d@D0V8g71@2ASL/80:^KaP040000002[VlH0Zi_60:^KaPd0`JS12`3F]KP4
0>g2Y`030000003]`ZL0kL:W0080kL:W1P3oag/30=^I4080000000<0oooo0000003oool0803oool0
04d0oooo00@02E[C00000000000000001@1FNMX00`000000OXKA07j6d@0207j6d@@0IWK?2`2ASL/7
0:^KaP030000002[VlH0Zi_60080Zi_63031Z<4;0=Je^0D0kL:W00@000000>g2Y`3]`ZL0kL:W1`3o
ag/00`3KVA000000000000020?ooo`030000003oool0oooo01l0oooo001?0?ooo`@000000`0:@L40
0`000000IWK?06Ifc`0706Ifc`X0THg;202[VlH010000000Zi_60:^KaP2[VlH=0<6X`@/0e[Fh1@3]
`ZL010000000kL:W0>g2Y`3]`ZL60?o7N`060000003KVA00fiT@0000LP3oool000008@3oool00500
oooo00<0000000Y1`@0000000`0000000`0:@L40000006Ifc`0706Ifc`X0THg;2@2[VlH010000000
Zi_60:^KaP2[VlH<0<6X`@/0e[Fh1@3]`ZL010000000kL:W0>g2Y`3]`ZL60?o7N`<0fiT@00<0001b
0?ooo`0000008@3oool00540oooo0P0000000`0:@L40000000000002000000P0IWK?2`2ASL/90:^K
aP030000002[VlH0Zi_600`0`JS1303F]KP50>g2Y`040000003]`ZL0kL:W0?o7N`800000103oag/2
0=^I40030000LP3oool000000240oooo001B0?ooo`8000000P0:@L43000000P0IWK?2P2ASL/90:^K
aP040000002[VlH0Zi_60:^KaP`0`JS12`3F]KP30>g2Y`@0000000<0kL:W0000003oag/01@3oag/3
0=^I40030?ooo`000000oooo0200oooo001C0?ooo`8000000P0:@L44000000H0IWK?2`2ASL/80:^K
aP8000000P2[VlH<0<6X`@`0e[Fh00<0kL:W000000000000100000000`3]`ZL0olMk0?o7N`040?o7
N`<0fiT@00<0001b0000003oool0803oool005@0oooo00<0000000Y1`@0:@L400`0000000`1VM/l0
00000000000406Ifc`/0THg;202[VlH4000000030:^KaP31Z<40`JS100X0`JS12`3F]KP50>g2Y`80
00000P3]`ZL60?o7N`80fiT@00<0001b0000003oool0803oool005@0oooo00L02T710000000:@L40
2T710000001VM/l000000080IWK?00<0000006Ifc`1VM/l00P1VM/l:096=b`X0Zi_60P0000000`2[
VlH0`JS10<6X`@0:0<6X`@`0e[Fh1@3]`ZL00`000000kL:W0>g2Y`060?o7N`80fiT@00<0001b0000
003oool0803oool005@0oooo00<0VR@R0000000000000P0:@L42000000L0IWK?2`2ASL/90:^KaP04
0000002[VlH0Zi_60:^KaP`0`JS12`3F]KP50>g2Y`030000003]`ZL0kL:W00H0olMk0`3KVA000`00
0000oooo0?ooo`0O0?ooo`00D03oool20000000301X0002J9280000000@0000000<0006A0000001V
M/l01P1VM/l;096=b`X0Zi_600<000000:^KaP2[VlH03031Z<4;0=Je^0H0kL:W00<000000>g2Y`3]
`ZL01P3oag/20=^I40030000LP3oool0oooo01l0oooo001>0?ooo`<0000000<06P0009XT8P2J9280
0P0000020000LP<00000201VM/l:096=b`X0Zi_600@000000:^KaP2[VlH0Zi_63031Z<4;0=Je^0D0
kL:W00<000000>g2Y`3]`ZL01P3oag/20=^I40030000LP3oool0oooo01l0oooo001=0?ooo`030000
002MlnT000000080000000L0VR@R0000002J:Rl0^TXf0000LP000000001b00<000000P3:dMl506If
c`/0THg;2@2[VlH010000000Zi_60:^KaP2[VlH<0<6X`@/0e[Fh1@3]`ZL010000000kL:W0>g2Y`3]
`ZL50?o7N`80fiT@00<000000?ooo`3oool07`3oool004`0oooo00<0000009gcj@0000000P2MlnT2
0000000409XT8P2jBSH0^TXf000000<0001b00<000000001T@0000000P1EDk<20<[Ag`80IWK?2`2A
SL/:0:^KaP040000002[VlH0Zi_60:^KaP`0`JS12`3F]KP40>g2Y`040000003]`ZL0kL:W0>g2Y`H0
olMk00<0fiT@0000003oool0803oool004/0oooo00<0000009gcj@0000000`2MlnT20000000709XT
8P2jBSH0^TXf0000000k03<000000000LP03000000H0EE>c00<0b]7O096=b`2ASL/02@2ASL/90:^K
aP040000002[VlH0Zi_60:^KaP`0`JS12`3F]KP40>g2Y`040000003]`ZL0kL:W0>g2Y`H0olMk00<0
fiT@0000003oool0803oool004X0oooo00@0000009gcj@2MlnT00000102MlnT2000000040:/m>000
0000000003/0<`<0000000<0EE>c0000000000000`1EDk<00`3:dMl0EE>c05EC/`0308]o`@P0THg;
2@2[VlH00`000000Zi_60:^KaP020:^KaP`0`JS12`3F]KP30>g2Y`030000003]`ZL0kL:W0080kL:W
1@3oag/00`3KVA0000000000LP0P0?ooo`00BP3oool00`000000bMgX000000060<WMj0L000000P1E
Dk<2000000<0EE>c00<0_[KA05EC/`1EDk<01`2;Ol44096=b`T0Zi_600<000000:^KaP2[VlH00P2[
VlH<0<6X`@/0e[Fh103]`ZL010000000kL:W0>g2Y`3]`ZL60?o7N`030000003KVA00oooo01l0oooo
00190?ooo`0400000039gNP0bMgX000000L0bMgX00@000000;Y:=P1Z>X@0JSZ40P000000101EDk<0
000000000000000505EC/`030000002;Ol40Rgo100T0Rgo100<0THg;0:^KaP2[VlH01`2[VlH00`00
0000Zi_60:^KaP020:^KaP/0`JS1303F]KP70>g2Y`H0olMk0P3KVA0P0?ooo`00B@3oool00`000000
bMgX000000090<WMj0040000002[?CP0JSZ406XjQ080000000<0EE>c0000RP0000001@1EDk<=08]o
`@D0ZIW6102[VlH00`000000Zi_60:^KaP020:^KaP`0`JS12`3F]KP80>g2Y`D0olMk0P3KVA0P0?oo
o`00B@3oool00`000000bMgX000000090<WMj080000000<0JSZ40000001Z>X@00P0m3V`2000000D0
EE>c3@2;Ol490:VIaP030000002YVLH0ZIW600<0Zi_62`31Z<4<0=Je^0L0kL:W1P3oag/00`3KVA00
oooo0?ooo`0N0?ooo`00B03oool00`000000bMgX0000000;0<WMj0@0000000@0?@i/0000000m3V`0
JSZ41@1EDk<=08]o`@T0ZIW600<000000:VIaP2YVLH00`2YVLH30<>ab@T0`JS12`3F]KP80>g2Y`D0
olMk8@3oool004P0oooo00<000000<WMj00000003039gNP20000000306XjQ0000000?@i/00<0JSZ4
101EDk<=08]o`@X0ZIW600<000000:VIaP2YVLH00P2YVLH80<>ab@@0`JS1303F]KP70>g2Y`@0olMk
00<000000?ooo`3oool07`3oool004L0oooo00<000000<WMj00000003P39gNP00`000000Zcdh06Xj
Q00606XjQ080EE>c3@2;Ol4:0:VIaP030000002YVLH0ZIW60080ZIW63033/LT00`31Z<40e[Fh0=Je
^0090=Je^0L0kL:W0`3oag/200000240oooo00170?ooo`0300000039gNP0000000h0bMgX00<00000
0:Y[RP2[?CP01`1Z>X@>08]o`@T0ZIW60P0000040:VIaPd0`k791`3Nd<X50=Je^0L0kL:W00@0olMk
00000000000000008@3oool004L0oooo0P00000@0<WMj0030000002ZJhX0ZV^:0080JSZ400<00000
06XjQ01Z>X@00`2ALZ`<08]o`@T0ZIW60`0000030:VIaPd0`k79303Nd<X70?Ka[`<000008P3oool0
04H0oooo00<000000<WMj00000004@39gNP010000000ZV^:0:Y[RP000008095b[0T0Rgo12`2YVLH2
000000<0ZIW63@33/LT<0=k@bPL0m_6_0`00000R0?ooo`00AP3oool2000000d0bKc=1P39gNP00`00
0000ZV^:0:Y[RP0:095b[0L0Rgo1302YVLH010000000ZIW60:VIaP2YVLH=0<>ab@`0g]3:1`3flJl3
00000280oooo00160?ooo`8000004`39_<d200000080ZV^:2`2ALZ`508]o`@`0ZIW600@000000:VI
aP2YVLH0ZIW63@33/LT<0=k@bP80m_6_00@000000?Ka[`3flJl0m_6_0`00000S0?ooo`00A@3oool2
000001D0bKc=00@000000:Y[RP2ZJhX0ZV^:2`2ALZ`408]o`@/0ZIW600<000000:VIaP2YVLH00P2Y
VLH=0<>ab@`0g]3:0P3flJl010000000m_6_0?Ka[`3flJl3000002<0oooo00150?ooo`0300000039
_<d0bKc=01D0bKc=00@000000:Y[RP2ZJhX0ZV^:302ALZ`208]o`@/0ZIW600<000000:VIaP2YVLH0
0P2YVLH=0<>ab@`0g]3:0`3flJl00`000000m_6_0?Ka[`03000002<0oooo00140?ooo`8000006039
_<d010000000ZV^:0:Y[RP2ZJhX=095b[0/0ZIW600@000000:VIaP2YVLH0ZIW63P33/LT;0=k@bP@0
m_6_00<000000?Ka[`3flJl00P00000T0?ooo`00A@3oool300000100bKc=00<000000<Vlc@39_<d0
1039_<d010000000ZV^:0:Y[RP2ZJhX<095b[080[IBm2@2YVLH010000000ZIW60:VIaP2YVLH>0<>a
b@/0g]3:103flJl00`000000m_6_0?Ka[`02000002@0oooo00150?ooo`0400000039_<d0bKc=0000
01L0bKc=00@000000:Y[RP2ZJhX0ZV^:2`2ALZ`40:fD_@H0ZIW600<000000:VIaP2YVLH00P2YVLH>
0<>ab@/0g]3:0P3flJl7000002@0oooo00140?ooo`8000000`39_<d00`000000bKc=0<Vlc@0D0<Vl
c@030000002ZJhX0ZV^:0080ZV^:2@2ALZ`70:fD_@@0ZIW600<000000:VIaP2YVLH00P2YVLH>0<>a
b@/0g]3:0`3flJl2000000040?Ka[`0000000000000002@0oooo00140?ooo`8000001039_<d00`00
0000bKc=0<Vlc@0C0<Vlc@800000102ZJhX7095b[0X0[IBm0P2YVLH00`000000ZIW60:VIaP020:VI
aPh0`k792`3Nd<X40?Ka[`040000003flJl00000000002D0oooo00140?ooo`8000001@39_<d00`00
0000bKc=0<Vlc@0C0<Vlc@800000102ZJhX5095b[0`0[IBm00<0ZIW60000002YVLH00`2YVLH>0<>a
b@/0g]3:103flJl010000000m_6_00000000000U0?ooo`00A03oool00`000000bKc=000000050<Vl
c@0300000039_<d0bKc=0180bKc=00<000000<Vlc@000000102ZJhX3095b[0h0[IBm00<000000:VI
aP2YVLH00P2YVLH>0<>ab@/0g]3:103flJl010000000m_6_00000000000U0?ooo`00A03oool00`00
0000bKc=000000060<Vlc@0300000039_<d0bKc=0140bKc=00@000000<Vlc@39_<d00000102ZJhX0
0`2ALZ`0[IBm0:fD_@0:0:fD_@<000000`2]U;d20:VIaPh0`k792`3Nd<X30?Ka[`040000003flJl0
0000000002H0oooo00130?ooo`0400000039_<d0bKc=000000L0bKc=00<000000<Vlc@39_<d04@39
_<d00`000000bKc=000000060;VB[`d0[IBm00<000000:fD_@2]U;d00`2]U;d>0<>ab@/0g]3:0`3f
lJl010000000m_6_00000000000V0?ooo`00@`3oool010000000bKc=0<Vlc@0000080<Vlc@030000
0039_<d0bKc=0100bKc=00@000000<Vlc@39_<d000001P2iTZl<0:fD_@800000102]U;d20<Bdb``0
`k792P3Nd<X30?Ka[`030000003flJl0m_6_008000009P3oool004<0oooo00@000000<Vlc@39_<d0
00002@39_<d200000140bKc=00@000000<Vlc@2cW/8000001P2iTZl:0:fD_@030000002]U;d0[IBm
00@0[IBm1034]</:0<>ab@X0g]3:0`3flJl010000000m_6_0?Ka[`00000W0?ooo`00@`3oool01000
0000a:>h0<BS^000000;0<BS^00300000034XkP0a:>h00h0a:>h00@000000<BS^02XR;<000001`2i
TZl80:fD_@030000002]U;d0[IBm00@0[IBm1`34]</80<>ab@X0g]3:0`3flJl010000000m_6_0?Ka
[`00000W0?ooo`00@`3oool010000000a:>h0<BS^000000<0<BS^00300000034XkP0a:>h00d0a:>h
00D000000<BS^034XkP0Z8Rc000000070;VB[`L0[IBm00<000000:fD_@2]U;d0102]U;d90<Bdb`H0
`k792P3Nd<X20?Ka[`030000003flJl0m_6_008000009`3oool004<0oooo00@000000<BS^034XkP0
00003@34XkP00`000000a:>h0<BS^00=0<BS^00500000034XkP0Z8Rc0:R8/`0000001`2iTZl50:fD
_@030000002]U;d0[IBm00@0[IBm3034]</40<>ab@X0g]3:0P3flJl010000000m_6_0?Ka[`00000X
0?ooo`00@`3oool010000000a:>h0<BS^000000>0<BS^00300000034XkP0a:>h00`0a:>h00D00000
0<BS^034XkP0Z8Rc000000080;VB[`<0[IBm00<000000:fD_@2]U;d01@2]U;d>0<Bdb`80`k792P3N
d<X20?Ka[`040000003flJl0m_6_000002P0oooo00130?ooo`0500000034XkP0a:>h0<BS^0000000
3P34XkP00`000000a:>h0<BS^00<0<BS^00500000034XkP0Z8Rc0:R8/`0000001`2iTZl010000000
[IBm0:fD_@0000060:fD_A40a;C;2P3Nd<X00`3flJl000000?Ka[`020?Ka[`030000003oool0oooo
02H0oooo00130?ooo`0500000034XkP0a:>h0<BS^00000003`34XkP00`000000a:>h0<BS^00;0<BS
^00300000034XkP0Z8Rc0080Z8Rc00<000000;VB[`2iTZl0102iTZl00`000000^I:_000000070:fD
_A40a;C;0P3LhmX80=k@bP030?Ka[`000000m_6_0080m_6_00<000000?ooo`3oool09P3oool004<0
oooo00D000000<BS^034XkP0a:>h0000000@0<BS^00300000034XkP0a:>h00X0a:>h00<000000<BS
^034XkP00P2XR;<00`000000^I:_0;VB[`040;VB[`80000000<0^I:_0:fD_@2]U;d01@2]U;dA0<Bd
b`<0g>?J1`3Nd<X40?Ka[`030000003oool0oooo02L0oooo00130?ooo`0500000034XkP0a:>h0<BS
^00000004@34XkP2000000/0a:>h00<000000<BS^02XR;<00P2XR;<200000080^I:_0P000000102i
TZl000000000002iTZl50:fD_A40a;C;1P3LhmX40=k@bPD0m_6_00<000000?ooo`3oool09`3oool0
04<0oooo00D000000<BS^034XkP0a:>h0000000C0<BS^00300000034XkP0a:>h00P0a:>h00<00000
0<BS^034XkP00P2XR;<2000000030;VB[`000000^I:_00H0^I:_102]U;dA0<Bdb`L0g>?J0`3Nd<X5
0?Ka[`030000003oool0oooo02L0oooo00130?ooo`0500000034XkP0a:>h0<BS^00000005034XkP0
0`000000a:>h0<BS^0080<BS^00300000034XkP0Z8Rc0080Z8Rc0P0000090;VB[`80[IBm4@34]</:
0=cSfP030=k@bP3flJl0m_6_00<0m_6_:P3oool004<0oooo00D000000<BS^034XkP0a:>h0000000E
0<BS^00300000034XkP0a:>h00L0a:>h00<000000<BS^034XkP00`2XR;<00`000000^I:_0;VB[`08
0;VB[`030:fD_@34]</0a;C;00l0a;C;2`3LhmX50?Ka[bX0oooo00130?ooo`0500000034XkP0a:>h
0<BS^00000005P34XkP00`000000a:>h0<BS^0070<BS^00300000034XkP0Z8Rc0080Z8Rc00<00000
0;VB[`2iTZl01`2iTZl00`3;]lH0a;C;0<Bdb`0?0<Bdb``0g>?J0P2DfhD20?Ka[`030000003oool0
oooo02P0oooo00130?ooo`0500000034XkP0a:>h0<BS^00000005`34XkP00`000000a:>h0<BS^006
0<BS^00300000034XkP0Z8Rc0080Z8Rc0P0000070;VB[`<0bkO64034]</<0=cSfP040000002DfhD0
U=^509CKQB/0oooo00130?ooo`0300000034XkP0a:>h0080a:>h00<000000<BS^034XkP05@34XkP0
0`000000a:>h0<BS^0050<BS^00800000034XkP0a:>h0:R8/`2JLJ<0000009YaX`0000050;VB[`D0
bkO63P34]</<0=cSfP0309CKQ@000000U=^50080U=^5:`3oool004<0oooo00<000000<BS^034XkP0
0P34XkP00`000000a:>h0<BS^00F0<BS^00300000034XkP0a:>h0080a:>h0`2kS:<01`000000^hbS
09YaX`2JLJ<0000009YaX`000000102iTZl70<^gaPd0a;C;2`3LhmX209CKQ@040000002DfhD0U=^5
09CKQB/0oooo00130?ooo`0300000034XkP0a:>h0080a:>h00<000000<BS^034XkP04@34XkP60;^<
X`030000002kS:<0^hbS00@0^hbS00D000000;^<X`2kS:<0VW6S0000000209YaX`030000002iTZl0
^I:_00P0bkO63034]</<0=cSfP0309CKQ@000000U=^50080U=^5;03oool004<0oooo00<000000<BS
^034XkP00P34XkP00`000000a:>h0<BS^0070<BS^140^hbS0P0000050;^<X`040000002kS:<0^hbS
000000<0VW6S00<000000<^gaP3;]lH0203;]lH:0<Bdb``0g>?J0`00000209CKQBd0oooo00130?oo
o`0300000034XkP0a:>h0080a:>h00<000000;^<X`2kS:<06P2kS:<00`000000^hbS0;^<X`020;^<
X`040000002kS:<0^hbS000000<0VW6S00<000000<^gaP3;]lH02@3;]lH90<Bdb`/0g>?J00D0U=^5
000000000000000009CKQ@0^0?ooo`00@`3oool00`000000^hbS0;^<X`020;^<X`030000002kS:<0
^hbS01/0^hbS00D000000;^<X`2kS:<0^hbS000000020;^<X`050000002JLJ<0VW6S09YaX`000000
303;]lH70<Bdb``0g>?J0`2DfhD00`000000oooo0?ooo`0]0?ooo`00A03oool01@000000^hbS0;^<
X`2kS:<0000001h0^hbS00P000000;^<X`2kS:<0^hbS0000002kS:<000000;^<X`80VW6S0P00000<
0<^gaPH0a;C;2`3LhmX309CKQ@030000003oool0oooo02h0oooo00140?ooo`050000002kS:<0^hbS
0;^<X`0000007`2kS:<01`000000^hbS0;^<X`000000^hbS0000002kS:<00P2JLJ<2000000`0bkO6
1@34]</;0=cSfP<0U=^500<000000?ooo`3oool0;`3oool004@0oooo00D000000;^<X`2kS:<0^hbS
0000000P0;^<X`030000002kS:<0^hbS008000000P2kS:<00`2JLJ<000000000000=0<^gaP@0a;C;
2`3LhmX209CKQ@030000003oool0oooo0300oooo00150?ooo`050000002kS:<0^hbS0;^<X`000000
802kS:<010000000^hbS0000000000030;^<X`800000303;]lH010000000bkO60<Bdb`34]</;0=cS
fP80U=^500<0000009CKQ@3oool0<@3oool004D0oooo00D000000;^<X`2kS:<0^hbS0000000Q0;^<
X`<000000`2kS:<00`000000VW6S0000000>0<^gaP030<Bdb`3LhmX0g>?J00P0g>?J0P2DfhD00`00
0000U=^50?ooo`0b0?ooo`00AP3oool010000000^hbS0;^<X`00000R0;^<X`8000000P2kS:<01000
0000^hbS09YaX`00000>0<^gaP/0g>?J0P2DfhD00`000000oooo0?ooo`0b0?ooo`00AP3oool01000
0000^hbS0;^<X`00000S0;^<X`050000002kS:<0^hbS0000002kS:<00P00000>0<^gaP030=K]i03L
hmX0g>?J00L0g>?J0P2DfhD00`000000oooo0?ooo`0c0?ooo`00AP3oool010000000^hbS0;^<X`00
000S0;^<X`030000002kS:<0^hbS00@000003@3;]lH20=K]i0T0g>?J00<0U=^50000003oool0=@3o
ool004L0oooo00<000000;^<X`0000008`2kS:<00`000000[Fn;0:e_R`0200000080[Fn;00<00000
0<^gaP3;]lH02@3;]lH30=K]i0P0g>?J00<0U=^50000003oool0=P3oool004L0oooo00<000000;^<
X`0000007`2kS:<40:e_R`040000002]Kh/00000000000<0[Fn;00<000000<^gaP3;]lH0203;]lH5
0=K]i0H0g>?J0P2DfhD00`000000oooo0?ooo`0e0?ooo`00A`3oool00`000000^hbS0000000K0;^<
X`P0[Fn;00<000000:e_R`2]Kh/00`0000000`2]Kh/000000<^gaP080<^gaPH0e^gT1P3LhmX00`2D
fhD000000?ooo`0g0?ooo`00B03oool2000001L0^hbS302]Kh/010000000[Fn;0:e_R`0000020:e_
R`800000203;]lH80=K]i0@0g>?J00<0U=^50000003oool0>03oool004P0oooo00<000000;^<X`00
00004@2kS:<A0:e_R`040000002]Kh/0[Fn;000000@0[Fn;00<000000<^gaP3;]lH0103;]lH90=K]
i0<0g>?J00<0U=^50000003oool0>@3oool004T0oooo0P00000=0;^<XaH0[Fn;00<000000:e_R`00
0000102]Kh/00`000000bkO60<^gaP030<^gaPX0e^gT0`3LhmX00`000000oooo0?ooo`0i0?ooo`00
B@3oool2000000T0^hbS6P2]Kh/00`000000[Fn;000000040:e_R`030000003;]lH0bkO60080bkO6
303FkN@00`3LhmX000000?ooo`0k0?ooo`00B@3oool2000000D0^hbS7P2]Kh/00`000000[Fn;0000
00040:e_R`040000003;]lH0bkO60<^gaPP0e^gT0P0000020=K]i0030000002DfhD0000003`0oooo
001:0?ooo`X000006P2]Kh/2000000H0[Fn;00<000000<^gaP3FkN@02`3FkN@3000003d0oooo0019
0?ooo`80000000<0[Fn;0000000000001P2]Kh/B000000P0[Fn;0P0000060:e_R`030000003FkN@0
e^gT00X0e^gT0`00000n0?ooo`00B`3oool00`000000[Fn;0:e_R`02000001H0[Fn;4@00000;0=K]
i0<00000?`3oool004`0oooo00@000000:e_R`2]Kh/0[Fn;0P00000L0:e_R`8000000`2]Kh/208`h
GP030000003FkN@0e^gT00P0e^gT100000100?ooo`00C@3oool00`000000[Fn;0:e_R`020:e_R`80
00006P2]Kh/2000000030:e_R`2<>5h0S3QN0080S3QN00<000000=K]i03FkN@01`3FkN@300000480
oooo001>0?ooo`030000002]Kh/0[Fn;00<0[Fn;0P00000H0:e_R`8000001@2<>5h00`000000e^gT
0=K]i0060=K]i0<00000@`3oool004l0oooo00<000000:e_R`2]Kh/0102]Kh/2000001@0[Fn;0P2<
>5h2000000@0S3QN00<000000=K]i03FkN@01P3FkN@2000004D0oooo001@0?ooo`030000002]Kh/0
[Fn;00D0[Fn;0P00000?0:e_R`D0S3QN0P00000408`hGP030000003FkN@0e^gT00@0e^gT0`000016
0?ooo`00D03oool00`000000[Fn;0:e_R`070:e_R`8000002P2]Kh/808`hGP800000102<>5h00`00
0000e^gT0=K]i0030=K]i0800000B03oool00540oooo00<000000:e_R`2]Kh/0202]Kh/2000000H0
[Fn;2P2<>5h2000000<0S3QN00<000000=K]i03FkN@00`3FkN@2000004T0oooo001B0?ooo`030000
002]Kh/0[Fn;00T0[Fn;0P0000000`2]Kh/0S3QN08`hGP0;08`hGP8000000`2<>5h00`000000e^gT
0=K]i0020=K]i0030000003oool0oooo04T0oooo001C0?ooo`030000002]Kh/0[Fn;00T0[Fn;00<0
S3QN000000000000302<>5h00`000000S3QN08`hGP0208`hGP050000003FkN@0e^gT0=K]i0000000
C03oool005@0oooo00<000000:e_R`2]Kh/01@2]Kh/608`hGP8000002P2<>5h01@000000S3QN08`h
GP2<>5h000000080e^gT00<000000?ooo`3oool0C03oool005D0oooo00<000000:e_R`2]Kh/00P2]
Kh/:08`hGP800000202<>5h00`000000S3QN08`hGP02000000030=K]i0000000oooo04h0oooo001F
0?ooo`8000003P2<>5h2000000H0S3QN00<0000008`hGP0000000P00001A0?ooo`00F03oool30000
00d0S3QN0P00000408`hGP@00000DP3oool005/0oooo0P00000=08`hGPL00000D`3oool005d0oooo
0`00000;08`hGPD00000E03oool00600oooo0P00000708`hGP8000000P3oool2000005D0oooo001R
0?ooo`<0000000@0S3QN0000000000000000F`3oool006D0oooo00<000000?ooo`3oool0G03oool0
0<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03o
ool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00
a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00001\
\>"],
  ImageRangeCache->{{{0, 195.625}, {284.625, 0}} -> {0.147757, -0.000723638, \
0.00347888, 0.00347888}}],

Cell[BoxData[
    \({12.349999999999909`\ Second, Null}\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell["\<\
In the parametric center of the surface, the triangle net shows \
that the parametric aperture is circular: all triangles in the center share \
the center point.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[seashellmirror, 
\tSurfacePoints -> Mesh, ShowComponents->False, PlotType -> SideView,
\tPlotRange -> {{-2.5,0}, {-2.5,0}, {4,7}}];\
\>", "Input",
  CellLabel->"In[35]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
1 0.4 -1.6 0.4 [
[ 0 0 0 0 ]
[ 1 1.2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.2 L
0 1.2 L
closepath
clip
newpath
0 g
.008 w
.78535 .97611 Mdot
.74374 1.02148 Mdot
.42837 .85044 Mdot
.74374 1.02148 Mdot
.68168 1.05394 Mdot
.42837 .85044 Mdot
.68168 1.05394 Mdot
.60744 1.07061 Mdot
.42837 .85044 Mdot
.60744 1.07061 Mdot
.52997 1.07062 Mdot
.42837 .85044 Mdot
.52997 1.07062 Mdot
.45678 1.05488 Mdot
.42837 .85044 Mdot
.45678 1.05488 Mdot
.39277 1.02555 Mdot
.42837 .85044 Mdot
.39277 1.02555 Mdot
.34008 .98533 Mdot
.42837 .85044 Mdot
.34008 .98533 Mdot
.29895 .93709 Mdot
.42837 .85044 Mdot
.29895 .93709 Mdot
.26867 .88371 Mdot
.42837 .85044 Mdot
.26867 .88371 Mdot
.24851 .82823 Mdot
.42837 .85044 Mdot
.24851 .82823 Mdot
.23841 .77403 Mdot
.42837 .85044 Mdot
.23841 .77403 Mdot
.23937 .72478 Mdot
.42837 .85044 Mdot
.23937 .72478 Mdot
.25331 .68409 Mdot
.42837 .85044 Mdot
.25331 .68409 Mdot
.28238 .655 Mdot
.42837 .85044 Mdot
.28238 .655 Mdot
.32777 .63946 Mdot
.42837 .85044 Mdot
.32777 .63946 Mdot
.38864 .63813 Mdot
.42837 .85044 Mdot
.38864 .63813 Mdot
.46164 .65051 Mdot
.42837 .85044 Mdot
.46164 .65051 Mdot
.54135 .67534 Mdot
.42837 .85044 Mdot
.54135 .67534 Mdot
.62103 .71105 Mdot
.42837 .85044 Mdot
.62103 .71105 Mdot
.69349 .75593 Mdot
.42837 .85044 Mdot
.69349 .75593 Mdot
.75163 .80799 Mdot
.42837 .85044 Mdot
.75163 .80799 Mdot
.78908 .8646 Mdot
.42837 .85044 Mdot
.78908 .8646 Mdot
.80101 .92217 Mdot
.42837 .85044 Mdot
.80101 .92217 Mdot
.78535 .97611 Mdot
.42837 .85044 Mdot
.78535 .97611 Mdot
.74374 1.02148 Mdot
.74374 1.02148 Mdot
.74374 1.02148 Mdot
.68168 1.05394 Mdot
.68168 1.05394 Mdot
.68168 1.05394 Mdot
.60744 1.07061 Mdot
.60744 1.07061 Mdot
.60744 1.07061 Mdot
.52997 1.07062 Mdot
.52997 1.07062 Mdot
.52997 1.07062 Mdot
.45678 1.05488 Mdot
.45678 1.05488 Mdot
.45678 1.05488 Mdot
.39277 1.02555 Mdot
.44409 1.15373 Mdot
.39277 1.02555 Mdot
.39277 1.02555 Mdot
.34008 .98533 Mdot
.44409 1.15373 Mdot
.44409 1.15373 Mdot
.38281 1.07436 Mdot
.34008 .98533 Mdot
.34008 .98533 Mdot
.29895 .93709 Mdot
.38281 1.07436 Mdot
.38281 1.07436 Mdot
.34238 .98646 Mdot
.29895 .93709 Mdot
.29895 .93709 Mdot
.26867 .88371 Mdot
.34238 .98646 Mdot
.34238 .98646 Mdot
.31518 .89186 Mdot
.26867 .88371 Mdot
.26867 .88371 Mdot
.24851 .82823 Mdot
.31518 .89186 Mdot
.31518 .89186 Mdot
.29465 .79234 Mdot
.24851 .82823 Mdot
.24851 .82823 Mdot
.23841 .77403 Mdot
.29465 .79234 Mdot
.29465 .79234 Mdot
.27606 .69215 Mdot
.23841 .77403 Mdot
.23841 .77403 Mdot
.23937 .72478 Mdot
.27606 .69215 Mdot
.27606 .69215 Mdot
.2596 .59911 Mdot
.23937 .72478 Mdot
.23937 .72478 Mdot
.25331 .68409 Mdot
.2596 .59911 Mdot
.2596 .59911 Mdot
.25333 .52321 Mdot
.25331 .68409 Mdot
.25331 .68409 Mdot
.28238 .655 Mdot
.25333 .52321 Mdot
.25333 .52321 Mdot
.27145 .47324 Mdot
.28238 .655 Mdot
.28238 .655 Mdot
.32777 .63946 Mdot
.27145 .47324 Mdot
.27145 .47324 Mdot
.32699 .4536 Mdot
.32777 .63946 Mdot
.32777 .63946 Mdot
.38864 .63813 Mdot
.32699 .4536 Mdot
.32699 .4536 Mdot
.42365 .4631 Mdot
.38864 .63813 Mdot
.38864 .63813 Mdot
.46164 .65051 Mdot
.42365 .4631 Mdot
.42365 .4631 Mdot
.55341 .49643 Mdot
.46164 .65051 Mdot
.46164 .65051 Mdot
.54135 .67534 Mdot
.55341 .49643 Mdot
.55341 .49643 Mdot
.70144 .54715 Mdot
.54135 .67534 Mdot
.54135 .67534 Mdot
.62103 .71105 Mdot
.70144 .54715 Mdot
.70144 .54715 Mdot
.85295 .61076 Mdot
.62103 .71105 Mdot
.62103 .71105 Mdot
.69349 .75593 Mdot
.85295 .61076 Mdot
.85295 .61076 Mdot
.99605 .68614 Mdot
.69349 .75593 Mdot
.69349 .75593 Mdot
.75163 .80799 Mdot
.99605 .68614 Mdot
.99605 .68614 Mdot
.75163 .80799 Mdot
.75163 .80799 Mdot
.78908 .8646 Mdot
.78908 .8646 Mdot
.78908 .8646 Mdot
.80101 .92217 Mdot
.80101 .92217 Mdot
.80101 .92217 Mdot
.78535 .97611 Mdot
.78535 .97611 Mdot
.44409 1.15373 Mdot
.44409 1.15373 Mdot
.44409 1.15373 Mdot
.38281 1.07436 Mdot
.53436 1.08865 Mdot
.38281 1.07436 Mdot
.38281 1.07436 Mdot
.34238 .98646 Mdot
.53436 1.08865 Mdot
.53436 1.08865 Mdot
.52125 .97808 Mdot
.34238 .98646 Mdot
.34238 .98646 Mdot
.31518 .89186 Mdot
.52125 .97808 Mdot
.52125 .97808 Mdot
.52147 .86352 Mdot
.31518 .89186 Mdot
.31518 .89186 Mdot
.29465 .79234 Mdot
.52147 .86352 Mdot
.52147 .86352 Mdot
.52428 .7386 Mdot
.29465 .79234 Mdot
.29465 .79234 Mdot
.27606 .69215 Mdot
.52428 .7386 Mdot
.52428 .7386 Mdot
.51212 .6042 Mdot
.27606 .69215 Mdot
.27606 .69215 Mdot
.2596 .59911 Mdot
.51212 .6042 Mdot
.51212 .6042 Mdot
.4728 .47345 Mdot
.2596 .59911 Mdot
.2596 .59911 Mdot
.25333 .52321 Mdot
.4728 .47345 Mdot
.4728 .47345 Mdot
.41757 .36839 Mdot
.25333 .52321 Mdot
.25333 .52321 Mdot
.27145 .47324 Mdot
.41757 .36839 Mdot
.41757 .36839 Mdot
.38421 .30932 Mdot
.27145 .47324 Mdot
.27145 .47324 Mdot
.32699 .4536 Mdot
.38421 .30932 Mdot
.38421 .30932 Mdot
.41422 .30421 Mdot
.32699 .4536 Mdot
.32699 .4536 Mdot
.42365 .4631 Mdot
.41422 .30421 Mdot
.41422 .30421 Mdot
.52125 .34581 Mdot
.42365 .4631 Mdot
.42365 .4631 Mdot
.55341 .49643 Mdot
.52125 .34581 Mdot
.52125 .34581 Mdot
.68338 .41709 Mdot
.55341 .49643 Mdot
.55341 .49643 Mdot
.70144 .54715 Mdot
.68338 .41709 Mdot
.68338 .41709 Mdot
.86574 .50024 Mdot
.70144 .54715 Mdot
.70144 .54715 Mdot
.85295 .61076 Mdot
.86574 .50024 Mdot
.86574 .50024 Mdot
.85295 .61076 Mdot
.85295 .61076 Mdot
.99605 .68614 Mdot
.99605 .68614 Mdot
.99605 .68614 Mdot
.73288 1.15373 Mdot
.53436 1.08865 Mdot
.73288 1.15373 Mdot
.73288 1.15373 Mdot
.73268 1.01862 Mdot
.53436 1.08865 Mdot
.53436 1.08865 Mdot
.52125 .97808 Mdot
.73268 1.01862 Mdot
.73268 1.01862 Mdot
.74619 .90417 Mdot
.52125 .97808 Mdot
.52125 .97808 Mdot
.52147 .86352 Mdot
.74619 .90417 Mdot
.74619 .90417 Mdot
.78353 .79321 Mdot
.52147 .86352 Mdot
.52147 .86352 Mdot
.52428 .7386 Mdot
.78353 .79321 Mdot
.78353 .79321 Mdot
.83501 .66454 Mdot
.52428 .7386 Mdot
.52428 .7386 Mdot
.51212 .6042 Mdot
.83501 .66454 Mdot
.83501 .66454 Mdot
.85959 .50979 Mdot
.51212 .6042 Mdot
.51212 .6042 Mdot
.4728 .47345 Mdot
.85959 .50979 Mdot
.85959 .50979 Mdot
.81245 .34779 Mdot
.4728 .47345 Mdot
.4728 .47345 Mdot
.41757 .36839 Mdot
.81245 .34779 Mdot
.81245 .34779 Mdot
.69529 .22004 Mdot
.41757 .36839 Mdot
.41757 .36839 Mdot
.38421 .30932 Mdot
.69529 .22004 Mdot
.69529 .22004 Mdot
.57867 .16572 Mdot
.38421 .30932 Mdot
.38421 .30932 Mdot
.41422 .30421 Mdot
.57867 .16572 Mdot
.57867 .16572 Mdot
.55422 .19681 Mdot
.41422 .30421 Mdot
.41422 .30421 Mdot
.52125 .34581 Mdot
.55422 .19681 Mdot
.55422 .19681 Mdot
.65144 .29406 Mdot
.52125 .34581 Mdot
.52125 .34581 Mdot
.68338 .41709 Mdot
.65144 .29406 Mdot
.65144 .29406 Mdot
.81891 .42207 Mdot
.68338 .41709 Mdot
.68338 .41709 Mdot
.86574 .50024 Mdot
.81891 .42207 Mdot
.81891 .42207 Mdot
.99022 .54715 Mdot
.86574 .50024 Mdot
.86574 .50024 Mdot
.99022 .54715 Mdot
.99022 .54715 Mdot
.73288 1.15373 Mdot
.89296 1.02555 Mdot
.73288 1.15373 Mdot
.73288 1.15373 Mdot
.73268 1.01862 Mdot
.89296 1.02555 Mdot
.89296 1.02555 Mdot
.90029 .87588 Mdot
.73268 1.01862 Mdot
.73268 1.01862 Mdot
.74619 .90417 Mdot
.90029 .87588 Mdot
.90029 .87588 Mdot
.92166 .77049 Mdot
.74619 .90417 Mdot
.74619 .90417 Mdot
.78353 .79321 Mdot
.92166 .77049 Mdot
.92166 .77049 Mdot
.99592 .68167 Mdot
.78353 .79321 Mdot
.78353 .79321 Mdot
.83501 .66454 Mdot
.99592 .68167 Mdot
.99592 .68167 Mdot
.83501 .66454 Mdot
.83501 .66454 Mdot
.85959 .50979 Mdot
.85959 .50979 Mdot
.85959 .50979 Mdot
.81245 .34779 Mdot
.81245 .34779 Mdot
.81245 .34779 Mdot
.69529 .22004 Mdot
.69529 .22004 Mdot
.69529 .22004 Mdot
.57867 .16572 Mdot
.79989 .04315 Mdot
.57867 .16572 Mdot
.57867 .16572 Mdot
.55422 .19681 Mdot
.79989 .04315 Mdot
.79989 .04315 Mdot
.70657 .13064 Mdot
.55422 .19681 Mdot
.55422 .19681 Mdot
.65144 .29406 Mdot
.70657 .13064 Mdot
.70657 .13064 Mdot
.78113 .30207 Mdot
.65144 .29406 Mdot
.65144 .29406 Mdot
.81891 .42207 Mdot
.78113 .30207 Mdot
.78113 .30207 Mdot
.92457 .49976 Mdot
.81891 .42207 Mdot
.81891 .42207 Mdot
.99022 .54715 Mdot
.92457 .49976 Mdot
.92457 .49976 Mdot
.99022 .54715 Mdot
.99022 .54715 Mdot
.97471 1.08598 Mdot
.89296 1.02555 Mdot
.97471 1.08598 Mdot
.97471 1.08598 Mdot
.89296 1.02555 Mdot
.89296 1.02555 Mdot
.90029 .87588 Mdot
.97431 .68973 Mdot
.90029 .87588 Mdot
.90029 .87588 Mdot
.92166 .77049 Mdot
.97431 .68973 Mdot
.97431 .68973 Mdot
.99156 .59452 Mdot
.92166 .77049 Mdot
.92166 .77049 Mdot
.99592 .68167 Mdot
.99156 .59452 Mdot
.99156 .59452 Mdot
.99592 .68167 Mdot
.99592 .68167 Mdot
.79989 .04315 Mdot
.79989 .04315 Mdot
.79989 .04315 Mdot
.70657 .13064 Mdot
.84263 .09927 Mdot
.70657 .13064 Mdot
.70657 .13064 Mdot
.78113 .30207 Mdot
.84263 .09927 Mdot
.84263 .09927 Mdot
.88882 .35238 Mdot
.78113 .30207 Mdot
.78113 .30207 Mdot
.92457 .49976 Mdot
.88882 .35238 Mdot
.88882 .35238 Mdot
.97317 .62086 Mdot
.92457 .49976 Mdot
.92457 .49976 Mdot
.97317 .62086 Mdot
.97317 .62086 Mdot
.97471 1.08598 Mdot
.97471 1.08598 Mdot
.97471 1.08598 Mdot
.97431 .68973 Mdot
.93016 .49944 Mdot
.97431 .68973 Mdot
.97431 .68973 Mdot
.99156 .59452 Mdot
.93016 .49944 Mdot
.93016 .49944 Mdot
.9626 .40127 Mdot
.99156 .59452 Mdot
.99156 .59452 Mdot
.9626 .40127 Mdot
.9626 .40127 Mdot
.84263 .09927 Mdot
.95303 .09187 Mdot
.84263 .09927 Mdot
.84263 .09927 Mdot
.88882 .35238 Mdot
.95303 .09187 Mdot
.95303 .09187 Mdot
.97232 .41997 Mdot
.88882 .35238 Mdot
.88882 .35238 Mdot
.97317 .62086 Mdot
.97232 .41997 Mdot
.97232 .41997 Mdot
.95421 .7461 Mdot
.97317 .62086 Mdot
.97317 .62086 Mdot
.95421 .7461 Mdot
.95421 .7461 Mdot
.89296 1.02555 Mdot
.89296 1.02555 Mdot
.89296 1.02555 Mdot
.98459 1.1688 Mdot
.98459 1.1688 Mdot
.98459 1.1688 Mdot
.99662 1.15596 Mdot
.99662 1.15596 Mdot
.99662 1.15596 Mdot
.99022 .54715 Mdot
.93016 .49944 Mdot
.99022 .54715 Mdot
.99022 .54715 Mdot
.7899 .34418 Mdot
.93016 .49944 Mdot
.93016 .49944 Mdot
.9626 .40127 Mdot
.7899 .34418 Mdot
.7899 .34418 Mdot
.89541 .21776 Mdot
.9626 .40127 Mdot
.9626 .40127 Mdot
.89541 .21776 Mdot
.89541 .21776 Mdot
.95303 .09187 Mdot
.95303 .09187 Mdot
.95303 .09187 Mdot
.97232 .41997 Mdot
.97232 .41997 Mdot
.97232 .41997 Mdot
.95421 .7461 Mdot
.87681 .83631 Mdot
.95421 .7461 Mdot
.95421 .7461 Mdot
.89296 1.02555 Mdot
.87681 .83631 Mdot
.87681 .83631 Mdot
.73288 1.15373 Mdot
.89296 1.02555 Mdot
.89296 1.02555 Mdot
.73288 1.15373 Mdot
.73288 1.15373 Mdot
.98459 1.1688 Mdot
.98459 1.1688 Mdot
.98459 1.1688 Mdot
.99662 1.15596 Mdot
.99662 1.15596 Mdot
.99662 1.15596 Mdot
.99022 .54715 Mdot
.86574 .50024 Mdot
.99022 .54715 Mdot
.99022 .54715 Mdot
.7899 .34418 Mdot
.86574 .50024 Mdot
.86574 .50024 Mdot
.61244 .25332 Mdot
.7899 .34418 Mdot
.7899 .34418 Mdot
.89541 .21776 Mdot
.61244 .25332 Mdot
.61244 .25332 Mdot
.86952 .06749 Mdot
.89541 .21776 Mdot
.89541 .21776 Mdot
.86952 .06749 Mdot
.86952 .06749 Mdot
.87681 .83631 Mdot
.76613 .86213 Mdot
.87681 .83631 Mdot
.87681 .83631 Mdot
.73288 1.15373 Mdot
.76613 .86213 Mdot
.76613 .86213 Mdot
.73288 1.15373 Mdot
.73288 1.15373 Mdot
.5 Mabswid
[ ] 0 setdash
.78535 .97611 m
.74374 1.02148 L
.42837 .85044 L
.78535 .97611 L
s
.74374 1.02148 m
.68168 1.05394 L
.42837 .85044 L
.74374 1.02148 L
s
.68168 1.05394 m
.60744 1.07061 L
.42837 .85044 L
.68168 1.05394 L
s
.60744 1.07061 m
.52997 1.07062 L
.42837 .85044 L
.60744 1.07061 L
s
.52997 1.07062 m
.45678 1.05488 L
.42837 .85044 L
.52997 1.07062 L
s
.45678 1.05488 m
.39277 1.02555 L
.42837 .85044 L
.45678 1.05488 L
s
.39277 1.02555 m
.34008 .98533 L
.42837 .85044 L
.39277 1.02555 L
s
.34008 .98533 m
.29895 .93709 L
.42837 .85044 L
.34008 .98533 L
s
.29895 .93709 m
.26867 .88371 L
.42837 .85044 L
.29895 .93709 L
s
.26867 .88371 m
.24851 .82823 L
.42837 .85044 L
.26867 .88371 L
s
.24851 .82823 m
.23841 .77403 L
.42837 .85044 L
.24851 .82823 L
s
.23841 .77403 m
.23937 .72478 L
.42837 .85044 L
.23841 .77403 L
s
.23937 .72478 m
.25331 .68409 L
.42837 .85044 L
.23937 .72478 L
s
.25331 .68409 m
.28238 .655 L
.42837 .85044 L
.25331 .68409 L
s
.28238 .655 m
.32777 .63946 L
.42837 .85044 L
.28238 .655 L
s
.32777 .63946 m
.38864 .63813 L
.42837 .85044 L
.32777 .63946 L
s
.38864 .63813 m
.46164 .65051 L
.42837 .85044 L
.38864 .63813 L
s
.46164 .65051 m
.54135 .67534 L
.42837 .85044 L
.46164 .65051 L
s
.54135 .67534 m
.62103 .71105 L
.42837 .85044 L
.54135 .67534 L
s
.62103 .71105 m
.69349 .75593 L
.42837 .85044 L
.62103 .71105 L
s
.69349 .75593 m
.75163 .80799 L
.42837 .85044 L
.69349 .75593 L
s
.75163 .80799 m
.78908 .8646 L
.42837 .85044 L
.75163 .80799 L
s
.78908 .8646 m
.80101 .92217 L
.42837 .85044 L
.78908 .8646 L
s
.80101 .92217 m
.78535 .97611 L
.42837 .85044 L
.80101 .92217 L
s
.78535 .97611 m
.74374 1.02148 L
s
.74374 1.02148 m
1 1.06468 L
s
1 1.03815 m
.78535 .97611 L
s
1 1.13853 m
.74374 1.02148 L
s
.74374 1.02148 m
1 1.06468 L
s
.74374 1.02148 m
.68168 1.05394 L
s
.68168 1.05394 m
1 1.15581 L
s
1 1.13853 m
.74374 1.02148 L
s
.89557 1.2 m
.68168 1.05394 L
s
.68168 1.05394 m
1 1.15581 L
s
.68168 1.05394 m
.60744 1.07061 L
s
.60744 1.07061 m
.86476 1.2 L
s
.89557 1.2 m
.68168 1.05394 L
s
.73514 1.2 m
.60744 1.07061 L
s
.60744 1.07061 m
.86476 1.2 L
s
.60744 1.07061 m
.52997 1.07062 L
s
.52997 1.07062 m
.70518 1.2 L
s
.73514 1.2 m
.60744 1.07061 L
s
.61601 1.2 m
.52997 1.07062 L
s
.52997 1.07062 m
.70518 1.2 L
s
.52997 1.07062 m
.45678 1.05488 L
s
.45678 1.05488 m
.59639 1.2 L
s
.61601 1.2 m
.52997 1.07062 L
s
.52508 1.2 m
.45678 1.05488 L
s
.45678 1.05488 m
.59639 1.2 L
s
.45678 1.05488 m
.39277 1.02555 L
s
.39277 1.02555 m
.51986 1.2 L
s
.52508 1.2 m
.45678 1.05488 L
s
.50707 1.2 m
.44409 1.15373 L
.39277 1.02555 L
s
.39277 1.02555 m
.51986 1.2 L
s
.39277 1.02555 m
.34008 .98533 L
.44409 1.15373 L
.39277 1.02555 L
s
.44409 1.15373 m
.38281 1.07436 L
.34008 .98533 L
.44409 1.15373 L
s
.34008 .98533 m
.29895 .93709 L
.38281 1.07436 L
.34008 .98533 L
s
.38281 1.07436 m
.34238 .98646 L
.29895 .93709 L
.38281 1.07436 L
s
.29895 .93709 m
.26867 .88371 L
.34238 .98646 L
.29895 .93709 L
s
.34238 .98646 m
.31518 .89186 L
.26867 .88371 L
.34238 .98646 L
s
.26867 .88371 m
.24851 .82823 L
.31518 .89186 L
.26867 .88371 L
s
.31518 .89186 m
.29465 .79234 L
.24851 .82823 L
.31518 .89186 L
s
.24851 .82823 m
.23841 .77403 L
.29465 .79234 L
.24851 .82823 L
s
.29465 .79234 m
.27606 .69215 L
.23841 .77403 L
.29465 .79234 L
s
.23841 .77403 m
.23937 .72478 L
.27606 .69215 L
.23841 .77403 L
s
.27606 .69215 m
.2596 .59911 L
.23937 .72478 L
.27606 .69215 L
s
.23937 .72478 m
.25331 .68409 L
.2596 .59911 L
.23937 .72478 L
s
.2596 .59911 m
.25333 .52321 L
.25331 .68409 L
.2596 .59911 L
s
.25331 .68409 m
.28238 .655 L
.25333 .52321 L
.25331 .68409 L
s
.25333 .52321 m
.27145 .47324 L
.28238 .655 L
.25333 .52321 L
s
.28238 .655 m
.32777 .63946 L
.27145 .47324 L
.28238 .655 L
s
.27145 .47324 m
.32699 .4536 L
.32777 .63946 L
.27145 .47324 L
s
.32777 .63946 m
.38864 .63813 L
.32699 .4536 L
.32777 .63946 L
s
.32699 .4536 m
.42365 .4631 L
.38864 .63813 L
.32699 .4536 L
s
.38864 .63813 m
.46164 .65051 L
.42365 .4631 L
.38864 .63813 L
s
.42365 .4631 m
.55341 .49643 L
.46164 .65051 L
.42365 .4631 L
s
.46164 .65051 m
.54135 .67534 L
.55341 .49643 L
.46164 .65051 L
s
.55341 .49643 m
.70144 .54715 L
.54135 .67534 L
.55341 .49643 L
s
.54135 .67534 m
.62103 .71105 L
.70144 .54715 L
.54135 .67534 L
s
.70144 .54715 m
.85295 .61076 L
.62103 .71105 L
.70144 .54715 L
s
.62103 .71105 m
.69349 .75593 L
.85295 .61076 L
.62103 .71105 L
s
.85295 .61076 m
.99605 .68614 L
.69349 .75593 L
.85295 .61076 L
s
.69349 .75593 m
.75163 .80799 L
.99605 .68614 L
.69349 .75593 L
s
.99605 .68614 m
0 0 rlineto s
.99605 .68614 m
1 .68898 L
s
1 .78555 m
.75163 .80799 L
.99605 .68614 L
s
.75163 .80799 m
.78908 .8646 L
s
.78908 .8646 m
1 .80724 L
s
1 .78555 m
.75163 .80799 L
s
1 .87106 m
.78908 .8646 L
s
.78908 .8646 m
1 .80724 L
s
.78908 .8646 m
.80101 .92217 L
s
.80101 .92217 m
1 .90034 L
s
1 .87106 m
.78908 .8646 L
s
1 .95251 m
.80101 .92217 L
s
.80101 .92217 m
1 .90034 L
s
.80101 .92217 m
.78535 .97611 L
s
.78535 .97611 m
1 .98264 L
s
1 .95251 m
.80101 .92217 L
s
1 1.03815 m
.78535 .97611 L
s
.78535 .97611 m
1 .98264 L
s
.50707 1.2 m
.44409 1.15373 L
s
.44409 1.15373 m
.50177 1.2 L
s
.56686 1.2 m
.44409 1.15373 L
s
.44409 1.15373 m
.50177 1.2 L
s
.44409 1.15373 m
.38281 1.07436 L
s
.38281 1.07436 m
.56762 1.2 L
s
.56686 1.2 m
.44409 1.15373 L
s
.56838 1.2 m
.53436 1.08865 L
.38281 1.07436 L
s
.38281 1.07436 m
.56762 1.2 L
s
.38281 1.07436 m
.34238 .98646 L
.53436 1.08865 L
.38281 1.07436 L
s
.53436 1.08865 m
.52125 .97808 L
.34238 .98646 L
.53436 1.08865 L
s
.34238 .98646 m
.31518 .89186 L
.52125 .97808 L
.34238 .98646 L
s
.52125 .97808 m
.52147 .86352 L
.31518 .89186 L
.52125 .97808 L
s
.31518 .89186 m
.29465 .79234 L
.52147 .86352 L
.31518 .89186 L
s
.52147 .86352 m
.52428 .7386 L
.29465 .79234 L
.52147 .86352 L
s
.29465 .79234 m
.27606 .69215 L
.52428 .7386 L
.29465 .79234 L
s
.52428 .7386 m
.51212 .6042 L
.27606 .69215 L
.52428 .7386 L
s
.27606 .69215 m
.2596 .59911 L
.51212 .6042 L
.27606 .69215 L
s
.51212 .6042 m
.4728 .47345 L
.2596 .59911 L
.51212 .6042 L
s
.2596 .59911 m
.25333 .52321 L
.4728 .47345 L
.2596 .59911 L
s
.4728 .47345 m
.41757 .36839 L
.25333 .52321 L
.4728 .47345 L
s
.25333 .52321 m
.27145 .47324 L
.41757 .36839 L
.25333 .52321 L
s
.41757 .36839 m
.38421 .30932 L
.27145 .47324 L
.41757 .36839 L
s
.27145 .47324 m
.32699 .4536 L
.38421 .30932 L
.27145 .47324 L
s
.38421 .30932 m
.41422 .30421 L
.32699 .4536 L
.38421 .30932 L
s
.32699 .4536 m
.42365 .4631 L
.41422 .30421 L
.32699 .4536 L
s
.41422 .30421 m
.52125 .34581 L
.42365 .4631 L
.41422 .30421 L
s
.42365 .4631 m
.55341 .49643 L
.52125 .34581 L
.42365 .4631 L
s
.52125 .34581 m
.68338 .41709 L
.55341 .49643 L
.52125 .34581 L
s
.55341 .49643 m
.70144 .54715 L
.68338 .41709 L
.55341 .49643 L
s
.68338 .41709 m
.86574 .50024 L
.70144 .54715 L
.68338 .41709 L
s
.70144 .54715 m
.85295 .61076 L
.86574 .50024 L
.70144 .54715 L
s
.86574 .50024 m
0 0 rlineto s
.86574 .50024 m
1 .56279 L
s
1 .59071 m
.85295 .61076 L
.86574 .50024 L
s
.85295 .61076 m
.99605 .68614 L
s
.99605 .68614 m
1 .67815 L
s
1 .59071 m
.85295 .61076 L
s
1 .68586 m
.99605 .68614 L
s
.99605 .68614 m
1 .67815 L
s
.99605 .68614 m
0 0 rlineto s
.99605 .68614 m
1 .68898 L
s
1 .68586 m
.99605 .68614 L
s
.73955 1.2 m
.73288 1.15373 L
s
.73288 1.15373 m
.57085 1.2 L
s
.56838 1.2 m
.53436 1.08865 L
.73288 1.15373 L
s
.73288 1.15373 m
.57085 1.2 L
s
.73288 1.15373 m
.73268 1.01862 L
.53436 1.08865 L
.73288 1.15373 L
s
.53436 1.08865 m
.52125 .97808 L
.73268 1.01862 L
.53436 1.08865 L
s
.73268 1.01862 m
.74619 .90417 L
.52125 .97808 L
.73268 1.01862 L
s
.52125 .97808 m
.52147 .86352 L
.74619 .90417 L
.52125 .97808 L
s
.74619 .90417 m
.78353 .79321 L
.52147 .86352 L
.74619 .90417 L
s
.52147 .86352 m
.52428 .7386 L
.78353 .79321 L
.52147 .86352 L
s
.78353 .79321 m
.83501 .66454 L
.52428 .7386 L
.78353 .79321 L
s
.52428 .7386 m
.51212 .6042 L
.83501 .66454 L
.52428 .7386 L
s
.83501 .66454 m
.85959 .50979 L
.51212 .6042 L
.83501 .66454 L
s
.51212 .6042 m
.4728 .47345 L
.85959 .50979 L
.51212 .6042 L
s
.85959 .50979 m
.81245 .34779 L
.4728 .47345 L
.85959 .50979 L
s
.4728 .47345 m
.41757 .36839 L
.81245 .34779 L
.4728 .47345 L
s
.81245 .34779 m
.69529 .22004 L
.41757 .36839 L
.81245 .34779 L
s
.41757 .36839 m
.38421 .30932 L
.69529 .22004 L
.41757 .36839 L
s
.69529 .22004 m
.57867 .16572 L
.38421 .30932 L
.69529 .22004 L
s
.38421 .30932 m
.41422 .30421 L
.57867 .16572 L
.38421 .30932 L
s
.57867 .16572 m
.55422 .19681 L
.41422 .30421 L
.57867 .16572 L
s
.41422 .30421 m
.52125 .34581 L
.55422 .19681 L
.41422 .30421 L
s
.55422 .19681 m
.65144 .29406 L
.52125 .34581 L
.55422 .19681 L
s
.52125 .34581 m
.68338 .41709 L
.65144 .29406 L
.52125 .34581 L
s
.65144 .29406 m
.81891 .42207 L
.68338 .41709 L
.65144 .29406 L
s
.68338 .41709 m
.86574 .50024 L
.81891 .42207 L
.68338 .41709 L
s
.81891 .42207 m
.99022 .54715 L
.86574 .50024 L
.81891 .42207 L
s
.86574 .50024 m
0 0 rlineto s
.86574 .50024 m
1 .56279 L
s
1 .55364 m
.99022 .54715 L
.86574 .50024 L
s
.99022 .54715 m
0 0 rlineto s
.99022 .54715 m
1 .5537 L
s
1 .55364 m
.99022 .54715 L
s
.73955 1.2 m
.73288 1.15373 L
s
.73288 1.15373 m
.8167 1.2 L
s
.87072 1.2 m
.89296 1.02555 L
.73288 1.15373 L
s
.73288 1.15373 m
.8167 1.2 L
s
.73288 1.15373 m
.73268 1.01862 L
.89296 1.02555 L
.73288 1.15373 L
s
.89296 1.02555 m
.90029 .87588 L
.73268 1.01862 L
.89296 1.02555 L
s
.73268 1.01862 m
.74619 .90417 L
.90029 .87588 L
.73268 1.01862 L
s
.90029 .87588 m
.92166 .77049 L
.74619 .90417 L
.90029 .87588 L
s
.74619 .90417 m
.78353 .79321 L
.92166 .77049 L
.74619 .90417 L
s
.92166 .77049 m
.99592 .68167 L
.78353 .79321 L
.92166 .77049 L
s
.78353 .79321 m
.83501 .66454 L
.99592 .68167 L
.78353 .79321 L
s
.99592 .68167 m
0 0 rlineto s
.99592 .68167 m
1 .6778 L
s
1 .6084 m
.83501 .66454 L
.99592 .68167 L
s
.83501 .66454 m
.85959 .50979 L
s
.85959 .50979 m
1 .54267 L
s
1 .6084 m
.83501 .66454 L
s
1 .46899 m
.85959 .50979 L
s
.85959 .50979 m
1 .54267 L
s
.85959 .50979 m
.81245 .34779 L
s
.81245 .34779 m
1 .37671 L
s
1 .46899 m
.85959 .50979 L
s
1 .28403 m
.81245 .34779 L
s
.81245 .34779 m
1 .37671 L
s
.81245 .34779 m
.69529 .22004 L
s
.69529 .22004 m
1 .22134 L
s
1 .28403 m
.81245 .34779 L
s
1 .0838 m
.69529 .22004 L
s
.69529 .22004 m
1 .22134 L
s
.69529 .22004 m
.57867 .16572 L
s
.57867 .16572 m
1 .08081 L
s
1 .0838 m
.69529 .22004 L
s
1 .07634 m
.79989 .04315 L
.57867 .16572 L
s
.57867 .16572 m
1 .08081 L
s
.57867 .16572 m
.55422 .19681 L
.79989 .04315 L
.57867 .16572 L
s
.79989 .04315 m
.70657 .13064 L
.55422 .19681 L
.79989 .04315 L
s
.55422 .19681 m
.65144 .29406 L
.70657 .13064 L
.55422 .19681 L
s
.70657 .13064 m
.78113 .30207 L
.65144 .29406 L
.70657 .13064 L
s
.65144 .29406 m
.81891 .42207 L
.78113 .30207 L
.65144 .29406 L
s
.78113 .30207 m
.92457 .49976 L
.81891 .42207 L
.78113 .30207 L
s
.81891 .42207 m
.99022 .54715 L
.92457 .49976 L
.81891 .42207 L
s
.92457 .49976 m
0 0 rlineto s
.92457 .49976 m
1 .61298 L
s
1 .57157 m
.99022 .54715 L
.92457 .49976 L
s
.99022 .54715 m
0 0 rlineto s
.99022 .54715 m
1 .5537 L
s
1 .57157 m
.99022 .54715 L
s
.95014 1.2 m
.97471 1.08598 L
s
.97471 1.08598 m
.88828 1.2 L
s
.87072 1.2 m
.89296 1.02555 L
.97471 1.08598 L
s
.97471 1.08598 m
.88828 1.2 L
s
.97471 1.08598 m
0 0 rlineto s
.97471 1.08598 m
1 .89527 L
s
1 .85966 m
.89296 1.02555 L
.97471 1.08598 L
s
.89296 1.02555 m
.90029 .87588 L
s
.90029 .87588 m
1 .85187 L
s
1 .85966 m
.89296 1.02555 L
s
1 .82024 m
.97431 .68973 L
.90029 .87588 L
s
.90029 .87588 m
1 .85187 L
s
.90029 .87588 m
.92166 .77049 L
.97431 .68973 L
.90029 .87588 L
s
.97431 .68973 m
.99156 .59452 L
.92166 .77049 L
.97431 .68973 L
s
.92166 .77049 m
.99592 .68167 L
.99156 .59452 L
.92166 .77049 L
s
.99156 .59452 m
0 0 rlineto s
.99156 .59452 m
1 .58999 L
s
1 .67603 m
.99592 .68167 L
.99156 .59452 L
s
.99592 .68167 m
0 0 rlineto s
.99592 .68167 m
1 .6778 L
s
1 .67603 m
.99592 .68167 L
s
1 .07634 m
.79989 .04315 L
s
.79989 .04315 m
1 .00251 L
s
.88348 0 m
.79989 .04315 L
s
.79989 .04315 m
1 .00251 L
s
.79989 .04315 m
.70657 .13064 L
s
.70657 .13064 m
.9073 0 L
s
.88348 0 m
.79989 .04315 L
s
.9402 0 m
.84263 .09927 L
.70657 .13064 L
s
.70657 .13064 m
.9073 0 L
s
.70657 .13064 m
.78113 .30207 L
.84263 .09927 L
.70657 .13064 L
s
.84263 .09927 m
.88882 .35238 L
.78113 .30207 L
.84263 .09927 L
s
.78113 .30207 m
.92457 .49976 L
.88882 .35238 L
.78113 .30207 L
s
.88882 .35238 m
.97317 .62086 L
.92457 .49976 L
.88882 .35238 L
s
.92457 .49976 m
0 0 rlineto s
.92457 .49976 m
1 .61298 L
s
1 .64224 m
.97317 .62086 L
.92457 .49976 L
s
.97317 .62086 m
0 0 rlineto s
.97317 .62086 m
1 .8088 L
s
1 .64224 m
.97317 .62086 L
s
.95014 1.2 m
.97471 1.08598 L
s
.97471 1.08598 m
.95008 1.2 L
s
.96725 1.2 m
1 1.12549 L
s
1 1.05047 m
.97471 1.08598 L
s
.97471 1.08598 m
.95008 1.2 L
s
.97471 1.08598 m
0 0 rlineto s
.97471 1.08598 m
1 .89527 L
s
1 1.05047 m
.97471 1.08598 L
s
1 .82024 m
.97431 .68973 L
s
.97431 .68973 m
1 .68423 L
s
1 .60973 m
.93016 .49944 L
.97431 .68973 L
s
.97431 .68973 m
1 .68423 L
s
.97431 .68973 m
.99156 .59452 L
.93016 .49944 L
.97431 .68973 L
s
.93016 .49944 m
.9626 .40127 L
.99156 .59452 L
.93016 .49944 L
s
.99156 .59452 m
0 0 rlineto s
.99156 .59452 m
1 .58999 L
s
1 .43726 m
.9626 .40127 L
.99156 .59452 L
s
.9626 .40127 m
0 0 rlineto s
.9626 .40127 m
1 .39221 L
s
1 .43726 m
.9626 .40127 L
s
.9402 0 m
.84263 .09927 L
s
.84263 .09927 m
.96501 0 L
s
1 .03348 m
.95303 .09187 L
.84263 .09927 L
s
.84263 .09927 m
.96501 0 L
s
.84263 .09927 m
.88882 .35238 L
.95303 .09187 L
.84263 .09927 L
s
.95303 .09187 m
.97232 .41997 L
.88882 .35238 L
.95303 .09187 L
s
.88882 .35238 m
.97317 .62086 L
.97232 .41997 L
.88882 .35238 L
s
.97232 .41997 m
.95421 .7461 L
.97317 .62086 L
.97232 .41997 L
s
.97317 .62086 m
0 0 rlineto s
.97317 .62086 m
1 .8088 L
s
1 .83845 m
.95421 .7461 L
.97317 .62086 L
s
.95421 .7461 m
.89296 1.02555 L
s
.89296 1.02555 m
1 .85966 L
s
1 .83845 m
.95421 .7461 L
s
1 1.00881 m
.89296 1.02555 L
s
.89296 1.02555 m
1 .85966 L
s
.89296 1.02555 m
0 0 rlineto s
.89296 1.02555 m
.9079 1.2 L
s
.92381 1.2 m
1 1.05061 L
s
1 1.00881 m
.89296 1.02555 L
s
1 1.12017 m
.9327 1.2 L
s
.92381 1.2 m
1 1.05061 L
s
.97841 1.2 m
1 1.15775 L
s
1 1.12017 m
.9327 1.2 L
s
.97841 1.2 m
1 1.15775 L
s
.97404 1.2 m
1 1.17327 L
s
.97404 1.2 m
1 1.17327 L
s
.9626 1.2 m
.98459 1.1688 L
s
.98459 1.1688 m
1 1.1631 L
s
1 1.17134 m
.98459 1.1688 L
s
.98459 1.1688 m
1 1.1631 L
s
.98459 1.1688 m
0 0 rlineto s
.98459 1.1688 m
1 1.19956 L
s
1 1.17134 m
.98459 1.1688 L
s
.99061 1.2 m
.99662 1.15596 L
s
.99662 1.15596 m
.97362 1.2 L
s
.96725 1.2 m
1 1.12549 L
s
1 1.14741 m
.99662 1.15596 L
s
.99662 1.15596 m
.97362 1.2 L
s
.99662 1.15596 m
0 0 rlineto s
.99662 1.15596 m
1 1.15043 L
s
1 1.14741 m
.99662 1.15596 L
s
1 .55866 m
.99022 .54715 L
s
.99022 .54715 m
1 .57157 L
s
1 .60973 m
.93016 .49944 L
.99022 .54715 L
s
.99022 .54715 m
1 .57157 L
s
.99022 .54715 m
.7899 .34418 L
.93016 .49944 L
.99022 .54715 L
s
.93016 .49944 m
.9626 .40127 L
.7899 .34418 L
.93016 .49944 L
s
.7899 .34418 m
.89541 .21776 L
.9626 .40127 L
.7899 .34418 L
s
.9626 .40127 m
0 0 rlineto s
.9626 .40127 m
1 .39221 L
s
1 .28874 m
.89541 .21776 L
.9626 .40127 L
s
.89541 .21776 m
0 0 rlineto s
.89541 .21776 m
1 .19936 L
s
1 .28874 m
.89541 .21776 L
s
1 .03348 m
.95303 .09187 L
s
.95303 .09187 m
1 .03812 L
s
1 .09358 m
.95303 .09187 L
s
.95303 .09187 m
1 .03812 L
s
.95303 .09187 m
.97232 .41997 L
s
.97232 .41997 m
1 .29351 L
s
1 .09358 m
.95303 .09187 L
s
1 .44166 m
.97232 .41997 L
s
.97232 .41997 m
1 .29351 L
s
.97232 .41997 m
.95421 .7461 L
s
.95421 .7461 m
1 .61244 L
s
1 .44166 m
.97232 .41997 L
s
1 .57547 m
.87681 .83631 L
.95421 .7461 L
s
.95421 .7461 m
1 .61244 L
s
.95421 .7461 m
.89296 1.02555 L
.87681 .83631 L
.95421 .7461 L
s
.87681 .83631 m
.73288 1.15373 L
.89296 1.02555 L
.87681 .83631 L
s
.89296 1.02555 m
0 0 rlineto s
.89296 1.02555 m
.9079 1.2 L
s
.8453 1.2 m
.73288 1.15373 L
.89296 1.02555 L
s
.73288 1.15373 m
0 0 rlineto s
.73288 1.15373 m
.75554 1.2 L
s
.8453 1.2 m
.73288 1.15373 L
s
.9626 1.2 m
.98459 1.1688 L
s
.98459 1.1688 m
.97363 1.2 L
s
.94396 1.2 m
.98459 1.1688 L
s
.98459 1.1688 m
.97363 1.2 L
s
.98459 1.1688 m
0 0 rlineto s
.98459 1.1688 m
1 1.19956 L
s
.94396 1.2 m
.98459 1.1688 L
s
.99061 1.2 m
.99662 1.15596 L
s
.99662 1.15596 m
.98424 1.2 L
s
1 1.15318 m
.99662 1.15596 L
s
.99662 1.15596 m
.98424 1.2 L
s
.99662 1.15596 m
0 0 rlineto s
.99662 1.15596 m
1 1.15043 L
s
1 1.15318 m
.99662 1.15596 L
s
1 .55866 m
.99022 .54715 L
s
.99022 .54715 m
1 .55286 L
s
1 .57146 m
.86574 .50024 L
.99022 .54715 L
s
.99022 .54715 m
1 .55286 L
s
.99022 .54715 m
.7899 .34418 L
.86574 .50024 L
.99022 .54715 L
s
.86574 .50024 m
.61244 .25332 L
.7899 .34418 L
.86574 .50024 L
s
.7899 .34418 m
.89541 .21776 L
.61244 .25332 L
.7899 .34418 L
s
.61244 .25332 m
.86952 .06749 L
.89541 .21776 L
.61244 .25332 L
s
.89541 .21776 m
0 0 rlineto s
.89541 .21776 m
1 .19936 L
s
1 .13732 m
.86952 .06749 L
.89541 .21776 L
s
.86952 .06749 m
0 0 rlineto s
.86952 .06749 m
1 .03154 L
s
1 .13732 m
.86952 .06749 L
s
1 .57547 m
.87681 .83631 L
s
.87681 .83631 m
1 .67416 L
s
1 .63123 m
.76613 .86213 L
.87681 .83631 L
s
.87681 .83631 m
1 .67416 L
s
.87681 .83631 m
.73288 1.15373 L
.76613 .86213 L
.87681 .83631 L
s
.76613 .86213 m
0 0 rlineto s
.76613 .86213 m
.56896 1.2 L
s
.57085 1.2 m
.73288 1.15373 L
.76613 .86213 L
s
.73288 1.15373 m
0 0 rlineto s
.73288 1.15373 m
.75554 1.2 L
s
.57085 1.2 m
.73288 1.15373 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[35]:=",
  ImageSize->{240, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003`000182000`400?l00000o`00003ol03oool0
0=80oooo0P0000030?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`8000001P3oool30000
0000d03oool2000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo0?ooo`D000000`3oool00<h0oooo0P0000040?ooo`800000203oool00`000000
oooo0?ooo`020?ooo`D00000203oool00<`0oooo0P0000050?ooo`030000003oool0oooo00L0oooo
1P00000=0?ooo`00bP3oool2000000D0oooo0P0000060?ooo`D000000P3oool2000000h0oooo0038
0?ooo`8000001@3oool2000000@0oooo100000020?ooo`050000003oool0oooo0?ooo`000000403o
ool00<H0oooo0P0000060?ooo`030000003oool0000000@000001@3oool01@000000oooo0?ooo`3o
ool000000140oooo00340?ooo`8000001@3oool5000000T0oooo00D000000?ooo`3oool0oooo0000
000?0?ooo`<0000000320?ooo`8000000P3oool6000000`0oooo00<000000?ooo`3oool00P00000=
0?ooo`<000000P3oool100000000`03oool6000000<0oooo0P00000<0?ooo`040000003oool0oooo
000000/0oooo100000050?ooo`400000002n0?ooo`D000001@3oool00`000000oooo0?ooo`0;0?oo
o`040000003oool0oooo000000T0oooo0`0000080?ooo`800000002l0?ooo`8000001@3oool60000
00`0oooo00@000000?ooo`00000000001P3oool4000000X0oooo0P0000010?ooo`00^P3oool30000
00P0oooo00@000000?ooo`3oool0oooo1P0000050?ooo`030000003oool0000000@0oooo1000000=
0?ooo`8000000P3oool00;T0oooo0`0000070?ooo`8000002P3oool700000080oooo0`00000@0?oo
o`8000000`3oool00;L0oooo0P0000000`3oool000000?ooo`060?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`0000001P00000?0?ooo`800000103oool00;D0oooo0`0000000`3oool00000
0?ooo`050?ooo`8000003P3oool4000000L0oooo1P0000080?ooo`8000001@3oool00;<0oooo0`00
00020?ooo`030000003oool0oooo00<0oooo0P00000>0?ooo`@000003`3oool600000080oooo00<0
00000?ooo`3oool0103oool00;40oooo100000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo00000003000001@0oooo1P0000030?ooo`00[`3oool40000
00<0oooo00<000000?ooo`3oool00P3oool2000000l0oooo00@000000?ooo`00000000000`3oool2
00000180oooo00<000000?ooo`3oool00`3oool300000000[P3oool00`000000oooo000000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool2000000040?ooo`0000000000
000000D0oooo0P00000?0?ooo`030000003oool0oooo00<0oooo100000000:`0oooo100000030?oo
o`8000000`3oool2000000l0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`04
0?ooo`800000303oool00`000000oooo0000000400000080oooo0P0000000:X0oooo0P0000000`3o
ool000000?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool20000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`8000001`3oool50000
00D0oooo0P0000020?ooo`00Z03oool2000000030?ooo`000000000000@0oooo00@000000?ooo`3o
ool0oooo0P00000?0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`03
0?oooaX00000002V0?ooo`80000000<0oooo0000000000001@3oool01@000000oooo0?ooo`3oool0
00000100oooo00<000000?ooo`0000003P0000020?ooo`L00000103oool010000000oooo0?ooo`3o
ool2000000L0oooo002T0?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo008000003`3oool4000000030?ooo`000000000000H0oooo00<000000?ooo`3oool01@000007
0?ooo`8000000P3oool010000000oooo0000000000090?ooo`00X`3oool00`000000oooo0?ooo`02
000000H0oooo00@000000?ooo`3oool000003@3oool4000000H0oooo00<000000?ooo`3oool00P3o
ool5000000h0oooo1000000;0?ooo`00X@3oool200000080oooo00<000000?ooo`3oool01@3oool0
10000000oooo00000000000:0?ooo`@0000000<0oooo0000000000001P3oool6000000<0oooo00<0
00000?ooo`3oool0303oool5000000/0oooo002O0?ooo`8000000P3oool2000000L0oooo0`000007
0?ooo`D00000103oool00`000000oooo0?ooo`020?ooo`D0000000<0oooo0000003oool01@3oool0
0`000000oooo0?ooo`0:0?ooo`8000000P3oool2000000030?ooo`000000000000T0oooo002M0?oo
o`8000000P3oool2000000P0oooo0P0000050?ooo`@00000203oool6000000@0oooo00<000000?oo
o`0000001P3oool00`000000oooo0?ooo`080?ooo`800000103oool2000000<0oooo0P0000070?oo
o`00V`3oool2000000<0oooo00<000000?ooo`3oool01`3oool200000080oooo100000080?ooo`D0
0000203oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00D0oooo0`0000050?oo
o`030000003oool0000000D0oooo0P0000050?ooo`00VP3oool010000000oooo0?ooo`3oool20000
00T0oooo1@0000070?ooo`D0000000<0oooo0000003oool02P3oool010000000oooo0?ooo`000007
0?ooo`030000003oool0oooo0080oooo0P0000080?ooo`030000003oool0000000L0oooo0P000003
0?ooo`00V03oool2000000<0oooo00<000000?ooo`3oool01`3oool3000000H0oooo1@0000050?oo
o`030000003oool0oooo00X0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`02
000000X0oooo00@000000?ooo`3oool00000203oool200000040oooo002F0?ooo`8000000`3oool2
000000P0oooo0P000000103oool000000?ooo`3oool5000000P0oooo0P00000<0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool3000000`0oooo00@000000?ooo`3oool00000
2P3oool100000000U03oool2000000@0oooo00<000000?ooo`3oool01@3oool3000000030?ooo`00
0000000000<00000303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool3000000d0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`00TP3o
ool2000000@0oooo0P0000060?ooo`H0000000@0oooo0000003oool000002`3oool2000000l0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool0
2`3oool01@000000oooo0?ooo`3oool0000000/0oooo002@0?ooo`800000103oool2000000@0oooo
1@0000060?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`030?ooo`<000001@3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?oo
o`0000002`3oool008l0oooo00<000000?ooo`3oool00`3oool00`000000oooo00000006000000P0
oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00l0oooo00@000000?oo
o`3oool0oooo0`0000070?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`00S@3oool2000000<0oooo1@0000020?ooo`<000002P3oool01@000000oooo0?ooo`3o
ool0000000H0oooo0P00000B0?ooo`040000003oool0000000000080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2@3oool008/0oooo200000040?ooo`8000003@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool04P3oool2000000D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool008T0oooo100000030?ooo`8000000`3oool2000000h0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`02000001<0oooo0P0000070?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00280?oo
o`<0000000<0oooo0000000000000P0000030?ooo`800000403oool00`000000oooo0?ooo`040?oo
o`8000004P3oool3000000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool008L0
oooo00<000000?ooo`0000000`3oool600000180oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0?0?ooo`800000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0
oooo00250?ooo`80000000@0oooo0000003oool0oooo0P0000000`3oool000000000000300000140
oooo00<000000?ooo`3oool00`3oool2000000030?ooo`000000oooo00d0oooo0P0000050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool008@0oooo0P0000001P3oool00000
0?ooo`3oool000000?ooo`8000001@3oool2000000l0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000/0oooo0`0000070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02@3oool008<0oooo0P0000020?ooo`D000002@3oool2000000d0oooo00<000000?oo
o`3oool00P0000040?ooo`030000003oool0oooo00L0oooo0P00000:0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02@3oool00840oooo0P0000030?ooo`@000003@3oool2000000X0
oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`040?ooo`8000002`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00200?ooo`8000000`3oool200000180
oooo0P0000080?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool00P3oool2000000d0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`00O`3oool200000080oooo
0P00000F0?ooo`8000001P3oool2000000X0oooo1000000?0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool300000000O@3oool300000080oooo00@000000?ooo`0000000000
5`3oool2000000<0oooo00<000000?ooo`3oool02@3oool200000140oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`05000000<0oooo001l0?ooo`030000003oool000000080oooo00H0
00000?ooo`3oool000000?ooo`00000H0?ooo`@000002@3oool200000080oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`030?ooo`D00000203oool007/0oooo0`0000000`3oool00000
000000020?ooo`050000003oool0oooo0?ooo`0000005`3oool2000000030?ooo`000000000000D0
oooo0`0000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000100000020?ooo`03
0000003oool0oooo00P0oooo001i0?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool04`3oool010000000oooo0?ooo`0000020?ooo`80
000000<0oooo000000000000203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05000000L0oooo00<000000?ooo`3o
ool0203oool007P0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0403oool2000000<0oooo00<000000?ooo`3oool0
C000000007L0oooo00@000000?ooo`000000oooo0P0000060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`H000002P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00H0oooo2@0000040?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`00M@3oool2000000040?ooo`00
0000oooo000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00H00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo
2@0000060?ooo`030000003oool0oooo00<0oooo00@000000?ooo`000000oooo0`0000090?ooo`03
0000003oool0oooo00P0oooo001d0?ooo`060000003oool000000000003oool00000203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo1@0000020?ooo`8000001`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo2@00000>0?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo001b0?ooo`80000000<0oooo0000003oool00P0000090?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool3000000@0oooo00<000000?ooo`000000203oool00`00
0000oooo0?ooo`040?ooo`P000001`3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo
0?ooo`0000000`3oool010000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0203o
ool00740oooo00H000000?ooo`3oool000000?ooo`00000;0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00P3oool4000000D0oooo0P0000000`3oool000000?ooo`060?ooo`T00000
0`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool0
00001@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0203oool00700oooo00H000000?ooo`3oool000000?ooo`00000<0?ooo`030000003oool0
oooo00X0oooo100000000`3oool000000?ooo`040?ooo`8000000`3oool8000000@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`0000001P3oool00`000000oooo000000040?ooo`800000103oool00`000000oooo0?ooo`08
0?ooo`00KP3oool200000080oooo0`00000<0?ooo`030000003oool0oooo00P0oooo1@0000020?oo
o`030000003oool0oooo00X00000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03P3oool2000000L0oooo00<000000?ooo`0000001P3oool01@00
0000oooo0?ooo`3oool0000000X0oooo001]0?ooo`040000003oool0oooo0?ooo`8000003P3oool0
0`000000oooo0?ooo`050?ooo`<000001@3oool7000000H0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool2
000000P0oooo0P0000070?ooo`80000000<0oooo0000003oool02@3oool006`0oooo00<000000?oo
o`3oool00`00000?0?ooo`030000003oool0oooo0080oooo0`0000080?ooo`80000000<0oooo0000
00000000203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`800000203oool2000000T0oooo0P00000:0?oo
o`00JP3oool200000080oooo00<000000?ooo`000000403oool5000000`0oooo0P000000103oool0
00000000000000060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`000000203oool00`00
0000oooo0?ooo`090?ooo`8000002@3oool006T0oooo00@000000?ooo`3oool0oooo0`00000?0?oo
o`<000003`3oool01`000000oooo0?ooo`000000oooo0000003oool00P0000030?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00d0oooo00@000000?ooo`3oool00000203oool2000000/0oooo0P0000080?ooo`00J03o
ool010000000oooo0?ooo`3oool2000000d0oooo100000000`3oool000000?ooo`0=0?ooo`800000
103oool00`000000oooo000000020?ooo`80000000<0oooo0000003oool04@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool01@000000oooo
0?ooo`3oool0000000P0oooo0P00000;0?ooo`030000003oool0000000L0oooo001V0?ooo`800000
0`3oool2000000/0oooo0`0000050?ooo`030000003oool0oooo00X0oooo0P0000070?ooo`030000
003oool0000000<0oooo0P00000C0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0000000:0?ooo`030000003oool0oooo008000001@3oool006D0oooo00@0
00000?ooo`3oool0oooo0`0000090?ooo`<00000203oool00`000000oooo0?ooo`080?ooo`800000
2P3oool00`000000oooo000000020?ooo`030000003oool0000001<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`00I03oool010000000oooo0?ooo`3oool2000000L0
oooo1000000;0?ooo`030000003oool0oooo00H0oooo0P00000=0?ooo`050000003oool000000?oo
o`0000000P3oool200000180oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`040000003oool0
oooo000000X0oooo00<000000?ooo`3oool00`3oool400000000HP3oool2000000<0oooo0P000005
0?ooo`<000003P3oool00`000000oooo0?ooo`050?ooo`800000403oool010000000oooo00000000
00040?ooo`8000004@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo0080oooo100000010?ooo`00H@3oool00`000000oooo
0?ooo`020?ooo`8000000P3oool400000140oooo00<000000?ooo`3oool00`3oool2000001<0oooo
0`0000060?ooo`800000403oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000002@3oool00`000000oooo00000002000000@0oooo0@0000000600oooo00<000000?ooo`3o
ool00P3oool00`000000oooo00000002000001D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0C0?ooo`X0000000<0oooo0000000000003`3oool01P000000oooo0?ooo`000000oooo
000000/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`000000203oool3000000L0oooo0@00000005h0oooo0P0000040?ooo`<00000603oool0
0`000000oooo0?ooo`02000001<0oooo0`0000000`3oool000000?ooo`02000000D0oooo3`000004
0?ooo`040000003oool00000000000/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool3000000030?ooo`00
0000oooo00L0oooo0@00000005d0oooo00<000000?ooo`3oool01@00000I0?ooo`040000003oool0
0000000001<0oooo0P0000040?ooo`030000003oool0oooo008000002@3oool2000000P0oooo2@00
00090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00800000103oool00`000000oooo0?ooo`060?ooo`400000001L
0?ooo`D0000000@0oooo000000000000oooo0`00000F0?ooo`8000004P3oool3000000L0oooo00<0
00000?ooo`3oool00P00000:0?ooo`800000303oool2000000030?ooo`000000000000H0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0`00
00060?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`00F`3oool2000000D0oooo0P000004
0?ooo`8000004P3oool300000100oooo0`00000:0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02@3oool2000000X0oooo0`0000020?ooo`8000000`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`0000000`3oool000000?ooo`06
0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`00F`3oool00`000000oooo0?ooo`040?oo
o`8000001P3oool3000000d0oooo0P0000020?ooo`030000003oool0oooo00`0oooo0P00000=0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool2000000T0oooo0`0000030?oo
o`<000003`3oool010000000oooo0?ooo`3oool4000000@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`4000000@3oool005X0oooo00<000000?ooo`000000103oool00`00
0000oooo000000090?ooo`8000002@3oool2000000<0oooo00<000000?ooo`3oool02P3oool30000
0100oooo00<000000?ooo`3oool00`3oool2000000`0oooo0P0000080?ooo`030000003oool00000
00@0oooo0`00000=0?ooo`030000003oool0000000800000203oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo0@0000010?ooo`00F@3oool2000000030?ooo`000000oooo0080
oooo00@000000?ooo`3oool000002`3oool3000000D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`080?ooo`8000004`3oool00`000000oooo0?ooo`040?ooo`8000003@3oool00`00
0000oooo0?ooo`050?ooo`<000000`3oool010000000oooo0?ooo`3oool2000000X0oooo0`000002
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`4000000@3oool10?ooo`00F@3oool200000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0<0?ooo`80000000<0oooo0000000000001P3oool00`000000oooo0?ooo`05
0?ooo`<000005@3oool00`000000oooo0?ooo`050?ooo`8000003@3oool2000000H0oooo0`000000
0`3oool000000?ooo`050?ooo`8000001P3oool200000080oooo00@000000?ooo`3oool00000203o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`40oooo001H
0?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool03@3oool4000000H0oooo00<00000
0?ooo`3oool00P3oool3000001P0oooo00<000000?ooo`3oool01P3oool3000000d0oooo0P000004
0?ooo`040000003oool00000000000T0oooo0P000000103oool000000000000000040?ooo`030000
003oool0000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`400000
0@3oool10?ooo`00E`3oool00`000000oooo000000040?ooo`8000000`3oool00`000000oooo0?oo
o`0;0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool00P00000L0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`0000003P3oool200000080oooo00@000000?ooo`0000000000
2@3oool4000000H0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo0@0000010?ooo`40oooo001F0?ooo`040000003oool0oooo000000@0oooo
0P0000030?ooo`030000003oool0oooo00T0oooo0P0000080?ooo`L000007P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0000000l0oooo0P0000001@3oool000000?ooo`3oool0000000D0
oooo0`0000040?ooo`<000000`3oool00`000000oooo0000000:0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool100000040oooo0@3oool005H0oooo00<000000?ooo`000000
103oool00`000000oooo000000040?ooo`030000003oool0oooo00H0oooo0P00000=0?ooo`800000
803oool00`000000oooo0?ooo`080?ooo`040000003oool00000000000l0oooo0`0000020?ooo`03
0000003oool00000008000002P3oool200000080oooo0P00000;0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00E@3oool010000000oooo
0?ooo`0000040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool20000
00l0oooo00@000000?ooo`00000000007P3oool00`000000oooo0?ooo`090?ooo`040000003oool0
oooo000000/0oooo3@00000<0?ooo`<00000303oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00@3oool005@0oooo00@000000?ooo`3oool00000103o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0>0?ooo`8000000`3oool3000001`0oooo00<000000?ooo`3oool0103ooolC000000@0oooo
100000001@3oool00000000000000000oooo00L000001P3oool3000000/0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001D0?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?oo
o`800000403oool010000000oooo0?ooo`0000050?ooo`8000003P3ooolC000000H0oooo00<00000
0?ooo`3oool00P00000:0?ooo`D000000P3oool2000000040?ooo`0000000000000000D0oooo1P00
0000103oool000000?ooo`00000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`010?ooo`00D`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool0103oool010000000oooo0000003oool200000140oooo00D000000?ooo`3o
ool0oooo000000020?oooa<00000303oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo
0?ooo`0000001`3oool2000000<0oooo0`0000020?ooo`8000000`3oool3000000P0oooo1`000008
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`00DP3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool010000000oooo0000
000000070?oooa<000001`3oool3000001H0oooo00<000000?ooo`3oool02`3oool01@000000oooo
0?ooo`3oool0000000<0oooo0`0000050?ooo`@0000000<0oooo0000000000001P3oool3000000L0
oooo00D000000?ooo`3oool000000?ooo`06000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo0080oooo001B0?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`050?ooo`/000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00X0oooo0P00000D0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool0oooo0`00
00090?ooo`030000003oool000000080000000<0oooo0000003oool01`3oool3000000@0oooo00@0
00000?ooo`3oool0oooo0P0000050?ooo`H0000000<0oooo0000003oool00P3oool00`000000oooo
0?ooo`020?ooo`00D@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
1@3oool010000000oooo00000000000B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0303oool200000180oooo00<000000?ooo`3oool03@3oool300000080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`03000000030?ooo`000000oooo00T0oooo0`0000000`3oool0
00000?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`0000030?ooo`00
D03oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001@3oool2000000<0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0
oooo0`00000?0?ooo`030000003oool0oooo00/0oooo0P0000000`3oool000000?ooo`030?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo00X0
oooo0`0000050?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0300000000D03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00D0oooo0P0000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0@0?ooo`8000003P3oool00`000000oooo0?ooo`070?ooo`<00000103oool00`00
0000oooo0?ooo`020?ooo`8000001`3oool010000000oooo0?ooo`3oool2000000030?ooo`000000
oooo00`0oooo1@0000030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`030?ooo`00C`3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000103oool2000000D0oooo0P00000>0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool04P3oool2000000`0oooo00<000000?ooo`3oool0103oool3000000P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`8000000P3oool3000000030?ooo`00
0000oooo00`0oooo00@000000?ooo`3oool0oooo0`0000000`3oool00000000000040?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool004h0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000030?ooo`<000001P3oool00`000000oooo0000000<0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0503oool2000000X0oooo00<000000?ooo`3o
ool00P3oool2000000`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo0?ooo`<0000000<0oooo0000003oool02`3oool2000000D0oooo100000040?oo
o`060000003oool0oooo0000003oool000000`3oool200000000C@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001`3oool00`000000oooo0000000<
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05@3oool3000000L0oooo00<00000
0?ooo`0000000P00000?0?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`8000000P3oool0
1P000000oooo000000000000oooo000000/0oooo0P0000080?ooo`<000000P3oool01@000000oooo
0?ooo`000000oooo00@000000P3oool004d0oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`000000oooo0080000000<0oooo0000003oool01`3oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0603oool2000000@0oooo0`00000C0?oo
o`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`040000003oool0
00000?ooo`8000002`3oool2000000X0oooo1@000000103oool000000000000000050?ooo`00C03o
ool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo
0?ooo`070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0J0?ooo`@000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`3oool0oooo0P0000020?ooo`040000003oool000000?ooo`8000002`3oool2
000000X0oooo1`0000060?ooo`00B`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
008000000P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000001`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01T0oooo1P0000000`3oool000000?ooo`0D
0?ooo`030000003oool0oooo00@0oooo0P0000000`3oool00000000000020?ooo`050000003oool0
oooo0000003oool00P00000:0?ooo`800000303oool2000000030?ooo`000000000000H0oooo001;
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`00000000000P3oool00`000000oooo0?oo
o`090?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo01H0oooo0`0000060?ooo`<000005@3oool00`000000oooo0?ooo`050?ooo`800000
00@0oooo0000003oool000000`3oool00`000000oooo0000000:0?ooo`800000303oool200000003
0?ooo`000000000000H0oooo001:0?ooo`030000003oool0oooo00D0oooo0`0000020?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool3000000X0oooo4P0000060?ooo`030000
003oool0oooo00D0oooo0`0000000`3oool000000?ooo`030?ooo`030000003oool0000000T0oooo
00<000000?ooo`0000002`3oool4000000030?ooo`000000oooo00@0oooo00190?ooo`030000003o
ool0oooo00D0oooo0`0000020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403o
ool2000000`0oooo0`0000000`3oool000000000000=0?oooa80000000<0oooo0000003oool00`3o
ool00`000000oooo000000090?ooo`8000002`3oool5000000030?ooo`000000oooo00<0oooo0019
0?ooo`030000003oool0oooo00@0oooo0`0000020?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo00d0oooo0`00
000<0?ooo`8000000P3oool010000000oooo0?ooo`3oool2000001<0oooo00<000000?ooo`3oool0
103oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`000000203oool2000000X0
oooo00<000000?ooo`3oool00P000000103oool000000?ooo`0000030?ooo`00B03oool00`000000
oooo0?ooo`040?ooo`80000000@0oooo0000003oool00000403oool00`000000oooo0?ooo`030?oo
o`8000004`3oool00`000000oooo0?ooo`0:0?ooo`<000003@3oool2000000@0oooo00<000000?oo
o`3oool00`3oool300000140oooo00<000000?ooo`3oool0103oool4000000H0oooo0`0000070?oo
o`8000002P3oool00`000000oooo0?ooo`0200000080oooo0`0000020?ooo`00A`3oool00`000000
oooo0?ooo`030?ooo`80000000D0oooo000000000000oooo0000000A0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`070?ooo`8000003`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo0P00000@0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000000P0000060?ooo`<000001P3oool00`000000oooo000000090?oo
o`030000003oool0oooo00800000103oool200000040oooo00170?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool0oooo0`00000B0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`000000503oool00`000000oooo0?ooo`040?ooo`<000003`3oool2000000P0oooo00<000000?oo
o`3oool01`3oool2000000l0oooo00<000000?ooo`3oool00`3oool2000000030?ooo`0000000000
00H0oooo0`0000050?ooo`030000003oool0000000P0oooo00@000000?ooo`3oool0oooo0P000005
0?ooo`80000000160?ooo`040000003oool0oooo0?ooo`8000000`3oool3000001<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0000000D0?ooo`040000003oool0oooo0?ooo`<00000403o
ool2000000X0oooo00<000000?ooo`3oool02@3oool2000000h0oooo00<000000?ooo`3oool00`3o
ool3000000030?ooo`000000000000D0oooo0`0000050?ooo`800000203oool010000000oooo0?oo
o`3oool2000000H0oooo0@00000004D0oooo00D000000?ooo`3oool0oooo000000050?ooo`800000
503oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool04@3oool010000000
oooo00000000000B0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool20000
00d0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`000000oooo008000001@3oool00`00
0000oooo000000040?ooo`030000003oool0000000L0oooo00@000000?ooo`3oool0oooo0P000007
0?ooo`00A03oool01@000000oooo0?ooo`3oool0000000D0oooo0P00000E0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0403oool300000180oooo0P00000=0?ooo`030000003o
ool0oooo00d0oooo0P00000<0?ooo`030000003oool0oooo0080oooo0`0000030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000060?ooo`030000003o
ool0oooo0080oooo0P0000070?ooo`00A03oool010000000oooo0000000000050?ooo`P00000403o
ool00`000000oooo000000060?ooo`030000003oool0oooo00`0oooo0`0000020?ooo`030000003o
ool0oooo00h0oooo0P00000?0?ooo`030000003oool0oooo00l0oooo0P00000;0?ooo`040000003o
ool0oooo0?ooo`<00000103oool2000000<0oooo0P0000001`3oool000000?ooo`3oool000000?oo
o`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00130?ooo`03
0000003oool0000000@0oooo0`0000000`3oool000000?ooo`050?ooo`/000001@3oool2000000L0
oooo00<000000?ooo`3oool02@3oool3000000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo0`0000090?ooo`040000003oool0oooo0?oo
o`8000001@3oool2000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo00000005
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00480oooo0`0000020?oo
o`<0000000D0oooo0000003oool0oooo0000000A0?ooo`P000001`3oool00`000000oooo0?ooo`06
0?ooo`800000203oool00`000000oooo0?ooo`0;0?ooo`8000004P3oool00`000000oooo0?ooo`0D
0?ooo`800000203oool010000000oooo0?ooo`3oool2000000H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00120?ooo`030000003oool00000008000000`3oool010000000oooo
0?ooo`3oool2000001@0oooo0P0000020?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`<0
00002P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool05P3oool2000000L0oooo00<000000?ooo`3oool00P0000070?ooo`8000000P3oool00`000000
oooo0?ooo`02000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool00`3oool2000000L0
oooo00110?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`8000005@3oool00`000000oooo
0?ooo`040?ooo`D0000000@0oooo00000000000000003P3oool00`000000oooo0?ooo`070?ooo`80
00005P3oool00`000000oooo0?ooo`0G0?ooo`8000001P3oool010000000oooo0?ooo`0000080?oo
o`8000000P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000001@3o
ool2000000@0oooo0`0000000400oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03
0?ooo`800000503oool00`000000oooo000000080?ooo`T000002`3oool00`000000oooo0?ooo`05
0?ooo`800000603oool00`000000oooo0?ooo`0I0?ooo`8000001@3oool010000000oooo00000000
00080?ooo`80000000<0oooo0000000000000P3oool00`000000oooo000000020?ooo`030000003o
ool0oooo00@0oooo1P0000030?ooo`00@03oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`0000004`3oool00`000000oooo000000030?ooo`H0000000@0oooo
0000003oool0oooo0`0000000`3oool000000000000:000000H0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0K0?ooo`800000103oool00`000000oooo0000000:0?ooo`@0000000@0
oooo00000000000000000P3oool00`000000oooo0?ooo`030?ooo`<000001`3oool003l0oooo0`00
00040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000004`3oool00`000000oooo0000
0003000000<0oooo00D000000?ooo`3oool0oooo000000050?ooo`@00000203oool<000001H0oooo
00<000000?ooo`3oool07@3oool2000000<0oooo0`00000:0?ooo`D0000000H0oooo000000000000
oooo0000003oool4000000030?ooo`000000000000L0oooo000o0?ooo`<000000`3oool00`000000
oooo0?ooo`060?ooo`030000003oool000000140oooo1@0000040?ooo`8000001@3oool00`000000
oooo0?ooo`060?ooo`@00000103oool00`000000oooo0?ooo`02000000L0oooo2`00000;0?ooo`03
0000003oool0oooo01l0oooo0`0000000`3oool000000000000;0?ooo`@000000P3oool4000000D0
oooo0`0000060?ooo`00?`3oool300000080oooo00<000000?ooo`3oool01`3oool010000000oooo
0?ooo`00000;0?ooo`D000000P3oool00`000000oooo000000020?ooo`8000001`3oool00`000000
oooo0?ooo`0:0?ooo`@0000000<0oooo000000000000503oool<000002@0oooo1000000<0?ooo`H0
00001`3oool3000000H0oooo000n0?ooo`040000003oool000000?ooo`8000002P3oool010000000
oooo0?ooo`0000070?ooo`@000001P3oool010000000oooo0?ooo`3oool2000000T0oooo00<00000
0?ooo`3oool03P3oool3000001l0oooo3000000K0?ooo`800000203oool4000000030?ooo`000000
000000@000001P3oool3000000H0oooo000n0?ooo`050000003oool000000?ooo`0000002`3oool0
10000000oooo0?ooo`0000020?ooo`D000002P3oool00`000000oooo0?ooo`02000000/0oooo00<0
00000?ooo`3oool03@3oool2000000040?ooo`0000000000000001d0oooo00<000000?ooo`3oool0
203oool<000000l0oooo100000030?ooo`<000001P3oool4000000030?ooo`000000oooo00@0oooo
0`0000060?ooo`00?P3oool00`000000oooo00000002000000/0oooo00<000000?ooo`0000000`00
000?0?ooo`<0000000<0oooo0000003oool02P3oool00`000000oooo0?ooo`0=0?ooo`800000103o
ool3000001X0oooo00<000000?ooo`3oool0503oool;000000050?ooo`00000000000000003oool0
1P0000090?ooo`030000003oool000000080000000<0oooo0000003oool00`3oool3000000H0oooo
000m0?ooo`030000003oool0oooo0080000000<0oooo0000003oool01P3oool500000080oooo00<0
00000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool0
3@3oool2000000L0oooo0`00000G0?ooo`030000003oool0oooo01`0oooo2`0000020?ooo`@00000
1`3oool5000000030?ooo`000000oooo0080oooo0`0000060?ooo`00?@3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool4000000<0oooo00D000000?ooo`3oool0oooo0000000>0?oo
o`<000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`0000002P3oool3000001@0oooo00<000000?ooo`3oool06@3oool3000000<0oooo0`0000020?oo
o`80000000<0oooo0000000000001`0000040?ooo`H0000000@0oooo0000003oool0oooo0`000006
0?ooo`00?@3oool200000080oooo00<000000?ooo`0000000`0000070?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02@3oool2000000030?ooo`000000oooo00@0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000d0oooo0`00000A
0?ooo`030000003oool0oooo01D0oooo100000020?ooo`@000001@3oool2000000D0oooo1`000002
0?ooo`@0000000<0oooo0000000000000P000000103oool000000000000000060?ooo`00?03oool7
000000030?ooo`000000oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`07
0?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02P3oool010000000oooo0?ooo`00000@0?ooo`<000003P3oool00`000000oooo0?oo
o`0A0?ooo`@000000P3oool4000000T0oooo00<000000?ooo`3oool0203oool:00000080oooo1@00
00000`3oool000000?ooo`040?ooo`00?03oool2000000<0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool01@000000oooo0?ooo`3oool0000001<0oooo0`00000;0?ooo`030000003oool0oooo00h0oooo
0`0000030?ooo`<00000303oool2000000`0oooo2@0000020?ooo`@0000000<0oooo0000003oool0
103oool003`0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000090?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0
00005`3oool3000000P0oooo00<000000?ooo`3oool02P3oool400000080oooo1000000?0?ooo`80
00003P3oool4000000030?ooo`00000000000080000000H0oooo00000000000000000?ooo`000005
0?ooo`00?03oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000203oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`8000001`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?oo
o`3oool0000001X0oooo0`0000060?ooo`030000003oool0oooo00H0oooo0`0000030?ooo`<00000
4`3oool200000100oooo100000000`3oool0000000000006000000D0oooo000l0?ooo`8000000`3o
ool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool3000000<0
oooo00<000000?ooo`3oool00P3oool400000080oooo1000000F0?ooo`8000004P3oool00`000000
oooo00000002000000030?ooo`000000000000H000000P3oool003`0oooo0P0000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`800000
2P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo10000000103oool00000
0000000000020?ooo`@000006P3oool200000180oooo1P0000000`3oool000000000000300000080
oooo0P00000003`0oooo0P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`020?ooo`<000002`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0200oooo0`0000020?ooo`<000007P3oool200000180oooo00<000000?ooo`000000
1P0000000`3oool000000?ooo`0200000080oooo000l0?ooo`8000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0000000<00000803oool00`000000oooo0000000C0?ooo`030000003oool0000000<00000
00<0oooo0000000000001@0000010?ooo`00?03oool2000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`040000003oool00000000000<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo100000040?ooo`<00000
7@3oool00`000000oooo0000000C0?ooo`040000003oool000000?ooo`@000000P3oool500000000
?03oool300000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`800000
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool06P3oool400000080
oooo00<000000?ooo`3oool01@3oool2000001/0oooo0P00000D0?ooo`<000000P3oool600000003
0?ooo`000000000000400000000l0?ooo`<000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo0`0000070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000
oooo0?ooo`0F0?ooo`@0000000<0oooo0000000000000P3oool00`000000oooo0?ooo`080?ooo`80
00006@3oool2000001@0oooo0`0000020?ooo`<000000P3oool200000040oooo0@00000100000000
?03oool3000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00X0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0C0?oo
o`<00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo0P00000G0?oo
o`800000503oool2000000030?ooo`000000oooo00<000000P3oool010000000oooo000000000001
0?ooo`00?03oool3000000<0oooo00<000000?ooo`3oool00`3oool3000000<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02`3oool00`000000oooo000000080?ooo`030000003oool0oooo00l0oooo100000060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool3000001@0oooo0P00000E0?oo
o`<0000000<0oooo0000003oool00P0000000`3oool000000?ooo`020?ooo`400000000l0?ooo`80
000000D0oooo0000003oool0oooo000000040?ooo`8000001@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?oo
o`8000002@3oool00`000000oooo0?ooo`0;0?ooo`@000002@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0100oooo0P00000A0?ooo`030000003oool0000001D0oooo0`0000000`3o
ool000000?ooo`02000000030?ooo`000000oooo0080oooo0@00000003`0oooo0P0000001@3oool0
00000?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`8000003`3oool00`000000oooo0000000E
0?ooo`030000003oool000000080000000<0oooo0000000000000P0000030?ooo`400000000l0?oo
o`040000003oool0000000000080oooo00@000000?ooo`00000000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`040?ooo`@000003@3oool2000000H0oooo00<000000?ooo`3oool05@3oool2000000d0oooo00<0
00000?ooo`0000005@3oool00`000000oooo00000002000000030?ooo`000000oooo00<000000@3o
ool100000040oooo000l0?ooo`040000003oool0000000000080oooo0P0000060?ooo`050000003o
ool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo000000080?ooo`030000003oool0oooo0080oooo
0`00000@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0603oool3000000X0oooo
00<000000?ooo`0000005P3oool4000000030?ooo`000000oooo00<000000@3oool100000040oooo
000l0?ooo`040000003oool000000?ooo`<000001`3oool01@000000oooo0?ooo`3oool0000000T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`000000203oool500000180oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0K0?ooo`800000203oool00`000000oooo0000000F0?ooo`060000003oool000000000
003oool000000P3oool500000000?03oool00`000000oooo00000002000000030?ooo`000000oooo
00H0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000D0oooo1000
000E0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool2000000H0oooo0P00
000G0?ooo`P0000000<0oooo0000000000000P3oool003`0oooo8@0000000`3oool000000?ooo`0<
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000002
000000<0oooo00<000000?ooo`3oool04@3oool2000000T0oooo00<000000?ooo`3oool0803oool2
000000@0oooo0P00000A0?ooo`L000000P3oool00`000000oooo000000030?ooo`8000000P3oool0
03`0oooo00L000000?ooo`000000oooo0000003oool0000000P0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`3ooolQ000000@0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0280oooo100000000`3oool000000?ooo`090?ooo`L0
00001P3oool00`000000oooo0?ooo`0300000080oooo100000010?ooo`00?03oool01`000000oooo
0000003oool000000?ooo`000000203oool010000000oooo0?ooo`00000;0?ooo`050000003oool0
oooo0?ooo`0000003@3oool00`000000oooo0?ooo`050?ooo`030000003oool000000080000000<0
oooo0000003oool00P3oool500000140oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0V0?ooo`<000000`3oool7000000h0oooo00<000000?ooo`0000000P0000020?ooo`D00000000l
0?ooo`030000003oool000000080oooo0P0000090?ooo`030000003oool0000000/0oooo00@00000
0?ooo`3oool000003P3oool00`000000oooo0?ooo`040?ooo`<00000103oool00`000000oooo0?oo
o`050?ooo`L000002P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02H0oooo1P00
000E0?ooo`030000003oool000000080000000@0oooo00000000000000000P3oool100000000?03o
ool300000080oooo0P0000090?ooo`030000003oool0000000/0oooo00@000000?ooo`3oool00000
3P3oool010000000oooo0?ooo`3oool4000000H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`D00000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02H0
oooo0P0000030?ooo`8000005@3oool00`000000oooo0000000600000080oooo0@00000003`0oooo
100000000`3oool00000000000090?ooo`030000003oool0000000`0oooo00<000000?ooo`000000
3`3oool300000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00T0oooo1P00000;0?ooo`030000003oool0oooo02<0oooo1@0000050?ooo`800000
4`3oool3000000030?ooo`00000000000080000000<0oooo0000000000000@3oool003`0oooo0P00
00000`3oool000000?ooo`02000000X0oooo0P00000<0?ooo`030000003oool0000000d0oooo0`00
00040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0080oooo1@0000050?ooo`030000003oool0oooo0280oooo0P00
00020?ooo`030000003oool0000000L0oooo0P00000>0?ooo`<0000000@0oooo000000000000oooo
100000000`3oool00000000000010?ooo`00?03oool2000000040?ooo`000000oooo0?ooo`800000
2@3oool2000000`0oooo00<000000?ooo`0000002P3oool300000080oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`080?ooo`H000008P3oool2000000<0oooo00<000000?ooo`0000002P3oool2000000T0
oooo0`0000040?ooo`030000003oool0oooo0080000000<0oooo0000000000000`00000003`0oooo
0P000000103oool000000?ooo`3oool2000000T0oooo0P00000=0?ooo`030000003oool0oooo00L0
oooo0P0000050?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo000000040000
01X0oooo0`0000040?ooo`040000003oool0oooo000000`0oooo0P0000040?ooo`<000001`3oool0
0`000000oooo0?ooo`0300000080oooo0P0000010?ooo`00?03oool2000000040?ooo`000000oooo
0?ooo`8000002@3ooolC000000<0oooo0`0000070?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`800000403oool00`000000oooo0?oo
o`040?ooo`H000004P3oool2000000H0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`@00000
2P3oool00`000000oooo0?ooo`0300000080oooo0P0000010?ooo`00?03oool2000000040?ooo`00
0000oooo0?ooo`8000001P3oool5000000d0oooo00@000000?ooo`3oool0oooo1P0000080?ooo`80
00002`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0;0?ooo`D000002`3oool2000000L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0:0?ooo`<0000000<0oooo0000000000002P3oool00`000000
oooo00000003000000040?ooo`00000000000?ooo`400000000l0?ooo`80000000@0oooo0000003o
ool0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`0:0?ooo`@000001P3oool60000
0080oooo0P00000;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo1P0000030?ooo`8000001`3oool20000
00D0oooo00<000000?ooo`3oool01`3oool3000000H0oooo0P0000080?ooo`T000000P3oool003`0
oooo0P0000020?ooo`030000003oool0oooo00@00000203oool00`000000oooo0?ooo`090?ooo`80
00003`3oool5000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool05`3oool5000000H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`<000002`3oool00`000000oooo0?ooo`050?ooo`<0
000000@0oooo000000000000oooo0P0000020?ooo`00?03oool200000080oooo00@000000?ooo`3o
ool00000303oool00`000000oooo0?ooo`050?ooo`<000000P3oool00`000000oooo0?ooo`0=0?oo
o`8000000P3oool3000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool2000000D0oooo1P0000070?oo
o`030000003oool0oooo0080oooo0`00000?0?ooo`8000001@3oool3000000040?ooo`0000000000
0?ooo`8000000P3oool003`0oooo0P0000020?ooo`040000003oool00000000000`0oooo00<00000
0?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`03
0?ooo`<00000103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`8000004`3o
ool00`000000oooo0?ooo`0D0?ooo`8000002`3oool00`000000oooo0000000400000080oooo00<0
00000?ooo`0000000P00000D0?ooo`8000000`3oool5000000040?ooo`000000oooo00000080oooo
000l0?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool02P3oool010000000oooo0000
000000080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool3000000030?oo
o`000000oooo00@0oooo00@000000?ooo`3oool000005@3oool00`000000oooo0?ooo`0A0?ooo`<0
0000303oool00`000000oooo0?ooo`050?ooo`L000005P3oool20000000:0?ooo`00000000000000
003oool000000?ooo`000000oooo00000080oooo000k0?ooo`8000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00P0oooo0`00000:0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool02P3oool3000000@0oooo00<000000?ooo`0000005@3oool00`000000oooo0?oo
o`0@0?ooo`8000003P3oool00`000000oooo0?ooo`020?ooo`@000000P3oool00`000000oooo0?oo
o`020?ooo`P00000403oool4000000040?ooo`000000000000000080oooo0@0000010?ooo`00>`3o
ool200000080oooo0P0000050?ooo`030000003oool0oooo00@0oooo0`0000020?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool000000080000000<0oooo0000000000005P3oool00`000000oooo0?ooo`0>0?ooo`8000003`3o
ool00`000000oooo00000003000000D0oooo00<000000?ooo`3oool02`3oool8000000P0oooo1000
00000`3oool00000000000030?ooo`4000000@3oool003/0oooo0P000000103oool000000?ooo`00
00050?ooo`040000003oool0oooo0?ooo`<000001@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`3oool3000001H0
oooo00<000000?ooo`3oool02`3oool3000000l0oooo100000090?ooo`030000003oool0oooo01<0
oooo1`0000000`3oool0000000000005000000<0oooo0P00000003/0oooo0`0000030?ooo`030000
003oool0oooo00<0oooo0`0000080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00@000000?ooo`000000
00004`3oool00`000000oooo0?ooo`0:0?ooo`8000003@3oool6000000`0oooo00<000000?ooo`3o
ool06P3oool900000080oooo0P00000003/0oooo0`0000030?ooo`040000003oool0oooo0?ooo`@0
00002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0303oool01@000000oooo0?ooo`3oool0000000@0oooo0P00000A0?ooo`030000003oool0oooo
00P0oooo0P00000;0?ooo`@000000`3oool2000000`0oooo00<000000?ooo`3oool06P3oool50000
00030?ooo`000000000000H00000000k0?ooo`80000000@0oooo0000003oool0oooo100000040?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00@000000?ooo`3oool000001`3oool2000000h0oooo00<00000
0?ooo`3oool01`3oool2000000T0oooo100000060?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool06@3oool2000000050?ooo`00000000000000003oool02000000003X0oooo00<00000
0?ooo`0000000P3oool00`000000oooo00000003000000@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool0
10000000oooo0?ooo`0000090?ooo`<000002`3oool00`000000oooo0?ooo`040?ooo`<000001`3o
ool4000000T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0I0?ooo`050000003o
ool000000000003oool02@0000020?ooo`00>P3oool2000000@0oooo0P0000030?ooo`H000002@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0000000=0?ooo`800000203oool00`000000oooo0?ooo`030?ooo`8000001P3o
ool4000000`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0H0?ooo`040000003o
ool000000?ooo`X000000`3oool003X0oooo0P0000030?ooo`<00000203oool6000000D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo0P00
000@0?ooo`8000001P3oool010000000oooo0?ooo`3oool2000000@0oooo1000000?0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool05`3oool6000000030?ooo`000000000000<00000
00<0oooo0000003oool00`3oool003X0oooo0P0000020?ooo`050000003oool000000?ooo`000000
2@3oool010000000oooo0?ooo`3oool6000000T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0=0?ooo`8000004P3oool2000000<0oooo00<000000?ooo`0000000P0000020?ooo`@0
00004P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01<0oooo1@0000020?ooo`03
0000003oool0000000T00000103oool003X0oooo00H000000?ooo`3oool000000?ooo`0000020?oo
o`800000203oool00`000000oooo0?ooo`060?ooo`H00000103oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool04`3oool2000000040?ooo`0000000000
0?ooo`@000005@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo10000003
0?ooo`040000003oool0oooo0?ooo`P0000000@0oooo0000003oool00000103oool003X0oooo00<0
00000?ooo`0000000P3oool01P000000oooo0?ooo`000000oooo000000P0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`D00000303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo01@0oooo1@00000H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool02P3oool5000000H0oooo00@000000?ooo`3oool0oooo100000000`3oool00000000000040000
00030?ooo`000000oooo00<0oooo000i0?ooo`<000000`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`D000001P3oool00`000000oooo0?ooo`0=0?ooo`8000004P3oool500000080oooo0P00000F0?oo
o`8000004P3oool00`000000oooo0?ooo`070?ooo`@000002P3oool00`000000oooo0?ooo`050000
0080oooo1P0000020?ooo`030000003oool0oooo0040oooo000i0?ooo`8000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool7000000h0oooo00@000000?oo
o`3oool000003@3oool400000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool5000000d0oooo00<00000
0?ooo`0000000`0000020?ooo`030000003oool0000000@000000P3oool00`000000oooo00000003
0?ooo`00>03oool3000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00P0oooo1@00000:0?ooo`040000003oool0oooo000000T0oooo100000040?ooo`800000203o
ool200000140oooo00<000000?ooo`3oool04P3oool00`000000oooo0000000300000140oooo1@00
0000103oool000000?ooo`0000020?ooo`@000000`3oool00`000000oooo000000030?ooo`00>@3o
ool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo1P0000030?ooo`050000003oool0oooo0?ooo`00
00001@3oool4000000L0oooo00<000000?ooo`3oool02P3oool2000000h0oooo00<000000?ooo`3o
ool0403oool5000001@0oooo100000020?ooo`070000003oool0oooo0000003oool000000?ooo`03
000000<0oooo00<000000?ooo`0000000`3oool003T0oooo00<000000?ooo`3oool00P0000050?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`D000000P3oool00`000000oooo00000003000000T0oooo0P00000?0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool03@3oool4000000<0oooo00<000000?ooo`3oool04@3oool40000
00@0oooo00L000000?ooo`3oool000000?ooo`000000oooo00800000103oool00`000000oooo0000
00030?ooo`00>@3oool01P000000oooo0?ooo`000000oooo000000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1@00000;0?ooo`030000003oool0oooo0100oooo0P0000090?ooo`030000003oool0oooo00T0oooo
1@0000060?ooo`030000003oool0oooo0140oooo0`0000050?ooo`070000003oool0oooo0000003o
ool000000?ooo`03000000D0oooo0P0000030?ooo`00>@3oool010000000oooo0?ooo`0000020?oo
o`8000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02P3oool4000000030?ooo`00000000000080oooo1@0000050?ooo`030000003oool0oooo
01<0oooo0P0000060?ooo`030000003oool0oooo00D0oooo1@00000;0?ooo`030000003oool0oooo
00l0oooo0`0000070?ooo`030000003oool0oooo0080000000<0oooo0000000000000P0000050?oo
o`8000000`3oool003T0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000070?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool5000000H0oooo00<000000?oo
o`3oool01@3oool5000001P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`@000003`3oool00`000000oooo0?ooo`0>0?ooo`@000001`3oool01`000000oooo0?ooo`000000
oooo0000003oool00`0000060?ooo`030000003oool000000080oooo000i0?ooo`030000003oool0
000000H0oooo0`0000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0oooo1000
00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`05000001@0oooo0P0000000`3oool0000000000004000001<0oooo00<000000?ooo`3oool0303o
ool200000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02000000030?ooo`00
0000oooo008000001P3oool00`000000oooo000000020?ooo`00>03oool00`000000oooo00000009
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool4000000L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`800000203oool400000140oooo0`00000H
0?ooo`030000003oool0oooo00X0oooo0P0000030?ooo`030000003oool0oooo00H0oooo00@00000
0?ooo`3oool0oooo0`0000000`3oool0000000000002000000D0oooo00<000000?ooo`0000000P3o
ool003P0oooo00<000000?ooo`0000002@3oool3000000P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo1@00
00090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0<0?ooo`D000002@3oool3000000040?ooo`000000oooo000001H0oooo00<000000?ooo`3oool0
2@3oool2000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`04000000050?oo
o`00000000000?ooo`0000001P3oool200000080oooo000h0?ooo`030000003oool0000000T0oooo
00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool5000000@0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04P3oool500000004
0?ooo`0000000000000000L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`070?oo
o`8000001@3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0?ooo`<0000000@0oooo
0000003oool000000P3oool00`000000oooo0?ooo`030?ooo`8000000P3oool003P0oooo0P00000;
0?ooo`030000003oool0oooo008000001`3oool2000000@0oooo00<000000?ooo`3oool00P3oool5
000000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo0?ooo`800000603oool7000000L0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`050?ooo`8000001P3oool00`000000oooo0?ooo`080?ooo`040000003o
ool0oooo0?ooo`80000000D0oooo000000000000oooo000000020?ooo`030000003oool0oooo00<0
oooo0P0000020?ooo`00>03oool2000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`060000003oool0oooo0?ooo`000000oooo1@0000040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo
000001P0oooo0P0000070?ooo`D000000`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00@0oooo0P0000070?ooo`030000003oool0oooo00P0oooo1P0000001P3oool000000?ooo`00
0000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000010?ooo`00>03o
ool3000000X0oooo00<000000?ooo`3oool00`3oool2000000L0oooo1@0000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00P0oooo0`00000F0?ooo`<000003P3oool500000140oooo00<000000?ooo`3oool00P3o
ool2000000P0oooo00<000000?ooo`3oool00`3oool7000000080?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo00000001
0?ooo`00>03oool00`000000oooo00000003000000L0oooo00<000000?ooo`3oool01@3oool01000
0000oooo0?ooo`3oool5000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo01<0oooo0`00000E0?ooo`D00000303oool010000000oooo0?ooo`3o
ool2000000T0oooo1`0000060?ooo`8000000P3oool200000080oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`020?ooo`8000000@3oool003P0oooo00<000000?ooo`3oool00P3oool5
000000<0oooo00<000000?ooo`3oool0103oool5000000D0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00P0oooo0P00000B0?ooo`<000006P3oool00`000000oooo0?oo
o`05000000L0oooo00@000000?ooo`00000000001@3oool6000000`0oooo0P0000020?ooo`800000
0P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000D00000000i0?ooo`030000
003oool0oooo00<0oooo1P0000000`3oool000000?ooo`04000000@0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000001@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo0P0000000`3oool000000?ooo`0?0?oo
o`8000007P3oool00`000000oooo0?ooo`040?ooo`D000000P3oool9000000@0oooo00<000000?oo
o`3oool02P3oool200000080oooo0P0000030?ooo`/000000`3oool200000040oooo000i0?ooo`03
0000003oool0oooo00H0oooo1`0000080?ooo`8000001@3oool010000000oooo0?ooo`0000030?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00L0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`<000008@3oool00`000000oooo0?oo
o`070?ooo`D000002P3oool00`000000oooo0?ooo`0:0?ooo`/000000P3oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo0?ooo`8000000@3oool003T0oooo00<000000?ooo`3oool0203o
ool300000080oooo0`0000070?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool2000000@0oooo00<000000?ooo`3oool0203oool3000002D0oooo00<000000?ooo`3o
ool00P3oool7000000/0oooo00<000000?ooo`3oool00P3oool;000000030?ooo`000000oooo0080
00000P3oool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0?ooo`0000000@3oool0
03T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0400000080oooo0`0000050?oo
o`800000103oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`<00000:@3oool4000000030?ooo`00000000000080oooo00<0
00000?ooo`3oool01@3oool:000000H0oooo00@000000?ooo`3oool000000P3oool2000000050?oo
o`000000oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo0?oo
o`800000000j0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`02000000<0oooo0`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo0P00000Y0?oo
o`D0000000<0oooo0000000000000P3oool:000000<0oooo00<000000?ooo`3oool02@3oool01P00
0000oooo0?ooo`3oool000000?ooo`80000000<0oooo0000003oool00P3oool010000000oooo0?oo
o`0000090?ooo`030000003oool0oooo00800000000j0?ooo`030000003oool0oooo00<0oooo0P00
00050?ooo`030000003oool0oooo0080oooo0`0000030?ooo`<000000P3oool2000000<0oooo00<0
00000?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool2000000L0oooo00@000000?ooo`3oool0oooo0`00000W0?ooo`@0
000000<0oooo0000000000001`0000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool02@3oool01P000000oooo0?ooo`3oool000000?ooo`8000000P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000000P00000003X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo0P000004
0?ooo`<0000000<0oooo0000003oool00P3oool00`000000oooo000000020?ooo`030000003oool0
000000<0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00L0oooo1000
000W0?ooo`P00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0203oool2000000@0oooo0`0000030?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool01@3oool400000040oooo0@0000010?ooo`00>P3oool01@000000oooo0?oo
o`3oool0000000P0oooo00<000000?ooo`3oool01`3oool3000000@0oooo100000020?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000103oool2
000000T0oooo0P00000S0?ooo`L000003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`@000000`3oool0
0`000000oooo0?ooo`0100000000>P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00X0oooo0P0000060?ooo`D0000000L0oooo0000003oool0oooo0000003oool0000000<0oooo
00D000000?ooo`3oool0oooo000000080?ooo`<0000000<0oooo0000003oool06P3oool;00000180
oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0103oool2000000D0oooo00<000000?ooo`0000000`3oool5000000P0oooo0@0000010?oo
o`400000000k0?ooo`8000002`3oool00`000000oooo0?ooo`0;0?ooo`<00000103oool500000006
0?ooo`000000oooo0000003oool000000P3oool01@000000oooo0?ooo`3oool0000000H0oooo0`00
00040?ooo`030000003oool0oooo0140oooo200000030?ooo`@000005P3oool010000000oooo0?oo
o`0000070?ooo`030000003oool0oooo00L0oooo0P0000060?ooo`8000001@3oool00`000000oooo
0?ooo`05000000`0oooo0@0000010?ooo`40oooo000j0?ooo`H00000203oool00`000000oooo0?oo
o`0>0?ooo`<000000`3oool00`000000oooo00000004000000060?ooo`000000oooo0?ooo`000000
oooo0P0000040?ooo`<000001`3oool00`000000oooo0?ooo`0:0?ooo`L00000203oool3000001/0
oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool4000000<0oooo00<000000?ooo`3oool02`3oool100000040
oooo000k0?ooo`030000003oool000000080oooo2@00000C0?ooo`8000000P3oool8000000040?oo
o`000000oooo000000@0oooo0P00000:0?ooo`030000003oool0oooo0080oooo2000000;0?ooo`@0
00007`3oool2000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`<0
00000`3oool5000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0303oool100000040
oooo000l0?ooo`030000003oool0000000T0oooo2P00000<0?ooo`<0000000<0oooo000000000000
0P0000000`3oool0000000000003000000040?ooo`0000000000000000T0oooo2000000?0?ooo`@0
00008`3oool2000000@0oooo00<000000?ooo`3oool01P3oool2000000<0oooo100000020?ooo`@0
0000103oool00`000000oooo000000030?ooo`030000003oool0oooo00d0oooo0@00000003`0oooo
00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`070?ooo`P000001`3oool600000003
0?ooo`000000oooo00D000000`3oool7000000<0oooo00<000000?ooo`3oool03P3oool3000002L0
oooo0P0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`0000030?ooo`@0
00001`3oool2000000@0oooo00<000000?ooo`3oool03P3oool003`0oooo00D000000?ooo`3oool0
oooo000000080?ooo`030000003oool0oooo00h0oooo6000000:0?ooo`030000003oool0oooo00X0
oooo1000000Z0?ooo`050000003oool000000?ooo`000000203oool400000080oooo100000020?oo
o`8000001P3oool00`000000oooo000000040?ooo`030000003oool0oooo00h0oooo000m0?ooo`05
0000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0G0?oooa8000001`3oool00`00
0000oooo0?ooo`060?ooo`@00000;@3oool01@000000oooo0?ooo`3oool0000000D0oooo10000002
0?ooo`@000001@3oool00`000000oooo000000060?ooo`8000001@3oool00`000000oooo0?ooo`0;
0?ooo`<00000000m0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0C0?ooo`H0000000<0oooo0000003oool01`0000060?oooad00000903oool00`00
0000oooo0?ooo`0200000080oooo0`0000000`3oool0000000000003000000T0oooo00<000000?oo
o`0000001P3oool2000000@0oooo00<000000?ooo`3oool0203oool4000000<0oooo000n0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`D0
00000`3oool2000000050?ooo`00000000000000003oool01@0000000`3oool00000000000030000
00@0oooo0`0000000`3oool000000?ooo`0400000100oooo7@0000070?ooo`L0000000<0oooo0000
000000000P00000=0?ooo`030000003oool0000000H0oooo0P0000040?ooo`030000003oool0oooo
00@0oooo100000060?ooo`400000000n0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`090?ooo`D000001`3oool00`000000oooo0?ooo`0500000005
0?ooo`000000oooo0000003oool00`0000030?ooo``00000;`3ooolK000000@0oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01000000:
0?ooo`400000000n0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`@000002P3oool2000000<0oooo0P0000001@3oool00000000000000000
oooo00@000000P3oool>000000030?ooo`000000000000<00000<03oool00`000000oooo00000004
0?ooo`800000303ooolI000000/0oooo0@0000010?ooo`00?`3oool00`000000oooo0?ooo`040?oo
o`060000003oool0oooo0?ooo`000000oooo1@00000=0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`000000oooo0P0000000`3oool000000000000600000080oooo0`0000050?ooo`030000
003oool0oooo00D0000000<0oooo0000000000001000000Z0?ooo`<00000103oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool7000000D0oooo
3@00000003l0oooo00<000000?ooo`3oool01@3oool500000100oooo0P0000040?ooo`030000003o
ool0000000L000000P3oool00`000000oooo0?ooo`02000000@0oooo0P0000030?ooo`030000003o
ool0oooo00D0oooo1@0000020?ooo`D00000903oool2000000030?ooo`000000oooo0080oooo00<0
00000?ooo`0000003`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@00000103o
ool00`000000oooo0?ooo`0=0?ooo`4000000@3oool10?ooo`00?`3oool00`000000oooo0?ooo`05
000000040?ooo`000000oooo00000100oooo00<000000?ooo`0000001P000000203oool000000?oo
o`000000oooo0000003oool000000`3oool010000000oooo0?ooo`3oool2000000@0oooo1000000<
0?ooo`D000000P3oool5000001l0oooo0P0000000`3oool000000?ooo`0200000080oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`05000000040?ooo`000000oooo000000D0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`010?ooo`00?`3oool5000000D0oooo0P00000;
0?ooo`L00000103oool010000000oooo0?ooo`0000020?ooo`030000003oool000000080oooo00@0
00000?ooo`3oool0oooo0P0000030?ooo`8000001@3oool3000000l0oooo1P0000000`3oool00000
00000004000001T0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00X0
oooo1@0000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00100?ooo`040000003oool0oooo0?ooo`D0
000000<0oooo0000000000000`3oool700000080oooo00<000000?ooo`3oool01@3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
00000180oooo1@0000020?ooo`D000004`3oool2000000030?ooo`000000000000D0oooo00<00000
0?ooo`3oool0103oool6000000030?ooo`000000oooo00D0oooo0P0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`00@@3oool00`00
0000oooo0?ooo`050?ooo`H000001`3oool2000000P0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`<00000503oool500000080oooo1P00
000=0?ooo`040000003oool00000000000H0oooo00<000000?ooo`000000100000070?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00440oooo0P0000080?ooo`030000003o
ool00000008000001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`030?ooo`<00000203oool3000001H0oooo1@0000030?ooo`D000001`3oool300000003
0?ooo`000000oooo0080oooo1@00000<0?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`40
000000120?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool200000080oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000050?ooo`80
00002P3oool2000001T0oooo1@0000030?ooo`D000000P3oool2000000030?ooo`000000000000<0
0000103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo0P0000000`3oool0
00000?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool700000000
@P3oool2000000P0oooo00<000000?ooo`3oool00`3oool3000000T0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`00000000002P3oool30000
01/0oooo1P0000020?ooo`D0000000<0oooo0000003oool01P3oool00`000000oooo0?ooo`090?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool9000000D0oooo0@00000004<0oooo0P0000070?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000060?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo0P00000;0?ooo`<00000
7@3oool6000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`050000
003oool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`3oool:000000L0oooo00<000000?oo
o`3oool0103oool100000000A03oool2000000H0oooo00<000000?ooo`3oool00P0000060?ooo`80
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`0;0?ooo`<000005`3oool3000000<0oooo00<000000?oo
o`0000001@0000060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0300000030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool100000040oooo00140?ooo`80
00001`3oool2000000X0oooo100000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo0`0000060?ooo`80
00003P3oool300000140oooo0`0000050?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`000000100000020?ooo`030000003oool0oooo0080oooo2@0000060?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`4000000@3oool0
04D0oooo0P0000050?ooo`8000003@3oool3000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`060?ooo`8000003`3oool3000000/0oooo0`0000080?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool01@3oool7000000@0oooo0`0000080?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`4000000@3o
ool004D0oooo00<000000?ooo`0000000`3oool00`000000oooo0000000=0?ooo`030000003oool0
oooo00<0000000<0oooo0000003oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool2000000T0oooo0P00000@0?ooo`8000001P3oool3
000000X0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo0?ooo`L000002@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01P3oool100000040oooo00160?ooo`80000000<0oooo000000000000
0P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo0P0000060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0000000X0oooo0P00000@0?ooo`H000003@3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0700000080
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo0@0000010?ooo`00AP3oool00`000000oooo000000050?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01P3oool4000000<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P00000:0?ooo`80
00003@3oool3000000040?ooo`0000000000000000`0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`08
0?ooo`L000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0@000001
0?ooo`00A`3oool00`000000oooo000000040?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01P3oool010000000oooo0?ooo`3oool2000000030?ooo`000000oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`<000001`3oool3000000P0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0103o
ool2000000`0oooo00D000000?ooo`3oool000000?ooo`07000000@0oooo00<000000?ooo`3oool0
203oool100000040oooo00170?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo0`0000050?ooo`030000
003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00T0
oooo0P0000040?ooo`<000003@3oool3000000D0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000<0?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool7000000L0oooo0@000001
0?ooo`40oooo00180?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00@000000?ooo`00000000000`3oool0
0`000000oooo0?ooo`060?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool02P3o
ool4000001<0oooo0`0000000`3oool000000?ooo`040?ooo`050000003oool0oooo0?ooo`000000
1`3oool00`000000oooo0?ooo`020?ooo`80000000<0oooo0000003oool0303oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0oooo200000020?oo
o`00B@3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`<0000000<0oooo0000
003oool01P3oool010000000oooo0?ooo`0000070?ooo`8000001`3oool4000000030?ooo`000000
000001H0oooo0P0000050?ooo`050000003oool0oooo0?ooo`0000001`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool300000000B@3oool2000000050?oo
o`000000oooo0?ooo`0000001P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool2000000P0oooo00<000000?ooo`0000002@3oool010000000
oooo0?ooo`3oool3000000L0oooo0P00000D0?ooo`030000003oool00000008000000P3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0<0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0:0?ooo`4000000@3oool10?ooo`00BP3oool300000080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool2000000L0oooo0P00000:0?ooo`<00000303oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00<0oooo0`0000020?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool10?ooo`00BP3oool010000000oooo0000
000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000P0000050?ooo`030000
003oool0oooo00D0oooo0`0000000`3oool000000?ooo`0=0?ooo`800000403oool00`000000oooo
0?ooo`040?ooo`030000003oool00000008000001`3oool00`000000oooo000000040?ooo`030000
003oool0oooo00h0oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0oooo00/0
oooo0@0000010?ooo`40oooo001;0?ooo`060000003oool000000000003oool000000`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool01000
0000oooo0?ooo`3oool2000000<0oooo0P0000030?ooo`<000001@3oool2000000h0oooo0P00000=
0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo100000040?ooo`8000001@3o
ool00`000000oooo0?ooo`0>0?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0040oooo001<0?ooo`030000003oool00000008000000P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`030?ooo`@0000000@0oooo00000000000000002P3oool00`000000oooo
0?ooo`0=0?ooo`8000002`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`00
00000`3oool5000000D0oooo00<000000?ooo`3oool03`3oool01@000000oooo0000003oool00000
00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`00C03oool00`000000
oooo0?ooo`0200000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00@0oooo3`00000<0?ooo`030000003oool0oooo00h0oooo0P0000080?ooo`03
0000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000050?oooad0000000<0oooo0000
003oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0040oooo001=0?ooo`03
0000003oool0oooo00<000002@3ooolE000000<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`06000000P0oooo00<000000?ooo`3oool03`3oool2000000D0oooo00<000000?ooo`3o
ool01`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`0000000P3oool30000
00030?ooo`000000oooo0100oooo00<000000?ooo`0000006@00000004h0oooo00<000000?ooo`3o
ool02`0000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000103oool5000000@0oooo0P00000A0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`0000001P3oool4000000l0oooo00@000000?ooo`0000000000103o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0040oooo001>0?ooo`050000003oool0
00000000003oool00P00000:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool5000000030?ooo`000000oooo0100oooo0P0000000`3oool000000?ooo`090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo000000070?ooo`040000003oool0oooo0?ooo`<0
0000303oool010000000oooo0000000000030?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool00@3oool004l0oooo00D000000?ooo`3oool000000?ooo`03000000P0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`D00000403oool2000000X0oooo00D000000?oo
o`3oool000000?ooo`02000000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool01@3oool4
000000P0oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00P3oool004l0oooo00<000000?ooo`3oool00P000000103oool000000?ooo`000007
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo00000004
000000/0oooo00@000000?ooo`0000000000203oool00`000000oooo0?ooo`0200000080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`<000001@3oool2000000050?ooo`00
0000oooo0?ooo`000000403oool00`000000oooo0?ooo`020?ooo`00D03oool010000000oooo0?oo
o`0000020?ooo`040000003oool00000000000@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0=0?ooo`800000103oool5000000D0oooo00<000000?ooo`3oool00P3oool2000000D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool03@3oool4000000040?ooo`000000000000000080oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`020?ooo`00D@3oool010000000oooo0000000000020?ooo`80000000<0oooo
0000000000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01P3oool6000000H0oooo0P0000030?ooo`030000003oool0oooo0080000000<0oooo
0000003oool0203oool00`000000oooo0?ooo`0A0?ooo`@000000P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0080oooo001A0?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00`00000<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool6
000000@0oooo00L000000?ooo`3oool000000?ooo`000000oooo008000002@3oool00`000000oooo
0?ooo`0D0?ooo`@000004P3oool500000000DP3oool010000000oooo0000000000040?ooo`040000
003oool0oooo0?ooo`800000303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00`3oool900000080oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0D0?ooo`<0000000<0oooo0000000000000P0000080?ooo`L00000103oool005<0oooo
00@000000?ooo`0000000000103oool01@000000oooo0?ooo`000000oooo008000002P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0>0?ooo`8000001`3oool00`000000oooo0?ooo`090?ooo`d00000103oool00`00
0000oooo0?ooo`0D0?ooo`<000001@3oool8000000H0oooo00<000000?ooo`3oool00P3oool005<0
oooo00@000000?ooo`00000000001@3oool2000000@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool3000000030?ooo`000000
000000@000001@3ooolC000000P0oooo0P0000000`3oool0000000000005000000030?ooo`000000
0000008000001P3oool00`000000oooo0?ooo`030?ooo`00E03oool010000000oooo000000000005
0?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3o
ool0000000X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo0`0000030?ooo`8000000`3oool800000080oooo00<000000?ooo`3oool03@3o
ool;000000`0oooo0`0000030?ooo`030000003oool0oooo00<0oooo001D0?ooo`050000003oool0
00000?ooo`000000103oool010000000oooo0000000000040?ooo`8000001@3oool00`000000oooo
0?ooo`0;0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0403oool010000000
oooo0?ooo`0000050?ooo`<00000103oool2000000050?ooo`000000oooo0?ooo`0000000P3oool3
000000<0oooo1`00000A0?ooo`050000003oool000000?ooo`0000003`3oool4000000D0oooo001E
0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`03000000<0oooo0P000003
0?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000003o
ool0oooo0100oooo0`0000020?ooo`<00000103oool3000000<0oooo00@000000?ooo`3oool00000
1@3oool200000080oooo00<000000?ooo`3oool00`3oool6000000X0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0?0?ooo`@000000P3oool005H0oooo0P0000000`3oool00000
0?ooo`030?ooo`800000103oool2000000<0oooo0P0000000`3oool000000?ooo`0=0?ooo`040000
003oool0oooo000000`0oooo00<000000?ooo`3oool0403oool4000000D0oooo0P0000060?ooo`04
0000003oool0oooo000000L0oooo0P00000<0?ooo`H000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo0P00000?0?ooo`040000003oool0oooo0?ooo`800000001F0?ooo`80000000<0oooo
0000003oool0103oool2000000D0oooo0P0000030?ooo`<000003@3oool010000000oooo0?ooo`00
000=0?ooo`030000003oool0oooo00h0oooo0P0000000`3oool000000?ooo`030?ooo`800000203o
ool010000000oooo0?ooo`0000080?ooo`<00000403oool6000000030?ooo`000000oooo00@0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00E`3oool2000000030?ooo`00
0000oooo00<0oooo0P0000070?ooo`<000000P3oool2000000`0oooo00@000000?ooo`3oool00000
3@3oool00`000000oooo0?ooo`0;0?ooo`@000000`3oool010000000oooo00000000000:0?ooo`04
0000003oool0oooo000000L0oooo00@000000?ooo`3oool0oooo0P00000>0?ooo`030000003oool0
oooo00<0oooo1P0000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool0
05P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000090?ooo`<0000000<0oooo
0000003oool02`3oool00`000000oooo0000000>0?ooo`030000003oool0oooo00L0oooo0`000002
0?ooo`040000003oool0oooo0?ooo`D000002P3oool010000000oooo0?ooo`0000070?ooo`030000
003oool0oooo00<0oooo0`00000:0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`L00000
203oool00`000000oooo0?ooo`030?ooo`400000001H0?ooo`80000000<0oooo0000003oool00`3o
ool00`000000oooo000000090?ooo`H000002P3oool00`000000oooo0000000?0?ooo`030000003o
ool0oooo00<0oooo0`0000050?ooo`@000000P3oool00`000000oooo00000003000000L0oooo00@0
00000?ooo`3oool000001`3oool00`000000oooo0?ooo`060?ooo`8000001P3oool2000000L0oooo
0P0000090?ooo`030000003oool0000000D000000P3oool00`000000oooo0?ooo`030?ooo`400000
001I0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000002@3oool010000000
oooo0?ooo`3oool6000000H0oooo0P00000@0?ooo`030000003oool00000008000000`3oool50000
00T0oooo0P000000103oool000000000000000040?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool02@3oool2000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000
00090?ooo`8000001@3oool600000040oooo0@0000010?ooo`00F@3oool200000080oooo00L00000
0?ooo`3oool0oooo0000003oool0000000X0oooo00<000000?ooo`3oool00`3oool2000000030?oo
o`000000000000<0000000<0oooo000000000000403oool200000080oooo100000030?ooo`030000
003oool0oooo00X0oooo00@000000?ooo`3oool0oooo0`000000103oool000000?ooo`0000070?oo
o`030000003oool0oooo00/0oooo0`00000:0?ooo`030000003oool0000000/0oooo00<000000?oo
o`3oool0103oool010000000oooo0?ooo`3oool300000000FP3oool010000000oooo0?ooo`000003
0?ooo`040000003oool0oooo000000T0oooo0P0000060?ooo`800000103ooolG000000L0oooo00<0
00000?ooo`3oool02`3oool2000000@0oooo100000060?ooo`030000003oool0oooo00d0oooo0`00
00090?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0200000080oooo001K0?ooo`H0000000D0oooo0000003oool0oooo000000090?ooo`8000001`3o
ool2000000@0oooo0`0000080?ooo`<00000103oool2000000030?ooo`000000000000@0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000800000103o
ool00`000000oooo0?ooo`0;0?ooo`8000000`3oool3000000H0oooo00<000000?ooo`0000003@3o
ool2000000<0oooo00D000000?ooo`000000oooo000000020?ooo`00F`3oool010000000oooo0000
000000020?ooo`T000001@3oool00`000000oooo000000080?ooo`030000003oool0oooo0080oooo
00<000000?ooo`000000103oool3000000T0oooo00<000000?ooo`3oool00P0000020?ooo`030000
003oool0oooo00l0oooo0P0000020?ooo`030000003oool000000080oooo1000000=0?ooo`030000
003oool0oooo00H0oooo0P0000040?ooo`030000003oool0000000l0oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo001L0?ooo`040000003oool0000000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`T00000203oool200000080oooo0P0000000`3oool0000000000002
000000d0oooo00@000000?ooo`3oool0oooo0P00000D0?ooo`050000003oool000000?ooo`000000
1@3oool3000000X0oooo00<000000?ooo`3oool02@3oool2000000050?ooo`000000oooo0?ooo`00
0000403oool3000000030?ooo`000000oooo00<0oooo001M0?ooo`040000003oool0oooo00000080
oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00T0000000<0oooo0000
00000000100000000`3oool000000?ooo`0>0?ooo`050000003oool0oooo0000003oool00P00000C
0?ooo`80000000<0oooo0000003oool00`3oool010000000oooo0?ooo`3oool3000000H0oooo00<0
00000?ooo`3oool0303oool200000080oooo00<000000?ooo`3oool03`3oool2000000030?ooo`00
0000oooo00<0oooo001N0?ooo`030000003oool0000000<00000103oool00`000000oooo0?ooo`06
0?ooo`040000003oool0oooo000000L0oooo1P0000030?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`0000000`3oool200000180oooo0`0000040?ooo`030000003oool0oooo00@0oooo0`00
00000`3oool000000000000@0?ooo`@000004@3oool00`000000oooo000000050?ooo`00G`3oool0
10000000oooo0000003oool2000000@0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?oo
o`3oool0000000T0oooo00<000000?ooo`3oool00`0000000`3oool000000000000>0?ooo`030000
003oool0oooo00@0oooo0P00000@0?ooo`040000003oool0000000000080oooo00<000000?ooo`3o
ool0203oool300000100oooo00<000000?ooo`3oool00`00000>0?ooo`80000000<0oooo0000003o
ool0103oool005l0oooo00D000000?ooo`3oool000000?ooo`02000000<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3o
ool000000P3oool4000000d0oooo0P0000070?ooo`8000003P3oool01`000000oooo0000003oool0
00000?ooo`0000002@3oool010000000oooo0?ooo`3oool3000000d0oooo00@000000?ooo`3oool0
00000P3oool2000000/0oooo00@000000?ooo`00000000001P3oool00600oooo00<000000?ooo`00
00000P3oool2000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00@000000?ooo`3oool00000103oool3000000X0oooo00@000000?oo
o`3oool00000203oool2000000`0oooo0P0000030?ooo`800000203oool00`000000oooo0?ooo`05
0?ooo`@000002@3oool010000000oooo0?ooo`0000040?ooo`800000203oool01@000000oooo0000
003oool0000000H0oooo001Q0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`05
0000003oool0oooo0?ooo`0000001P3oool3000000H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`8000002P3oool2000000<0oooo00<000000?ooo`0000001@3oool20000
00`0oooo0`0000060?ooo`040000003oool0oooo000000H0oooo0P0000060?ooo`040000003oool0
0000000000L0oooo001R0?ooo`80000000@0oooo0000003oool0oooo0P0000020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`0000001`3oool00`000000oooo0000000300000080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`800000203oool2000000<0oooo00<000000?ooo`3oool0
0P0000020?ooo`030000003oool0oooo00l0oooo0`0000030?ooo`040000003oool0oooo000000P0
oooo0`0000020?ooo`030000003oool0oooo008000001`3oool006<0oooo0P0000000`3oool00000
0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001`3oool2000000<0oooo0`0000060?oo
o`030000003oool0oooo00T0oooo0P0000060?ooo`8000000P3oool00`000000oooo0?ooo`030?oo
o`8000005@3oool3000000@0oooo00<000000?ooo`3oool0203oool2000000<0oooo00<000000?oo
o`3oool01P3oool006<0oooo00@000000?ooo`0000000000103oool3000000H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool01P000000oooo0?ooo`3oool000000?ooo`<00000103oool00`000000oooo0?oo
o`0:0?ooo`800000103oool200000080oooo00<000000?ooo`3oool00P3oool4000001H0oooo1000
00000`3oool000000?ooo`090?ooo`060000003oool000000000003oool000001`3oool100000000
I03oool2000000030?ooo`000000oooo00@0oooo0P0000050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`0000001@3oool300000080oooo00<000000?ooo`3oool02`3oool200000080oooo
0P0000000`3oool000000?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
4`3oool010000000oooo0?ooo`3oool3000000T0oooo00@000000?ooo`3oool0oooo0P0000070?oo
o`400000001U0?ooo`<000001P3oool2000000D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool2000000P0
oooo1000000>0?ooo`@0000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000oooo00000002000000D0
oooo00@000000?ooo`3oool0oooo0P0000000`3oool00000000000040?ooo`800000001V0?ooo`<0
00001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000002P3oool40000
00d0oooo0`0000030?ooo`030000003oool0oooo00H0oooo0P00000B0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool3000000030?ooo`000000oooo00<0oooo0P0000030?oo
o`@000000@3oool100000000IP3oool3000000L0oooo0`0000030?ooo`030000003oool0oooo00H0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000002`3oool00`000000oooo00000002000000X0oooo0`0000000`3oool000000000000;
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`<000000P3oool00`000000oooo000000050?ooo`<000000@3oool006L0oooo0P0000080?oo
o`030000003oool000000080oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool2000000X0oooo00@00000
0?ooo`3oool0oooo0`0000070?ooo`030000003oool00000008000003@3oool2000000l0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0000000<0
oooo0000003oool00`3oool00`000000oooo0?ooo`0200000000J03oool2000000P0oooo00H00000
0?ooo`00000000000?ooo`0000090?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0`3oool3000000@0oooo0`0000020?ooo`8000003@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000
003oool00000008000000P3oool010000000oooo0?ooo`0000020?ooo`00J@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo008000002P3oool2000000L0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo0`0000000`3oool0
0000000000050?ooo`800000303oool2000000`0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool300000080
oooo0@0000010?ooo`400000001Z0?ooo`8000001`3oool010000000oooo0?ooo`3oool2000000X0
oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`00000:0?ooo`8000002@3oool00`00
0000oooo0?ooo`060?ooo`@000001`3oool2000000`0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00<000000@3oool100000000J@3oool00`00
0000oooo0?ooo`03000000D0oooo00@000000?ooo`3oool0oooo0P00000:0?ooo`030000003oool0
oooo00D0oooo0P00000=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool3
000000040?ooo`00000000000?ooo`<000001P3oool2000000/0oooo0P0000080?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`060000003o
ool0oooo0000003oool00000103oool400000000K@3oool00`000000oooo00000002000000<0oooo
00@000000?ooo`3oool0oooo0`0000080?ooo`8000001`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00L0oooo100000050?ooo`8000000P3oool3000000H0oooo0P00000;0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool00000
00D0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`030000003oool0oooo00800000001^0?oo
o`8000000P3oool200000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0000000D0oooo0P00000?0?ooo`800000103oool3000000030?ooo`000000
oooo00H0oooo0P0000040?ooo`@000001@3oool2000000X0oooo0P0000050?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000001P3oool010000000oooo0?ooo`3oool2000000@0oooo
00<000000?ooo`0000000P00000006l0oooo0P0000030?ooo`<000000P3oool01@000000oooo0?oo
o`3oool0000000L0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`00000@0?ooo`@0
00001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000@0oooo0P0000000`3oool0
0000000000050?ooo`8000002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`3oool2000000@0oooo10000002
0?ooo`00L03oool3000000@0oooo100000030?ooo`8000001@3oool010000000oooo0?ooo`000002
0?ooo`050000003oool0oooo0?ooo`0000002`3oool4000000030?ooo`000000000000L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000060?ooo`80000000@0oooo0000000000000000
103oool2000000T0oooo0P0000020?ooo`030000003oool0oooo00@0oooo0P0000060?ooo`050000
003oool0oooo0?ooo`000000103oool700000000LP3oool2000000@0oooo00@000000?ooo`000000
0000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`800000103oool00`00
0000oooo0?ooo`060?ooo`<000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000001`3oool200000080oooo0P0000040?ooo`8000002@3oool00`00
0000oooo000000060?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P000002
0?ooo`80000000<0oooo0000000000000P0000020?ooo`00L`3oool2000000@0oooo00<000000?oo
o`0000000`0000020?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo00@00000
0?ooo`3oool0oooo1000000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000090?ooo`8000000P3oool2000000@0oooo0P0000080?ooo`8000001@3o
ool2000000D0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool50000
0080oooo001d0?ooo`<000000P3oool00`000000oooo000000030?ooo`8000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0000000D0oooo0`00000@0?ooo`8000001P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000002`3oool010000000oooo0?ooo`3oool3000000<0oooo
0P0000060?ooo`030000003oool0000000@0oooo0P0000050?ooo`040000003oool0oooo00000080
oooo0P0000020?ooo`H000000P3oool007D0oooo00<000000?ooo`0000000P3oool00`000000oooo
000000040?ooo`H0000000<0oooo0000003oool00P3oool6000001@0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00T0oooo0P0000040?ooo`80
00000`3oool2000000@0oooo00<000000?ooo`3oool00P000000103oool000000?ooo`0000040?oo
o`040000003oool0oooo00000080oooo0P0000030?ooo`<0000000@0oooo0000003oool000000@3o
ool007H0oooo00<000000?ooo`0000000P3oool2000000L0oooo1@0000000`3oool0000000000002
000000@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool02`3oool2000000@0oooo0`0000020?ooo`8000000P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`0000000P3o
ool2000000<0oooo1P0000010?ooo`4000000@3oool007L0oooo00<000000?ooo`0000000P3oool2
000000T0oooo0`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool400000003
0?ooo`00000000000080oooo0@0000000001\
\>"],
  ImageRangeCache->{{{0, 239}, {287, 0}} -> {-2.50001, 3.99894, 0.0104604, \
0.0104604}}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Trace", "Subsection"],

Cell["The mirror is ready to be traced.", "Text"],

Cell[CellGroupData[{

Cell["\<\
Timing[propagatedseashellmirror = PropagateSystem[{
\tMove[LineOfRays[1], {-2, 1, 9}, {1, 0, 0}],
\tResonate[seashellmirror],
\tBoundary[{-2.5, -2.5, 0}, {2.5, 2.5, 12}]
}, MaxIterations->40];]\
\>", "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \({14.066666666666606`\ Second, Null}\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell["Two rays are emerging at the top opening, one at the bottom.", "Text"],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[propagatedseashellmirror, PlotPoints -> 30, RayPointSize \
-> 5];\
\>", "Input",
  CellLabel->"In[30]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.84267 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.428812 1.87955 -0.0368803 1.87955 [
[ 0 0 0 0 ]
[ 1 1.84267 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.84267 L
0 1.84267 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.3984 .58597 m
.10275 .24818 L
s
.90507 .40933 m
.3984 .58597 L
s
.63769 .04219 m
.90507 .40933 L
s
.90507 .40933 m
.97512 1.64732 L
s
.10275 .24818 m
.63769 .04219 L
s
.0271 1.50888 m
.10275 .24818 L
s
.56615 .85834 m .62278 .75381 L .53034 .84366 L .634 .524 .712 r
F
.56615 .85834 m .66721 .75074 L .62278 .75381 L F
.41653 .91463 m .56615 .85834 L .53034 .84366 L .733 .555 .651 r
F
.59555 .8735 m .66721 .75074 L .56615 .85834 L .513 .376 .631 r
F
.43296 .93382 m .56615 .85834 L .41653 .91463 L .688 .473 .589 r
F
.43296 .93382 m .59555 .8735 L .56615 .85834 L F
.53034 .84366 m .57303 .75912 L .49314 .82923 L .724 .65 .775 r
F
.53034 .84366 m .62278 .75381 L .57303 .75912 L F
.39826 .89444 m .53034 .84366 L .49314 .82923 L .775 .642 .716 r
F
.41653 .91463 m .53034 .84366 L .39826 .89444 L .733 .555 .651 r
F
0 g
.38772 1.26388 m
.38799 1.2464 L
s
.38799 1.2464 m
.3984 .58597 L
s
.59555 .8735 m .69881 .75293 L .66721 .75074 L .513 .376 .631 r
F
.61502 .88935 m .69881 .75293 L .59555 .8735 L .321 .152 .49 r
F
.44582 .95165 m .59555 .8735 L .43296 .93382 L .641 .389 .523 r
F
.44582 .95165 m .61502 .88935 L .59555 .8735 L F
.49314 .82923 m .52775 .76486 L .46011 .81529 L .797 .79 .846 r
F
.49314 .82923 m .57303 .75912 L .52775 .76486 L F
.3803 .87371 m .49314 .82923 L .46011 .81529 L .809 .74 .788 r
F
.39826 .89444 m .49314 .82923 L .3803 .87371 L .775 .642 .716 r
F
.62278 .75381 m .60083 .68422 L .57303 .75912 L .729 .681 .804 r
F
.62278 .75381 m .64557 .65191 L .60083 .68422 L F
.66721 .75074 m .64557 .65191 L .62278 .75381 L .568 .542 .786 r
F
.57303 .75912 m .55799 .71594 L .52775 .76486 L .857 .836 .824 r
F
.57303 .75912 m .60083 .68422 L .55799 .71594 L F
.61502 .88935 m .71386 .7626 L .69881 .75293 L .321 .152 .49 r
F
.62296 .90563 m .71386 .7626 L .61502 .88935 L 0 0 .167 r
F
.45399 .96779 m .61502 .88935 L .44582 .95165 L .586 .296 .444 r
F
.45399 .96779 m .62296 .90563 L .61502 .88935 L F
.29358 .92434 m .43296 .93382 L .41653 .91463 L .851 .578 .526 r
F
.29681 .93655 m .43296 .93382 L .29358 .92434 L .833 .533 .482 r
F
.29681 .93655 m .44582 .95165 L .43296 .93382 L F
.28995 .91117 m .41653 .91463 L .39826 .89444 L .869 .632 .577 r
F
.29358 .92434 m .41653 .91463 L .28995 .91117 L .851 .578 .526 r
F
.66721 .75074 m .67865 .62514 L .64557 .65191 L .568 .542 .786 r
F
.69881 .75293 m .67865 .62514 L .66721 .75074 L .181 .24 .689 r
F
.2993 .94761 m .44582 .95165 L .29681 .93655 L .819 .496 .443 r
F
.2993 .94761 m .45399 .96779 L .44582 .95165 L F
.46011 .81529 m .49481 .77288 L .43608 .80286 L .797 .966 .914 r
F
.49481 .77288 m .48831 .77563 L .43608 .80286 L F
.53611 .73963 m .50709 .76615 L .53814 .73657 L 0 0 0 r
F
.46011 .81529 m .52775 .76486 L .50322 .77016 L .797 .966 .914 r
F
.532 .7458 m .50696 .76668 L .53611 .73963 L 0 0 0 r
F
.52961 .74939 m .52743 .75105 L .532 .7458 L F
.52743 .75105 m .50696 .76668 L .532 .7458 L F
.54319 .73287 m .53814 .73657 L .55038 .71078 L F
.54319 .73287 m .55038 .71078 L .55069 .72424 L F
.55799 .71594 m .55899 .67345 L .55224 .72242 L .857 .745 .23 r
F
.55228 .72236 m .55038 .71078 L .55252 .68936 L 0 0 .118 r
F
.5517 .72305 m .55224 .72242 L .55171 .72303 L .857 .745 .23 r
F
.55799 .71594 m .55657 .71754 L .54144 .73493 L F
.55069 .72424 m .55038 .71078 L .55177 .71926 L 0 0 .118 r
F
.55171 .72303 m .55177 .71926 L .55228 .72236 L F
.55069 .72424 m .55177 .71926 L .55171 .72303 L F
.55657 .71754 m .55224 .72242 L .55226 .7225 L .857 .745 .23 r
F
.55224 .72252 m .55224 .72242 L .54144 .73493 L F
.54144 .73493 m .5481 .72722 L .5436 .7324 L F
.52775 .76486 m .52845 .76084 L .50322 .77016 L .796 .96 .637 r
F
.52845 .76084 m .52915 .7568 L .51132 .76598 L F
.52845 .76084 m .51132 .76598 L .50322 .77016 L F
.52915 .7568 m .5075 .76683 L .50322 .77016 L F
.5305 .74899 m .52961 .74939 L .50322 .77016 L F
.50567 .76768 m .50709 .76615 L .50679 .76734 L .142 0 0 r
F
.50679 .76734 m .50696 .76668 L .52961 .74939 L 0 0 0 r
F
.50696 .76668 m .50709 .76615 L .53611 .73963 L F
.50567 .76768 m .49041 .7744 L .50709 .76615 L .142 0 0 r
F
.49041 .7744 m .46922 .78373 L .49451 .77199 L F
.49041 .7744 m .49451 .77199 L .50709 .76615 L F
.50322 .77016 m .50683 .76714 L .49781 .77132 L .796 .96 .637 r
F
.48161 .79021 m .50322 .77016 L .49781 .77132 L .797 .966 .914 r
F
.46011 .81529 m .49781 .77132 L .49481 .77288 L F
.50476 .76866 m .49062 .77466 L .50567 .76768 L .142 0 0 r
F
.49062 .77466 m .46922 .78373 L .50567 .76768 L F
.46051 .79191 m .48831 .77563 L .46079 .79178 L 0 0 0 r
F
.43608 .80286 m .46204 .78932 L .46051 .79191 L F
.46204 .78932 m .48831 .77563 L .46051 .79191 L F
.46011 .81529 m .50322 .77016 L .48161 .79021 L .797 .966 .914 r
F
.4714 .78865 m .45914 .79135 L .47008 .78568 L .142 0 0 r
F
.43608 .80286 m .46051 .79191 L .46034 .79192 L 0 0 0 r
F
.46035 .79191 m .45914 .79135 L .4714 .78865 L .142 0 0 r
F
.45693 .79198 m .45599 .78987 L .46035 .79191 L .217 0 0 r
F
.53056 .74864 m .53082 .74713 L .50322 .77016 L .796 .96 .637 r
F
.49168 .78267 m .46952 .78443 L .49452 .77324 L .142 0 0 r
F
.49767 .77302 m .49452 .77324 L .49869 .77137 L F
.49168 .78267 m .49452 .77324 L .49767 .77302 L F
.50089 .7728 m .50567 .76768 L .50433 .77388 L F
.50221 .77442 m .50433 .77388 L .5038 .77634 L F
.50089 .7728 m .50433 .77388 L .50221 .77442 L F
.49862 .77296 m .50221 .77442 L .49851 .77535 L .255 0 .315 r
F
.49862 .77296 m .50089 .7728 L .50221 .77442 L F
.52547 .85649 m .5162 .83366 L .52569 .8251 L .667 .445 .573 r
F
.5162 .83366 m .50745 .81213 L .51917 .82046 L F
.5162 .83366 m .51917 .82046 L .52569 .8251 L F
.48804 .78656 m .48784 .78664 L .49168 .78267 L .142 0 0 r
F
.50592 .77764 m .52261 .78279 L .50691 .78297 L .255 0 .315 r
F
.50115 .78939 m .50433 .77698 L .50691 .78297 L 0 0 0 r
F
.50433 .77698 m .50517 .77367 L .50557 .77578 L F
.50433 .77698 m .50557 .77578 L .50691 .78297 L F
.50158 .78892 m .51798 .78356 L .5247 .79589 L .568 .349 .543 r
F
.51798 .78356 m .52382 .78479 L .5247 .79589 L F
.51019 .81158 m .5247 .79589 L .51917 .82046 L F
.49486 .79641 m .50742 .79619 L .51019 .81158 L F
.50742 .79619 m .5247 .79589 L .51019 .81158 L F
.50013 .79053 m .5247 .79589 L .49486 .79641 L F
.4711 .79925 m .47333 .798 L .4813 .80015 L .445 .029 .155 r
F
.4588 .79621 m .45844 .79539 L .46629 .79713 L .217 0 0 r
F
.5026 .81045 m .50575 .81092 L .51507 .8387 L .764 .478 .501 r
F
.48575 .78739 m .51917 .82046 L .48129 .7935 L .568 .349 .543 r
F
.52177 .85869 m .50575 .81092 L .52547 .85649 L .667 .445 .573 r
F
.50575 .81092 m .50745 .81213 L .52547 .85649 L F
.53028 .83865 m .52569 .8251 L .53083 .83578 L F
.5276 .85281 m .52642 .83566 L .53028 .83865 L F
.52642 .83566 m .52569 .8251 L .53028 .83865 L F
.53478 .85381 m .57098 .87061 L .54854 .90025 L .711 .597 .727 r
F
.57098 .87061 m .56858 .87614 L .54854 .90025 L F
.54089 .84685 m .57257 .87134 L .53478 .85381 L F
.54089 .84685 m .5287 .79695 L .54764 .83915 L .599 .432 .627 r
F
.60356 .85532 m .57839 .76132 L .6042 .85516 L .569 .453 .682 r
F
.52569 .8251 m .53649 .82885 L .54089 .84685 L .667 .445 .573 r
F
.53028 .83865 m .54089 .84685 L .53478 .85381 L .711 .597 .727 r
F
.53334 .84101 m .54089 .84685 L .54579 .8669 L .667 .445 .573 r
F
.52569 .8251 m .54089 .84685 L .53334 .84101 L F
.52727 .82848 m .5415 .83457 L .57387 .86978 L .711 .597 .727 r
F
.56904 .86452 m .57398 .85877 L .57387 .86978 L F
.5415 .83457 m .57109 .85662 L .56904 .86452 L F
.57109 .85662 m .57398 .85877 L .56904 .86452 L F
.57109 .85662 m .56693 .83905 L .57329 .84819 L .569 .453 .682 r
F
.54764 .83915 m .54787 .83569 L .55803 .84689 L .599 .432 .627 r
F
.54787 .83569 m .56693 .83905 L .57259 .86293 L F
.57109 .85662 m .57409 .84853 L .57398 .85877 L .711 .597 .727 r
F
.5287 .79695 m .53876 .81728 L .54764 .83915 L .599 .432 .627 r
F
.52931 .79639 m .56187 .83178 L .54888 .83773 L .592 .48 .695 r
F
.52382 .78479 m .53174 .7942 L .52931 .79639 L F
.58135 .86078 m .57831 .85565 L .60356 .85532 L .569 .453 .682 r
F
.57831 .85565 m .57409 .84853 L .5783 .8495 L F
.57831 .85565 m .5783 .8495 L .60356 .85532 L F
.5246 .78407 m .52614 .78266 L .52606 .78418 L 0 0 0 r
F
.53757 .7408 m .55799 .71594 L .53866 .73813 L .796 .96 .637 r
F
.52775 .76486 m .55538 .72016 L .53757 .7408 L F
.55538 .72016 m .55799 .71594 L .53757 .7408 L F
.52775 .76486 m .53866 .73813 L .52916 .75676 L F
.54319 .73287 m .55069 .72424 L .5513 .75037 L 0 0 0 r
F
.54319 .73287 m .5513 .75037 L .54461 .73984 L F
.55108 .76494 m .55147 .75063 L .56673 .77837 L .322 .245 .612 r
F
.55108 .76494 m .56673 .77837 L .56672 .77868 L F
.55147 .75063 m .55224 .72242 L .56539 .77254 L F
.55147 .75063 m .56539 .77254 L .56676 .77778 L F
.55147 .75063 m .56676 .77778 L .56673 .77837 L F
.5597 .80161 m .55291 .77896 L .56504 .77872 L .569 .453 .682 r
F
.56622 .78882 m .56716 .76966 L .57816 .76541 L F
.5274 .78103 m .53344 .75598 L .53551 .75125 L 0 0 0 r
F
.53344 .75598 m .53691 .74157 L .54217 .736 L F
.52637 .78421 m .53691 .74157 L .5274 .78103 L F
.5597 .80161 m .56504 .77872 L .56622 .78882 L .569 .453 .682 r
F
.52584 .78554 m .55794 .80508 L .55257 .81561 L .592 .48 .695 r
F
.52604 .78502 m .55794 .80508 L .52584 .78554 L F
.52524 .78412 m .55794 .80508 L .52452 .78407 L F
.52524 .78412 m .54802 .78586 L .55794 .80508 L F
.55257 .81561 m .55794 .80508 L .56077 .81057 L F
.56803 .833 m .56077 .81057 L .57829 .84454 L F
.55257 .81561 m .56077 .81057 L .56803 .833 L F
.55147 .78184 m .55159 .78001 L .5545 .79121 L .599 .432 .627 r
F
.56077 .81057 m .56713 .78704 L .57829 .84454 L .592 .48 .695 r
F
.55958 .77241 m .5535 .7782 L .52783 .77945 L .322 .245 .612 r
F
.5655 .77761 m .55831 .77885 L .52783 .77945 L F
.55963 .80175 m .55189 .77556 L .5597 .80161 L .569 .453 .682 r
F
.55159 .78001 m .55269 .77896 L .55858 .80381 L .599 .432 .627 r
F
.55159 .78001 m .55858 .80381 L .5545 .79121 L F
.56504 .77872 m .56672 .77868 L .56622 .78882 L .569 .453 .682 r
F
.55858 .80381 m .55189 .77556 L .55963 .80175 L F
.55147 .78184 m .56794 .78404 L .56713 .78704 L .592 .48 .695 r
F
.55858 .80381 m .56713 .78704 L .56077 .81057 L F
.55147 .78184 m .56713 .78704 L .55858 .80381 L F
.54554 .78105 m .55147 .78184 L .56077 .81057 L F
.52376 .78401 m .52523 .78318 L .52446 .78406 L 0 0 0 r
F
.52446 .78406 m .57829 .84454 L .5783 .8495 L .592 .48 .695 r
F
.52369 .78313 m .52452 .78407 L .52446 .78406 L F
.52452 .78407 m .57829 .84454 L .52446 .78406 L F
.52523 .78318 m .52614 .78266 L .5246 .78407 L 0 0 0 r
F
.52446 .78406 m .57936 .85079 L .52382 .78479 L .592 .48 .695 r
F
.52446 .78406 m .5246 .78407 L .52382 .78479 L 0 0 0 r
F
.52523 .78318 m .5246 .78407 L .52446 .78406 L F
.53174 .7942 m .55475 .82154 L .52931 .79639 L .592 .48 .695 r
F
.55475 .82154 m .57936 .85079 L .56187 .83178 L F
.55475 .82154 m .56187 .83178 L .52931 .79639 L F
.56693 .83905 m .5779 .84941 L .57329 .84819 L F
.5779 .84941 m .57409 .84853 L .57329 .84819 L F
.56187 .83178 m .56888 .83939 L .56693 .83905 L F
.56888 .83939 m .57936 .85079 L .56693 .83905 L F
.56693 .83905 m .55858 .80381 L .57342 .84838 L .569 .453 .682 r
F
.55858 .80381 m .55963 .80175 L .57342 .84838 L F
.57332 .84805 m .55963 .80175 L .57347 .84749 L F
.55963 .80175 m .5597 .80161 L .57347 .84749 L F
.56713 .78704 m .56794 .78404 L .56812 .78509 L .592 .48 .695 r
F
.56713 .78704 m .56812 .78509 L .57829 .84454 L F
.5545 .79121 m .55858 .80381 L .56693 .83905 L .599 .432 .627 r
F
.56187 .83178 m .57329 .84819 L .54888 .83773 L .592 .48 .695 r
F
.52382 .78479 m .54888 .83773 L .52518 .78986 L F
.54787 .83569 m .55147 .78184 L .56693 .83905 L .599 .432 .627 r
F
.55147 .78184 m .5545 .79121 L .56693 .83905 L F
.55147 .78184 m .54554 .78105 L .55159 .78001 L F
.52783 .77948 m .55668 .77913 L .52692 .78282 L .322 .245 .612 r
F
.55668 .77913 m .56708 .779 L .54554 .78105 L F
.55668 .77913 m .54554 .78105 L .52692 .78282 L F
.52637 .78421 m .5274 .78103 L .52692 .78282 L 0 0 0 r
F
.52284 .78278 m .52614 .78266 L .52277 .78457 L F
.52452 .78407 m .52604 .78502 L .52584 .78554 L .592 .48 .695 r
F
.52915 .7568 m .5305 .74899 L .5075 .76683 L .796 .96 .637 r
F
.5305 .74899 m .53814 .73657 L .53691 .74157 L 0 0 0 r
F
.52961 .74939 m .53814 .73657 L .5305 .74899 L F
.53691 .74157 m .53739 .7396 L .53866 .73813 L F
.52916 .75676 m .53866 .73813 L .53082 .74713 L .796 .96 .637 r
F
.52774 .75219 m .53691 .74157 L .52597 .7858 L 0 0 0 r
F
.52369 .78313 m .54554 .78105 L .54802 .78586 L .592 .48 .695 r
F
.52369 .78313 m .54802 .78586 L .52524 .78412 L F
.54764 .83915 m .52597 .7858 L .53215 .78336 L .599 .432 .627 r
F
.54012 .78199 m .53215 .78336 L .5399 .7803 L F
.54764 .83915 m .53215 .78336 L .54012 .78199 L F
.50557 .77578 m .5233 .77172 L .52284 .78278 L .255 0 .315 r
F
.52284 .78278 m .52774 .75219 L .52614 .78266 L 0 0 0 r
F
.50777 .77364 m .52331 .77147 L .50557 .77578 L .255 0 .315 r
F
.52331 .77147 m .5233 .77172 L .50557 .77578 L F
.51556 .78305 m .52284 .78278 L .52277 .78457 L 0 0 0 r
F
.50557 .77578 m .52369 .78313 L .50592 .77764 L .255 0 .315 r
F
.52261 .78279 m .51556 .78305 L .50691 .78297 L F
.45705 .98196 m .62296 .90563 L .45399 .96779 L .51 .171 .329 r
F
.45705 .98196 m .6197 .92152 L .62296 .90563 L F
.45526 .99394 m .6197 .92152 L .45705 .98196 L .37 0 .124 r
F
.45526 .99394 m .60707 .93584 L .6197 .92152 L F
.44936 1.00361 m .60707 .93584 L .45526 .99394 L .061 0 0 r
F
.44936 1.00361 m .58792 .9475 L .60707 .93584 L F
.44044 1.01098 m .58792 .9475 L .44936 1.00361 L .4 .848 .762 r
F
.44044 1.01098 m .56546 .95595 L .58792 .9475 L F
.42964 1.01629 m .56546 .95595 L .44044 1.01098 L .646 .959 .929 r
F
.42964 1.01629 m .54269 .96146 L .56546 .95595 L F
.29925 .9776 m .44044 1.01098 L .44936 1.00361 L .762 .337 .241 r
F
.29698 .98123 m .44044 1.01098 L .29925 .9776 L .737 .276 .154 r
F
.29698 .98123 m .42964 1.01629 L .44044 1.01098 L F
.29419 .98329 m .40237 1.00964 L .29698 .98123 L .708 .211 .058 r
F
.40237 1.00964 m .42964 1.01629 L .40279 1.00919 L F
.40237 1.00964 m .40279 1.00919 L .29698 .98123 L F
.30133 .96563 m .45526 .99394 L .45705 .98196 L .794 .428 .364 r
F
.30076 .9724 m .45526 .99394 L .30133 .96563 L .78 .388 .311 r
F
.30076 .9724 m .44936 1.00361 L .45526 .99394 L F
.29925 .9776 m .44936 1.00361 L .30076 .9724 L .762 .337 .241 r
F
.29419 .98329 m .418 1.01989 L .42964 1.01629 L .708 .211 .058 r
F
.29117 .98379 m .40633 1.02221 L .418 1.01989 L .68 .155 0 r
F
.29117 .98379 m .38247 1.00978 L .29419 .98329 L F
.38247 1.00978 m .3899 1.01189 L .38389 1.01009 L F
.38247 1.00978 m .38389 1.01009 L .29419 .98329 L F
.39677 1.01385 m .418 1.01989 L .3968 1.01362 L F
.418 1.01989 m .54269 .96146 L .42964 1.01629 L .717 .961 .944 r
F
.418 1.01989 m .51338 .96951 L .54269 .96146 L F
.54129 .89295 m .54973 .91216 L .54113 .8929 L .711 .597 .727 r
F
.54973 .91216 m .54962 .91211 L .5263 .85968 L F
.52727 .82848 m .56706 .86375 L .56489 .86407 L F
.56706 .86375 m .57387 .86978 L .56489 .86407 L F
.56489 .86407 m .57387 .86978 L .57257 .87134 L F
.53028 .83865 m .54854 .90025 L .52641 .8591 L F
.5276 .85281 m .53083 .83578 L .54579 .8669 L .667 .445 .573 r
F
.52727 .82848 m .57257 .87134 L .53028 .83865 L .711 .597 .727 r
F
.53075 .96349 m .55244 .91342 L .54269 .96146 L .78 .671 .743 r
F
.55244 .91342 m .56858 .87614 L .55667 .91538 L F
.55244 .91342 m .55667 .91538 L .54269 .96146 L F
.54854 .90025 m .55244 .91342 L .52641 .8591 L .711 .597 .727 r
F
.55244 .91342 m .54973 .91216 L .52641 .8591 L F
.56278 .92674 m .57101 .87322 L .6042 .85516 L .765 .681 .77 r
F
.57101 .87322 m .58135 .86078 L .6042 .85516 L F
.54269 .96146 m .55667 .91538 L .56278 .92674 L F
.57098 .87061 m .57257 .87134 L .56858 .87614 L .711 .597 .727 r
F
.55667 .91538 m .57259 .86293 L .56278 .92674 L .765 .681 .77 r
F
.55244 .91342 m .57387 .86978 L .55689 .92845 L .711 .597 .727 r
F
.54854 .90025 m .56858 .87614 L .55244 .91342 L F
.56858 .87614 m .57387 .86978 L .55244 .91342 L F
.51916 .94884 m .52597 .95819 L .51502 .96873 L .797 .714 .772 r
F
.52714 .94354 m .52597 .95819 L .51916 .94884 L F
.52665 .96419 m .55112 .9128 L .53075 .96349 L .78 .671 .743 r
F
.55112 .9128 m .56858 .87614 L .55244 .91342 L F
.55112 .9128 m .55244 .91342 L .53075 .96349 L F
.53394 .94211 m .54968 .91214 L .52665 .96419 L F
.54968 .91214 m .56858 .87614 L .55112 .9128 L F
.54968 .91214 m .55112 .9128 L .52665 .96419 L F
.53524 .93817 m .54143 .89638 L .54845 .91156 L F
.5263 .85968 m .54962 .91211 L .54893 .91179 L .711 .597 .727 r
F
.52714 .94354 m .53314 .93956 L .52597 .95819 L .797 .714 .772 r
F
.52714 .94354 m .53959 .8924 L .53524 .93817 L .78 .671 .743 r
F
.53959 .8924 m .54143 .89638 L .53524 .93817 L F
.54461 .90978 m .52987 .95444 L .52597 .95819 L .797 .714 .772 r
F
.52192 .96499 m .54845 .91156 L .54968 .91214 L .78 .671 .743 r
F
.5263 .85968 m .54893 .91179 L .52618 .86342 L .711 .597 .727 r
F
.54893 .91179 m .55476 .92521 L .54845 .91156 L F
.54893 .91179 m .54845 .91156 L .52618 .86342 L F
.52641 .8591 m .54129 .89295 L .5263 .85968 L F
.54129 .89295 m .54113 .8929 L .5263 .85968 L F
.53959 .8924 m .54579 .8669 L .54143 .89638 L .78 .671 .743 r
F
.53023 .90504 m .53588 .89121 L .528 .93285 L .827 .699 .724 r
F
.52852 .9039 m .52714 .94354 L .51916 .94884 L .797 .714 .772 r
F
.53023 .90504 m .52714 .94354 L .52852 .9039 L F
.53588 .89121 m .53959 .8924 L .52192 .96499 L .827 .699 .724 r
F
.53762 .89177 m .54845 .91156 L .54223 .90322 L .711 .597 .727 r
F
.52618 .86342 m .53959 .8924 L .53762 .89177 L F
.53959 .8924 m .54845 .91156 L .53762 .89177 L F
.52618 .86342 m .54223 .90322 L .5259 .87238 L F
.52454 .87383 m .5259 .87238 L .52456 .87396 L .692 .491 .611 r
F
.51655 .82193 m .5257 .87126 L .52454 .87383 L F
.5257 .87126 m .5259 .87238 L .52454 .87383 L F
.53023 .90504 m .52574 .87206 L .53588 .89121 L .827 .699 .724 r
F
.52425 .86346 m .52607 .86696 L .5259 .87238 L .692 .491 .611 r
F
.51547 .86243 m .52177 .85869 L .52456 .87396 L F
.51547 .86243 m .52456 .87396 L .52289 .87594 L F
.51458 .84486 m .51507 .8387 L .51702 .84956 L .764 .478 .501 r
F
.51702 .84956 m .51507 .8387 L .52177 .85869 L F
.47333 .798 m .48072 .79891 L .4813 .80015 L .445 .029 .155 r
F
.4711 .79925 m .4813 .80015 L .4809 .80044 L F
.483 .8032 m .4806 .80066 L .48203 .80129 L .764 .478 .501 r
F
.4806 .80066 m .4809 .80044 L .5026 .81045 L F
.4809 .80044 m .48146 .80003 L .48375 .80116 L F
.4809 .80044 m .48375 .80116 L .5026 .81045 L F
.4751 .79699 m .4714 .78865 L .47885 .79488 L .142 0 0 r
F
.47885 .79488 m .4714 .78865 L .48185 .79319 L F
.47333 .798 m .47885 .79488 L .48072 .79891 L .445 .029 .155 r
F
.46051 .79191 m .46079 .79178 L .46035 .79191 L 0 0 0 r
F
.35394 .83318 m .43608 .80286 L .42413 .7937 L .746 .948 .945 r
F
.42413 .7937 m .42256 .79378 L .43147 .79274 L .217 0 0 r
F
.42344 .79379 m .42413 .7937 L .42391 .79353 L .746 .948 .945 r
F
.35394 .83318 m .42413 .7937 L .42344 .79379 L F
.45693 .79198 m .42413 .7937 L .45599 .78987 L .217 0 0 r
F
.42413 .7937 m .43147 .79274 L .45599 .78987 L F
.42256 .79378 m .41783 .79403 L .42103 .79368 L F
.42256 .79378 m .42103 .79368 L .45599 .78987 L F
.4751 .79699 m .46035 .79191 L .4714 .78865 L .142 0 0 r
F
.47613 .79931 m .47333 .798 L .4751 .79699 L F
.47333 .798 m .46035 .79191 L .4751 .79699 L F
.43252 .80013 m .46034 .79192 L .42391 .79353 L 0 0 0 r
F
.43608 .80286 m .46034 .79192 L .43252 .80013 L F
.45844 .79539 m .46047 .79197 L .47333 .798 L .217 0 0 r
F
.4588 .79621 m .47333 .798 L .47192 .79879 L .445 .029 .155 r
F
.46629 .79713 m .47333 .798 L .47613 .79931 L .217 0 0 r
F
.45844 .79539 m .47333 .798 L .46629 .79713 L F
.43204 .79442 m .4588 .79621 L .47192 .79879 L .445 .029 .155 r
F
.4588 .79621 m .47462 .79727 L .47333 .798 L F
.46051 .79191 m .45693 .79198 L .44651 .79253 L 0 0 0 r
F
.35394 .83318 m .42344 .79379 L .34883 .81493 L .746 .948 .945 r
F
.42344 .79379 m .42391 .79353 L .42278 .79385 L F
.42344 .79379 m .42278 .79385 L .34883 .81493 L F
.42329 .79376 m .41783 .79403 L .42345 .79374 L .217 0 0 r
F
.40634 .79658 m .4014 .79582 L .40732 .79644 L 0 .521 .831 r
F
.40729 .79827 m .42103 .79435 L .40639 .79667 L .438 .876 .871 r
F
.42103 .79435 m .42278 .79385 L .40732 .79644 L F
.42103 .79435 m .40732 .79644 L .39721 .79813 L F
.42936 .79615 m .4014 .79582 L .41783 .79403 L .217 0 0 r
F
.44285 .79938 m .47736 .80039 L .46757 .80855 L .653 .302 .365 r
F
.47736 .80039 m .47736 .80045 L .46757 .80855 L F
.47743 .80039 m .47742 .80194 L .46757 .80855 L F
.49499 .85504 m .47808 .83071 L .4778 .8188 L .884 .508 .322 r
F
.48557 .84357 m .47808 .83071 L .49499 .85504 L F
.49362 .84523 m .4778 .8188 L .48588 .82489 L F
.47743 .80039 m .47963 .80046 L .47742 .80194 L .653 .302 .365 r
F
.44465 .79935 m .47964 .80045 L .44285 .79938 L F
.47935 .80001 m .47877 .79871 L .48011 .80014 L .764 .478 .501 r
F
.43863 .79514 m .4809 .80044 L .47411 .79902 L .445 .029 .155 r
F
.43027 .7943 m .4809 .80044 L .43863 .79514 L F
.4809 .80044 m .48 .80021 L .47411 .79902 L F
.47973 .8004 m .48011 .80014 L .50511 .82666 L .764 .478 .501 r
F
.45992 .79874 m .48 .80021 L .4426 .79928 L .653 .302 .365 r
F
.45925 .79721 m .4588 .79621 L .47468 .79904 L .217 0 0 r
F
.45925 .79721 m .47468 .79904 L .47411 .79902 L F
.45925 .79721 m .42425 .79369 L .45693 .79198 L F
.45844 .79539 m .45693 .79198 L .46047 .79197 L F
.42391 .79353 m .47885 .79488 L .47462 .79727 L .445 .029 .155 r
F
.42391 .79353 m .47462 .79727 L .43204 .79442 L F
.44651 .79253 m .42907 .79255 L .42391 .79353 L 0 0 0 r
F
.45693 .79198 m .42907 .79255 L .44651 .79253 L F
.4588 .79621 m .46629 .79713 L .47491 .79904 L .217 0 0 r
F
.47468 .79904 m .47491 .79904 L .47573 .79922 L F
.4588 .79621 m .47491 .79904 L .47468 .79904 L F
.48575 .78739 m .4714 .78865 L .48852 .7836 L .142 0 0 r
F
.4816 .79308 m .47637 .79081 L .48575 .78739 L F
.47637 .79081 m .4714 .78865 L .48575 .78739 L F
.4714 .78865 m .46952 .78443 L .49168 .78267 L F
.46952 .78443 m .49062 .77466 L .50476 .76866 L F
.49481 .77288 m .49571 .77178 L .48831 .77563 L .797 .966 .914 r
F
.46079 .79178 m .49571 .77178 L .48102 .78272 L 0 0 0 r
F
.46952 .78443 m .46922 .78373 L .49062 .77466 L .142 0 0 r
F
.48831 .77563 m .49571 .77178 L .46079 .79178 L 0 0 0 r
F
.47008 .78568 m .45599 .78987 L .46922 .78373 L .142 0 0 r
F
.45914 .79135 m .45599 .78987 L .47008 .78568 L F
.46035 .79191 m .48102 .78272 L .42907 .79255 L 0 0 0 r
F
.46079 .79178 m .48102 .78272 L .46035 .79191 L F
.45693 .79198 m .46035 .79191 L .46047 .79197 L .217 0 0 r
F
.42391 .79353 m .47383 .78408 L .47885 .79488 L .445 .029 .155 r
F
.4239 .7929 m .45038 .79613 L .42384 .78888 L F
.46932 .79844 m .47411 .79902 L .47096 .79839 L F
.48 .80021 m .47964 .80045 L .4426 .79928 L .653 .302 .365 r
F
.47964 .80045 m .47963 .80046 L .44285 .79938 L F
.42391 .79353 m .47411 .79902 L .4239 .7929 L .445 .029 .155 r
F
.4611 .80138 m .42425 .79369 L .45925 .79721 L .217 0 0 r
F
.46139 .80205 m .45915 .80154 L .4611 .80138 L F
.45915 .80154 m .42425 .79369 L .4611 .80138 L F
.49414 .84677 m .50345 .85687 L .50015 .85689 L .787 .597 .643 r
F
.49412 .84675 m .49421 .84684 L .49414 .84677 L F
.51938 .89783 m .52377 .87709 L .52512 .88292 L .827 .699 .724 r
F
.51938 .89783 m .52512 .88292 L .52035 .89847 L F
.52377 .87709 m .52532 .87911 L .53023 .90504 L F
.50691 .93498 m .52208 .87928 L .51459 .91716 L .915 .784 .702 r
F
.50646 .92578 m .52208 .87928 L .50691 .93498 L F
.40633 1.02221 m .49647 .97759 L .418 1.01989 L .715 .971 .931 r
F
.49647 .97759 m .49849 .97659 L .49645 .97769 L F
.49647 .97759 m .49645 .97769 L .418 1.01989 L F
.52035 .89847 m .52512 .88292 L .53023 .90504 L .827 .699 .724 r
F
.52439 .87418 m .52541 .87296 L .53023 .90504 L F
.52509 .87084 m .52574 .87206 L .53023 .90504 L F
.53146 .88979 m .5148 .96894 L .49833 .97554 L .797 .714 .772 r
F
.53146 .88979 m .51502 .96873 L .51482 .96882 L F
.49647 .97759 m .49658 .97746 L .49849 .97659 L .715 .971 .931 r
F
.49849 .97659 m .51338 .96951 L .4963 .97853 L F
.49645 .97769 m .4963 .97853 L .418 1.01989 L F
.49849 .97659 m .4963 .97853 L .49645 .97769 L F
.39233 1.01754 m .4057 1.02201 L .39212 1.01748 L .662 .119 0 r
F
.4057 1.02201 m .40633 1.02221 L .40572 1.02201 L F
.4057 1.02201 m .40572 1.02201 L .39212 1.01748 L F
.41942 1.01133 m .44377 .9976 L .47144 .98487 L .591 .948 .851 r
F
.40137 1.02052 m .42721 1.00655 L .41942 1.01133 L F
.42721 1.00655 m .44377 .9976 L .41942 1.01133 L F
.40116 1.02045 m .44253 .99817 L .40137 1.02052 L F
.48362 .80442 m .52289 .87594 L .51055 .85735 L .692 .491 .611 r
F
.48362 .80442 m .51055 .85735 L .50961 .85566 L F
.52289 .87594 m .52015 .87237 L .51063 .85751 L F
.52289 .87594 m .51063 .85751 L .51055 .85735 L F
.50646 .92578 m .50709 .90211 L .5221 .87542 L .915 .784 .702 r
F
.52289 .87594 m .52327 .87664 L .52015 .87237 L .692 .491 .611 r
F
.51935 .90177 m .49743 .97438 L .51682 .90997 L .797 .714 .772 r
F
.49743 .97438 m .4973 .97484 L .49743 .97438 L F
.49743 .97438 m .49743 .97438 L .51682 .90997 L F
.49447 .94772 m .49511 .97397 L .48432 .97889 L .849 .862 .852 r
F
.49519 .94793 m .49511 .97397 L .49447 .94772 L F
.44516 .9925 m .48432 .97889 L .43643 1.00071 L F
.30085 .95734 m .45705 .98196 L .45399 .96779 L .806 .462 .406 r
F
.30133 .96563 m .45705 .98196 L .30085 .95734 L .794 .428 .364 r
F
.49669 .86078 m .51365 .88276 L .50817 .89734 L .787 .597 .643 r
F
.49669 .86078 m .50817 .89734 L .50045 .88141 L F
.50045 .88141 m .50817 .89734 L .50494 .90595 L F
.51365 .88276 m .50537 .90518 L .50494 .90595 L F
.50229 .87135 m .50229 .87144 L .50231 .87142 L F
.50229 .87144 m .50469 .89871 L .50232 .8715 L F
.50229 .87144 m .50232 .8715 L .50231 .87142 L F
.4973 .97484 m .4973 .97481 L .51682 .90997 L .797 .714 .772 r
F
.49648 .97755 m .49649 .97747 L .51682 .90997 L F
.51682 .90997 m .49654 .97731 L .50161 .95952 L F
.52208 .87928 m .52327 .87664 L .5157 .91357 L .915 .784 .702 r
F
.51682 .90997 m .50161 .95952 L .50333 .95363 L .797 .714 .772 r
F
.52564 .88094 m .53146 .88979 L .51918 .92157 L F
.40633 1.02221 m .4456 1.00054 L .49647 .97759 L .715 .971 .931 r
F
.4456 1.00054 m .48577 .97838 L .49624 .97761 L F
.4456 1.00054 m .49624 .97761 L .49647 .97759 L F
.51935 .90177 m .51918 .92157 L .4978 .97691 L .797 .714 .772 r
F
.49649 .9775 m .4978 .97691 L .49264 .99025 L F
.51935 .90177 m .4978 .97691 L .49649 .9775 L F
.52564 .88094 m .51918 .92157 L .51935 .90177 L F
.52327 .87664 m .52377 .87709 L .51938 .89783 L .915 .784 .702 r
F
.5194 .89552 m .51938 .89783 L .50454 .96803 L F
.52327 .87664 m .51938 .89783 L .5194 .89552 L F
.51459 .91716 m .5157 .91357 L .50454 .96803 L F
.52208 .87928 m .5157 .91357 L .51459 .91716 L F
.50021 .95051 m .51459 .91716 L .50333 .95363 L F
.52035 .89847 m .51935 .90177 L .51682 .90997 L .797 .714 .772 r
F
.50454 .96803 m .51938 .89783 L .53023 .90504 L .827 .699 .724 r
F
.52035 .89847 m .51682 .90997 L .50967 .93188 L .797 .714 .772 r
F
.51682 .90997 m .50333 .95363 L .50967 .93188 L F
.52208 .87928 m .52304 .87643 L .52327 .87664 L .915 .784 .702 r
F
.50646 .92578 m .5221 .87542 L .52304 .87643 L F
.50015 .85689 m .52564 .88094 L .52177 .89328 L .787 .597 .643 r
F
.49412 .84675 m .52177 .89328 L .49669 .86078 L F
.50634 .89282 m .51176 .87494 L .50745 .89555 L .949 .898 .509 r
F
.51176 .87494 m .51231 .8731 L .51192 .8749 L F
.51176 .87494 m .51192 .8749 L .50745 .89555 L F
.50469 .89871 m .50469 .89868 L .50231 .87142 L .787 .597 .643 r
F
.49412 .84675 m .50494 .90595 L .50229 .87135 L F
.49497 .9457 m .49766 .94066 L .49606 .94819 L .949 .898 .509 r
F
.50499 .90622 m .50501 .90686 L .49606 .94819 L F
.49151 .94895 m .48432 .97889 L .44516 .9925 L .849 .862 .852 r
F
.49497 .9457 m .49078 .95875 L .49151 .94895 L F
.49078 .95875 m .48432 .97889 L .49151 .94895 L F
.4952 .94548 m .49506 .94591 L .49497 .9457 L F
.49506 .94591 m .48432 .97889 L .49497 .9457 L F
.49511 .97397 m .47144 .98487 L .43643 1.00071 L F
.32218 .99412 m .36554 1.00859 L .32252 .99425 L .662 .119 0 r
F
.36554 1.00859 m .39233 1.01754 L .36341 1.00789 L F
.36554 1.00859 m .36341 1.00789 L .32252 .99425 L F
.40631 1.02221 m .39516 1.02368 L .40633 1.02221 L F
.39233 1.01754 m .39212 1.01748 L .32252 .99425 L F
.32218 .99412 m .39516 1.02368 L .40631 1.02221 L F
.39439 1.0198 m .43601 1.0011 L .39516 1.02368 L 0 0 0 r
F
.43601 1.0011 m .44253 .99817 L .42895 1.00549 L F
.43601 1.0011 m .42895 1.00549 L .39516 1.02368 L F
.47989 .97387 m .46624 .98236 L .47961 .9744 L .849 .862 .852 r
F
.48577 .97838 m .49727 .97438 L .49647 .97759 L .715 .971 .931 r
F
.44253 .99817 m .44377 .9976 L .40137 1.02052 L .591 .948 .851 r
F
.39516 1.02368 m .47144 .98487 L .40633 1.02221 L F
.47144 .98487 m .4834 .97946 L .40633 1.02221 L F
.49511 .97397 m .49511 .97416 L .47144 .98487 L .849 .862 .852 r
F
.51365 .88276 m .51615 .886 L .50537 .90518 L .787 .597 .643 r
F
.49606 .94819 m .50745 .89555 L .49867 .94896 L .915 .784 .702 r
F
.50745 .89555 m .51231 .8731 L .50804 .89688 L F
.50745 .89555 m .50804 .89688 L .49867 .94896 L F
.50499 .90622 m .50537 .90518 L .50501 .90686 L .949 .898 .509 r
F
.50537 .91167 m .50709 .90211 L .50646 .92578 L .915 .784 .702 r
F
.50494 .90595 m .52177 .89328 L .50967 .93188 L .787 .597 .643 r
F
.51615 .886 m .52177 .89328 L .50494 .90595 L F
.50494 .90595 m .50499 .90622 L .50229 .87135 L F
.50499 .90622 m .50478 .89971 L .50229 .87135 L F
.50498 .90618 m .50634 .89282 L .50537 .90518 L .949 .898 .509 r
F
.50473 .89815 m .50634 .89282 L .50498 .90618 L F
.50634 .89282 m .50745 .89555 L .50537 .90518 L F
.51176 .87494 m .50701 .88039 L .51231 .8731 L F
.49891 .9492 m .49596 .95394 L .4952 .94548 L .849 .862 .852 r
F
.50333 .95363 m .49596 .95394 L .49891 .9492 L F
.50333 .95363 m .49768 .97299 L .49596 .95394 L F
.49768 .97299 m .49511 .97416 L .4952 .94548 L F
.49497 .9457 m .49151 .94895 L .48428 .96567 L F
.4834 .97946 m .48577 .97838 L .40633 1.02221 L .591 .948 .851 r
F
.49511 .97416 m .49508 .9819 L .43643 1.00071 L .849 .862 .852 r
F
.43601 1.0011 m .49088 .97215 L .44253 .99817 L 0 0 0 r
F
.43643 1.00071 m .43803 1.0002 L .43601 1.0011 L .849 .862 .852 r
F
.49151 .94895 m .44173 .99573 L .48428 .96567 L F
.44173 .99573 m .43601 1.0011 L .44544 .99418 L F
.44173 .99573 m .44544 .99418 L .48428 .96567 L F
.45067 .992 m .49088 .97215 L .43601 1.0011 L 0 0 0 r
F
.44253 .99817 m .49088 .97215 L .44377 .9976 L .591 .948 .851 r
F
.44377 .9976 m .49088 .97215 L .47144 .98487 L F
.45821 .98836 m .4748 .98119 L .48556 .97514 L 0 0 0 r
F
.46025 .98771 m .4748 .98119 L .45821 .98836 L F
.45067 .992 m .48556 .97514 L .48748 .97383 L F
.46502 .98603 m .48033 .97872 L .45067 .992 L F
.44976 .9967 m .49508 .9819 L .43129 1.00952 L .849 .862 .852 r
F
.44976 .9967 m .43129 1.00952 L .42344 1.01292 L F
.43586 1.00125 m .44976 .9967 L .42344 1.01292 L F
.43839 1.00008 m .49508 .9819 L .43586 1.00125 L F
.42344 1.01292 m .49264 .99025 L .41513 1.02073 L F
.49508 .9819 m .49264 .99025 L .42344 1.01292 L F
.4626 .98704 m .45933 .98936 L .46535 .98589 L F
.45933 .98936 m .41513 1.02073 L .46517 .98602 L F
.45933 .98936 m .46517 .98602 L .46535 .98589 L F
.43601 1.0011 m .43628 1.00093 L .48428 .96567 L F
.44552 .99415 m .43628 1.00093 L .45067 .992 L F
.39439 1.0198 m .45067 .992 L .43601 1.0011 L 0 0 0 r
F
.45067 .992 m .46025 .98771 L .45821 .98836 L F
.46624 .98236 m .43586 1.00125 L .46653 .98243 L .849 .862 .852 r
F
.43628 1.00093 m .43586 1.00125 L .45083 .99194 L F
.45067 .992 m .45083 .99194 L .47989 .97387 L F
.43628 1.00093 m .45083 .99194 L .45067 .992 L F
.43601 1.0011 m .43839 1.00008 L .43586 1.00125 L F
.43601 1.0011 m .43586 1.00125 L .43628 1.00093 L F
.43803 1.0002 m .43839 1.00008 L .43601 1.0011 L F
.32218 .99412 m .32252 .99425 L .29117 .98379 L .662 .119 0 r
F
.30843 .99051 m .39516 1.02368 L .32218 .99412 L F
.36903 1.01332 m .39501 1.02362 L .36672 1.0128 L .655 .102 0 r
F
.38382 1.01934 m .38387 1.01936 L .30138 .98781 L F
.39501 1.02362 m .30138 .98781 L .30139 .98781 L F
.25947 .87191 m .29117 .98379 L .29419 .98329 L .947 .693 .23 r
F
.25947 .87191 m .28822 .98277 L .29117 .98379 L .921 .659 .169 r
F
.28822 .98277 m .32218 .99412 L .29117 .98379 L .662 .119 0 r
F
.28822 .98277 m .30843 .99051 L .32218 .99412 L F
.25947 .87191 m .28564 .98024 L .28822 .98277 L .87 .601 .073 r
F
.28564 .98024 m .36482 1.01164 L .28822 .98277 L .655 .102 0 r
F
.36482 1.01164 m .36903 1.01332 L .36579 1.01209 L F
.36482 1.01164 m .36579 1.01209 L .28822 .98277 L F
.36903 1.01332 m .36672 1.0128 L .28822 .98277 L F
.28564 .98024 m .32088 .99598 L .3311 .99827 L F
.32088 .99598 m .38479 1.02454 L .3311 .99827 L F
.3899 1.01189 m .39249 1.01257 L .29419 .98329 L .68 .155 0 r
F
.39677 1.01385 m .3968 1.01362 L .29419 .98329 L F
.25947 .87191 m .29419 .98329 L .29698 .98123 L .958 .71 .26 r
F
.25947 .87191 m .28375 .97619 L .28564 .98024 L .78 .512 0 r
F
.28375 .97619 m .33556 1.00098 L .28564 .98024 L .649 .091 0 r
F
.39501 1.02362 m .39501 1.02362 L .38387 1.01936 L .655 .102 0 r
F
.39501 1.02362 m .38387 1.01936 L .38382 1.01934 L F
.37243 1.01862 m .38479 1.02454 L .37102 1.01838 L .649 .091 0 r
F
.33556 1.00098 m .37243 1.01862 L .32297 .99692 L F
.37243 1.01862 m .37102 1.01838 L .32297 .99692 L F
.33556 1.00098 m .32297 .99692 L .28564 .98024 L F
.30422 .98598 m .37547 1.0248 L .38062 1.02254 L F
.39501 1.02362 m .39516 1.02368 L .39501 1.02362 L .655 .102 0 r
F
.39501 1.02362 m .38479 1.02454 L .39516 1.02368 L F
.3311 .99827 m .38479 1.02454 L .39501 1.02362 L F
.38479 1.02454 m .39439 1.0198 L .39498 1.0228 L 0 0 0 r
F
.38479 1.02454 m .39498 1.0228 L .39516 1.02368 L F
.48428 .96567 m .44552 .99415 L .47989 .97387 L .849 .862 .852 r
F
.50473 .89815 m .50548 .89229 L .51176 .87494 L .949 .898 .509 r
F
.50551 .88638 m .50701 .88039 L .50473 .89815 L F
.50568 .91004 m .50479 .89176 L .50443 .8888 L .787 .597 .643 r
F
.50477 .89963 m .50443 .8888 L .50231 .87142 L F
.50568 .91004 m .50443 .8888 L .50477 .89963 L F
.50568 .91004 m .50967 .93188 L .50479 .89176 L F
.50232 .87152 m .50502 .89371 L .4994 .87018 L .891 .724 .667 r
F
.50162 .87113 m .4994 .87018 L .49932 .86986 L F
.50232 .87152 m .4994 .87018 L .50162 .87113 L F
.50287 .87166 m .48557 .84357 L .49499 .85504 L .884 .508 .322 r
F
.50701 .88039 m .50162 .87113 L .50287 .87166 L F
.50162 .87113 m .48557 .84357 L .50287 .87166 L F
.50383 .87657 m .50033 .87042 L .503 .87349 L 0 0 .408 r
F
.50033 .87042 m .49617 .86312 L .50162 .87113 L F
.49617 .86312 m .49507 .86019 L .50162 .87113 L F
.48377 .84134 m .4851 .84298 L .50162 .87113 L F
.472 .82067 m .4716 .81958 L .48557 .84357 L F
.4851 .84298 m .48557 .84357 L .50162 .87113 L F
.472 .82067 m .48557 .84357 L .4851 .84298 L F
.47411 .79902 m .48 .80021 L .45992 .79874 L .653 .302 .365 r
F
.46139 .80205 m .45925 .79721 L .47613 .79931 L .217 0 0 r
F
.45925 .79721 m .47573 .79922 L .47613 .79931 L F
.42384 .78888 m .47096 .79839 L .45992 .79874 L .653 .302 .365 r
F
.44583 .79918 m .4426 .79928 L .43406 .79702 L .217 0 0 r
F
.44831 .7991 m .41876 .7942 L .42433 .79371 L F
.46139 .80205 m .44583 .79918 L .44831 .7991 L F
.44583 .79918 m .41876 .7942 L .44831 .7991 L F
.44092 .79835 m .45992 .79874 L .4426 .79928 L .653 .302 .365 r
F
.42391 .79353 m .43027 .7943 L .43863 .79514 L .445 .029 .155 r
F
.42384 .78888 m .45992 .79874 L .44092 .79835 L .653 .302 .365 r
F
.50499 .85686 m .47957 .8005 L .50979 .85682 L .764 .478 .501 r
F
.47957 .8005 m .47935 .80001 L .4796 .80048 L F
.47957 .8005 m .4796 .80048 L .50979 .85682 L F
.4138 .79711 m .4014 .79582 L .42936 .79615 L .217 0 0 r
F
.42384 .78888 m .4426 .79928 L .43376 .78981 L .653 .302 .365 r
F
.40634 .79658 m .39727 .79233 L .4014 .79582 L 0 .521 .831 r
F
.39727 .79233 m .39574 .79225 L .4014 .79582 L F
.3917 .78971 m .38436 .78679 L .4014 .79582 L F
.40557 .79522 m .42384 .78888 L .39963 .79286 L .438 .876 .871 r
F
.39963 .79286 m .42384 .78888 L .39842 .79238 L F
.39842 .79238 m .42384 .78888 L .4068 .79278 L .041 0 0 r
F
.40351 .79158 m .39084 .78729 L .40634 .79658 L 0 .521 .831 r
F
.39084 .78729 m .3829 .78557 L .40634 .79658 L F
.41876 .7942 m .41783 .79403 L .42433 .79371 L .217 0 0 r
F
.39721 .79813 m .42391 .79353 L .42384 .78888 L .438 .876 .871 r
F
.4068 .79278 m .42384 .78888 L .43376 .78981 L .041 0 0 r
F
.4068 .79278 m .43376 .78981 L .39317 .7878 L F
.44277 .79938 m .46757 .80855 L .45888 .80831 L .653 .302 .365 r
F
.44285 .79938 m .46757 .80855 L .44277 .79938 L F
.46757 .80855 m .46537 .81003 L .45888 .80831 L F
.49425 .84688 m .49415 .84661 L .50418 .8567 L .884 .508 .322 r
F
.49415 .84661 m .47742 .80268 L .50221 .85272 L F
.49415 .84661 m .50221 .85272 L .50418 .8567 L F
.50499 .85686 m .47779 .80269 L .47988 .80118 L .764 .478 .501 r
F
.50435 .85686 m .52381 .87809 L .50371 .85687 L .787 .597 .643 r
F
.5051 .85686 m .51024 .86268 L .50435 .85686 L F
.51024 .86268 m .52381 .87809 L .50435 .85686 L F
.47742 .80268 m .47742 .80194 L .50435 .85686 L .884 .508 .322 r
F
.50537 .85895 m .52564 .88094 L .50538 .85896 L .787 .597 .643 r
F
.50537 .85895 m .50538 .85896 L .49414 .84677 L F
.49421 .84684 m .50537 .85895 L .49414 .84677 L F
.50345 .85687 m .52564 .88094 L .50015 .85689 L F
.52381 .87809 m .52564 .88094 L .49412 .84675 L F
.50418 .8567 m .50435 .85686 L .51231 .8731 L .884 .508 .322 r
F
.47742 .80268 m .50435 .85686 L .50418 .8567 L F
.51231 .8731 m .50435 .85686 L .50499 .85686 L .764 .478 .501 r
F
.50435 .85686 m .47779 .80269 L .50499 .85686 L F
.49358 .84379 m .5051 .85686 L .49412 .84675 L .787 .597 .643 r
F
.5051 .85686 m .50371 .85687 L .49412 .84675 L F
.48584 .81593 m .48678 .81569 L .48716 .81678 L .653 .302 .365 r
F
.48584 .81593 m .48716 .81678 L .49028 .82572 L F
.48588 .82489 m .4778 .8188 L .47742 .80268 L .884 .508 .322 r
F
.47683 .81826 m .48584 .81593 L .49028 .82572 L .653 .302 .365 r
F
.45888 .80831 m .47629 .81291 L .47683 .81826 L F
.47629 .81291 m .48678 .81569 L .47683 .81826 L F
.44763 .80062 m .4778 .8188 L .45303 .80205 L F
.44277 .79938 m .4778 .8188 L .44763 .80062 L F
.43562 .79949 m .4366 .79947 L .44763 .80062 L 0 .521 .831 r
F
.44797 .8007 m .44763 .80062 L .4577 .80166 L F
.43562 .79949 m .44763 .80062 L .44797 .8007 L F
.4576 .80167 m .4577 .80166 L .46139 .80205 L F
.44803 .80072 m .4577 .80166 L .4576 .80167 L F
.43562 .79949 m .44797 .8007 L .44803 .80072 L F
.44797 .8007 m .4577 .80166 L .44803 .80072 L F
.4426 .79928 m .44465 .79935 L .44285 .79938 L .653 .302 .365 r
F
.46139 .80205 m .44763 .80062 L .4426 .79928 L .217 0 0 r
F
.46139 .80205 m .4426 .79928 L .44583 .79918 L F
.4426 .79928 m .44763 .80062 L .43376 .78981 L .653 .302 .365 r
F
.44763 .80062 m .45303 .80205 L .45289 .80196 L F
.46757 .80855 m .48678 .81569 L .46537 .81003 L F
.42278 .79385 m .42391 .79353 L .40632 .79656 L .438 .876 .871 r
F
.40635 .7966 m .40632 .79656 L .39721 .79813 L F
.42278 .79385 m .40632 .79656 L .40635 .7966 L F
.40634 .79658 m .40732 .79644 L .4366 .79947 L 0 .521 .831 r
F
.40634 .79658 m .4366 .79947 L .43562 .79949 L F
.44663 .80258 m .44905 .80386 L .44743 .80337 L .759 .44 .445 r
F
.46706 .81341 m .46991 .81492 L .4716 .81958 L F
.47359 .82586 m .4716 .81958 L .47456 .82772 L F
.46706 .81341 m .4716 .81958 L .47359 .82586 L F
.4756 .81731 m .46889 .81213 L .46514 .80975 L .653 .302 .365 r
F
.46524 .81031 m .46514 .80975 L .45303 .80205 L F
.4756 .81731 m .46514 .80975 L .46524 .81031 L F
.46504 .80915 m .46458 .80826 L .46575 .8097 L 0 0 .408 r
F
.46458 .80826 m .46139 .80205 L .46503 .80844 L F
.46458 .80826 m .46503 .80844 L .46575 .8097 L F
.44449 .80248 m .42608 .79964 L .43774 .80043 L 0 .521 .831 r
F
.44575 .80222 m .43774 .80043 L .45024 .80128 L F
.44641 .80236 m .45303 .80205 L .44663 .80258 L .759 .44 .445 r
F
.45303 .80205 m .46214 .80784 L .44663 .80258 L F
.46214 .80784 m .451 .80446 L .44663 .80258 L F
.46889 .81213 m .46991 .81492 L .44663 .80258 L F
.44641 .80236 m .44743 .80337 L .45288 .80376 L F
.52013 .85554 m .51959 .84164 L .52217 .85845 L .692 .491 .611 r
F
.48582 .8067 m .50511 .82666 L .52013 .85554 L F
.51458 .84486 m .5026 .81045 L .51507 .8387 L .764 .478 .501 r
F
.5069 .8301 m .5026 .81045 L .51458 .84486 L F
.50511 .82666 m .483 .8032 L .5026 .81045 L F
.483 .8032 m .48203 .80129 L .5026 .81045 L F
.48147 .80051 m .52013 .85554 L .51547 .86243 L .692 .491 .611 r
F
.52013 .85554 m .52217 .85845 L .52177 .85869 L F
.52013 .85554 m .52177 .85869 L .51547 .86243 L F
.51063 .85751 m .52381 .87809 L .49358 .84379 L .787 .597 .643 r
F
.50961 .85566 m .50511 .82666 L .51319 .8621 L .764 .478 .501 r
F
.50511 .82666 m .5026 .81045 L .50645 .82924 L F
.50511 .82666 m .50645 .82924 L .51319 .8621 L F
.51257 .85906 m .50645 .82924 L .51338 .85972 L F
.50645 .82924 m .5026 .81045 L .5069 .8301 L F
.50645 .82924 m .5069 .8301 L .51338 .85972 L F
.50435 .8252 m .51655 .82193 L .51959 .84164 L .692 .491 .611 r
F
.48147 .80051 m .49618 .80949 L .50435 .8252 L F
.49618 .80949 m .51655 .82193 L .50435 .8252 L F
.50511 .82666 m .51959 .84164 L .52013 .85554 L F
.51338 .85972 m .5069 .8301 L .51458 .84486 L .764 .478 .501 r
F
.50979 .85682 m .4796 .80048 L .50511 .82666 L F
.4796 .80048 m .47973 .8004 L .50511 .82666 L F
.47988 .80118 m .47613 .79931 L .47877 .79871 L F
.47736 .80039 m .47743 .80039 L .47736 .80045 L .653 .302 .365 r
F
.47779 .80269 m .47613 .79931 L .47988 .80118 L .764 .478 .501 r
F
.47963 .80046 m .48147 .80051 L .47742 .80285 L .653 .302 .365 r
F
.4774 .80196 m .47742 .80285 L .46757 .80855 L F
.47963 .80046 m .47742 .80285 L .4774 .80196 L F
.46757 .80855 m .48147 .80051 L .48678 .81569 L F
.4685 .80977 m .46139 .80205 L .46612 .80223 L .884 .508 .322 r
F
.46214 .80784 m .46889 .81213 L .451 .80446 L .759 .44 .445 r
F
.4778 .8188 m .46934 .81241 L .46889 .81213 L .653 .302 .365 r
F
.4778 .8188 m .46889 .81213 L .4756 .81731 L F
.47808 .83071 m .4716 .81958 L .47742 .80268 L .884 .508 .322 r
F
.4716 .81958 m .46612 .80223 L .47742 .80268 L F
.50126 .86827 m .4778 .8188 L .49362 .84523 L F
.4778 .8188 m .49028 .82572 L .46934 .81241 L .653 .302 .365 r
F
.46889 .81213 m .49028 .82572 L .46991 .81492 L .759 .44 .445 r
F
.4785 .83481 m .47456 .82772 L .47816 .83149 L 0 0 .408 r
F
.47857 .83553 m .47769 .83381 L .4785 .83481 L F
.47769 .83381 m .47456 .82772 L .4785 .83481 L F
.46514 .80848 m .46139 .80205 L .4685 .80977 L .884 .508 .322 r
F
.472 .82067 m .46503 .80844 L .4716 .81958 L 0 0 .408 r
F
.46503 .80844 m .46139 .80205 L .46514 .80848 L F
.46503 .80844 m .46514 .80848 L .4716 .81958 L F
.45289 .80196 m .45303 .80205 L .44641 .80236 L .759 .44 .445 r
F
.45324 .80383 m .44575 .80222 L .44894 .80155 L 0 .521 .831 r
F
.45289 .80196 m .45024 .80128 L .46139 .80205 L F
.46348 .80542 m .46256 .80319 L .46309 .80535 L 0 0 .408 r
F
.46309 .80535 m .46256 .80319 L .46139 .80205 L F
.46479 .80781 m .46256 .80319 L .46504 .80915 L F
.47456 .82772 m .46504 .80915 L .47231 .82154 L F
.46504 .80915 m .46575 .8097 L .47816 .83149 L F
.47456 .82772 m .46256 .80319 L .47238 .82346 L F
.47456 .82772 m .47231 .82154 L .47816 .83149 L F
.48377 .84134 m .472 .82067 L .4851 .84298 L F
.46991 .81492 m .49028 .82572 L .47656 .83154 L .759 .44 .445 r
F
.49932 .86986 m .5029 .88485 L .49883 .87595 L .891 .724 .667 r
F
.5029 .88485 m .50502 .89371 L .49883 .87595 L F
.49883 .87595 m .50502 .89371 L .49498 .92474 L F
.49883 .87595 m .49498 .92474 L .49496 .92458 L F
.49793 .87398 m .49494 .92489 L .48839 .94295 L F
.49856 .86944 m .49822 .87462 L .49793 .87398 L F
.49822 .87462 m .49494 .92489 L .49793 .87398 L F
.49932 .86986 m .49787 .88804 L .49856 .86944 L F
.49787 .88804 m .49494 .92489 L .49744 .88654 L F
.49787 .88804 m .49744 .88654 L .49856 .86944 L F
.49494 .86743 m .47857 .83553 L .4999 .87018 L 0 0 .408 r
F
.46991 .81492 m .47656 .83154 L .47456 .82772 L .759 .44 .445 r
F
.47857 .83553 m .47816 .83149 L .50383 .87657 L 0 0 .408 r
F
.51231 .8731 m .50961 .85566 L .51319 .8621 L .764 .478 .501 r
F
.49028 .82572 m .51063 .85751 L .49358 .84379 L .787 .597 .643 r
F
.50701 .88039 m .49425 .84688 L .51231 .8731 L .884 .508 .322 r
F
.49425 .84688 m .50418 .8567 L .51231 .8731 L F
.50382 .87207 m .50126 .86827 L .49412 .84675 L F
.50701 .88039 m .50287 .87166 L .50382 .87207 L F
.50287 .87166 m .50126 .86827 L .50382 .87207 L F
.50701 .88039 m .49412 .84675 L .49425 .84688 L F
.49412 .84675 m .50231 .87142 L .50043 .85597 L .787 .597 .643 r
F
.50043 .85597 m .50231 .87142 L .49932 .86986 L .891 .724 .667 r
F
.50231 .87142 m .50232 .87152 L .50162 .87113 L F
.50231 .87142 m .50162 .87113 L .49932 .86986 L F
.49425 .84688 m .49412 .84675 L .49362 .84523 L .884 .508 .322 r
F
.49028 .82572 m .49412 .84675 L .50043 .85597 L .787 .597 .643 r
F
.47738 .83311 m .49028 .82572 L .50043 .85597 L .759 .44 .445 r
F
.47653 .83155 m .47656 .83154 L .47456 .82772 L 0 0 .408 r
F
.49579 .86909 m .47656 .83154 L .47653 .83155 L F
.49579 .86909 m .49494 .86743 L .49494 .86744 L F
.49856 .86944 m .49793 .87398 L .49853 .8751 L .891 .724 .667 r
F
.49496 .92458 m .49498 .92474 L .49494 .92489 L F
.48895 .94072 m .50475 .88794 L .49494 .92489 L .127 0 .358 r
F
.50475 .88794 m .50701 .88039 L .50487 .88828 L F
.50475 .88794 m .50487 .88828 L .49494 .92489 L F
.49856 .86944 m .49853 .8751 L .50354 .8826 L .891 .724 .667 r
F
.49853 .8751 m .49839 .90311 L .50323 .88384 L F
.49853 .8751 m .50323 .88384 L .50354 .8826 L F
.49455 .91841 m .50464 .88764 L .48895 .94072 L .127 0 .358 r
F
.50464 .88764 m .50701 .88039 L .50475 .88794 L F
.50464 .88764 m .50475 .88794 L .48895 .94072 L F
.50002 .87735 m .49579 .86909 L .50383 .87657 L 0 0 .408 r
F
.50538 .88227 m .50002 .87735 L .50383 .87657 L F
.4792 .97628 m .48318 .96822 L .48075 .97715 L .127 0 .358 r
F
.4748 .98119 m .48033 .97872 L .48249 .97737 L 0 0 0 r
F
.4748 .98119 m .48249 .97737 L .49088 .97215 L F
.48033 .97872 m .48318 .96822 L .48428 .96567 L .949 .898 .509 r
F
.48748 .97383 m .48556 .97514 L .49088 .97215 L 0 0 0 r
F
.48033 .97872 m .48428 .96567 L .49088 .97215 L .949 .898 .509 r
F
.48428 .96567 m .49222 .93946 L .49171 .95178 L F
.48428 .96567 m .49171 .95178 L .49088 .97215 L F
.4952 .94548 m .49519 .94793 L .49447 .94772 L .849 .862 .852 r
F
.49222 .93946 m .49606 .94819 L .49088 .97215 L .949 .898 .509 r
F
.49497 .9457 m .47961 .9744 L .48549 .97079 L .849 .862 .852 r
F
.48171 .96954 m .49494 .92489 L .48318 .96822 L .127 0 .358 r
F
.47729 .97353 m .48839 .94295 L .48171 .96954 L F
.48839 .94295 m .49494 .92489 L .48171 .96954 L F
.48318 .96822 m .49268 .9332 L .48428 .96567 L .949 .898 .509 r
F
.49104 .93693 m .48937 .94574 L .48786 .94678 L .891 .724 .667 r
F
.48428 .96567 m .49268 .9332 L .49222 .93946 L .949 .898 .509 r
F
.49222 .93946 m .50551 .88638 L .50473 .89815 L F
.49268 .9332 m .50701 .88039 L .49222 .93946 L F
.50502 .89371 m .48937 .94574 L .49104 .93693 L .891 .724 .667 r
F
.49222 .93946 m .50498 .90618 L .49248 .94006 L .949 .898 .509 r
F
.50498 .90618 m .50537 .90518 L .50499 .90622 L F
.50498 .90618 m .50499 .90622 L .49248 .94006 L F
.49248 .94006 m .50499 .90622 L .49766 .94066 L F
.49248 .94006 m .49766 .94066 L .49497 .9457 L F
.50469 .89871 m .50478 .89971 L .50469 .89868 L .787 .597 .643 r
F
.50478 .89971 m .50568 .91004 L .50477 .89963 L F
.50478 .89971 m .50477 .89963 L .50469 .89868 L F
.50499 .90622 m .50568 .91004 L .50478 .89971 L F
.49222 .93946 m .50473 .89815 L .50498 .90618 L .949 .898 .509 r
F
.49867 .94896 m .50537 .91167 L .50646 .92578 L .915 .784 .702 r
F
.49088 .97215 m .50646 .92578 L .50691 .93498 L F
.50502 .89371 m .50967 .93188 L .48937 .94574 L .891 .724 .667 r
F
.48839 .94295 m .49494 .92489 L .48786 .94678 L F
.49106 .92367 m .48839 .94295 L .49455 .91841 L F
.47614 .97458 m .49494 .92489 L .47729 .97353 L .127 0 .358 r
F
.48036 .97394 m .47998 .9747 L .48549 .97079 L .849 .862 .852 r
F
.48549 .97079 m .47998 .9747 L .48426 .97278 L F
.49088 .97215 m .49606 .94819 L .49867 .94896 L .915 .784 .702 r
F
.50967 .93188 m .50333 .95363 L .4952 .94548 L .849 .862 .852 r
F
.50967 .93188 m .49497 .9457 L .48549 .97079 L F
.48786 .94678 m .50967 .93188 L .48426 .97278 L .891 .724 .667 r
F
.49455 .91841 m .48426 .97278 L .49872 .91213 L F
.48839 .94295 m .48426 .97278 L .49455 .91841 L F
.50548 .89229 m .50701 .88039 L .5107 .87615 L .949 .898 .509 r
F
.50548 .89229 m .5107 .87615 L .51176 .87494 L F
.52327 .87664 m .52322 .87659 L .52015 .87237 L .692 .491 .611 r
F
.52333 .87673 m .5221 .87542 L .52015 .87237 L F
.52177 .85869 m .5224 .85989 L .52456 .87396 L F
.50709 .90211 m .51231 .8731 L .52528 .86976 L .915 .784 .702 r
F
.49607 .91377 m .50541 .89906 L .50701 .88039 L .127 0 .358 r
F
.50541 .89906 m .50859 .89405 L .50825 .89114 L F
.50541 .89906 m .50825 .89114 L .50701 .88039 L F
.50101 .87927 m .50002 .87735 L .50051 .8778 L 0 0 .408 r
F
.50101 .87927 m .50051 .8778 L .50538 .88227 L F
.50354 .8826 m .50323 .88384 L .50585 .88872 L .891 .724 .667 r
F
.5036 .88432 m .50101 .87927 L .50273 .88045 L 0 0 .408 r
F
.50401 .88384 m .50273 .88045 L .50538 .88227 L F
.5036 .88432 m .50273 .88045 L .50401 .88384 L F
.50273 .88248 m .49835 .87325 L .49958 .87627 L F
.50784 .89131 m .5036 .88432 L .50538 .88227 L F
.50859 .89405 m .5073 .89153 L .50784 .89131 L F
.5073 .89153 m .5036 .88432 L .50784 .89131 L F
.49786 .91266 m .50859 .89405 L .49607 .91377 L .127 0 .358 r
F
.49872 .91213 m .48426 .97278 L .50105 .9128 L .891 .724 .667 r
F
.5053 .90223 m .50859 .89405 L .49786 .91266 L .127 0 .358 r
F
.49872 .91213 m .49786 .91266 L .49455 .91841 L F
.5053 .90223 m .49786 .91266 L .49872 .91213 L F
.5051 .89415 m .50573 .89607 L .50697 .89166 L .891 .724 .667 r
F
.49288 .91046 m .50573 .89607 L .5051 .89415 L F
.49288 .91046 m .50105 .9128 L .50573 .89607 L F
.47614 .97458 m .49455 .91841 L .48895 .94072 L .127 0 .358 r
F
.47614 .97458 m .49595 .92542 L .49455 .91841 L F
.43586 1.00125 m .41513 1.02073 L .47998 .9747 L .849 .862 .852 r
F
.43586 1.00125 m .47998 .9747 L .48036 .97394 L F
.44552 .99415 m .45067 .992 L .47989 .97387 L F
.47998 .9747 m .4626 .98704 L .4792 .97628 L F
.46624 .98236 m .46653 .98243 L .47961 .9744 L F
.47792 .97557 m .48318 .96822 L .4792 .97628 L .127 0 .358 r
F
.47614 .97458 m .4817 .96955 L .47792 .97557 L F
.4817 .96955 m .48318 .96822 L .47792 .97557 L F
.4655 .98583 m .48033 .97872 L .46524 .98594 L 0 0 0 r
F
.46524 .98594 m .48033 .97872 L .46503 .98603 L F
.46503 .98603 m .48033 .97872 L .46502 .98603 L F
.46999 .98326 m .48033 .97872 L .4655 .98583 L .335 0 .007 r
F
.4626 .98704 m .46535 .98589 L .4792 .97628 L .849 .862 .852 r
F
.47998 .9747 m .4792 .97628 L .48426 .97278 L F
.39128 1.02143 m .4655 .98583 L .39144 1.02126 L 0 0 0 r
F
.4655 .98583 m .46524 .98594 L .39144 1.02126 L F
.39622 1.01897 m .46524 .98594 L .39622 1.01889 L F
.46524 .98594 m .46503 .98603 L .39622 1.01889 L F
.41193 1.01139 m .46503 .98603 L .41222 1.01125 L F
.41193 1.01139 m .41222 1.01125 L .39639 1.01881 L F
.39639 1.01881 m .41193 1.01139 L .39639 1.01881 L F
.46503 .98603 m .46502 .98603 L .39639 1.01881 L F
.46703 .9842 m .46535 .98589 L .46443 .98625 L .726 .979 .917 r
F
.37547 1.0248 m .45245 .99097 L .38479 1.02454 L .335 0 .007 r
F
.46793 .98378 m .46535 .98589 L .46703 .9842 L .726 .979 .917 r
F
.29471 .98199 m .37547 1.0248 L .30422 .98598 L .649 .091 0 r
F
.28375 .97619 m .29471 .98199 L .30422 .98598 L F
.25947 .87191 m .29698 .98123 L .29925 .9776 L .959 .711 .263 r
F
.28289 .97061 m .35203 1.01108 L .28375 .97619 L .626 .065 0 r
F
.39639 1.01881 m .46502 .98603 L .45067 .992 L 0 0 0 r
F
.39622 1.01889 m .39639 1.01881 L .39639 1.01881 L F
.39144 1.02126 m .39622 1.01897 L .39622 1.01889 L F
.38479 1.02454 m .39128 1.02143 L .39144 1.02126 L F
.45245 .99097 m .46075 .98774 L .38479 1.02454 L .335 0 .007 r
F
.46075 .98774 m .46484 .98614 L .39271 1.02074 L F
.46075 .98774 m .39271 1.02074 L .39269 1.02071 L F
.39516 1.02368 m .40116 1.02045 L .40137 1.02052 L .591 .948 .851 r
F
.41082 1.013 m .41513 1.02073 L .39187 1.02242 L .726 .979 .917 r
F
.46484 .98614 m .43535 1.00666 L .41082 1.013 L F
.43535 1.00666 m .41513 1.02073 L .41082 1.013 L F
.35725 1.01414 m .3724 1.02301 L .35301 1.0129 L .626 .065 0 r
F
.3724 1.02301 m .37547 1.0248 L .37218 1.02306 L F
.3724 1.02301 m .37218 1.02306 L .35301 1.0129 L F
.35203 1.01108 m .35725 1.01414 L .34501 1.00866 L F
.35725 1.01414 m .35301 1.0129 L .34501 1.00866 L F
.35203 1.01108 m .34501 1.00866 L .28375 .97619 L F
.31019 .98659 m .36751 1.0242 L .37232 1.02296 L F
.38481 1.0207 m .39219 1.01849 L .39063 1.01814 L .335 0 .007 r
F
.37547 1.0248 m .38587 1.02087 L .38481 1.0207 L F
.38587 1.02087 m .39219 1.01849 L .38481 1.0207 L F
.39063 1.01814 m .39377 1.01789 L .3923 1.0174 L F
.39219 1.01849 m .39377 1.01789 L .39063 1.01814 L F
.46517 .98602 m .41513 1.02073 L .46484 .98614 L .726 .979 .917 r
F
.39377 1.01789 m .39779 1.01637 L .3923 1.0174 L .335 0 .007 r
F
.39269 1.02071 m .39271 1.02074 L .38479 1.02454 L F
.46535 .98589 m .39187 1.02242 L .38344 1.02304 L .726 .979 .917 r
F
.46535 .98589 m .38344 1.02304 L .45281 .9908 L F
.42834 1.00483 m .43716 1.0015 L .42501 1.00548 L .335 0 .007 r
F
.46333 1.00645 m .4632 1.0045 L .45864 1.01485 L 0 0 0 r
F
.4632 1.0045 m .46299 1.00142 L .46188 1.00485 L F
.4632 1.0045 m .46188 1.00485 L .45864 1.01485 L F
.46349 1.00887 m .46333 1.00645 L .45625 1.02223 L F
.46333 1.00645 m .45864 1.01485 L .45625 1.02223 L F
.49802 .97134 m .49795 .97166 L .48577 .97838 L .591 .948 .851 r
F
.49802 .97134 m .48577 .97838 L .4834 .97946 L F
.47144 .98487 m .49088 .97215 L .4983 .96991 L F
.47144 .98487 m .4983 .96991 L .49802 .97134 L F
.49768 .97299 m .49508 .9819 L .49511 .97416 L .849 .862 .852 r
F
.48577 .97838 m .49795 .97166 L .49727 .97438 L .715 .971 .931 r
F
.47144 .98487 m .49802 .97134 L .4834 .97946 L .591 .948 .851 r
F
.49654 .97731 m .49656 .97724 L .50161 .95952 L .797 .714 .772 r
F
.49649 .97747 m .4967 .97635 L .50161 .95952 L F
.49088 .97215 m .50021 .95051 L .4983 .96991 L .915 .784 .702 r
F
.50021 .95051 m .50333 .95363 L .4983 .96991 L F
.4983 .96991 m .51459 .91716 L .50454 .96803 L F
.50454 .96803 m .53023 .90504 L .52192 .96499 L .827 .699 .724 r
F
.49802 .97134 m .4983 .96991 L .50454 .96803 L .591 .948 .851 r
F
.49802 .97134 m .50454 .96803 L .49795 .97166 L F
.4973 .97484 m .49648 .97755 L .4973 .97481 L .797 .714 .772 r
F
.49648 .97755 m .49264 .99025 L .49649 .97747 L F
.49833 .97554 m .49955 .97505 L .4961 .98131 L F
.51338 .96951 m .52665 .96419 L .54269 .96146 L .717 .961 .944 r
F
.49955 .97505 m .5148 .96894 L .4961 .98131 L .797 .714 .772 r
F
.4961 .98131 m .5148 .96894 L .49264 .99025 L F
.49849 .97659 m .50454 .96803 L .52192 .96499 L .715 .971 .931 r
F
.49658 .97746 m .50454 .96803 L .49849 .97659 L F
.49795 .97166 m .50454 .96803 L .49647 .97759 L F
.49654 .97731 m .49649 .97747 L .49656 .97724 L .797 .714 .772 r
F
.49649 .97747 m .49264 .99025 L .4967 .97635 L F
.49849 .97659 m .52192 .96499 L .51338 .96951 L .715 .971 .931 r
F
.5003 .96583 m .50958 .98603 L .51582 .94797 L .785 .573 .614 r
F
.46821 1.01429 m .45625 1.02223 L .45864 1.02875 L .439 .15 .376 r
F
.49413 .97515 m .45931 1.01843 L .46821 1.01429 L F
.45931 1.01843 m .45625 1.02223 L .46821 1.01429 L F
.47815 1.00967 m .50958 .98603 L .46821 1.01429 L .864 .65 .611 r
F
.48085 1.00842 m .48514 1.00508 L .47815 1.00967 L F
.48514 1.00508 m .50958 .98603 L .47815 1.00967 L F
.52192 .96499 m .53394 .94211 L .52665 .96419 L .78 .671 .743 r
F
.52192 .96499 m .52714 .94354 L .53524 .93817 L F
.51482 .96882 m .51502 .96873 L .5148 .96894 L .797 .714 .772 r
F
.51338 .96951 m .52192 .96499 L .52665 .96419 L .717 .961 .944 r
F
.53023 .90504 m .528 .93285 L .52192 .96499 L .827 .699 .724 r
F
.52353 .9607 m .51482 .97797 L .52997 .97441 L .685 .415 .508 r
F
.49409 1.02509 m .50905 .99316 L .50958 .98603 L .851 .705 .7 r
F
.50905 .99316 m .50999 .99068 L .50958 .98603 L F
.51482 .97797 m .50905 .99316 L .52997 .97441 L .685 .415 .508 r
F
.53363 .97928 m .52781 .98746 L .53654 .98315 L .862 .644 .606 r
F
.52997 .97441 m .53654 .98315 L .53703 .98049 L F
.47815 1.05726 m .51156 1.0103 L .49409 1.02509 L .963 .919 .714 r
F
.51156 1.0103 m .52676 .98893 L .52468 .99123 L F
.51156 1.0103 m .52468 .99123 L .49409 1.02509 L F
.52612 1.00017 m .5127 1.02938 L .5324 .99258 L F
.48972 1.04414 m .49924 1.03802 L .52612 1.00017 L F
.49924 1.03802 m .5127 1.02938 L .52612 1.00017 L F
.47867 1.05806 m .5127 1.02938 L .48972 1.04414 L F
.53898 .98206 m .53479 .98881 L .55282 .98478 L .923 .957 .632 r
F
.53479 .98881 m .52911 1.01017 L .55282 .98478 L F
.55952 1.00457 m .57212 .99789 L .57611 .9895 L .865 .833 .813 r
F
.56689 1.00244 m .49848 1.06465 L .60316 .99195 L .827 .998 .78 r
F
.56689 1.00244 m .55113 1.01552 L .57212 .99789 L 0 0 0 r
F
.56116 1.00409 m .53837 1.02611 L .56689 1.00244 L .827 .998 .78 r
F
.53837 1.02611 m .49848 1.06465 L .56689 1.00244 L F
.56689 1.00244 m .57212 .99789 L .55952 1.00457 L 0 0 0 r
F
.54032 1.02201 m .49848 1.06465 L .57874 .98711 L .827 .998 .78 r
F
.49848 1.06465 m .48361 1.07359 L .52015 1.07616 L .383 0 0 r
F
.48361 1.07359 m .44641 1.09596 L .49034 1.08416 L F
.48361 1.07359 m .49034 1.08416 L .52015 1.07616 L F
.50657 1.05641 m .49006 1.06735 L .49848 1.06465 L .827 .998 .78 r
F
.4991 1.06039 m .49734 1.06161 L .49961 1.05879 L .553 .121 .174 r
F
.49657 1.06174 m .49006 1.06735 L .50657 1.05641 L .827 .998 .78 r
F
.54706 1.11325 m .423 1.11606 L .39595 1.18084 L .792 .842 .889 r
F
.52015 1.07616 m .423 1.11606 L .54706 1.11325 L .534 .924 .853 r
F
.44678 1.10629 m .44641 1.09596 L .423 1.11606 L F
.49027 1.08843 m .46355 1.09301 L .44678 1.10629 L F
.46355 1.09301 m .44641 1.09596 L .44678 1.10629 L F
.48789 1.08539 m .44641 1.09596 L .49027 1.08843 L F
.5099 1.07891 m .44641 1.09596 L .51371 1.07881 L F
.48438 1.08043 m .47753 1.09002 L .4829 1.07402 L .383 0 0 r
F
.47753 1.09002 m .47699 1.08942 L .4829 1.07402 L F
.47586 1.09235 m .47496 1.09037 L .4829 1.07402 L F
.4829 1.07402 m .47044 1.09967 L .44641 1.09596 L F
.47044 1.09967 m .47003 1.10052 L .46752 1.10003 L F
.47044 1.09967 m .46752 1.10003 L .44641 1.09596 L F
.47414 1.10113 m .46926 1.1019 L .47196 1.09948 L .553 .121 .174 r
F
.46926 1.1019 m .46671 1.1023 L .47003 1.10052 L F
.46926 1.1019 m .47003 1.10052 L .47196 1.09948 L F
.47586 1.09235 m .47003 1.10052 L .47496 1.09037 L .383 0 0 r
F
.49353 1.06763 m .48438 1.08043 L .4829 1.07402 L F
.47753 1.09002 m .47586 1.09235 L .47699 1.08942 L F
.49848 1.06465 m .49079 1.07435 L .49353 1.06763 L F
.49079 1.07435 m .48474 1.08197 L .49353 1.06763 L F
.48474 1.08197 m .47003 1.10052 L .48438 1.08043 L F
.48474 1.08197 m .48438 1.08043 L .49353 1.06763 L F
.48414 1.08658 m .48179 1.11403 L .47522 1.10304 L .695 .275 .246 r
F
.48816 1.06796 m .47003 1.10052 L .49848 1.06465 L F
.48306 1.08409 m .47048 1.0997 L .48345 1.07892 L .553 .121 .174 r
F
.48232 1.09393 m .47048 1.0997 L .48306 1.08409 L F
.47003 1.10052 m .46593 1.10272 L .44641 1.09596 L .383 0 0 r
F
.46789 1.10613 m .46749 1.10766 L .46467 1.10309 L .605 .249 .339 r
F
.46789 1.10613 m .46467 1.10309 L .4648 1.10305 L F
.46789 1.10613 m .4648 1.10305 L .46721 1.1057 L F
.48208 1.12024 m .46749 1.10766 L .46789 1.10613 L F
.49053 1.12864 m .48211 1.12098 L .48208 1.12024 L F
.48211 1.12098 m .46749 1.10766 L .48208 1.12024 L F
.48129 1.10326 m .48179 1.11403 L .48414 1.08658 L .516 .147 .278 r
F
.4808 1.10614 m .48179 1.11403 L .48129 1.10326 L F
.54706 1.11325 m .39595 1.18084 L .57781 1.17549 L .792 .842 .889 r
F
.53067 1.16857 m .51246 1.1653 L .49053 1.12864 L .605 .249 .339 r
F
.49053 1.12864 m .50193 1.16342 L .46749 1.10766 L F
.4813 1.11978 m .48011 1.13368 L .47134 1.1102 L .695 .275 .246 r
F
.48047 1.11928 m .48011 1.13368 L .4813 1.11978 L .516 .147 .278 r
F
.51246 1.1653 m .50193 1.16342 L .49053 1.12864 L .605 .249 .339 r
F
.48047 1.11928 m .48572 1.12489 L .48485 1.12625 L .516 .147 .278 r
F
.48047 1.11928 m .48485 1.12625 L .48035 1.12415 L F
.48572 1.12489 m .49972 1.13983 L .4869 1.13581 L F
.48572 1.12489 m .4869 1.13581 L .48011 1.13368 L F
.53067 1.16857 m .49053 1.12864 L .48034 1.11999 L .605 .249 .339 r
F
.54054 1.15216 m .53067 1.16857 L .50127 1.1402 L .395 .305 .635 r
F
.5003 1.1374 m .50127 1.1402 L .49721 1.13627 L F
.54054 1.15216 m .50127 1.1402 L .5003 1.1374 L F
.49782 1.13228 m .49721 1.13627 L .48865 1.12801 L F
.54054 1.15216 m .49721 1.13627 L .49782 1.13228 L F
.4648 1.10305 m .46494 1.10325 L .47134 1.1102 L .605 .249 .339 r
F
.46593 1.10272 m .45706 1.10536 L .44641 1.09596 L .383 0 0 r
F
.47048 1.0997 m .4644 1.10266 L .47888 1.08462 L .553 .121 .174 r
F
.46671 1.1023 m .4644 1.10266 L .48232 1.09393 L F
.47763 1.11625 m .46789 1.10613 L .47134 1.1102 L .605 .249 .339 r
F
.4813 1.11978 m .47346 1.1118 L .47763 1.11625 L F
.47346 1.1118 m .46789 1.10613 L .47763 1.11625 L F
.48208 1.12024 m .46789 1.10613 L .4813 1.11978 L F
.46789 1.10613 m .46721 1.1057 L .47134 1.1102 L F
.4648 1.10305 m .46467 1.10309 L .4644 1.10266 L F
.4648 1.10305 m .4644 1.10266 L .46494 1.10325 L F
.4648 1.10305 m .45855 1.10668 L .45706 1.10536 L .383 0 0 r
F
.46593 1.10272 m .46494 1.10325 L .4648 1.10305 L F
.46494 1.10325 m .45855 1.10668 L .4648 1.10305 L F
.47522 1.10304 m .4813 1.11978 L .47134 1.1102 L .695 .275 .246 r
F
.49053 1.12864 m .47134 1.1102 L .48034 1.11999 L .605 .249 .339 r
F
.47874 1.11825 m .4644 1.10266 L .47414 1.10113 L .553 .121 .174 r
F
.4808 1.10614 m .47414 1.10113 L .48186 1.09991 L F
.48179 1.11403 m .4813 1.11978 L .47522 1.10304 L .695 .275 .246 r
F
.47874 1.11825 m .47414 1.10113 L .4808 1.10614 L .553 .121 .174 r
F
.47003 1.10052 m .46766 1.1035 L .46889 1.10113 L .383 0 0 r
F
.46766 1.1035 m .46242 1.1101 L .46889 1.10113 L F
.46889 1.10113 m .46242 1.1101 L .45855 1.10668 L F
.46949 1.09998 m .46821 1.10244 L .46901 1.1018 L .695 .275 .246 r
F
.47067 1.09544 m .46821 1.10244 L .46949 1.09998 L F
.47067 1.09544 m .46551 1.10461 L .46821 1.10244 L F
.46551 1.10461 m .46636 1.10515 L .46901 1.1018 L F
.47048 1.0997 m .47888 1.08462 L .48345 1.07892 L .553 .121 .174 r
F
.48566 1.06876 m .47067 1.09544 L .47003 1.10052 L .695 .275 .246 r
F
.47067 1.09544 m .46901 1.1018 L .47003 1.10052 L F
.48566 1.06876 m .47003 1.10052 L .48816 1.06796 L F
.47414 1.10113 m .47196 1.09948 L .48232 1.09393 L .553 .121 .174 r
F
.51371 1.07881 m .48789 1.08539 L .49027 1.08843 L .534 .924 .853 r
F
.48778 1.09446 m .48345 1.07892 L .49734 1.06161 L .553 .121 .174 r
F
.4808 1.10614 m .48435 1.11216 L .48438 1.11253 L .516 .147 .278 r
F
.48373 1.10835 m .48345 1.07892 L .48778 1.09446 L .553 .121 .174 r
F
.48136 1.10656 m .48345 1.07892 L .48373 1.10835 L F
.48566 1.06876 m .48414 1.08658 L .46656 1.10562 L .695 .275 .246 r
F
.48186 1.09991 m .47645 1.10077 L .48232 1.09393 L .553 .121 .174 r
F
.48099 1.09836 m .4808 1.10614 L .48179 1.09946 L .516 .147 .278 r
F
.48099 1.09836 m .48197 1.09824 L .4825 1.09467 L F
.47645 1.10077 m .47414 1.10113 L .47818 1.09757 L .553 .121 .174 r
F
.48414 1.08658 m .46763 1.11705 L .46242 1.1101 L .695 .275 .246 r
F
.4808 1.10614 m .48414 1.08658 L .48473 1.07961 L .516 .147 .278 r
F
.48283 1.09814 m .48318 1.10137 L .48099 1.09836 L F
.47645 1.10077 m .47818 1.09757 L .48232 1.09393 L .553 .121 .174 r
F
.48566 1.06876 m .46656 1.10562 L .46551 1.10461 L .695 .275 .246 r
F
.47993 1.09776 m .48134 1.0844 L .47961 1.08031 L .553 .121 .174 r
F
.48134 1.0844 m .48224 1.07586 L .4807 1.07847 L F
.48134 1.0844 m .4807 1.07847 L .47961 1.08031 L F
.48311 1.07966 m .48407 1.08292 L .48473 1.07961 L .516 .147 .278 r
F
.48146 1.07971 m .48407 1.08292 L .48311 1.07966 L F
.48146 1.07971 m .48099 1.09836 L .48407 1.08292 L F
.49053 1.12864 m .48208 1.12024 L .4813 1.11978 L .605 .249 .339 r
F
.4808 1.10614 m .48047 1.11928 L .48179 1.11403 L .516 .147 .278 r
F
.48047 1.11928 m .4813 1.11978 L .48179 1.11403 L F
.4808 1.10614 m .49972 1.13983 L .48047 1.11928 L F
.48685 1.1107 m .50086 1.14019 L .4808 1.10614 L F
.48034 1.11999 m .49734 1.06161 L .4991 1.06039 L .553 .121 .174 r
F
.48395 1.10852 m .4874 1.09757 L .48283 1.09814 L F
.4879 1.09598 m .4991 1.06039 L .48433 1.0838 L F
.48099 1.09836 m .4825 1.09467 L .48473 1.07961 L .516 .147 .278 r
F
.48283 1.09814 m .48225 1.08709 L .48172 1.08792 L .553 .121 .174 r
F
.48253 1.07314 m .48241 1.07425 L .48566 1.06876 L .516 .147 .278 r
F
.48241 1.07425 m .48414 1.07185 L .48566 1.06876 L F
.48226 1.07569 m .48355 1.07426 L .48566 1.06876 L F
.48226 1.07569 m .48198 1.07834 L .48355 1.07426 L F
.48216 1.07785 m .48224 1.07586 L .48206 1.07755 L .553 .121 .174 r
F
.48198 1.07834 m .48473 1.07961 L .48536 1.07224 L .516 .147 .278 r
F
.48198 1.07834 m .48536 1.07224 L .48355 1.07426 L F
.48146 1.07971 m .48184 1.0797 L .48198 1.07834 L F
.48184 1.0797 m .48473 1.07961 L .48198 1.07834 L F
.48216 1.07785 m .48206 1.07755 L .48134 1.0844 L .553 .121 .174 r
F
.48172 1.08792 m .48216 1.07785 L .48134 1.0844 L F
.48172 1.08792 m .4991 1.06039 L .48224 1.07586 L F
.47961 1.08031 m .48224 1.07586 L .47957 1.07831 L F
.48224 1.07586 m .48226 1.07569 L .47957 1.07831 L F
.47957 1.07831 m .48058 1.07733 L .48115 1.07692 L 0 0 0 r
F
.48058 1.07733 m .48209 1.07585 L .48154 1.07649 L F
.48159 1.07446 m .48147 1.07913 L .48198 1.07834 L .516 .147 .278 r
F
.48159 1.07446 m .48169 1.07636 L .48154 1.07649 L F
.48097 1.07625 m .48181 1.07552 L .4817 1.07517 L 0 0 0 r
F
.48058 1.07733 m .48154 1.07649 L .48115 1.07692 L F
.48147 1.07913 m .48146 1.07971 L .48154 1.0795 L .516 .147 .278 r
F
.48147 1.07913 m .48154 1.0795 L .48198 1.07834 L F
.48154 1.07649 m .48283 1.09814 L .48134 1.0844 L F
.48169 1.07636 m .48283 1.09814 L .48154 1.07649 L F
.48209 1.07585 m .48226 1.07569 L .48208 1.07588 L 0 0 0 r
F
.48209 1.07585 m .48208 1.07588 L .48154 1.07649 L F
.48159 1.07446 m .48198 1.07834 L .48253 1.07314 L .516 .147 .278 r
F
.48169 1.07636 m .48833 1.09745 L .48283 1.09814 L F
.48205 1.07604 m .48833 1.09745 L .48169 1.07636 L F
.48189 1.07772 m .48294 1.07907 L .48205 1.07604 L 0 0 .384 r
F
.48189 1.07772 m .48205 1.07604 L .48183 1.07714 L F
.51016 1.05275 m .4991 1.06039 L .50657 1.05641 L .827 .998 .78 r
F
.52719 1.0354 m .4991 1.06039 L .51016 1.05275 L F
.48115 1.07692 m .55113 1.01552 L .48109 1.07698 L 0 0 0 r
F
.48159 1.07446 m .48205 1.07604 L .48169 1.07636 L .516 .147 .278 r
F
.48203 1.07617 m .48181 1.07552 L .48097 1.07625 L 0 0 0 r
F
.48115 1.07692 m .48197 1.07611 L .49575 1.06412 L F
.47336 1.08631 m .48138 1.07541 L .48034 1.0762 L .619 .823 .419 r
F
.4991 1.06039 m .49657 1.06174 L .48226 1.07569 L .553 .121 .174 r
F
.4991 1.06039 m .48226 1.07569 L .48224 1.07586 L F
.48226 1.07569 m .49657 1.06174 L .48115 1.07692 L 0 0 0 r
F
.48183 1.07714 m .48205 1.07604 L .48178 1.07511 L 0 0 .384 r
F
.48166 1.0752 m .48178 1.07511 L .48159 1.07446 L F
.47825 1.08001 m .48097 1.07625 L .4817 1.07517 L .619 .823 .419 r
F
.48165 1.07521 m .48166 1.0752 L .48164 1.07498 L 0 0 .384 r
F
.48178 1.07738 m .48164 1.07498 L .48162 1.07493 L F
.47825 1.08001 m .4817 1.07517 L .48138 1.07541 L .619 .823 .419 r
F
.48109 1.07698 m .48203 1.07617 L .48203 1.07617 L 0 0 0 r
F
.48006 1.07171 m .48178 1.07738 L .48162 1.07493 L 0 0 .384 r
F
.48355 1.07426 m .48536 1.07224 L .48566 1.06876 L .516 .147 .278 r
F
.54579 1.0144 m .48743 1.06714 L .49006 1.06735 L .827 .998 .78 r
F
.48743 1.06714 m .48657 1.06847 L .49006 1.06735 L F
.49731 1.06276 m .55113 1.01552 L .55978 1.00834 L 0 0 0 r
F
.49731 1.06276 m .55978 1.00834 L .56689 1.00244 L F
.49946 1.05926 m .49961 1.05879 L .49657 1.06174 L .553 .121 .174 r
F
.52719 1.0354 m .49657 1.06174 L .4991 1.06039 L .827 .998 .78 r
F
.49575 1.06412 m .49657 1.06174 L .55113 1.01552 L 0 0 0 r
F
.48197 1.07611 m .49657 1.06174 L .49575 1.06412 L F
.48241 1.07425 m .48226 1.07569 L .48414 1.07185 L .516 .147 .278 r
F
.49657 1.06174 m .49961 1.05879 L .51611 1.04493 L 0 0 0 r
F
.49657 1.06174 m .51611 1.04493 L .55113 1.01552 L F
.51423 1.03302 m .4898 1.06358 L .53545 1.023 L F
.4898 1.06358 m .48566 1.06876 L .48743 1.06714 L F
.4898 1.06358 m .48743 1.06714 L .53545 1.023 L F
.48743 1.06714 m .48566 1.06876 L .48657 1.06847 L .827 .998 .78 r
F
.4898 1.06358 m .48159 1.07446 L .48566 1.06876 L 0 0 0 r
F
.51423 1.03302 m .48607 1.06878 L .4898 1.06358 L F
.48607 1.06878 m .48159 1.07446 L .4898 1.06358 L F
.48897 1.06517 m .48572 1.06925 L .51423 1.03302 L F
.48572 1.06925 m .48159 1.07446 L .48607 1.06878 L F
.48572 1.06925 m .48607 1.06878 L .51423 1.03302 L F
.5127 1.02938 m .5132 1.02878 L .53515 .98746 L .865 .833 .813 r
F
.5132 1.02878 m .52911 1.01017 L .53491 .98834 L F
.5132 1.02878 m .53491 .98834 L .53515 .98746 L F
.46314 1.04102 m .4649 1.0442 L .46766 1.04852 L .613 .046 0 r
F
.47467 1.05755 m .47395 1.05897 L .47463 1.05794 L .685 .415 .508 r
F
.48118 1.03088 m .47709 1.05939 L .49409 1.02509 L .938 .694 .543 r
F
.47701 1.04797 m .47709 1.05939 L .48118 1.03088 L F
.46892 1.03304 m .49409 1.02509 L .48514 1.00508 L .864 .65 .611 r
F
.48118 1.03088 m .46645 1.0373 L .47467 1.05755 L .685 .415 .508 r
F
.47048 1.03277 m .46645 1.0373 L .48118 1.03088 L F
.46645 1.0373 m .46314 1.04102 L .46377 1.04192 L F
.46645 1.0373 m .46377 1.04192 L .47467 1.05755 L F
.46918 1.033 m .49409 1.02509 L .46892 1.03304 L .938 .694 .543 r
F
.48118 1.03088 m .48441 1.02943 L .46918 1.033 L F
.48441 1.02943 m .49409 1.02509 L .46918 1.033 L F
.48514 1.00508 m .49409 1.02509 L .50958 .98603 L .864 .65 .611 r
F
.46733 1.03343 m .46672 1.03342 L .46314 1.04102 L .439 .15 .376 r
F
.46733 1.03343 m .46314 1.04102 L .46918 1.033 L F
.49508 .99854 m .46918 1.033 L .50909 .98932 L .685 .415 .508 r
F
.46918 1.033 m .46314 1.04102 L .47048 1.03277 L F
.46918 1.033 m .47048 1.03277 L .50909 .98932 L F
.46821 1.01429 m .50958 .98603 L .5003 .96583 L .785 .573 .614 r
F
.49413 .97515 m .45864 1.02875 L .46031 1.03332 L .439 .15 .376 r
F
.46672 1.03342 m .46031 1.03332 L .46314 1.04102 L F
.49413 .97515 m .46031 1.03332 L .46672 1.03342 L F
.48118 1.03088 m .46892 1.03304 L .46768 1.03343 L .938 .694 .543 r
F
.45749 1.03747 m .4582 1.03643 L .45524 1.03737 L F
.45531 1.03808 m .45524 1.03737 L .43583 1.0435 L F
.45749 1.03747 m .45524 1.03737 L .45531 1.03808 L F
.47463 1.05794 m .47395 1.05897 L .47514 1.06145 L .862 .644 .606 r
F
.47467 1.05755 m .46314 1.04102 L .47382 1.05875 L .685 .415 .508 r
F
.47467 1.05755 m .47382 1.05875 L .47404 1.05879 L F
.4738 1.05875 m .47709 1.05939 L .4674 1.04673 L .938 .694 .543 r
F
.46314 1.04102 m .45551 1.04038 L .45751 1.043 L .613 .046 0 r
F
.46314 1.04102 m .45751 1.043 L .46602 1.04621 L F
.46031 1.03332 m .4582 1.03643 L .46314 1.04102 L .352 0 0 r
F
.4582 1.03643 m .45551 1.04038 L .46273 1.04099 L F
.4582 1.03643 m .46273 1.04099 L .46314 1.04102 L F
.43583 1.0435 m .4582 1.03643 L .4524 1.03059 L .864 .65 .611 r
F
.47485 1.05895 m .47514 1.06145 L .47564 1.06249 L .862 .644 .606 r
F
.47463 1.05794 m .47477 1.05894 L .47485 1.05895 L F
.47477 1.05894 m .47514 1.06145 L .47485 1.05895 L F
.47103 1.05412 m .47156 1.05514 L .47381 1.05875 L .613 .046 0 r
F
.47382 1.05875 m .47381 1.05875 L .47395 1.05897 L F
.47103 1.05412 m .47381 1.05875 L .47382 1.05875 L F
.44868 1.05393 m .47367 1.05873 L .43553 1.05135 L .951 .614 .21 r
F
.47367 1.05873 m .476 1.05918 L .47376 1.05874 L F
.47367 1.05873 m .47376 1.05874 L .43553 1.05135 L F
.48164 1.07506 m .4817 1.07517 L .48293 1.07335 L .619 .823 .419 r
F
.48138 1.07541 m .48157 1.07527 L .48164 1.07506 L F
.48157 1.07527 m .4817 1.07517 L .48164 1.07506 L F
.47686 1.06001 m .47485 1.05895 L .47537 1.06128 L .862 .644 .606 r
F
.47698 1.06031 m .47537 1.06128 L .47564 1.06249 L F
.4775 1.05947 m .47537 1.06128 L .47698 1.06031 L F
.50191 1.04164 m .48095 1.07035 L .48262 1.07279 L .923 .957 .632 r
F
.49379 1.0506 m .48095 1.07034 L .49393 1.05054 L .862 .644 .606 r
F
.49393 1.05053 m .4948 1.04957 L .4899 1.05252 L .619 .823 .419 r
F
.48095 1.07034 m .48095 1.07035 L .49393 1.05053 L .862 .644 .606 r
F
.4954 1.04435 m .5127 1.02938 L .49446 1.04474 L .619 .823 .419 r
F
.50191 1.04164 m .48159 1.07446 L .502 1.0416 L .923 .957 .632 r
F
.49415 1.05029 m .48095 1.07035 L .50191 1.04164 L F
.50178 1.04169 m .5127 1.02938 L .4954 1.04435 L .619 .823 .419 r
F
.5215 1.02383 m .55428 1.00734 L .56416 .99696 L .865 .833 .813 r
F
.5127 1.02938 m .52024 1.02538 L .5215 1.02383 L F
.52024 1.02538 m .55428 1.00734 L .5215 1.02383 L F
.54579 1.0144 m .49006 1.06735 L .55661 1.00541 L .827 .998 .78 r
F
.53545 1.023 m .48743 1.06714 L .54579 1.0144 L F
.48805 1.06579 m .55021 1.01073 L .49331 1.05802 L 0 0 0 r
F
.50093 1.05708 m .55021 1.01073 L .48805 1.06579 L F
.51534 1.03162 m .55021 1.01073 L .51993 1.02578 L F
.49331 1.05802 m .53545 1.023 L .50834 1.03581 L F
.53545 1.023 m .55021 1.01073 L .50834 1.03581 L F
.55661 1.00541 m .55235 1.00938 L .54032 1.02201 L .827 .998 .78 r
F
.55235 1.00938 m .49006 1.06735 L .54032 1.02201 L F
.57524 .98642 m .54032 1.02201 L .57874 .98711 L F
.56689 1.00244 m .55952 1.00457 L .5127 1.02938 L 0 0 0 r
F
.57524 .98642 m .56434 .99678 L .55661 1.00541 L .827 .998 .78 r
F
.5127 1.02938 m .56416 .99696 L .56622 .9948 L .865 .833 .813 r
F
.56434 .99678 m .54579 1.0144 L .55428 1.00734 L .827 .998 .78 r
F
.56434 .99678 m .55428 1.00734 L .55661 1.00541 L F
.56434 .99678 m .53545 1.023 L .54579 1.0144 L F
.57524 .98642 m .56691 .99408 L .56434 .99678 L F
.5127 1.02938 m .57115 .99162 L .51922 1.02175 L .865 .833 .813 r
F
.56691 .99408 m .53545 1.023 L .56434 .99678 L .827 .998 .78 r
F
.55282 .98478 m .52675 1.01738 L .57524 .98642 L 0 0 0 r
F
.52675 1.01738 m .55987 .99816 L .57524 .98642 L F
.55282 .98478 m .53456 1.00776 L .52675 1.01738 L F
.51423 1.03302 m .53545 1.023 L .56691 .99408 L F
.55987 .99816 m .56691 .99408 L .57524 .98642 L F
.51423 1.03302 m .56691 .99408 L .55987 .99816 L F
.52911 1.01017 m .53456 1.00776 L .55282 .98478 L .923 .957 .632 r
F
.62296 .90563 m .71227 .77959 L .71386 .7626 L 0 0 .167 r
F
.6197 .92152 m .71227 .77959 L .62296 .90563 L .69 .882 .501 r
F
.58792 .9475 m .6702 .82323 L .60707 .93584 L .827 .822 .844 r
F
.58792 .9475 m .63799 .84193 L .6702 .82323 L F
.56546 .95595 m .63799 .84193 L .58792 .9475 L .779 .728 .806 r
F
.59759 .93001 m .58527 .96473 L .61297 .912 L .865 .833 .813 r
F
.59202 .93209 m .61297 .912 L .5863 .93423 L F
.56546 .95595 m .6042 .85516 L .63799 .84193 L .779 .728 .806 r
F
.54269 .96146 m .6042 .85516 L .56546 .95595 L .765 .681 .77 r
F
.5863 .93423 m .61297 .912 L .59807 .87343 L .743 .672 .782 r
F
.58934 .93309 m .57524 .98642 L .58605 .96208 L .782 .709 .783 r
F
.59727 .86316 m .58445 .93492 L .58934 .93309 L F
.58445 .93492 m .57524 .98642 L .58934 .93309 L F
.58934 .93309 m .58605 .96208 L .59759 .93001 L F
.512 1.03039 m .5127 1.02938 L .4948 1.04957 L .619 .823 .419 r
F
.49409 1.02509 m .52468 .99123 L .50841 .99452 L .851 .705 .7 r
F
.52468 .99123 m .52676 .98893 L .52174 .99046 L F
.52468 .99123 m .52174 .99046 L .50841 .99452 L F
.47642 1.05655 m .47709 1.05939 L .47706 1.05556 L .938 .694 .543 r
F
.47642 1.05655 m .47706 1.05556 L .47689 1.0328 L F
.47521 1.05149 m .47642 1.05655 L .47689 1.0328 L F
.47431 1.05576 m .47709 1.05939 L .47135 1.03529 L F
.52997 .97441 m .51969 .98992 L .51983 .98996 L .862 .644 .606 r
F
.50841 .99452 m .52049 .99013 L .50905 .99316 L .851 .705 .7 r
F
.52997 .97441 m .51983 .98996 L .5203 .99008 L .862 .644 .606 r
F
.52049 .99013 m .51969 .98992 L .50905 .99316 L .851 .705 .7 r
F
.4948 1.04957 m .50178 1.04169 L .48247 1.05618 L .619 .823 .419 r
F
.4899 1.05252 m .48247 1.05618 L .47696 1.06032 L F
.4948 1.04957 m .48247 1.05618 L .4899 1.05252 L F
.52174 .99046 m .50648 1.02021 L .53087 .98768 L .862 .644 .606 r
F
.53165 .98744 m .5024 1.02816 L .53569 .98621 L F
.51156 1.0103 m .48535 1.04838 L .5024 1.02816 L F
.5024 1.02816 m .5324 .99258 L .53607 .98574 L .963 .919 .714 r
F
.53757 .98405 m .53491 .98834 L .53898 .98206 L .923 .957 .632 r
F
.47709 1.05939 m .5324 .99258 L .48535 1.04838 L .963 .919 .714 r
F
.53491 .98834 m .50191 1.04164 L .53479 .98879 L .923 .957 .632 r
F
.53491 .98834 m .53479 .98879 L .53898 .98206 L F
.502 1.0416 m .4862 1.06704 L .48757 1.06611 L F
.502 1.0416 m .48572 1.06925 L .50516 1.04028 L F
.50156 1.0455 m .50516 1.04028 L .4948 1.04957 L .619 .823 .419 r
F
.50516 1.04028 m .512 1.03039 L .50191 1.04164 L F
.50516 1.04028 m .50191 1.04164 L .4948 1.04957 L F
.50191 1.04164 m .502 1.0416 L .53898 .98206 L .923 .957 .632 r
F
.53882 .98203 m .53594 .98642 L .53491 .98834 L F
.53515 .98746 m .53226 1.00648 L .53607 .98574 L .865 .833 .813 r
F
.53654 .98315 m .53617 .98606 L .53882 .98203 L .862 .644 .606 r
F
.52174 .99046 m .536 .98612 L .53654 .98315 L F
.536 .98612 m .53617 .98606 L .53654 .98315 L F
.54013 .9777 m .53882 .98203 L .53898 .98206 L .783 .681 .752 r
F
.54075 .97699 m .55474 .96105 L .54541 .9683 L .865 .833 .813 r
F
.54238 .97234 m .54226 .97268 L .54541 .9683 L .963 .919 .714 r
F
.54131 .97323 m .5399 .97797 L .54013 .9777 L .783 .681 .752 r
F
.54111 .9734 m .5399 .97797 L .54131 .97323 L F
.54238 .97234 m .54541 .9683 L .54049 .97374 L .963 .919 .714 r
F
.53947 .9743 m .53913 .97832 L .54047 .97498 L .731 .611 .724 r
F
.53947 .9743 m .54047 .97498 L .54049 .97374 L F
.54049 .97374 m .54047 .97498 L .54111 .9734 L F
.53913 .97832 m .5399 .97797 L .54111 .9734 L F
.54049 .97374 m .54541 .9683 L .54052 .97164 L .851 .705 .7 r
F
.54238 .97234 m .54049 .97374 L .54111 .9734 L .963 .919 .714 r
F
.54845 .91156 m .55476 .92521 L .54461 .90978 L .711 .597 .727 r
F
.54893 .91179 m .55689 .92845 L .55476 .92521 L F
.54962 .91211 m .55689 .92845 L .54893 .91179 L F
.54845 .91156 m .54579 .8669 L .57259 .86293 L .78 .671 .743 r
F
.54461 .90978 m .55689 .92845 L .52987 .95444 L .797 .714 .772 r
F
.55244 .91342 m .55689 .92845 L .54973 .91216 L .711 .597 .727 r
F
.54973 .91216 m .55689 .92845 L .54962 .91211 L F
.54968 .91214 m .57259 .86293 L .56858 .87614 L .78 .671 .743 r
F
.54845 .91156 m .57259 .86293 L .54968 .91214 L F
.57329 .84819 m .57409 .84853 L .57109 .85662 L .711 .597 .727 r
F
.57259 .86293 m .57109 .85662 L .57342 .84838 L .569 .453 .682 r
F
.54579 .8669 m .54764 .83915 L .57259 .86293 L .599 .432 .627 r
F
.54764 .83915 m .55803 .84689 L .57259 .86293 L F
.57173 .85795 m .5542 .92436 L .56383 .91094 L .783 .681 .752 r
F
.54541 .9683 m .54986 .94982 L .55091 .90382 L .743 .672 .782 r
F
.54986 .94982 m .55437 .9234 L .55091 .90382 L F
.56325 .85544 m .56022 .87867 L .57173 .85795 L .731 .611 .724 r
F
.56022 .87867 m .55507 .91802 L .56629 .87755 L F
.56022 .87867 m .56629 .87755 L .57173 .85795 L F
.54143 .89638 m .54579 .8669 L .54845 .91156 L .78 .671 .743 r
F
.53588 .89121 m .54579 .8669 L .53959 .8924 L .827 .699 .724 r
F
.55091 .90382 m .55619 .88956 L .54099 .88222 L .635 .606 .803 r
F
.55619 .88956 m .56022 .87867 L .54727 .88106 L F
.55619 .88956 m .54727 .88106 L .54099 .88222 L F
.54845 .91156 m .54606 .91046 L .54223 .90322 L .711 .597 .727 r
F
.5412 .92454 m .54541 .9683 L .55091 .90382 L .851 .705 .7 r
F
.54101 .93808 m .54541 .9683 L .5412 .92454 L F
.54112 .97123 m .54541 .9683 L .54101 .93808 L F
.5407 .95963 m .54101 .93808 L .53955 .92807 L F
.54112 .97123 m .54101 .93808 L .5407 .95963 L F
.53947 .9743 m .54049 .97374 L .54054 .97043 L .731 .611 .724 r
F
.5407 .95963 m .53947 .9743 L .54054 .97043 L F
.5407 .95963 m .52997 .97441 L .53882 .98203 L F
.53955 .92807 m .52997 .97441 L .5407 .95963 L F
.52993 .94524 m .52353 .9607 L .52997 .97441 L .58 .472 .695 r
F
.54223 .90322 m .54461 .90978 L .52564 .88094 L .711 .597 .727 r
F
.53588 .89121 m .52647 .87171 L .54579 .8669 L .827 .699 .724 r
F
.52647 .87171 m .52538 .86946 L .52872 .86904 L F
.52647 .87171 m .52872 .86904 L .54579 .8669 L F
.52574 .87206 m .52538 .86946 L .53588 .89121 L F
.5259 .87238 m .54223 .90322 L .52564 .88094 L .711 .597 .727 r
F
.53146 .88979 m .53023 .90504 L .52852 .9039 L .797 .714 .772 r
F
.53146 .88979 m .53314 .93956 L .52714 .94354 L F
.52843 .86795 m .52852 .86625 L .52872 .86904 L .667 .445 .573 r
F
.52547 .85649 m .52852 .86625 L .52843 .86795 L F
.52547 .85649 m .52569 .8251 L .52852 .86625 L F
.52872 .86904 m .5276 .85281 L .54579 .8669 L F
.51655 .82193 m .5263 .85968 L .52607 .86696 L .692 .491 .611 r
F
.51655 .82193 m .52607 .86696 L .52425 .86346 L F
.52538 .86946 m .52547 .85649 L .52872 .86904 L .667 .445 .573 r
F
.55437 .9234 m .56022 .87867 L .55091 .90382 L .743 .672 .782 r
F
.54975 .85145 m .54623 .89354 L .55384 .90262 L .731 .611 .724 r
F
.52727 .82848 m .53028 .83865 L .5263 .85968 L .711 .597 .727 r
F
.51655 .82193 m .52727 .82848 L .5263 .85968 L .692 .491 .611 r
F
.55091 .90382 m .54099 .88222 L .52642 .85088 L .635 .606 .803 r
F
.5412 .92454 m .55091 .90382 L .53567 .93414 L .851 .705 .7 r
F
.54606 .91046 m .54461 .90978 L .54223 .90322 L .711 .597 .727 r
F
.52327 .87664 m .52439 .87418 L .52377 .87709 L .915 .784 .702 r
F
.52333 .87673 m .52564 .88094 L .52234 .8758 L .692 .491 .611 r
F
.52333 .87673 m .52234 .8758 L .52304 .87643 L F
.52327 .87664 m .52333 .87673 L .52322 .87659 L F
.52327 .87664 m .52538 .86946 L .52439 .87418 L .915 .784 .702 r
F
.52377 .87709 m .52439 .87418 L .52532 .87911 L .827 .699 .724 r
F
.52289 .87594 m .52456 .87396 L .52564 .88094 L .692 .491 .611 r
F
.52304 .87643 m .52538 .86946 L .52327 .87664 L .915 .784 .702 r
F
.52304 .87643 m .5221 .87542 L .52528 .86976 L F
.52528 .86976 m .51231 .8731 L .52538 .86946 L F
.52564 .88094 m .52035 .89847 L .50967 .93188 L .797 .714 .772 r
F
.52439 .87418 m .52509 .87084 L .52541 .87296 L .827 .699 .724 r
F
.52509 .87084 m .52538 .86946 L .52574 .87206 L F
.52083 .87073 m .51702 .84956 L .52538 .86946 L .764 .478 .501 r
F
.51702 .84956 m .52177 .85869 L .52538 .86946 L F
.52456 .87396 m .5259 .87238 L .52564 .88094 L .692 .491 .611 r
F
.52177 .85869 m .52217 .85845 L .5224 .85989 L F
.52538 .86946 m .52177 .85869 L .52547 .85649 L .667 .445 .573 r
F
.46633 .99048 m .47157 .9885 L .46634 .99041 L .335 0 .007 r
F
.47437 .98481 m .47157 .9885 L .47515 .9845 L F
.3923 1.0174 m .47114 .98866 L .47342 .98519 L F
.43716 1.0015 m .46633 .99048 L .43519 1.00177 L F
.46633 .99048 m .46634 .99041 L .43519 1.00177 L F
.43716 1.0015 m .43519 1.00177 L .42501 1.00548 L F
.39779 1.01637 m .42834 1.00483 L .40745 1.01188 L F
.42834 1.00483 m .42501 1.00548 L .40745 1.01188 L F
.39779 1.01637 m .40745 1.01188 L .3923 1.0174 L F
.36751 1.0242 m .39779 1.01637 L .37547 1.0248 L .565 .163 .238 r
F
.3923 1.0174 m .41476 1.00848 L .45245 .99097 L .335 0 .007 r
F
.3899 1.01189 m .39677 1.01385 L .39249 1.01257 L .68 .155 0 r
F
.45281 .9908 m .38344 1.02304 L .36751 1.0242 L .726 .979 .917 r
F
.41476 1.00848 m .47515 .9845 L .45245 .99097 L .335 0 .007 r
F
.36751 1.0242 m .46674 .99016 L .39779 1.01637 L .565 .163 .238 r
F
.46674 .99016 m .46633 .99048 L .39779 1.01637 L F
.38123 1.02095 m .4535 1.01632 L .46299 1.00142 L .677 .294 .313 r
F
.46299 1.00142 m .3808 1.02103 L .38197 1.02075 L 0 0 0 r
F
.40182 1.01605 m .38197 1.02075 L .39537 1.01759 L F
.44784 1.00505 m .43853 1.00727 L .40182 1.01605 L F
.39599 1.01745 m .4535 1.01632 L .38123 1.02095 L .746 .346 .294 r
F
.37959 1.02137 m .44352 1.03116 L .39599 1.01745 L F
.39599 1.01745 m .44352 1.03116 L .4535 1.01632 L F
.45589 1.01235 m .40445 1.01877 L .44945 1.02225 L 0 0 0 r
F
.42681 1.01007 m .38197 1.02075 L .40182 1.01605 L F
.43306 1.00857 m .38197 1.02075 L .42681 1.01007 L F
.44784 1.00505 m .39537 1.01759 L .40596 1.01508 L F
.46299 1.00142 m .38197 1.02075 L .44784 1.00505 L F
.3808 1.02103 m .36751 1.0242 L .40117 1.01623 L F
.47114 .98866 m .47157 .9885 L .47342 .98519 L .335 0 .007 r
F
.46674 .99016 m .47157 .9885 L .46633 .99048 L .565 .163 .238 r
F
.37861 1.02039 m .46299 1.00142 L .47157 .9885 L F
.36751 1.0242 m .3808 1.02103 L .37861 1.02039 L F
.3808 1.02103 m .46299 1.00142 L .37861 1.02039 L F
.37738 1.01985 m .37897 1.01971 L .36751 1.0242 L .726 .979 .917 r
F
.46999 .98326 m .47515 .9845 L .48033 .97872 L .335 0 .007 r
F
.47317 .98361 m .47351 .9826 L .47877 .97717 L .127 0 .358 r
F
.44274 .99106 m .37897 1.01971 L .37738 1.01985 L .726 .979 .917 r
F
.47294 .97776 m .44185 .99164 L .44274 .99106 L F
.44185 .99164 m .37897 1.01971 L .44274 .99106 L F
.47294 .97776 m .46443 .98625 L .37897 1.01971 L F
.47792 .97557 m .46443 .98625 L .47294 .97776 L F
.47833 .9758 m .46535 .98589 L .47792 .97557 L F
.4792 .97628 m .47858 .97672 L .47833 .9758 L F
.47858 .97672 m .46535 .98589 L .47833 .9758 L F
.47792 .97557 m .47499 .97686 L .47485 .9775 L F
.47499 .97686 m .38793 1.01521 L .47485 .9775 L F
.45245 .99097 m .46999 .98326 L .46075 .98774 L .335 0 .007 r
F
.47485 .9775 m .38793 1.01521 L .38945 1.01493 L .726 .979 .917 r
F
.46535 .98589 m .46517 .98602 L .46484 .98614 L F
.46999 .98326 m .4655 .98583 L .46484 .98614 L .335 0 .007 r
F
.46999 .98326 m .46484 .98614 L .46075 .98774 L F
.45245 .99097 m .47515 .9845 L .46999 .98326 L F
.46718 .98232 m .38945 1.01493 L .42594 1.00823 L .726 .979 .917 r
F
.47485 .9775 m .38945 1.01493 L .46718 .98232 L F
.47792 .97557 m .46793 .98378 L .46703 .9842 L F
.47351 .9826 m .42594 1.00823 L .47264 .98397 L F
.47792 .97557 m .47304 .97863 L .47351 .9826 L F
.47304 .97863 m .42594 1.00823 L .47351 .9826 L F
.47351 .9826 m .47657 .975 L .47762 .97604 L .127 0 .358 r
F
.47614 .97458 m .48075 .97715 L .48033 .97872 L F
.47351 .9826 m .47714 .97357 L .47614 .97458 L F
.47317 .98361 m .47352 .98273 L .47351 .9826 L F
.47351 .9826 m .47762 .97604 L .47877 .97717 L F
.47317 .98361 m .47877 .97717 L .47682 .98111 L F
.47342 .98519 m .47157 .9885 L .47437 .98481 L .335 0 .007 r
F
.47157 .9885 m .47317 .98361 L .48033 .97872 L .127 0 .358 r
F
.47157 .9885 m .47353 .9835 L .47317 .98361 L F
.47356 .98311 m .46152 1.00169 L .46299 1.00142 L .726 .979 .917 r
F
.47792 .97557 m .47351 .9826 L .47356 .98311 L F
.47359 .98334 m .47352 .98273 L .47317 .98361 L .127 0 .358 r
F
.47351 .9826 m .46152 1.00169 L .47356 .98311 L .726 .979 .917 r
F
.47353 .9835 m .47359 .98334 L .47317 .98361 L .127 0 .358 r
F
.48426 .97278 m .4792 .97628 L .47792 .97557 L .726 .979 .917 r
F
.47823 .97543 m .47792 .97557 L .46299 1.00142 L F
.46714 .99434 m .47359 .98334 L .47157 .9885 L .538 .333 .551 r
F
.50307 .90558 m .49862 .92148 L .49216 .93597 L .981 .91 .65 r
F
.47359 .98334 m .50047 .91476 L .47352 .98273 L .127 0 .358 r
F
.50047 .91476 m .50859 .89405 L .50035 .91488 L F
.50047 .91476 m .50035 .91488 L .47352 .98273 L F
.47264 .98397 m .42594 1.00823 L .46152 1.00169 L .726 .979 .917 r
F
.49595 .92542 m .50307 .90558 L .49455 .91841 L .127 0 .358 r
F
.47714 .97357 m .50859 .89405 L .47614 .97458 L F
.50307 .90558 m .49216 .93597 L .46299 1.00142 L .981 .91 .65 r
F
.47659 .96939 m .49966 .91509 L .49216 .93597 L .538 .333 .551 r
F
.49595 .92542 m .5053 .90223 L .50307 .90558 L .127 0 .358 r
F
.49966 .91509 m .50177 .91012 L .49216 .93597 L .538 .333 .551 r
F
.50177 .91012 m .50314 .90688 L .50047 .91476 L F
.50314 .90688 m .50859 .89405 L .5024 .90985 L F
.50314 .90688 m .5024 .90985 L .50047 .91476 L F
.50177 .91012 m .50047 .91476 L .49216 .93597 L F
.46299 1.00142 m .46473 .99753 L .47157 .9885 L F
.47682 .98111 m .47877 .97717 L .48033 .97872 L .127 0 .358 r
F
.48426 .97278 m .47823 .97543 L .46299 1.00142 L .726 .979 .917 r
F
.47685 .97033 m .49216 .93597 L .4776 .97311 L .538 .333 .551 r
F
.47352 .98273 m .47714 .97357 L .47351 .9826 L .127 0 .358 r
F
.46454 .99777 m .47659 .96939 L .47359 .98334 L .538 .333 .551 r
F
.47659 .96939 m .4776 .97311 L .47359 .98334 L F
.46454 .99777 m .47359 .98334 L .46714 .99434 L F
.49216 .93597 m .47398 .98663 L .46299 1.00142 L .981 .91 .65 r
F
.49216 .93597 m .48426 .97278 L .47398 .98663 L F
.49862 .92148 m .48426 .97278 L .49216 .93597 L F
.47659 .96939 m .49216 .93597 L .47685 .97033 L .538 .333 .551 r
F
.4933 .93006 m .51355 .91641 L .50859 .89405 L F
.49984 .9312 m .51355 .91641 L .4933 .93006 L F
.49779 .94257 m .51355 .91641 L .48688 .94517 L F
.50585 .88872 m .49839 .90311 L .50697 .89166 L .891 .724 .667 r
F
.50684 .89171 m .50307 .90558 L .50139 .9096 L .981 .91 .65 r
F
.50725 .8914 m .50713 .89109 L .50644 .88981 L 0 0 .408 r
F
.5073 .89153 m .50644 .88981 L .50585 .88872 L F
.50859 .89405 m .50725 .8914 L .5073 .89153 L F
.50725 .8914 m .50644 .88981 L .5073 .89153 L F
.49579 .86909 m .49494 .86744 L .50383 .87657 L F
.49494 .86743 m .4999 .87018 L .50383 .87657 L F
.50786 .88774 m .503 .87349 L .50701 .88039 L F
.50859 .89405 m .503 .87349 L .50786 .88774 L F
.49856 .86944 m .50697 .89166 L .50714 .89105 L .891 .724 .667 r
F
.50445 .88042 m .50714 .89105 L .50817 .88736 L F
.49856 .86944 m .50714 .89105 L .50445 .88042 L F
.51355 .91641 m .51352 .91631 L .50859 .89405 L .325 .323 .703 r
F
.50662 .89127 m .50139 .9096 L .50214 .9026 L .981 .91 .65 r
F
.50671 .89123 m .50139 .9096 L .50662 .89127 L F
.50644 .88981 m .50232 .88137 L .50273 .88248 L 0 0 .408 r
F
.50232 .88137 m .49835 .87325 L .50273 .88248 L F
.50323 .88384 m .49839 .90311 L .50585 .88872 L .891 .724 .667 r
F
.50716 .89115 m .49835 .87325 L .50644 .88981 L 0 0 .408 r
F
.50292 .883 m .49472 .86668 L .49579 .86909 L F
.50585 .88872 m .50279 .88266 L .50292 .883 L F
.50279 .88266 m .49472 .86668 L .50292 .883 L F
.50644 .88981 m .49472 .86668 L .50585 .88872 L F
.49853 .8751 m .49288 .91046 L .49839 .90311 L .891 .724 .667 r
F
.49793 .87398 m .49288 .91046 L .49853 .8751 L F
.49579 .86909 m .48415 .84601 L .47656 .83154 L 0 0 .408 r
F
.47603 .83176 m .47656 .83154 L .47738 .83311 L .759 .44 .445 r
F
.47656 .83154 m .49028 .82572 L .47738 .83311 L F
.47738 .83311 m .50043 .85597 L .47506 .82767 L F
.4716 .81958 m .46514 .80848 L .4685 .80977 L .884 .508 .322 r
F
.49498 .86657 m .49596 .86466 L .49754 .8706 L .847 .538 .465 r
F
.47558 .8289 m .4721 .8212 L .46256 .80319 L 0 0 .408 r
F
.47024 .81643 m .46507 .80566 L .47558 .8289 L F
.47738 .83311 m .46256 .80319 L .47456 .82772 L F
.47593 .82972 m .46256 .80319 L .47738 .83311 L F
.42608 .79964 m .43562 .79949 L .46139 .80205 L 0 .521 .831 r
F
.44763 .80062 m .45289 .80196 L .43376 .78981 L .653 .302 .365 r
F
.46029 .80444 m .45324 .80383 L .44894 .80155 L 0 .521 .831 r
F
.45851 .80465 m .45324 .80383 L .46029 .80444 L F
.47058 .81818 m .46507 .80566 L .46347 .80408 L 0 0 .408 r
F
.4721 .8212 m .46964 .81577 L .47058 .81818 L F
.46964 .81577 m .46507 .80566 L .47058 .81818 L F
.45085 .80059 m .45096 .80062 L .44936 .79875 L .759 .44 .445 r
F
.45259 .80198 m .44923 .80149 L .45024 .80128 L 0 .521 .831 r
F
.4721 .8212 m .46347 .80408 L .46256 .80319 L 0 0 .408 r
F
.47558 .8289 m .46256 .80319 L .47593 .82972 L F
.46507 .80566 m .45136 .80206 L .45259 .80198 L 0 .521 .831 r
F
.45136 .80206 m .44923 .80149 L .45259 .80198 L F
.4426 .79928 m .44285 .79938 L .44277 .79938 L .653 .302 .365 r
F
.4426 .79928 m .44277 .79938 L .44763 .80062 L F
.46507 .80566 m .45024 .80128 L .46426 .80486 L 0 .521 .831 r
F
.44763 .80062 m .4138 .79711 L .43406 .79702 L .217 0 0 r
F
.43376 .78981 m .45289 .80196 L .44641 .80236 L .759 .44 .445 r
F
.45153 .80143 m .45372 .80387 L .45096 .80062 L F
.45372 .80387 m .45395 .80389 L .44936 .79875 L F
.45851 .80465 m .45585 .80404 L .45356 .80388 L 0 .521 .831 r
F
.45585 .80404 m .45349 .80385 L .45356 .80388 L F
.47456 .82772 m .47656 .83154 L .47603 .83176 L .759 .44 .445 r
F
.36488 .85304 m .46011 .81529 L .43608 .80286 L .82 .851 .871 r
F
.3803 .87371 m .46011 .81529 L .36488 .85304 L .809 .74 .788 r
F
.44743 .80337 m .46706 .81341 L .47603 .83176 L .759 .44 .445 r
F
.44905 .80386 m .46706 .81341 L .44743 .80337 L F
.46706 .81341 m .47456 .82772 L .47603 .83176 L F
.47738 .83311 m .47506 .82767 L .45372 .80387 L F
.45351 .80385 m .45372 .80387 L .45153 .80143 L F
.47506 .82767 m .50043 .85597 L .47495 .82742 L F
.49472 .86668 m .47558 .8289 L .49579 .86909 L 0 0 .408 r
F
.47558 .8289 m .47593 .82972 L .49579 .86909 L F
.47738 .83311 m .45372 .80387 L .45351 .80385 L .759 .44 .445 r
F
.47603 .83176 m .47738 .83311 L .45351 .80385 L F
.47603 .83176 m .45351 .80385 L .45349 .80385 L F
.45372 .80387 m .47506 .82767 L .45395 .80389 L F
.47506 .82767 m .47495 .82742 L .45395 .80389 L F
.48725 .85194 m .48056 .83797 L .47558 .8289 L 0 0 .408 r
F
.49617 .86312 m .48377 .84134 L .49507 .86019 L F
.45701 .80413 m .45585 .80404 L .45851 .80465 L 0 .521 .831 r
F
.46426 .80486 m .45289 .80196 L .46139 .80205 L F
.44585 .79439 m .45428 .80392 L .45026 .79607 L .759 .44 .445 r
F
.47238 .82346 m .46479 .80781 L .46504 .80915 L 0 0 .408 r
F
.45428 .80392 m .50043 .85597 L .45701 .80413 L .759 .44 .445 r
F
.45428 .80392 m .45701 .80413 L .45026 .79607 L F
.46507 .80566 m .45851 .80465 L .46029 .80444 L 0 .521 .831 r
F
.46507 .80566 m .45725 .80415 L .45851 .80465 L F
.45725 .80415 m .45683 .80407 L .45701 .80413 L F
.45725 .80415 m .45701 .80413 L .45851 .80465 L F
.44936 .79875 m .45395 .80389 L .44585 .79439 L .759 .44 .445 r
F
.45395 .80389 m .50043 .85597 L .45428 .80392 L F
.45395 .80389 m .45428 .80392 L .44585 .79439 L F
.43376 .78981 m .44641 .80236 L .44524 .79593 L F
.45349 .80385 m .45351 .80385 L .45153 .80143 L F
.45356 .80127 m .45701 .80413 L .45492 .80341 L .847 .538 .465 r
F
.45026 .79607 m .45454 .80118 L .45356 .80127 L F
.45454 .80118 m .45701 .80413 L .45356 .80127 L F
.48056 .83797 m .4733 .82358 L .47558 .8289 L 0 0 .408 r
F
.49336 .86398 m .49076 .85862 L .48725 .85194 L F
.4733 .82358 m .50043 .85597 L .49498 .86657 L .847 .538 .465 r
F
.49076 .85862 m .4736 .82325 L .48725 .85194 L 0 0 .408 r
F
.4736 .82325 m .46507 .80566 L .474 .82428 L F
.4736 .82325 m .474 .82428 L .48725 .85194 L F
.45589 .80495 m .4733 .82358 L .47508 .82711 L .847 .538 .465 r
F
.49903 .87491 m .48768 .85159 L .49958 .87627 L 0 0 .408 r
F
.50043 .85597 m .49932 .86986 L .49856 .86944 L .891 .724 .667 r
F
.50033 .87042 m .50162 .87113 L .503 .87349 L 0 0 .408 r
F
.50043 .85597 m .49856 .86944 L .50817 .88736 L .891 .724 .667 r
F
.49754 .8706 m .50043 .85597 L .50817 .88736 L .847 .538 .465 r
F
.49596 .86466 m .50043 .85597 L .49754 .8706 L F
.49026 .85682 m .50817 .88736 L .487 .85009 L F
.49498 .86657 m .49754 .8706 L .49026 .85682 L F
.49754 .8706 m .50817 .88736 L .49026 .85682 L F
.49835 .87325 m .49026 .85682 L .49903 .87491 L 0 0 .408 r
F
.49026 .85682 m .48768 .85159 L .49903 .87491 L F
.48768 .85159 m .49012 .85691 L .49958 .87627 L F
.49958 .87627 m .49012 .85691 L .49336 .86398 L F
.49012 .85691 m .46507 .80566 L .49336 .86398 L F
.48415 .84601 m .47593 .82972 L .47738 .83311 L F
.47519 .83093 m .47603 .83176 L .45293 .80377 L .759 .44 .445 r
F
.47519 .83093 m .45293 .80377 L .45288 .80376 L F
.45349 .80385 m .45339 .80384 L .45356 .80388 L 0 .521 .831 r
F
.45356 .80388 m .45339 .80384 L .45324 .80383 L F
.47603 .83176 m .45153 .80143 L .4449 .79404 L .759 .44 .445 r
F
.44743 .80337 m .47519 .83093 L .45292 .80381 L F
.46595 .8208 m .47508 .82711 L .49498 .86657 L .847 .538 .465 r
F
.45589 .80495 m .47508 .82711 L .46595 .8208 L F
.45754 .80476 m .4733 .82358 L .45589 .80495 L F
.4889 .85425 m .48781 .85217 L .49012 .85691 L 0 0 .408 r
F
.48768 .85159 m .48781 .85217 L .4889 .85425 L F
.48768 .85159 m .46507 .80566 L .48781 .85217 L F
.47398 .82601 m .47164 .82066 L .49026 .85682 L .325 .323 .703 r
F
.48056 .83797 m .47024 .81643 L .4733 .82358 L 0 0 .408 r
F
.47164 .82066 m .46507 .80566 L .47315 .82207 L .325 .323 .703 r
F
.47164 .82066 m .47315 .82207 L .49026 .85682 L F
.4793 .81516 m .47851 .81267 L .47884 .8149 L F
.48903 .85719 m .49498 .86657 L .49026 .85682 L .847 .538 .465 r
F
.48735 .85131 m .49026 .85682 L .487 .85009 L F
.48903 .85719 m .49026 .85682 L .48735 .85131 L F
.45356 .80127 m .45492 .80341 L .45908 .80409 L F
.46022 .80438 m .45908 .80409 L .45998 .80437 L 0 .521 .831 r
F
.45288 .80376 m .45293 .80377 L .4449 .79404 L .759 .44 .445 r
F
.44641 .80236 m .45288 .80376 L .4449 .79404 L F
.45908 .80409 m .44173 .79952 L .45869 .80402 L 0 .521 .831 r
F
.45908 .80409 m .45869 .80402 L .45998 .80437 L F
.4677 .82357 m .48903 .85719 L .47789 .82754 L .847 .538 .465 r
F
.50064 .88273 m .49653 .86971 L .49812 .87278 L .325 .323 .703 r
F
.50319 .89273 m .49653 .86971 L .50064 .88273 L F
.48903 .85719 m .48735 .85131 L .48554 .84788 L .847 .538 .465 r
F
.47398 .82601 m .49026 .85682 L .49812 .87278 L .325 .323 .703 r
F
.487 .85009 m .50817 .88736 L .48147 .8308 L .847 .538 .465 r
F
.50339 .89264 m .49812 .87278 L .50712 .89106 L .325 .323 .703 r
F
.50319 .89273 m .49812 .87278 L .50339 .89264 L F
.50708 .89095 m .50139 .9096 L .50692 .89053 L .981 .91 .65 r
F
.50687 .8917 m .50307 .90558 L .50684 .89171 L F
.50713 .89109 m .50307 .90558 L .50708 .89095 L F
.49455 .91841 m .49786 .91266 L .49607 .91377 L .127 0 .358 r
F
.49288 .91046 m .49106 .92367 L .49872 .91213 L .891 .724 .667 r
F
.50214 .9026 m .50139 .9096 L .46299 1.00142 L .981 .91 .65 r
F
.50662 .89127 m .49277 .92625 L .51355 .91641 L F
.51354 .91639 m .50319 .89273 L .50665 .89136 L .325 .323 .703 r
F
.50319 .89273 m .50712 .89106 L .50716 .89115 L F
.5058 .89627 m .5048 .89323 L .50541 .89782 L F
.5048 .89323 m .50382 .89062 L .50541 .89782 L F
.48554 .84788 m .48147 .8308 L .48039 .82851 L .847 .538 .465 r
F
.48554 .84788 m .48039 .82851 L .47815 .82764 L F
.48735 .85131 m .48147 .8308 L .48554 .84788 L F
.50319 .89273 m .47398 .82601 L .49653 .86971 L .325 .323 .703 r
F
.50708 .89095 m .50692 .89153 L .50691 .8915 L .981 .91 .65 r
F
.50692 .89153 m .50687 .8917 L .50691 .8915 L F
.50691 .8915 m .50687 .8917 L .50684 .89171 L F
.51349 .9162 m .50665 .89136 L .50716 .89115 L .325 .323 .703 r
F
.51354 .91639 m .50665 .89136 L .51349 .9162 L F
.50692 .89053 m .50671 .89123 L .50662 .89127 L .981 .91 .65 r
F
.50859 .89405 m .50716 .89115 L .50713 .89109 L 0 0 .408 r
F
.50859 .89405 m .50713 .89109 L .50725 .8914 L F
.51354 .91639 m .50716 .89115 L .50859 .89405 L .325 .323 .703 r
F
.50817 .88736 m .50708 .89095 L .50692 .89053 L .981 .91 .65 r
F
.50817 .88736 m .50713 .89109 L .50708 .89095 L F
.50817 .88736 m .50816 .88738 L .51355 .91641 L F
.50816 .88738 m .50662 .89127 L .51355 .91641 L F
.46869 .99684 m .51582 .94797 L .51355 .91641 L .688 .477 .596 r
F
.51355 .91641 m .50477 .93262 L .51455 .93882 L 0 0 0 r
F
.51541 .9422 m .51471 .94233 L .51355 .91641 L .582 .471 .693 r
F
.51582 .94797 m .51508 .94421 L .51541 .9422 L F
.51508 .94421 m .51471 .94233 L .51541 .9422 L F
.4723 .99571 m .51582 .94797 L .46869 .99684 L .688 .477 .596 r
F
.46544 1.0039 m .48241 .98506 L .46463 1.00412 L .785 .573 .614 r
F
.48241 .98506 m .51582 .94797 L .4723 .99571 L F
.48241 .98506 m .4723 .99571 L .46463 1.00412 L F
.50958 .98603 m .51158 .96998 L .51461 .95538 L .722 .573 .687 r
F
.50985 .98389 m .51728 .96968 L .51693 .96947 L F
.51574 .96959 m .51693 .96947 L .51601 .96891 L F
.50985 .98389 m .51693 .96947 L .51574 .96959 L F
.51461 .95538 m .51202 .96645 L .51582 .94797 L F
.51158 .96998 m .51202 .96645 L .51461 .95538 L F
.51304 .96096 m .5102 .96533 L .51237 .96458 L .439 .15 .376 r
F
.51582 .94797 m .51627 .94385 L .51623 .94381 L .582 .471 .693 r
F
.51508 .94421 m .51623 .94381 L .51471 .94233 L F
.51582 .94797 m .51623 .94381 L .51508 .94421 L F
.51628 .94379 m .51486 .9456 L .51589 .94544 L .439 .15 .376 r
F
.5163 .94372 m .51623 .94381 L .51628 .94379 L F
.51623 .94381 m .51486 .9456 L .51628 .94379 L F
.48807 .97918 m .51582 .94797 L .46544 1.0039 L .785 .573 .614 r
F
.50443 .96108 m .51582 .94797 L .4663 1.00367 L F
.51202 .96645 m .51589 .94544 L .51582 .94797 L .722 .573 .687 r
F
.4663 1.00367 m .48807 .97918 L .46544 1.0039 L .785 .573 .614 r
F
.4663 1.00367 m .49477 .97186 L .51826 .94116 L 0 0 0 r
F
.51589 .94544 m .5164 .94269 L .51628 .94379 L .722 .573 .687 r
F
.51589 .94544 m .51628 .94379 L .51582 .94797 L F
.51589 .94544 m .51486 .9456 L .51447 .94803 L .439 .15 .376 r
F
.51826 .94116 m .5163 .94372 L .51589 .94544 L F
.5102 .96533 m .51651 .96921 L .52353 .9607 L F
.49477 .97186 m .45625 1.02223 L .51123 .95389 L F
.4663 1.00367 m .45625 1.02223 L .49477 .97186 L 0 0 0 r
F
.46774 1.00329 m .50443 .96108 L .4663 1.00367 L .785 .573 .614 r
F
.51447 .94803 m .49477 .97186 L .51123 .95389 L .439 .15 .376 r
F
.51486 .9456 m .49477 .97186 L .51447 .94803 L F
.51355 .91641 m .51455 .93882 L .51826 .94116 L 0 0 0 r
F
.51768 .93863 m .51355 .91641 L .51826 .94116 L .85 .565 .028 r
F
.51355 .91641 m .51354 .91639 L .51352 .91631 L .325 .323 .703 r
F
.48039 .82851 m .50817 .88736 L .51355 .91641 L .941 .624 .408 r
F
.50477 .93262 m .51613 .94371 L .51826 .94116 L 0 0 0 r
F
.51471 .94233 m .51106 .92381 L .51355 .91641 L .582 .471 .693 r
F
.47398 .82601 m .47968 .82823 L .46507 .80566 L .325 .323 .703 r
F
.48113 .83047 m .47341 .81001 L .46507 .80566 L F
.47789 .82754 m .47196 .81065 L .47145 .81039 L .847 .538 .465 r
F
.48554 .84788 m .47815 .82764 L .47789 .82754 L F
.47815 .82764 m .47196 .81065 L .47789 .82754 L F
.48376 .84834 m .48113 .83047 L .47968 .82823 L .325 .323 .703 r
F
.48376 .84834 m .47968 .82823 L .47398 .82601 L F
.48113 .83047 m .47851 .81267 L .47341 .81001 L F
.47815 .82764 m .48039 .82851 L .47196 .81065 L .847 .538 .465 r
F
.50541 .89782 m .48396 .8299 L .48376 .84834 L .325 .323 .703 r
F
.48396 .8299 m .48113 .8288 L .48376 .84834 L F
.5035 .88977 m .49962 .87948 L .50334 .89126 L F
.50354 .88936 m .47851 .81267 L .49962 .87948 L F
.50979 .90528 m .47851 .81267 L .50891 .90582 L F
.48147 .80051 m .48362 .80442 L .49028 .82572 L .692 .491 .611 r
F
.48362 .80442 m .5102 .85682 L .49028 .82572 L F
.50375 .8874 m .49034 .81883 L .47851 .81267 L .325 .323 .703 r
F
.49034 .81883 m .47958 .81418 L .47288 .81024 L .308 .581 .938 r
F
.47341 .81001 m .47288 .81024 L .46507 .80566 L F
.49034 .81883 m .47288 .81024 L .47341 .81001 L F
.50354 .88936 m .50334 .89126 L .50541 .89782 L .325 .323 .703 r
F
.48113 .8288 m .48087 .8287 L .48376 .84834 L F
.50891 .90582 m .5058 .89627 L .50541 .89782 L F
.51355 .91641 m .50979 .90528 L .50891 .90582 L F
.47168 .81077 m .48039 .82851 L .51355 .91641 L .941 .624 .408 r
F
.47196 .81065 m .48039 .82851 L .47168 .81077 L F
.48396 .8299 m .4793 .81516 L .48113 .8288 L .325 .323 .703 r
F
.50354 .88936 m .49962 .87948 L .5035 .88977 L F
.5048 .89323 m .50354 .88936 L .50382 .89062 L F
.4793 .81516 m .47884 .8149 L .48087 .8287 L F
.4793 .81516 m .48087 .8287 L .48113 .8288 L F
.50979 .90528 m .5044 .88132 L .50375 .8874 L F
.5044 .88132 m .49034 .81883 L .50375 .8874 L F
.47168 .81077 m .5056 .89636 L .49034 .81883 L .941 .624 .408 r
F
.48409 .81683 m .47467 .81203 L .46507 .80566 L .308 .581 .938 r
F
.4677 .82357 m .47789 .82754 L .47145 .81039 L .847 .538 .465 r
F
.4677 .82357 m .47145 .81039 L .46955 .80942 L F
.46507 .80566 m .45998 .80437 L .45725 .80415 L 0 .521 .831 r
F
.45998 .80437 m .4455 .80068 L .45725 .80415 L F
.46504 .80915 m .46348 .80542 L .46309 .80535 L 0 0 .408 r
F
.45908 .80409 m .4677 .82357 L .46955 .80942 L .847 .538 .465 r
F
.46507 .80566 m .46022 .80438 L .45998 .80437 L 0 .521 .831 r
F
.47987 .81548 m .46022 .80438 L .46507 .80566 L .308 .581 .938 r
F
.47145 .81039 m .47196 .81065 L .46995 .80638 L .847 .538 .465 r
F
.46995 .80638 m .47196 .81065 L .47168 .81077 L .941 .624 .408 r
F
.46995 .80638 m .47168 .81077 L .49034 .81883 L F
.49034 .81883 m .48409 .81683 L .47958 .81418 L .308 .581 .938 r
F
.49277 .92625 m .50295 .93131 L .51355 .91641 L .981 .91 .65 r
F
.5056 .89636 m .50942 .90599 L .50656 .89292 L .941 .624 .408 r
F
.5056 .89636 m .50656 .89292 L .49034 .81883 L F
.51354 .91639 m .51076 .90468 L .50979 .90528 L .325 .323 .703 r
F
.51355 .91641 m .51355 .91639 L .51354 .91639 L F
.51355 .91639 m .49034 .81883 L .51354 .91639 L F
.50942 .90599 m .51355 .91641 L .51076 .90467 L .941 .624 .408 r
F
.51076 .90468 m .49034 .81883 L .50979 .90528 L .325 .323 .703 r
F
.50942 .90599 m .51076 .90467 L .49034 .81883 L .941 .624 .408 r
F
.46454 .99777 m .49779 .94257 L .48688 .94517 L .538 .333 .551 r
F
.47548 .96988 m .485 .96373 L .51355 .91641 L .981 .91 .65 r
F
.46299 1.00142 m .46454 .99777 L .46473 .99753 L .538 .333 .551 r
F
.38444 1.01674 m .37738 1.01985 L .39053 1.01871 L .726 .979 .917 r
F
.37738 1.01985 m .36751 1.0242 L .3808 1.02103 L F
.37738 1.01985 m .3808 1.02103 L .39053 1.01871 L F
.38793 1.01521 m .38444 1.01674 L .39535 1.01756 L F
.38444 1.01674 m .39053 1.01871 L .39535 1.01756 L F
.3027 .98316 m .36751 1.0242 L .31019 .98659 L .626 .065 0 r
F
.38793 1.01521 m .39535 1.01756 L .46299 1.00142 L .726 .979 .917 r
F
.28289 .97061 m .3027 .98316 L .31019 .98659 L .626 .065 0 r
F
.25947 .87191 m .29925 .9776 L .30076 .9724 L .952 .699 .243 r
F
.28336 .96352 m .34245 1.00613 L .28289 .97061 L .553 0 0 r
F
.34245 1.00613 m .36751 1.0242 L .33177 1.00157 L F
.34245 1.00613 m .33177 1.00157 L .28289 .97061 L F
.28336 .96352 m .36157 1.02221 L .36751 1.0242 L F
.36732 1.02413 m .46299 1.00142 L .36751 1.0242 L .677 .294 .313 r
F
.36157 1.02221 m .4253 1.00915 L .36732 1.02413 L F
.4253 1.00915 m .46299 1.00142 L .36732 1.02413 L F
.37446 1.0198 m .38123 1.02095 L .42789 1.0098 L F
.36157 1.02221 m .37768 1.02118 L .37446 1.0198 L F
.37768 1.02118 m .38123 1.02095 L .37446 1.0198 L F
.4253 1.00915 m .42789 1.0098 L .46299 1.00142 L F
.46299 1.00142 m .44784 1.00505 L .45589 1.01235 L 0 0 0 r
F
.45917 1.00689 m .46237 1.00157 L .46272 1.00148 L .688 .477 .596 r
F
.46299 1.00142 m .46522 .99768 L .46454 .99777 L .538 .333 .551 r
F
.46522 .99768 m .51355 .91641 L .46454 .99777 L F
.46441 .99784 m .46299 1.00142 L .46522 .99768 L .981 .91 .65 r
F
.46441 .99784 m .46522 .99768 L .51355 .91641 L F
.46237 1.00157 m .50647 .9282 L .46272 1.00148 L .688 .477 .596 r
F
.46272 1.00148 m .50647 .9282 L .46522 .99768 L F
.50647 .9282 m .51355 .91641 L .50429 .93198 L F
.50647 .9282 m .50429 .93198 L .46522 .99768 L F
.45917 1.00689 m .46522 .99768 L .46299 1.00142 L F
.47336 .98746 m .46522 .99768 L .46507 .99862 L 0 0 0 r
F
.46463 1.00412 m .4723 .99571 L .46869 .99684 L .688 .477 .596 r
F
.47336 .98746 m .46507 .99862 L .46349 1.00887 L 0 0 0 r
F
.47874 .98071 m .47336 .98746 L .46349 1.00887 L F
.50753 .92753 m .47229 .98579 L .47874 .98071 L F
.51355 .91641 m .50429 .93198 L .50753 .92753 L F
.50429 .93198 m .47229 .98579 L .50753 .92753 L F
.47229 .98579 m .46522 .99768 L .47874 .98071 L F
.46522 .99768 m .46299 1.00142 L .46349 1.00887 L F
.46379 .9992 m .46798 .99811 L .50675 .9286 L .688 .477 .596 r
F
.50647 .9282 m .50675 .9286 L .51355 .91641 L F
.46379 .9992 m .50675 .9286 L .50647 .9282 L F
.51157 .9223 m .49034 .81883 L .51355 .91641 L .582 .471 .693 r
F
.51106 .92381 m .49034 .81883 L .51157 .9223 L F
.51346 .91604 m .51355 .91641 L .51382 .91788 L .85 .565 .028 r
F
.51346 .91604 m .51382 .91788 L .51768 .93863 L F
.49034 .81883 m .51346 .91604 L .51768 .93863 L F
.51279 .91721 m .51333 .91957 L .51533 .91279 L F
.51333 .91957 m .51665 .93414 L .51556 .9165 L F
.51333 .91957 m .51556 .9165 L .51533 .91279 L F
.49034 .81883 m .51279 .91721 L .51436 .89719 L F
.51279 .91721 m .51533 .91279 L .51436 .89719 L F
.46236 1.00159 m .4666 1.00057 L .46798 .99811 L .688 .477 .596 r
F
.46236 1.00159 m .46798 .99811 L .46379 .9992 L F
.36157 1.02221 m .42789 1.0098 L .4253 1.00915 L .677 .294 .313 r
F
.51665 .93414 m .51826 .94116 L .51776 .93433 L .85 .565 .028 r
F
.52304 .87643 m .52234 .8758 L .5221 .87542 L .692 .491 .611 r
F
.51319 .8621 m .51257 .85906 L .51338 .85972 L .764 .478 .501 r
F
.51055 .85735 m .51063 .85751 L .5102 .85682 L .692 .491 .611 r
F
.50961 .85566 m .51055 .85735 L .5102 .85682 L F
.51837 .87141 m .51458 .84486 L .52083 .87073 L .764 .478 .501 r
F
.51231 .8731 m .51319 .8621 L .51837 .87141 L F
.51319 .8621 m .51458 .84486 L .51837 .87141 L F
.51231 .8731 m .50499 .85686 L .50979 .85682 L F
.51458 .84486 m .51702 .84956 L .52083 .87073 L F
.51813 .90949 m .52642 .85088 L .50836 .83484 L .582 .471 .693 r
F
.51528 .90018 m .50836 .83484 L .49034 .81883 L F
.51813 .90949 m .50836 .83484 L .51528 .90018 L F
.51528 .90018 m .51826 .94116 L .5205 .94946 L .153 .15 .601 r
F
.51665 .93414 m .51776 .93433 L .51528 .90018 L .85 .565 .028 r
F
.48147 .80051 m .51959 .84164 L .48582 .8067 L .692 .491 .611 r
F
.51665 .93414 m .51528 .90018 L .51436 .89719 L .85 .565 .028 r
F
.514 .93871 m .51813 .90949 L .49034 .81883 L .582 .471 .693 r
F
.514 .93871 m .52642 .85088 L .514 .93871 L F
.5164 .94269 m .52642 .85088 L .514 .93872 L F
.5109 .83839 m .51131 .84427 L .5114 .8441 L .153 .15 .601 r
F
.52642 .85088 m .51805 .84488 L .51077 .83822 L .508 .581 .863 r
F
.51894 .91588 m .52642 .85088 L .51811 .92697 L .722 .573 .687 r
F
.51805 .84488 m .52065 .89991 L .52282 .87977 L .153 .15 .601 r
F
.51854 .84532 m .52282 .87977 L .52582 .85187 L F
.51805 .84488 m .52282 .87977 L .51854 .84532 L F
.52282 .87977 m .52642 .85088 L .51894 .91588 L .722 .573 .687 r
F
.51155 .84381 m .51894 .91588 L .51805 .84488 L .153 .15 .601 r
F
.51894 .91588 m .52353 .9607 L .52065 .89991 L F
.51894 .91588 m .52065 .89991 L .51805 .84488 L F
.5114 .8441 m .51528 .90018 L .5184 .92309 L F
.51805 .84488 m .51315 .84047 L .51077 .83822 L .508 .581 .863 r
F
.52642 .85088 m .51077 .83822 L .50836 .83484 L F
.51101 .83855 m .5184 .92309 L .51894 .91588 L .153 .15 .601 r
F
.51101 .83855 m .51155 .84381 L .51805 .84488 L F
.517 .84413 m .51289 .84117 L .51077 .83822 L .508 .581 .863 r
F
.51028 .83144 m .5109 .83839 L .51101 .83855 L .153 .15 .601 r
F
.5109 .83839 m .5184 .92309 L .51101 .83855 L F
.51436 .89719 m .51077 .83822 L .5107 .83814 L .85 .565 .028 r
F
.48409 .81683 m .47987 .81548 L .47467 .81203 L .308 .581 .938 r
F
.46955 .80942 m .47145 .81039 L .46995 .80638 L .847 .538 .465 r
F
.46638 .80527 m .46955 .80942 L .46995 .80638 L F
.45356 .80127 m .45908 .80409 L .46638 .80527 L F
.46532 .80726 m .45956 .80433 L .46022 .80438 L .308 .581 .938 r
F
.45998 .80437 m .45869 .80402 L .45853 .804 L 0 .521 .831 r
F
.45683 .80407 m .45138 .80302 L .45585 .80404 L F
.45683 .80407 m .45585 .80404 L .45701 .80413 L F
.45585 .80404 m .45138 .80302 L .45349 .80385 L F
.45492 .80341 m .45754 .80476 L .45589 .80495 L .847 .538 .465 r
F
.45701 .80413 m .45754 .80476 L .45492 .80341 L F
.45725 .80415 m .4455 .80068 L .45138 .80302 L 0 .521 .831 r
F
.45492 .80341 m .4677 .82357 L .45908 .80409 L .847 .538 .465 r
F
.45853 .804 m .44173 .79952 L .44326 .80011 L 0 .521 .831 r
F
.45869 .80402 m .44173 .79952 L .45853 .804 L F
.45138 .80302 m .43727 .80029 L .45339 .80384 L F
.45138 .80302 m .45339 .80384 L .45349 .80385 L F
.39317 .7878 m .43376 .78981 L .41251 .79198 L .365 0 0 r
F
.42608 .79964 m .40634 .79658 L .43562 .79949 L 0 .521 .831 r
F
.43406 .79702 m .4138 .79711 L .42936 .79615 L .217 0 0 r
F
.44195 .80119 m .40247 .78973 L .43727 .80029 L 0 .521 .831 r
F
.45138 .80302 m .42397 .79557 L .44195 .80119 L F
.42397 .79557 m .40247 .78973 L .44195 .80119 L F
.43571 .79055 m .44524 .79593 L .4449 .79404 L .759 .44 .445 r
F
.43376 .78981 m .44524 .79593 L .43571 .79055 L F
.4455 .80068 m .40247 .78973 L .45138 .80302 L 0 .521 .831 r
F
.40285 .78982 m .40212 .78911 L .40247 .78973 L F
.41764 .79359 m .40212 .78911 L .40285 .78982 L F
.4104 .79132 m .40212 .78911 L .41764 .79359 L F
.41251 .79198 m .43376 .78981 L .43571 .79055 L .365 0 0 r
F
.44688 .79625 m .45153 .80143 L .44529 .79418 L .759 .44 .445 r
F
.45153 .80143 m .44936 .79875 L .44529 .79418 L F
.44529 .79418 m .44936 .79875 L .44585 .79439 L F
.4449 .79404 m .44688 .79625 L .44529 .79418 L F
.41712 .79248 m .43571 .79055 L .45026 .79607 L .365 0 0 r
F
.41251 .79198 m .43571 .79055 L .41712 .79248 L F
.41121 .79138 m .45026 .79607 L .39538 .78404 L F
.41251 .79198 m .41712 .79248 L .41121 .79138 L F
.41712 .79248 m .45026 .79607 L .41121 .79138 L F
.40967 .79109 m .40212 .78911 L .40925 .79102 L 0 .521 .831 r
F
.41251 .79198 m .39538 .78404 L .39524 .78658 L .365 0 0 r
F
.40967 .79109 m .40925 .79102 L .44326 .80011 L 0 .521 .831 r
F
.44173 .79952 m .40967 .79109 L .44326 .80011 L F
.44326 .80011 m .4104 .79132 L .41764 .79359 L F
.41226 .79196 m .41251 .79198 L .40967 .79109 L .365 0 0 r
F
.43727 .80029 m .40247 .78973 L .4049 .79403 L 0 .521 .831 r
F
.40212 .78911 m .38302 .78409 L .40351 .79158 L F
.38302 .78409 m .37557 .78213 L .40351 .79158 L F
.39727 .79233 m .3917 .78971 L .39574 .79225 L F
.3917 .78971 m .37557 .78213 L .38436 .78679 L F
.4068 .79278 m .39317 .7878 L .35755 .78603 L .041 0 0 r
F
.39506 .79009 m .39317 .7878 L .41251 .79198 L .365 0 0 r
F
.35755 .78603 m .38091 .78719 L .39506 .79009 L F
.38091 .78719 m .39317 .7878 L .39506 .79009 L F
.35755 .78603 m .41226 .79196 L .40967 .79109 L F
.35755 .78603 m .40967 .79109 L .36238 .78228 L F
.39515 .78839 m .40967 .79109 L .41557 .79264 L .308 .581 .938 r
F
.39515 .78839 m .41557 .79264 L .41356 .79285 L F
.39515 .78839 m .37557 .78213 L .3952 .78729 L F
.40864 .7909 m .40858 .79081 L .40967 .79109 L F
.45324 .80383 m .44449 .80248 L .44575 .80222 L 0 .521 .831 r
F
.44449 .80248 m .43844 .80065 L .44575 .80222 L F
.43844 .80065 m .43774 .80043 L .44575 .80222 L F
.45324 .80383 m .43727 .80029 L .44449 .80248 L F
.45339 .80384 m .43727 .80029 L .45324 .80383 L F
.44449 .80248 m .4049 .79403 L .42608 .79964 L F
.43727 .80029 m .4049 .79403 L .44449 .80248 L F
.43964 .80262 m .39515 .78839 L .44978 .80164 L .308 .581 .938 r
F
.39515 .78839 m .39509 .78229 L .37557 .78213 L F
.39509 .78229 m .39499 .772 L .38316 .77798 L F
.39499 .772 m .39453 .77177 L .38316 .77798 L F
.46617 .80524 m .46641 .80531 L .46638 .80527 L .847 .538 .465 r
F
.45908 .80409 m .46641 .80531 L .46617 .80524 L F
.43964 .80262 m .44978 .80164 L .45908 .80409 L .308 .581 .938 r
F
.45956 .80433 m .45908 .80409 L .46022 .80438 L F
.43964 .80262 m .45908 .80409 L .45956 .80433 L F
.45908 .80409 m .46955 .80942 L .46641 .80531 L .847 .538 .465 r
F
.47742 .80268 m .46139 .80205 L .47613 .79931 L .884 .508 .322 r
F
.45026 .79607 m .45356 .80127 L .46995 .80638 L .847 .538 .465 r
F
.41898 .79092 m .45026 .79607 L .46995 .80638 L .522 0 0 r
F
.39538 .78404 m .45026 .79607 L .39546 .78243 L .365 0 0 r
F
.39546 .78243 m .45026 .79607 L .41898 .79092 L .522 0 0 r
F
.39509 .78229 m .38316 .77798 L .37557 .78213 L .308 .581 .938 r
F
.39084 .78729 m .37557 .78213 L .3829 .78557 L 0 .521 .831 r
F
.36238 .78228 m .39515 .78839 L .36788 .77802 L .365 0 0 r
F
.39515 .78839 m .40967 .79109 L .39524 .78658 L F
.396 .77229 m .39498 .77152 L .39515 .78839 L .308 .581 .938 r
F
.39515 .78839 m .39524 .78658 L .36788 .77802 L .365 0 0 r
F
.4102 .7932 m .396 .77229 L .39515 .78839 L .308 .581 .938 r
F
.41356 .79285 m .41557 .79264 L .44978 .80164 L F
.42137 .7955 m .396 .77229 L .4102 .7932 L F
.41898 .79092 m .46549 .80503 L .4141 .7816 L .522 0 0 r
F
.42433 .79371 m .42329 .79376 L .42425 .79369 L .217 0 0 r
F
.42329 .79376 m .42345 .79374 L .42425 .79369 L F
.42861 .79698 m .41791 .78888 L .42137 .7955 L .308 .581 .938 r
F
.41791 .78888 m .396 .77229 L .42137 .7955 L F
.39538 .78404 m .39546 .78243 L .37028 .77616 L .365 0 0 r
F
.37028 .77616 m .39546 .78243 L .41898 .79092 L .522 0 0 r
F
.37028 .77616 m .41898 .79092 L .38712 .7693 L F
.44743 .80337 m .45292 .80381 L .45288 .80376 L .759 .44 .445 r
F
.47987 .81548 m .43964 .80262 L .45956 .80433 L .308 .581 .938 r
F
.45891 .80878 m .41524 .78377 L .43964 .80262 L F
.41524 .78377 m .39856 .77422 L .41686 .78687 L F
.41524 .78377 m .41686 .78687 L .43964 .80262 L F
.46549 .80503 m .46519 .80425 L .41395 .78131 L .522 0 0 r
F
.45326 .80351 m .39856 .77422 L .45891 .80878 L .308 .581 .938 r
F
.46934 .81212 m .39498 .77152 L .39856 .77422 L F
.43964 .80262 m .39856 .77422 L .43342 .80063 L F
.46549 .80503 m .41395 .78131 L .4141 .7816 L .522 0 0 r
F
.46549 .80503 m .46995 .80638 L .46519 .80425 L F
.41395 .78131 m .46995 .80638 L .49034 .81883 L .553 0 0 r
F
.47987 .81548 m .45956 .80433 L .46532 .80726 L .308 .581 .938 r
F
.45153 .80143 m .45096 .80062 L .45085 .80059 L .759 .44 .445 r
F
.46759 .80754 m .39498 .77152 L .46934 .81212 L .308 .581 .938 r
F
.4141 .7816 m .41395 .78131 L .38712 .7693 L .522 0 0 r
F
.41898 .79092 m .4141 .7816 L .38712 .7693 L F
.49034 .81883 m .46759 .80754 L .46934 .81212 L .308 .581 .938 r
F
.38712 .7693 m .41395 .78131 L .49034 .81883 L .553 0 0 r
F
.39499 .772 m .39498 .77152 L .39453 .77177 L .308 .581 .938 r
F
.43342 .80063 m .42861 .79698 L .4102 .7932 L F
.39524 .78658 m .39538 .78404 L .36788 .77802 L .365 0 0 r
F
.36788 .77802 m .39538 .78404 L .37028 .77616 L F
.50836 .83484 m .51077 .83822 L .49034 .81883 L .508 .581 .863 r
F
.49034 .81883 m .51436 .89719 L .51028 .83144 L .85 .565 .028 r
F
.49034 .81883 m .40682 .76505 L .39498 .77152 L .308 .581 .938 r
F
.38712 .7693 m .49034 .81883 L .40682 .76505 L .553 0 0 r
F
.51077 .83822 m .40682 .76505 L .49034 .81883 L .508 .581 .863 r
F
.51077 .83822 m .51528 .90018 L .5109 .83839 L .153 .15 .601 r
F
.51436 .89719 m .51528 .90018 L .51077 .83822 L .85 .565 .028 r
F
.51289 .84117 m .40682 .76505 L .51077 .83822 L .508 .581 .863 r
F
.51528 .90018 m .5205 .94946 L .52353 .9607 L .153 .15 .601 r
F
.50477 .93262 m .4663 1.00367 L .51613 .94371 L 0 0 0 r
F
.51471 .94233 m .5164 .94269 L .514 .93872 L .582 .471 .693 r
F
.51627 .94385 m .5164 .94269 L .51471 .94233 L F
.51693 .94356 m .50625 .96291 L .5205 .94946 L .439 .15 .376 r
F
.50625 .96291 m .5102 .96533 L .5205 .94946 L F
.51202 .96645 m .51984 .90367 L .51798 .92481 L .722 .573 .687 r
F
.51202 .96645 m .51798 .92481 L .51557 .94718 L F
.52268 .88091 m .52282 .87977 L .51894 .91588 L F
.51984 .90367 m .52268 .88091 L .51894 .91588 L F
.52065 .89991 m .52353 .9607 L .52488 .89638 L .153 .15 .601 r
F
.52282 .87977 m .55091 .90382 L .52642 .85088 L .722 .573 .687 r
F
.52299 .88117 m .55091 .90382 L .52282 .87977 L F
.52065 .89991 m .52488 .89638 L .52282 .87977 L .153 .15 .601 r
F
.53146 .88979 m .54461 .90978 L .53314 .93956 L .797 .714 .772 r
F
.53013 .93595 m .55091 .90382 L .52299 .88117 L .722 .573 .687 r
F
.53124 .94295 m .52997 .97441 L .53313 .95478 L .58 .472 .695 r
F
.52991 .93461 m .52993 .94524 L .53124 .94295 L F
.52993 .94524 m .52997 .97441 L .53124 .94295 L F
.5412 .92454 m .53567 .93414 L .53124 .94295 L .851 .705 .7 r
F
.5412 .92454 m .53124 .94295 L .53145 .9426 L F
.53124 .94295 m .55091 .90382 L .53013 .93595 L .722 .573 .687 r
F
.53108 .94328 m .52299 .88117 L .52632 .90795 L F
.54296 .87991 m .54407 .87956 L .54975 .85145 L .58 .472 .695 r
F
.5412 .92454 m .53145 .9426 L .53471 .93693 L .851 .705 .7 r
F
.53124 .94295 m .53313 .95478 L .5365 .9338 L .58 .472 .695 r
F
.5238 .95568 m .52353 .9607 L .52993 .94524 L F
.53955 .92807 m .5412 .92454 L .52421 .95693 L .851 .705 .7 r
F
.54975 .85145 m .54529 .87917 L .54727 .88106 L .731 .611 .724 r
F
.54975 .85145 m .55507 .91802 L .56325 .85544 L F
.56022 .87867 m .56199 .87386 L .54099 .88222 L .635 .606 .803 r
F
.56199 .87386 m .54247 .88007 L .54099 .88222 L F
.53124 .94295 m .5365 .9338 L .54529 .87917 L .58 .472 .695 r
F
.54407 .87956 m .54529 .87917 L .54975 .85145 L F
.53124 .94295 m .54529 .87917 L .54407 .87956 L F
.54099 .88222 m .54247 .88007 L .54031 .88075 L .635 .606 .803 r
F
.54579 .8669 m .54089 .84685 L .54764 .83915 L .599 .432 .627 r
F
.52977 .84262 m .5298 .85809 L .54975 .85145 L .58 .472 .695 r
F
.54099 .88222 m .54031 .88075 L .53719 .87402 L .635 .606 .803 r
F
.54031 .88075 m .53752 .87474 L .53719 .87402 L F
.54099 .88222 m .53719 .87402 L .52642 .85088 L F
.53957 .87913 m .52904 .85646 L .52642 .85088 L F
.52904 .85646 m .52413 .84588 L .52642 .85088 L F
.52488 .89638 m .52632 .90795 L .52904 .85646 L .153 .15 .601 r
F
.52898 .85632 m .52904 .85646 L .52913 .85484 L F
.52488 .89638 m .52904 .85646 L .52898 .85632 L F
.52769 .85355 m .52898 .85632 L .52913 .85484 L F
.51028 .83144 m .51101 .83855 L .52977 .84262 L F
.52642 .85088 m .52413 .84588 L .51805 .84488 L .508 .581 .863 r
F
.51101 .83855 m .52913 .85484 L .52977 .84262 L .153 .15 .601 r
F
.51917 .82046 m .52727 .82848 L .50859 .81427 L .568 .349 .543 r
F
.50763 .81225 m .50859 .81427 L .48159 .79373 L F
.51917 .82046 m .50859 .81427 L .50763 .81225 L F
.48575 .78739 m .50013 .79053 L .49486 .79641 L F
.48804 .78656 m .5247 .79589 L .48575 .78739 L F
.49896 .78892 m .49851 .77535 L .49963 .78906 L .142 0 0 r
F
.50819 .79091 m .5247 .79589 L .48804 .78656 L .568 .349 .543 r
F
.51917 .82046 m .48159 .79373 L .48129 .7935 L F
.48129 .79352 m .50379 .81062 L .49337 .8059 L F
.48159 .79373 m .52044 .82328 L .48129 .79352 L F
.48537 .79719 m .49384 .78311 L .49913 .79403 L .142 0 0 r
F
.49384 .78311 m .49851 .77535 L .49913 .79403 L F
.48185 .79319 m .48804 .78656 L .48537 .79719 L F
.48804 .78656 m .49851 .77535 L .49134 .78727 L F
.48804 .78656 m .49134 .78727 L .48537 .79719 L F
.4816 .79308 m .48852 .7836 L .49168 .78267 L F
.48102 .78272 m .49064 .78562 L .48804 .78656 L .568 .349 .543 r
F
.48403 .7857 m .48804 .78656 L .48575 .78739 L F
.48102 .78272 m .48804 .78656 L .48403 .7857 L F
.49851 .77535 m .50081 .77477 L .50002 .79383 L .142 0 0 r
F
.50089 .7728 m .5038 .77634 L .50002 .79383 L F
.50567 .76768 m .50679 .76734 L .50433 .77698 L F
.5038 .77634 m .50433 .77698 L .50002 .79383 L F
.50567 .76768 m .50433 .77698 L .5038 .77634 L F
.52387 .75801 m .52774 .75219 L .52284 .78278 L 0 0 0 r
F
.50691 .78297 m .50685 .77453 L .50823 .7815 L F
.50685 .77453 m .50679 .76734 L .50746 .77394 L F
.50685 .77453 m .50746 .77394 L .50823 .7815 L F
.51002 .77145 m .52981 .75224 L .52608 .77109 L .255 0 .315 r
F
.52387 .75801 m .50679 .76734 L .52961 .74939 L 0 0 0 r
F
.50921 .77224 m .52608 .77109 L .50777 .77364 L .255 0 .315 r
F
.50746 .77394 m .50679 .76734 L .52387 .75801 L 0 0 0 r
F
.50517 .77367 m .50679 .76734 L .50685 .77453 L F
.50089 .7728 m .49869 .77137 L .50476 .76866 L .142 0 0 r
F
.49851 .77535 m .49862 .77296 L .50089 .7728 L F
.49862 .77296 m .49869 .77137 L .50089 .7728 L F
.49168 .78267 m .49869 .77137 L .49851 .77535 L F
.49481 .77288 m .49781 .77132 L .49571 .77178 L .797 .966 .914 r
F
.49571 .77178 m .51002 .77145 L .49862 .77296 L .255 0 .315 r
F
.51002 .77145 m .52608 .77109 L .50921 .77224 L F
.51002 .77145 m .50921 .77224 L .49862 .77296 L F
.50557 .77578 m .50685 .77453 L .50691 .78297 L 0 0 0 r
F
.50517 .77367 m .50685 .77453 L .50557 .77578 L F
.50823 .7815 m .50746 .77394 L .52387 .75801 L F
.50089 .7728 m .50921 .77224 L .50221 .77442 L .255 0 .315 r
F
.50921 .77224 m .50777 .77364 L .50221 .77442 L F
.50683 .76714 m .53082 .74713 L .49781 .77132 L .796 .96 .637 r
F
.5305 .74899 m .53056 .74864 L .52961 .74939 L F
.52774 .75219 m .52961 .74939 L .5305 .74899 L 0 0 0 r
F
.49996 .77168 m .53082 .74713 L .52981 .75224 L .255 0 .315 r
F
.49996 .77168 m .52981 .75224 L .51002 .77145 L F
.49781 .77132 m .53082 .74713 L .49571 .77178 L .796 .96 .637 r
F
.49571 .77178 m .49845 .76985 L .49996 .77168 L .255 0 .315 r
F
.49845 .76985 m .53082 .74713 L .49996 .77168 L F
.49064 .78562 m .50819 .79091 L .48804 .78656 L .568 .349 .543 r
F
.49913 .79403 m .49896 .78892 L .50002 .79383 L .142 0 0 r
F
.49896 .78892 m .49963 .78906 L .50002 .79383 L F
.52904 .85646 m .52357 .84453 L .52403 .84566 L .635 .606 .803 r
F
.49816 .78288 m .51556 .78305 L .49064 .78562 L .568 .349 .543 r
F
.51556 .78305 m .51798 .78356 L .49064 .78562 L F
.50379 .81062 m .52044 .82328 L .49707 .80962 L F
.52569 .8251 m .50002 .79383 L .52182 .78709 L .667 .445 .573 r
F
.49064 .78562 m .50555 .78449 L .50158 .78892 L .568 .349 .543 r
F
.52569 .8251 m .52587 .7995 L .53649 .82885 L .667 .445 .573 r
F
.52587 .7995 m .5287 .79695 L .53649 .82885 L F
.52382 .78479 m .53666 .8325 L .5247 .79589 L .592 .48 .695 r
F
.50555 .78449 m .51798 .78356 L .50158 .78892 L .568 .349 .543 r
F
.50002 .79383 m .50699 .78336 L .52597 .7858 L 0 0 0 r
F
.50002 .79383 m .50115 .78939 L .50691 .78297 L F
.50002 .79383 m .50691 .78297 L .50699 .78336 L F
.48102 .78272 m .49816 .78288 L .49064 .78562 L .568 .349 .543 r
F
.50745 .81213 m .50002 .79383 L .52569 .8251 L .667 .445 .573 r
F
.52044 .82328 m .51655 .82193 L .48147 .80051 L .568 .349 .543 r
F
.4908 .77729 m .49816 .78288 L .48102 .78272 L .255 0 .315 r
F
.49862 .77296 m .49851 .77535 L .4908 .77729 L F
.49851 .77535 m .49816 .78288 L .4908 .77729 L F
.49571 .77178 m .49862 .77296 L .48102 .78272 L F
.47096 .79839 m .47411 .79902 L .45992 .79874 L .653 .302 .365 r
F
.47742 .80268 m .47613 .79931 L .47742 .80194 L .884 .508 .322 r
F
.46708 .79421 m .51028 .83144 L .52002 .83702 L .093 .444 .88 r
F
.48803 .8098 m .52002 .83702 L .51859 .83383 L F
.46708 .79421 m .52002 .83702 L .48803 .8098 L F
.45537 .78549 m .51028 .83144 L .46708 .79421 L F
.51028 .83144 m .51044 .83361 L .51049 .83375 L .153 .15 .601 r
F
.51044 .83361 m .51077 .83822 L .51049 .83375 L F
.51049 .83375 m .51077 .83822 L .5109 .83839 L F
.5107 .83814 m .51077 .83822 L .51028 .83144 L .85 .565 .028 r
F
.47411 .79902 m .47468 .79904 L .47573 .79922 L .217 0 0 r
F
.47935 .80001 m .48011 .80014 L .47973 .8004 L .764 .478 .501 r
F
.4806 .80066 m .48011 .80014 L .48146 .80003 L F
.4809 .80044 m .48147 .80051 L .48 .80021 L .445 .029 .155 r
F
.48 .80021 m .48147 .80051 L .47964 .80045 L .653 .302 .365 r
F
.47964 .80045 m .48147 .80051 L .47963 .80046 L F
.4796 .80048 m .47935 .80001 L .47973 .8004 L .764 .478 .501 r
F
.48011 .80014 m .47877 .79871 L .48077 .79969 L F
.48011 .80014 m .48077 .79969 L .48146 .80003 L F
.47383 .78408 m .48127 .79253 L .48146 .80003 L .445 .029 .155 r
F
.4813 .80015 m .48146 .80003 L .48147 .80051 L F
.47383 .78408 m .48146 .80003 L .4813 .80015 L F
.4809 .80044 m .4813 .80015 L .48147 .80051 L F
.48129 .79352 m .49337 .8059 L .48146 .80003 L .568 .349 .543 r
F
.50379 .81062 m .49707 .80962 L .48147 .80051 L F
.5026 .81045 m .47877 .79871 L .50002 .79383 L .764 .478 .501 r
F
.48146 .80003 m .49337 .8059 L .48147 .80051 L .568 .349 .543 r
F
.5026 .81045 m .50002 .79383 L .50575 .81092 L .764 .478 .501 r
F
.48185 .79319 m .4816 .79308 L .48784 .78664 L .142 0 0 r
F
.48185 .79319 m .48784 .78664 L .48804 .78656 L F
.48129 .7935 m .48159 .79373 L .48129 .79352 L .568 .349 .543 r
F
.48102 .78272 m .48575 .78739 L .48129 .7935 L F
.47613 .79931 m .4751 .79699 L .48185 .79319 L .142 0 0 r
F
.47383 .78408 m .48102 .78272 L .48127 .79253 L .445 .029 .155 r
F
.47613 .79931 m .48185 .79319 L .48537 .79719 L .142 0 0 r
F
.40682 .76505 m .49034 .81883 L .51028 .83144 L 0 .193 .618 r
F
.40682 .76505 m .51028 .83144 L .45537 .78549 L F
.5011 .80475 m .49092 .77327 L .43167 .76748 L .508 .581 .863 r
F
.46129 .78799 m .43167 .76748 L .40682 .76505 L F
.5011 .80475 m .43167 .76748 L .46129 .78799 L F
.53924 .84196 m .52977 .84262 L .54975 .85145 L .391 .56 .901 r
F
.41786 .77298 m .5011 .80475 L .40682 .76505 L .508 .581 .863 r
F
.48803 .8098 m .51859 .83383 L .50773 .82014 L .093 .444 .88 r
F
.51859 .83383 m .52977 .84262 L .51637 .82895 L F
.51859 .83383 m .51637 .82895 L .50773 .82014 L F
.50575 .8191 m .5011 .80475 L .41786 .77298 L .508 .581 .863 r
F
.5145 .82483 m .52977 .84262 L .53924 .84196 L .391 .56 .901 r
F
.50773 .82014 m .51637 .82895 L .5145 .82483 L F
.51637 .82895 m .52977 .84262 L .5145 .82483 L F
.50728 .80897 m .51382 .82334 L .5145 .82483 L .635 .606 .803 r
F
.52044 .82328 m .52727 .82848 L .51655 .82193 L .568 .349 .543 r
F
.51049 .816 m .5145 .82483 L .53924 .84196 L .391 .56 .901 r
F
.51176 .81879 m .5145 .82483 L .51774 .83191 L .635 .606 .803 r
F
.50728 .80897 m .5145 .82483 L .51176 .81879 L F
.51805 .84488 m .517 .84413 L .51315 .84047 L .508 .581 .863 r
F
.50575 .81092 m .50002 .79383 L .50745 .81213 L .667 .445 .573 r
F
.51767 .83176 m .51664 .82952 L .51289 .84117 L .508 .581 .863 r
F
.51152 .81831 m .49092 .77327 L .50425 .81447 L F
.50728 .80897 m .506 .80618 L .51382 .82334 L .635 .606 .803 r
F
.506 .80618 m .49092 .77327 L .51152 .81831 L F
.506 .80618 m .51152 .81831 L .51382 .82334 L F
.50699 .78336 m .50823 .7815 L .51556 .78305 L 0 0 0 r
F
.57347 .84749 m .5597 .80161 L .57816 .76541 L .569 .453 .682 r
F
.54764 .83915 m .5399 .7803 L .55147 .78184 L .599 .432 .627 r
F
.57342 .84838 m .57839 .76132 L .60356 .85532 L .569 .453 .682 r
F
.52518 .78986 m .54888 .83773 L .53666 .8325 L .592 .48 .695 r
F
.52587 .7995 m .52597 .7858 L .5287 .79695 L .667 .445 .573 r
F
.5287 .79695 m .52597 .7858 L .53876 .81728 L .599 .432 .627 r
F
.52587 .7995 m .52182 .78709 L .52597 .7858 L .667 .445 .573 r
F
.52569 .8251 m .52182 .78709 L .52587 .7995 L F
.5247 .79589 m .53666 .8325 L .52727 .82848 L .592 .48 .695 r
F
.50699 .78336 m .51556 .78305 L .52597 .7858 L 0 0 0 r
F
.49851 .77535 m .50592 .77764 L .49816 .78288 L .255 0 .315 r
F
.50592 .77764 m .50691 .78297 L .49816 .78288 L F
.50699 .78336 m .50691 .78297 L .50823 .7815 L 0 0 0 r
F
.51917 .82046 m .5247 .79589 L .52727 .82848 L .568 .349 .543 r
F
.49807 .78885 m .57972 .82591 L .49092 .77327 L .635 .606 .803 r
F
.51854 .80321 m .57972 .82591 L .49807 .78885 L F
.53266 .81982 m .57972 .82591 L .50182 .797 L F
.5783 .8495 m .57829 .84454 L .57936 .85079 L .592 .48 .695 r
F
.57409 .84853 m .57936 .85079 L .57807 .85525 L .711 .597 .727 r
F
.57409 .84853 m .57807 .85525 L .57387 .86978 L F
.57259 .86293 m .57342 .84838 L .57409 .84853 L .569 .453 .682 r
F
.57259 .86293 m .57409 .84853 L .58135 .86078 L F
.5779 .84941 m .57936 .85079 L .57409 .84853 L .592 .48 .695 r
F
.58115 .84714 m .57173 .85795 L .59727 .86316 L .555 .633 .883 r
F
.55423 .83578 m .56452 .84013 L .53266 .81982 L .635 .606 .803 r
F
.5415 .83457 m .57329 .84819 L .57109 .85662 L .711 .597 .727 r
F
.57342 .84838 m .57332 .84805 L .57347 .84749 L .569 .453 .682 r
F
.57109 .85662 m .57329 .84819 L .57342 .84838 L F
.57313 .84376 m .57173 .85795 L .58115 .84714 L .555 .633 .883 r
F
.55423 .83578 m .56687 .85179 L .57313 .84376 L F
.56687 .85179 m .57173 .85795 L .57313 .84376 L F
.57645 .83949 m .57972 .82591 L .57378 .84197 L .743 .672 .782 r
F
.57514 .84117 m .57378 .84197 L .57313 .84376 L F
.57645 .83949 m .57378 .84197 L .57514 .84117 L F
.56794 .84231 m .57006 .83936 L .53266 .81982 L .635 .606 .803 r
F
.57006 .83936 m .57972 .82591 L .54438 .82134 L F
.57006 .83936 m .54438 .82134 L .53266 .81982 L F
.53266 .81982 m .54975 .85145 L .56325 .85544 L .514 .607 .884 r
F
.56604 .8524 m .56325 .85544 L .57173 .85795 L F
.53266 .81982 m .56325 .85544 L .56604 .8524 L F
.57514 .84117 m .58115 .84714 L .57633 .84069 L .555 .633 .883 r
F
.5762 .84055 m .5809 .84532 L .57972 .82591 L .743 .672 .782 r
F
.5762 .84055 m .57633 .84069 L .57622 .84054 L .555 .633 .883 r
F
.57514 .84117 m .57633 .84069 L .5762 .84055 L F
.581 .847 m .58101 .84708 L .58115 .84714 L F
.5542 .84085 m .56604 .8524 L .5611 .84449 L .514 .607 .884 r
F
.56604 .8524 m .57173 .85795 L .56687 .85179 L F
.56604 .8524 m .56687 .85179 L .5611 .84449 L F
.53803 .93093 m .52997 .97441 L .53955 .92807 L .731 .611 .724 r
F
.54529 .87917 m .52997 .97441 L .54727 .88106 L F
.52997 .97441 m .5203 .99008 L .52174 .99046 L .862 .644 .606 r
F
.52997 .97441 m .52174 .99046 L .52781 .98746 L F
.52997 .97441 m .52781 .98746 L .53363 .97928 L F
.50905 .99316 m .51969 .98992 L .52997 .97441 L .685 .415 .508 r
F
.50905 .99316 m .54052 .97164 L .53955 .92807 L .851 .705 .7 r
F
.54052 .97164 m .54112 .97123 L .5407 .95963 L F
.54052 .97164 m .5407 .95963 L .53955 .92807 L F
.54054 .97043 m .54111 .9734 L .55437 .9234 L .731 .611 .724 r
F
.55507 .91802 m .55437 .9234 L .57173 .85795 L F
.54054 .97043 m .55437 .9234 L .55507 .91802 L F
.55437 .9234 m .57491 .84589 L .56353 .86971 L .743 .672 .782 r
F
.5542 .92436 m .55169 .93913 L .56383 .91094 L .783 .681 .752 r
F
.54813 .94738 m .5498 .94973 L .56383 .91094 L F
.54541 .9683 m .55646 .95909 L .54986 .94982 L .743 .672 .782 r
F
.54131 .97323 m .54238 .97234 L .56383 .91094 L .783 .681 .752 r
F
.57173 .85795 m .54111 .9734 L .54131 .97323 L F
.54986 .94982 m .55217 .94026 L .55437 .9234 L .743 .672 .782 r
F
.57101 .87322 m .57259 .86293 L .58135 .86078 L .765 .681 .77 r
F
.57173 .85795 m .55668 .95883 L .59727 .86316 L .783 .681 .752 r
F
.55668 .95883 m .55685 .95876 L .59727 .86316 L F
.55661 .95931 m .58521 .89617 L .59727 .86316 L F
.55661 .95931 m .53898 .98206 L .55282 .98478 L F
.56383 .91094 m .55012 .95018 L .55646 .95909 L F
.56383 .91094 m .55646 .95909 L .55668 .95883 L F
.55646 .95909 m .5791 .94022 L .54986 .94982 L .743 .672 .782 r
F
.5791 .94022 m .57953 .93712 L .54986 .94982 L F
.57199 .94728 m .5791 .94022 L .55687 .95875 L .865 .833 .813 r
F
.58445 .93492 m .57855 .94421 L .57524 .98642 L .782 .709 .783 r
F
.56341 .95579 m .55282 .98478 L .58445 .93492 L F
.59202 .93209 m .55687 .95875 L .55886 .95785 L .865 .833 .813 r
F
.56357 .94395 m .57953 .93712 L .58413 .89854 L .743 .672 .782 r
F
.59727 .86316 m .58521 .89617 L .58445 .93492 L .782 .709 .783 r
F
.58521 .89617 m .5791 .94022 L .58445 .93492 L F
.57953 .93712 m .5863 .93423 L .58436 .90228 L .743 .672 .782 r
F
.57953 .93712 m .58436 .90228 L .58413 .89854 L F
.55661 .95931 m .55282 .98478 L .56341 .95579 L .783 .681 .752 r
F
.57855 .94421 m .55282 .98478 L .57273 .98623 L .782 .709 .783 r
F
.57855 .94421 m .57273 .98623 L .57524 .98642 L F
.57076 .95247 m .59202 .93209 L .55886 .95785 L .865 .833 .813 r
F
.58115 .84714 m .59727 .86316 L .59242 .85701 L .555 .633 .883 r
F
.58115 .84714 m .59242 .85701 L .58616 .85066 L F
.59727 .86316 m .59333 .89794 L .59996 .86368 L .782 .709 .783 r
F
.5863 .93423 m .59807 .87343 L .59129 .85586 L .743 .672 .782 r
F
.5809 .84532 m .59129 .85586 L .57972 .82591 L F
.57313 .84376 m .57972 .82591 L .56872 .8419 L .635 .606 .803 r
F
.58115 .84714 m .58895 .85262 L .57839 .83925 L .555 .633 .883 r
F
.5762 .84055 m .57645 .83949 L .57593 .84071 L .743 .672 .782 r
F
.5298 .85809 m .54193 .88424 L .54975 .85145 L .58 .472 .695 r
F
.54247 .88007 m .56679 .84471 L .54031 .88075 L .635 .606 .803 r
F
.56679 .84471 m .57972 .82591 L .56634 .84454 L F
.56679 .84471 m .56634 .84454 L .54031 .88075 L F
.62291 .86474 m .59727 .86316 L .62736 .86902 L .547 .644 .898 r
F
.51556 .78305 m .52387 .75801 L .52284 .78278 L 0 0 0 r
F
.52331 .77147 m .52608 .77109 L .5233 .77172 L .255 0 .315 r
F
.53112 .77939 m .53116 .77944 L .52441 .77952 L .322 .245 .612 r
F
.56672 .77868 m .53116 .77944 L .53112 .77939 L F
.56672 .77868 m .56708 .779 L .53116 .77944 L F
.53551 .75125 m .55958 .77241 L .52783 .77945 L F
.53082 .74713 m .53551 .75125 L .52441 .77952 L F
.53551 .75125 m .52783 .77945 L .52441 .77952 L F
.55171 .72303 m .55224 .72242 L .55108 .76494 L F
.55189 .77556 m .5513 .75037 L .55228 .72236 L 0 0 .118 r
F
.5513 .75037 m .55069 .72424 L .55171 .72303 L F
.5513 .75037 m .55171 .72303 L .55228 .72236 L F
.53551 .75125 m .54327 .73773 L .55108 .76494 L .322 .245 .612 r
F
.54217 .736 m .54319 .73287 L .54461 .73984 L 0 0 0 r
F
.5436 .7324 m .5517 .72305 L .5439 .73204 L .857 .745 .23 r
F
.5517 .72305 m .55171 .72303 L .5439 .73204 L F
.5481 .72722 m .55224 .72242 L .5436 .7324 L F
.5439 .73204 m .55171 .72303 L .53551 .75125 L .322 .245 .612 r
F
.52597 .7858 m .54217 .736 L .55189 .77556 L 0 0 0 r
F
.54327 .73773 m .5513 .75037 L .55108 .76494 L .322 .245 .612 r
F
.54217 .736 m .54461 .73984 L .55189 .77556 L 0 0 0 r
F
.54327 .73773 m .55171 .72303 L .5513 .75037 L .322 .245 .612 r
F
.52706 .78246 m .5274 .78103 L .54217 .736 L 0 0 0 r
F
.5274 .78103 m .53551 .75125 L .54217 .736 L F
.52284 .78278 m .52608 .77109 L .52369 .78313 L .255 0 .315 r
F
.5233 .77172 m .52608 .77109 L .52284 .78278 L F
.6042 .85516 m .60567 .74006 L .63799 .84193 L .591 .513 .736 r
F
.6042 .85516 m .57839 .76132 L .60567 .74006 L F
.52176 .76754 m .58895 .85262 L .62291 .86474 L .547 .644 .898 r
F
.58895 .85262 m .59727 .86316 L .62291 .86474 L F
.51556 .78305 m .52369 .78313 L .51798 .78356 L .568 .349 .543 r
F
.50823 .7815 m .52387 .75801 L .51556 .78305 L 0 0 0 r
F
.50221 .77442 m .50777 .77364 L .50557 .77578 L .255 0 .315 r
F
.51556 .78305 m .526 .78525 L .52597 .7858 L 0 0 0 r
F
.52261 .78279 m .52369 .78313 L .51556 .78305 L .255 0 .315 r
F
.49797 .76455 m .58101 .84708 L .581 .847 L .555 .633 .883 r
F
.49797 .76455 m .55423 .83578 L .58101 .84708 L F
.57645 .83949 m .57313 .84376 L .56353 .86971 L .743 .672 .782 r
F
.57622 .84054 m .57839 .83925 L .52176 .76754 L .555 .633 .883 r
F
.58115 .84714 m .57839 .83925 L .57622 .84054 L F
.57595 .84156 m .5762 .84055 L .57523 .84236 L .743 .672 .782 r
F
.5762 .84055 m .57593 .84071 L .57523 .84236 L F
.5863 .93423 m .59129 .85586 L .5809 .84532 L F
.58616 .85066 m .59242 .85701 L .58895 .85262 L .555 .633 .883 r
F
.55687 .95875 m .56341 .95579 L .58521 .89617 L .783 .681 .752 r
F
.55661 .95931 m .56341 .95579 L .55687 .95875 L F
.55474 .96105 m .55646 .95909 L .54541 .9683 L .865 .833 .813 r
F
.54131 .97323 m .53898 .98206 L .54238 .97234 L .783 .681 .752 r
F
.53913 .97832 m .53882 .98203 L .5399 .97797 L .731 .611 .724 r
F
.5399 .97797 m .53882 .98203 L .54013 .9777 L .783 .681 .752 r
F
.53703 .98049 m .53654 .98315 L .53882 .98203 L .862 .644 .606 r
F
.5024 1.02816 m .53607 .98574 L .54075 .97699 L .963 .919 .714 r
F
.54226 .97268 m .54075 .97699 L .54541 .9683 L F
.5024 1.02816 m .54075 .97699 L .54226 .97268 L F
.55012 .95018 m .53898 .98206 L .55661 .95931 L .783 .681 .752 r
F
.53882 .98203 m .53757 .98405 L .53898 .98206 L .923 .957 .632 r
F
.53607 .98574 m .57076 .95247 L .55474 .96105 L .865 .833 .813 r
F
.57076 .95247 m .55886 .95785 L .55474 .96105 L F
.58521 .89617 m .56341 .95579 L .5791 .94022 L .782 .709 .783 r
F
.55886 .95785 m .55687 .95875 L .55646 .95909 L .865 .833 .813 r
F
.55668 .95883 m .55646 .95909 L .55661 .95931 L .783 .681 .752 r
F
.55668 .95883 m .55661 .95931 L .55685 .95876 L F
.55886 .95785 m .55646 .95909 L .55474 .96105 L .865 .833 .813 r
F
.5791 .94022 m .5863 .93423 L .57953 .93712 L .743 .672 .782 r
F
.59202 .93209 m .5863 .93423 L .5791 .94022 L .865 .833 .813 r
F
.59202 .93209 m .5791 .94022 L .57199 .94728 L F
.54986 .94982 m .56357 .94395 L .5809 .84532 L .743 .672 .782 r
F
.56357 .94395 m .58413 .89854 L .5809 .84532 L F
.55217 .94026 m .57491 .84589 L .55437 .9234 L F
.57491 .84589 m .57595 .84156 L .57363 .84683 L F
.57491 .84589 m .57363 .84683 L .56353 .86971 L F
.56199 .87386 m .57313 .84376 L .54247 .88007 L .635 .606 .803 r
F
.57313 .84376 m .56872 .8419 L .54247 .88007 L F
.54986 .94982 m .5809 .84532 L .5762 .84055 L .743 .672 .782 r
F
.57595 .84156 m .57523 .84236 L .56353 .86971 L F
.52692 .78282 m .5274 .78103 L .52706 .78246 L 0 0 0 r
F
.52441 .77952 m .52783 .77948 L .52369 .78313 L .322 .245 .612 r
F
.52783 .77948 m .52692 .78282 L .52369 .78313 L F
.52597 .7858 m .52637 .78421 L .52706 .78246 L 0 0 0 r
F
.52369 .78313 m .52524 .78412 L .52452 .78407 L .592 .48 .695 r
F
.52277 .78457 m .52376 .78401 L .52382 .78479 L 0 0 0 r
F
.52376 .78401 m .52446 .78406 L .52382 .78479 L F
.52382 .78479 m .5246 .78407 L .526 .78525 L F
.5246 .78407 m .52606 .78418 L .526 .78525 L F
.52369 .78313 m .52446 .78406 L .52382 .78479 L .592 .48 .695 r
F
.51798 .78356 m .52369 .78313 L .52382 .78479 L .568 .349 .543 r
F
.49797 .76455 m .57514 .84117 L .52176 .76754 L .555 .633 .883 r
F
.57514 .84117 m .57622 .84054 L .52176 .76754 L F
.56624 .84467 m .56794 .84231 L .56452 .84013 L .635 .606 .803 r
F
.56624 .84467 m .56452 .84013 L .55423 .83578 L F
.50182 .797 m .51854 .80321 L .49807 .78885 L F
.51111 .80609 m .54975 .85145 L .53266 .81982 L .514 .607 .884 r
F
.54157 .82642 m .5542 .84085 L .54597 .82967 L F
.49587 .78393 m .5542 .84085 L .48669 .76374 L F
.5542 .84085 m .5611 .84449 L .49797 .76455 L F
.50321 .80003 m .56624 .84467 L .50182 .797 L .635 .606 .803 r
F
.50333 .80029 m .53924 .84196 L .50752 .80334 L .391 .56 .901 r
F
.51049 .816 m .50728 .80897 L .51176 .81879 L .635 .606 .803 r
F
.50866 .81199 m .50728 .80897 L .51049 .816 L F
.51049 .816 m .53924 .84196 L .50333 .80029 L .391 .56 .901 r
F
.50321 .80003 m .49092 .77327 L .50866 .81199 L .635 .606 .803 r
F
.45098 .76227 m .50752 .80334 L .45413 .76235 L .391 .56 .901 r
F
.51859 .83383 m .52002 .83702 L .52977 .84262 L .093 .444 .88 r
F
.52977 .84262 m .52904 .85646 L .5298 .85809 L .58 .472 .695 r
F
.53926 .87847 m .50321 .80003 L .52904 .85646 L .635 .606 .803 r
F
.50321 .80003 m .50866 .81199 L .52904 .85646 L F
.45413 .76235 m .50321 .80003 L .47428 .76285 L .391 .56 .901 r
F
.56451 .84708 m .56624 .84467 L .50321 .80003 L .635 .606 .803 r
F
.50321 .80003 m .50752 .80334 L .50123 .79567 L .391 .56 .901 r
F
.50321 .80003 m .50123 .79567 L .47428 .76285 L F
.45098 .76227 m .51049 .816 L .50333 .80029 L F
.50915 .81307 m .50866 .81199 L .51049 .816 L .635 .606 .803 r
F
.53924 .84196 m .54975 .85145 L .54381 .84447 L .391 .56 .901 r
F
.53924 .84196 m .54381 .84447 L .47428 .76285 L F
.54031 .88075 m .56451 .84708 L .50321 .80003 L .635 .606 .803 r
F
.47428 .76285 m .51111 .80609 L .53266 .81982 L .514 .607 .884 r
F
.50221 .77442 m .50557 .77578 L .49851 .77535 L .255 0 .315 r
F
.50557 .77578 m .50592 .77764 L .49851 .77535 L F
.49851 .77535 m .50089 .7728 L .50081 .77477 L .142 0 0 r
F
.48669 .76374 m .54157 .82642 L .49797 .76455 L .514 .607 .884 r
F
.54157 .82642 m .54597 .82967 L .49797 .76455 L F
.47428 .76285 m .49587 .78393 L .48669 .76374 L F
.51664 .82952 m .51152 .81831 L .50749 .82448 L .508 .581 .863 r
F
.51152 .81831 m .50425 .81447 L .50749 .82448 L F
.51664 .82952 m .50749 .82448 L .51289 .84117 L F
.45098 .76227 m .50773 .82014 L .5145 .82483 L .391 .56 .901 r
F
.45098 .76227 m .5145 .82483 L .51049 .816 L F
.51595 .8279 m .50915 .81307 L .51774 .83191 L .635 .606 .803 r
F
.50915 .81307 m .51176 .81879 L .51774 .83191 L F
.51289 .84117 m .50575 .8191 L .41786 .77298 L .508 .581 .863 r
F
.42834 .76288 m .48803 .8098 L .45098 .76227 L .093 .444 .88 r
F
.48803 .8098 m .50773 .82014 L .45098 .76227 L F
.40682 .76505 m .45537 .78549 L .42834 .76288 L 0 .193 .618 r
F
.42834 .76288 m .46708 .79421 L .48803 .8098 L .093 .444 .88 r
F
.52413 .84588 m .51774 .83191 L .51805 .84488 L .508 .581 .863 r
F
.51774 .83191 m .51767 .83176 L .51767 .83186 L F
.51774 .83191 m .51767 .83186 L .51805 .84488 L F
.51805 .84488 m .51767 .83186 L .51289 .84117 L F
.51767 .83186 m .51767 .83176 L .51763 .83183 L F
.51767 .83186 m .51763 .83183 L .51289 .84117 L F
.42834 .76288 m .45537 .78549 L .46708 .79421 L .093 .444 .88 r
F
.52357 .84453 m .51595 .8279 L .52243 .84216 L .635 .606 .803 r
F
.51595 .8279 m .51774 .83191 L .52243 .84216 L F
.52357 .84453 m .52243 .84216 L .52403 .84566 L F
.53957 .87913 m .53926 .87847 L .52904 .85646 L F
.52904 .85646 m .52403 .84566 L .52413 .84588 L F
.52582 .85187 m .52488 .89638 L .52898 .85632 L .153 .15 .601 r
F
.52582 .85187 m .52898 .85632 L .52769 .85355 L F
.5298 .85809 m .52991 .93461 L .54193 .88424 L .58 .472 .695 r
F
.54031 .88075 m .53957 .87913 L .53752 .87474 L .635 .606 .803 r
F
.52991 .93461 m .53124 .94295 L .54407 .87956 L .58 .472 .695 r
F
.52991 .93461 m .54407 .87956 L .54296 .87991 L F
.53471 .93693 m .53108 .94328 L .53387 .93852 L .851 .705 .7 r
F
.53145 .9426 m .53108 .94328 L .53471 .93693 L F
.53145 .9426 m .53124 .94295 L .53108 .94328 L F
.53108 .94328 m .53124 .94295 L .53013 .93595 L .722 .573 .687 r
F
.52488 .89638 m .52353 .9607 L .52632 .90795 L .153 .15 .601 r
F
.52632 .90795 m .52299 .88117 L .52268 .88091 L .722 .573 .687 r
F
.52282 .87977 m .52488 .89638 L .52582 .85187 L .153 .15 .601 r
F
.52268 .88091 m .52299 .88117 L .52282 .87977 L .722 .573 .687 r
F
.51894 .91588 m .5184 .92309 L .52353 .9607 L .153 .15 .601 r
F
.5205 .94946 m .51304 .96096 L .52353 .9607 L .439 .15 .376 r
F
.51304 .96096 m .51237 .96458 L .52353 .9607 L F
.51826 .94116 m .51693 .94356 L .5205 .94946 L F
.52991 .93461 m .5238 .95568 L .52993 .94524 L .58 .472 .695 r
F
.5266 .91004 m .5238 .95568 L .52991 .93461 L F
.52904 .85646 m .5238 .95568 L .5298 .85809 L F
.51202 .96645 m .52996 .935 L .51382 .95199 L .722 .573 .687 r
F
.50985 .98389 m .51601 .96891 L .51202 .96645 L F
.51601 .96891 m .52996 .935 L .51202 .96645 L F
.48085 1.00842 m .46892 1.03304 L .48514 1.00508 L .864 .65 .611 r
F
.47543 1.01871 m .46892 1.03304 L .48085 1.00842 L F
.50641 .95988 m .49413 .97515 L .47494 1.01964 L .439 .15 .376 r
F
.46874 1.0331 m .46892 1.03304 L .4797 1.00931 L .864 .65 .611 r
F
.50625 .96291 m .47494 1.01964 L .5102 .96533 L .439 .15 .376 r
F
.51557 .94718 m .51798 .92481 L .5164 .94269 L .722 .573 .687 r
F
.51984 .90367 m .51811 .92697 L .5164 .94269 L F
.51382 .95199 m .52971 .93526 L .52268 .88091 L F
.52971 .93526 m .52996 .935 L .52632 .90795 L F
.52971 .93526 m .52632 .90795 L .52268 .88091 L F
.51131 .84427 m .51528 .90018 L .5114 .8441 L .153 .15 .601 r
F
.51886 .96692 m .51693 .96947 L .51796 .96938 L .685 .415 .508 r
F
.51081 .98359 m .51768 .96993 L .50985 .98389 L .722 .573 .687 r
F
.51651 .96921 m .51681 .9694 L .52353 .9607 L .439 .15 .376 r
F
.46733 1.03343 m .46918 1.033 L .52353 .9607 L F
.52353 .9607 m .51886 .96692 L .51796 .96938 L .685 .415 .508 r
F
.51921 .96926 m .51796 .96938 L .51482 .97797 L F
.52353 .9607 m .51796 .96938 L .51921 .96926 L F
.51768 .96993 m .51796 .96938 L .51728 .96968 L .722 .573 .687 r
F
.51796 .96938 m .53108 .94328 L .51741 .96943 L F
.51796 .96938 m .51741 .96943 L .51728 .96968 L F
.51768 .96993 m .51728 .96968 L .50985 .98389 L F
.47494 1.01964 m .47044 1.02941 L .51681 .9694 L .439 .15 .376 r
F
.47494 1.01964 m .51681 .9694 L .51651 .96921 L F
.51003 .99107 m .51796 .96938 L .50958 .98603 L .851 .705 .7 r
F
.51796 .96938 m .50969 .9791 L .51482 .97797 L .685 .415 .508 r
F
.51693 .96947 m .50969 .9791 L .51796 .96938 L F
.50969 .9791 m .49508 .99854 L .50858 .98447 L F
.50969 .9791 m .50858 .98447 L .51482 .97797 L F
.5102 .96533 m .47494 1.01964 L .51651 .96921 L .439 .15 .376 r
F
.51601 .96891 m .53108 .94328 L .52996 .935 L .722 .573 .687 r
F
.51728 .96968 m .53108 .94328 L .51601 .96891 L F
.46934 .81212 m .45326 .80351 L .45891 .80878 L .308 .581 .938 r
F
.48688 .94517 m .49984 .9312 L .4933 .93006 L .538 .333 .551 r
F
.49277 .92625 m .47548 .96988 L .50295 .93131 L .981 .91 .65 r
F
.514 .93872 m .514 .93871 L .514 .93871 L .582 .471 .693 r
F
.47548 .96988 m .46441 .99784 L .485 .96373 L .981 .91 .65 r
F
.35873 1.01818 m .39599 1.01745 L .36157 1.02221 L .746 .346 .294 r
F
.39599 1.01745 m .38123 1.02095 L .36157 1.02221 L F
.38212 1.02074 m .36751 1.0242 L .37027 1.02357 L 0 0 0 r
F
.38212 1.02074 m .37027 1.02357 L .3713 1.02333 L F
.3789 1.02153 m .3713 1.02333 L .37538 1.0224 L F
.38212 1.02074 m .3713 1.02333 L .3789 1.02153 L F
.38466 1.02017 m .44352 1.03116 L .37959 1.02137 L .783 .326 .159 r
F
.38803 1.01937 m .39881 1.02166 L .38466 1.02017 L F
.39881 1.02166 m .44352 1.03116 L .38466 1.02017 L F
.40117 1.01623 m .38212 1.02074 L .3789 1.02153 L 0 0 0 r
F
.40117 1.01623 m .3789 1.02153 L .38901 1.01914 L F
.3804 1.01775 m .38798 1.01936 L .39599 1.01745 L .746 .346 .294 r
F
.41167 1.02361 m .41537 1.02449 L .38803 1.01937 L .783 .326 .159 r
F
.41537 1.02449 m .44352 1.03116 L .41828 1.0258 L F
.41537 1.02449 m .41828 1.0258 L .38803 1.01937 L F
.44784 1.00505 m .4048 1.01536 L .45589 1.01235 L 0 0 0 r
F
.41167 1.02361 m .38803 1.01937 L .38901 1.01914 L .783 .326 .159 r
F
.4048 1.01536 m .37538 1.0224 L .40813 1.01831 L 0 0 0 r
F
.4048 1.01536 m .40813 1.01831 L .45589 1.01235 L F
.36833 1.00165 m .39449 1.01787 L .36044 1.01146 L .69 .152 0 r
F
.41167 1.02361 m .43746 1.04089 L .44352 1.03116 L .783 .326 .159 r
F
.44352 1.03116 m .45446 1.02369 L .45056 1.02307 L .785 .573 .614 r
F
.45446 1.02369 m .45418 1.02334 L .45056 1.02307 L F
.44352 1.03116 m .44805 1.02594 L .45036 1.02099 L F
.44805 1.02594 m .45056 1.02307 L .45048 1.02225 L F
.44805 1.02594 m .45048 1.02225 L .45036 1.02099 L F
.46188 1.00485 m .45048 1.02225 L .45625 1.02223 L 0 0 0 r
F
.45036 1.02099 m .46774 1.00329 L .4535 1.01632 L .785 .573 .614 r
F
.45625 1.02223 m .44017 1.02227 L .45418 1.02334 L .352 0 0 r
F
.45056 1.02307 m .46774 1.00329 L .45036 1.02099 L .785 .573 .614 r
F
.4535 1.01632 m .45589 1.01235 L .46299 1.00142 L .688 .477 .596 r
F
.4535 1.01632 m .45656 1.01296 L .45589 1.01235 L F
.46774 1.00329 m .46463 1.00412 L .4535 1.01632 L .785 .573 .614 r
F
.46299 1.00142 m .44945 1.02225 L .45048 1.02225 L 0 0 0 r
F
.46299 1.00142 m .45048 1.02225 L .46188 1.00485 L F
.45076 1.02517 m .40524 1.02234 L .44768 1.02682 L .352 0 0 r
F
.45418 1.02334 m .45057 1.02327 L .45076 1.02517 L F
.45057 1.02327 m .40524 1.02234 L .45076 1.02517 L F
.44017 1.02227 m .40524 1.02234 L .45418 1.02334 L F
.40445 1.01877 m .39386 1.0201 L .40976 1.02233 L 0 0 0 r
F
.39386 1.0201 m .40524 1.02234 L .40976 1.02233 L F
.36044 1.01146 m .41167 1.02361 L .35994 1.01341 L .783 .326 .159 r
F
.40718 1.02255 m .43746 1.04089 L .41167 1.02361 L F
.40022 1.02313 m .43746 1.04089 L .40718 1.02255 L F
.40022 1.02313 m .43583 1.0435 L .43746 1.04089 L F
.40524 1.02234 m .37538 1.0224 L .39472 1.02358 L .352 0 0 r
F
.40524 1.02234 m .39472 1.02358 L .40718 1.02255 L F
.39386 1.0201 m .37538 1.0224 L .40524 1.02234 L 0 0 0 r
F
.39091 1.01869 m .39911 1.02322 L .40022 1.02313 L .783 .326 .159 r
F
.39911 1.02322 m .43583 1.0435 L .40022 1.02313 L F
.39472 1.02358 m .38366 1.02291 L .3899 1.02399 L .352 0 0 r
F
.3823 1.02075 m .3899 1.02399 L .39091 1.01869 L .783 .326 .159 r
F
.3899 1.02399 m .43583 1.0435 L .39911 1.02322 L F
.3899 1.02399 m .39911 1.02322 L .39091 1.01869 L F
.40991 1.02743 m .43583 1.0435 L .3899 1.02399 L .69 .152 0 r
F
.40991 1.02743 m .43553 1.05135 L .43583 1.0435 L F
.40822 1.03059 m .43553 1.05135 L .40991 1.02743 L F
.40801 1.03099 m .40561 1.03066 L .40779 1.03141 L .352 0 0 r
F
.40812 1.03078 m .40658 1.03071 L .40801 1.03099 L F
.40658 1.03071 m .40561 1.03066 L .40801 1.03099 L F
.40801 1.03099 m .43553 1.05135 L .40822 1.03059 L .69 .152 0 r
F
.42084 1.03357 m .43553 1.05135 L .40801 1.03099 L 0 .254 .757 r
F
.42084 1.03357 m .43514 1.04403 L .43553 1.05135 L F
.43553 1.05135 m .44015 1.04928 L .43578 1.0447 L .938 .694 .543 r
F
.47709 1.05939 m .54238 .97234 L .52676 .98893 L .963 .919 .714 r
F
.50178 1.04169 m .4954 1.04435 L .47696 1.06032 L .619 .823 .419 r
F
.47696 1.06032 m .4954 1.04435 L .47709 1.05939 L F
.4954 1.04435 m .49446 1.04474 L .47709 1.05939 L F
.47709 1.05939 m .47867 1.05806 L .48972 1.04414 L .963 .919 .714 r
F
.47709 1.05939 m .52676 .98893 L .47815 1.05726 L F
.52174 .99046 m .47564 1.06249 L .51156 1.0103 L .862 .644 .606 r
F
.52676 .98893 m .52821 .98733 L .50841 .99452 L .851 .705 .7 r
F
.5203 .99008 m .47564 1.06249 L .52174 .99046 L .862 .644 .606 r
F
.48085 1.07017 m .47564 1.06249 L .48006 1.07171 L F
.5024 1.02816 m .4759 1.06215 L .48085 1.07017 L F
.4759 1.06215 m .47564 1.06249 L .48085 1.07017 L F
.46808 1.0493 m .46872 1.05049 L .47103 1.05412 L .613 .046 0 r
F
.4766 1.05929 m .47485 1.05895 L .47686 1.06001 L .862 .644 .606 r
F
.47404 1.05879 m .47382 1.05875 L .47395 1.05897 L .685 .415 .508 r
F
.47367 1.05873 m .47696 1.06032 L .4766 1.05929 L .951 .614 .21 r
F
.44868 1.05393 m .47429 1.05971 L .47367 1.05873 L F
.4899 1.05252 m .48085 1.07017 L .49379 1.0506 L .862 .644 .606 r
F
.48085 1.07017 m .48006 1.07171 L .48095 1.07034 L F
.48085 1.07017 m .48095 1.07034 L .49379 1.0506 L F
.52675 1.01738 m .51423 1.03302 L .55987 .99816 L 0 0 0 r
F
.52675 1.01738 m .48897 1.06517 L .51423 1.03302 L F
.51922 1.02175 m .56691 .99408 L .52911 1.01017 L .865 .833 .813 r
F
.56691 .99408 m .56788 .99306 L .52911 1.01017 L F
.53456 1.00776 m .48897 1.06517 L .52675 1.01738 L 0 0 0 r
F
.49116 1.06115 m .48805 1.06579 L .49331 1.05802 L .619 .823 .419 r
F
.48162 1.07493 m .48164 1.07498 L .48159 1.07446 L 0 0 .384 r
F
.48006 1.07171 m .48162 1.07493 L .48129 1.07393 L F
.48006 1.07171 m .48168 1.07481 L .48122 1.07553 L F
.4817 1.07517 m .48181 1.07506 L .48179 1.07503 L 0 0 0 r
F
.48181 1.07506 m .50093 1.05708 L .48179 1.07503 L F
.48757 1.06611 m .48159 1.07446 L .48572 1.06925 L .923 .957 .632 r
F
.4862 1.06704 m .48159 1.07446 L .48757 1.06611 L F
.48236 1.07329 m .48271 1.07333 L .49914 1.04926 L .619 .823 .419 r
F
.5038 1.04231 m .49914 1.04926 L .50948 1.03411 L F
.48236 1.07329 m .49914 1.04926 L .5038 1.04231 L F
.53479 .98881 m .502 1.0416 L .50861 1.03515 L .923 .957 .632 r
F
.4812 1.07555 m .48279 1.07334 L .48272 1.07333 L .619 .823 .419 r
F
.4812 1.07555 m .49682 1.05272 L .49914 1.04926 L F
.48805 1.06579 m .48572 1.06925 L .48897 1.06517 L .923 .957 .632 r
F
.48179 1.07503 m .50093 1.05708 L .48805 1.06579 L 0 0 0 r
F
.48138 1.07541 m .48293 1.07335 L .48284 1.07334 L .619 .823 .419 r
F
.48138 1.07541 m .48537 1.06975 L .4831 1.0729 L F
.4812 1.07555 m .48138 1.07541 L .48284 1.07326 L F
.54032 1.02201 m .49006 1.06735 L .52719 1.0354 L .827 .998 .78 r
F
.4817 1.07517 m .56689 1.00244 L .55021 1.01073 L 0 0 0 r
F
.48138 1.07541 m .49331 1.05802 L .49506 1.0553 L .619 .823 .419 r
F
.48203 1.07617 m .49731 1.06276 L .56689 1.00244 L 0 0 0 r
F
.48203 1.07617 m .49731 1.06276 L .48203 1.07617 L F
.48203 1.07617 m .56689 1.00244 L .48181 1.07552 L F
.48181 1.07552 m .56689 1.00244 L .4817 1.07517 L F
.48182 1.07458 m .50634 1.11463 L .48168 1.07481 L 0 0 .384 r
F
.55427 1.12932 m .51229 1.12402 L .50856 1.11216 L .395 .305 .635 r
F
.48227 1.07386 m .48137 1.0753 L .48271 1.07333 L .619 .823 .419 r
F
.48262 1.07279 m .48006 1.07171 L .48159 1.07446 L .923 .957 .632 r
F
.4823 1.07328 m .48182 1.07458 L .48006 1.07171 L .629 .212 0 r
F
.48034 1.0762 m .48271 1.07333 L .48236 1.07329 L .619 .823 .419 r
F
.49393 1.05053 m .48095 1.07035 L .49415 1.05029 L .923 .957 .632 r
F
.48095 1.07035 m .48006 1.07171 L .48095 1.07035 L F
.48095 1.07035 m .48095 1.07035 L .49415 1.05029 L F
.43553 1.05135 m .4738 1.05875 L .46602 1.04621 L .938 .694 .543 r
F
.43553 1.05135 m .46602 1.04621 L .45569 1.04231 L F
.476 1.05918 m .47435 1.05885 L .4738 1.05875 L .951 .614 .21 r
F
.47376 1.05874 m .4738 1.05875 L .43553 1.05135 L F
.476 1.05918 m .4738 1.05875 L .47376 1.05874 L F
.48129 1.07393 m .48162 1.07493 L .48159 1.07446 L 0 0 .384 r
F
.48006 1.07171 m .48182 1.07458 L .48168 1.07481 L F
.48535 1.04838 m .47564 1.06249 L .5024 1.02816 L .862 .644 .606 r
F
.47513 1.06143 m .47638 1.06355 L .48006 1.07171 L .629 .212 0 r
F
.48095 1.07034 m .49393 1.05053 L .49393 1.05054 L .862 .644 .606 r
F
.48095 1.07035 m .48006 1.07171 L .48262 1.07279 L .923 .957 .632 r
F
.48095 1.07034 m .48006 1.07171 L .48095 1.07035 L .862 .644 .606 r
F
.48223 1.07347 m .50156 1.0455 L .47649 1.06374 L .619 .823 .419 r
F
.47649 1.06374 m .49261 1.05201 L .47696 1.06032 L F
.47466 1.0598 m .47556 1.06173 L .47696 1.06032 L .951 .614 .21 r
F
.47556 1.06173 m .47649 1.06374 L .47655 1.06331 L F
.47556 1.06173 m .47655 1.06331 L .47696 1.06032 L F
.47556 1.06173 m .4823 1.07328 L .48199 1.07306 L .629 .212 0 r
F
.47649 1.06374 m .48199 1.07306 L .48025 1.07184 L F
.47556 1.06173 m .48199 1.07306 L .47649 1.06374 L F
.47556 1.06173 m .48025 1.07184 L .48006 1.07171 L F
.47336 1.08631 m .48223 1.07347 L .47649 1.06374 L .619 .823 .419 r
F
.45751 1.043 m .45689 1.05552 L .46881 1.05782 L .613 .046 0 r
F
.45569 1.04231 m .45689 1.05552 L .45751 1.043 L F
.44868 1.05393 m .47336 1.08631 L .47649 1.06374 L .951 .614 .21 r
F
.47462 1.06024 m .47556 1.06173 L .47638 1.06355 L .629 .212 0 r
F
.47395 1.05897 m .47445 1.05997 L .47556 1.06173 L F
.47395 1.05897 m .47638 1.06355 L .47513 1.06143 L F
.44868 1.05393 m .47649 1.06374 L .47556 1.06173 L .951 .614 .21 r
F
.47429 1.05971 m .47556 1.06173 L .47466 1.0598 L F
.44868 1.05393 m .47556 1.06173 L .47429 1.05971 L F
.47283 1.05846 m .47383 1.05993 L .47014 1.05311 L .613 .046 0 r
F
.46964 1.05232 m .47014 1.05311 L .46808 1.0493 L F
.47283 1.05846 m .47014 1.05311 L .46964 1.05232 L F
.47001 1.06456 m .47336 1.08631 L .45112 1.05377 L 0 .075 .633 r
F
.46881 1.05782 m .46612 1.05798 L .47697 1.06853 L .613 .046 0 r
F
.46612 1.05798 m .45918 1.05838 L .4767 1.06837 L F
.46612 1.05798 m .4767 1.06837 L .47697 1.06853 L F
.48034 1.0762 m .4812 1.07555 L .48137 1.0753 L .619 .823 .419 r
F
.48034 1.0762 m .48137 1.0753 L .48227 1.07386 L F
.49129 1.06036 m .50948 1.03411 L .51092 1.03194 L F
.48034 1.0762 m .49142 1.06019 L .49129 1.06036 L F
.49142 1.06019 m .50948 1.03411 L .49129 1.06036 L F
.48057 1.07207 m .4811 1.07316 L .48128 1.07317 L .629 .212 0 r
F
.48057 1.07207 m .48128 1.07317 L .4821 1.07326 L F
.47445 1.05997 m .4811 1.07316 L .47556 1.06173 L F
.48178 1.07738 m .48183 1.07714 L .48166 1.0752 L 0 0 .384 r
F
.48178 1.07738 m .48166 1.0752 L .48165 1.07521 L F
.48183 1.07714 m .48178 1.07511 L .48166 1.0752 L F
.51037 1.12378 m .49933 1.12239 L .50634 1.11463 L .395 .305 .635 r
F
.48109 1.07698 m .48203 1.07617 L .48097 1.07625 L 0 0 0 r
F
.48178 1.07738 m .48189 1.07772 L .48183 1.07714 L 0 0 .384 r
F
.48833 1.09745 m .49373 1.11588 L .48318 1.10137 L .516 .147 .278 r
F
.48833 1.09745 m .48318 1.10137 L .48283 1.09814 L F
.48034 1.11999 m .47874 1.11825 L .48186 1.09991 L .553 .121 .174 r
F
.49373 1.11588 m .48685 1.1107 L .48099 1.09836 L .516 .147 .278 r
F
.49373 1.11588 m .50086 1.14019 L .48685 1.1107 L F
.49513 1.12106 m .49373 1.11588 L .48833 1.09745 L 0 0 .384 r
F
.49644 1.12564 m .4953 1.1215 L .49513 1.12106 L F
.49645 1.12565 m .4953 1.1215 L .49644 1.12564 L F
.48857 1.09847 m .48833 1.09745 L .48346 1.08084 L F
.48346 1.08088 m .48346 1.08084 L .48294 1.07907 L F
.48857 1.09847 m .48346 1.08084 L .48346 1.08088 L F
.48134 1.0844 m .48283 1.09814 L .48099 1.09836 L .516 .147 .278 r
F
.48099 1.09836 m .48685 1.1107 L .4808 1.10614 L F
.48034 1.11999 m .48172 1.08792 L .47993 1.09776 L .553 .121 .174 r
F
.48172 1.08792 m .48134 1.0844 L .47993 1.09776 L F
.48034 1.11999 m .48136 1.10656 L .48373 1.10835 L F
.48034 1.11999 m .48395 1.10852 L .48172 1.08792 L F
.49644 1.12563 m .48833 1.09745 L .48857 1.09847 L 0 0 .384 r
F
.49651 1.12586 m .49644 1.12564 L .49644 1.12563 L F
.49644 1.12564 m .48833 1.09745 L .49644 1.12563 L F
.48227 1.07821 m .48978 1.1037 L .48294 1.07907 L F
.48189 1.07772 m .48352 1.08311 L .48227 1.07821 L F
.48352 1.08311 m .48978 1.1037 L .48227 1.07821 L F
.48554 1.09096 m .48646 1.1157 L .48019 1.08332 L 0 0 .183 r
F
.48978 1.1037 m .49651 1.12586 L .48857 1.09847 L 0 0 .384 r
F
.48978 1.1037 m .48857 1.09847 L .48294 1.07907 L F
.48352 1.08311 m .50383 1.11741 L .48978 1.1037 L F
.50383 1.11741 m .50294 1.1184 L .48978 1.1037 L F
.49651 1.12586 m .49645 1.12565 L .49644 1.12564 L F
.4953 1.1215 m .49373 1.11588 L .49513 1.12106 L F
.49651 1.12586 m .49803 1.13088 L .49373 1.11588 L F
.49803 1.13088 m .49866 1.13267 L .49373 1.11588 L F
.48978 1.1037 m .50038 1.11554 L .49803 1.13088 L F
.49746 1.10799 m .49105 1.11248 L .48554 1.09096 L 0 0 .183 r
F
.49105 1.11248 m .48646 1.1157 L .48554 1.09096 L F
.49848 1.10838 m .49631 1.11007 L .49746 1.10799 L .395 .305 .635 r
F
.48525 1.083 m .50383 1.11741 L .48352 1.08311 L 0 0 .384 r
F
.4823 1.07328 m .50547 1.113 L .48182 1.07458 L .629 .212 0 r
F
.50547 1.113 m .50608 1.11405 L .50556 1.11321 L F
.50547 1.113 m .50556 1.11321 L .48182 1.07458 L F
.48272 1.07333 m .48284 1.07326 L .49682 1.05272 L .619 .823 .419 r
F
.49914 1.04926 m .49682 1.05272 L .50948 1.03411 L F
.49506 1.0553 m .49331 1.05802 L .5127 1.02938 L F
.50516 1.04028 m .48805 1.06579 L .5105 1.03805 L .923 .957 .632 r
F
.48805 1.06579 m .48897 1.06517 L .5105 1.03805 L F
.5024 1.02816 m .4899 1.05252 L .53569 .98621 L .862 .644 .606 r
F
.4899 1.05252 m .49379 1.0506 L .53569 .98621 L F
.4766 1.05929 m .47709 1.05939 L .47477 1.05894 L .951 .614 .21 r
F
.5203 .99008 m .47485 1.05895 L .4775 1.05947 L .862 .644 .606 r
F
.4831 1.0729 m .48537 1.06975 L .48805 1.06579 L .619 .823 .419 r
F
.4831 1.0729 m .48805 1.06579 L .49116 1.06115 L F
.52911 1.01017 m .53226 1.00648 L .53515 .98746 L .865 .833 .813 r
F
.53594 .98642 m .49393 1.05053 L .53491 .98834 L .923 .957 .632 r
F
.49393 1.05053 m .49415 1.05029 L .53491 .98834 L F
.49393 1.05054 m .49393 1.05053 L .53617 .98606 L .862 .644 .606 r
F
.49393 1.05053 m .50156 1.0455 L .4948 1.04957 L .619 .823 .419 r
F
.49261 1.05201 m .49611 1.04946 L .49393 1.05053 L F
.49611 1.04946 m .50156 1.0455 L .49393 1.05053 L F
.49261 1.05201 m .49393 1.05053 L .47696 1.06032 L F
.49393 1.05053 m .4899 1.05252 L .47696 1.06032 L F
.53569 .98621 m .49379 1.0506 L .53617 .98606 L .862 .644 .606 r
F
.49379 1.0506 m .49393 1.05054 L .53617 .98606 L F
.52015 1.07616 m .5099 1.07891 L .51371 1.07881 L .534 .924 .853 r
F
.60316 .99195 m .49848 1.06465 L .6078 .99287 L .827 .998 .78 r
F
.6078 .99287 m .49848 1.06465 L .52015 1.07616 L .849 .91 .876 r
F
.52901 1.04683 m .50051 1.10209 L .47976 1.05192 L .417 .456 .793 r
F
.50608 1.11405 m .50634 1.11463 L .48182 1.07458 L .629 .212 0 r
F
.4823 1.07328 m .48228 1.0752 L .48974 1.08752 L F
.49237 1.09188 m .49238 1.09189 L .48138 1.07372 L 0 .075 .633 r
F
.4823 1.07328 m .48974 1.08752 L .49693 1.09924 L .629 .212 0 r
F
.50634 1.11463 m .50633 1.11464 L .48168 1.07481 L 0 0 .384 r
F
.51229 1.12402 m .51037 1.12378 L .5064 1.11456 L .395 .305 .635 r
F
.51037 1.12378 m .50634 1.11463 L .5064 1.11456 L F
.50515 1.11977 m .50809 1.11748 L .50652 1.1224 L 0 0 .384 r
F
.48168 1.07481 m .50698 1.11569 L .50515 1.11977 L F
.50698 1.11569 m .50809 1.11748 L .50515 1.11977 L F
.48168 1.07481 m .50652 1.1224 L .48122 1.07553 L F
.49969 1.10367 m .50008 1.10431 L .49746 1.10799 L .417 .456 .793 r
F
.4823 1.07328 m .49658 1.09861 L .50608 1.11405 L .629 .212 0 r
F
.49658 1.09861 m .50379 1.11037 L .50608 1.11405 L F
.64911 1.00997 m .52015 1.07616 L .54706 1.11325 L .776 .778 .854 r
F
.6078 .99287 m .52015 1.07616 L .64911 1.00997 L .849 .91 .876 r
F
.53262 1.05862 m .50856 1.11216 L .50379 1.11037 L .417 .456 .793 r
F
.50008 1.10431 m .50379 1.11037 L .49746 1.10799 L F
.53262 1.05862 m .50379 1.11037 L .50008 1.10431 L F
.49969 1.10367 m .49746 1.10799 L .49237 1.09188 L F
.49658 1.09861 m .49763 1.10046 L .50379 1.11037 L .629 .212 0 r
F
.50856 1.11216 m .49631 1.11007 L .49848 1.10838 L .395 .305 .635 r
F
.50856 1.11216 m .49272 1.11655 L .49631 1.11007 L F
.48438 1.11253 m .50086 1.14019 L .49972 1.13983 L .516 .147 .278 r
F
.48435 1.11216 m .50086 1.14019 L .48438 1.11253 L F
.55427 1.12932 m .54054 1.15216 L .48034 1.11999 L .395 .305 .635 r
F
.54054 1.15216 m .48865 1.12801 L .48034 1.11999 L F
.50038 1.11554 m .50652 1.1224 L .49803 1.13088 L 0 0 .384 r
F
.49933 1.12239 m .49488 1.12183 L .50856 1.11216 L .395 .305 .635 r
F
.49488 1.12183 m .49272 1.11655 L .50856 1.11216 L F
.50608 1.11405 m .50809 1.11748 L .50634 1.11463 L .629 .212 0 r
F
.50675 1.1152 m .49763 1.10046 L .50809 1.11748 L F
.50608 1.11405 m .50379 1.11037 L .50675 1.1152 L F
.50379 1.11037 m .49763 1.10046 L .50675 1.1152 L F
.52901 1.04683 m .53262 1.05862 L .50008 1.10431 L .417 .456 .793 r
F
.52901 1.04683 m .50008 1.10431 L .49969 1.10367 L F
.69509 1.04046 m .54706 1.11325 L .57781 1.17549 L .699 .653 .801 r
F
.64911 1.00997 m .54706 1.11325 L .69509 1.04046 L .776 .778 .854 r
F
.53262 1.05862 m .55427 1.12932 L .50856 1.11216 L .417 .456 .793 r
F
.49238 1.09189 m .49746 1.10799 L .48029 1.07191 L 0 .075 .633 r
F
.48974 1.08752 m .49009 1.0882 L .49237 1.09188 L .629 .212 0 r
F
.48974 1.08752 m .49237 1.09188 L .49693 1.09924 L F
.48138 1.07372 m .48029 1.07191 L .48029 1.07191 L 0 .075 .633 r
F
.49238 1.09189 m .48029 1.07191 L .48138 1.07372 L F
.4811 1.07316 m .48138 1.07372 L .4823 1.07328 L .629 .212 0 r
F
.48138 1.07372 m .48228 1.07549 L .48228 1.0752 L F
.48138 1.07372 m .48228 1.0752 L .4823 1.07328 L F
.48031 1.07194 m .48046 1.07218 L .4794 1.07023 L .613 .046 0 r
F
.47932 1.0701 m .4794 1.07023 L .47383 1.05993 L F
.48031 1.07194 m .4794 1.07023 L .47932 1.0701 L F
.48122 1.07553 m .48525 1.083 L .48352 1.08311 L 0 0 .384 r
F
.48081 1.07618 m .48028 1.07703 L .48138 1.07541 L .619 .823 .419 r
F
.47336 1.08631 m .48028 1.07703 L .48081 1.07618 L F
.47957 1.07831 m .48115 1.07692 L .48109 1.07698 L 0 0 0 r
F
.47957 1.07831 m .48109 1.07698 L .48097 1.07625 L F
.47825 1.08001 m .47957 1.07831 L .48097 1.07625 L .619 .823 .419 r
F
.48029 1.07191 m .49746 1.10799 L .4767 1.06837 L 0 .075 .633 r
F
.46602 1.04621 m .45751 1.043 L .47697 1.06853 L .613 .046 0 r
F
.46602 1.04621 m .47697 1.06853 L .47856 1.06944 L F
.46602 1.04621 m .48073 1.07345 L .48097 1.07314 L F
.47704 1.06653 m .4767 1.06837 L .46818 1.05267 L 0 .075 .633 r
F
.4767 1.06837 m .47336 1.08631 L .47001 1.06456 L F
.4767 1.06837 m .47001 1.06456 L .46818 1.05267 L F
.47856 1.06944 m .47697 1.06853 L .48073 1.07345 L .613 .046 0 r
F
.46818 1.05267 m .47704 1.06653 L .46818 1.05267 L 0 .075 .633 r
F
.47293 1.05861 m .48031 1.07194 L .47383 1.05993 L .613 .046 0 r
F
.47673 1.06415 m .48057 1.07207 L .4821 1.07326 L .629 .212 0 r
F
.47673 1.06415 m .4821 1.07326 L .4823 1.07328 L F
.47556 1.06173 m .47673 1.06415 L .4823 1.07328 L F
.47283 1.05846 m .47291 1.05861 L .47293 1.05861 L .613 .046 0 r
F
.47291 1.05861 m .48029 1.07191 L .47293 1.05861 L F
.48029 1.07191 m .48097 1.07314 L .48031 1.07194 L F
.48029 1.07191 m .48031 1.07194 L .47293 1.05861 L F
.47704 1.06653 m .48029 1.07191 L .47704 1.06653 L 0 .075 .633 r
F
.48097 1.07314 m .48101 1.07315 L .48074 1.07265 L .613 .046 0 r
F
.48046 1.07218 m .48074 1.07265 L .46808 1.0493 L F
.48097 1.07314 m .48074 1.07265 L .48046 1.07218 L F
.48279 1.07334 m .48284 1.07326 L .48272 1.07333 L .619 .823 .419 r
F
.48086 1.07285 m .4811 1.07316 L .47395 1.05897 L .613 .046 0 r
F
.48101 1.07315 m .48104 1.07315 L .48086 1.07285 L F
.48104 1.07315 m .4811 1.07316 L .48086 1.07285 L F
.47018 1.05317 m .48101 1.07315 L .4723 1.05655 L F
.47489 1.06148 m .48101 1.07315 L .47602 1.06314 L F
.48284 1.07334 m .48293 1.07335 L .48537 1.06975 L .619 .823 .419 r
F
.47976 1.05192 m .48867 1.08015 L .48029 1.07191 L 0 .075 .633 r
F
.47976 1.05192 m .48029 1.07191 L .47704 1.06653 L F
.48029 1.07191 m .48029 1.07191 L .47704 1.06653 L F
.4649 1.0442 m .47283 1.05846 L .46808 1.0493 L .613 .046 0 r
F
.47429 1.05971 m .47696 1.06032 L .47367 1.05873 L .951 .614 .21 r
F
.46872 1.05049 m .47018 1.05317 L .47141 1.05486 L .613 .046 0 r
F
.47018 1.05317 m .4723 1.05655 L .47141 1.05486 L F
.46872 1.05049 m .47141 1.05486 L .47103 1.05412 L F
.51983 .98996 m .47485 1.05895 L .5203 .99008 L .862 .644 .606 r
F
.51983 .98996 m .47463 1.05794 L .47485 1.05895 L F
.51969 .98992 m .47463 1.05794 L .51983 .98996 L F
.4766 1.05929 m .47696 1.06032 L .47709 1.05939 L .951 .614 .21 r
F
.4775 1.05947 m .4766 1.05929 L .47686 1.06001 L .862 .644 .606 r
F
.46626 1.04633 m .46808 1.0493 L .46766 1.04852 L .613 .046 0 r
F
.4649 1.0442 m .46808 1.0493 L .46626 1.04633 L F
.47156 1.05514 m .47396 1.059 L .47395 1.05897 L F
.46766 1.04852 m .46808 1.0493 L .47103 1.05412 L F
.4738 1.05875 m .4674 1.04673 L .46602 1.04621 L .938 .694 .543 r
F
.476 1.05918 m .4766 1.05929 L .47435 1.05885 L .951 .614 .21 r
F
.4766 1.05929 m .47477 1.05894 L .47435 1.05885 L F
.50909 .98932 m .4846 1.01688 L .47467 1.05755 L .685 .415 .508 r
F
.51482 .97797 m .47467 1.05755 L .49764 1.02321 L F
.47467 1.05755 m .47463 1.05794 L .49764 1.02321 L F
.46188 1.03953 m .47431 1.05576 L .47135 1.03529 L .938 .694 .543 r
F
.47156 1.05514 m .47489 1.06148 L .47396 1.059 L .613 .046 0 r
F
.47489 1.06148 m .47602 1.06314 L .47395 1.05897 L F
.47976 1.05192 m .47704 1.06653 L .46818 1.05267 L 0 .075 .633 r
F
.47704 1.06653 m .47704 1.06653 L .46818 1.05267 L F
.47704 1.06653 m .48029 1.07191 L .4767 1.06837 L F
.48867 1.08015 m .49237 1.09188 L .48029 1.07191 L F
.49237 1.09188 m .48138 1.07372 L .48029 1.07191 L F
.48974 1.08752 m .48228 1.07549 L .49009 1.0882 L .629 .212 0 r
F
.48228 1.0752 m .48228 1.07549 L .48974 1.08752 L F
.49693 1.09924 m .49009 1.0882 L .49763 1.10046 L F
.50051 1.10209 m .49969 1.10367 L .48447 1.06684 L .417 .456 .793 r
F
.49969 1.10367 m .49237 1.09188 L .48447 1.06684 L F
.50051 1.10209 m .48447 1.06684 L .47976 1.05192 L F
.49272 1.11655 m .48034 1.11999 L .49105 1.11248 L .395 .305 .635 r
F
.49272 1.11655 m .49105 1.11248 L .49746 1.10799 L F
.4815 1.08324 m .48019 1.08332 L .47961 1.08031 L 0 0 .183 r
F
.49746 1.10799 m .48019 1.08332 L .4815 1.08324 L F
.48646 1.1157 m .48 1.10147 L .47961 1.08031 L F
.4804 1.07968 m .47961 1.08031 L .47957 1.07831 L F
.49746 1.10799 m .47961 1.08031 L .4804 1.07968 L F
.48616 1.09783 m .47957 1.07831 L .47336 1.08631 L F
.49746 1.10799 m .48431 1.08616 L .48616 1.09783 L F
.48431 1.08616 m .47957 1.07831 L .48616 1.09783 L F
.50383 1.11741 m .50652 1.1224 L .50294 1.1184 L 0 0 .384 r
F
.49488 1.12183 m .48034 1.11999 L .49272 1.11655 L .395 .305 .635 r
F
.47336 1.08631 m .47825 1.08001 L .48028 1.07703 L .619 .823 .419 r
F
.4767 1.06837 m .49746 1.10799 L .48616 1.09783 L 0 .075 .633 r
F
.47608 1.07169 m .48616 1.09783 L .47336 1.08631 L F
.4767 1.06837 m .48616 1.09783 L .47608 1.07169 L F
.48031 1.07194 m .48097 1.07314 L .48046 1.07218 L .613 .046 0 r
F
.48097 1.07314 m .48073 1.07345 L .48228 1.07549 L F
.47697 1.06853 m .45716 1.05849 L .48228 1.07549 L F
.45918 1.05838 m .45716 1.05849 L .47697 1.06853 L F
.45112 1.05377 m .47336 1.08631 L .44868 1.05393 L 0 .075 .633 r
F
.45689 1.05552 m .45716 1.05849 L .46881 1.05782 L .613 .046 0 r
F
.45551 1.04038 m .45569 1.04231 L .45751 1.043 L F
.44015 1.04928 m .47521 1.03355 L .43578 1.0447 L .938 .694 .543 r
F
.43578 1.0447 m .47521 1.03355 L .43583 1.0435 L F
.47521 1.03355 m .47176 1.0335 L .43583 1.0435 L F
.43583 1.0435 m .44812 1.03392 L .44352 1.03116 L .864 .65 .611 r
F
.45611 1.02569 m .45354 1.02676 L .45551 1.04038 L .352 0 0 r
F
.44812 1.03392 m .4524 1.03059 L .44691 1.02909 L .864 .65 .611 r
F
.4524 1.03059 m .45416 1.02468 L .44691 1.02909 L F
.44812 1.03392 m .44691 1.02909 L .44352 1.03116 L F
.45625 1.02223 m .45464 1.0231 L .45611 1.02569 L .352 0 0 r
F
.45464 1.0231 m .45446 1.02369 L .45611 1.02569 L F
.45864 1.02875 m .45551 1.04038 L .46031 1.03332 L F
.45625 1.02223 m .45611 1.02569 L .45864 1.02875 L F
.45611 1.02569 m .45551 1.04038 L .45864 1.02875 L F
.45488 1.0234 m .46821 1.01429 L .45296 1.02187 L .785 .573 .614 r
F
.45418 1.02334 m .45296 1.02187 L .45056 1.02307 L F
.45488 1.0234 m .45296 1.02187 L .45418 1.02334 L F
.47494 1.01964 m .49413 .97515 L .46672 1.03342 L .439 .15 .376 r
F
.48085 1.00842 m .46821 1.01429 L .45446 1.02369 L .864 .65 .611 r
F
.45416 1.02468 m .45446 1.02369 L .44352 1.03116 L F
.45418 1.02334 m .42851 1.03708 L .45611 1.02569 L .352 0 0 r
F
.42851 1.03708 m .42864 1.03722 L .45611 1.02569 L F
.45354 1.02676 m .42864 1.03722 L .44968 1.03969 L F
.44962 1.03989 m .42959 1.03821 L .44566 1.05003 L .613 .046 0 r
F
.44962 1.03989 m .44566 1.05003 L .44654 1.05064 L F
.44724 1.05112 m .45112 1.05377 L .44868 1.05393 L .318 .468 .852 r
F
.45339 1.05495 m .44653 1.05067 L .45363 1.0559 L .613 .046 0 r
F
.44962 1.03989 m .44653 1.05067 L .45339 1.05495 L F
.48085 1.00842 m .45446 1.02369 L .45416 1.02468 L .864 .65 .611 r
F
.45354 1.02676 m .44968 1.03969 L .45551 1.04038 L .352 0 0 r
F
.4524 1.03059 m .48085 1.00842 L .45416 1.02468 L .864 .65 .611 r
F
.45551 1.04038 m .44962 1.03989 L .45716 1.05849 L .613 .046 0 r
F
.44962 1.03989 m .45363 1.0559 L .45716 1.05849 L F
.45569 1.04231 m .46602 1.04621 L .46188 1.03953 L .938 .694 .543 r
F
.42864 1.03722 m .42959 1.03821 L .45551 1.04038 L .352 0 0 r
F
.40718 1.02255 m .39472 1.02358 L .44768 1.02682 L F
.45056 1.02307 m .46821 1.01429 L .5003 .96583 L .785 .573 .614 r
F
.44768 1.02682 m .41143 1.02461 L .43761 1.0322 L .352 0 0 r
F
.40445 1.01877 m .40976 1.02233 L .44945 1.02225 L 0 0 0 r
F
.43853 1.00727 m .43306 1.00857 L .42681 1.01007 L F
.47494 1.01964 m .46672 1.03342 L .46733 1.03343 L .439 .15 .376 r
F
.47494 1.01964 m .46733 1.03343 L .47044 1.02941 L F
.4524 1.03059 m .46874 1.0331 L .4797 1.00931 L .864 .65 .611 r
F
.4582 1.03643 m .46874 1.0331 L .4524 1.03059 L F
.46602 1.04621 m .4674 1.04673 L .46188 1.03953 L .938 .694 .543 r
F
.47176 1.0335 m .46768 1.03343 L .4582 1.03643 L F
.47176 1.0335 m .4582 1.03643 L .45749 1.03747 L F
.47135 1.03529 m .47521 1.05149 L .47689 1.0328 L F
.40712 .97278 m .47976 1.05192 L .45112 1.05377 L .318 .468 .852 r
F
.43761 1.0322 m .41554 1.03114 L .42851 1.03708 L .352 0 0 r
F
.43761 1.0322 m .38697 1.02423 L .40561 1.03066 L F
.41143 1.02461 m .40991 1.02743 L .43761 1.0322 L F
.38366 1.02291 m .37538 1.0224 L .43761 1.0322 L F
.40712 .97278 m .45112 1.05377 L .44724 1.05112 L .318 .468 .852 r
F
.44654 1.05064 m .44566 1.05003 L .44653 1.05067 L .613 .046 0 r
F
.40712 .97278 m .44724 1.05112 L .38373 .98865 L .318 .468 .852 r
F
.44724 1.05112 m .44868 1.05393 L .44367 1.04889 L F
.42959 1.03821 m .44949 1.05331 L .45716 1.05849 L .613 .046 0 r
F
.44724 1.05112 m .44367 1.04889 L .38373 .98865 L .318 .468 .852 r
F
.43476 1.03994 m .44868 1.05393 L .42084 1.03357 L 0 .254 .757 r
F
.42851 1.03708 m .42682 1.03798 L .42864 1.03722 L .352 0 0 r
F
.38373 .98865 m .43476 1.03994 L .42851 1.03708 L 0 .254 .757 r
F
.41496 1.02289 m .42851 1.03708 L .42747 1.0366 L F
.38373 .98865 m .42851 1.03708 L .41496 1.02289 L F
.45464 1.0231 m .45418 1.02334 L .45446 1.02369 L .352 0 0 r
F
.42959 1.03821 m .42682 1.03798 L .44949 1.05331 L .613 .046 0 r
F
.41643 1.02823 m .42747 1.0366 L .42084 1.03357 L 0 .254 .757 r
F
.40596 1.01508 m .39537 1.01759 L .40117 1.01623 L 0 0 0 r
F
.38373 .98865 m .42747 1.0366 L .41643 1.02823 L 0 .254 .757 r
F
.46818 1.05267 m .47001 1.06456 L .45112 1.05377 L 0 .075 .633 r
F
.51229 1.12402 m .5064 1.11456 L .50856 1.11216 L .395 .305 .635 r
F
.50634 1.11463 m .50809 1.11748 L .50633 1.11464 L 0 0 .384 r
F
.50834 1.03581 m .51534 1.03162 L .5127 1.02938 L 0 0 0 r
F
.51534 1.03162 m .51993 1.02578 L .5127 1.02938 L F
.50861 1.03515 m .5105 1.03805 L .52733 1.01687 L .923 .957 .632 r
F
.502 1.0416 m .50516 1.04028 L .50861 1.03515 L F
.50516 1.04028 m .5105 1.03805 L .50861 1.03515 L F
.51092 1.03194 m .50948 1.03411 L .5127 1.02938 L .619 .823 .419 r
F
.53156 1.00093 m .50861 1.03515 L .52733 1.01687 L .923 .957 .632 r
F
.53479 .98881 m .50861 1.03515 L .53156 1.00093 L F
.48097 1.07314 m .48228 1.07549 L .48101 1.07315 L .613 .046 0 r
F
.43514 1.04403 m .44868 1.05393 L .44365 1.05294 L 0 .254 .757 r
F
.43514 1.04403 m .44365 1.05294 L .43553 1.05135 L F
.42864 1.03722 m .42682 1.03798 L .42959 1.03821 L .352 0 0 r
F
.42851 1.03708 m .40812 1.03078 L .42688 1.03795 L F
.41554 1.03114 m .40812 1.03078 L .42851 1.03708 L F
.39091 1.01869 m .40022 1.02313 L .40718 1.02255 L .783 .326 .159 r
F
.41143 1.02461 m .39472 1.02358 L .40991 1.02743 L .352 0 0 r
F
.38373 .98865 m .42084 1.03357 L .36833 1.00165 L 0 .254 .757 r
F
.39472 1.02358 m .3899 1.02399 L .40991 1.02743 L .352 0 0 r
F
.39449 1.01787 m .40991 1.02743 L .3823 1.02075 L .69 .152 0 r
F
.40991 1.02743 m .3899 1.02399 L .3823 1.02075 L F
.38901 1.01914 m .3789 1.02153 L .37622 1.0222 L 0 0 0 r
F
.38901 1.01914 m .37622 1.0222 L .37867 1.02161 L F
.38901 1.01914 m .38803 1.01937 L .35994 1.01341 L .783 .326 .159 r
F
.35873 1.01818 m .37959 1.02137 L .38795 1.01937 L .746 .346 .294 r
F
.35994 1.01341 m .38803 1.01937 L .35873 1.01818 L .783 .326 .159 r
F
.38803 1.01937 m .37959 1.02137 L .35873 1.01818 L F
.36044 1.01146 m .3823 1.02075 L .39091 1.01869 L F
.39449 1.01787 m .3823 1.02075 L .36044 1.01146 L .69 .152 0 r
F
.37407 1.00589 m .40801 1.03099 L .37811 1.00771 L F
.40801 1.03099 m .40822 1.03059 L .37811 1.00771 L F
.40812 1.03078 m .40779 1.03141 L .42688 1.03795 L .352 0 0 r
F
.37811 1.00771 m .40822 1.03059 L .40991 1.02743 L .69 .152 0 r
F
.36833 1.00165 m .37407 1.00589 L .37811 1.00771 L F
.42084 1.03357 m .40801 1.03099 L .36833 1.00165 L 0 .254 .757 r
F
.42688 1.03795 m .40779 1.03141 L .42682 1.03798 L .352 0 0 r
F
.40779 1.03141 m .40561 1.03066 L .40779 1.03141 L F
.40779 1.03141 m .40779 1.03141 L .42682 1.03798 L F
.38697 1.02423 m .37538 1.0224 L .38261 1.02459 L F
.38697 1.02423 m .38261 1.02459 L .42682 1.03798 L F
.45446 1.02369 m .45488 1.0234 L .45418 1.02334 L .785 .573 .614 r
F
.37867 1.02161 m .37622 1.0222 L .37538 1.0224 L 0 0 0 r
F
.45589 1.01235 m .46463 1.00412 L .4666 1.00057 L .688 .477 .596 r
F
.45589 1.01235 m .45917 1.00689 L .46299 1.00142 L F
.45589 1.01235 m .4666 1.00057 L .46236 1.00159 L F
.45656 1.01296 m .46463 1.00412 L .45589 1.01235 L F
.50958 .98603 m .51081 .98359 L .50985 .98389 L .722 .573 .687 r
F
.5298 .85809 m .5266 .91004 L .52991 .93461 L .58 .472 .695 r
F
.54623 .89354 m .54405 .91961 L .55195 .90589 L .731 .611 .724 r
F
.54623 .89354 m .55195 .90589 L .55384 .90262 L F
.53387 .93852 m .53108 .94328 L .52421 .95693 L .851 .705 .7 r
F
.55384 .90262 m .5407 .95963 L .55507 .91802 L .731 .611 .724 r
F
.54405 .91961 m .5407 .95963 L .55384 .90262 L F
.53939 .9236 m .53803 .93093 L .53955 .92807 L F
.51003 .99107 m .53955 .92807 L .51796 .96938 L .851 .705 .7 r
F
.53955 .92807 m .52421 .95693 L .51796 .96938 L F
.54049 .97374 m .54111 .9734 L .54054 .97043 L .731 .611 .724 r
F
.5407 .95963 m .54054 .97043 L .55507 .91802 L F
.53955 .92807 m .54101 .93808 L .5412 .92454 L .851 .705 .7 r
F
.54727 .88106 m .53939 .9236 L .5407 .95963 L .731 .611 .724 r
F
.55437 .9234 m .56353 .86971 L .56022 .87867 L .743 .672 .782 r
F
.5542 .92436 m .54813 .94738 L .55169 .93913 L .783 .681 .752 r
F
.54813 .94738 m .54131 .97323 L .5498 .94973 L F
.52821 .98733 m .54049 .97374 L .5159 .98893 L .851 .705 .7 r
F
.51969 .98992 m .5159 .98893 L .50905 .99316 L F
.52821 .98733 m .5159 .98893 L .51969 .98992 L F
.54049 .97374 m .54052 .97164 L .50905 .99316 L F
.54034 .97776 m .55474 .96105 L .54075 .97699 L .865 .833 .813 r
F
.53607 .98574 m .54305 .97651 L .54034 .97776 L F
.54305 .97651 m .55474 .96105 L .54034 .97776 L F
.54111 .9734 m .54049 .97374 L .53982 .97448 L .963 .919 .714 r
F
.54238 .97234 m .53982 .97448 L .52676 .98893 L F
.48535 1.04838 m .5024 1.02816 L .54226 .97268 L F
.48535 1.04838 m .54226 .97268 L .54238 .97234 L F
.52049 .99013 m .52821 .98733 L .51969 .98992 L .851 .705 .7 r
F
.53226 1.00648 m .59759 .93001 L .53607 .98574 L .865 .833 .813 r
F
.59759 .93001 m .61297 .912 L .59202 .93209 L F
.59759 .93001 m .59202 .93209 L .53607 .98574 L F
.59996 .86368 m .58934 .93309 L .62005 .86759 L .782 .709 .783 r
F
.59333 .89794 m .58934 .93309 L .59996 .86368 L F
.58934 .93309 m .59759 .93001 L .62005 .86759 L F
.59428 .93388 m .58605 .96208 L .59759 .93001 L .865 .833 .813 r
F
.58605 .96208 m .58527 .96473 L .59759 .93001 L F
.62005 .86759 m .58605 .96208 L .62736 .86902 L .782 .709 .783 r
F
.58605 .96208 m .57524 .98642 L .57874 .98711 L .751 .708 .811 r
F
.57115 .99162 m .57661 .98845 L .61297 .912 L .865 .833 .813 r
F
.60707 .93584 m .69644 .80118 L .6197 .92152 L .888 .96 .839 r
F
.60707 .93584 m .6702 .82323 L .69644 .80118 L F
.62736 .86902 m .58605 .96208 L .6078 .99287 L .751 .708 .811 r
F
.58605 .96208 m .57874 .98711 L .6078 .99287 L F
.52911 1.01017 m .57115 .99162 L .58527 .96473 L .865 .833 .813 r
F
.52911 1.01017 m .58527 .96473 L .59428 .93388 L F
.57115 .99162 m .57615 .98941 L .57661 .98845 L F
.56691 .99408 m .57115 .99162 L .56788 .99306 L F
.56622 .9948 m .57615 .98941 L .57115 .99162 L F
.56416 .99696 m .57615 .98941 L .56622 .9948 L F
.56416 .99696 m .55952 1.00457 L .57615 .98941 L F
.55428 1.00734 m .55952 1.00457 L .56416 .99696 L F
.53491 .98834 m .49415 1.05029 L .50191 1.04164 L .923 .957 .632 r
F
.48118 1.03088 m .46768 1.03343 L .47176 1.0335 L .938 .694 .543 r
F
.47521 1.03355 m .48118 1.03088 L .47176 1.0335 L F
.51123 .95389 m .50641 .95988 L .47494 1.01964 L .439 .15 .376 r
F
.4797 1.00931 m .47543 1.01871 L .48085 1.00842 L .864 .65 .611 r
F
.4846 1.01688 m .47048 1.03277 L .48118 1.03088 L .685 .415 .508 r
F
.47689 1.0328 m .47701 1.04797 L .48118 1.03088 L .938 .694 .543 r
F
.48101 1.07315 m .48228 1.07549 L .4811 1.07316 L .613 .046 0 r
F
.46551 1.10461 m .46242 1.1101 L .46636 1.10515 L .695 .275 .246 r
F
.46551 1.10461 m .46656 1.10562 L .46242 1.1101 L F
.49803 1.13088 m .50086 1.14019 L .49866 1.13267 L 0 0 .384 r
F
.49803 1.13088 m .50652 1.1224 L .50086 1.14019 L F
.48035 1.12415 m .48485 1.12625 L .48011 1.13368 L .516 .147 .278 r
F
.47134 1.1102 m .48011 1.13368 L .46763 1.11705 L .695 .275 .246 r
F
.48646 1.1157 m .48034 1.11999 L .48 1.10147 L 0 0 .183 r
F
.57874 .98711 m .56116 1.00409 L .60316 .99195 L .827 .998 .78 r
F
.55952 1.00457 m .57611 .9895 L .57615 .98941 L .865 .833 .813 r
F
.52911 1.01017 m .52733 1.01687 L .53456 1.00776 L .923 .957 .632 r
F
.50905 .99316 m .49764 1.02321 L .51969 .98992 L .685 .415 .508 r
F
.50905 .99316 m .51003 .99107 L .50999 .99068 L .851 .705 .7 r
F
.51482 .97797 m .49508 .99854 L .50909 .98932 L .685 .415 .508 r
F
.40557 .79522 m .39963 .79286 L .34995 .80103 L .438 .876 .871 r
F
.34995 .80103 m .39963 .79286 L .35012 .79903 L F
.39963 .79286 m .39842 .79238 L .35012 .79903 L F
.35012 .79903 m .39842 .79238 L .4068 .79278 L .041 0 0 r
F
.35012 .79903 m .4068 .79278 L .35755 .78603 L F
.39721 .79813 m .40557 .79522 L .34995 .80103 L .438 .876 .871 r
F
.42608 .79964 m .4049 .79403 L .40557 .79522 L 0 .521 .831 r
F
.41068 .79726 m .40557 .79522 L .40634 .79658 L F
.42608 .79964 m .40557 .79522 L .41068 .79726 L F
.30139 .98781 m .30138 .98781 L .28822 .98277 L .655 .102 0 r
F
.34883 .81493 m .39721 .79813 L .34995 .80103 L .438 .876 .871 r
F
.34883 .81493 m .40729 .79827 L .39721 .79813 L F
.40729 .79827 m .40639 .79667 L .39721 .79813 L F
.55159 .78001 m .55189 .77556 L .55269 .77896 L .599 .432 .627 r
F
.55958 .77241 m .5655 .77761 L .5535 .7782 L .322 .245 .612 r
F
.5655 .77761 m .56672 .77868 L .55831 .77885 L F
.55159 .78001 m .5399 .7803 L .55189 .77556 L .599 .432 .627 r
F
.54554 .78105 m .5399 .7803 L .55159 .78001 L F
.56504 .77872 m .56716 .76966 L .56672 .77868 L .569 .453 .682 r
F
.56504 .77872 m .55189 .77556 L .56716 .76966 L F
.55291 .77896 m .55189 .77556 L .56504 .77872 L F
.56673 .77837 m .56676 .77778 L .56708 .779 L .322 .245 .612 r
F
.56672 .77868 m .56673 .77837 L .56708 .779 L F
.57816 .76541 m .56716 .76966 L .57839 .76132 L .569 .453 .682 r
F
.56716 .76966 m .55189 .77556 L .56727 .76729 L F
.56716 .76966 m .56727 .76729 L .57839 .76132 L F
.54217 .736 m .53691 .74157 L .54319 .73287 L 0 0 0 r
F
.54144 .73493 m .5439 .73204 L .53866 .73813 L .857 .745 .23 r
F
.53691 .74157 m .53866 .73813 L .54319 .73287 L 0 0 0 r
F
.53739 .7396 m .53814 .73657 L .54319 .73287 L F
.53866 .73813 m .5439 .73204 L .53082 .74713 L .857 .745 .23 r
F
.53082 .74713 m .5439 .73204 L .53551 .75125 L .322 .245 .612 r
F
.54554 .78105 m .56708 .779 L .56794 .78404 L .592 .48 .695 r
F
.54461 .73984 m .5513 .75037 L .55189 .77556 L 0 0 0 r
F
.039 .916 .04 r
.41997 .87268 m
.44249 .86544 L
s
.44249 .86544 m
.47936 .85359 L
s
.47936 .85359 m
.48523 .85171 L
s
.47972 .85821 m
.48096 .85758 L
s
.48096 .85758 m
.48287 .85661 L
s
.48287 .85661 m
.48533 .85536 L
s
.48533 .85536 m
.4859 .85507 L
s
.4859 .85507 m
.48656 .85474 L
s
.28633 .89729 m .39826 .89444 L .3803 .87371 L .888 .695 .635 r
F
.039 .916 .04 r
.41276 .88223 m
.41364 .87761 L
s
.28995 .91117 m .39826 .89444 L .28633 .89729 L .869 .632 .577 r
F
.30085 .95734 m .45399 .96779 L .2993 .94761 L .806 .462 .406 r
F
.039 .916 .04 r
.39392 .98173 m
.41276 .88223 L
s
.28633 .89729 m .3803 .87371 L .28319 .88296 L .888 .695 .635 r
F
.28319 .88296 m .3803 .87371 L .36488 .85304 L .903 .765 .699 r
F
.60083 .68422 m .55899 .67345 L .55799 .71594 L .893 .762 .71 r
F
.60083 .68422 m .58358 .62142 L .55899 .67345 L F
.64557 .65191 m .58358 .62142 L .60083 .68422 L .744 .663 .771 r
F
.69881 .75293 m .69355 .61225 L .67865 .62514 L .181 .24 .689 r
F
.71386 .7626 m .69355 .61225 L .69881 .75293 L .839 .622 .076 r
F
.039 .916 .04 r
.65719 .86863 m
.66286 .87093 L
s
.65883 .86684 m
.66286 .87093 L
s
.65675 .86472 m
.65883 .86684 L
s
.64557 .65191 m .60487 .56705 L .58358 .62142 L .744 .663 .771 r
F
.67865 .62514 m .60487 .56705 L .64557 .65191 L .557 .59 .842 r
F
.6197 .92152 m .69644 .80118 L .71227 .77959 L .69 .882 .501 r
F
.039 .916 .04 r
.65576 .86806 m
.65719 .86863 L
s
.65482 .86767 m
.65576 .86806 L
s
.64479 .84943 m
.64621 .85041 L
s
.62666 .80624 m
.64662 .79983 L
s
.644 .84824 m
.64621 .85041 L
s
.36488 .85304 m .43608 .80286 L .35394 .83318 L .82 .851 .871 r
F
0 g
.51653 .75716 m
.53814 .73657 L
s
.28097 .86848 m .36488 .85304 L .35394 .83318 L .909 .841 .766 r
F
.28319 .88296 m .36488 .85304 L .28097 .86848 L .903 .765 .699 r
F
0 g
.53814 .73657 m
.55038 .71078 L
s
.55899 .67345 m
.58358 .62142 L
s
.71386 .7626 m .69156 .61819 L .69355 .61225 L .839 .622 .076 r
F
.71227 .77959 m .69156 .61819 L .71386 .7626 L .975 .811 .615 r
F
.67865 .62514 m .60674 .52317 L .60487 .56705 L .557 .59 .842 r
F
0 g
.58358 .62142 m
.60487 .56705 L
s
.69355 .61225 m .60674 .52317 L .67865 .62514 L 0 .045 .559 r
F
.28007 .85416 m .35394 .83318 L .34883 .81493 L .894 .916 .83 r
F
.28097 .86848 m .35394 .83318 L .28007 .85416 L .909 .841 .766 r
F
0 g
.55228 .72212 m
.55899 .67345 L
s
.71227 .77959 m .67781 .64153 L .69156 .61819 L .975 .811 .615 r
F
.69644 .80118 m .67781 .64153 L .71227 .77959 L .869 .758 .738 r
F
.28082 .8403 m .34883 .81493 L .35012 .79903 L .839 .975 .879 r
F
.28007 .85416 m .34883 .81493 L .28082 .8403 L .894 .916 .83 r
F
.69355 .61225 m .58985 .50402 L .60674 .52317 L 0 .045 .559 r
F
0 g
.60487 .56705 m
.60674 .52317 L
s
.69156 .61819 m .58985 .50402 L .69355 .61225 L .859 .552 .466 r
F
0 g
.56676 .77778 m
.56708 .779 L
s
.69644 .80118 m .65716 .67529 L .67781 .64153 L .869 .758 .738 r
F
.039 .916 .04 r
.66041 .64868 m
.66377 .66449 L
s
.6702 .82323 m .65716 .67529 L .69644 .80118 L .762 .685 .778 r
F
.039 .916 .04 r
.68869 .78173 m
.68959 .78601 L
s
.68787 .77792 m
.6879 .77802 L
s
.6879 .77802 m
.68869 .78173 L
s
.68717 .78679 m
.68959 .78601 L
s
.68208 .78843 m
.68281 .78819 L
s
.64662 .79983 m
.66755 .7931 L
s
.68281 .78819 m
.68717 .78679 L
s
.57839 .76132 m .55252 .68936 L .55077 .66583 L 0 0 .485 r
F
.55189 .77556 m .55252 .68936 L .57839 .76132 L 0 0 .118 r
F
0 g
.55038 .71078 m
.55252 .68936 L
s
.25947 .87191 m .29358 .92434 L .28995 .91117 L .888 .595 .084 r
F
.25947 .87191 m .29681 .93655 L .29358 .92434 L .879 .578 .063 r
F
.25947 .87191 m .2993 .94761 L .29681 .93655 L .883 .585 .071 r
F
.25947 .87191 m .28995 .91117 L .28633 .89729 L .907 .634 .134 r
F
.25947 .87191 m .30085 .95734 L .2993 .94761 L .898 .609 .105 r
F
.6702 .82323 m .6325 .71047 L .65716 .67529 L .762 .685 .778 r
F
.63799 .84193 m .6325 .71047 L .6702 .82323 L .662 .599 .774 r
F
.25947 .87191 m .30133 .96563 L .30085 .95734 L .918 .643 .153 r
F
.25947 .87191 m .28633 .89729 L .28319 .88296 L .927 .689 .203 r
F
0 0 0 r
5 Mabswid
.68959 .78601 Mdot
0 g
.5 Mabswid
.63769 .04219 m
.64577 .46291 L
s
.63799 .84193 m .60567 .74006 L .6325 .71047 L .662 .599 .774 r
F
.25947 .87191 m .30076 .9724 L .30133 .96563 L .938 .675 .203 r
F
.28339 .8272 m .35012 .79903 L .35755 .78603 L .718 .986 .886 r
F
.28082 .8403 m .35012 .79903 L .28339 .8272 L .839 .975 .879 r
F
.25947 .87191 m .28319 .88296 L .28097 .86848 L .939 .75 .279 r
F
.039 .916 .04 r
.29112 .89254 m
.37235 .85775 L
s
.37235 .85775 m
.40763 .84264 L
s
.40763 .84264 m
.41429 .83978 L
s
.41429 .83978 m
.45227 .82352 L
s
.45227 .82352 m
.45311 .82316 L
s
.45311 .82316 m
.46306 .81889 L
s
.29095 .89262 m
.29112 .89254 L
s
.29006 .893 m
.29095 .89262 L
s
.28917 .89338 m
.29006 .893 L
s
.2883 .89375 m
.28917 .89338 L
s
.28639 .89457 m
.2883 .89375 L
s
.28557 .89492 m
.28639 .89457 L
s
.28484 .89524 m
.28557 .89492 L
s
.28461 .89533 m
.28484 .89524 L
s
.2911 .90478 m
.39156 .98334 L
s
.29096 .90467 m
.2911 .90478 L
s
.29023 .9041 m
.29096 .90467 L
s
.28941 .90345 m
.29023 .9041 L
s
.28874 .90292 m
.28941 .90345 L
s
.28702 .90158 m
.28874 .90292 L
s
.28595 .90074 m
.28702 .90158 L
s
.28551 .9004 m
.28595 .90074 L
s
.28503 .90003 m
.28551 .9004 L
s
0 g
.56708 .779 m
.56812 .78509 L
s
.60567 .74006 m .55077 .66583 L .54748 .63375 L .245 .367 .789 r
F
.039 .916 .04 r
.35137 .59567 m
.53892 .62539 L
s
.57839 .76132 m .55077 .66583 L .60567 .74006 L 0 0 .485 r
F
0 g
.55077 .66583 m
.55252 .68936 L
s
.69156 .61819 m .56705 .51468 L .58985 .50402 L .859 .552 .466 r
F
.67781 .64153 m .56705 .51468 L .69156 .61819 L .785 .593 .64 r
F
.25947 .87191 m .28097 .86848 L .28007 .85416 L .935 .807 .347 r
F
.57781 1.17549 m .3872 1.28099 L .61462 1.25066 L .769 .676 .76 r
F
0 g
.37931 1.79705 m
.38218 1.61516 L
s
.38745 1.28086 m
.38772 1.26388 L
s
.57781 1.17549 m .39595 1.18084 L .3872 1.28099 L .769 .676 .76 r
F
0 g
.38218 1.61516 m
.38422 1.48573 L
s
.38422 1.48573 m
.38745 1.28096 L
s
.74025 1.08192 m .57781 1.17549 L .61462 1.25066 L .624 .537 .735 r
F
.69509 1.04046 m .57781 1.17549 L .74025 1.08192 L .699 .653 .801 r
F
.61462 1.25066 m .42031 1.3872 L .65748 1.31796 L .727 .554 .657 r
F
.61462 1.25066 m .3872 1.28099 L .42031 1.3872 L F
.77844 1.1269 m .61462 1.25066 L .65748 1.31796 L .534 .409 .656 r
F
.74025 1.08192 m .61462 1.25066 L .77844 1.1269 L .624 .537 .735 r
F
.60567 .74006 m .54748 .63375 L .6325 .71047 L .245 .367 .789 r
F
.039 .916 .04 r
.53892 .62539 m
.65694 .64409 L
s
.25947 .87191 m .28007 .85416 L .28082 .8403 L .905 .847 .394 r
F
.28784 .81511 m .35755 .78603 L .37028 .77616 L .52 .915 .822 r
F
.28339 .8272 m .35755 .78603 L .28784 .81511 L .718 .986 .886 r
F
.6325 .71047 m .54748 .63375 L .5457 .59238 L .576 .563 .802 r
F
0 g
.54748 .63375 m
.55077 .66583 L
s
.67781 .64153 m .55097 .54852 L .56705 .51468 L .785 .593 .64 r
F
0 g
.56705 .51468 m
.58985 .50402 L
s
.65716 .67529 m .55097 .54852 L .67781 .64153 L .711 .6 .73 r
F
.6325 .71047 m .5457 .59238 L .65716 .67529 L .576 .563 .802 r
F
.25947 .87191 m .28082 .8403 L .28339 .8272 L .841 .859 .406 r
F
.65716 .67529 m .5457 .59238 L .55097 .54852 L .711 .6 .73 r
F
0 g
.5457 .59238 m
.54748 .63375 L
s
.55097 .54852 m
.56705 .51468 L
s
.3872 1.28099 m
.39595 1.18084 L
s
.5457 .59238 m
.55097 .54852 L
s
.36751 1.0242 m
.37825 1.02342 L
s
.37825 1.02342 m
.37863 1.02339 L
s
.25947 .87191 m .28339 .8272 L .28784 .81511 L .732 .828 .372 r
F
.2941 .80423 m .37028 .77616 L .38712 .7693 L .287 .774 .698 r
F
.28784 .81511 m .37028 .77616 L .2941 .80423 L .52 .915 .822 r
F
.77844 1.1269 m .65748 1.31796 L .80233 1.16525 L .534 .409 .656 r
F
.65748 1.31796 m .49584 1.45734 L .69651 1.35511 L .65 .404 .533 r
F
.65748 1.31796 m .42031 1.3872 L .49584 1.45734 L F
0 g
.3872 1.28099 m
.42031 1.3872 L
s
.80233 1.16525 m .65748 1.31796 L .69651 1.35511 L .355 .189 .513 r
F
.039 .916 .04 r
.457 .82547 m
.46747 .81824 L
s
.46747 .81824 m
.47078 .81595 L
s
.47078 .81595 m
.47183 .81522 L
s
.47183 .81522 m
.47433 .8135 L
s
.28761 .94245 m
.28782 .94231 L
s
.28716 .94276 m
.28761 .94245 L
s
.28698 .94289 m
.28716 .94276 L
s
.28628 .94338 m
.28698 .94289 L
s
.28573 .94375 m
.28628 .94338 L
s
.28546 .94394 m
.28573 .94375 L
s
.28542 .94397 m
.28546 .94394 L
s
.27127 .95374 m
.27752 .94942 L
s
0 0 0 r
5 Mabswid
.27127 .95374 Mdot
.039 .916 .04 r
.5 Mabswid
.49058 .88339 m
.49805 .88099 L
s
.28962 .94785 m
.48165 .88625 L
s
.28883 .94811 m
.28962 .94785 L
s
.28859 .94818 m
.28883 .94811 L
s
.28771 .94847 m
.28859 .94818 L
s
.28702 .94869 m
.28771 .94847 L
s
.28666 .9488 m
.28702 .94869 L
s
.28658 .94883 m
.28666 .9488 L
s
.48165 .88625 m
.48796 .88423 L
s
.48796 .88423 m
.49058 .88339 L
s
.27127 .95374 m
.27802 .95157 L
s
.49004 .87894 m
.49705 .87872 L
s
.27634 .88564 m
.48068 .87924 L
s
.48068 .87924 m
.4871 .87903 L
s
.4871 .87903 m
.49004 .87894 L
s
.27625 .88565 m
.27634 .88564 L
s
.27578 .88566 m
.27625 .88565 L
s
.2753 .88567 m
.27578 .88566 L
s
.25794 .88622 m
.26277 .88607 L
s
.27486 .88569 m
.2753 .88567 L
s
.27387 .88572 m
.27486 .88569 L
s
.27335 .88574 m
.27387 .88572 L
s
.27304 .88575 m
.27335 .88574 L
s
.27284 .88575 m
.27304 .88575 L
s
.37805 .99127 m
.37848 .99308 L
s
0 g
.39595 1.18084 m
.423 1.11606 L
s
0 0 0 r
5 Mabswid
.25794 .88622 Mdot
.039 .916 .04 r
.5 Mabswid
.51548 .94525 m
.51973 .94622 L
s
.54587 .95221 m
.56833 .95736 L
s
.53478 .94967 m
.54587 .95221 L
s
.53219 .94907 m
.53478 .94967 L
s
.51973 .94622 m
.52955 .94847 L
s
.49819 .94128 m
.50168 .94208 L
s
.5145 .94502 m
.51548 .94525 L
s
.50798 .94353 m
.5145 .94502 L
s
.50168 .94208 m
.50798 .94353 L
s
.47664 .93634 m
.49819 .94128 L
s
.32776 .90222 m
.47664 .93634 L
s
.27628 .89042 m
.32776 .90222 L
s
.2762 .8904 m
.27628 .89042 L
s
.27581 .89031 m
.2762 .8904 L
s
.27537 .89021 m
.27581 .89031 L
s
.25794 .88622 m
.26308 .8874 L
s
.27505 .89014 m
.27537 .89021 L
s
.27423 .88995 m
.27505 .89014 L
s
.27359 .88981 m
.27423 .88995 L
s
.27356 .8898 m
.27359 .88981 L
s
.27321 .88972 m
.27356 .8898 L
s
.25947 .87191 m .28784 .81511 L .2941 .80423 L 0 0 0 r
F
.73274 .91076 m .69509 1.04046 L .74025 1.08192 L .489 .521 .817 r
F
.698 .89157 m .69509 1.04046 L .73274 .91076 L .612 .621 .836 r
F
.698 .89157 m .64911 1.00997 L .69509 1.04046 L F
0 g
.64577 .46291 m
.64769 .56274 L
s
.66162 .87786 m .64911 1.00997 L .698 .89157 L .696 .68 .831 r
F
.66162 .87786 m .6078 .99287 L .64911 1.00997 L F
.2941 .80423 m .38712 .7693 L .30196 .79472 L .287 .774 .698 r
F
.30196 .79472 m .38712 .7693 L .40682 .76505 L 0 0 0 r
F
.76091 .93435 m .74025 1.08192 L .77844 1.1269 L .296 .36 .759 r
F
.73274 .91076 m .74025 1.08192 L .76091 .93435 L .489 .521 .817 r
F
.039 .916 .04 r
.71478 .99092 m
.75791 1.00081 L
s
.75791 1.00081 m
.75795 1.00082 L
s
0 0 0 r
5 Mabswid
.30423 1.39812 Mdot
.62736 .86902 m .6078 .99287 L .66162 .87786 L .751 .708 .811 r
F
.039 .916 .04 r
.5 Mabswid
.56833 .95736 m
.71478 .99092 L
s
.25947 .87191 m .2941 .80423 L .30196 .79472 L 0 0 0 r
F
.039 .916 .04 r
.28782 .94231 m
.457 .82547 L
s
0 g
.57611 .9895 m
.5764 .9889 L
s
.5764 .9889 m
.58111 .97899 L
s
.039 .916 .04 r
.47757 .82666 m
.48244 .8149 L
s
.48244 .8149 m
.4834 .81258 L
s
.45718 .87589 m
.47757 .82666 L
s
.30196 .79472 m .40682 .76505 L .31113 .78671 L 0 0 0 r
F
.31113 .78671 m .40682 .76505 L .42834 .76288 L .061 0 0 r
F
.25947 .87191 m .30196 .79472 L .31113 .78671 L 0 0 0 r
F
.7771 .95982 m .77844 1.1269 L .80233 1.16525 L 0 .053 .589 r
F
.76091 .93435 m .77844 1.1269 L .77725 .97867 L .296 .36 .759 r
F
.80233 1.16525 m .69651 1.35511 L .80334 1.18788 L .355 .189 .513 r
F
.77637 .98406 m .80155 1.15978 L .80334 1.18788 L .757 .548 0 r
F
.80155 1.15978 m .80233 1.16525 L .80236 1.16581 L F
.80155 1.15978 m .80236 1.16581 L .80334 1.18788 L F
.77409 .95508 m .77725 .97867 L .7771 .95982 L .296 .36 .759 r
F
.76091 .93435 m .77725 .97867 L .77409 .95508 L F
0 g
.59138 .85609 m
.59689 .87037 L
s
.59129 .85586 m
.59138 .85609 L
s
.59689 .87037 m
.59807 .87343 L
s
.423 1.11606 m
.44641 1.09596 L
s
.69651 1.35511 m .49584 1.45734 L .57864 1.45583 L .343 0 .156 r
F
0 g
.42031 1.3872 m
.49584 1.45734 L
s
.25947 .87191 m .28289 .97061 L .28375 .97619 L 0 0 .207 r
F
.039 .916 .04 r
.55527 1.23489 m
.61432 1.11991 L
s
.36153 1.61208 m
.55527 1.23489 L
s
.31546 1.70178 m
.36153 1.61208 L
s
.61432 1.11991 m
.68282 .98656 L
s
.68282 .98656 m
.69386 .96505 L
s
.69386 .96505 m
.69605 .96079 L
s
.69605 .96079 m
.69711 .95874 L
s
.69471 .95118 m
.69742 .95048 L
s
.69742 .95048 m
.69816 .95029 L
s
.69816 .95029 m
.69886 .95011 L
s
.72241 .98618 m
.72255 .98497 L
s
.72255 .98497 m
.7227 .98377 L
s
.68939 .9662 m
.71005 .96715 L
s
.71005 .96715 m
.71188 .96723 L
s
.71188 .96723 m
.71223 .96724 L
s
.31113 .78671 m .42834 .76288 L .32126 .78026 L .061 0 0 r
F
.32126 .78026 m .42834 .76288 L .45098 .76227 L .152 0 0 r
F
.25947 .87191 m .31113 .78671 L .32126 .78026 L 0 0 .117 r
F
.69651 1.35511 m .57864 1.45583 L .71118 1.34813 L .343 0 .156 r
F
.80334 1.18788 m .69651 1.35511 L .71118 1.34813 L 0 0 0 r
F
0 g
.4644 1.10266 m
.47175 1.0935 L
s
.3713 1.02333 m
.37538 1.0224 L
s
.36751 1.0242 m
.3713 1.02333 L
s
.039 .916 .04 r
.6809 .92696 m
.6873 .92721 L
s
.6873 .92721 m
.68857 .92726 L
s
.70159 .93917 m
.70218 .94218 L
s
.45131 1.02091 m
.45389 1.02014 L
s
.46097 1.01801 m
.46475 1.01688 L
s
.45389 1.02014 m
.46097 1.01801 L
s
.46741 1.01608 m
.48609 1.01047 L
s
.46475 1.01688 m
.46741 1.01608 L
s
.25947 .87191 m .38269 .80929 L .377 .82127 L .195 0 .293 r
F
.25947 .87191 m .3857 .7987 L .38269 .80929 L .203 0 .308 r
F
.25947 .87191 m .38592 .78968 L .3857 .7987 L .218 0 .333 r
F
.25947 .87191 m .38348 .78234 L .38592 .78968 L .236 .015 .361 r
F
.25947 .87191 m .37862 .77677 L .38348 .78234 L .253 .04 .385 r
F
.32126 .78026 m .45098 .76227 L .33196 .77542 L .152 0 0 r
F
.25947 .87191 m .37169 .77298 L .37862 .77677 L .264 .056 .399 r
F
.33196 .77542 m .45098 .76227 L .47428 .76285 L .211 0 0 r
F
.33196 .77542 m .47428 .76285 L .34279 .77224 L F
.34279 .77224 m .47428 .76285 L .49797 .76455 L .263 0 0 r
F
.34279 .77224 m .49797 .76455 L .35333 .77075 L F
.25947 .87191 m .36311 .77098 L .37169 .77298 L .265 .058 .4 r
F
.25947 .87191 m .35333 .77075 L .36311 .77098 L .252 .041 .386 r
F
.25947 .87191 m .34279 .77224 L .35333 .77075 L .222 .002 .354 r
F
.25947 .87191 m .33196 .77542 L .34279 .77224 L .168 0 .301 r
F
.25947 .87191 m .32126 .78026 L .33196 .77542 L .084 0 .223 r
F
.25947 .87191 m .28336 .96352 L .28289 .97061 L 0 0 .353 r
F
.25947 .87191 m .28545 .95492 L .28336 .96352 L 0 0 .465 r
F
.25947 .87191 m .28938 .94485 L .28545 .95492 L 0 0 .531 r
F
.25947 .87191 m .29528 .93342 L .28938 .94485 L .018 .054 .556 r
F
.25947 .87191 m .30312 .92077 L .29528 .93342 L .11 .09 .552 r
F
.25947 .87191 m .31272 .90712 L .30312 .92077 L .17 .099 .527 r
F
.25947 .87191 m .3237 .89274 L .31272 .90712 L .205 .087 .489 r
F
.25947 .87191 m .33551 .87794 L .3237 .89274 L .22 .061 .442 r
F
.25947 .87191 m .34747 .86306 L .33551 .87794 L .221 .027 .392 r
F
.25947 .87191 m .35884 .84844 L .34747 .86306 L .213 0 .347 r
F
.25947 .87191 m .36889 .83441 L .35884 .84844 L .203 0 .312 r
F
.25947 .87191 m .377 .82127 L .36889 .83441 L .195 0 .294 r
F
.039 .916 .04 r
.34666 .85782 m
.34671 .85803 L
s
.34656 .85741 m
.34657 .85742 L
s
.34657 .85742 m
.34666 .85782 L
s
.3478 .86267 m
.34808 .86385 L
s
.34808 .86385 m
.3481 .86397 L
s
.34779 .86264 m
.3478 .86267 L
s
.34671 .85803 m
.34674 .85815 L
s
.34616 .8557 m
.34656 .85741 L
s
.52176 .76754 m .62736 .86902 L .54506 .77225 L .547 .644 .898 r
F
.54506 .77225 m .62736 .86902 L .66162 .87786 L .487 .637 .921 r
F
0 g
.64769 .56274 m
.6497 .66747 L
s
.5669 .77919 m .66162 .87786 L .698 .89157 L .34 .586 .935 r
F
0 g
.6497 .66747 m
.6506 .71425 L
s
.54506 .77225 m .66162 .87786 L .5669 .77919 L .487 .637 .921 r
F
0 g
.6506 .71425 m
.65114 .74219 L
s
.7771 .95982 m .80233 1.16525 L .77637 .98406 L 0 .053 .589 r
F
.039 .916 .04 r
.78284 1.00652 m
.78579 1.0072 L
s
.28545 .95492 m .36157 1.02221 L .28336 .96352 L 0 .119 .606 r
F
.28545 .95492 m .35873 1.01818 L .36157 1.02221 L F
.58581 .78875 m .698 .89157 L .73274 .91076 L .026 .425 .865 r
F
0 g
.65114 .74219 m
.65172 .77233 L
s
.5669 .77919 m .698 .89157 L .58581 .78875 L .34 .586 .935 r
F
0 g
.65172 .77233 m
.65198 .78606 L
s
0 0 0 r
5 Mabswid
.78579 1.0072 Mdot
.039 .916 .04 r
.5 Mabswid
.77833 1.03318 m
.77834 1.03316 L
s
.78378 1.0142 m
.78461 1.01131 L
s
.78461 1.01131 m
.78579 1.0072 L
s
0 g
.37931 1.79705 m
.97512 1.64732 L
s
.0271 1.50888 m
.37931 1.79705 L
s
.44641 1.09596 m
.46242 1.1101 L
s
.35333 .77075 m .49797 .76455 L .52176 .76754 L .329 0 0 r
F
.28938 .94485 m .35873 1.01818 L .28545 .95492 L 0 .259 .764 r
F
.59992 .80111 m .73274 .91076 L .76091 .93435 L .463 0 0 r
F
.039 .916 .04 r
.59269 .92352 m
.6809 .92696 L
s
.58581 .78875 m .73274 .91076 L .59992 .80111 L .026 .425 .865 r
F
.28938 .94485 m .36044 1.01146 L .35873 1.01818 L 0 .259 .764 r
F
0 0 0 r
5 Mabswid
.35137 .59567 Mdot
.35333 .77075 m .52176 .76754 L .36311 .77098 L .329 0 0 r
F
.36311 .77098 m .52176 .76754 L .54506 .77225 L .411 0 0 r
F
.29528 .93342 m .36044 1.01146 L .28938 .94485 L .126 .362 .823 r
F
.71118 1.34813 m .57864 1.45583 L .61461 1.37859 L .825 .951 .901 r
F
0 g
.5 Mabswid
.49584 1.45734 m
.57864 1.45583 L
s
.039 .916 .04 r
.34616 .8557 m
.34883 .85542 L
s
.34883 .85542 m
.34885 .85542 L
s
.34885 .85542 m
.34942 .85536 L
s
.34942 .85536 m
.34976 .85532 L
s
.34976 .85532 m
.34977 .85532 L
s
.35382 .8549 m
.35412 .85486 L
s
.35412 .85486 m
.35661 .8546 L
s
.35661 .8546 m
.35834 .85442 L
s
.35834 .85442 m
.35851 .8544 L
s
.64068 .82463 m
.64469 .8242 L
s
0 0 0 r
5 Mabswid
.64469 .8242 Mdot
.039 .916 .04 r
.5 Mabswid
.65095 .8476 m
.65106 .84802 L
s
.65088 .84734 m
.65095 .8476 L
s
.6493 .84143 m
.64931 .84148 L
s
.64563 .82772 m
.64918 .84097 L
s
.64918 .84097 m
.6493 .84143 L
s
.64469 .8242 m
.64563 .82772 L
s
0 g
.4644 1.10266 m
.46467 1.10309 L
s
.36311 .77098 m .54506 .77225 L .37169 .77298 L .411 0 0 r
F
.60725 .81614 m .76091 .93435 L .7771 .95982 L .789 .29 0 r
F
.039 .916 .04 r
.65106 .84802 m
.65168 .85032 L
s
.59992 .80111 m .76091 .93435 L .60725 .81614 L .463 0 0 r
F
.039 .916 .04 r
.6309 .82566 m
.64068 .82463 L
s
.63033 .82572 m
.6309 .82566 L
s
0 g
.40742 1.0321 m
.42682 1.03798 L
s
.40323 1.03084 m
.40742 1.0321 L
s
.39538 1.02846 m
.40323 1.03084 L
s
.38261 1.02459 m
.39538 1.02846 L
s
.37538 1.0224 m
.38261 1.02459 L
s
.71118 1.34813 m .61461 1.37859 L .68229 1.30027 L .825 .951 .901 r
F
.039 .916 .04 r
.67545 1.32636 m
.68158 1.32518 L
s
.30423 1.39812 m
.65659 1.33001 L
s
.77407 1.19061 m .71118 1.34813 L .68229 1.30027 L .89 .887 .823 r
F
.039 .916 .04 r
.68158 1.32518 m
.6823 1.31919 L
s
.6823 1.31919 m
.68242 1.31824 L
s
.37731 1.3845 m
.68513 1.29687 L
s
.80334 1.18788 m .71118 1.34813 L .77407 1.19061 L 0 0 0 r
F
.039 .916 .04 r
.75163 1.27794 m
.75712 1.27637 L
s
.75712 1.27637 m
.76155 1.27511 L
s
.76155 1.27511 m
.76501 1.27413 L
s
.76163 1.26149 m
.76294 1.26641 L
s
.76294 1.26641 m
.76403 1.27047 L
s
.76403 1.27047 m
.76501 1.27413 L
s
.75802 1.228 m
.75955 1.23581 L
s
.75786 1.2272 m
.75802 1.228 L
s
.76074 1.25819 m
.76163 1.26149 L
s
.65286 .85472 m
.75028 1.21904 L
s
.7584 1.23614 m
.75955 1.23581 L
s
.34545 1.355 m
.72884 1.24465 L
s
.75198 1.23799 m
.7584 1.23614 L
s
.74929 1.23876 m
.75198 1.23799 L
s
.75126 1.27804 m
.75163 1.27794 L
s
.68497 1.29707 m
.72241 .98618 L
s
.7554 1.00451 m .80334 1.18788 L .77407 1.19061 L .992 .811 .561 r
F
.039 .916 .04 r
.77025 1.06133 m
.77833 1.03318 L
s
.77637 .98406 m .80334 1.18788 L .7554 1.00451 L .757 .548 0 r
F
.37169 .77298 m .54506 .77225 L .5669 .77919 L .493 0 0 r
F
0 0 0 r
5 Mabswid
.76501 1.27413 Mdot
.29528 .93342 m .36833 1.00165 L .36044 1.01146 L .126 .362 .823 r
F
.30312 .92077 m .36833 1.00165 L .29528 .93342 L .309 .415 .808 r
F
.37169 .77298 m .5669 .77919 L .37862 .77677 L .493 0 0 r
F
0 g
.5 Mabswid
.46242 1.1101 m
.46763 1.11705 L
s
.46763 1.11705 m
.47847 1.13149 L
s
.47847 1.13149 m
.48011 1.13368 L
s
.37862 .77677 m .5669 .77919 L .58581 .78875 L .558 .092 .104 r
F
.30312 .92077 m .38373 .98865 L .36833 1.00165 L .309 .415 .808 r
F
.31272 .90712 m .38373 .98865 L .30312 .92077 L .427 .436 .766 r
F
.37862 .77677 m .58581 .78875 L .38348 .78234 L .558 .092 .104 r
F
.60601 .83345 m .7771 .95982 L .77637 .98406 L .873 .468 .257 r
F
.60725 .81614 m .7771 .95982 L .60601 .83345 L .789 .29 0 r
F
.039 .916 .04 r
.53048 .95897 m
.68939 .9662 L
s
.70218 .94218 m
.75514 1.21323 L
s
.38348 .78234 m .59992 .80111 L .38592 .78968 L .601 .177 .209 r
F
.38348 .78234 m .58581 .78875 L .59992 .80111 L F
.31272 .90712 m .40712 .97278 L .38373 .98865 L .427 .436 .766 r
F
.3237 .89274 m .40712 .97278 L .31272 .90712 L .505 .439 .716 r
F
0 g
.49972 1.13983 m
.50086 1.14019 L
s
.48011 1.13368 m
.49972 1.13983 L
s
.38592 .78968 m .60725 .81614 L .3857 .7987 L .626 .239 .29 r
F
.38592 .78968 m .59992 .80111 L .60725 .81614 L F
0 0 0 r
5 Mabswid
.75955 1.23581 Mdot
.3237 .89274 m .43772 .95461 L .40712 .97278 L .505 .439 .716 r
F
.33551 .87794 m .43772 .95461 L .3237 .89274 L .558 .433 .665 r
F
.039 .916 .04 r
.5 Mabswid
.3481 .86397 m
.3548 .89241 L
s
0 g
.44639 1.05121 m
.45112 1.05441 L
s
.43467 1.04328 m
.44639 1.05121 L
s
.42682 1.03798 m
.43467 1.04328 L
s
.45112 1.05441 m
.48228 1.07549 L
s
.3857 .7987 m .60601 .83345 L .38269 .80929 L .639 .284 .353 r
F
.039 .916 .04 r
.58638 .83036 m
.60638 .82824 L
s
.3857 .7987 m .60725 .81614 L .60601 .83345 L .639 .284 .353 r
F
.039 .916 .04 r
.35851 .8544 m
.58183 .83084 L
s
0 0 0 r
5 Mabswid
.68158 1.32518 Mdot
.77407 1.19061 m .68229 1.30027 L .71381 1.1763 L .89 .887 .823 r
F
.039 .916 .04 r
.5 Mabswid
.72935 1.20384 m
.73126 1.1972 L
s
.72222 1.20592 m
.72935 1.20384 L
s
.71402 1.02012 m .77407 1.19061 L .71381 1.1763 L .868 .741 .72 r
F
.039 .916 .04 r
.75152 1.12659 m
.76347 1.08496 L
s
.7554 1.00451 m .77407 1.19061 L .71402 1.02012 L .992 .811 .561 r
F
.33551 .87794 m .47328 .93489 L .43772 .95461 L .558 .433 .665 r
F
.039 .916 .04 r
.39359 .90195 m
.47972 .85821 L
s
.4305 .9172 m
.59269 .92352 L
s
.4265 .95423 m
.42654 .95424 L
s
.42476 .95416 m
.42498 .95417 L
s
.42498 .95417 m
.4265 .95423 L
s
.42527 .95292 m
.42528 .95289 L
s
.42476 .95416 m
.42483 .95399 L
s
.42483 .95399 m
.42527 .95292 L
s
.34747 .86306 m .47328 .93489 L .33551 .87794 L .595 .419 .613 r
F
.039 .916 .04 r
.4405 .91617 m
.45718 .87589 L
s
0 g
.50086 1.14019 m
.50809 1.11748 L
s
.60601 .83345 m .77637 .98406 L .59509 .85247 L .873 .468 .257 r
F
0 g
.65198 .78606 m
.65316 .84731 L
s
.65316 .84731 m
.65325 .85185 L
s
.59509 .85247 m .77637 .98406 L .7554 1.00451 L .865 .543 .44 r
F
0 0 0 r
5 Mabswid
.34616 .8557 Mdot
.38269 .80929 m .59509 .85247 L .377 .82127 L .644 .319 .406 r
F
.38269 .80929 m .60601 .83345 L .59509 .85247 L F
.34747 .86306 m .51046 .91428 L .47328 .93489 L .595 .419 .613 r
F
.039 .916 .04 r
.5 Mabswid
.36847 .91471 m
.36851 .91469 L
s
.36833 .91478 m
.36847 .91471 L
s
.36865 .91479 m
.36872 .9148 L
s
.37295 .91496 m
.3741 .91501 L
s
.3741 .91501 m
.3756 .91506 L
s
.3756 .91506 m
.37566 .91507 L
s
.36872 .9148 m
.37295 .91496 L
s
.36833 .91478 m
.36865 .91479 L
s
.35884 .84844 m .51046 .91428 L .34747 .86306 L .619 .399 .561 r
F
.377 .82127 m .57445 .87262 L .36889 .83441 L .642 .348 .457 r
F
.377 .82127 m .59509 .85247 L .57445 .87262 L F
.68229 1.30027 m .61461 1.37859 L .57665 1.26317 L .77 .68 .764 r
F
0 g
.57864 1.45583 m
.61461 1.37859 L
s
.68229 1.30027 m .57665 1.26317 L .61171 1.23219 L .77 .68 .764 r
F
.039 .916 .04 r
.31306 1.32499 m
.60177 1.24097 L
s
.71381 1.1763 m .68229 1.30027 L .61171 1.23219 L .745 .679 .787 r
F
.35884 .84844 m .54537 .89337 L .51046 .91428 L .619 .399 .561 r
F
.039 .916 .04 r
.37065 .91361 m
.37073 .91357 L
s
.37038 .91374 m
.37065 .91361 L
s
.37073 .91357 m
.37147 .91319 L
s
.37147 .91319 m
.37149 .91318 L
s
.36851 .91469 m
.37038 .91374 L
s
.36889 .83441 m .54537 .89337 L .35884 .84844 L .635 .375 .508 r
F
.36889 .83441 m .57445 .87262 L .54537 .89337 L F
0 g
.49009 1.0882 m
.49368 1.09404 L
s
.49368 1.09404 m
.50809 1.11748 L
s
.48228 1.07549 m
.49009 1.0882 L
s
.61171 1.23219 m .50193 1.16342 L .53067 1.16857 L .671 .501 .647 r
F
.61171 1.23219 m .57665 1.26317 L .50193 1.16342 L F
0 g
.48439 1.13502 m
.50193 1.16342 L
s
.50193 1.16342 m
.52869 1.19915 L
s
.57665 1.26317 m
.61461 1.37859 L
s
.63352 1.15312 m .53067 1.16857 L .55427 1.12932 L .611 .531 .74 r
F
.63352 1.15312 m .61171 1.23219 L .53067 1.16857 L F
0 g
.52869 1.19915 m
.57665 1.26317 L
s
0 0 0 r
5 Mabswid
.36833 .91478 Mdot
.72935 1.20384 Mdot
.31546 1.70178 Mdot
.43772 .95461 m .47976 1.05192 L .40712 .97278 L .523 .531 .805 r
F
.57445 .87262 m .7554 1.00451 L .71402 1.02012 L .825 .572 .557 r
F
.039 .916 .04 r
.5 Mabswid
.6855 .95356 m
.69471 .95118 L
s
.59509 .85247 m .7554 1.00451 L .57445 .87262 L .865 .543 .44 r
F
.43772 .95461 m .52901 1.04683 L .47976 1.05192 L .523 .531 .805 r
F
.039 .916 .04 r
.43785 .95475 m
.53048 .95897 L
s
.71381 1.1763 m .61171 1.23219 L .63352 1.15312 L .745 .679 .787 r
F
0 g
.65963 1.18438 m
.66242 1.32932 L
s
.65642 1.03145 m .71381 1.1763 L .63352 1.15312 L .745 .658 .764 r
F
.71402 1.02012 m .71381 1.1763 L .65642 1.03145 L .868 .741 .72 r
F
.59113 1.03997 m .55427 1.12932 L .52901 1.04683 L .619 .577 .785 r
F
.59113 1.03997 m .63352 1.15312 L .55427 1.12932 L F
0 0 0 r
5 Mabswid
.42476 .95416 Mdot
.47328 .93489 m .52901 1.04683 L .43772 .95461 L .633 .558 .752 r
F
.65642 1.03145 m .63352 1.15312 L .59113 1.03997 L .745 .658 .764 r
F
.54537 .89337 m .71402 1.02012 L .65642 1.03145 L .773 .579 .637 r
F
.039 .916 .04 r
.5 Mabswid
.64082 .9651 m
.65781 .96071 L
s
.57445 .87262 m .71402 1.02012 L .54537 .89337 L .825 .572 .557 r
F
.47328 .93489 m .59113 1.03997 L .52901 1.04683 L .633 .558 .752 r
F
.51046 .91428 m .59113 1.03997 L .47328 .93489 L .71 .573 .699 r
F
.039 .916 .04 r
.55828 .9888 m
.60725 .9741 L
s
.54537 .89337 m .65642 1.03145 L .51046 .91428 L .773 .579 .637 r
F
.51046 .91428 m .65642 1.03145 L .59113 1.03997 L .71 .573 .699 r
F
.039 .916 .04 r
.61182 .97273 m
.61499 .97178 L
s
.61499 .97178 m
.61752 .97112 L
s
.61775 .97106 m
.61779 .97105 L
s
.61779 .97105 m
.61882 .97079 L
s
.61752 .97112 m
.61775 .97106 L
s
0 g
.65325 .85185 m
.6553 .95893 L
s
.6553 .95893 m
.6556 .97432 L
s
.039 .916 .04 r
.60925 .9735 m
.60934 .97347 L
s
.60934 .97347 m
.61182 .97273 L
s
0 g
.6556 .97432 m
.65963 1.18438 L
s
0 0 0 r
5 Mabswid
.61499 .97178 Mdot
0 g
.5 Mabswid
.97512 1.64732 m
.66242 1.32932 L
s
.66242 1.32932 m
.0271 1.50888 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[30]:=",
  ImageSize->{156.25, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002L00017b000`400?l00000o`00003oW03oool0
09`0oooo002L0?ooo`00W03oool009`0oooo002L0?ooo`00W03oool00680oooo0P00000h0?ooo`00
G`3oool3000000030?ooo`000000oooo03L0oooo001L0?ooo`<00000103oool2000003L0oooo001J
0?ooo`8000001`3oool00`000000oooo0000000f0?ooo`00E`3oool3000000T0oooo00@000000?oo
o`3oool00000=@3oool005D0oooo0P00000<0?ooo`040000003oool0oooo000003D0oooo001B0?oo
o`<000003P3oool01@000000oooo0?ooo`3oool0000003@0oooo001?0?ooo`<000004@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0340oooo001=0?ooo`800000503oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0340oooo001:0?ooo`<000005P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0300oooo00170?ooo`<000006@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo02l0oooo00150?ooo`800000703oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo02h0oooo00120?ooo`<000007P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo02h0oooo00100?ooo`8000008@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo02d0oooo000m0?ooo`<000008`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo02`0oooo000j0?ooo`<000009P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo02`0oooo000h0?ooo`800000:@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo02/0oooo000e0?ooo`<00000:`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
02X0oooo000b0?ooo`<00000;P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02T0
oooo000`0?ooo`800000<@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02T0oooo
000]0?ooo`<00000<`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02P0oooo000[
0?ooo`800000=P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02L0oooo000X0?oo
o`<00000>03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02L0oooo000U0?ooo`<0
0000>`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02H0oooo000S0?ooo`800000
?P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02D0oooo000P0?ooo`<00000@03o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02@0oooo000M0?ooo`<00000@`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02@0oooo000K0?ooo`800000AP3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo02<0oooo000H0?ooo`<00000B03oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0280oooo000F0?ooo`800000B`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0240oooo000C0?ooo`<00000C@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0240oooo000@0?ooo`<00000D03oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0200oooo000?0?ooo`030000003oool0oooo0540oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0O0?ooo`003`3oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool07`3oool000l0oooo0P00001C0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool07P3oool000l0oooo00<000000?ooo`000000DP3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01d0oooo000?0?ooo`040000003oool0
oooo00000540oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0L0?ooo`003`3oool0
1@000000oooo0?ooo`3oool000000500oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0L0?ooo`003`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0K0?ooo`003`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0J0?oo
o`003`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0J0?ooo`003`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`003P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0H0?ooo`003P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`003P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0G0?ooo`003P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0F0?ooo`003P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0E0?ooo`003P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0E0?ooo`003P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0D
0?ooo`003P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0C0?ooo`003P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0B0?ooo`00
3P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0B0?ooo`003P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0A0?ooo`003P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0@0?ooo`003P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0?0?ooo`003P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0>0?ooo`003P3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0903oool2000000l0oooo000>
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0Q
0?ooo`<0000000<0oooo0000003oool03P3oool000h0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo01h0oooo0`0000040?ooo`030000003oool0oooo
00d0oooo000=0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`0K0?ooo`<000001`3oool00`000000oooo0?ooo`0=0?ooo`003@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0603oool3000000X0oooo
00<000000?ooo`3oool03@3oool000d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo01D0oooo0`00000=0?ooo`030000003oool0oooo00d0oooo000=
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0B
0?ooo`<00000403oool00`000000oooo0?ooo`0=0?ooo`003@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool03`3oool3000001<0oooo00<000000?oo
o`3oool03@3oool000d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo00`0oooo0`00000F0?ooo`030000003oool0oooo00d0oooo000=0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`090?ooo`<00000
6@3oool00`000000oooo0?ooo`0=0?ooo`003@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool01P3oool3000001d0oooo00<000000?ooo`3oool0303o
ool000d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo00<0oooo0`00000P0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`03000002<0oooo00<000000?oo
o`3oool0303oool000d0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0a0?ooo`<0
00009P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo02H0oooo0P0000060?ooo`<00000:03oool00`000000oooo0?ooo`0<0?ooo`003@3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02@0oooo00<000000=^=M`002hl00`3o
ool300000080oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00D000000=^=M`3KSGL0fheg000;
S`02000000D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0240oooo00<000000<RGX`3KSGL00P3KSGL0
0`002hl000000?ooo`040?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0303oool0
00d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0N0?ooo`8000000`38Uj<30=^=
M`030000003oool0oooo00<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0<0?oo
o`003@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01/0oooo100000050<RGX`<0
fheg1@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00`0oooo000<0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool05`3oool3000000<0oooo00<000000<RGX`38Uj<0
1038Uj<30=^=M`@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0<0?ooo`00303o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01<0oooo0`0000050?ooo`0300000038
Uj<0b9NS00H0b9NS0`3KSGL30?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0303o
ool000`0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0?0?ooo`<00000203oool0
0`000000]YVj0<RGX`080<RGX`80fheg0P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00`0oooo000<0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02`3oool30000
00/0oooo00<000000;JI^P2fVKX02@38Uj<20=^=M`030?ooo`000000oooo02L0oooo00<000000?oo
o`3oool0303oool000`0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`070?ooo`<0
00003P3oool010000000]YVj0;JI^P2fVKX90<RGX`80fheg00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0<0?ooo`00303oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00<0
oooo0`00000@0?ooo`030000002fVKX0]YVj00@0]YVj2038Uj<00`3KSGL000000?ooo`0W0?ooo`03
0000003oool0oooo00`0oooo000<0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`000000
0P00000C0?ooo`030000002fVKX0]YVj00D0]YVj2038Uj<00`000000fheg0?ooo`0V0?ooo`030000
003oool0oooo00`0oooo000<0?ooo`030000003oool0oooo02H0oooo0`0000050?ooo`030000003o
ool0oooo01@0oooo00<000000;JI^P2fVKX01P2fVKX70<RGX`030000003KSGL0fheg02L0oooo00<0
00000?ooo`3oool02`3oool000`0oooo00<000000?ooo`3oool09@3oool5000000@0oooo00<00000
0?ooo`3oool0503oool00`000000]YVj0;JI^P080;JI^PD0b9NS00@000000<RGX`38Uj<0fheg9P3o
ool00`000000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0?ooo`0U0?ooo`D000000P09jPX2
0?ooo`030000003oool0oooo01@0oooo00<0000009>@c@2fVKX02@2fVKX40<RGX`0500000038Uj<0
b9NS0<RGX`3KSGL09@3oool00`000000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0?ooo`0U
0?ooo`D000000P3oool700WZ2Q80oooo00<0000009>@c@2CT<d02P2fVKX30<RGX`0300000038Uj<0
b9NS0080b9NS00<0fheg0?ooo`3oool08P3oool00`000000oooo0?ooo`0;0?ooo`00303oool00`00
0000oooo0?ooo`0V0?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`L02NX:2`3oool01000
0000Ti3=09>@c@2CT<d;0;JI^P030<RGX`000000b9NS00@0b9NS00<0fheg0?ooo`3oool08@3oool0
0`000000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
00T0oooo1`09jPX40?ooo`030000002CT<d0Ti3=00<0Ti3=2P2fVKX00`000000b9NS0<RGX`040<RG
Xb<0oooo00<000000?ooo`3oool02`3oool000`0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`0@0?ooo`@02NX:00<0000009>@c@2CT<d0102CT<d90;JI^P0300000038Uj<0b9NS00@0
b9NS8`3oool00`000000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo01@0oooo00<0000009>@c@2CT<d01P2CT<d70;JI^P030000002fVKX0]YVj00@0b9NS
8`3oool00`000000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo01@0oooo00<0000003iMb@2CT<d01`2CT<d60;JI^P040000002fVKX0]YVj0;JI^P80b9NS
00<0nLnM0?ooo`3oool08@3oool00`000000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo01@0oooo00<0000003iMb@0nGLT0202CT<d50;JI^P030000002f
VKX0]YVj0080]YVj00<0b9NS0?W?W@3FWa<08P3oool00`000000oooo0?ooo`0;0?ooo`00303oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01D0oooo00<0000003iMb@0nGLT02@2CT<d3
0;JI^P030000002fVKX0]YVj0080]YVj0`3icidR0?ooo`030000003oool0oooo00/0oooo000;0?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool05@3oool010000000?Ug903iMb@0nGLT9
09>@c@80]YVj00<000000;JI^P2fVKX00P2fVKX30?W?WB80oooo00<000000?ooo`3oool02`3oool0
00/0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0E0?ooo`030000000nGLT0?Ug9
0080?Ug92P2CT<d010000000]YVj0;JI^P2fVKX20=k2_080nLnM8P3oool00`000000oooo0?ooo`0;
0?ooo`002`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01D0oooo00<0000003iM
b@0nGLT00`0nGLT909>@c@030000002fVKX0]YVj00<0g/:l0P3icidR0?ooo`030000003oool0oooo
00/0oooo000;0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool05@3oool00`000000
?Ug903iMb@0503iMb@L0Ti3=00<0000009>@c@2fVKX00`3N`[`20?W?WB80oooo00<000000?ooo`3o
ool02`3oool000/0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0E0?ooo`030000
000007`0?Ug900H0?Ug91P2CT<d00`000000Ti3=0=k2_0030=k2_080nLnM8P3oool00`000000oooo
0?ooo`0;0?ooo`002`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01D0oooo00<0
00000000O00007`01`0nGLT509>@c@030000002CT<d0g/:l00@0g/:l00<0nLnM0=JO4`3oool0803o
ool00`000000oooo0?ooo`0;0?ooo`002`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo01D0oooo00<000000000O00007`0200nGLT509>@c@0300000033[lL0g/:l00<0g/:l0P3icidQ
0?ooo`030000003oool0oooo00/0oooo000;0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool05@3oool010000000001l0000O00007`803iMb@<0Ti3=00<0`jo700000033[lL0103N`[`2
0?W?WB80oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0E0?ooo`030000000007`0001l0080001l200nGLT01@2CT<d0`jo70<>_a`000000
`jo700@0g/:l0P3icidR0?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool05@3oool00`0001h0001l0000O0030000O0L0?Ug90`33[lL00`00
0000`jo70<>_a`040=k2_0030?W?W@3oool0oooo0200oooo00<000000?ooo`3oool02P3oool000/0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0D0?ooo`030000000001h0000N00@0
001l1`0nGLT0102YVLH0`jo70<>_a`0000020<>_a`@0g/:l00<0nLnM0?ooo`3oool0803oool00`00
0000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01@0
oooo00<0000000007P0001h01@0007`503iMb@80ZIW60P33[lL00`000000`jo70<>_a`040=k2_003
0?W?W@3oool0oooo0200oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0C0?ooo`8000000P0001h60000O0<0?Ug90`2YVLH20<>_a`040000
0033[lL0`jo70<>_a`<0g/:l00<0nLnM0?ooo`3oool0803oool00`000000oooo0?ooo`0:0?ooo`00
2`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01<0oooo00<00000058nW00001h0
0P0001h60000O00303iMb@2YVLH0ZIW600<0ZIW600<0`jo700000033[lL00P33[lL30=k2_080nLnM
8@3oool00`000000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo0180oooo00<00000058nW01B?Y`00`0001h50000O00309N3_02YVLH0ZIW600@0ZIW600<0
`jo700000033[lL00P33[lL40=k2_0030?W?W@3oool0oooo01l0oooo00<000000?ooo`3oool02P3o
ool000/0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`040000001B?Y`0
0000000000<0000N0`0007`309N3_0H0ZIW600<0`jo700000033[lL00`33[lL30=k2_0030?W?W@3o
ool0oooo01l0oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0@0?ooo`03000000110500DSjL00800000100001h00`0007`0Uh>l09N3_003
09N3_0H0ZIW600<000000<>_a`33[lL00P33[lL30=k2_0030?W?W@3oool0oooo01l0oooo00<00000
0?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool0;`3oool010000000oooo02H0000V0003
03H000P0@`000P3oool0103;mJ<0@@1@0440D0110503000000<0000N00<0^JK609N3_02GPk`0102G
Pk`60:VIaP0300000033[lL0`jo70080`jo70`3N`[`00`3icid0oooo0?ooo`0O0?ooo`030000003o
ool0oooo00X0oooo000:0?ooo`030000003oool0oooo02/0oooo0P0f000804<000<0E0003`1Y0000
0`000000000N058nW002095c[PH0Uh>l1P2YVLH00`000000`jo70<>_a`020<>_a`<0000000<0g/:l
0?ooo`3oool07`3oool00`000000oooo0?ooo`0:0?ooo`002P3oool00`000000oooo0?ooo`0U0?oo
o`0501D0>@0[04d0:`1=03P0FP102V800`133VHM07h00080000000<0TG>^09N3_02GPk`0102GPk`5
0:VIaP0400000033[lL0`jo70<>_a`D000008@3oool00`000000oooo0?ooo`0:0?ooo`002P3oool0
0`000000oooo0?ooo`0T0?ooo`805@0i0P0[04d01P0h05X0@`iV04<>IP133VH0@0YR03`3G140VBde
3P2>5aX609N3_0D0ZIW600@000000<>_a`33[lL0`jo71@00000Q0?ooo`030000003oool0oooo00X0
oooo000:0?ooo`030000003oool0oooo0280oooo00<0000000007@0E03T00P0[04d01@0h05X0@`iV
04<>IP133VH0@0YR0080?0=L8@2I;CD409N3_0D0ZIW600@000000<>_a`33[lL0`jo71@00000Q0?oo
o`030000003oool0oooo00X0oooo000:0?ooo`030000003oool0oooo0240oooo0P000000100E03T0
:`1=02/0C@0h05X304<>IP04040:HP0l0e`0?0=L03L0EA80X3e:402I;CD409N3_0@0ZIW600<00000
0:VIaP33[lL00P33[lL300000280oooo00<000000?ooo`3oool02P3oool000X0oooo00<000000?oo
o`3oool08@3oool01@0000005@0i02/0C@0[04d0>01J0080@`iV00H0@0YR03`3G00l0e`0?0=L03L0
E@0c04h70:=8FQ/0X3e:0P1f000209N3_0@0ZIW600<000000:VIaP33[lL01033[lLS0?ooo`030000
003oool0oooo00X0oooo000:0?ooo`030000003oool0oooo0200oooo00D0000000007@0E03T0:`1=
03P0FP0204<>IP04040:HP0l0e`0?0=L03L0E@<0<`1>4`2SB5X@0:0mBP80MP0000<0Uh>l0:VIaP2Y
VLH00`0000000`2YVLH0`jo70<>_a`020<>_a`030>?eeP3oool0oooo0280oooo00<000000?ooo`3o
ool02@3oool000X0oooo00<000000?ooo`3oool0803oool0100000005@0i02/0C@0h05X204<>IP04
040:HP0l0e`0=`1E03L0E@<0<`1>00<0<@1;0:AAI`2TDFL01@2TDFLG0:=8FPD0X3e:0`1f00000`2G
Pk`0000000000003000000040:VIaP33[lL0`jo70>?eeRD0oooo00<000000?ooo`3oool02@3oool0
00X0oooo00<000000?ooo`3oool07`3oool0100000005@0i02/0C@0h05X204<>IP80?0=L00@0=`1E
03<0CP0c04h0<`1>0`0a04/C0:AAIa00XdQJ0P39BP000`1f00002NX:00WZ2P0200WZ2P80000000<0
ZIW60<>_a`3SmMH09P3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0N
0?ooo`080;_CG`000000:`1=03P0FP133VH0@0YR03`3G00g05D303<0CP@0<@1;1@2TFG@J0:AAI`<0
2NX:0P2SB5X00`09jPX0bDX00<U:000207H0000500000009jPX000000000003Cd]P00P3SmMHV0?oo
o`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo01h0oooo00@0000001D0>@0[
04d0@`iV0P0l0e`303<0CPH0<@1;3P2TFG@F0:AAI`80ggM10P39BP0307H000040000003Cd]P0dm;H
0>?eeRL0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool07@3oool01`2k
del0000M02/0C@133VH0?0=L03L0E@0c04h00`0a04/300000080<`1?102RGh8C0:AIM0h0Y55W0`3O
Md430<U:000307H000000000dm;H0080hoGF9`3oool00`000000oooo0?ooo`090?ooo`002P3oool0
0`000000oooo0?ooo`0M0?ooo`050000000[04d0@0YR03`3G00c04h0100a04/5000000`0XUn25@2T
FG@40:AAI`D0ggM10`39BP000`000000MP000>?eeP0X0?ooo`030000003oool0oooo00T0oooo000:
0?ooo`030000003oool0oooo01`0oooo00@0^m=O01D0>@0l0e`0<`1>0`0a04/303<0C`@000000`2N
IXl@0:9OPQ80Y5Ud0P3MRg060=mg@@040<U:00000000MP0007H002P0oooo00<000000?ooo`3oool0
2@3oool000X0oooo00<000000?ooo`3oool0703oool010000000=`1E0340B`0a04/303<0C`<0=P1H
0`00000809iVSa80XUn22`2TFG@40=f;L0H0ggM100@000000<U:0039BP00MP009`3oool00`000000
oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0L0?ooo`030340B`0c04l0=P1H00<0=P1H
1@0h1V@30000000309Q[W02NIXl0WVJ?00P0WVJ?5@2RGh830:AIM0H0gH]`1@3OMd4010000000bDX0
0<U:0039BP0207H002D0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0
6P3oool00`000000:aV602/IQP0503P?L@H0>0IT1P2HJi`<09iVSa40XUn20`3CTXh70=f;L0<0ggM1
00<000000=mg@@39BP000P39BP0207H002@0oooo00<000000?ooo`3oool02@3oool000T0oooo00<0
00000?ooo`3oool06P3oool2000000030000Q`0[6HH0:aV60080=1Im1`0h3g4208i^ZPP0V6^L3@2N
IXl<0:9OPPD0di:>1`3MRg020=mg@@040000003OMd40ggM10=mg@@<0bDX000<0MP000?ooo`3oool0
8@3oool00`000000oooo0?ooo`090?ooo`002@3oool00`000000oooo0?ooo`0J0?ooo`80000000@0
001J01`GS@0[6HH0:aV60`0d5Wd503P?L@D0SVjZ202HJi`>09iVS`L0XUn21`3CTXh70=f;L0030=mg
@@000000ggM100<0ggM10`39BP000`1f0000oooo0?ooo`0P0?ooo`030000003oool0oooo00T0oooo
00090?ooo`030000003oool0oooo01X0oooo0`0000000`043Hh071N=02/IQP0202/IQP@0=1Im00<0
>0ma08i^ZP2>KZX00P2>KZX01009jPX0SVjZ08i^ZP2>KZX:09Q[W0h0WVJ?0P2RGh8:0=>BSPH0gH]`
00<000000=mg@@3OMd400`3OMd430<U:000307H0003oool0oooo01l0oooo00<000000?ooo`3oool0
2@3oool000T0oooo00<000000?ooo`3oool06`3oool2000000030000Q`0L5hd071N=00<0:aV60`0d
5Wd2085`]`@0SVjZ0`00000208i^ZP/0V6^L2`2NIXl30<FDX`X0di:>1@3MRg000`000000gH]`0=mg
@@050=mg@@<0bDX0803oool00`000000oooo0?ooo`090?ooo`002@3oool00`000000oooo0?ooo`0M
0?ooo`040000M`043Hh071N=01`GS@<0:aV600<0=1Im085`]`21L;L00`21L;L00`2>KZX000000000
0003000000@0SVjZ2`2HJi`609iVS`H0aIBS2P3CTXh40=f;L0030000003MRg00gH]`00H0ggM10`39
BP000`1f0000oooo0?ooo`0L0?ooo`030000003oool0oooo00T0oooo00090?ooo`030000003oool0
oooo01d0oooo00<0001g00@=SP0L5hd00P0L5hd202/IQP80KFo41@21L;L5000000H0SVjZ302HJi`2
09iVS`P0aIBS2`3CTXh20=f;L0030000003MRg00gH]`0080gH]`1@3OMd430<U:000307H0003oool0
oooo01/0oooo00<000000?ooo`3oool02@3oool000T0oooo00<000000?ooo`3oool07@3oool00`00
05X0002700@=SP0301`GS@0402/IQP1]Kl@0KFo406e_a0@0PG2g1@00000808i^ZPX0V6^L0`2eT[89
0<FDX`X0di:>00<0gH]`0000003MRg00103MRg060=mg@@<0bDX0703oool00`000000oooo0?ooo`09
0?ooo`002@3oool00`000000oooo0?ooo`0N0?ooo`030000M`043Hh071N=008071N=0P1?J/h406e_
a0<0PG2g0`0000000`21L;L0SVjZ08i^ZP0908i^ZPD0V6^L1P2eT[890<FDX`X0di:>00<000000=f;
L03MRg00103MRg060=mg@@<0bDX0703oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000
oooo0?ooo`0N0?ooo`040000M`043Hh010f>01`GS@@0Cf[>101]Kl@7085`]``0SVjZ00<0V6^L0;FB
/P2eT[801`2eT[8:0<FDX`P0di:>00<000000=>BSP3MRg001P3MRg050=mg@@<0bDX06`3oool00`00
0000oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`0M0?ooo`040000000007L0002700@=
SP8085cB101?J/h506e_a0L0PG2g00@0SVjZ00000000000000001@2>KZX30::>`0T0]I:b2P35U:<7
0=>BSP030000003CTXh0di:>00L0gH]`1@3OMd420<U:01/0oooo00<000000?ooo`3oool0203oool0
00T0oooo00<000000?ooo`3oool0703oool200000080001g00@010f>021LdP0PG=8085cB101?J/h5
06e_a0H0PG2g1@00000208i^ZPH0XXk02P2eT[890<FDX`H0di:>00@000000=>BSP3CTXh0di:>1`3M
Rg060=mg@@030<U:003oool0oooo01P0oooo00<000000?ooo`3oool0203oool000T0oooo00<00000
0?ooo`3oool0703oool2000000040000FP0007L004;30012``<085cB101?J/h606e_a0@0PG2g1@00
00090::>`0X0]I:b2P35U:<40=>BSP030000003CTXh0di:>0080di:>00<02NX:0=f;L03MRg001@3M
Rg050=mg@@0304]L`P3oool0oooo01L0oooo00<000000?ooo`3oool0203oool000T0oooo00<00000
0?ooo`3oool0703oool3000000040000M`007Y/001jK0012``<085cB101?J/h606e_a0<0PG2g1@00
000:0::>`0X0]I:b1P35U:<3000000060<FDX`3CTXh0di:>0=>BSP0000002NX:1@3CTXh70=f;L0D0
ggM16@3oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`0M0?ooo`800000
00D0001g000NV`007Y/001jK0012``03021LdP@0Cf[>1`1]Kl@2085`]`<000000P25Qlh:0::>`0X0
]I:b1035U:<5000000040<FDX`3CTXh0di:>000000L0di:>1`3MRg040=mg@AT0oooo00<000000?oo
o`3oool0203oool000T0oooo00<000000?ooo`3oool07`3oool00`0003@0S@00000NV`02000NV`04
0012``0PG=8085cB021LdP@0Cf[>1`1]Kl@00`21L;L0QHO>08F7cP0408F7cPX0XXk02P2eT[830<FD
X`D000000`35U:<00`000000di:>0=>BSP070=>BSPL0gH]`0P3OMd4I0?ooo`030000003oool0oooo
00P0oooo00090?ooo`030000003oool0oooo0200oooo00<0X10008d000007Y/00P007Y/01000@/<0
85cB021LdP0PG=8404mZcPD0KFo400<0DGOJ08F7cP25Qlh01P25Qlh:0::>`0/0]I:b00<0aIBS0000
000000000`0000030<FDX`030000003CTXh0di:>00P0di:>1`3MRg000`3OMd40oooo0?ooo`0G0?oo
o`030000003oool0oooo00P0oooo00090?ooo`030000003oool0oooo0200oooo00@0YaX00?Fe@P2=
0000S@000P007Y/01000@/<085cB021LdP0PG=8404mZcP<0KFo40`1AMmX808F7cPX0XXk02`2eT[80
1035U:<000000000000000040<FDX`0300000035U:<0di:>00T0di:>1`3MRg0I0?ooo`030000003o
ool0oooo00P0oooo00090?ooo`030000003oool0oooo02<0oooo00D0YaX008d000007Y/001jK0012
``03021LdP@0Cf[>00<0KFo4055gfP1AMmX00`1AMmX808F7cP/0XXk02P2eT[870<FDX`0400000035
U:<0aIBS0<FDX`X0di:>1@3MRg03000001H0oooo00<000000?ooo`3oool0203oool000P0oooo00<0
00000?ooo`3oool09P3oool0102W6P00S@00000NV`00@/<3021LdP<0Cf[>0P00@L45055gfPP0QHO>
2`2RS/0:0;FB/PH0aIBS00<000000<FDX`35U:<00P35U:<:0=>BSP<0gH]`00<0`H`0000000000000
0P00000E0?ooo`030000003oool0oooo00P0oooo00080?ooo`030000003oool0oooo02P0oooo00<0
S@00000NV`00@/<00`0PG=800`1?J/h004710011`@020011`@D0DGOJ2025Qlh;0::>`0/0]I:b1035
U:<00`000000aIBS0<FDX`040<FDX`T0di:>00D0gH]`0<6<0031S000000000WZ2P02000001D0oooo
00<000000?ooo`3oool0203oool000P0oooo00<000000?ooo`3oool0:P3oool00`007Y/004;3021L
dP030;0V00@004711@1AMmX808F7cP/0XXk02`2eT[830<FDX`0300000035U:<0aIBS00D0aIBS1P3C
TXh20?g?S`<0`H`000@0000000WZ2P00000000005@3oool00`000000oooo0?ooo`080?ooo`00203o
ool00`000000oooo0?ooo`0/0?ooo`<0b5<X0P2`9P040011`@D0DGOJ2025Qlh;0::>`0/0]I:b0P35
U:<00`000000aIBS0<FDX`060<FDX`80di:>1@3mchl40<6<008000005P3oool00`000000oooo0?oo
o`080?ooo`00203oool00`000000oooo0?ooo`0]0?ooo`030;iHB`00000000000080000000@0/2H0
0011`@00@L4004711@1AMmX808F7cP/0XXk02`2eT[800`35U:<000000<FDX`050<FDX`80g[fh203m
chl30<6<01P0oooo00<000000?ooo`3oool0203oool000P0oooo00<000000?ooo`3oool0<@3oool6
000000D0DGOJ2025Qlh;0::>`0/0]I:b00<000000<FDX`3N_KP01`3N_KP70?g?S`<0`H`000<02NX:
0?ooo`3oool05@3oool00`000000oooo0?ooo`080?ooo`00203oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo0080oooo00<0FP000000001AMmX0101AMmX808F7cP/0XXk01@2eT[850;jX
``030000003N_KP0g[fh00L0g[fh1`3mchl30<6<01T0oooo00<000000?ooo`3oool01`3oool000P0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`030?ooo`030011`@000000000000@0
DGOJ2025Qlh80::>`080WY?82P2nZ<<00`000000g[fh0=jm^0070=jm^0L0oLn?0`31S0000`003IH0
oooo0?ooo`0F0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool0103oool00`00@L40DGOJ00000004055gfPP0QHO>0P2RS/0809jCb0T0_ZS3
00<000000=jm^03N_KP0203N_KP70?g?S`80`H`000<000fF0?ooo`3oool05P3oool00`000000oooo
0?ooo`070?ooo`00203oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00H0oooo00<0
W0/00000000000000P004j8806Ydb`X0WY?82@2nZ<<00`000000g[fh0=jm^0080=jm^0L0oLn?0`31
S00H0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool01P3oool3000CXP03000000004j80g:BK00L0JWC;00<0fNSP09jCb02NTlP01`2NTlP9
0;jX``030000002nZ<<0g[fh00P0g[fh1`3mchl30<6<01P0oooo00<000000?ooo`3oool01`3oool0
00P0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`070?ooo`<001>R00<00000000C
XP1ZM</01`1ZM</:09jCb0P0_ZS300<000000;jX``3N_KP02@3N_KP60?g?S`<0`H`0603oool00`00
0000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00P0
oooo0`004j800`000000JWC;06Ydb`0606Ydb`X0WY?8202nZ<<00`000000_ZS30;jX``090=jm^0L0
oLn?0P31S00H0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool02@3oool3000CXP030000001ZM</0JWC;00D0JWC;00<0a/OJ09jCb02NTlP0
202NTlP80;jX``030000002nZ<<0g[fh00T0g[fh103mchl01009jPX0oLn?0<6<0031S00H0?ooo`03
0000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
203oool20680008001>R00<0XCH00000001ZM</01P1ZM</:09jCb0P0_ZS300<000000;jX``3N_KP0
2@3N_KP40?g?S`0400WZ2P3mchl0`H`00<6<01P0oooo00<000000?ooo`3oool01`3oool000P0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`050?ooo`8000000`1R000010000000000^
000CXP00000706Ydb`X0WY?8202nZ<<00`000000_ZS30;jX``090=jm^0@0oLn?00D02NX:0?g?S`31
S000`H`0000=UP0G0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool0103oool01`000000R>cJ068000000000HP000000002aASh00P0002h0
0`000000JWC;06Ydb`0506Ydb`030<K7fP2NTlP0WY?800P0WY?81`2nZ<<00`000000_ZS30;jX``0:
0=jm^0H0oLn?0P31S00G0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool00`3oool01P000000R>cJ08S/fP28k=X0HP0000000080/DHn0`00
02h00`000000JWC;06Ydb`0506Ydb`X0WY?81`2nZ<<010000000_ZS30;jX``2nZ<<90=jm^0H0oLn?
0P31S00G0?ooo`030000003oool0oooo00L0oooo00070?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool00P3oool00`000000R>cJ08S/fP0408S/fP030000002=7R`0000^0080000^00<0
000006Ydb`1ZM</01@1ZM</:09jCb0L0_ZS300@000000;jX``2nZ<<0_ZS32@3N_KP60?g?S`80`H`0
5`3oool00`000000oooo0?ooo`070?ooo`001`3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo0080oooo00<000000<[Gh`3:en<0103:en<00`000000/DHn0000;P0306E>XP030000001U
CZ80IDjR00@0JWC;00<0/ZO=09jCb02NTlP0202NTlP60;jX``040000002nZ<<0_ZS30;jX``X0g[fh
1@3mchl20<6<01L0oooo00<000000?ooo`3oool01`3oool000L0oooo00<000000?ooo`3oool0<P3o
ool01@000000oooo0?ooo`3oool0000000P0b]OS00H0000008@UA`1UCZ80IDjR0000HP00000606E>
XP0306Ydb`2NTlP0WY?800P0WY?81P2nZ<<00`000000_ZS30;jX``020;jX``T0g[fh1P3mchl00`31
S000oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo00070?ooo`030000003oool0oooo0380
oooo00D000000?ooo`3oool0oooo000000090<[Gh`@000001`1UCZ80102bYld0W8Nm09b7_@2LQkd8
09jCb0D0_ZS300<000000;jX``2nZ<<00P2nZ<<90=jm^0H0oLn?00<0`H`00?ooo`3oool05@3oool0
0`000000oooo0?ooo`070?ooo`001`3oool00`000000oooo0?ooo`0b0?ooo`050000003oool0oooo
0?ooo`0000002P3:en<010000000VSmF0000003:en<706E>XPH0W8Nm1@2NTlP50;jX``030000002n
Z<<0_ZS30080_ZS32P3N_KP50?g?S`030<6<003oool0oooo01D0oooo00<000000?ooo`3oool01`3o
ool000L0oooo00<000000?ooo`3oool0<P3oool010000000oooo0?ooo`00000;0<[Gh`0609XoEP00
0000VSmF09XoEP1UCZ80b]OS101UCZ8:09b7_@80WY?81@2nZ<<00`000000_ZS30;jX``030;jX``T0
g[fh1@3mchl20<6<01L0oooo00<000000?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool0
<P3oool010000000oooo0?ooo`00000<0<[Gh`040000002J?eH0VSmF09XoEP@0IDjR3P2LQkd40;jX
``030000002nZ<<0_ZS300<0_ZS32P3N_KP50?g?S`030<6<003oool0oooo01D0oooo00<000000?oo
o`3oool01P3oool000L0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0000000=0<[Gh`03
0000002J?eH0VSmF0080VSmF0P1UCZ800`3:en<0W8Nm09b7_@0<09b7_@<0_Zg900<0_ZS30000002n
Z<<01@2nZ<<90=jm^0D0oLn?00<0`H`00?ooo`3oool05@3oool00`000000oooo0?ooo`060?ooo`00
1`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0000000h0b]OS00<0000009XoEP2J?eH0
0P2J?eH00`1UCZ80W8Nm09b7_@0=09b7_@@0_Zg900<000000;j]b@2nZ<<0102nZ<<90=jm^0D0oLn?
00<0`H`00?ooo`3oool05@3oool00`000000oooo0?ooo`060?ooo`001`3oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0000000h0b]OS00<0Zh2U0000002[P:D0102[P:D=09b7_@D0_Zg900<0
00000;j]b@2n[LT00P2n[LT20;jX``X0g[fh103mchl00`31S000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00H0oooo00070?ooo`030000003oool0oooo0380oooo0P00000@0<[Gh`030:^0Y@000000
Zh2U00@0Zh2U302LQkd50;j]b@030000002n[LT0_Zg900D0_Zg92@3N_KP50?g?SaL0oooo00<00000
0?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool0<P3oool200000140a:g200<0Zh2U0000
002[P:D0102[P:D;09b7_@D0_Zg900<000000;j]b@2n[LT01@2n[LT40>?SdPD0g[fh1@3mchlG0?oo
o`030000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo0380oooo0P00000B0<B]`P03
0:^0Y@000000Zh2U00@0Zh2U2@2LQkd60;j]b@030000002n[LT0_Zg900D0_Zg90P3Shm83000000@0
hn?B00<0g[fh0?g?S`3mchl00P00000G0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000
003oool0oooo0380oooo0P00000C0<B]`P030:^0Y@000000Zh2U00@0Zh2U202LQkd60;j]b@030000
002n[LT0_Zg900D0_Zg900<0hn?B0000000000000`0000040>?SdP@000005`3oool00`000000oooo
0?ooo`060?ooo`001`3oool00`000000oooo0?ooo`0b0?ooo`8000004`34[L800`2[P:D000000:^0
Y@060:^0Y@H0W8Nm1P2n[LT00`000000_Zg90;j]b@040;j]b@80hn?B1@0000040>?SdP<00000603o
ool00`000000oooo0?ooo`060?ooo`001`3oool00`000000oooo0?ooo`0b0?ooo`8000005034[L80
0`2[P:D000000:^0Y@060:^0Y@@0W8Nm1`2n[LT00`000000_Zg90;j]b@040;j]b@80hn?B1@000003
0>?SdP@00000603oool00`000000oooo0?ooo`060?ooo`001`3oool00`000000oooo0?ooo`0b0?oo
o`8000005@34[L800`2[P:D000000:^0Y@060:^0Y@<0W8Nm1`2n[LT00`000000_Zg90;j]b@040;j]
b@<0hn?B0`0000040>?SdP<000006@3oool00`000000oooo0?ooo`060?ooo`001`3oool00`000000
oooo0?ooo`0b0?ooo`8000005P34[L800`000000Zh2U0:^0Y@060:^0Y@80W8Nm1`2n[LT00`000000
_Zg90;j]b@040;j]b@P0hn?B1000000J0?ooo`030000003oool0oooo00H0oooo00060?ooo`030000
003oool0oooo03<0oooo0P00000G0<B]`P030000002[P:D0Zh2U00H0Zh2U202n[LT00`000000_Zg9
0;j]b@030;j]b@P0hn?B1@00000J0?ooo`030000003oool0oooo00H0oooo00060?ooo`030000003o
ool0oooo03<0oooo00<000000<B]`P34[L805P34[L800`2[P:D000000:^0Y@060:^0Y@030<F^``2n
[LT0_Zg900D0_Zg900<000000;j]b@2n[LT00`2n[LT70>?SdPD000006`3oool00`000000oooo0?oo
o`060?ooo`001P3oool00`000000oooo0?ooo`0c0?ooo`0300000034[L80a:g201L0a:g200<0Zh2U
0000002[P:D0102[P:D00`09jPX0aJk30<F^``060;j]b@030000002n[LT0_Zg900<0_Zg91`3Shm85
000001/0oooo00<000000?ooo`3oool01P3oool000H0oooo00<000000?ooo`3oool0<`3oool00`00
0000a:g20<B]`P0F0<B]`P0300WZ2P34[L80000000@0Zh2U1@35[/<50;j]b@030000002n[LT0_Zg9
0080_Zg92@3Shm83000001`0oooo00<000000?ooo`3oool01P3oool000H0oooo00<000000?ooo`3o
ool0<`3oool00`000000a:g20<B]`P0E0<B]`P@02NX:00<000000:^0Y@2[P:D01`35[/<40;j]b@03
0000002n[LT0_Zg90080_Zg92@3Shm820000000300WZ2P3oool0oooo01X0oooo00<000000?ooo`3o
ool01P3oool000H0oooo00<000000?ooo`3oool0<`3oool00`000000a:g20<B]`P0B0<B]`P@02NX:
102jSJP00`000000aJk30<F^``070<F^``<0_Zg900<000000;j]b@2n[LT00P2n[LT90>?SdP@00000
703oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0c0?ooo`0300000034
[L80a:g200h0a:g21009jPX30;Z=Z00300WZ2P2jSJP0^XfX0080^XfX00<000000<F^``35[/<02035
[/<20;j]b@030000002n[LT0_Zg90080_Zg92@3Shm85000001/0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0<`3oool00`000000a:g20<B]`P080<B]`P<0^XfX0`09jPX6
0;Z=Z00300WZ2P2jSJP0^XfX00@0^XfX00<000000<F^``35[/<02035[/<00`2n[LT000000;j]b@02
0;j]b@T0hn?B1P00000K0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
03<0oooo00@000000<B]`P34[L80a:g21P2jSJP400WZ2PT0^XfX00<02NX:0;Z=Z02jSJP0102jSJP0
0`000000aJk30<F^``090<F^``040000002n[LT0_Zg90;j]b@T0hn?B1P00000K0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo03<0oooo00<000000;Z=Z02jSJP0102jSJP3
00WZ2P`0^XfX00<02NX:0;Z=Z02jSJP00P2jSJP300WZ2P0300000035[/<0aJk300T0aJk300@00000
0;j]b@2n[LT0_Zg9203Shm82000000040?ooo`0000000000000001`0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0<`3oool010000000^XfX0;Z=Z02jSJP300WZ2Pl0^XfX
1@09jPX40;Z=Z00300000035[/<0aJk300P0aJk300@000000<F^``2n[LT0_Zg9203Shm800`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03<0oooo
1009jPX?0;Z=Z0@02NX:202jSJP00`000000aJk30<F^``080<F^``0300000035[/<0aJk300T0hn?B
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`0`0?ooo`<02NX:0P00000>0;Z=Z0<02NX:0P2jSJP00`09jPX0^XfX0;Z=Z0070;Z=Z00300000035
[/<0aJk300P0aJk300<000000<F^``35[/<0203Shm800`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo02`0oooo1009jPX30?ooo`8000002P2jSJP4
00WZ2P@0^XfX00<02NX:0;Z=Z02jSJP02@2jSJP00`000000aJk30<F^``070<F^``0300000035[/<0
aJk3008000001P3Shm800`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo02T0oooo0`09jPX70?ooo`030000003oool0000000H0^XfX0`09jPX80;Z=
Z00300WZ2P2jSJP0^XfX00P0^XfX00<02NX:00000035[/<02035[/<00`000000aJk3000000030000
00@0hn?B00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`0W0?ooo`802NX:2P3oool00`000000oooo000000020;Z=Z0@02NX:2P2jSJP00`09jPX0
^XfX0;Z=Z0050;Z=Z0@02NX:00<0^XfX00000035[/<01P35[/<8000000@0hn?B00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool02NX:00802NX:3@2jSJP00`09jPX0^XfX0;Z=Z0030;Z=Z0<02NX:1P2jSJP010000000aJk3
0<F^``35[/<300000080aJk31P0000030>?SdP030000003oool0oooo0280oooo00<000000?ooo`3o
ool01@3oool000D0oooo00<000000?ooo`3oool0<P3oool400WZ2P030?ooo`000000^XfX00d0^XfX
00<02NX:0;Z=Z009jPX00`09jPX90;Z=Z0@000001035[/<20=?ciP@000000P3ClnH20>?SdRD0oooo
00<000000?ooo`3oool01@3oool000D0oooo00<000000?ooo`3oool0;`3oool300WZ2P80oooo00@0
00000?ooo`3oool000003@2jSJP300WZ2PL0^XfX0`09jPX4000000H0aJk3103ClnH00`000000do?V
0=?ciP030=?ciP030>?SdP3oool0oooo02<0oooo00<000000?ooo`3oool01@3oool000D0oooo00<0
00000?ooo`3oool0;@3oool200WZ2PD0oooo00@000000?ooo`3oool000002@2jSJP500WZ2P@0^XfX
1009jPX4000000@0YVN800<000000<F^``35[/<00`35[/<50=?ciP040000003ClnH0do?V0=?ciRL0
oooo00<000000?ooo`3oool01@3oool000D0oooo00<000000?ooo`3oool0=03oool01@000000oooo
0?ooo`3oool0000000D0^XfX0`09jPX30;Z=Z0H02NX:00@0YVN80000000000000000202VIhP00`00
0000aJk30<F^``020<F^``L0do?V00<000000=?ciP3oool09`3oool00`000000oooo0?ooo`050?oo
o`001@3oool00`000000oooo0?ooo`0d0?ooo`050000003oool0oooo0?ooo`0000000P2jSJP300WZ
2P030;Z=Z009jPX02NX:00@02NX:00<0^XfX0:IWR00000000`00000;0:IWR00400000035[/<0aJk3
0<F^``T0do?V00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`050?ooo`001@3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo00P02NX:0`2jSJP00`2VIhP02NX:000000020000
0100YVN800<000000<F^``3ClnH0203ClnH20?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool0=03oool600WZ2PD0^XfX00<0YVN800000000
00000P00000C0:IWR0030000003ClnH0do?V00H0do?V1@3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo02H0oooo0`0000060?ooo`D02NX:
00<000000?ooo`3oool00P3oool010000000^XfX0:IWR02VIhP300000080YVN800<02NX:0:IWR02V
IhP04P2VIhP00`000000do?V0=?ciP050=?ciPL0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0U0?ooo`D000001@09jPX40?ooo`030000
003oool0oooo00<0oooo100000050:IWR00300WZ2P2VIhP0YVN80140YVN800<000000=?ciP3ClnH0
1@3ClnH90?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool000D0oooo00<0
00000?ooo`3oool09@3oool2000000<02NX:2@3oool00`000000oooo0?ooo`0300000080oooo00<0
00000:IWR02VIhP00`2VIhP00`09jPX0YVN80:IWR00B0:IWR0030000003ClnH0do?V00@0do?V2`3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0
oooo02D0oooo1@0000080?ooo`@000001P3oool00`000000YVN80:IWR0020:IWR00300WZ2P2VIhP0
YVN80140YVN800<000000=?ciP3ClnH00`3ClnH>0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool09P3oool3000000H0oooo0`0000000`3o
ool000000?ooo`080?ooo`040000002VIhP0YVN800WZ2Q80YVN80P1G02L00`000000do?V0=?ciP02
0=?ciQ00oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`040?ooo`001@3oool00`00
0000oooo0?ooo`0[0?ooo`@00000103oool00`000000oooo0?ooo`080?ooo`030000002VIhP02NX:
0100YVN80`1G02L00`000000do?V0=?ciP020=?ciQ80oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0X0?ooo`<00000203oool00`000000
oooo0?ooo`090?ooo`0300WZ2P2VIhP0YVN800d0YVN81@1G02L010000000do?V0=?ciP3ClnHD0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3o
ool0903oool4000000/0oooo00<000000?ooo`3oool02@3oool00`09jPX000000:IWR00;0:IWR0H0
E`0W00@000000=?ciP3ClnH0do?V5P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
00@0oooo00050?ooo`030000003oool0oooo0240oooo0`00000?0?ooo`030000003oool0oooo00P0
oooo00@02NX:0?ooo`3oool000002@2VIhP805L09`030000003ClnH0oooo01P0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0M0?ooo`@0
00004P3oool00`000000oooo0?ooo`080?ooo`0500WZ2P3oool0oooo0?ooo`0000001P2VIhP905L0
9`030000003ClnH0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`040?oo
o`001@3oool00`000000oooo0?ooo`0J0?ooo`<000005P3oool00`000000oooo0?ooo`070?ooo`03
00WZ2P3oool0oooo00<0oooo00@000000:IWR02VIhP0YVN82`1G02L00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0103oool000@0oooo00<000000?ooo`3o
ool05`3oool4000001T0oooo00<000000?ooo`3oool01`3oool00`09jPX0oooo0?ooo`040?ooo`h0
00007`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo00040?ooo`030000
003oool0oooo01@0oooo0`00000M0?ooo`030000003oool0oooo00H0oooo00<02NX:0?ooo`3oool0
<`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00040?ooo`030000003o
ool0oooo0100oooo1000000P0?ooo`030000003oool0oooo00H0oooo00<02NX:0?ooo`3oool0=03o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00040?ooo`030000003oool0
oooo00d0oooo0`00000T0?ooo`030000003oool0oooo00D0oooo00<02NX:0?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo00040?ooo`030000003oool0oooo
00T0oooo1000000W0?ooo`030000003oool0oooo00D0oooo00<02NX:0?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00040?ooo`030000003oool0oooo00H0
oooo0`00000[0?ooo`030000003oool0oooo00@0oooo00<02NX:0?ooo`3oool0>@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo0080oooo
1000000^0?ooo`030000003oool0oooo00@0oooo00<02NX:0?ooo`3oool0>P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003oool0000000800000<P3o
ool00`000000oooo0?ooo`030?ooo`0300WZ2P3oool0oooo03`0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`030?ooo`00103oool2000003D0oooo00<000000?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`0m0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool0
00H0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`020?ooo`0300WZ2P3oool0oooo
03l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`001`3oool00`000000
oooo0?ooo`0a0?ooo`050000003oool0oooo0?ooo`09jPX0@`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00<0oooo00080?ooo`030000003oool0oooo0300oooo00D000000?ooo`3o
ool0oooo00WZ2P140?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool000T0
oooo00<000000?ooo`3oool0;`3oool010000000oooo0?ooo`09jPY60?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool00`3oool000X0oooo0P00000_0?ooo`040000003oool0oooo00WZ
2TL0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00303oool00`000000
oooo0?ooo`0/0?ooo`030000003oool02NX:04T0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`030?ooo`003@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool02NX:04X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`003P3oool00`000000oooo0?oo
o`0Z0?ooo`0300000009jPX0oooo04/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`030?ooo`003`3oool00`000000oooo0?ooo`0Y0?ooo`0300000009jPX0oooo04`0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00403oool2000002T0oooo00<02NX:0?oo
o`3oool0C@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo000B0?ooo`03
0000003oool0oooo02H0oooo00<02NX:0?ooo`3oool0CP3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo000C0?ooo`030000003oool0oooo02@0oooo00<02NX:0000003oool0
D03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo000D0?ooo`030000003o
ool0oooo02<0oooo00<02NX:0000003oool0D@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00<0oooo000E0?ooo`030000003oool0oooo0240oooo00<02NX:0?ooo`000000D`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000F0?ooo`8000008@3oool00`09
jPX0oooo0000001D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool001P0
oooo00<000000?ooo`3oool07@3oool01009jPX0oooo0?ooo`00001E0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool001T0oooo00<000000?ooo`3oool0703oool01009jPX0
oooo0?ooo`00001F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool001X0
oooo00<000000?ooo`3oool06P3oool01@09jPX0oooo0?ooo`3oool0000005L0oooo00D000000?oo
o`3oool0oooo000000040?ooo`006`3oool00`000000oooo0?ooo`0I0?ooo`0500WZ2P3oool0oooo
0?ooo`000000F03oool010000000oooo0?ooo`0000040?ooo`00703oool2000001P0oooo00<02NX:
0?ooo`3oool00P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0000000@0oooo000N0?oo
o`030000003oool0oooo01@0oooo00<02NX:0?ooo`3oool00`3oool00`000000oooo0?ooo`1H0?oo
o`800000103oool001l0oooo00<000000?ooo`3oool04`3oool00`09jPX0oooo0?ooo`030?ooo`03
0000003oool0oooo05L0oooo0`0000040?ooo`00803oool00`000000oooo0?ooo`0A0?ooo`0300WZ
2P3oool0oooo00@0oooo00<000000?ooo`3oool0D`3oool4000000L0oooo000Q0?ooo`030000003o
ool0oooo0100oooo00<02NX:0?ooo`3oool0103oool00`000000oooo0?ooo`1?0?ooo`@000002`3o
ool00280oooo0P00000?0?ooo`0300WZ2P3oool0oooo00D0oooo00<000000?ooo`3oool0B`3oool4
000000l0oooo000T0?ooo`030000003oool0oooo00`0oooo00<02NX:0?ooo`3oool01@3oool00`00
0000oooo0?ooo`170?ooo`@000004`3oool002D0oooo00<000000?ooo`3oool02P3oool00`09jPX0
oooo0?ooo`060?ooo`030000003oool0oooo04<0oooo1000000G0?ooo`009P3oool00`000000oooo
0?ooo`060?ooo`<000002@3oool00`000000oooo0?ooo`0o0?ooo`@000006`3oool002L0oooo00<0
00000?ooo`3oool0103oool5000000P0oooo00<000000?ooo`3oool0>`3oool4000001l0oooo000X
0?ooo`800000103oool5000000P0oooo00<000000?ooo`3oool0=`3oool4000002<0oooo000Z0?oo
o`040000003oool0oooo0?ooo`D00000203oool00`000000oooo0?ooo`0c0?ooo`@000009`3oool0
02/0oooo00@000000?ooo`3oool0oooo0`0000080?ooo`030000003oool0oooo0300oooo1000000[
0?ooo`00;03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02/0oooo1@00000_0?oo
o`00;@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02L0oooo1000000d0?ooo`00
;P3oool2000000X0oooo00<000000?ooo`3oool08`3oool4000003P0oooo000`0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool07`3oool4000003`0oooo000a0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool06`3oool400000400oooo000b0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool05`3oool4000004@0oooo000c0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool04`3oool4000004P0oooo000d0?ooo`800000103oool00`000000oooo
0?ooo`0?0?ooo`@00000C03oool003H0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`@00000
D03oool003L0oooo00@000000?ooo`3oool000002@3oool4000005@0oooo000h0?ooo`030000003o
ool0000000D0oooo1000001H0?ooo`00>@3oool2000000030?ooo`000000000000800000G03oool0
03X0oooo0P00001P0?ooo`00W03oool009`0oooo002L0?ooo`00W03oool009`0oooo002L0?ooo`00
W03oool00001\
\>"],
  ImageRangeCache->{{{0, 155.25}, {286.875, 0}} -> {0.228143, 0.0182453, \
0.00342704, 0.00342704}}]
}, Open  ]],

Cell["The rays are reflected many times.", "Text"],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[propagatedseashellmirror, 
\tShowLabels -> False, PlotType -> SideView, PlotPoints -> 30, RayPointSize \
-> 5];\
\>", "Input",
  CellLabel->"In[31]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.4 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.190476 0.0571429 0.190476 [
[ 0 0 0 0 ]
[ 1 2.4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.2278 1.22402 m
.5 1.31378 L
.4863 1.33138 L
.2278 1.22402 L
.2278 1.22402 L
F
.5 1.31378 m
.79336 1.40354 L
.76912 1.44114 L
.4863 1.33138 L
.5 1.31378 L
F
.79336 1.40354 m
.92984 1.4933 L
.9174 1.55303 L
.76912 1.44114 L
.79336 1.40354 L
F
.92984 1.4933 m
.81452 1.58306 L
.84302 1.66675 L
.9174 1.55303 L
.92984 1.4933 L
F
.81452 1.58306 m
.5 1.67282 L
.58201 1.78195 L
.84302 1.66675 L
.81452 1.58306 L
F
.5 1.67282 m
.16433 1.76258 L
.27573 1.89823 L
.58201 1.78195 L
.5 1.67282 L
F
.2278 1.22402 m
.4863 1.33138 L
.46773 1.34689 L
.2278 1.22402 L
.2278 1.22402 L
F
.4863 1.33138 m
.76912 1.44114 L
.73059 1.47317 L
.46773 1.34689 L
.4863 1.33138 L
F
.76912 1.44114 m
.9174 1.55303 L
.87857 1.60092 L
.73059 1.47317 L
.76912 1.44114 L
F
.9174 1.55303 m
.84302 1.66675 L
.84247 1.72797 L
.87857 1.60092 L
.9174 1.55303 L
F
.84302 1.66675 m
.58201 1.78195 L
.65978 1.85199 L
.84247 1.72797 L
.84302 1.66675 L
F
.58201 1.78195 m
.27573 1.89823 L
.44218 1.97063 L
.65978 1.85199 L
.58201 1.78195 L
F
.2278 1.22402 m
.46773 1.34689 L
.44506 1.35983 L
.2278 1.22402 L
.2278 1.22402 L
F
.46773 1.34689 m
.73059 1.47317 L
.67999 1.4976 L
.44506 1.35983 L
.46773 1.34689 L
F
.73059 1.47317 m
.87857 1.60092 L
.81444 1.63149 L
.67999 1.4976 L
.73059 1.47317 L
F
.87857 1.60092 m
.84247 1.72797 L
.80192 1.75552 L
.81444 1.63149 L
.87857 1.60092 L
F
.84247 1.72797 m
.65978 1.85199 L
.69067 1.86416 L
.80192 1.75552 L
.84247 1.72797 L
F
.65978 1.85199 m
.44218 1.97063 L
.57406 1.95305 L
.69067 1.86416 L
.65978 1.85199 L
F
.2278 1.22402 m
.44506 1.35983 L
.41925 1.36982 L
.2278 1.22402 L
.2278 1.22402 L
F
.44506 1.35983 m
.67999 1.4976 L
.62104 1.51312 L
.41925 1.36982 L
.44506 1.35983 L
F
.67999 1.4976 m
.81444 1.63149 L
.73152 1.64208 L
.62104 1.51312 L
.67999 1.4976 L
F
.81444 1.63149 m
.80192 1.75552 L
.72314 1.74616 L
.73152 1.64208 L
.81444 1.63149 L
F
.80192 1.75552 m
.69067 1.86416 L
.6524 1.81808 L
.72314 1.74616 L
.80192 1.75552 L
F
.69067 1.86416 m
.57406 1.95305 L
.59817 1.85548 L
.6524 1.81808 L
.69067 1.86416 L
F
.2278 1.22402 m
.41925 1.36982 L
.39141 1.37664 L
.2278 1.22402 L
.2278 1.22402 L
F
.41925 1.36982 m
.62104 1.51312 L
.55848 1.51932 L
.39141 1.37664 L
.41925 1.36982 L
F
.62104 1.51312 m
.73152 1.64208 L
.64113 1.63312 L
.55848 1.51932 L
.62104 1.51312 L
F
.73152 1.64208 m
.72314 1.74616 L
.62432 1.70434 L
.64113 1.63312 L
.73152 1.64208 L
F
.72314 1.74616 m
.6524 1.81808 L
.56492 1.72859 L
.62432 1.70434 L
.72314 1.74616 L
F
.6524 1.81808 m
.59817 1.85548 L
.52394 1.71269 L
.56492 1.72859 L
.6524 1.81808 L
F
.2278 1.22402 m
.39141 1.37664 L
.36268 1.3802 L
.2278 1.22402 L
.2278 1.22402 L
F
.39141 1.37664 m
.55848 1.51932 L
.49729 1.51664 L
.36268 1.3802 L
.39141 1.37664 L
F
.55848 1.51932 m
.64113 1.63312 L
.55653 1.60753 L
.49729 1.51664 L
.55848 1.51932 L
F
.64113 1.63312 m
.62432 1.70434 L
.5336 1.63946 L
.55653 1.60753 L
.64113 1.63312 L
F
.62432 1.70434 m
.56492 1.72859 L
.48146 1.61704 L
.5336 1.63946 L
.62432 1.70434 L
F
.56492 1.72859 m
.52394 1.71269 L
.44399 1.56294 L
.48146 1.61704 L
.56492 1.72859 L
F
.2278 1.22402 m
.36268 1.3802 L
.33412 1.38054 L
.2278 1.22402 L
.2278 1.22402 L
F
.36268 1.3802 m
.49729 1.51664 L
.44171 1.50616 L
.33412 1.38054 L
.36268 1.3802 L
F
.49729 1.51664 m
.55653 1.60753 L
.4888 1.56973 L
.44171 1.50616 L
.49729 1.51664 L
F
.55653 1.60753 m
.5336 1.63946 L
.47508 1.56229 L
.4888 1.56973 L
.55653 1.60753 L
F
.5336 1.63946 m
.48146 1.61704 L
.45068 1.5026 L
.47508 1.56229 L
.5336 1.63946 L
F
.48146 1.61704 m
.44399 1.56294 L
.45111 1.43178 L
.45068 1.5026 L
.48146 1.61704 L
F
.2278 1.22402 m
.33412 1.38054 L
.30664 1.37782 L
.2278 1.22402 L
.2278 1.22402 L
F
.33412 1.38054 m
.44171 1.50616 L
.39462 1.48941 L
.30664 1.37782 L
.33412 1.38054 L
F
.44171 1.50616 m
.4888 1.56973 L
.44338 1.52452 L
.39462 1.48941 L
.44171 1.50616 L
F
.4888 1.56973 m
.47508 1.56229 L
.45651 1.48216 L
.44338 1.52452 L
.4888 1.56973 L
F
.47508 1.56229 m
.45068 1.5026 L
.48061 1.39744 L
.45651 1.48216 L
.47508 1.56229 L
F
.45068 1.5026 m
.45111 1.43178 L
.5492 1.32761 L
.48061 1.39744 L
.45068 1.5026 L
F
.2278 1.22402 m
.30664 1.37782 L
.28095 1.37229 L
.2278 1.22402 L
.2278 1.22402 L
F
.30664 1.37782 m
.39462 1.48941 L
.35718 1.46804 L
.28095 1.37229 L
.30664 1.37782 L
F
.39462 1.48941 m
.44338 1.52452 L
.41921 1.47624 L
.35718 1.46804 L
.39462 1.48941 L
F
.44338 1.52452 m
.45651 1.48216 L
.46739 1.40557 L
.41921 1.47624 L
.44338 1.52452 L
F
.45651 1.48216 m
.48061 1.39744 L
.536 1.30633 L
.46739 1.40557 L
.45651 1.48216 L
F
.48061 1.39744 m
.5492 1.32761 L
.65162 1.24639 L
.536 1.30633 L
.48061 1.39744 L
F
.2278 1.22402 m
.28095 1.37229 L
.25749 1.36426 L
.2278 1.22402 L
.2278 1.22402 L
F
.28095 1.37229 m
.35718 1.46804 L
.32902 1.44364 L
.25749 1.36426 L
.28095 1.37229 L
F
.35718 1.46804 m
.41921 1.47624 L
.41055 1.4283 L
.32902 1.44364 L
.35718 1.46804 L
F
.41921 1.47624 m
.46739 1.40557 L
.48796 1.33618 L
.41055 1.4283 L
.41921 1.47624 L
F
.46739 1.40557 m
.536 1.30633 L
.56963 1.22898 L
.48796 1.33618 L
.46739 1.40557 L
F
.536 1.30633 m
.65162 1.24639 L
.6658 1.17913 L
.56963 1.22898 L
.536 1.30633 L
F
.2278 1.22402 m
.25749 1.36426 L
.2365 1.35404 L
.2278 1.22402 L
.2278 1.22402 L
F
.25749 1.36426 m
.32902 1.44364 L
.30875 1.41755 L
.2365 1.35404 L
.25749 1.36426 L
F
.32902 1.44364 m
.41055 1.4283 L
.41021 1.38306 L
.30875 1.41755 L
.32902 1.44364 L
F
.41055 1.4283 m
.48796 1.33618 L
.5017 1.27555 L
.41021 1.38306 L
.41055 1.4283 L
F
.48796 1.33618 m
.56963 1.22898 L
.55799 1.16299 L
.5017 1.27555 L
.48796 1.33618 L
F
.56963 1.22898 m
.6658 1.17913 L
.57359 1.11765 L
.55799 1.16299 L
.56963 1.22898 L
F
.2278 1.22402 m
.2365 1.35404 L
.21804 1.34194 L
.2278 1.22402 L
.2278 1.22402 L
F
.2365 1.35404 m
.30875 1.41755 L
.29456 1.39078 L
.21804 1.34194 L
.2365 1.35404 L
F
.30875 1.41755 m
.41021 1.38306 L
.41252 1.34194 L
.29456 1.39078 L
.30875 1.41755 L
F
.41021 1.38306 m
.5017 1.27555 L
.50283 1.22402 L
.41252 1.34194 L
.41021 1.38306 L
F
.5017 1.27555 m
.55799 1.16299 L
.51258 1.1061 L
.50283 1.22402 L
.5017 1.27555 L
F
.55799 1.16299 m
.57359 1.11765 L
.43607 1.05726 L
.51258 1.1061 L
.55799 1.16299 L
F
.2278 1.22402 m
.21804 1.34194 L
.20202 1.32825 L
.2278 1.22402 L
.2278 1.22402 L
F
.21804 1.34194 m
.29456 1.39078 L
.28481 1.36399 L
.20202 1.32825 L
.21804 1.34194 L
F
.29456 1.39078 m
.41252 1.34194 L
.4147 1.30552 L
.28481 1.36399 L
.29456 1.39078 L
F
.41252 1.34194 m
.50283 1.22402 L
.49545 1.18146 L
.4147 1.30552 L
.41252 1.34194 L
F
.50283 1.22402 m
.51258 1.1061 L
.46399 1.05726 L
.49545 1.18146 L
.50283 1.22402 L
F
.51258 1.1061 m
.43607 1.05726 L
.33546 .99713 L
.46399 1.05726 L
.51258 1.1061 L
F
.2278 1.22402 m
.20202 1.32825 L
.18825 1.31323 L
.2278 1.22402 L
.2278 1.22402 L
F
.20202 1.32825 m
.28481 1.36399 L
.27827 1.33745 L
.18825 1.31323 L
.20202 1.32825 L
F
.28481 1.36399 m
.4147 1.30552 L
.41663 1.27374 L
.27827 1.33745 L
.28481 1.36399 L
F
.4147 1.30552 m
.49545 1.18146 L
.48777 1.14749 L
.41663 1.27374 L
.4147 1.30552 L
F
.49545 1.18146 m
.46399 1.05726 L
.43762 1.0168 L
.48777 1.14749 L
.49545 1.18146 L
F
.46399 1.05726 m
.33546 .99713 L
.31545 .93968 L
.43762 1.0168 L
.46399 1.05726 L
F
.2278 1.22402 m
.18825 1.31323 L
.17651 1.29708 L
.2278 1.22402 L
.2278 1.22402 L
F
.18825 1.31323 m
.27827 1.33745 L
.27415 1.31115 L
.17651 1.29708 L
.18825 1.31323 L
F
.27827 1.33745 m
.41663 1.27374 L
.41982 1.24593 L
.27415 1.31115 L
.27827 1.33745 L
F
.41663 1.27374 m
.48777 1.14749 L
.48672 1.12147 L
.41982 1.24593 L
.41663 1.27374 L
F
.48777 1.14749 m
.43762 1.0168 L
.44072 .98578 L
.48672 1.12147 L
.48777 1.14749 L
F
.43762 1.0168 m
.31545 .93968 L
.36385 .88935 L
.44072 .98578 L
.43762 1.0168 L
F
.2278 1.22402 m
.17651 1.29708 L
.16655 1.27999 L
.2278 1.22402 L
.2278 1.22402 L
F
.17651 1.29708 m
.27415 1.31115 L
.27202 1.2848 L
.16655 1.27999 L
.17651 1.29708 L
F
.27415 1.31115 m
.41982 1.24593 L
.42617 1.22093 L
.27202 1.2848 L
.27415 1.31115 L
F
.41982 1.24593 m
.48672 1.12147 L
.49598 1.10215 L
.42617 1.22093 L
.41982 1.24593 L
F
.48672 1.12147 m
.44072 .98578 L
.46607 .96509 L
.49598 1.10215 L
.48672 1.12147 L
F
.44072 .98578 m
.36385 .88935 L
.43787 .85119 L
.46607 .96509 L
.44072 .98578 L
F
.2278 1.22402 m
.16655 1.27999 L
.15813 1.26214 L
.2278 1.22402 L
.2278 1.22402 L
F
.16655 1.27999 m
.27202 1.2848 L
.27151 1.25799 L
.15813 1.26214 L
.16655 1.27999 L
F
.27202 1.2848 m
.42617 1.22093 L
.43709 1.19709 L
.27151 1.25799 L
.27202 1.2848 L
F
.42617 1.22093 m
.49598 1.10215 L
.51668 1.08738 L
.43709 1.19709 L
.42617 1.22093 L
F
.49598 1.10215 m
.46607 .96509 L
.50343 .95414 L
.51668 1.08738 L
.49598 1.10215 L
F
.46607 .96509 m
.43787 .85119 L
.50145 .82876 L
.50343 .95414 L
.46607 .96509 L
F
.2278 1.22402 m
.15813 1.26214 L
.15102 1.24369 L
.2278 1.22402 L
.2278 1.22402 L
F
.15813 1.26214 m
.27151 1.25799 L
.27213 1.23025 L
.15102 1.24369 L
.15813 1.26214 L
F
.27151 1.25799 m
.43709 1.19709 L
.45287 1.17253 L
.27213 1.23025 L
.27151 1.25799 L
F
.43709 1.19709 m
.51668 1.08738 L
.54852 1.07396 L
.45287 1.17253 L
.43709 1.19709 L
F
.51668 1.08738 m
.50343 .95414 L
.54749 .94999 L
.54852 1.07396 L
.51668 1.08738 L
F
.50343 .95414 m
.50145 .82876 L
.54406 .82192 L
.54749 .94999 L
.50343 .95414 L
F
.2278 1.22402 m
.15102 1.24369 L
.14504 1.22486 L
.2278 1.22402 L
.2278 1.22402 L
F
.15102 1.24369 m
.27213 1.23025 L
.27312 1.20122 L
.14504 1.22486 L
.15102 1.24369 L
F
.27213 1.23025 m
.45287 1.17253 L
.47234 1.14535 L
.27312 1.20122 L
.27213 1.23025 L
F
.45287 1.17253 m
.54852 1.07396 L
.58978 1.05794 L
.47234 1.14535 L
.45287 1.17253 L
F
.54852 1.07396 m
.54749 .94999 L
.59753 .94704 L
.58978 1.05794 L
.54852 1.07396 L
F
.54749 .94999 m
.54406 .82192 L
.5737 .82524 L
.59753 .94704 L
.54749 .94999 L
F
.2278 1.22402 m
.14504 1.22486 L
.14004 1.20585 L
.2278 1.22402 L
.2278 1.22402 L
F
.14504 1.22486 m
.27312 1.20122 L
.27347 1.17076 L
.14004 1.20585 L
.14504 1.22486 L
F
.27312 1.20122 m
.47234 1.14535 L
.49269 1.1141 L
.27347 1.17076 L
.27312 1.20122 L
F
.47234 1.14535 m
.58978 1.05794 L
.63648 1.03541 L
.49269 1.1141 L
.47234 1.14535 L
F
.58978 1.05794 m
.59753 .94704 L
.65275 .9381 L
.63648 1.03541 L
.58978 1.05794 L
F
.59753 .94704 m
.5737 .82524 L
.60013 .8284 L
.65275 .9381 L
.59753 .94704 L
F
.2278 1.22402 m
.14004 1.20585 L
.13597 1.18696 L
.2278 1.22402 L
.2278 1.22402 L
F
.14004 1.20585 m
.27347 1.17076 L
.27199 1.13908 L
.13597 1.18696 L
.14004 1.20585 L
F
.27347 1.17076 m
.49269 1.1141 L
.50985 1.07816 L
.27199 1.13908 L
.27347 1.17076 L
F
.49269 1.1141 m
.63648 1.03541 L
.68209 1.00365 L
.50985 1.07816 L
.49269 1.1141 L
F
.63648 1.03541 m
.65275 .9381 L
.70912 .91664 L
.68209 1.00365 L
.63648 1.03541 L
F
.65275 .9381 m
.60013 .8284 L
.62688 .81954 L
.70912 .91664 L
.65275 .9381 L
F
.2278 1.22402 m
.13597 1.18696 L
.13283 1.16848 L
.2278 1.22402 L
.2278 1.22402 L
F
.13597 1.18696 m
.27199 1.13908 L
.26767 1.10676 L
.13283 1.16848 L
.13597 1.18696 L
F
.27199 1.13908 m
.50985 1.07816 L
.51918 1.03814 L
.26767 1.10676 L
.27199 1.13908 L
F
.50985 1.07816 m
.68209 1.00365 L
.71824 .96235 L
.51918 1.03814 L
.50985 1.07816 L
F
.68209 1.00365 m
.70912 .91664 L
.75968 .87962 L
.71824 .96235 L
.68209 1.00365 L
F
.70912 .91664 m
.62688 .81954 L
.6541 .79059 L
.75968 .87962 L
.70912 .91664 L
F
.2278 1.22402 m
.13283 1.16848 L
.13076 1.15079 L
.2278 1.22402 L
.2278 1.22402 L
F
.13283 1.16848 m
.26767 1.10676 L
.25993 1.07481 L
.13076 1.15079 L
.13283 1.16848 L
F
.26767 1.10676 m
.51918 1.03814 L
.51663 .99598 L
.25993 1.07481 L
.26767 1.10676 L
F
.51918 1.03814 m
.71824 .96235 L
.7364 .91425 L
.51663 .99598 L
.51918 1.03814 L
F
.71824 .96235 m
.75968 .87962 L
.79619 .82966 L
.7364 .91425 L
.71824 .96235 L
F
.75968 .87962 m
.6541 .79059 L
.6821 .74226 L
.79619 .82966 L
.75968 .87962 L
F
.2278 1.22402 m
.13076 1.15079 L
.13 1.13426 L
.2278 1.22402 L
.2278 1.22402 L
F
.13076 1.15079 m
.25993 1.07481 L
.24895 1.0445 L
.13 1.13426 L
.13076 1.15079 L
F
.25993 1.07481 m
.51663 .99598 L
.5 .95474 L
.24895 1.0445 L
.25993 1.07481 L
F
.51663 .99598 m
.7364 .91425 L
.72989 .86498 L
.5 .95474 L
.51663 .99598 L
F
.7364 .91425 m
.79619 .82966 L
.81016 .77522 L
.72989 .86498 L
.7364 .91425 L
F
.79619 .82966 m
.6821 .74226 L
.70874 .68546 L
.81016 .77522 L
.79619 .82966 L
F
.2278 1.22402 m
.13 1.13426 L
.13089 1.11926 L
.2278 1.22402 L
.2278 1.22402 L
F
.13 1.13426 m
.24895 1.0445 L
.23585 1.01726 L
.13089 1.11926 L
.13 1.13426 L
F
.24895 1.0445 m
.5 .95474 L
.46992 .91811 L
.23585 1.01726 L
.24895 1.0445 L
F
.5 .95474 m
.72989 .86498 L
.69615 .82185 L
.46992 .91811 L
.5 .95474 L
F
.72989 .86498 m
.81016 .77522 L
.79415 .72846 L
.69615 .82185 L
.72989 .86498 L
F
.81016 .77522 m
.70874 .68546 L
.72457 .63787 L
.79415 .72846 L
.81016 .77522 L
F
.2278 1.22402 m
.13089 1.11926 L
.13383 1.10615 L
.2278 1.22402 L
.2278 1.22402 L
F
.13089 1.11926 m
.23585 1.01726 L
.22265 .99447 L
.13383 1.10615 L
.13089 1.11926 L
F
.23585 1.01726 m
.46992 .91811 L
.4304 .8897 L
.22265 .99447 L
.23585 1.01726 L
F
.46992 .91811 m
.69615 .82185 L
.6387 .79208 L
.4304 .8897 L
.46992 .91811 L
F
.69615 .82185 m
.79415 .72846 L
.74541 .7014 L
.6387 .79208 L
.69615 .82185 L
F
.79415 .72846 m
.72457 .63787 L
.71501 .61703 L
.74541 .7014 L
.79415 .72846 L
F
.2278 1.22402 m
.13383 1.10615 L
.13926 1.09523 L
.2278 1.22402 L
.2278 1.22402 L
F
.13383 1.10615 m
.22265 .99447 L
.21202 .97726 L
.13926 1.09523 L
.13383 1.10615 L
F
.22265 .99447 m
.4304 .8897 L
.38833 .87232 L
.21202 .97726 L
.22265 .99447 L
F
.4304 .8897 m
.6387 .79208 L
.56792 .78097 L
.38833 .87232 L
.4304 .8897 L
F
.6387 .79208 m
.74541 .7014 L
.67122 .70213 L
.56792 .78097 L
.6387 .79208 L
F
.74541 .7014 m
.71501 .61703 L
.67311 .63338 L
.67122 .70213 L
.74541 .7014 L
F
.2278 1.22402 m
.13926 1.09523 L
.14755 1.08672 L
.2278 1.22402 L
.2278 1.22402 L
F
.13926 1.09523 m
.21202 .97726 L
.20677 .96634 L
.14755 1.08672 L
.13926 1.09523 L
F
.21202 .97726 m
.38833 .87232 L
.35207 .86754 L
.20677 .96634 L
.21202 .97726 L
F
.38833 .87232 m
.56792 .78097 L
.49933 .79076 L
.35207 .86754 L
.38833 .87232 L
F
.56792 .78097 m
.67122 .70213 L
.59083 .7326 L
.49933 .79076 L
.56792 .78097 L
F
.67122 .70213 m
.67311 .63338 L
.61316 .68683 L
.59083 .7326 L
.67122 .70213 L
F
.2278 1.22402 m
.14755 1.08672 L
.15901 1.08076 L
.2278 1.22402 L
.2278 1.22402 L
F
.14755 1.08672 m
.20677 .96634 L
.2093 .96198 L
.15901 1.08076 L
.14755 1.08672 L
F
.20677 .96634 m
.35207 .86754 L
.3292 .87542 L
.2093 .96198 L
.20677 .96634 L
F
.35207 .86754 m
.49933 .79076 L
.44857 .82041 L
.3292 .87542 L
.35207 .86754 L
F
.49933 .79076 m
.59083 .7326 L
.52871 .78889 L
.44857 .82041 L
.49933 .79076 L
F
.59083 .7326 m
.61316 .68683 L
.5673 .76827 L
.52871 .78889 L
.59083 .7326 L
F
.2278 1.22402 m
.15901 1.08076 L
.17377 1.07741 L
.2278 1.22402 L
.2278 1.22402 L
F
.15901 1.08076 m
.2093 .96198 L
.22106 .96391 L
.17377 1.07741 L
.15901 1.08076 L
F
.2093 .96198 m
.3292 .87542 L
.32432 .89469 L
.22106 .96391 L
.2093 .96198 L
F
.3292 .87542 m
.44857 .82041 L
.42506 .86632 L
.32432 .89469 L
.3292 .87542 L
F
.44857 .82041 m
.52871 .78889 L
.50004 .86336 L
.42506 .86632 L
.44857 .82041 L
F
.52871 .78889 m
.5673 .76827 L
.55837 .86448 L
.50004 .86336 L
.52871 .78889 L
F
.2278 1.22402 m
.17377 1.07741 L
.19179 1.07662 L
.2278 1.22402 L
.2278 1.22402 L
F
.17377 1.07741 m
.22106 .96391 L
.24229 .97148 L
.19179 1.07662 L
.17377 1.07741 L
F
.22106 .96391 m
.32432 .89469 L
.33773 .92309 L
.24229 .97148 L
.22106 .96391 L
F
.32432 .89469 m
.42506 .86632 L
.42788 .92352 L
.33773 .92309 L
.32432 .89469 L
F
.42506 .86632 m
.50004 .86336 L
.49943 .94748 L
.42788 .92352 L
.42506 .86632 L
F
.50004 .86336 m
.55837 .86448 L
.57194 .96357 L
.49943 .94748 L
.50004 .86336 L
F
.2278 1.22402 m
.19179 1.07662 L
.21286 1.07829 L
.2278 1.22402 L
.2278 1.22402 L
F
.19179 1.07662 m
.24229 .97148 L
.27202 .98372 L
.21286 1.07829 L
.19179 1.07662 L
F
.24229 .97148 m
.33773 .92309 L
.36576 .95784 L
.27202 .98372 L
.24229 .97148 L
F
.33773 .92309 m
.42788 .92352 L
.44706 .98685 L
.36576 .95784 L
.33773 .92309 L
F
.42788 .92352 m
.49943 .94748 L
.50435 1.03415 L
.44706 .98685 L
.42788 .92352 L
F
.49943 .94748 m
.57194 .96357 L
.56213 1.05829 L
.50435 1.03415 L
.49943 .94748 L
F
.2278 1.22402 m
.21286 1.07829 L
.23658 1.08226 L
.2278 1.22402 L
.2278 1.22402 L
F
.21286 1.07829 m
.27202 .98372 L
.30842 .99949 L
.23658 1.08226 L
.21286 1.07829 L
F
.27202 .98372 m
.36576 .95784 L
.40243 .99601 L
.30842 .99949 L
.27202 .98372 L
F
.36576 .95784 m
.44706 .98685 L
.46979 1.05177 L
.40243 .99601 L
.36576 .95784 L
F
.44706 .98685 m
.50435 1.03415 L
.49318 1.11876 L
.46979 1.05177 L
.44706 .98685 L
F
.50435 1.03415 m
.56213 1.05829 L
.49515 1.14649 L
.49318 1.11876 L
.50435 1.03415 L
F
.2278 1.22402 m
.23658 1.08226 L
.26243 1.08835 L
.2278 1.22402 L
.2278 1.22402 L
F
.23658 1.08226 m
.30842 .99949 L
.34923 1.01766 L
.26243 1.08835 L
.23658 1.08226 L
F
.30842 .99949 m
.40243 .99601 L
.44166 1.03491 L
.34923 1.01766 L
.30842 .99949 L
F
.40243 .99601 m
.46979 1.05177 L
.48722 1.1147 L
.44166 1.03491 L
.40243 .99601 L
F
.46979 1.05177 m
.49318 1.11876 L
.46264 1.19893 L
.48722 1.1147 L
.46979 1.05177 L
F
.49318 1.11876 m
.49515 1.14649 L
.38863 1.22959 L
.46264 1.19893 L
.49318 1.11876 L
F
.2278 1.22402 m
.26243 1.08835 L
.28982 1.09635 L
.2278 1.22402 L
.2278 1.22402 L
F
.26243 1.08835 m
.34923 1.01766 L
.39233 1.03719 L
.28982 1.09635 L
.26243 1.08835 L
F
.34923 1.01766 m
.44166 1.03491 L
.47907 1.07222 L
.39233 1.03719 L
.34923 1.01766 L
F
.44166 1.03491 m
.48722 1.1147 L
.49734 1.17285 L
.47907 1.07222 L
.44166 1.03491 L
F
.48722 1.1147 m
.46264 1.19893 L
.42902 1.27362 L
.49734 1.17285 L
.48722 1.1147 L
F
.46264 1.19893 m
.38863 1.22959 L
.30362 1.31032 L
.42902 1.27362 L
.46264 1.19893 L
F
.2278 1.22402 m
.28982 1.09635 L
.3181 1.1061 L
.2278 1.22402 L
.2278 1.22402 L
F
.28982 1.09635 m
.39233 1.03719 L
.43607 1.05726 L
.3181 1.1061 L
.28982 1.09635 L
F
.39233 1.03719 m
.47907 1.07222 L
.51258 1.1061 L
.43607 1.05726 L
.39233 1.03719 L
F
.47907 1.07222 m
.49734 1.17285 L
.50283 1.22402 L
.51258 1.1061 L
.47907 1.07222 L
F
.49734 1.17285 m
.42902 1.27362 L
.41252 1.34194 L
.50283 1.22402 L
.49734 1.17285 L
F
.42902 1.27362 m
.30362 1.31032 L
.29456 1.39078 L
.41252 1.34194 L
.42902 1.27362 L
F
.2278 1.22402 m
.3181 1.1061 L
.34663 1.11743 L
.2278 1.22402 L
.2278 1.22402 L
F
.3181 1.1061 m
.43607 1.05726 L
.47944 1.07735 L
.34663 1.11743 L
.3181 1.1061 L
F
.43607 1.05726 m
.51258 1.1061 L
.54224 1.13527 L
.47944 1.07735 L
.43607 1.05726 L
F
.51258 1.1061 m
.50283 1.22402 L
.50691 1.26622 L
.54224 1.13527 L
.51258 1.1061 L
F
.50283 1.22402 m
.41252 1.34194 L
.41976 1.40221 L
.50691 1.26622 L
.50283 1.22402 L
F
.41252 1.34194 m
.29456 1.39078 L
.36466 1.47098 L
.41976 1.40221 L
.41252 1.34194 L
F
.2278 1.22402 m
.34663 1.11743 L
.37477 1.13024 L
.2278 1.22402 L
.2278 1.22402 L
F
.34663 1.11743 m
.47944 1.07735 L
.52208 1.09733 L
.37477 1.13024 L
.34663 1.11743 L
F
.47944 1.07735 m
.54224 1.13527 L
.56957 1.15913 L
.52208 1.09733 L
.47944 1.07735 L
F
.54224 1.13527 m
.50691 1.26622 L
.51103 1.29771 L
.56957 1.15913 L
.54224 1.13527 L
F
.50691 1.26622 m
.41976 1.40221 L
.43973 1.45138 L
.51103 1.29771 L
.50691 1.26622 L
F
.41976 1.40221 m
.36466 1.47098 L
.46519 1.54769 L
.43973 1.45138 L
.41976 1.40221 L
F
.2278 1.22402 m
.37477 1.13024 L
.4019 1.14445 L
.2278 1.22402 L
.2278 1.22402 L
F
.37477 1.13024 m
.52208 1.09733 L
.56401 1.1174 L
.4019 1.14445 L
.37477 1.13024 L
F
.52208 1.09733 m
.56957 1.15913 L
.59701 1.1779 L
.56401 1.1174 L
.52208 1.09733 L
F
.56957 1.15913 m
.51103 1.29771 L
.51584 1.31727 L
.59701 1.1779 L
.56957 1.15913 L
F
.51103 1.29771 m
.43973 1.45138 L
.45513 1.48521 L
.51584 1.31727 L
.51103 1.29771 L
F
.43973 1.45138 m
.46519 1.54769 L
.53585 1.61385 L
.45513 1.48521 L
.43973 1.45138 L
F
.2278 1.22402 m
.4019 1.14445 L
.4274 1.15998 L
.2278 1.22402 L
.2278 1.22402 L
F
.4019 1.14445 m
.56401 1.1174 L
.60538 1.13815 L
.4274 1.15998 L
.4019 1.14445 L
F
.56401 1.1174 m
.59701 1.1779 L
.62726 1.1928 L
.60538 1.13815 L
.56401 1.1174 L
F
.59701 1.1779 m
.51584 1.31727 L
.52322 1.32492 L
.62726 1.1928 L
.59701 1.1779 L
F
.51584 1.31727 m
.45513 1.48521 L
.4572 1.4994 L
.52322 1.32492 L
.51584 1.31727 L
F
.45513 1.48521 m
.53585 1.61385 L
.5492 1.65898 L
.4572 1.4994 L
.45513 1.48521 L
F
.2278 1.22402 m
.4274 1.15998 L
.45064 1.17679 L
.2278 1.22402 L
.2278 1.22402 L
F
.4274 1.15998 m
.60538 1.13815 L
.64612 1.16045 L
.45064 1.17679 L
.4274 1.15998 L
F
.60538 1.13815 m
.62726 1.1928 L
.66259 1.20616 L
.64612 1.16045 L
.60538 1.13815 L
F
.62726 1.1928 m
.52322 1.32492 L
.53674 1.32289 L
.66259 1.20616 L
.62726 1.1928 L
F
.52322 1.32492 m
.4572 1.4994 L
.45046 1.49186 L
.53674 1.32289 L
.52322 1.32492 L
F
.4572 1.4994 m
.5492 1.65898 L
.52178 1.67196 L
.45046 1.49186 L
.4572 1.4994 L
F
.2278 1.22402 m
.45064 1.17679 L
.471 1.19478 L
.2278 1.22402 L
.2278 1.22402 L
F
.45064 1.17679 m
.64612 1.16045 L
.68567 1.18528 L
.471 1.19478 L
.45064 1.17679 L
F
.64612 1.16045 m
.66259 1.20616 L
.70405 1.22133 L
.68567 1.18528 L
.64612 1.16045 L
F
.66259 1.20616 m
.53674 1.32289 L
.55965 1.31634 L
.70405 1.22133 L
.66259 1.20616 L
F
.53674 1.32289 m
.45046 1.49186 L
.44438 1.46569 L
.55965 1.31634 L
.53674 1.32289 L
F
.45046 1.49186 m
.52178 1.67196 L
.48563 1.64674 L
.44438 1.46569 L
.45046 1.49186 L
F
.2278 1.22402 m
.471 1.19478 L
.48782 1.21382 L
.2278 1.22402 L
.2278 1.22402 L
F
.471 1.19478 m
.68567 1.18528 L
.72281 1.21356 L
.48782 1.21382 L
.471 1.19478 L
F
.68567 1.18528 m
.70405 1.22133 L
.75087 1.24219 L
.72281 1.21356 L
.68567 1.18528 L
F
.70405 1.22133 m
.55965 1.31634 L
.59247 1.31339 L
.75087 1.24219 L
.70405 1.22133 L
F
.55965 1.31634 m
.44438 1.46569 L
.44223 1.43156 L
.59247 1.31339 L
.55965 1.31634 L
F
.44438 1.46569 m
.48563 1.64674 L
.45157 1.58989 L
.44223 1.43156 L
.44438 1.46569 L
F
.2278 1.22402 m
.48782 1.21382 L
.50048 1.23368 L
.2278 1.22402 L
.2278 1.22402 L
F
.48782 1.21382 m
.72281 1.21356 L
.75561 1.24586 L
.50048 1.23368 L
.48782 1.21382 L
F
.72281 1.21356 m
.75087 1.24219 L
.80038 1.27236 L
.75561 1.24586 L
.72281 1.21356 L
F
.75087 1.24219 m
.59247 1.31339 L
.63279 1.32375 L
.80038 1.27236 L
.75087 1.24219 L
F
.59247 1.31339 m
.44223 1.43156 L
.43926 1.4073 L
.63279 1.32375 L
.59247 1.31339 L
F
.44223 1.43156 m
.45157 1.58989 L
.40245 1.52537 L
.43926 1.4073 L
.44223 1.43156 L
F
.2278 1.22402 m
.50048 1.23368 L
.5084 1.25407 L
.2278 1.22402 L
.2278 1.22402 L
F
.50048 1.23368 m
.75561 1.24586 L
.78164 1.28215 L
.5084 1.25407 L
.50048 1.23368 L
F
.75561 1.24586 m
.80038 1.27236 L
.84841 1.31411 L
.78164 1.28215 L
.75561 1.24586 L
F
.80038 1.27236 m
.63279 1.32375 L
.67737 1.35594 L
.84841 1.31411 L
.80038 1.27236 L
F
.63279 1.32375 m
.43926 1.4073 L
.43207 1.41316 L
.67737 1.35594 L
.63279 1.32375 L
F
.43926 1.4073 m
.40245 1.52537 L
.3212 1.49011 L
.43207 1.41316 L
.43926 1.4073 L
F
.2278 1.22402 m
.5084 1.25407 L
.51112 1.27455 L
.2278 1.22402 L
.2278 1.22402 L
F
.5084 1.25407 m
.78164 1.28215 L
.79821 1.32168 L
.51112 1.27455 L
.5084 1.25407 L
F
.78164 1.28215 m
.84841 1.31411 L
.88982 1.36732 L
.79821 1.32168 L
.78164 1.28215 L
F
.84841 1.31411 m
.67737 1.35594 L
.72413 1.41368 L
.88982 1.36732 L
.84841 1.31411 L
F
.67737 1.35594 m
.43207 1.41316 L
.42851 1.46307 L
.72413 1.41368 L
.67737 1.35594 L
F
.43207 1.41316 m
.3212 1.49011 L
.22183 1.51783 L
.42851 1.46307 L
.43207 1.41316 L
F
.2278 1.22402 m
.51112 1.27455 L
.50834 1.29464 L
.2278 1.22402 L
.2278 1.22402 L
F
.51112 1.27455 m
.79821 1.32168 L
.80276 1.36287 L
.50834 1.29464 L
.51112 1.27455 L
F
.79821 1.32168 m
.88982 1.36732 L
.9189 1.42896 L
.80276 1.36287 L
.79821 1.32168 L
F
.88982 1.36732 m
.72413 1.41368 L
.7714 1.49322 L
.9189 1.42896 L
.88982 1.36732 L
F
.72413 1.41368 m
.42851 1.46307 L
.44652 1.55601 L
.7714 1.49322 L
.72413 1.41368 L
F
.42851 1.46307 m
.22183 1.51783 L
.15202 1.61771 L
.44652 1.55601 L
.42851 1.46307 L
F
.2278 1.22402 m
.50834 1.29464 L
.5 1.31378 L
.2278 1.22402 L
.2278 1.22402 L
F
.50834 1.29464 m
.80276 1.36287 L
.79336 1.40354 L
.5 1.31378 L
.50834 1.29464 L
F
.80276 1.36287 m
.9189 1.42896 L
.92984 1.4933 L
.79336 1.40354 L
.80276 1.36287 L
F
.9189 1.42896 m
.7714 1.49322 L
.81452 1.58306 L
.92984 1.4933 L
.9189 1.42896 L
F
.7714 1.49322 m
.44652 1.55601 L
.5 1.67282 L
.81452 1.58306 L
.7714 1.49322 L
F
.44652 1.55601 m
.15202 1.61771 L
.16433 1.76258 L
.5 1.67282 L
.44652 1.55601 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.16433 1.76258 m
.27573 1.89823 L
.44218 1.97063 L
.57406 1.95305 L
.59817 1.85548 L
.52394 1.71269 L
.44399 1.56294 L
.45111 1.43178 L
.5492 1.32761 L
.65162 1.24639 L
.6658 1.17913 L
.57359 1.11765 L
.43607 1.05726 L
.33546 .99713 L
.31545 .93968 L
.36385 .88935 L
.43787 .85119 L
.50145 .82876 L
.54406 .82192 L
.5737 .82524 L
.60013 .8284 L
.62688 .81954 L
.6541 .79059 L
.6821 .74226 L
.70874 .68546 L
.72457 .63787 L
.71501 .61703 L
.67311 .63338 L
.61316 .68683 L
.5673 .76827 L
.55837 .86448 L
.57194 .96357 L
.56213 1.05829 L
.49515 1.14649 L
.38863 1.22959 L
.30362 1.31032 L
.29456 1.39078 L
.36466 1.47098 L
.46519 1.54769 L
.53585 1.61385 L
.5492 1.65898 L
.52178 1.67196 L
.48563 1.64674 L
.45157 1.58989 L
.40245 1.52537 L
.3212 1.49011 L
.22183 1.51783 L
.15202 1.61771 L
.16433 1.76258 L
s
.97619 .05714 m
.97619 .05714 L
.97619 2.34286 L
.97619 2.34286 L
.97619 .05714 L
s
.97619 .05714 m
.02381 .05714 L
.02381 2.34286 L
.97619 2.34286 L
.97619 .05714 L
s
.02381 .05714 m
.02381 .05714 L
.02381 2.34286 L
.02381 2.34286 L
.02381 .05714 L
s
.02381 .05714 m
.97619 .05714 L
.97619 2.34286 L
.02381 2.34286 L
.02381 .05714 L
s
.97619 .05714 m
.97619 .05714 L
.02381 .05714 L
.02381 .05714 L
.97619 .05714 L
s
.97619 2.34286 m
.97619 2.34286 L
.02381 2.34286 L
.02381 2.34286 L
.97619 2.34286 L
s
.039 .916 .04 r
.11905 1.77143 m
.79997 1.77143 L
s
% Start of user PostScript
-2. 9. 1.57485 9. MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.79997 1.77143 Mdot
.039 .916 .04 r
.5 Mabswid
.11905 1.77143 m
.80048 1.77143 L
s
% Start of user PostScript
-2. 9. 1.57751 9. MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.80048 1.77143 Mdot
.039 .916 .04 r
.5 Mabswid
.11905 1.77143 m
.76211 1.77143 L
s
% Start of user PostScript
-2. 9. 1.37605 9. MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.76211 1.77143 Mdot
.039 .916 .04 r
.5 Mabswid
.79997 1.77143 m
.8663 1.40977 L
s
% Start of user PostScript
1.57485 9. 1.92309 7.10128 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.8663 1.40977 Mdot
.039 .916 .04 r
.5 Mabswid
.80048 1.77143 m
.76866 1.28409 L
s
% Start of user PostScript
1.57751 9. 1.41046 6.44145 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.76866 1.28409 Mdot
.039 .916 .04 r
.5 Mabswid
.76211 1.77143 m
.78537 1.23628 L
s
% Start of user PostScript
1.37605 9. 1.4982 6.19047 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.78537 1.23628 Mdot
.039 .916 .04 r
.5 Mabswid
.8663 1.40977 m
.16563 1.16498 L
s
% Start of user PostScript
1.92309 7.10128 -1.75543 5.81614 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.16563 1.16498 Mdot
.039 .916 .04 r
.5 Mabswid
.76866 1.28409 m
.46454 1.43953 L
s
% Start of user PostScript
1.41046 6.44145 -0.186164 7.25752 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.46454 1.43953 Mdot
.039 .916 .04 r
.5 Mabswid
.78537 1.23628 m
.444 1.34791 L
s
% Start of user PostScript
1.4982 6.19047 -0.294007 6.7765 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.444 1.34791 Mdot
.039 .916 .04 r
.5 Mabswid
.16563 1.16498 m
.49186 1.1523 L
s
% Start of user PostScript
-1.75543 5.81614 -0.0427464 5.74956 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.49186 1.1523 Mdot
.039 .916 .04 r
.5 Mabswid
.46454 1.43953 m
.47864 .82901 L
s
% Start of user PostScript
-0.186164 7.25752 -0.112147 4.05231 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.47864 .82901 Mdot
.039 .916 .04 r
.5 Mabswid
.444 1.34791 m
.27416 1.32953 L
s
% Start of user PostScript
-0.294007 6.7765 -1.18567 6.68001 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.27416 1.32953 Mdot
.039 .916 .04 r
.5 Mabswid
.49186 1.1523 m
.15014 1.23981 L
s
% Start of user PostScript
-0.0427464 5.74956 -1.83677 6.209 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.15014 1.23981 Mdot
.039 .916 .04 r
.5 Mabswid
.47864 .82901 m
.63884 1.03749 L
s
% Start of user PostScript
-0.112147 4.05231 0.728898 5.14681 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.63884 1.03749 Mdot
.039 .916 .04 r
.5 Mabswid
.27416 1.32953 m
.23782 .94536 L
s
% Start of user PostScript
-1.18567 6.68001 -1.37642 4.66315 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.23782 .94536 Mdot
.039 .916 .04 r
.5 Mabswid
.15014 1.23981 m
.5207 1.10132 L
s
% Start of user PostScript
-1.83677 6.209 0.108661 5.48193 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.5207 1.10132 Mdot
.039 .916 .04 r
.5 Mabswid
.63884 1.03749 m
.48646 .81913 L
s
% Start of user PostScript
0.728898 5.14681 -0.0710926 4.00042 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.48646 .81913 Mdot
.039 .916 .04 r
.5 Mabswid
.23782 .94536 m
.72647 .96269 L
s
% Start of user PostScript
-1.37642 4.66315 1.18896 4.75415 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.72647 .96269 Mdot
.039 .916 .04 r
.5 Mabswid
.5207 1.10132 m
.53823 1.51237 L
s
% Start of user PostScript
0.108661 5.48193 0.200731 7.63992 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.53823 1.51237 Mdot
.039 .916 .04 r
.5 Mabswid
.48646 .81913 m
.59674 .97019 L
s
% Start of user PostScript
-0.0710926 4.00042 0.507889 4.79349 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.59674 .97019 Mdot
.039 .916 .04 r
.5 Mabswid
.72647 .96269 m
.69767 .70071 L
s
% Start of user PostScript
1.18896 4.75415 1.03774 3.37873 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.69767 .70071 Mdot
.039 .916 .04 r
.5 Mabswid
.53823 1.51237 m
.77772 1.32013 L
s
% Start of user PostScript
0.200731 7.63992 1.45803 6.63069 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.77772 1.32013 Mdot
.039 .916 .04 r
.5 Mabswid
.59674 .97019 m
.46706 .99092 L
s
% Start of user PostScript
0.507889 4.79349 -0.172927 4.90232 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.46706 .99092 Mdot
.039 .916 .04 r
.5 Mabswid
.69767 .70071 m
.49451 .95209 L
s
% Start of user PostScript
1.03774 3.37873 -0.0288474 4.69848 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.49451 .95209 Mdot
.039 .916 .04 r
.5 Mabswid
.77772 1.32013 m
.67095 1.88033 L
s
% Start of user PostScript
1.45803 6.63069 0.897505 9.57174 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.67095 1.88033 Mdot
.039 .916 .04 r
.5 Mabswid
.46706 .99092 m
.13959 1.10495 L
s
% Start of user PostScript
-0.172927 4.90232 -1.89213 5.50101 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.13959 1.10495 Mdot
.039 .916 .04 r
.5 Mabswid
.67095 1.88033 m
.02381 1.79488 L
s
% Start of user PostScript
0.897505 9.57174 -2.5 9.12314 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.02381 1.79488 Mdot
.039 .916 .04 r
.5 Mabswid
.13959 1.10495 m
.40069 1.40183 L
s
% Start of user PostScript
-1.89213 5.50101 -0.521353 7.0596 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.40069 1.40183 Mdot
.039 .916 .04 r
.5 Mabswid
.40069 1.40183 m
.79097 1.57043 L
s
% Start of user PostScript
-0.521353 7.0596 1.52757 7.94477 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.79097 1.57043 Mdot
.039 .916 .04 r
.5 Mabswid
.79097 1.57043 m
.75494 1.29639 L
s
% Start of user PostScript
1.52757 7.94477 1.33845 6.50603 MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.75494 1.29639 Mdot
.039 .916 .04 r
.5 Mabswid
.75494 1.29639 m
.08922 2.34286 L
s
% Start of user PostScript
1.33845 6.50603 -2.15661 12. MAarrowhead1
% End of user PostScript
0 0 0 r
5 Mabswid
.08922 2.34286 Mdot
0 0 m
1 0 L
1 2.4 L
0 2.4 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[31]:=",
  ImageSize->{120, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001h000182000`400?l00000o`00003oN03oool0
07P0oooo001h0?ooo`00N03oool007P0oooo001h0?ooo`00N03oool007P0oooo00020?ooog<00000
0`3oool00080oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`000P3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo
06l0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0K`3oool00`000000
oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo
00020?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00080oooo00<00000
0?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`1_0?oo
o`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3o
ool00@3oool00080oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`000P3o
ool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0
oooo06l0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0K`3oool00`00
0000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040
oooo00020?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00080oooo00<0
00000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo06l0oooo00<000000?oo
o`3oool00@3oool00080oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`00
0P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo
0040oooo00020?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00080oooo
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?oo
o`1_0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo06l0oooo00<00000
0?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?oo
o`000P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo00020?ooo`030000
003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0K`3o
ool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0
oooo0040oooo00020?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00080
oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo
0?ooo`1_0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo06l0oooo00<0
00000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`01
0?ooo`000P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo00020?ooo`03
0000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0
K`3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`1_0?ooo`030000003o
ool0oooo0040oooo00020?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool0
0080oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000
oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo06l0oooo
00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?oo
o`010?ooo`000P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo00020?oo
o`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3o
ool0K`3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`1_0?ooo`030000
003oool0oooo0040oooo00020?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3o
ool00080oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`000P3oool00`00
0000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo06l0
oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0K`3oool00`000000oooo
0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo0002
0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?oo
o`3oool0K`3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo0040oooo00020?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0
0@3oool00080oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`000P3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo
06l0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0K`3oool00`000000
oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo
00020?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00080oooo00<00000
0?ooo`3oool0C`3oool2000001h0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?oo
o`3oool0C03oool30000000307moO`000000oooo01d0oooo00<000000?ooo`3oool00@3oool00080
oooo00<000000?ooo`3oool0BP3oool2000000D0Ogmo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`190?ooo`030000001oOgl0Ogmo00D0Ogmo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?oo
o`180?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`3oool0703oool00`000000oooo0?oo
o`010?ooo`000P3oool00`000000oooo0?ooo`160?ooo`800000201oOgl00`000000Ogmo07moO`0L
0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo04D0oooo00<0000007mo
O`1oOgl0201oOgl010000000Ogmo07moO`1oOglK0?ooo`030000003oool0oooo0040oooo00020?oo
o`030000003oool0oooo04@0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0207mo
Oa/0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0@`3oool00`000000
Ogmo07moO`0707moO`<000001@1oOglJ0?ooo`030000003oool0oooo0040oooo00020?ooo`030000
003oool0oooo04<0oooo00<0000007moO`1oOgl01P1oOgl5000000D0Ogmo6@3oool00`000000oooo
0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`120?ooo`030000001oOgl0Ogmo00L0Ogmo0P00
00000`09jPX000000000000507moOaT0oooo00<000000?ooo`3oool00@3oool00080oooo00<00000
0?ooo`3oool0@P3oool00`000000Ogmo07moO`0707moO`80000000<02NX:0000000000001P1oOglH
0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo0440oooo00<0000007mo
O`1oOgl02@1oOgl00`09jPX000000000000807moOaL0oooo00<000000?ooo`3oool00@3oool00080
oooo00<000000?ooo`3oool0@@3oool00`000000Ogmo07moO`0807moO`@02NX:2@1oOglF0?ooo`03
0000003oool0oooo0040oooo00020?ooo`030000003oool0oooo0400oooo00<0000007moO`1oOgl0
201oOgl00`09jPX0Ogmo00WZ2P0200WZ2PT0Ogmo5P3oool00`000000oooo0?ooo`010?ooo`000P3o
ool00`000000oooo0?ooo`0o0?ooo`0307moO`000000Ogmo00P0Ogmo00<02NX:07moO`0000000`09
jPX:07moOaD0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0?@3oool2
07moO`030000001oOgl0Ogmo00L0Ogmo00@02NX:07moO`1oOgl000001009jPX907moOaD0oooo00<0
00000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0>`3oool407moO`030000001oOgl0
Ogmo00H0Ogmo00@02NX:07moO`1oOgl000000P09jPX00`1oOgl02NX:00WZ2P0907moOaD0oooo00<0
00000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0>P3oool407moO`030000001oOgl0
Ogmo00L0Ogmo00D02NX:07moO`000000Ogmo00WZ2P0207moO`0300WZ2P1oOgl0Ogmo00T0Ogmo503o
ool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0h0?ooo`H0Ogmo00<00000
07moO`1oOgl01P1oOgl00`09jPX0Ogmo0000000507moO`0300WZ2P1oOgl0Ogmo00T0Ogmo503oool0
0`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0g0?ooo`L0Ogmo00<0000007mo
O`1oOgl01@1oOgl00`09jPX0Ogmo0000000607moO`0300WZ2P1oOgl0Ogmo00T0Ogmo503oool00`00
0000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0e0?ooo`T0Ogmo00<0000007moO`1o
Ogl0101oOgl01009jPX0Ogmo07moO`00000607moO`0300WZ2P1oOgl0Ogmo00T0Ogmo503oool00`00
0000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0c0?ooo`<00000201oOgl00`000000
Ogmo07moO`0307moO`0400WZ2P1oOgl0Ogmo000000L0Ogmo00<02NX:07moO`1oOgl0201oOglE0?oo
o`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo0340oooo00<0Ogmo00000000
00000`00000707moO`030000001oOgl0Ogmo0080Ogmo00@02NX:07moO`1oOgl00000201oOgl00`09
jPX0Ogmo07moO`0807moOaD0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3o
ool0;`3oool207moO`<0000000<02NX:0000000000000P1oOgl90000000400WZ2P1oOgl000000000
00T0Ogmo00<02NX:07moO`1oOgl0201oOglE0?ooo`030000003oool0oooo0040oooo00020?ooo`03
0000003oool0oooo02d0oooo101oOgl30000000300WZ2P000000000000800000101oOgl01@000000
Ogmo07moO`1oOgl02NX:008000002`1oOgl00`09jPX0Ogmo07moO`0707moOaH0oooo00<000000?oo
o`3oool00@3oool00080oooo00<000000?ooo`3oool0:`3oool607moO`@000001009jPX407moO`05
0000001oOgl0Ogmo07moO`09jPX03P1oOgl00`09jPX0Ogmo07moO`0607moOaH0oooo00<000000?oo
o`3oool00@3oool00080oooo00<000000?ooo`3oool0:@3oool507moO`<0000000<0Ogmo00000000
00001P09jPX307moO`040000001oOgl0Ogmo00WZ2Pl0Ogmo00<02NX:07moO`1oOgl01P1oOglF0?oo
o`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo02L0oooo1@1oOgl2000000@0
Ogmo2@09jPX207moO`030000001oOgl02NX:0100Ogmo00<02NX:07moO`1oOgl01@1oOglG0?ooo`03
0000003oool0oooo0040oooo00020?ooo`030000003oool0oooo02D0oooo1@1oOgl2000000H0Ogmo
0`09jPX00`1oOgl02NX:00WZ2P0400WZ2P0307moO`0000002NX:0140Ogmo00<02NX:07moO`1oOgl0
101oOglH0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo02<0oooo1P1o
Ogl00`000000Ogmo07moO`0607moO`<02NX:00@0Ogmo00WZ2P09jPX02NX:101oOgl00`09jPX0Ogmo
07moO`0@07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo603oool00`000000oooo0?ooo`010?ooo`000P3o
ool00`000000oooo0?ooo`0Q0?ooo`H0Ogmo0P00000907moO`<02NX:0P1oOgl00`09jPX0Ogmo00WZ
2P0207moO`0300WZ2P000000Ogmo0140Ogmo00<02NX:07moO`1oOgl00`1oOglI0?ooo`030000003o
ool0oooo0040oooo00020?ooo`030000003oool0oooo0200oooo1P1oOgl00`000000Ogmo07moO`08
07moO`D02NX:0P1oOgl400WZ2P0307moO`000000Ogmo0140Ogmo00<02NX:07moO`1oOgl00P1oOglJ
0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo01l0oooo1P1oOgl00`00
0000Ogmo07moO`0907moO`0500WZ2P1oOgl02NX:07moO`09jPX00`1oOgl300WZ2P80Ogmo00<00000
07moO`1oOgl03`1oOgl00`09jPX0Ogmo07moO`0207moOaX0oooo00<000000?ooo`3oool00@3oool0
0080oooo00<000000?ooo`3oool07@3oool707moO`030000001oOgl0Ogmo00`0Ogmo00<02NX:07mo
O`1oOgl00P1oOgl400WZ2P80Ogmo00<02NX:07moO`1oOgl03`1oOgl01009jPX0Ogmo07moO`1oOglK
0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo01`0oooo1`1oOgl00`00
0000Ogmo07moO`0=07moO`0300WZ2P1oOgl0Ogmo0080Ogmo1@09jPX00`1oOgl02NX:07moO`0@07mo
O`0400WZ2P1oOgl0Ogmo07moOa/0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?oo
o`3oool06P3oool807moO`030000001oOgl0Ogmo00h0Ogmo00@02NX:07moO`1oOgl0Ogmo2@09jPX@
07moO`0300WZ2P1oOgl0Ogmo01`0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?oo
o`3oool05P3oool3000000P0Ogmo00<0000007moO`1oOgl03`1oOgl01009jPX00000000000000002
00WZ2P<0Ogmo1009jPXA07moO`0300WZ2P1oOgl0oooo01/0oooo00<000000?ooo`3oool00@3oool0
0080oooo00<000000?ooo`3oool05@3oool5000000H0Ogmo00<0000007moO`1oOgl0401oOgl50000
00D0Ogmo1009jPX@07moO`0300WZ2P3oool0oooo01/0oooo00<000000?ooo`3oool00@3oool00080
oooo00<000000?ooo`3oool05@3oool2000001002NX:301oOgl5000000H0Ogmo0`09jPX807moO`<0
2NX:101oOgl00`0000002NX:0000000L0?ooo`030000003oool0oooo0040oooo00020?ooo`030000
003oool0oooo01D0oooo1@00000607moO`030000001oOgl0Ogmo00@0Ogmo3009jPX5000000T02NX:
0`00000607moO`D02NX:0P0000000`09jPX000000000000K0?ooo`030000003oool0oooo0040oooo
00020?ooo`030000003oool0oooo01@0oooo0P1oOgl3000000P0Ogmo00<0000007moO`1oOgl03`1o
Ogl01009jPX0000000000000000207moO`802NX:101oOgl00`09jPX0000000000003000000X02NX:
0P0000000`09jPX000000000000K0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003o
ool0oooo01<0oooo101oOgl200WZ2PP0Ogmo00<0000007moO`1oOgl03@1oOgl300000080Ogmo1009
jPX407moO`D02NX:0P00000507moO`D02NX:1@00000K0?ooo`030000003oool0oooo0040oooo0002
0?ooo`030000003oool0oooo01<0oooo101oOgl200WZ2PP0Ogmo00<0000007moO`1oOgl0301oOgl5
000000T02NX:00<0Ogmo0000000000001000000407moO`802NX:1@1oOgl3000001`0oooo00<00000
0?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool04P3oool407moO`@02NX:201oOgl00`00
0000Ogmo07moO`0;07moO`0300000009jPX02NX:008000001@09jPX507moO`030000001oOgl00000
0080000000<02NX:07moO`1oOgl0201oOglP0?ooo`030000003oool0oooo0040oooo00020?ooo`03
0000003oool0oooo0180oooo101oOgl400WZ2PP0Ogmo0P00000:07moO`<02NX:1000000207moO`@0
2NX:0`1oOgl00`000000Ogmo00WZ2P0400WZ2PT0Ogmo8@3oool00`000000oooo0?ooo`010?ooo`00
0P3oool00`000000oooo0?ooo`0A0?ooo`D0Ogmo1009jPX:07moO`8000001@1oOgl300WZ2P<0Ogmo
0`00000:07moO`040000001oOgl0Ogmo07moO`@02NX:1`1oOglR0?ooo`030000003oool0oooo0040
oooo00020?ooo`030000003oool0oooo0140oooo1@1oOgl01@09jPX0Ogmo00WZ2P1oOgl02NX:00/0
Ogmo00<0000007moO`09jPX00P09jPX807moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<0000007moO`1o
Ogl00P1oOgl300WZ2PD0Ogmo903oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo
0?ooo`0@0?ooo`P0Ogmo00<02NX:07moO`1oOgl02P1oOgl300WZ2P030000001oOgl0Ogmo00P0Ogmo
00<02NX:07moO`1oOgl0201oOgl00`000000Ogmo07moO`0407moO`0400WZ2P0000000000000002H0
oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0403oool807moO`0300WZ
2P1oOgl0Ogmo00P0Ogmo0P09jPX407moO`800000201oOgl00`09jPX0Ogmo07moO`0807moO`030000
001oOgl0Ogmo00@0Ogmo00<0000000WZ2P0000000P00000U0?ooo`030000003oool0oooo0040oooo
00020?ooo`030000003oool0oooo00l0oooo2@1oOgl00`09jPX0Ogmo07moO`0507moO`<02NX:201o
Ogl00`000000Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl01@1o
Ogl20000000300WZ2P000000000002D0oooo00<000000?ooo`3oool00@3oool00080oooo00<00000
0?ooo`3oool03`3oool907moO`0300WZ2P1oOgl0Ogmo0080Ogmo0`09jPX<07moO`8000001@1oOgl0
0`09jPX0Ogmo07moO`0707moO`030000001oOgl0Ogmo00<0Ogmo0P3oool5000002D0oooo00<00000
0?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool03`3oool907moO`0300WZ2P1oOgl02NX:
00802NX:4@1oOgl2000000<0Ogmo00<02NX:07moO`1oOgl01`1oOgl00`000000Ogmo07moO`0207mo
O`@0oooo0`00000V0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo00h0
oooo0`1oOgl200WZ2PD0Ogmo0P09jPXF07moO`<0000000<02NX:07moO`1oOgl01`1oOgl00`000000
Ogmo07moO`0_0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo00h0oooo
0P1oOgl300WZ2P80Ogmo1009jPXJ07moO`0300WZ2P000000Ogmo00H0Ogmo00<0000007moO`1oOgl0
<03oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0=0?ooo`0307moO`09
jPX02NX:00D02NX:0`1oOgl00`09jPX0Ogmo07moO`0H07moO`0300WZ2P1oOgl0000000@0000000<0
Ogmo0000001oOgl0<P3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0:
0?ooo`<000001P09jPX507moO`0300WZ2P1oOgl0Ogmo01P0Ogmo00<02NX:07moO`1oOgl01@000000
0`1oOgl0oooo0?ooo`0a0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo
00T0oooo1@00000600WZ2PD0Ogmo00<02NX:07moO`1oOgl05`1oOgl300WZ2P80000000@02NX:0000
000000000000<`3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`090?oo
o`80000000@02NX:0000000000002NX:2P1oOgl00`09jPX0Ogmo07moO`0D07moO`H02NX:0P000000
1009jPX000000000001oOgl300000300oooo00<000000?ooo`3oool00@3oool00080oooo00<00000
0?ooo`3oool02@3oool20000000300WZ2P000000000000/0Ogmo00<02NX:07moO`1oOgl05P1oOgl4
00WZ2P0407moO`0000002NX:000000D0Ogmo0P00000^0?ooo`030000003oool0oooo0040oooo0002
0?ooo`030000003oool0oooo00X0oooo0P0000000`09jPX0Ogmo07moO`0:07moO`0300WZ2P1oOgl0
Ogmo01<0Ogmo0`09jPX00`1oOgl02NX:00WZ2P0307moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0:0?oo
o`<0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`09jPX0Ogmo07moO`0@07moO`<02NX:0`1oOgl200WZ
2P@0000000<02NX:07moO`1oOgl01`1oOgl00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
0040oooo00020?ooo`030000003oool0oooo00X0oooo101oOgl00`09jPX0Ogmo07moO`0807moO`03
00WZ2P1oOgl0Ogmo00h0Ogmo0P09jPX00`1oOgl02NX:00WZ2P0400WZ2PD0000000<02NX:07moO`1o
Ogl0201oOgl2000002X0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0
2P3oool307moO`80000000<02NX:07moO`1oOgl01`1oOgl00`09jPX0Ogmo07moO`0;07moO`<02NX:
00<0Ogmo00WZ2P09jPX02@09jPX20000000300WZ2P1oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0:0?ooo`80Ogmo1000
00000`09jPX0Ogmo07moO`0507moOa<02NX:101oOgl400WZ2PD0000000<02NX:07moO`1oOgl02`1o
Ogl2000002L0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool02P3oool2
07moO`8000002P09jPX00`1oOgl02NX:07moO`0707moO`<02NX:1`1oOgl500WZ2P0307moO`09jPX0
Ogmo00<0000000<0Ogmo00WZ2P1oOgl03P1oOgl00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo0040oooo00020?ooo`030000003oool0oooo00X0oooo0P1oOgl5000000H02NX:0P1oOgl00`09
jPX0Ogmo07moO`0307moO`<02NX:1P1oOgl400WZ2P0307moO`09jPX0Ogmo0080Ogmo00<0000000WZ
2P1oOgl01@1oOgl00`09jPX0Ogmo07moO`0=07moO`030000001oOgl0oooo02<0oooo00<000000?oo
o`3oool00@3oool00080oooo00<000000?ooo`3oool02`3oool207moO`<000000P1oOgl400WZ2P<0
Ogmo00@02NX:07moO`1oOgl0Ogmo0P09jPX507moO`@02NX:201oOgl00`000000Ogmo00WZ2P0607mo
O`0300WZ2P1oOgl0Ogmo00h0Ogmo00<0000007moO`3oool08P3oool00`000000oooo0?ooo`010?oo
o`000P3oool00`000000oooo0?ooo`0;0?ooo`P0Ogmo0P09jPX01@1oOgl02NX:00WZ2P09jPX0Ogmo
00<02NX:0`1oOgl400WZ2PX0Ogmo0P00000207moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07mo
O`1oOgl03P1oOgl010000000Ogmo07moO`1oOglQ0?ooo`030000003oool0oooo0040oooo00020?oo
o`030000003oool0oooo00/0oooo2@1oOgl200WZ2P80Ogmo1009jPX0101oOgl02NX:00WZ2P09jPX=
07moO`030000001oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0>
07moO`030000001oOgl0Ogmo0080Ogmo803oool00`000000oooo0?ooo`010?ooo`000P3oool00`00
0000oooo0?ooo`0;0?ooo`P0Ogmo1@09jPX00`1oOgl02NX:00WZ2P0400WZ2Pd0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo00d0Ogmo00<0000007mo
O`1oOgl0101oOglO0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo00/0
oooo1P1oOgl800WZ2P0307moO`09jPX0Ogmo00<0Ogmo0`09jPX907moO`030000001oOgl0Ogmo00@0
Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0=07moO`030000001oOgl0Ogmo00D0
Ogmo1P3oool3000001D0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0
2`3oool30000000307moO`09jPX02NX:00@02NX:0P1oOgl01009jPX0Ogmo07moO`09jPX707moO`<0
2NX:1@1oOgl00`000000Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1o
Ogl03@1oOgl00`000000Ogmo07moO`0607moO`@0oooo1@00000D0?ooo`030000003oool0oooo0040
oooo00020?ooo`030000003oool0oooo00X0oooo0`00000800WZ2P<0Ogmo00<02NX:07moO`09jPX0
2P1oOgl300WZ2P800000201oOgl00`09jPX0Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo00d0Ogmo
00<0000007moO`1oOgl01`1oOgl30?ooo`0300000009jPX02NX:00800000503oool00`000000oooo
0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0:0?ooo`80000000<02NX:0000000000001`09
jPX307moO`802NX:301oOgl0100000002NX:00WZ2P09jPX707moO`0300WZ2P1oOgl0Ogmo00@0Ogmo
00<02NX:07moO`1oOgl0301oOgl00`000000Ogmo07moO`0907moO`<02NX:1000000D0?ooo`030000
003oool0oooo0040oooo00020?ooo`030000003oool0oooo00X0oooo1@00000;07moO`0300WZ2P1o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2PD0Ogmo00<02NX:07moO`1oOgl0101o
Ogl00`09jPX0Ogmo07moO`0;07moO`800000201oOgl300WZ2P80Ogmo00@0oooo0000000000000000
5@3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0;0?ooo`<00000301o
Ogl200WZ2PT0Ogmo00<0000007moO`1oOgl01@1oOgl300WZ2P80Ogmo00<02NX:07moO`1oOgl0101o
Ogl00`09jPX0Ogmo07moO`0:07moO`030000001oOgl0Ogmo00D0Ogmo0`09jPX607moO`<02NX:5@3o
ool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0=0?ooo`d0Ogmo0P09jPX8
07moO`030000001oOgl0Ogmo00T0Ogmo0`09jPX607moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl00`1oOgl300WZ2PL0Ogmo0P00000300WZ2QD0oooo00<000000?ooo`3oool00@3oool0
0080oooo00<000000?ooo`3oool03P3oool<07moO`0300WZ2P1oOgl02NX:00H0Ogmo00<0000007mo
O`1oOgl0301oOgl400WZ2P<0Ogmo00<02NX:07moO`1oOgl01`1oOgl2000000<0Ogmo0`09jPX807mo
O`@000000`09jPXE0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo00h0
oooo3@1oOgl00`09jPX0Ogmo00WZ2P0407moO`030000001oOgl0Ogmo00d0Ogmo00@02NX:07moO`1o
Ogl0Ogmo1009jPX807moO`030000001oOgl0Ogmo00<02NX:2P1oOgl5000000<02NX:00<0Ogmo0?oo
o`3oool04P3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0?0?ooo``0
Ogmo00@02NX:07moO`1oOgl02NX:0P1oOgl00`000000Ogmo07moO`0>07moO`0300WZ2P1oOgl0Ogmo
00@0Ogmo0`09jPX507moO`0400000009jPX02NX:00WZ2Pd0Ogmo0P0000000`09jPX0000000000004
00WZ2P0307moO`3oool0oooo0140oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?oo
o`3oool0403oool;07moO`0600WZ2P1oOgl0Ogmo07moO`09jPX000004@1oOgl00`09jPX0Ogmo07mo
O`0407moO`0300WZ2P1oOgl0Ogmo00H02NX:3`1oOgl01009jPX0000000000009jPX40000000407mo
O`09jPX0Ogmo07moOa80oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0
4@3oool907moO`0300000009jPX000000080Ogmo00<0000000WZ2P1oOgl0401oOgl00`09jPX0Ogmo
07moO`0200WZ2P<0Ogmo00<02NX:07moO`09jPX01@09jPX=07moO`802NX:0P1oOgl00`09jPX00000
00000004000000@0Ogmo4@3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?oo
o`0B0?ooo`L0Ogmo0P0000001009jPX000000000001oOgl500WZ2Ph0Ogmo00<02NX:07moO`09jPX0
0P09jPX207moO`<02NX:00<0Ogmo0000001oOgl00`1oOgl300WZ2PP0Ogmo0P09jPX307moO`0600WZ
2P1oOgl02NX:00WZ2P0000002NX:0P00000507moOa00oooo00<000000?ooo`3oool00@3oool00080
oooo00<000000?ooo`3oool04`3oool607moO`80000000<02NX:0000000000001@09jPX?07moO`L0
2NX:00@0Ogmo00WZ2P1oOgl00000201oOgl200WZ2PD0Ogmo00<02NX:07moO`1oOgl00`1oOgl01P09
jPX0Ogmo00WZ2P09jPX0000000WZ2P8000001@1oOgl@0?ooo`030000003oool0oooo0040oooo0002
0?ooo`030000003oool0oooo01<0oooo1P1oOgl5000000P02NX:201oOgl3000000L02NX:0P1oOgl0
0`09jPX0Ogmo0000000:07moO`D02NX:1@1oOgl00`09jPX0Ogmo00WZ2P0400WZ2P030000001oOgl0
Ogmo00D0Ogmo3`3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0D0?oo
o`H0Ogmo0`00000207moO`0300000009jPX02NX:00802NX:0P1oOgl700WZ2PD000001`09jPX00`1o
Ogl02NX:0000000<07moO`D02NX:101oOgl800WZ2PP0Ogmo3P3oool00`000000oooo0?ooo`010?oo
o`000P3oool00`000000oooo0?ooo`0F0?ooo`T0Ogmo00@0000007moO`1oOgl0Ogmo0P09jPX00`1o
Ogl02NX:07moO`0507moO`<02NX:0P00000200WZ2PH0Ogmo00<02NX:07moO`1oOgl02@1oOgl200WZ
2PD0Ogmo3009jPX907moO`d0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3o
ool0603oool607moO`030000001oOgl0Ogmo0080Ogmo1@09jPX507moO`D0000000<02NX:07moO`1o
Ogl0101oOgl00`0000002NX:07moO`0807moO`802NX:2@1oOgl900WZ2P/0Ogmo303oool00`000000
oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0I0?ooo`D0Ogmo00<0000007moO`1oOgl0
101oOgl300WZ2PH0Ogmo0`0000000`1oOgl02NX:07moO`0407moO`030000001oOgl02NX:00L0Ogmo
0P09jPX;07moO`0300WZ2P1oOgl0Ogmo00H02NX:301oOgl;0?ooo`030000003oool0oooo0040oooo
00020?ooo`030000003oool0oooo01X0oooo101oOgl00`000000Ogmo07moO`0507moO`<02NX:2@1o
Ogl00`09jPX0Ogmo07moO`0207moO`040000001oOgl0Ogmo00WZ2PD0Ogmo0P09jPX<07moO`0500WZ
2P1oOgl0Ogmo07moO`09jPX00P1oOgl400WZ2P/0Ogmo2`3oool00`000000oooo0?ooo`010?ooo`00
0P3oool00`000000oooo0?ooo`0K0?ooo`<0Ogmo00<0000007moO`1oOgl01`1oOgl01009jPX00000
00000000000607moO`0500WZ2P1oOgl0Ogmo07moO`0000000`1oOgl01009jPX0Ogmo07moO`1oOgl2
00WZ2Pd0Ogmo00<02NX:07moO`1oOgl01P1oOgl200WZ2P0407moO`09jPX02NX:00WZ2PT0Ogmo2P3o
ool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0L0?ooo`80Ogmo00<00000
07moO`1oOgl01`1oOgl5000000D0Ogmo00@02NX:07moO`1oOgl000000P1oOgl01009jPX0Ogmo00WZ
2P1oOgl200WZ2Pd0Ogmo0`09jPX707moO`<02NX:101oOgl300WZ2P80Ogmo0`0000000`1oOgl0oooo
0?ooo`080?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo01d0oooo00<0
Ogmo0000001oOgl0201oOgl2000000802NX:00<0000007moO`1oOgl00`1oOgl00`09jPX0Ogmo0000
000207moO`802NX:00<0Ogmo00WZ2P09jPX03P1oOgl00`09jPX0Ogmo00WZ2P0807moO`<02NX:1`1o
Ogl300WZ2P<0000000<0Ogmo0?ooo`3oool01`3oool00`000000oooo0?ooo`010?ooo`000P3oool0
0`000000oooo0?ooo`0N0?ooo`0307moO`000000Ogmo00L0Ogmo1000000300WZ2P<0Ogmo00@02NX:
0000001oOgl0Ogmo0P09jPX00`1oOgl02NX:00WZ2P0>07moO`0300WZ2P1oOgl02NX:00T0Ogmo0`09
jPX807moO`80000000<02NX:0000000000000P1oOgl80?ooo`030000003oool0oooo0040oooo0002
0?ooo`030000003oool0oooo01l0oooo00<0Ogmo0000001oOgl01`1oOgl3000000<0Ogmo0P09jPX0
101oOgl02NX:07moO`1oOgl600WZ2Pd0Ogmo00@02NX:07moO`1oOgl02NX:2@1oOgl300WZ2PP0Ogmo
1@00000207moO`P0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0803o
ool00`1oOgl0000007moO`0>07moO`802NX:00<0000000WZ2P09jPX01@09jPX<07moO`0400WZ2P1o
Ogl0Ogmo00WZ2PX0Ogmo0`09jPX907moO`<00000101oOgl70?ooo`030000003oool0oooo0040oooo
00020?ooo`030000003oool0oooo0240oooo00<0Ogmo0000001oOgl0301oOgl2000000H02NX:0P1o
Ogl00`09jPX0Ogmo07moO`0807moO`802NX:0`1oOgl00`09jPX0Ogmo07moO`0707moO`0400WZ2P1o
Ogl0Ogmo00WZ2PT0Ogmo0P09jPX507moO`L0oooo00<000000?ooo`3oool00@3oool00080oooo00<0
00000?ooo`3oool08P3oool00`1oOgl0000007moO`0;07moO`80000000@02NX:000000000000Ogmo
0`09jPX0101oOgl02NX:07moO`09jPX707moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1o
Ogl0201oOgl01009jPX0Ogmo07moO`09jPX807moO`<02NX:1@1oOgl70?ooo`030000003oool0oooo
0040oooo00020?ooo`030000003oool0oooo02<0oooo00<0Ogmo0000001oOgl02P1oOgl5000000<0
Ogmo0P09jPX00`1oOgl02NX:00WZ2P0607moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1o
Ogl02@1oOgl01009jPX0Ogmo07moO`09jPX807moO`<02NX:1@1oOgl70?ooo`030000003oool0oooo
0040oooo00020?ooo`030000003oool0oooo02@0oooo00<0Ogmo0000001oOgl02@1oOgl4000000D0
Ogmo1009jPX507moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl02@1oOgl01009jPX0
Ogmo07moO`09jPX707moO`@02NX:1@1oOgl70?ooo`030000003oool0oooo0040oooo00020?ooo`03
0000003oool0oooo02D0oooo00<0Ogmo000000000000201oOgl00`000000Ogmo07moO`0607moO`H0
2NX:00<0Ogmo00WZ2P09jPX01@1oOgl00`09jPX0Ogmo07moO`0:07moO`0400WZ2P1oOgl0Ogmo00WZ
2PL0Ogmo00@02NX:07moO`09jPX02NX:1P1oOgl60?ooo`030000003oool0oooo0040oooo00020?oo
o`030000003oool0oooo02@0oooo101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo
00H0Ogmo1009jPX207moO`802NX:1@1oOgl00`09jPX0Ogmo07moO`0:07moO`0400WZ2P1oOgl0Ogmo
07moO`802NX:1@1oOgl00`09jPX0Ogmo07moO`0200WZ2PH0Ogmo1P3oool00`000000oooo0?ooo`01
0?ooo`000P3oool00`000000oooo0?ooo`0S0?ooo`H0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0707moO`802NX:0P1oOgl00`09jPX0Ogmo07moO`0300WZ2P80Ogmo00<02NX:07mo
O`1oOgl02P1oOgl01009jPX0Ogmo07moO`1oOgl200WZ2PL0Ogmo00<02NX:07moO`1oOgl01P1oOgl6
0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo01l0oooo1000000707mo
O`800000101oOgl00`000000Ogmo07moO`0707moO`<0000000<02NX:07moO`1oOgl0101oOgl200WZ
2Pd0Ogmo00@02NX:07moO`1oOgl0Ogmo0P09jPX707moO`0300WZ2P1oOgl0Ogmo00H0Ogmo1P3oool0
0`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0K0?ooo`@00000101oOgl20000
00L0Ogmo00@0000007moO`1oOgl000002@1oOgl30000000300WZ2P000000Ogmo00H0Ogmo0`09jPX;
07moO`0400WZ2P1oOgl0Ogmo07moO`802NX:1`1oOgl00`09jPX0Ogmo07moO`0607moO`H0oooo00<0
00000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool05`3oool4000000X0Ogmo0`000005
07moO`030000001oOgl0000000T0Ogmo0P0000000`09jPX000000000000607moO`0400WZ2P1oOgl0
Ogmo07moO`<02NX:201oOgl01P09jPX0Ogmo07moO`09jPX0Ogmo00WZ2PL0Ogmo00<02NX:07moO`1o
Ogl01P1oOgl60?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo01D0oooo
0P00000A07moO`800000101oOgl2000000T0Ogmo1@00000507moO`0300WZ2P1oOgl0Ogmo00D0Ogmo
0P09jPX507moO`0700WZ2P1oOgl0Ogmo07moO`09jPX0Ogmo00WZ2P0707moO`0300WZ2P1oOgl0Ogmo
00H0Ogmo1P3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0E0?ooo`03
0000001oOgl0Ogmo0180Ogmo00<0000007moO`1oOgl00P1oOgl2000000T0Ogmo0`00000607moO`03
00WZ2P1oOgl0Ogmo00L0Ogmo0P09jPX307moO`802NX:0P1oOgl00`09jPX0Ogmo00WZ2P0607moO`03
00WZ2P1oOgl0Ogmo00L0Ogmo1P3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo
0?ooo`0D0?ooo`030000001oOgl0Ogmo01<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo
0000000@07moO`0300WZ2P1oOgl0Ogmo00X0Ogmo1P09jPX0101oOgl02NX:07moO`09jPX607moO`03
00WZ2P1oOgl0Ogmo00H0Ogmo1`3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo
0?ooo`0C0?ooo`030000001oOgl0Ogmo01D0Ogmo00D0000007moO`1oOgl0Ogmo0000000207moO`03
0000001oOgl0Ogmo00`0Ogmo00<02NX:07moO`1oOgl03P1oOgl500WZ2P0307moO`09jPX0Ogmo00D0
Ogmo00<02NX:07moO`1oOgl01P1oOgl70?ooo`030000003oool0oooo0040oooo00020?ooo`030000
003oool0oooo01<0oooo00<0000007moO`1oOgl05P1oOgl010000000Ogmo07moO`00000307moO`03
0000001oOgl0Ogmo00/0Ogmo00<02NX:07moO`1oOgl03P1oOgl600WZ2P0300000009jPX0000000@0
Ogmo00<02NX:07moO`1oOgl01P1oOgl70?ooo`030000003oool0oooo0040oooo00020?ooo`030000
003oool0oooo0180oooo00<0000007moO`1oOgl0601oOgl00`000000Ogmo0000000407moO`030000
001oOgl0Ogmo00T0Ogmo00<02NX:07moO`1oOgl03@1oOgl700WZ2P80000000<02NX:000000000000
0`1oOgl00`09jPX0Ogmo07moO`0607moO`L0oooo00<000000?ooo`3oool00@3oool00080oooo00<0
00000?ooo`3oool04@3oool00`000000Ogmo07moO`0J07moO`8000001@1oOgl00`000000Ogmo07mo
O`0707moO`0300WZ2P1oOgl0Ogmo00l0Ogmo00<02NX:07moO`1oOgl00P1oOgl01009jPX000000000
0009jPX2000000<0Ogmo00<02NX:07moO`1oOgl01P1oOgl70?ooo`030000003oool0oooo0040oooo
00020?ooo`030000003oool0oooo0140oooo00<0000007moO`1oOgl06`1oOgl2000000D0Ogmo00<0
000007moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0?07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0
2NX:0000000000000`00000207moO`0300WZ2P1oOgl0Ogmo00H0Ogmo203oool00`000000oooo0?oo
o`010?ooo`000P3oool00`000000oooo0?ooo`0@0?ooo`030000001oOgl0Ogmo01d0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo0100Ogmo00<02NX:
07moO`1oOgl00P1oOgl00`09jPX0Ogmo00000002000000<0Ogmo00<02NX:07moO`1oOgl01@1oOgl9
0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo00l0oooo00<0000007mo
O`1oOgl07P1oOgl2000000H0Ogmo00<0000007moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0@07mo
O`0300WZ2P1oOgl0Ogmo0080Ogmo00@02NX:07moO`1oOgl02NX:101oOgl00`09jPX0Ogmo07moO`05
07moO`T0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool03`3oool00`00
0000Ogmo07moO`0O07moO`8000001P1oOgl01@000000Ogmo07moO`1oOgl02NX:0180Ogmo00<02NX:
07moO`1oOgl00`1oOgl01009jPX0Ogmo07moO`09jPX407moO`0300WZ2P1oOgl0Ogmo00@0Ogmo2P3o
ool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0>0?ooo`030000001oOgl0
Ogmo0200Ogmo0P00000707moO`030000001oOgl02NX:01<0Ogmo00<02NX:07moO`1oOgl00`1oOgl0
1009jPX0Ogmo07moO`09jPX407moO`0300WZ2P1oOgl0Ogmo00<0Ogmo2`3oool00`000000oooo0?oo
o`010?ooo`000P3oool00`000000oooo0?ooo`0=0?ooo`030000001oOgl0Ogmo0280Ogmo0P000006
07moO`030000001oOgl02NX:01<0Ogmo00<02NX:07moO`1oOgl00`1oOgl01009jPX0Ogmo07moO`09
jPX307moO`0300WZ2P1oOgl0Ogmo00@0Ogmo2`3oool00`000000oooo0?ooo`010?ooo`000P3oool0
0`000000oooo0?ooo`0=0?ooo`030000001oOgl0Ogmo02<0Ogmo00<0000007moO`1oOgl01@1oOgl0
0`09jPX0Ogmo07moO`0B07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00@02NX:07moO`1oOgl02NX:0`1o
Ogl00`09jPX0Ogmo07moO`0307moO``0oooo00<000000?ooo`3oool00@3oool00080oooo00<00000
0?ooo`3oool03@3oool00`000000Ogmo07moO`0S07moO`8000001@1oOgl00`09jPX0000007moO`0C
07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00@02NX:07moO`1oOgl02NX:0`1oOgl00`09jPX0Ogmo07mo
O`0307moO``0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool03@3oool0
0`000000Ogmo07moO`0T07moO`800000101oOgl00`09jPX0000007moO`0C07moO`0300WZ2P1oOgl0
Ogmo00<0Ogmo00@02NX:07moO`1oOgl02NX:0`1oOgl00`09jPX0Ogmo07moO`0207moO`d0oooo00<0
00000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool03@3oool00`000000Ogmo07moO`0U
07moO`<0000000D0Ogmo00WZ2P1oOgl0Ogmo0000000B07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00@0
2NX:07moO`1oOgl02NX:0`1oOgl00`09jPX0Ogmo07moO`0207moO`d0oooo00<000000?ooo`3oool0
0@3oool00080oooo00<000000?ooo`3oool03@3oool00`000000Ogmo07moO`0U07moO`060000001o
Ogl0Ogmo00000009jPX0Ogmo0P00000B07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00@02NX:07moO`1o
Ogl02NX:0`1oOgl00`09jPX0Ogmo07moO`0207moO`d0oooo00<000000?ooo`3oool00@3oool00080
oooo00<000000?ooo`3oool03@3oool00`000000Ogmo07moO`0V07moO`030000001oOgl02NX:0080
0000501oOgl00`09jPX0Ogmo07moO`0407moO`0400WZ2P1oOgl0Ogmo00WZ2P80Ogmo00<02NX:07mo
O`1oOgl00P1oOgl>0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo00d0
oooo00<0000007moO`1oOgl09`1oOgl00`09jPX0Ogmo07moO`0E07moO`0300WZ2P1oOgl0Ogmo00@0
Ogmo00@02NX:07moO`1oOgl02NX:0P1oOgl00`09jPX0Ogmo07moO`0207moO`h0oooo00<000000?oo
o`3oool00@3oool00080oooo00<000000?ooo`3oool03@3oool00`000000Ogmo07moO`0W07moO`03
00WZ2P1oOgl0Ogmo01D0Ogmo00<02NX:07moO`1oOgl00`1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:
0080Ogmo00<02NX:07moO`1oOgl00P1oOgl>0?ooo`030000003oool0oooo0040oooo00020?ooo`03
0000003oool0oooo00h0oooo00<0000007moO`1oOgl09@1oOgl00`09jPX0Ogmo0000000E07moO`03
00WZ2P1oOgl0Ogmo00@0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0207moO`0400WZ2P1oOgl0Ogmo
07moO`l0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool03P3oool00`00
0000Ogmo07moO`0T07moO`0400WZ2P1oOgl0Ogmo000001D0Ogmo00<02NX:07moO`1oOgl0101oOgl0
1@09jPX0Ogmo07moO`1oOgl02NX:0080Ogmo00@02NX:07moO`1oOgl0Ogmo3`3oool00`000000oooo
0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0>0?ooo`030000001oOgl0Ogmo02@0Ogmo00D0
2NX:07moO`1oOgl0Ogmo0000000D07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00L02NX:07moO`1oOgl0
Ogmo00WZ2P1oOgl02NX:00@0Ogmo3`3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000
oooo0?ooo`0>0?ooo`030000001oOgl0Ogmo02<0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`000000
Ogmo07moO`0B07moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2P@0
Ogmo3`3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0>0?ooo`030000
001oOgl0Ogmo0280Ogmo00<02NX:07moO`1oOgl0101oOgl00`000000Ogmo07moO`0A07moO`0300WZ
2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2P<0Ogmo403oool00`000000oooo
0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0>0?ooo`030000001oOgl0Ogmo0280Ogmo00<0
2NX:07moO`1oOgl0101oOgl00`000000Ogmo07moO`0@07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<0
2NX:07moO`1oOgl00P1oOgl200WZ2P80Ogmo4@3oool00`000000oooo0?ooo`010?ooo`000P3oool0
0`000000oooo0?ooo`0>0?ooo`030000001oOgl0Ogmo0240Ogmo00<02NX:07moO`1oOgl01P1oOgl0
0`000000Ogmo07moO`0?07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl00P1oOgl2
00WZ2P0307moO`3oool0oooo0100oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?oo
o`3oool03P3oool00`000000Ogmo07moO`0Q07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<0000007mo
O`1oOgl03`1oOgl300WZ2P80Ogmo0P09jPX00`0000002NX:0000000207moO`0300000009jPX00000
01<0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool03P3oool00`000000
Ogmo07moO`0P07moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl03P1oOgl600WZ2P80
000000<02NX:0000000000000P0000000`09jPX000000000000B0?ooo`030000003oool0oooo0040
oooo00020?ooo`030000003oool0oooo00T0ooooBP09jPX20000000300WZ2P000000000000800000
00<02NX:0000000000004P3oool00`000000oooo0?ooo`010?ooo`0000@0oooo0000000000000000
403oool00`000000Ogmo07moO`0N07moO`0300WZ2P1oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
301oOgl00`09jPX0Ogmo00WZ2P0400WZ2PX000004P3oool00`000000oooo0?ooo`010?ooo`001@00
00020?ooo`D02NX:2@3oool00`000000Ogmo07moO`0L07moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl02`1oOgl300WZ2P<0Ogmo0P09jPX300000080oooo0`00000C0?ooo`030000003o
ool0oooo0040oooo0005000000D02NX:303oool00`000000Ogmo07moO`0J07moO`0300WZ2P1oOgl0
Ogmo00d0Ogmo00<0000007moO`1oOgl02`1oOgl00`09jPX0Ogmo07moO`0707moOaT0oooo00<00000
0?ooo`3oool00@3oool000D000002P09jPX80?ooo`030000001oOgl0Ogmo01T0Ogmo00<02NX:07mo
O`1oOgl03P1oOgl00`000000Ogmo07moO`0:07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo6P3oool00`00
0000oooo0?ooo`010?ooo`0000@0oooo00000000000000000`3oool300WZ2PD0oooo1`09jPX00`3o
ool0000007moO`0I07moO`0300WZ2P1oOgl0Ogmo00l0Ogmo00<0000007moO`1oOgl0201oOgl00`09
jPX0Ogmo00WZ2P0707moOa/0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3o
ool01@3oool00`09jPX0oooo0?ooo`090?ooo`P02NX:4`1oOgl00`09jPX0Ogmo07moO`0A07moO`03
0000001oOgl0Ogmo00L0Ogmo0P09jPX00`1oOgl02NX:00WZ2P0407moOa`0oooo00<000000?ooo`3o
ool00@3oool00080oooo00<000000?ooo`3oool0503oool00`000000Ogmo07moO`0207moO`P02NX:
2`1oOgl00`09jPX0Ogmo07moO`0A07moO`030000001oOgl0Ogmo00L0Ogmo1@09jPX307moOad0oooo
00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool05@3oool00`000000Ogmo07mo
O`0907moO`L02NX:0`1oOgl00`09jPX0Ogmo07moO`0C07moO`030000001oOgl0Ogmo00H0Ogmo1009
jPX307moOah0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool05P3oool0
0`000000Ogmo07moO`0?07moO`P02NX:4@1oOgl00`000000Ogmo07moO`0607moO`@02NX:0P1oOglO
0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo01L0oooo00<0000007mo
O`1oOgl0401oOgl00`09jPX0Ogmo07moO`0307moO`P02NX:2P1oOgl00`000000Ogmo07moO`0507mo
O`<02NX:0P1oOglP0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo01L0
oooo00<0000007moO`1oOgl03`1oOgl00`09jPX0Ogmo07moO`0<07moO`L02NX:0`1oOgl00`000000
Ogmo07moO`0407moO`<000000P1oOglQ0?ooo`030000003oool0oooo0040oooo00020?ooo`030000
003oool0oooo01P0oooo00<0000007moO`1oOgl03P1oOgl00`09jPX0Ogmo07moO`0C07moO`P02NX:
00<0Ogmo0000000000000`00000R0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003o
ool0oooo01T0oooo00<0000007moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0F07moO`030000001o
Ogl0Ogmo00<0Ogmo1009jPX200000280oooo00<000000?ooo`3oool00@3oool00080oooo00<00000
0?ooo`3oool06P3oool00`000000Ogmo07moO`0:07moO`0300WZ2P1oOgl0Ogmo01L0Ogmo00<00000
07moO`1oOgl0101oOgl500000280oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?oo
o`3oool06`3oool2000000X0Ogmo00<02NX:07moO`1oOgl05`1oOgl00`000000Ogmo07moO`0507mo
O`<000008`3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0M0?ooo`80
00001`1oOgl00`09jPX0Ogmo07moO`0H07moO`030000001oOgl0Ogmo00<0Ogmo:03oool00`000000
oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0O0?ooo`<00000101oOgl00`09jPX0Ogmo
07moO`0G07moO`030000001oOgl0Ogmo00<0Ogmo:@3oool00`000000oooo0?ooo`010?ooo`000P3o
ool00`000000oooo0?ooo`0R0?ooo`80000000<0Ogmo00WZ2P1oOgl06@1oOgl00`000000Ogmo07mo
O`0207moObX0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0903oool0
0`09jPX0000007moO`0I07moO`030000001oOgl0Ogmo02`0oooo00<000000?ooo`3oool00@3oool0
0080oooo00<000000?ooo`3oool0903oool01009jPX0oooo00000000000H07moO`030000001oOgl0
oooo02`0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool08`3oool00`09
jPX0oooo0?ooo`020?ooo`8000005@1oOgl00`000000Ogmo0?ooo`0]0?ooo`030000003oool0oooo
0040oooo00020?ooo`030000003oool0oooo0280oooo00<02NX:0?ooo`3oool01@3oool3000000h0
Ogmo1@00000_0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo0280oooo
00<02NX:0?ooo`3oool0203oool2000000@0Ogmo2000000d0?ooo`030000003oool0oooo0040oooo
00020?ooo`030000003oool0oooo0240oooo00<02NX:0?ooo`3oool02`3oool4000003`0oooo00<0
00000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0803oool00`09jPX0oooo0?ooo`1<
0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo0200oooo00<02NX:0?oo
o`3oool0C03oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0O0?ooo`03
00WZ2P3oool0oooo04d0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0
7`3oool00`09jPX0oooo0?ooo`1=0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003o
ool0oooo01h0oooo00<02NX:0?ooo`3oool0CP3oool00`000000oooo0?ooo`010?ooo`000P3oool0
0`000000oooo0?ooo`0M0?ooo`0300WZ2P3oool0oooo04l0oooo00<000000?ooo`3oool00@3oool0
0080oooo00<000000?ooo`3oool07@3oool00`09jPX0oooo0?ooo`1?0?ooo`030000003oool0oooo
0040oooo00020?ooo`030000003oool0oooo01`0oooo00<02NX:0?ooo`3oool0D03oool00`000000
oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo0540oooo
00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool06`3oool00`09jPX0oooo0?oo
o`1A0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo01X0oooo00<02NX:
0?ooo`3oool0DP3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0J0?oo
o`0300WZ2P3oool0oooo0580oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3o
ool06@3oool00`09jPX0oooo0?ooo`1C0?ooo`030000003oool0oooo0040oooo00020?ooo`030000
003oool0oooo01P0oooo00<02NX:0?ooo`3oool0E03oool00`000000oooo0?ooo`010?ooo`000P3o
ool00`000000oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo05@0oooo00<000000?ooo`3oool00@3o
ool00080oooo00<000000?ooo`3oool05`3oool00`09jPX0oooo0?ooo`1E0?ooo`030000003oool0
oooo0040oooo00020?ooo`030000003oool0oooo01H0oooo00<02NX:0?ooo`3oool0EP3oool00`00
0000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo05H0
oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool05@3oool00`09jPX0oooo
0?ooo`1G0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo01@0oooo00<0
2NX:0?ooo`3oool0F03oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0D
0?ooo`0300WZ2P3oool0oooo05P0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?oo
o`3oool04`3oool00`09jPX0oooo0?ooo`1I0?ooo`030000003oool0oooo0040oooo00020?ooo`03
0000003oool0oooo01<0oooo00<02NX:0?ooo`3oool0F@3oool00`000000oooo0?ooo`010?ooo`00
0P3oool00`000000oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo05X0oooo00<000000?ooo`3oool0
0@3oool00080oooo00<000000?ooo`3oool04@3oool00`09jPX0oooo0?ooo`1K0?ooo`030000003o
ool0oooo0040oooo00020?ooo`030000003oool0oooo0140oooo00<02NX:0?ooo`3oool0F`3oool0
0`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo
05`0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool03`3oool00`09jPX0
oooo0?ooo`1M0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo00l0oooo
00<02NX:0?ooo`3oool0G@3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?oo
o`0>0?ooo`0300WZ2P3oool0oooo05h0oooo00<000000?ooo`3oool00@3oool00080oooo00<00000
0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`1N0?ooo`030000003oool0oooo0040oooo00020?oo
o`030000003oool0oooo00d0oooo00<02NX:0?ooo`3oool0G`3oool00`000000oooo0?ooo`010?oo
o`000P3oool00`000000oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo0600oooo00<000000?ooo`3o
ool00@3oool00080oooo00<000000?ooo`3oool0303oool00`09jPX0oooo0?ooo`1P0?ooo`030000
003oool0oooo0040oooo00020?ooo`030000003oool0oooo00/0oooo00<02NX:0?ooo`3oool0H@3o
ool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`080?ooo`0300WZ2P3oool0
2NX:06@0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0203oool00`09
jPX0oooo00WZ2P1T0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo00L0
oooo1@09jPYS0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo00L0oooo
1009jPYT0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo00L0oooo0`09
jPYU0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo00H0oooo0`09jPYV
0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo00@0oooo0`0000000`09
jPX0oooo0?ooo`1U0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo00<0
oooo1@00001W0?ooo`030000003oool0oooo0040oooo00020?ooog<000000`3oool000P0oooo1@00
001[0?ooo`002@3oool3000006`0oooo001h0?ooo`00N03oool007P0oooo001h0?ooo`00N03oool0
0001\
\>"],
  ImageRangeCache->{{{0, 119}, {287, 0}} -> {-2.62503, -0.330946, 0.0441181, \
0.0441181}}]
}, Open  ]],

Cell["Here are the rays without the surface.", "Text"],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[propagatedseashellmirror, ShowComponents->False, 
\tRayPointSize -> 5, ShowText -> Hold[RaySourceNumber[[1,1]]]];\
\>", "Input",\

  CellLabel->"In[33]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.6106 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.299888 1.62313 -0.0125241 1.62313 [
[ 0 0 0 0 ]
[ 1 1.6106 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.6106 L
0 1.6106 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
[ ] 0 setdash
.65045 .5302 m
.72442 .57137 L
s
0 0 0 r
5 Mabswid
.65045 .5302 Mdot
.039 .916 .04 r
.5 Mabswid
.41976 .62641 m
.65045 .5302 L
s
.46695 .60366 m
.77247 .50001 L
s
0 0 0 r
5 Mabswid
.46695 .60366 Mdot
.039 .916 .04 r
.5 Mabswid
.43743 .76049 m
.46695 .60366 L
s
.74026 .59838 m
.56055 .51961 L
s
0 0 0 r
5 Mabswid
.74026 .59838 Mdot
.039 .916 .04 r
.5 Mabswid
.60209 .45733 m
.74026 .59838 L
s
0 0 0 r
5 Mabswid
.60209 .45733 Mdot
.039 .916 .04 r
.5 Mabswid
.72442 .57137 m
.60209 .45733 L
s
.73692 .34899 m
.39986 .27456 L
s
0 0 0 r
5 Mabswid
.73692 .34899 Mdot
.039 .916 .04 r
.5 Mabswid
.77247 .50001 m
.73692 .34899 L
s
0 0 0 r
5 Mabswid
.72442 .57137 Mdot
.77247 .50001 Mdot
.039 .916 .04 r
.5 Mabswid
.56055 .51961 m
.32094 .62221 L
s
0 0 0 r
5 Mabswid
.56055 .51961 Mdot
.039 .916 .04 r
.5 Mabswid
.32094 .62221 m
.50173 .75645 L
s
0 0 0 r
5 Mabswid
.32094 .62221 Mdot
.039 .916 .04 r
.5 Mabswid
.31014 .68221 m
.54983 .51488 L
s
0 0 0 r
5 Mabswid
.31014 .68221 Mdot
.039 .916 .04 r
.5 Mabswid
.57088 .59842 m
.31014 .68221 L
s
0 0 0 r
5 Mabswid
.57088 .59842 Mdot
.039 .916 .04 r
.5 Mabswid
.29532 .6069 m
.57088 .59842 L
s
0 0 0 r
5 Mabswid
.43743 .76049 Mdot
.039 .916 .04 r
.5 Mabswid
.39453 .56099 m
.43743 .76049 L
s
0 0 0 r
5 Mabswid
.29532 .6069 Mdot
.039 .916 .04 r
.5 Mabswid
.88598 .73712 m
.29532 .6069 L
s
.42802 1.16048 m
.86485 1.03482 L
s
0 0 0 r
5 Mabswid
.34678 1.17554 Mdot
.039 .916 .04 r
.5 Mabswid
.77302 1.09125 m
.34678 1.17554 L
s
.54983 .51488 m
.48396 .66951 L
s
0 0 0 r
5 Mabswid
.54983 .51488 Mdot
.039 .916 .04 r
.5 Mabswid
.3928 1.12715 m
.86073 .99056 L
s
.79055 .67446 m
.35995 1.51685 L
s
0 0 0 r
5 Mabswid
.79055 .67446 Mdot
.039 .916 .04 r
.5 Mabswid
.70086 .68753 m
.79055 .67446 L
s
.81592 .69501 m
.77302 1.09125 L
s
0 0 0 r
5 Mabswid
.81592 .69501 Mdot
.039 .916 .04 r
.5 Mabswid
.48396 .66951 m
.81592 .69501 L
s
.78811 .64968 m
.41976 .62641 L
s
0 0 0 r
5 Mabswid
.78811 .64968 Mdot
.039 .916 .04 r
.5 Mabswid
.86073 .99056 m
.78811 .64968 L
s
.50173 .75645 m
.70086 .68753 L
s
0 0 0 r
5 Mabswid
.50173 .75645 Mdot
.039 .916 .04 r
.5 Mabswid
.35679 1.09306 m
.82826 .95338 L
s
0 0 0 r
5 Mabswid
.88598 .73712 Mdot
.039 .916 .04 r
.5 Mabswid
.82826 .95338 m
.88598 .73712 L
s
0 0 0 r
5 Mabswid
.39986 .27456 Mdot
.039 .916 .04 r
.5 Mabswid
.7293 .52988 m
.39453 .56099 L
s
0 0 0 r
5 Mabswid
.7293 .52988 Mdot
.039 .916 .04 r
.5 Mabswid
.86485 1.03482 m
.7293 .52988 L
s
0 0 0 r
5 Mabswid
.86485 1.03482 Mdot
.86073 .99056 Mdot
.77302 1.09125 Mdot
.39453 .56099 Mdot
.41976 .62641 Mdot
.82826 .95338 Mdot
.35995 1.51685 Mdot
.48396 .66951 Mdot
.70086 .68753 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[33]:=",
  ImageSize->{185.562, 298.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002i0001:R000`400?l00000o`00003o^@3oool0
0;T0oooo002i0?ooo`00^@3oool00;T0oooo002i0?ooo`00^@3oool00;T0oooo002i0?ooo`00^@3o
ool00;T0oooo002i0?ooo`00^@3oool00;T0oooo002i0?ooo`00^@3oool00;T0oooo002i0?ooo`00
^@3oool00;T0oooo002i0?ooo`00^@3oool00;T0oooo002i0?ooo`00^@3oool00;T0oooo002i0?oo
o`00^@3oool00;T0oooo002i0?ooo`00^@3oool00;T0oooo002i0?ooo`00^@3oool00;T0oooo002i
0?ooo`00^@3oool00;T0oooo002i0?ooo`00^@3oool00;T0oooo002i0?ooo`00^@3oool00;T0oooo
002i0?ooo`00^@3oool00;T0oooo002i0?ooo`00^@3oool004P0oooo0`00001^0?ooo`00A`3oool5
000006d0oooo00170?ooo`D00000K@3oool004L0oooo1@00000500WZ2VP0oooo00180?ooo`<00000
1P3oool500WZ2V<0oooo001F0?ooo`D02NX:GP3oool005/0oooo1@09jPYI0?ooo`00H03oool500WZ
2U@0oooo001U0?ooo`D02NX:C`3oool006X0oooo1009jPY;0?ooo`00KP3oool500WZ2TH0oooo001c
0?ooo`D02NX:@@3oool007P0oooo1@09jPXl0?ooo`00O@3oool500WZ2PD0oooo0`00000_0?ooo`00
PP3oool400WZ2PD00000;P3oool008H0oooo0P0000000`09jPX000000000000^0?ooo`00QP3oool2
0000000300WZ2P000000000002h0oooo00270?ooo`0300000009jPX0000002l0oooo00290?ooo`03
00WZ2P3oool0oooo02d0oooo00290?ooo`0300WZ2P3oool0oooo02d0oooo00290?ooo`0300WZ2P3o
ool0oooo02d0oooo00290?ooo`0300WZ2P3oool0oooo02d0oooo00290?ooo`0300WZ2P3oool0oooo
02d0oooo002:0?ooo`0300WZ2P3oool0oooo02`0oooo002:0?ooo`0300WZ2P3oool0oooo02`0oooo
002:0?ooo`0300WZ2P3oool0oooo02`0oooo002:0?ooo`0300WZ2P3oool0oooo02`0oooo002:0?oo
o`0300WZ2P3oool0oooo02`0oooo002;0?ooo`0300WZ2P3oool0oooo02/0oooo002;0?ooo`0300WZ
2P3oool0oooo02/0oooo002;0?ooo`0300WZ2P3oool0oooo02/0oooo002;0?ooo`0300WZ2P3oool0
oooo02/0oooo002<0?ooo`0300WZ2P3oool0oooo02X0oooo001^0?ooo`<000006`3oool00`09jPX0
oooo0?ooo`0Z0?ooo`00K@3oool5000001X0oooo00<02NX:0?ooo`3oool0:P3oool006d0oooo0P00
000200WZ2P030000003oool0oooo01P0oooo00<02NX:0?ooo`3oool0:P3oool006d0oooo10000000
0`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo02X0oooo001^0?ooo`<0000000<0oooo00WZ
2P3oool06@3oool00`09jPX0oooo0?ooo`0Y0?ooo`00L@3oool00`09jPX0oooo00WZ2P0I0?ooo`03
00WZ2P3oool0oooo02T0oooo001b0?ooo`0300WZ2P3oool02NX:01P0oooo00<02NX:0?ooo`3oool0
:@3oool007<0oooo00<02NX:0?ooo`09jPX05`3oool00`09jPX0oooo0?ooo`0Y0?ooo`00M03oool0
0`09jPX0oooo00WZ2P0F0?ooo`<00000:@3oool007D0oooo00<02NX:0?ooo`09jPX0503oool50000
02P0oooo001f0?ooo`0300WZ2P3oool02NX:01<0oooo1@00000X0?ooo`00I03oool300000100oooo
00<02NX:0?ooo`09jPX0403oool200WZ2PD00000:03oool006<0oooo1P00000?0?ooo`0300WZ2P3o
ool02NX:00`0oooo0`09jPX30?ooo`<00000:@3oool006<0oooo1`00000?0?ooo`0300WZ2P3oool0
2NX:00P0oooo0`09jPXb0?ooo`00H`3oool7000000d0oooo0`0000000`09jPX0oooo00WZ2P040?oo
o`<02NX:00@0oooo0000000000000000<@3oool00640oooo0P09jPX00`3oool00000000000040000
00802NX:2P3oool50000000300WZ2P3oool02NX:00<02NX:0`3oool500000300oooo001P0?ooo`D0
2NX:00@0oooo00000000000000000`3oool200WZ2PP0oooo00<0000000WZ2P09jPX00P00000400WZ
2P80oooo0`09jPX20000000300WZ2P00000000000300oooo001O0?ooo`802NX:0`3oool00`09jPX0
oooo0?ooo`070?ooo`802NX:103oool=00WZ2P<0oooo0P0000000`09jPX000000000000`0?ooo`00
G@3oool200WZ2P@0oooo00<02NX:0?ooo`3oool01P3oool<00WZ2P8000000P3oool300WZ2P030?oo
o`09jPX0oooo00<0oooo00<0000000WZ2P000000<@3oool005X0oooo0`09jPX50?ooo`X02NX:103o
ool500WZ2PT0oooo0P09jPX00`3oool02NX:0?ooo`040?ooo`0300WZ2P3oool0oooo02l0oooo0017
0?ooo`<000003@3oool<00WZ2PX0oooo1@09jPX30?ooo`802NX:2@3oool00`09jPX0oooo00WZ2P04
0?ooo`0300WZ2P3oool0oooo02l0oooo00160?ooo`D000000P3oool;00WZ2P030?ooo`09jPX0oooo
00L0oooo00<02NX:0?ooo`3oool01P3oool400WZ2PP0oooo0`09jPX70?ooo`<02NX:0`0000000`09
jPX0oooo0?ooo`0_0?ooo`00AP3oool5000000802NX:1P3oool300WZ2P80oooo00<02NX:0?ooo`3o
ool01P3oool00`09jPX0oooo0?ooo`040?ooo`@02NX:3P3oool200WZ2PH0oooo00<02NX:00000000
00000P0000000`09jPX0oooo0?ooo`0_0?ooo`00AP3oool5000000H0oooo0P09jPX30?ooo`802NX:
2@3oool00`09jPX0oooo0?ooo`020?ooo`<02NX:4`3oool200WZ2PD0oooo1@0000000`09jPX0oooo
0?ooo`0^0?ooo`00A`3oool3000000D0oooo0P09jPX40?ooo`0300WZ2P3oool0oooo00T0oooo00<0
2NX:0?ooo`09jPX00P09jPXH0?ooo`<02NX:0P3oool50000000300WZ2P3oool0oooo02h0oooo0019
0?ooo`0300WZ2P3oool0oooo00<02NX:103oool200WZ2P/0oooo1009jPXM0?ooo`802NX:00H0oooo
00000000000000000?ooo`09jPX`0?ooo`00B@3oool300WZ2PH0oooo00<02NX:0?ooo`3oool0203o
ool400WZ2PL0oooo0`00000H0?ooo`802NX:00D0oooo00WZ2P000000000000WZ2P0_0?ooo`00B03o
ool200WZ2PH0oooo0P09jPX30?ooo`<000000P3oool600WZ2PL0oooo1@00000I0?ooo`0600WZ2P00
00002NX:00000009jPX00000;P3oool003D0oooo0`00000=0?ooo`<02NX:00<0oooo00WZ2P3oool0
103oool00`09jPX0oooo0?ooo`020?ooo`D000004@09jPX2000001X0oooo0P00000200WZ2P030000
003oool0oooo02`0oooo000d0?ooo`D000002P3ooolI00WZ2P<0oooo00<02NX:0?ooo`3oool00`3o
ool200WZ2PD000006P3oool30000000300WZ2P000000oooo02d0oooo000d0?ooo`8000003@09jPX7
0?ooo`0400WZ2P3oool02NX:00WZ2PH0oooo0P0000000`09jPX00000000000050?ooo`0400WZ2P3o
ool0oooo0?ooo`<02NX:0`3oool3000001`0oooo0`0000000`09jPX0oooo0?ooo`0/0?ooo`00=03o
ool5000000P02NX:2@3oool200WZ2PL0oooo0P09jPX00`0000002NX:000000060?ooo`@02NX::03o
ool00`09jPX0oooo0?ooo`0/0?ooo`00=@3oool3000000030?ooo`000000000000<000001009jPX7
0?ooo`802NX:00@0oooo00000000000000000P3oool200WZ2P80oooo00<02NX:0?ooo`3oool0103o
ool300WZ2R/0oooo00<02NX:0?ooo`3oool0;03oool003T0oooo1@0000040?ooo`D02NX:00@0oooo
00WZ2P3oool02NX:1@0000000`09jPX0oooo0?ooo`020?ooo`0400WZ2P3oool0oooo0?ooo`<02NX:
00<0oooo00WZ2P3oool0:`3oool00`09jPX0oooo0?ooo`0/0?ooo`00>@3oool5000000P0oooo1@09
jPX5000000T02NX:103oool00`09jPX0oooo0?ooo`0[0?ooo`0300WZ2P3oool0oooo02/0oooo000j
0?ooo`<0000000<0oooo00WZ2P3oool01@3oool00`09jPX0oooo0?ooo`030?ooo`D000000`3oool3
00WZ2P030?ooo`09jPX02NX:00l02NX:8`3oool00`09jPX0oooo0?ooo`0[0?ooo`00?`3oool200WZ
2P<0oooo00<02NX:0?ooo`3oool0103oool01@09jPX00000000000000000oooo00H02NX:1P3oool0
0`09jPX0oooo0?ooo`090?oooa402NX:4P3oool00`09jPX0oooo0?ooo`020?ooo`<000009P3oool0
0440oooo0`09jPX70?ooo`0300WZ2P3oool02NX:00802NX:103oool500WZ2P80oooo00<02NX:0?oo
o`3oool06`3ooolA00WZ2P80oooo00<02NX:0?ooo`3oool01@00000U0?ooo`00@@3oool200WZ2PL0
oooo0`09jPX70?ooo`0300WZ2P3oool0oooo0080oooo1@09jPX/0?ooo`D02NX:0P0000000`09jPX0
00000000000U0?ooo`00?`3oool200WZ2P80oooo0P09jPX20?ooo`<02NX:0P3oool00`09jPX0oooo
0?ooo`050?ooo`0300WZ2P3oool0oooo00<0oooo00@02NX:0?ooo`3oool0oooo1009jPXZ0?ooo`03
00WZ2P3oool0oooo0080000000<02NX:0000000000009@3oool003h0oooo00<02NX:0?ooo`3oool0
0`3oool300WZ2PD0oooo00<02NX:0?ooo`3oool01@3oool01009jPX0oooo0?ooo`3oool3000000L0
oooo1@09jPXU0?ooo`0700WZ2P3oool0oooo0?ooo`0000002NX:0000000V0?ooo`00?@3oool01009
jPX0oooo0?ooo`3oool300WZ2P80oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`05
0?ooo`0300WZ2P3oool0oooo00D000002`3oool400WZ2R80oooo00<02NX:0?ooo`0000000P000000
0`09jPX000000?ooo`0T0?ooo`00>03oool3000000802NX:00@0oooo00WZ2P09jPX02NX:1P3oool2
00WZ2P<0oooo00<02NX:0?ooo`3oool0103oool01009jPX0oooo0?ooo`3oool5000000H02NX:2@3o
ool500WZ2Qd0oooo1P09jPX00`000000oooo0?ooo`0S0?ooo`00=`3oool4000000<02NX:2`3oool0
1@09jPX0oooo0?ooo`3oool02NX:00D0oooo00@02NX:0?ooo`3oool0oooo1@0000060?oooa802NX:
303oool3000000H0oooo1@09jPX01P3oool000000000000000002NX:000002D0oooo000g0?ooo`80
00000P09jPX00`000000oooo0?ooo`0<0?ooo`0400WZ2P3oool0oooo00WZ2PD0oooo00<02NX:0?oo
o`3oool00P3oool3000001H0oooo3P09jPX5000000D02NX:103oool00`09jPX0oooo0?ooo`020000
000300WZ2P3oool0oooo00<000008@3oool003L0oooo1@00000?0?ooo`<02NX:1@3oool00`09jPX0
oooo0?ooo`0S0?ooo`@02NX:0P3oool5000000/02NX:00D0oooo00WZ2P3oool02NX:0?ooo`050000
0200oooo000h0?ooo`<000004P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo02L0
oooo0P09jPX5000000X0oooo2@09jPX200000200oooo001=0?ooo`802NX:0`3oool00`09jPX0oooo
0?ooo`0U0?ooo`<02NX:0`3oool3000000<02NX:203oool200WZ2P<0oooo00<02NX:000000000000
0`00000P0?ooo`00CP3oool200WZ2P80oooo00<02NX:0?ooo`3oool08P3oool300WZ2P`0oooo1@09
jPX30?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`0000000P00000Q0?ooo`00CP3oool0
0`09jPX0oooo00WZ2P0200WZ2R40oooo0`09jPXD0?ooo`D02NX:0`3oool01009jPX0oooo0?ooo`09
jPXR0?ooo`00CP3oool01@09jPX0oooo0?ooo`3oool02NX:01h0oooo0`09jPXI0?ooo`0300WZ2P3o
ool02NX:00@02NX:0P3oool00`09jPX0oooo0?ooo`0P0?ooo`00CP3oool01009jPX0oooo0?ooo`3o
ool200WZ2QX0oooo0`09jPXL0?ooo`0300WZ2P3oool02NX:00@0oooo1@09jPXP0?ooo`00C`3oool0
0`09jPX0oooo00WZ2P020?ooo`802NX:5P3oool200WZ2Qh0oooo00D02NX:0?ooo`3oool0oooo00WZ
2P030?ooo`802NX:0`3oool400WZ2PD0oooo0`00000D0?ooo`00C`3oool00`09jPX0oooo00WZ2P04
0?ooo`0300WZ2P3oool0oooo0100oooo0`09jPXP0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX00`3o
ool200WZ2PL0oooo1009jPX5000001<0oooo001?0?ooo`0300WZ2P3oool02NX:00D0oooo00<02NX:
0?ooo`3oool0303oool300WZ2R80oooo00<02NX:0?ooo`3oool00P3oool01009jPX0oooo0?ooo`3o
ool200WZ2P/0oooo0P0000000`09jPX000000000000C0?ooo`00C`3oool00`09jPX0oooo00WZ2P06
0?ooo`802NX:2@3oool300WZ2RD0oooo00<02NX:0?ooo`3oool00P3oool01009jPX0oooo0?ooo`3o
ool200WZ2P/0oooo0P0000000`09jPX000000000000C0?ooo`00C`3oool00`09jPX0000000000008
0?ooo`0400WZ2P000000000000000080oooo0`09jPXW0?ooo`0300WZ2P3oool0oooo00@0oooo00D0
2NX:0?ooo`3oool0oooo00WZ2P0<0?ooo`0300000009jPX0000001@0oooo001>0?ooo`80000000<0
2NX:0000000000001`3oool50000000300WZ2P3oool0oooo02P0oooo00<02NX:0?ooo`3oool0103o
ool01@09jPX0oooo0?ooo`3oool02NX:00`0oooo00<02NX:0?ooo`3oool0503oool004h0oooo0P00
00000`09jPX00000000000070?ooo`D00000:P3oool00`09jPX0oooo0?ooo`050?ooo`0500WZ2P3o
ool0oooo0?ooo`09jPX0303oool00`09jPX0oooo0?ooo`0D0?ooo`00CP3oool5000000L0oooo1@00
000Z0?ooo`0300WZ2P3oool0oooo00D0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0<0?ooo`0300WZ
2P3oool0oooo01@0oooo001?0?ooo`<000002@3oool3000002X0oooo00<02NX:0?ooo`3oool01`3o
ool01009jPX0oooo0?ooo`09jPX;0?ooo`0300WZ2P3oool0oooo01D0oooo00280?ooo`0300WZ2P3o
ool0oooo00L0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P0:0?ooo`0300WZ2P3oool0oooo01D0oooo
00270?ooo`0300WZ2P3oool0oooo00P0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P0:0?ooo`0300WZ
2P3oool0oooo01D0oooo00270?ooo`0300WZ2P3oool0oooo00T0oooo0P09jPX00`3oool02NX:0?oo
o`090?ooo`0300WZ2P3oool0oooo01D0oooo00260?ooo`0300WZ2P3oool0oooo00X0oooo0P09jPX0
0`3oool02NX:0?ooo`080?ooo`0300WZ2P3oool0oooo01H0oooo00260?ooo`0300WZ2P3oool0oooo
00X0oooo0P09jPX00`3oool02NX:0?ooo`080?ooo`0300WZ2P3oool0oooo01H0oooo00250?ooo`03
00WZ2P3oool0oooo00/0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3o
ool05P3oool008D0oooo00<02NX:0?ooo`3oool0303oool01009jPX0oooo0?ooo`09jPX80?ooo`03
00WZ2P3oool0oooo01H0oooo00240?ooo`0300WZ2P3oool0oooo00d0oooo00@02NX:0?ooo`3oool0
2NX:1`3oool00`09jPX0oooo0?ooo`0G0?ooo`00Q03oool00`09jPX0oooo0?ooo`0=0?ooo`0400WZ
2P3oool0oooo00WZ2PL0oooo00<02NX:0?ooo`3oool05`3oool008<0oooo00<02NX:0?ooo`3oool0
3@3oool200WZ2P<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0G0?ooo`00P`3o
ool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`0H0?ooo`00PP3oool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool0
2NX:0080oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0H0?ooo`00PP3oool00`09
jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00`3oool00`09
jPX0oooo0?ooo`0H0?ooo`00P@3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool02NX:0080
oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0H0?ooo`00P@3oool00`09jPX0oooo
0?ooo`0?0?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00D02NX:0?ooo`3oool0oooo00WZ2P0K0?oo
o`00P03oool00`09jPX0oooo0?ooo`0@0?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00D02NX:0?oo
o`3oool0oooo00WZ2P0K0?ooo`00P03oool00`09jPX0oooo0?ooo`0@0?ooo`0400WZ2P3oool0oooo
00WZ2P80oooo00D02NX:0?ooo`3oool0oooo00WZ2P0K0?ooo`00O`3oool00`09jPX0oooo0?ooo`0A
0?ooo`0700WZ2P3oool0oooo0?ooo`09jPX0oooo00WZ2P030?ooo`0300WZ2P3oool0oooo01T0oooo
001o0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo00WZ
2P020?ooo`0300WZ2P3oool0oooo01X0oooo001n0?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:
0?ooo`3oool00P3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2Q`0oooo001n0?ooo`0300WZ2P3o
ool0oooo0140oooo00<02NX:0?ooo`3oool00P3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2Q`0
oooo001m0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool00`3oool01009jPX0oooo
00WZ2P09jPXM0?ooo`00O03oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00<0oooo
00@02NX:0?ooo`09jPX02NX:7@3oool007`0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo
0?ooo`030?ooo`0400WZ2P3oool02NX:00WZ2Qd0oooo001k0?ooo`0300WZ2P3oool0oooo01@0oooo
00<02NX:0?ooo`3oool00`3oool01009jPX0oooo0?ooo`09jPXM0?ooo`00N`3oool00`09jPX0oooo
0?ooo`0D0?ooo`0300WZ2P3oool0oooo00@0oooo0`09jPXM0?ooo`00NP3oool00`09jPX0oooo0?oo
o`0E0?ooo`0300WZ2P3oool0oooo00@0oooo0`09jPXM0?ooo`00NP3oool00`09jPX0oooo0?ooo`0D
0?ooo`0300WZ2P3oool0oooo00D0oooo0`09jPXM0?ooo`00N@3oool00`09jPX0oooo0?ooo`0E0?oo
o`0300WZ2P3oool0oooo00D0oooo0`09jPXM0?ooo`00N@3oool00`09jPX0oooo0?ooo`0E0?ooo`03
00WZ2P3oool0oooo00D0oooo0P09jPX00`3oool02NX:0?ooo`0K0?ooo`00N03oool00`09jPX0oooo
0?ooo`0F0?ooo`0300WZ2P3oool0oooo00D0oooo0P09jPX00`3oool02NX:0?ooo`0K0?ooo`00N03o
ool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo00<0oooo0`0000000`09jPX0oooo00WZ
2P0L0?ooo`00M`3oool00`09jPX0oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo0080oooo1@000002
00WZ2Q`0oooo001g0?ooo`0300WZ2P3oool0oooo01L0oooo00<02NX:0?ooo`3oool00P3oool50000
00802NX:703oool007H0oooo00<02NX:0?ooo`3oool0603oool00`09jPX0oooo00WZ2P0200WZ2PD0
000000<02NX:0?ooo`09jPX06`3oool007H0oooo00<02NX:0?ooo`3oool05`3oool300WZ2P@0oooo
0`000000103oool02NX:0?ooo`09jPXK0?ooo`00M@3oool00`09jPX0oooo0?ooo`0D0?ooo`D02NX:
2`3oool200WZ2Q/0oooo001e0?ooo`0300WZ2P3oool0oooo0140oooo0`09jPX40?ooo`0300WZ2P3o
ool0oooo00T0oooo0P09jPXK0?ooo`00M03oool00`09jPX0oooo0?ooo`0?0?ooo`<02NX:1`3oool0
0`09jPX0oooo0?ooo`090?ooo`0400WZ2P0000000000000001T0oooo001d0?ooo`0300WZ2P3oool0
oooo00/0oooo1009jPX:0?ooo`0300WZ2P3oool0oooo00T0oooo1@00000H0?ooo`00L`3oool00`09
jPX0oooo0?ooo`090?ooo`<02NX:3P3oool00`09jPX0oooo0?ooo`090?ooo`D00000603oool007<0
oooo00<02NX:0?ooo`3oool01P3oool300WZ2Q40oooo00<02NX:0?ooo`3oool01P3oool300WZ2PD0
0000603oool00780oooo00<02NX:0?ooo`3oool00`3oool400WZ2Q@0oooo00<02NX:0?ooo`3oool0
0P3oool400WZ2P@0oooo0`00000I0?ooo`00LP3oool00`09jPX0oooo0?ooo`0300WZ2QP0oooo00<0
2NX:0?ooo`09jPX00P09jPX90?ooo`0300WZ2P3oool0oooo01P0oooo001a0?ooo`@02NX:6P3oool3
00WZ2P`0oooo00<02NX:0?ooo`3oool0603oool006h0oooo1009jPXI0?ooo`D02NX:3P3oool00`09
jPX0oooo0?ooo`0H0?ooo`00J`3oool300WZ2P80oooo00<02NX:0?ooo`3oool05@3oool300WZ2P@0
oooo00<02NX:0?ooo`3oool0303oool3000001P0oooo001W0?ooo`@02NX:1@3oool00`09jPX0oooo
0?ooo`0A0?ooo`@02NX:1`3oool00`09jPX0oooo0?ooo`0;0?ooo`D000005`3oool006@0oooo0`09
jPX80?ooo`0300WZ2P3oool0oooo00l0oooo0`09jPX;0?ooo`0300WZ2P3oool0oooo00/0oooo1@00
000G0?ooo`00H@3oool300WZ2P/0oooo00<02NX:0?ooo`3oool02`3oool400WZ2Ph0oooo00<02NX:
0?ooo`3oool0203oool300WZ2PD000005`3oool005d0oooo1009jPX=0?ooo`0300WZ2P3oool0oooo
00T0oooo0`09jPXB0?ooo`0300WZ2P3oool0oooo00@0oooo1009jPX40?ooo`<00000603oool005X0
oooo0`09jPXA0?ooo`0300WZ2P3oool0oooo00D0oooo1009jPXE0?ooo`0400WZ2P3oool0oooo0?oo
o`<02NX:8`3oool005L0oooo0`09jPXC0?ooo`0300WZ2P3oool0oooo00<0oooo0`09jPXI0?ooo`@0
2NX:9P3oool005<0oooo1009jPXF0?ooo`0300WZ2P3oool0oooo00<02NX:6@3oool400WZ2RT0oooo
001@0?ooo`<02NX:6@3oool400WZ2QP0oooo1009jPX20?ooo`0300WZ2P3oool0oooo02P0oooo001=
0?ooo`<02NX:6@3oool400WZ2QP0oooo0`09jPX60?ooo`0300WZ2P3oool0oooo02P0oooo00190?oo
o`@02NX:603oool400WZ2P80oooo00<02NX:0?ooo`3oool04`3oool400WZ2PP0oooo0`00000Y0?oo
o`00AP3oool300WZ2QT0oooo0`09jPX60?ooo`0300WZ2P3oool0oooo0100oooo0`09jPX;0?ooo`D0
0000:03oool004<0oooo0`09jPXH0?ooo`@02NX:203oool00`09jPX0oooo0?ooo`0=0?ooo`@02NX:
3P3oool5000002P0oooo00110?ooo`802NX:603oool300WZ2P`0oooo00<02NX:0?ooo`3oool02@3o
ool400WZ2Pd0oooo1@09jPX5000002P0oooo001G0?ooo`@02NX:3P3oool00`09jPX0oooo0?ooo`07
0?ooo`<02NX:303oool500WZ2PH0oooo0`00000Y0?ooo`00E03oool300WZ2Q80oooo00<02NX:0?oo
o`3oool00`3oool400WZ2PX0oooo1@09jPXg0?ooo`00D@3oool300WZ2Q@0oooo00@02NX:0?ooo`3o
ool0oooo0`09jPX90?ooo`D02NX:?03oool004d0oooo1009jPXG0?ooo`@02NX:1`3oool500WZ2T40
oooo001:0?ooo`<02NX:603oool300WZ2PH0oooo1@09jPY60?ooo`00B03oool200WZ2QL0oooo1009
jPX20?ooo`0300WZ2P3oool02NX:00@02NX:B`3oool005h0oooo0`09jPX40?ooo`@02NX:D03oool0
05X0oooo1009jPX20?ooo`D02NX:00<0oooo00WZ2P3oool0D@3oool005L0oooo0`09jPX00`3oool0
2NX:00WZ2P0300WZ2PD0oooo00<02NX:0?ooo`3oool0D@3oool005<0oooo2009jPX:0?ooo`0300WZ
2P3oool0oooo0540oooo001@0?ooo`H02NX:3P3oool00`09jPX0oooo0?ooo`1B0?ooo`00C03oool5
00WZ2Q<0oooo00<02NX:0?ooo`3oool0DP3oool003l0oooo0`0000050?ooo`D02NX:5`3oool00`09
jPX0oooo0?ooo`1C0?ooo`00?P3oool4000000D02NX:703oool00`09jPX0oooo0?ooo`1C0?ooo`00
?P3oool2000000802NX:00<000000?ooo`3oool07@3oool00`09jPX0oooo0?ooo`1D0?ooo`00?P3o
ool5000001l0oooo00<02NX:0?ooo`3oool0E03oool003l0oooo0`00000O0?ooo`0300WZ2P3oool0
oooo05D0oooo001Q0?ooo`0300WZ2P3oool0oooo05D0oooo001P0?ooo`0300WZ2P3oool0oooo05H0
oooo001P0?ooo`0300WZ2P3oool0oooo05H0oooo001O0?ooo`0300WZ2P3oool0oooo05L0oooo001O
0?ooo`0300WZ2P3oool0oooo05L0oooo001N0?ooo`0300WZ2P3oool0oooo05P0oooo001N0?ooo`03
00WZ2P3oool0oooo05P0oooo001M0?ooo`0300WZ2P3oool0oooo05T0oooo001M0?ooo`0300WZ2P3o
ool0oooo05T0oooo001L0?ooo`0300WZ2P3oool0oooo05X0oooo001L0?ooo`0300WZ2P3oool0oooo
05X0oooo001K0?ooo`0300WZ2P3oool0oooo05/0oooo001K0?ooo`0300WZ2P3oool0oooo05/0oooo
001J0?ooo`0300WZ2P3oool0oooo05`0oooo001J0?ooo`0300WZ2P3oool0oooo05`0oooo001I0?oo
o`0300WZ2P3oool0oooo05d0oooo001I0?ooo`0300WZ2P3oool0oooo05d0oooo001H0?ooo`0300WZ
2P3oool0oooo05h0oooo001H0?ooo`0300WZ2P3oool0oooo05h0oooo001G0?ooo`0300WZ2P3oool0
oooo05l0oooo001G0?ooo`0300WZ2P3oool0oooo05l0oooo001F0?ooo`0300WZ2P3oool0oooo0600
oooo001E0?ooo`0300WZ2P3oool0oooo0640oooo001E0?ooo`0300WZ2P3oool0oooo0640oooo001D
0?ooo`0300WZ2P3oool0oooo0680oooo001D0?ooo`0300WZ2P3oool0oooo0680oooo001C0?ooo`03
00WZ2P3oool0oooo06<0oooo001C0?ooo`0300WZ2P3oool0oooo06<0oooo001B0?ooo`0300WZ2P3o
ool0oooo06@0oooo001B0?ooo`0300WZ2P3oool0oooo06@0oooo001A0?ooo`0300WZ2P3oool0oooo
06D0oooo001A0?ooo`0300WZ2P3oool0oooo06D0oooo001@0?ooo`0300WZ2P3oool0oooo06H0oooo
001@0?ooo`0300WZ2P3oool0oooo06H0oooo001?0?ooo`0300WZ2P3oool0oooo06L0oooo001?0?oo
o`0300WZ2P3oool0oooo06L0oooo001>0?ooo`0300WZ2P3oool0oooo06P0oooo001>0?ooo`0300WZ
2P3oool0oooo06P0oooo001=0?ooo`0300WZ2P3oool0oooo06T0oooo001=0?ooo`0300WZ2P3oool0
oooo06T0oooo001<0?ooo`0300WZ2P3oool0oooo06X0oooo001<0?ooo`0300WZ2P3oool0oooo06X0
oooo001;0?ooo`0300WZ2P3oool0oooo06/0oooo001;0?ooo`0300WZ2P3oool0oooo06/0oooo001:
0?ooo`0300WZ2P3oool0oooo06`0oooo001:0?ooo`0300WZ2P3oool0oooo06`0oooo00190?ooo`03
00WZ2P3oool0oooo06d0oooo00190?ooo`0300WZ2P3oool0oooo06d0oooo00180?ooo`0300WZ2P3o
ool0oooo06h0oooo00180?ooo`0300WZ2P3oool0oooo06h0oooo00170?ooo`0300WZ2P3oool0oooo
06l0oooo00170?ooo`0300WZ2P3oool0oooo06l0oooo00160?ooo`0300WZ2P3oool0oooo0700oooo
00160?ooo`0300WZ2P3oool0oooo0700oooo00150?ooo`0300WZ2P3oool0oooo0740oooo00150?oo
o`0300WZ2P3oool0oooo0740oooo00140?ooo`0300WZ2P3oool0oooo0780oooo00140?ooo`0300WZ
2P3oool0oooo0780oooo00110?ooo`<00000M@3oool00400oooo1@00001d0?ooo`00@03oool50000
07@0oooo00100?ooo`D00000M03oool00440oooo0`00001e0?ooo`00^@3oool00;T0oooo002i0?oo
o`00^@3oool00;T0oooo002i0?ooo`00^@3oool00;T0oooo002i0?ooo`00^@3oool00;T0oooo002i
0?ooo`00^@3oool00;T0oooo002i0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 184.562}, {297.812, 0}} -> {0.184756, 0.00678282, \
0.00333816, 0.00333816}}]
}, Open  ]],

Cell["Altogether, 31 intersections are found.", "Text"],

Cell[CellGroupData[{

Cell["Length[First[propagatedseashellmirror]]", "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(31\)], "Output",
  CellLabel->"Out[34]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1920}, {0, 1174}},
ScreenStyleEnvironment->"AllBrackets",
WindowSize->{1208, 1010},
WindowMargins->{{46, Automatic}, {33, Automatic}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 47, 0, 52, "Section"],
Cell[1826, 55, 378, 8, 40, "Text"],

Cell[CellGroupData[{
Cell[2229, 67, 32, 0, 36, "Subsection"],

Cell[CellGroupData[{
Cell[2286, 71, 44, 0, 34, "Subsubsection"],
Cell[2333, 73, 58, 0, 30, "Text"],
Cell[2394, 75, 126, 4, 27, "Input"],
Cell[2523, 81, 153, 5, 42, "Input"],
Cell[2679, 88, 181, 6, 57, "Input"],
Cell[2863, 96, 298, 8, 102, "Input"],
Cell[3164, 106, 133, 4, 27, "Input"],
Cell[3300, 112, 56, 0, 30, "Text"],
Cell[3359, 114, 89, 1, 27, "Input"],
Cell[3451, 117, 176, 6, 57, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3664, 128, 30, 0, 34, "Subsubsection"],
Cell[3697, 130, 48, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[3770, 134, 246, 14, 192, "Input"],
Cell[4019, 150, 198804, 8431, 296, 149170, 7813, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[202872, 8587, 42, 0, 34, "Subsubsection"],
Cell[202917, 8589, 137, 5, 24, "Text"],

Cell[CellGroupData[{
Cell[203079, 8598, 299, 16, 249, "Input"],
Cell[203381, 8616, 791, 15, 114, "Output"]
}, Open  ]],
Cell[204187, 8634, 570, 10, 58, "Text"],

Cell[CellGroupData[{
Cell[204782, 8648, 377, 8, 164, "Input"],
Cell[205162, 8658, 1309, 25, 159, "Output"]
}, Open  ]],
Cell[206486, 8686, 137, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[206648, 8693, 67, 1, 28, "Input"],
Cell[206718, 8696, 66, 2, 21, "Output"]
}, Open  ]],
Cell[206799, 8701, 203, 6, 25, "Text"],

Cell[CellGroupData[{
Cell[207027, 8711, 145, 4, 28, "Input"],
Cell[207175, 8717, 452064, 15450, 294, 417909, 15023, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[659254, 24170, 113, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[659392, 24177, 149, 4, 42, "Input"],
Cell[659544, 24183, 493488, 17504, 294, 456685, 17045, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1153035, 41689, 94, 2, 26, "Output"]
}, Open  ]],
Cell[1153144, 41694, 185, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[1153354, 41702, 192, 5, 57, "Input"],
Cell[1153549, 41709, 125518, 3270, 296, 28587, 2068, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1279128, 44986, 27, 0, 36, "Subsection"],
Cell[1279158, 44988, 49, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[1279232, 44992, 243, 7, 96, "Input"],
Cell[1279478, 45001, 94, 2, 21, "Output"]
}, Open  ]],
Cell[1279587, 45006, 76, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[1279688, 45010, 126, 4, 28, "Input"],
Cell[1279817, 45016, 250564, 6772, 294, 208395, 6246, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1530396, 51791, 50, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[1530471, 51795, 172, 5, 45, "Input"],
Cell[1530646, 51802, 73097, 2742, 294, 32977, 2241, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1603758, 54547, 54, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[1603837, 54551, 176, 5, 45, "Input"],
Cell[1604016, 54558, 21868, 484, 305, 3243, 249, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1625899, 55045, 55, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[1625979, 55049, 81, 1, 27, "Input"],
Cell[1626063, 55052, 61, 2, 26, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

